(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   8208092,     143579]
NotebookOptionsPosition[   7670110,     136021]
NotebookOutlinePosition[   8094545,     141740]
CellTagsIndexPosition[   8088216,     141553]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Optica User Guide",
 FontSlant->"Italic"]], "Chapter",
 CellChangeTimes->{{3.614732227401032*^9, 3.614732229700718*^9}},
 FontSize->72,
 CellTags->{
  "list of topics", "Components and Sources", "TurboPlot", 
   "Getting Started Introduction", 
   "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", 
   "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", 
   "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", 
   "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database",
    "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", 
   "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", 
   "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", 
   "RG21.", "RG22."},ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["1. Introduction",
 BaseStyle->"Hyperlink",
 ButtonData:>"1."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, Inherited}},
 CellTags->{
  "Optica User Guide Introduction", 
   "RG1."},ExpressionUUID->"dc0a96d6-42ba-4e7e-a04b-d1cd188e123c"],

Cell[TextData[{
 ButtonBox["Loading Optica",
  BaseStyle->"Hyperlink",
  ButtonData:>"Loading"],
 ButtonBox["\nA basic Optica example",
  BaseStyle->"Hyperlink",
  ButtonData:>"Optica Example"],
 ButtonBox["\nInputting data",
  BaseStyle->"Hyperlink",
  ButtonData:>"Data"],
 ButtonBox["\nModelling an optical system",
  BaseStyle->"Hyperlink",
  ButtonData:>"Optical System"],
 ButtonBox["\nVariable definition",
  BaseStyle->"Hyperlink",
  ButtonData:>"Variable"],
 ButtonBox["\nBasic Commands",
  BaseStyle->"Hyperlink",
  ButtonData:>"Basic Commands"],
 ButtonBox["\nUsing Options",
  BaseStyle->"Hyperlink",
  ButtonData:>"Options"],
 ButtonBox["\nOptica's high-level functions",
  BaseStyle->"Hyperlink",
  ButtonData:>"High-Level Functions"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "Optica User Guide Introduction", 
   "RG1."},ExpressionUUID->"e0c4d643-70f6-4836-9c40-03b74debd9f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["2. Modeling Optical Components and Light Sources",
 BaseStyle->"Hyperlink",
 ButtonData:>"2."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"4a364c6c-e761-4046-a86f-d89ea8625e78"],

Cell[TextData[{
 ButtonBox["Modeling a light source",
  BaseStyle->"Hyperlink",
  ButtonData:>"Modeling a light source"],
 "\n",
 ButtonBox["Ray versus TurboRays",
  BaseStyle->"Hyperlink",
  ButtonData:>"Ray versus TurboRays"],
 "\n",
 ButtonBox["How Optica manages default light source settings",
  BaseStyle->"Hyperlink",
  ButtonData:>"How Rayica manages default light source settings"],
 "\n",
 ButtonBox["Modeling an optical component",
  BaseStyle->"Hyperlink",
  ButtonData:>"Modeling an optical component"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"6b27a151-f4f4-4956-b667-3be01c6cdcfb"]
}, Open  ]],

Cell[TextData[ButtonBox["3. Introduction to the AnalyzeSystem and TurboPlot",
 BaseStyle->"Hyperlink",
 ButtonData:>"3."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"8e43a153-945d-443c-a0cc-85ec2123aaf5"],

Cell[TextData[ButtonBox["4. The Move Function",
 BaseStyle->"Hyperlink",
 ButtonData:>"4."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"b74d67e9-0c5c-4ce5-8590-e9aa832807f4"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["5. Using AnalyzeSystem for Ray Tracing",
 BaseStyle->"Hyperlink",
 ButtonData:>"5."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "AnalyzeSystem", 
   "RG5."},ExpressionUUID->"64fd74ad-0072-470b-b3f7-9f300bdb4b0d"],

Cell[TextData[{
 ButtonBox["Tracing a single ray",
  BaseStyle->"Hyperlink",
  ButtonData:>"Tracing a single ray"],
 "\n",
 ButtonBox["Working with the ray-trace data",
  BaseStyle->"Hyperlink",
  ButtonData:>"Working with the ray-trace data"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "AnalyzeSystem", 
   "RG5."},ExpressionUUID->"d60aceae-7f54-4a23-b259-fa147cdc1f4a"]
}, Open  ]],

Cell[TextData[ButtonBox["6. The ShowSystem Function",
 BaseStyle->"Hyperlink",
 ButtonData:>"6."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"d874da31-c29b-488e-bdbc-ce9772b4d92a"],

Cell[TextData[ButtonBox["7. Tracing a Cone of Rays",
 BaseStyle->"Hyperlink",
 ButtonData:>"7."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"6173a065-e587-4289-b359-1a97c194207a"],

Cell[TextData[ButtonBox["8. Adding a Cylindrical Lens to the System",
 BaseStyle->"Hyperlink",
 ButtonData:>"8."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"366e34ac-5a23-4e5e-9912-7d62cad0673b"],

Cell[TextData[ButtonBox["9. The RayChoice Option",
 BaseStyle->"Hyperlink",
 ButtonData:>"9."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"27036f11-17b1-419a-9225-d2efc422b35e"],

Cell[TextData[ButtonBox["10. Using Screen to Look at the Focal Plane",
 BaseStyle->"Hyperlink",
 ButtonData:>"10."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"b0f5a7c1-8385-4a35-8868-0d36a17dc819"],

Cell[TextData[ButtonBox["11. The ShowRange Option",
 BaseStyle->"Hyperlink",
 ButtonData:>"11."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"5d01d7a9-8738-4410-9bb4-b920f68abd19"],

Cell[TextData[ButtonBox["12. The ReadRays Function",
 BaseStyle->"Hyperlink",
 ButtonData:>"12."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"4fdc0240-d792-44aa-9a7d-d69a91f27981"],

Cell[TextData[ButtonBox["13. The PropagateSystem Function",
 BaseStyle->"Hyperlink",
 ButtonData:>"13."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"a77b774e-25e0-4f93-8238-7d0210d8bc9d"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["14. Using TurboPlot for High-Speed Ray Tracing and \
Rendering",
 BaseStyle->"Hyperlink",
 ButtonData:>"14."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "TurboPlot", 
   "RG14."},ExpressionUUID->"c87a726b-0d67-4996-9dac-7542c014ef85"],

Cell[TextData[{
 ButtonBox["AnalyzeSystem versus TurboPlot",
  BaseStyle->"Hyperlink",
  ButtonData:>"AnalyzeSystem versus TurboPlot"],
 "\n",
 ButtonBox["CreateClones",
  BaseStyle->"Hyperlink",
  ButtonData:>"CreateClones"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "TurboPlot", 
   "RG14."},ExpressionUUID->"864d8473-2564-4695-84d1-669e9e4ec4c7"]
}, Open  ]],

Cell[TextData[ButtonBox["15. Optimization with OptimizeSystem",
 BaseStyle->"Hyperlink",
 ButtonData:>"15."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"17e5c49d-2fae-46d7-9e75-4d321d6f1a9c"],

Cell[TextData[ButtonBox["16. ReadRays with TurboTrace and TurboPlot",
 BaseStyle->"Hyperlink",
 ButtonData:>"16."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"bc59ff48-ba49-4640-979c-25cf3357c9ad"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["17. Energy Calculations with FindIntensity",
 BaseStyle->"Hyperlink",
 ButtonData:>"17."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "FindIntensity", 
   "RG17."},ExpressionUUID->"0225a6ed-e4de-45a0-bf44-173443ff56f9"],

Cell[TextData[{
 ButtonBox["2-D Calculations with FindIntensity",
  BaseStyle->"Hyperlink",
  ButtonData:>"2-D Calculations with FindIntensity"],
 "\n",
 ButtonBox["FindFocus",
  BaseStyle->"Hyperlink",
  ButtonData:>"FindFocus"],
 "\n",
 ButtonBox["Measuring the Point Spread Function",
  BaseStyle->"Hyperlink",
  ButtonData:>"Point Spread Function"],
 "\n",
 ButtonBox["Measuring the Modulation Transfer Function",
  BaseStyle->"Hyperlink",
  ButtonData:>"ModulationTransferFunction"],
 "\n",
 ButtonBox["1-D Calculations with FindIntensity",
  BaseStyle->"Hyperlink",
  ButtonData:>"1-D Calculations with FindIntensity"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "FindIntensity", 
   "RG17."},ExpressionUUID->"69e7edd6-dba9-4da0-af18-6eb332da20ac"]
}, Open  ]],

Cell[TextData[ButtonBox["18. The Resonate Function",
 BaseStyle->"Hyperlink",
 ButtonData:>"18."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"7ae9b663-367a-4311-8677-e276b0672d16"],

Cell[TextData[ButtonBox["19. Optica's Database",
 BaseStyle->"Hyperlink",
 ButtonData:>"19."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"ef984e6b-ab68-43bb-afb9-ca465f2a990c"],

Cell[TextData[ButtonBox["20. The TransferTraits Function",
 BaseStyle->"Hyperlink",
 ButtonData:>"20."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"080fecd6-06a0-444a-b8dd-234d550a7beb"],

Cell[CellGroupData[{

Cell[TextData[ButtonBox["21. What's Missing?",
 BaseStyle->"Hyperlink",
 ButtonData:>"21."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"fdeeb244-3332-43ca-95c2-6c4de1b3d371"],

Cell[TextData[{
 ButtonBox["Features not discussed here",
  BaseStyle->"Hyperlink",
  ButtonData:>"Features not discussed here"],
 "\n",
 ButtonBox["Features not covered in the basic package",
  BaseStyle->"Hyperlink",
  ButtonData:>"Features not covered in the basic package"],
 "\n",
 ButtonBox["Features left to the future",
  BaseStyle->"Hyperlink",
  ButtonData:>"Features left to the future"]
}], "Outline3",
 CellMargins->{{Inherited, Inherited}, {2, 2}},
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"3eb4baaf-4492-4fa0-a5de-09e6ad2f6df5"]
}, Open  ]],

Cell[TextData[ButtonBox["22. Backward Compatibility Issues",
 BaseStyle->"Hyperlink",
 ButtonData:>"22."]], "Outline2",
 CellMargins->{{Inherited, Inherited}, {2, 
   2}},ExpressionUUID->"1aa6e449-50c0-46db-a167-7167ccfb2930"],

Cell[CellGroupData[{

Cell["1. Introduction", "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", 
   "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", 
   "RG1.0"},ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3"],

Cell[TextData[{
 "Nearly every optical engineering endeavor can benefit from the use of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", including but not limited to: optimization, lasers and resonators, \
non-sequential calculations, stray-light analysis, time-dependent optical \
systems, imaging systems, spectroscopic measurement, astronomical systems, \
solar concentrators, fiber-optic systems, opto-mechanical systems, \
polarization calculations, turbulent media, and photon-density calculations."
}], "Text",
 CellTags->{
  "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", 
   "RG1.0"},ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1"],

Cell[TextData[{
 "This guide will get you acquainted with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s most important features. By learning the functions introduced here, you \
will have a good foothold for using ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". In particular, you will learn how to model optical components and light \
sources together for ray tracing as well as receive an overview of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s most important capabilities. In addition to this User Guide, advanced \
information is provided in the companion ",
 ButtonBox["Principles Of Optica",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"Principles of Rayica"],
 " guide as well as through our website: www.opticasoftware.com. Before \
beginning, however, you must first load ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "into memory."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", 
   "RG1.0"},ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9"],

Cell[CellGroupData[{

Cell[TextData[{
 "Loading ",
 StyleBox["Optica",
  FontSlant->"Italic"]
}], "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 GroupPageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{
  "Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", 
   "RG1.", "RG1.1"},ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f"],

Cell[TextData[{
 "The basic ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package is made up of two folders: ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " and ",
 StyleBox["OpticaTools",
  FontSlant->"Italic"],
 ". The original ",
 "Optica",
 " and Wavica packages have now been combined to make the new ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package. The ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " folder contains all of the essential files that make up ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " while ",
 StyleBox["OpticaTools",
  FontSlant->"Italic"],
 " contains auxiliary functions for loading packages and working with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Make sure that both the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " and ",
 StyleBox["OpticaTools",
  FontSlant->"Italic"],
 " folders are located together in a directory path recognized by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " for packages. The ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package is loaded with the following command:"
}], "Text",
 Evaluatable->False,
 GroupPageBreakWithin->False,
 AspectRatioFixed->True,
 CellTags->{
  "Loading Rayica", "Rayica User Guide Introduction", "RG1.", 
   "RG1.1"},ExpressionUUID->"53444f15-79b2-4da2-b4fc-a3aabc38a11b"],

Cell[CellGroupData[{

Cell[TextData[{
 "Needs[\"",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "`",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "`\"]"
}], "Input",
 AspectRatioFixed->True,
 CellTags->{
  "Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"},
 CellLabel->"In[1]:=",ExpressionUUID->"d0f1842b-9e8e-4fc2-bb3d-62a54619b000"],

Cell[BoxData["\<\"Optica 4.01 (May 23, 2014 build) was loaded in 13 s and \
needs 30151 kilobytes of memory on top of 26516 kilobytes already used\"\>"], \
"Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.566101726564761*^9, 3.56613916775756*^9, 
  3.614707783570065*^9},
 CellTags->{
  "Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"30459a7a-ca46-4d83-af0d-fdb4a9801d45"],

Cell["+++++++++++++++++++++++++++++++++", "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{3.566101726564761*^9, 3.56613916775756*^9, 
  3.61470777104392*^9},
 CellTags->{
  "Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"2b7b290f-ec8f-499f-8ccd-8f8a5c6dde38"]
}, Open  ]],

Cell[TextData[{
 "This loading process can take a minute or two, depending on your computer's \
speed. In addition to being loaded as a package, all of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " files are formatted as ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebooks. The ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " source code is made accessible in the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " folder so that you can develop new functions of your own by studying ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s built-in functions. This is particularly helpful when you wish to model \
new component ideas in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Loading Rayica", "Rayica User Guide Introduction", "RG1.", 
   "RG1.1"},ExpressionUUID->"b86d0f77-e2c9-4cc9-b06f-923277e3bc7c"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"41f630dd-c76a-4762-9b3a-8b0549a3ab54"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "A basic ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " example"
}], "Subsection",
 CellTags->{
  "1.3", "Rayica Example", "A Basic Rayica Example", 
   "Rayica User Guide Introduction", "RG1.", 
   "RG1.3"},ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793"],

Cell[TextData[{
 "The simplest way to learn ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " is to experiment with its text-based interface.  To this end, we have \
included a series of examples based on a simple optical system in this \
Introduction of the User Guide. The following series of examples will be used \
to demonstrate the elements necessary to create and analyze a basic optical \
system in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". Each line of the initial example will be discussed in specific with \
references to later sections of this booklet for more extensive explanations \
of the functions used. "
}], "Text",
 CellTags->{
  "Loading Rayica", "A Basic Rayica Example", 
   "Rayica User Guide Introduction", "RG1.", 
   "RG1.3"},ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\t\tLineOfRays[45,NumberOfRays->11],
\t\tMove[PlanoConvexLens[100, 50, 10], 50],
\t\tMove[Screen[50], 200]
\t\t}]\
\>", "Input",
 CellTags->{
  "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"},
 CellLabel->"In[2]:=",ExpressionUUID->"528d9f96-c640-4726-aec0-55305c4ecf62"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyNkr9Lw0AYhk+Kmzg76qhQ7CQGTjhwaUQ6OIijFMTR2b+gaVbdXB2kig7+
2AJBtwYpOAnZKri4ObgU1Pbue1Mu8hI/CISHj4e7996l9tHOQU0pNTf+Zsff
5D883tusrW0bZSdIlTetgmeDwc3ZyUiDX/Um00hX6vVkZvSlo3Dhfn5/y1wK
h4H52T7z+3wxjeK4f9j+1KtvD7cbu2HBq/xsn/n9HFTybHP40D92mkaVhvnZ
fsmvMvGD95zHuPMMi/teCK/ys33m93nDdC1/Kd4XvMrP9sv+WPzg7h7r5jXP
n+6uz4Om9OdbeJXf7xsGvWsZP98pdz171+gd/B17vkeNHjE/22d+cOSOviDP
juRS9JH42T7zg7se55KDStCfzOeK+dm+n/NfHokHvfP9Q40e/e88033mB+9K
bugL8lyWdwFnfrYPf1zyg7senwboNfrclx6i18z/C6rAGhY=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYAADywMMUNDhKbGVL8HLYfUqEDCA
i+s/3rbZNszTYQ1YXAEu/h8MPKDmfNiDrn4FRL0DTLwdaj5E3AAu7gF1zz+w
eRZwcQjwg7kTQ3w1mjkw8TVo9qKa88EGXXwFmr9QxQ0wxKHuhIvjCk8ASLtW
ow==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYEABlgc6PCW28iV4wcVXrwIBgwP6
j7dttg3zhIuvAYsrHPgPBh5o5nzYg65+BUS9Qzua+RBxAwcPNPf8A5trAeX7
obsTQxzqTgxxqDtxmPPBBl0c6s4D2MUNMMSh7jyAKzwBioVWow==
       "], {{
       56.421974580955585`, 25., 0.}, {60., 25., 0.}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 
       24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 25., 
       0.}}, {{56.421974580955585`, 24.148145657226706`, 
       6.4704761275630185`}, {60., 24.148145657226706`, 
       6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, 24.148145657226706`, 6.4704761275630185`}}, {{
       56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {60., 
       21.65063509461097, 12.499999999999998`}, {60., 17.67766952966369, 
       17.677669529663685`}, {56.421974580955585`, 17.67766952966369, 
       17.677669529663685`}, {56.421974580955585`, 21.65063509461097, 
       12.499999999999998`}}, {{56.421974580955585`, 17.67766952966369, 
       17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
       60., 12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
       12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
       17.67766952966369, 17.677669529663685`}}, {{56.421974580955585`, 
       12.500000000000004`, 21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {
       56.421974580955585`, 12.500000000000004`, 21.650635094610966`}}, {{
       56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {60., 
       6.470476127563024, 24.148145657226706`}, {60., 
       7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
       7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
       6.470476127563024, 24.148145657226706`}}, {{56.421974580955585`, 
       1.5308084989341915`*^-15, 25.}, {60., 1.5308084989341915`*^-15, 25.}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
       56.421974580955585`, 1.5308084989341915`*^-15, 25.}}, {{
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}}, {{
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}}, {{
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, -21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}}, {{
       56.42197458095559, -21.650635094610962`, 12.500000000000009`}, {
       60., -21.650635094610962`, 12.500000000000009`}, {
       60., -24.148145657226706`, 6.470476127563026}, {
       56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -21.650635094610962`, 12.500000000000009`}}, {{
       56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
       60., -24.148145657226706`, 6.470476127563026}, {60., -25., 
       3.061616997868383*^-15}, {56.421974580955585`, -25., 
       3.061616997868383*^-15}, {56.421974580955585`, -24.148145657226706`, 
       6.470476127563026}}, {{56.421974580955585`, -25., 
       3.061616997868383*^-15}, {60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.421974580955585`, -24.148145657226706`, -6.47047612756302}, {
       56.421974580955585`, -25., 3.061616997868383*^-15}}, {{
       56.421974580955585`, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
       56.421974580955585`, -24.14814565722671, -6.470476127563009}}, {{
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.421974580955585`, -17.677669529663692`, -17.677669529663685`}, {
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}}, {{
       56.421974580955585`, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
       56.421974580955585`, -17.677669529663696`, -17.677669529663678`}}, {{
       56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
       56.421974580955585`, -12.50000000000001, -21.65063509461096}}, {{
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.421974580955585`, -2.6796885989305705`*^-14, -25.}, {
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}}, {{
       56.421974580955585`, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.421974580955585`, 
       6.470476127563007, -24.14814565722671}, {
       56.421974580955585`, -4.592425496802574*^-15, -25.}}, {{
       56.421974580955585`, 6.470476127563007, -24.14814565722671}, {60., 
       6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
       6.470476127563007, -24.14814565722671}}, {{56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       17.67766952966367, -17.67766952966371}, {56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}}, {{56.421974580955585`, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
       21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
       17.677669529663685`, -17.677669529663692`}}, {{56.421974580955585`, 
       21.65063509461096, -12.50000000000001}, {60., 
       21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
       21.65063509461096, -12.50000000000001}}, {{56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
       25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjIdIDQlgcYUECmw+pVIGCAIb4GLK6AIQ6hP+xB
F18BUe+AXdwAQ/zffxCwwBCHuhNDfDUOc9bgsBfqThsc7jyAw50Y4lB3YohD
3QkXBwDSv0No
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjIdGBAAZYH0MVXrwIBAwzxNWBxBQxxCPiwB118
BUS9A3ZxAwzxf/9BwAJDHOpODPHVOMxZg8NeqDttcLgTw18rcIQD1J0Y4lB3
HgAAFJhDaA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhjIdIDQlg4MKCDTwePqhvtvVC0cHHeV1h15KOkA
E3/2u4V1wjJTh/9goAEX35EmfKB6raHDdigNE2cC05oOT6H6YOLuUHNh9sDE
T58/v3725Ns2qO7KdLCDqD+Arv4vxB0HnqGZD3XHgR1o7nkCUXeAFeouNP8e
8ETzL9QdByDuem0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZxx4HHUH0w
8XCoue5Qe2DiN27fPrxl3Zc9MHfBxE2g7vZEU/8dGk8v0MyHxdNONPdA3QF3
Fzy+oOEegeZfWDxBwuf3HgDLNNAY
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBQBGImIAaxUUCD2QEYk/fvlZ+KE70d0MVRgRFc3Ir3ofGk
OV4O6OKoQBsufipq7cqzTzwd0MVRgRJcPCw0bMPmFJh6hDgqEIKLN36eqMAh
CVOPEMcFGMEkTD0uIASXRzMfhz4luDia+3Go14aLo4UPDvVGcHG08MeuvsEM
Lo4Wv7jED6Aa4OdQ6rC2UnGHKVwcf7z7OQQcf/PprbohXBx/vPs5cJqs8L9a
rwkXxx/vfg7OWyIVmZ8qwMXxx7ufw25+mSstVwXg4vjj3Q9DHH+8w82Hi+OP
d7j74eL44x0ePnBx/PEOD3+4OK54h6mHxi8u8QOo4pkOZn2bHhf81sRQjx7v
MPUdz5O9rEyVcfkLQ/0pyZ4zRWrSGOrR450Rqt7Ov4hJN1YQQz16vP8HgwwH
rYdqdSYfGTDUM2AFmTjEMeMdzfwD6OrR4x3N/Rjq0eMd5h5o+GCoR493mHpo
+GOoxx7v8PiFqwcA17Ppmg==
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxTTMoPSmViYGBQBGJmIOb9e+Wn4kRvBwYQaDA7wAAFVrwPjSfN8YKIMxjB
xU9FrV159oknVFwbLh4WGrZhcwpMXAku3vh5ogKHJExcCC7OCCZh4giAph4u
j2Y+XBzNPXBxNPfDxdH8i2a/n0Opw9pKxR2mB9DFA46/+fRW3RBDnNNkhf/V
ek0McectkYrMTxUwxHfzy1xpuSqAIc6AFcDVY7gTaj6GONQ9GOJQ92OIQ/2L
Jp7pYNa36XHBb3RzMh06nid7WZkqY4ifkuw5U6QmDRdnhIrb+Rcx6cYKwsX/
g0GGg9ZDtTqTjwwY5jCgATT1B3CYfwBVF9w9GOJQ92OIQ/0LFwcA8tOMAQ==

      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367525327085*^9, 3.5660869791591988`*^9, 
  3.566101730973316*^9, 3.5661391718367777`*^9, 3.6147077879901943`*^9},
 CellTags->{
  "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"2cd65a8a-29ca-47a4-b77a-241da870ded0"],

Cell[BoxData["\<\"-traced system-\"\>"], "Output",
 CellChangeTimes->{3.563367525335847*^9, 3.5660869791648912`*^9, 
  3.566101730980879*^9, 3.566139171844811*^9, 3.614707787995473*^9},
 CellTags->{
  "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"},
 CellLabel->"Out[2]=",ExpressionUUID->"decbdd55-e771-48ea-ad88-55eaabd4f074"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"033ae809-63ce-4eb9-9982-e5b4caef8625"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inputting data", "Subsection",
 CellTags->{
  "1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", 
   "RG1.4"},ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a"],

Cell[TextData[{
 "The first thing about this example to observe is the format. Because ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " uses a text-based input system, it does not matter whether or not you \
include line breaks where they have been included. They have been put into \
this example for the sake of clarity. The generated image can be instantly \
resized by selecting a corner of the image and dragging the corner of the \
picture until in is the desired size."
}], "Text",
 CellTags->{
  "Inputting Data", "Rayica User Guide Introduction", "RG1.", 
   "RG1.4"},ExpressionUUID->"6fc8cab9-7ee2-44e2-b98b-cdd60e0e3655"],

Cell[TextData[{
 "Another important note about entering data in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " is that every function in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has a specific input format. For example, the input format for ",
 StyleBox["TurboPlot", "Input"],
 " is ",
 StyleBox["TurboPlot[system, options]", "Input",
  FontWeight->"Plain"],
 ". ",
 StyleBox["TurboPlot", "Input"],
 " takes two different inputs: an optical system (system) and any option \
definitions (options). When any input variable contains multiple elements (in \
this case, an optical system) it is necessary to enclose those elements in \
curly brackets (\[OpenCurlyDoubleQuote]",
 StyleBox["{}", "Input"],
 "\[CloseCurlyDoubleQuote]). As with any mathematical system, it is important \
to close all brackets and parentheses appropriately or else the calculation \
will fail. Note that sometimes an input element is not required for final \
calculation. ",
 StyleBox["TurboPlot", "Input"],
 " does not require that options be entered in order to perform a calculation \
(nor does any other function for that matter). It is always valuable to check \
a functions definition to see whether or not an input element is required for \
calculation or not."
}], "Text",
 CellTags->{
  "Inputting Data", "Rayica User Guide Introduction", "RG1.", 
   "RG1.4"},ExpressionUUID->"dda7200a-0a2d-46e4-a177-efe1267d01ee"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"054d5311-4067-40d5-bc3e-4b005d80ec26"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modelling an optical system", "Subsection",
 CellTags->{
  "1.5", "Optical System", "Modelling an Optical System", 
   "Rayica User Guide Introduction", "RG1.", 
   "RG1.5"},ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784"],

Cell[TextData[{
 "When entering an optical system into ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", you should consider what elements to include. To produce any meaningful \
result, it is necessary to have two things: light sources and optical \
components. More often than not, you will have only one light source but \
several components though only one of each has been included in this example. \
The light source is ",
 StyleBox["LineOfRays", "Input"],
 " and the optical component is ",
 StyleBox["PlanoConvexLens", "Input"],
 ". Another essential element of this system is the ",
 StyleBox["Screen", "Input"],
 ". While not an optical element per se, the ",
 StyleBox["Screen", "Input"],
 " provides a necessary function in that it intercepts all rays which come in \
contact with it without changing the optical properties of the ray."
}], "Text",
 CellTags->{
  "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", 
   "RG1.5"},ExpressionUUID->"87327b10-7eee-41c6-ac55-2a9376422dad"],

Cell[TextData[{
 "Just as important as the components and light sources that you include in \
an optical system is their position in the system. As such, you will make \
almost constant use of the ",
 StyleBox["Move", "Input"],
 " function. ",
 StyleBox["Move", "Input"],
 " allows any object to be moved to any location or position within an \
optical system. For more information on the ",
 StyleBox["Move", "Input"],
 " function and its uses, see ",
 ButtonBox["Section 4",
  BaseStyle->"Hyperlink",
  ButtonData:>"4."],
 " of this guide."
}], "Text",
 CellTags->{
  "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", 
   "RG1.5"},ExpressionUUID->"fa99db1d-7880-4526-9fdb-e0675a094fe9"],

Cell[TextData[{
 "The ultimate use of an optical system in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " is analysis and/or display. If you are unsure of the function that you \
wish to use to analyze the optical system you have created, you can access a \
list of available functions using the ",
 StyleBox["OpticaFunctions", "Input"],
 " command."
}], "Text",
 CellTags->{
  "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", 
   "RG1.5"},ExpressionUUID->"aebb1dd9-09f9-4ca0-b88c-b3e5ed789c74"],

Cell["Basic Steps to follow when creating an optical system:", "Text",
 CellTags->{
  "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", 
   "RG1.5"},ExpressionUUID->"e0a3b9c6-0ae8-4dbb-8793-b4c9f770f285"],

Cell[TextData[{
 "1) Determine what light source to use\n2) Create a component list (see the ",
 ButtonBox["Resonate",
  BaseStyle->"Hyperlink",
  ButtonData:>"18."],
 " section if you have any composite lenses)\n3) Position the components in \
your list using the ",
 StyleBox["Move", "Input"],
 " function\n4) Bound the system using a ",
 StyleBox["Screen", "Input"],
 " or a ",
 StyleBox["Boundary", "Input"],
 "\n5) Assign the resulting system to a variable\n6) Use different high level \
functions to analyze the system as necessary"
}], "Text",
 CellTags->{
  "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", 
   "RG1.5"},ExpressionUUID->"4dafee9d-c203-44b3-bd11-6d428cd52708"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Modelling an Optical System", "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"aa596a2d-47a7-483c-93b4-520dd475278c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Variable definition", "Subsection",
 CellTags->{
  "1.6", "Basic Rayica Example", "Variable", "Variable Definition", 
   "Rayica User Guide Introduction", "RG1.", 
   "RG1.6"},ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093"],

Cell["\<\
It is an excellent idea to assign the system to a variable as shown below.\
\>", "Text",
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", 
   "RG1.6"},ExpressionUUID->"104e8fd2-1286-4ad8-bd49-62165d86e223"],

Cell[CellGroupData[{

Cell["\<\
opticalsystem = {
LineOfRays[45,NumberOfRays->11],
Move[PlanoConvexLens[100, 50, 10], 50],
Move[Screen[50], 200]
}\
\>", "Input",
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"},
 CellLabel->"In[3]:=",ExpressionUUID->"f920023b-619f-404b-8aca-2883db8d47c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"LineOfRays", "[", 
       RowBox[{"45", ",", 
        RowBox[{"NumberOfRays", "\[Rule]", "11"}]}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "50.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", "50", "]"}], ",", "200.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0., 0.392193, 0.]],
    DisplayForm]}], "}"}]], "Output",
 CellChangeTimes->{3.5633675254783792`*^9, 3.5660869793462133`*^9, 
  3.566101731416607*^9, 3.5661391723421097`*^9, 3.614707788254135*^9},
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"},
 CellLabel->"Out[3]=",ExpressionUUID->"369f0439-ef91-407d-b2b8-1a6d1ee2c936"]
}, Open  ]],

Cell["\<\
When an optical system is assigned to a variable, you can then use that \
variable to perform any number of calculations. It is always a good idea to \
assign an optical system to a variable if you intend to use the same system \
for repeated calculations as this can dramatically reduce input time. What is \
further, you can assign the output of a function to a variable as shown below\
\
\>", "Text",
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", 
   "RG1.6"},ExpressionUUID->"dee619ee-4b4d-47a4-a93c-18511ca4be05"],

Cell[CellGroupData[{

Cell["tracedresult = TurboPlot[opticalsystem]", "Input",
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"},
 CellLabel->"In[4]:=",ExpressionUUID->"5727830a-6763-4831-be3d-b5c19b2eeef4"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyNkr9Lw0AYhk+Kmzg76qhQ7CQGTjhwaUQ6OIijFMTR2b+gaVbdXB2kig7+
2AJBtwYpOAnZKri4ObgU1Pbue1Mu8hI/CISHj4e7996l9tHOQU0pNTf+Zsff
5D883tusrW0bZSdIlTetgmeDwc3ZyUiDX/Um00hX6vVkZvSlo3Dhfn5/y1wK
h4H52T7z+3wxjeK4f9j+1KtvD7cbu2HBq/xsn/n9HFTybHP40D92mkaVhvnZ
fsmvMvGD95zHuPMMi/teCK/ys33m93nDdC1/Kd4XvMrP9sv+WPzg7h7r5jXP
n+6uz4Om9OdbeJXf7xsGvWsZP98pdz171+gd/B17vkeNHjE/22d+cOSOviDP
juRS9JH42T7zg7se55KDStCfzOeK+dm+n/NfHokHvfP9Q40e/e88033mB+9K
bugL8lyWdwFnfrYPf1zyg7senwboNfrclx6i18z/C6rAGhY=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYAADywMMUNDhKbGVL8HLYfUqEDCA
i+s/3rbZNszTYQ1YXAEu/h8MPKDmfNiDrn4FRL0DTLwdaj5E3AAu7gF1zz+w
eRZwcQjwg7kTQ3w1mjkw8TVo9qKa88EGXXwFmr9QxQ0wxKHuhIvjCk8ASLtW
ow==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYEABlgc6PCW28iV4wcVXrwIBgwP6
j7dttg3zhIuvAYsrHPgPBh5o5nzYg65+BUS9Qzua+RBxAwcPNPf8A5trAeX7
obsTQxzqTgxxqDtxmPPBBl0c6s4D2MUNMMSh7jyAKzwBioVWow==
       "], {{
       56.421974580955585`, 25., 0.}, {60., 25., 0.}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 
       24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 25., 
       0.}}, {{56.421974580955585`, 24.148145657226706`, 
       6.4704761275630185`}, {60., 24.148145657226706`, 
       6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, 24.148145657226706`, 6.4704761275630185`}}, {{
       56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {60., 
       21.65063509461097, 12.499999999999998`}, {60., 17.67766952966369, 
       17.677669529663685`}, {56.421974580955585`, 17.67766952966369, 
       17.677669529663685`}, {56.421974580955585`, 21.65063509461097, 
       12.499999999999998`}}, {{56.421974580955585`, 17.67766952966369, 
       17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
       60., 12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
       12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
       17.67766952966369, 17.677669529663685`}}, {{56.421974580955585`, 
       12.500000000000004`, 21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {
       56.421974580955585`, 12.500000000000004`, 21.650635094610966`}}, {{
       56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {60., 
       6.470476127563024, 24.148145657226706`}, {60., 
       7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
       7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
       6.470476127563024, 24.148145657226706`}}, {{56.421974580955585`, 
       1.5308084989341915`*^-15, 25.}, {60., 1.5308084989341915`*^-15, 25.}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
       56.421974580955585`, 1.5308084989341915`*^-15, 25.}}, {{
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}}, {{
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}}, {{
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, -21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}}, {{
       56.42197458095559, -21.650635094610962`, 12.500000000000009`}, {
       60., -21.650635094610962`, 12.500000000000009`}, {
       60., -24.148145657226706`, 6.470476127563026}, {
       56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -21.650635094610962`, 12.500000000000009`}}, {{
       56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
       60., -24.148145657226706`, 6.470476127563026}, {60., -25., 
       3.061616997868383*^-15}, {56.421974580955585`, -25., 
       3.061616997868383*^-15}, {56.421974580955585`, -24.148145657226706`, 
       6.470476127563026}}, {{56.421974580955585`, -25., 
       3.061616997868383*^-15}, {60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.421974580955585`, -24.148145657226706`, -6.47047612756302}, {
       56.421974580955585`, -25., 3.061616997868383*^-15}}, {{
       56.421974580955585`, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
       56.421974580955585`, -24.14814565722671, -6.470476127563009}}, {{
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.421974580955585`, -17.677669529663692`, -17.677669529663685`}, {
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}}, {{
       56.421974580955585`, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
       56.421974580955585`, -17.677669529663696`, -17.677669529663678`}}, {{
       56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
       56.421974580955585`, -12.50000000000001, -21.65063509461096}}, {{
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.421974580955585`, -2.6796885989305705`*^-14, -25.}, {
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}}, {{
       56.421974580955585`, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.421974580955585`, 
       6.470476127563007, -24.14814565722671}, {
       56.421974580955585`, -4.592425496802574*^-15, -25.}}, {{
       56.421974580955585`, 6.470476127563007, -24.14814565722671}, {60., 
       6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
       6.470476127563007, -24.14814565722671}}, {{56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       17.67766952966367, -17.67766952966371}, {56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}}, {{56.421974580955585`, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
       21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
       17.677669529663685`, -17.677669529663692`}}, {{56.421974580955585`, 
       21.65063509461096, -12.50000000000001}, {60., 
       21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
       21.65063509461096, -12.50000000000001}}, {{56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
       25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjIdIDQlgcYUECmw+pVIGCAIb4GLK6AIQ6hP+xB
F18BUe+AXdwAQ/zffxCwwBCHuhNDfDUOc9bgsBfqThsc7jyAw50Y4lB3YohD
3QkXBwDSv0No
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmBhjIdGBAAZYH0MVXrwIBAwzxNWBxBQxxCPiwB118
BUS9A3ZxAwzxf/9BwAJDHOpODPHVOMxZg8NeqDttcLgTw18rcIQD1J0Y4lB3
HgAAFJhDaA==
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmBhjIdIDQlg4MKCDTwePqhvtvVC0cHHeV1h15KOkA
E3/2u4V1wjJTh/9goAEX35EmfKB6raHDdigNE2cC05oOT6H6YOLuUHNh9sDE
T58/v3725Ns2qO7KdLCDqD+Arv4vxB0HnqGZD3XHgR1o7nkCUXeAFeouNP8e
8ETzL9QdByDuem0DE/eEqjeDugstfA78gboLJr4L6p6tUBomzgZxx4HHUH0w
8XCoue5Qe2DiN27fPrxl3Zc9MHfBxE2g7vZEU/8dGk8v0MyHxdNONPdA3QF3
Fzy+oOEegeZfWDxBwuf3HgDLNNAY
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBQBGImIAaxUUCD2QEYk/fvlZ+KE70d0MVRgRFc3Ir3ofGk
OV4O6OKoQBsufipq7cqzTzwd0MVRgRJcPCw0bMPmFJh6hDgqEIKLN36eqMAh
CVOPEMcFGMEkTD0uIASXRzMfhz4luDia+3Go14aLo4UPDvVGcHG08MeuvsEM
Lo4Wv7jED6Aa4OdQ6rC2UnGHKVwcf7z7OQQcf/PprbohXBx/vPs5cJqs8L9a
rwkXxx/vfg7OWyIVmZ8qwMXxx7ufw25+mSstVwXg4vjj3Q9DHH+8w82Hi+OP
d7j74eL44x0ePnBx/PEOD3+4OK54h6mHxi8u8QOo4pkOZn2bHhf81sRQjx7v
MPUdz5O9rEyVcfkLQ/0pyZ4zRWrSGOrR450Rqt7Ov4hJN1YQQz16vP8HgwwH
rYdqdSYfGTDUM2AFmTjEMeMdzfwD6OrR4x3N/Rjq0eMd5h5o+GCoR493mHpo
+GOoxx7v8PiFqwcA17Ppmg==
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxTTMoPSmViYGBQBGJmIOb9e+Wn4kRvBwYQaDA7wAAFVrwPjSfN8YKIMxjB
xU9FrV159oknVFwbLh4WGrZhcwpMXAku3vh5ogKHJExcCC7OCCZh4giAph4u
j2Y+XBzNPXBxNPfDxdH8i2a/n0Opw9pKxR2mB9DFA46/+fRW3RBDnNNkhf/V
ek0McectkYrMTxUwxHfzy1xpuSqAIc6AFcDVY7gTaj6GONQ9GOJQ92OIQ/2L
Jp7pYNa36XHBb3RzMh06nid7WZkqY4ifkuw5U6QmDRdnhIrb+Rcx6cYKwsX/
g0GGg9ZDtTqTjwwY5jCgATT1B3CYfwBVF9w9GOJQ92OIQ/0LFwcA8tOMAQ==

      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367525821707*^9, 3.5660869799737587`*^9, 
  3.5661017320128202`*^9, 3.566139175175226*^9, 3.614707788766943*^9},
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"},
 CellLabel->
  "During evaluation of \
In[4]:=",ExpressionUUID->"acdffe68-5863-48c5-a77f-a7c3baf51997"],

Cell[BoxData["\<\"-traced system-\"\>"], "Output",
 CellChangeTimes->{3.5633675258294287`*^9, 3.566086979980452*^9, 
  3.566101732051083*^9, 3.566139175183922*^9, 3.614707788770919*^9},
 CellTags->{
  "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"},
 CellLabel->"Out[4]=",ExpressionUUID->"c9ab9764-21af-4c4b-9970-43a26f36b411"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"ddcfaf90-344d-4cea-ab86-cbf260c01c93"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic commands", "Subsection",
 CellTags->{
  "1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", 
   "RG1.", "RG1.2"},ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451"],

Cell[TextData[{
 "If you already know the name of command that you want to include in your \
optical system but would like to review the definition before actually \
including it, you can use the ",
 StyleBox["?", "Input"],
 " command to display the definition."
}], "Text",
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", 
   "RG1.2"},ExpressionUUID->"b961e791-5ad4-44d6-be6c-25237633de9a"],

Cell[CellGroupData[{

Cell["?PlanoConvexLens", "Input",
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"},
 CellLabel->"In[5]:=",ExpressionUUID->"60b3ccf1-9b6a-42b4-beda-efdf85878f43"],

Cell[BoxData[
 StyleBox["\<\"PlanoConvexLens[focallength, aperture, thickness, label, \
options] denotes a lens with a planar surface on one side and a convex \
spherical surface on the other side. \\n\\nPlanoConvexLens is created with \
its first surface centered about the origin and its second surface positioned \
down the positive x axis. The aperture parameter may designate a circle, \
rectangle, or polygon depending on the number and type of elements listed by \
it. The user-named label parameter is optional and can be omitted. When it is \
present, its text content is used to identify the object in both the rendered \
graphics and the output cell expression. When it is omitted, Optica uses the \
default setting of the Labels option with the rendered graphics. \\n\\nNote \
that the specified focallength is always determined for a particular setting \
of the DesignWaveLength and ComponentMedium options. By default, Optica uses \
DesignWaveLength->0.5461 microns and ComponentMedium->BK7. Care should be \
taken to insure that these default settings are compatible with the intended \
experimental design or unintended results can occur.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.614707789041918*^9},
 CellTags->{
  "Basic Commands", "Info3614689788-8836408", 
   "Rayica User Guide Introduction", "RG1.", 
   "RG1.2"},ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30"],

Cell[BoxData["\<\"PlanoConvexLens[focallength, aperture, thickness, label, \
options] denotes a lens with a planar surface on one side and a convex \
spherical surface on the other side. \\n\\nPlanoConvexLens is created with \
its first surface centered about the origin and its second surface positioned \
down the positive x axis. The aperture parameter may designate a circle, \
rectangle, or polygon depending on the number and type of elements listed by \
it. The user-named label parameter is optional and can be omitted. When it is \
present, its text content is used to identify the object in both the rendered \
graphics and the output cell expression. When it is omitted, Optica uses the \
default setting of the Labels option with the rendered graphics. \\n\\nNote \
that the specified focallength is always determined for a particular setting \
of the DesignWaveLength and ComponentMedium options. By default, Optica uses \
DesignWaveLength->0.5461 microns and ComponentMedium->BK7. Care should be \
taken to insure that these default settings are compatible with the intended \
experimental design or unintended results can occur.\"\>"], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", 
   "RG1.2"},ExpressionUUID->"3598c355-5d0a-4d3d-9b3d-f7fd245ab10e"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["?", "Input"],
 " command works with all defined elements of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", from functions to light sources to options. Almost anything that can be \
evaluated by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can be defined using the ",
 StyleBox["?", "Input"],
 " command."
}], "Text",
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", 
   "RG1.2"},ExpressionUUID->"32f40f05-473f-4afc-9899-3d622bcdf716"],

Cell[TextData[{
 "Another very useful command is the ",
 StyleBox["%", "Input"],
 " command. Use of ",
 StyleBox["%", "Input"],
 " is discussed in the 10 minute introduction to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " which you may wish to read. Essentially, ",
 StyleBox["%", "Input"],
 " acts as a variable which stores the result of the previous calculation. \
So, if you wish to use the results of the last calculation performed, simply \
create a new input using ",
 StyleBox["%", "Input"],
 " and evaluate it."
}], "Text",
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", 
   "RG1.2"},ExpressionUUID->"65aef86b-430e-45bc-abf8-ddddcf93ef68"],

Cell[TextData[{
 "The final fundamental command is ",
 StyleBox["Options[ ]", "Input"],
 ". When you enter a ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " function name into the square brackets and press Shift+Enter, a list of \
the options associated with that function name are displayed. Finding a rule \
and applying it will be discussed in the next section."
}], "Text",
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", 
   "RG1.2"},ExpressionUUID->"81c3bf14-369a-4990-9b18-332f42382a7d"],

Cell[CellGroupData[{

Cell["Options[Screen]", "Input",
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"},
 CellLabel->"In[6]:=",ExpressionUUID->"345e0557-ca6e-4cb5-b0f5-2b96d006835d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Labels", "\[Rule]", "\<\"S\"\>"}], ",", 
   RowBox[{"LabelPositions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentDescription", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Transmittance", "\[Rule]", "100"}], ",", 
   RowBox[{"GraphicDesign", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Automatic", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Trace"}]}], "}"}]}], ",", 
   RowBox[{"Sketch", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Trace"}]}], "}"}]}], ",", 
   RowBox[{"Wire", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Empty"}]}], "}"}]}], ",", 
   RowBox[{"Solid", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Fill", ",", "Trace"}], "}"}]}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Empty"}]}], "}"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367526364437*^9, 3.566086980705431*^9, 
  3.566101732755691*^9, 3.566139175857169*^9, 3.614707789266986*^9},
 CellTags->{
  "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"},
 CellLabel->"Out[6]=",ExpressionUUID->"b4961016-071a-4a8e-bb6c-c90ac5d3702f"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"49dddedf-8a52-4696-a0f4-ea824834129b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Options", "Subsection",
 CellTags->{
  "1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.",
    "RG1.7"},ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366"],

Cell[TextData[{
 "Options are available for almost every element of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". To discover what options are associated with the elements that you are \
using, use the ",
 StyleBox["Options[]", "Input"],
 " command as discussed in the Basic Commands section of this booklet. \
Options are assigned to ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " elements using what is known as a rule (\[OpenCurlyDoubleQuote]",
 StyleBox["->", "Input"],
 "\[CloseCurlyDoubleQuote]) in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". What this means is that you select an option (or options) to assign a \
value (like ",
 StyleBox["PlotType", "Input"],
 " in the following example) and then assign it a new value using the rule \
arrow."
}], "Text",
 CellTags->{
  "Using Options", "Rayica User Guide Introduction", "RG1.", 
   "RG1.7"},ExpressionUUID->"d698385b-2681-4ae0-b85a-a3df7977a811"],

Cell[CellGroupData[{

Cell["TurboPlot[tracedresult, PlotType->TopView]", "Input",
 CellTags->{
  "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"},
 CellLabel->"In[7]:=",ExpressionUUID->"3714197e-e855-42e0-9712-befe94db8040"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYCYs/KCGdmMx8HBjCwPACh/TD4a1aBgMGBDk+J
rXwJXg6roXx0/ejy6PpR+QoH9B9v22wb5gnno+tHl0fXj+pehr3/wcADxmdA
148uj6Yfzl8FUe8A078CysdlPkweXT8q38AB5j8YH10/ujy6fhgf4g4LBw9o
+P+D8tH1o8YPwn+nz59fP3vyaxsYX0tXdy/j72c2MP3tXV2n0pMO2aDrR5dH
1w/jd4DlH9nA/AdRfwnDfHR5dP0w/lmwe2/bwML/NJSPrh9dHtW/t9HMv4Sm
/xEB8x9h6IfxO6H+gflPExoe6PrR5WH6u9DC88bt24e3rJtiCYvfU9D4QtcP
AJQmdgg=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{56.421974580955585`, -25.}, {
       52.75044883428478, -16.666666666666668`}, {
       50.67375799589205, -8.333333333333336}, {
       49.99999999999999, -3.552713678800501*^-15}, {50.67375799589205, 
       8.333333333333329}, {52.750448834284775`, 16.666666666666657`}, {
       56.42197458095558, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.421974580955585`, -25.}}, {{56.421974580955585`, 0.}, {
       52.75044883428478, 0.}, {50.67375799589205, 0.}, {49.99999999999999, 
       0.}, {50.67375799589205, 0.}, {52.750448834284775`, 0.}, {
       56.42197458095558, 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
       60., 0.}, {60., 0.}, {60., 0.}, {56.421974580955585`, 0.}}, {{
       56.421974580955585`, 25.}, {60., 25.}, {60., 24.148145657226706`}, {
       56.421974580955585`, 24.148145657226706`}, {56.421974580955585`, 
       25.}}, {{56.421974580955585`, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.421974580955585`, 
       21.65063509461097}, {56.421974580955585`, 24.148145657226706`}}, {{
       56.421974580955585`, 21.65063509461097}, {60., 21.65063509461097}, {
       60., 17.67766952966369}, {56.421974580955585`, 17.67766952966369}, {
       56.421974580955585`, 21.65063509461097}}, {{56.421974580955585`, 
       17.67766952966369}, {60., 17.67766952966369}, {60., 
       12.500000000000004`}, {56.421974580955585`, 12.500000000000004`}, {
       56.421974580955585`, 17.67766952966369}}, {{56.421974580955585`, 
       12.500000000000004`}, {60., 12.500000000000004`}, {60., 
       6.470476127563024}, {56.421974580955585`, 6.470476127563024}, {
       56.421974580955585`, 12.500000000000004`}}, {{56.421974580955585`, 
       6.470476127563024}, {60., 6.470476127563024}, {60., 
       7.0819236220599744`*^-15}, {56.421974580955585`, 
       7.0819236220599744`*^-15}, {56.421974580955585`, 
       6.470476127563024}}, {{56.421974580955585`, 
       1.5308084989341915`*^-15}, {60., 1.5308084989341915`*^-15}, {
       60., -6.470476127563016}, {56.421974580955585`, -6.470476127563016}, {
       56.421974580955585`, 1.5308084989341915`*^-15}}, {{
       56.421974580955585`, -6.470476127563016}, {60., -6.470476127563016}, {
       60., -12.499999999999995`}, {
       56.421974580955585`, -12.499999999999995`}, {
       56.421974580955585`, -6.470476127563016}}, {{
       56.421974580955585`, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.421974580955585`, -17.677669529663685`}, {
       56.421974580955585`, -12.499999999999995`}}, {{
       56.421974580955585`, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.421974580955585`, -21.65063509461097}, {
       56.421974580955585`, -17.677669529663685`}}, {{
       56.42197458095559, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.421974580955585`, -24.148145657226706`}, {
       56.42197458095559, -21.650635094610962`}}, {{
       56.421974580955585`, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.421974580955585`, -25.}, {
       56.421974580955585`, -24.148145657226706`}}, {{
       56.421974580955585`, -25.}, {60., -25.}, {60., -24.148145657226706`}, {
       56.421974580955585`, -24.148145657226706`}, {
       56.421974580955585`, -25.}}, {{
       56.421974580955585`, -24.14814565722671}, {60., -24.14814565722671}, {
       60., -21.65063509461097}, {56.421974580955585`, -21.65063509461097}, {
       56.421974580955585`, -24.14814565722671}}, {{
       56.421974580955585`, -21.65063509461097}, {60., -21.65063509461097}, {
       60., -17.677669529663692`}, {
       56.421974580955585`, -17.677669529663692`}, {
       56.421974580955585`, -21.65063509461097}}, {{
       56.421974580955585`, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.421974580955585`, -12.50000000000001}, {
       56.421974580955585`, -17.677669529663696`}}, {{
       56.421974580955585`, -12.50000000000001}, {60., -12.50000000000001}, {
       60., -6.470476127563038}, {56.421974580955585`, -6.470476127563038}, {
       56.421974580955585`, -12.50000000000001}}, {{
       56.421974580955585`, -6.470476127563038}, {60., -6.470476127563038}, {
       60., -2.6796885989305705`*^-14}, {
       56.421974580955585`, -2.6796885989305705`*^-14}, {
       56.421974580955585`, -6.470476127563038}}, {{
       56.421974580955585`, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.421974580955585`, 6.470476127563007}, {
       56.421974580955585`, -4.592425496802574*^-15}}, {{56.421974580955585`, 
       6.470476127563007}, {60., 6.470476127563007}, {60., 
       12.499999999999984`}, {56.421974580955585`, 12.499999999999984`}, {
       56.421974580955585`, 6.470476127563007}}, {{56.421974580955585`, 
       12.499999999999984`}, {60., 12.499999999999984`}, {60., 
       17.67766952966367}, {56.42197458095559, 17.67766952966367}, {
       56.421974580955585`, 12.499999999999984`}}, {{56.421974580955585`, 
       17.677669529663685`}, {60., 17.677669529663685`}, {60., 
       21.65063509461096}, {56.421974580955585`, 21.65063509461096}, {
       56.421974580955585`, 17.677669529663685`}}, {{56.421974580955585`, 
       21.65063509461096}, {60., 21.65063509461096}, {60., 
       24.148145657226703`}, {56.421974580955585`, 24.148145657226703`}, {
       56.421974580955585`, 21.65063509461096}}, {{56.421974580955585`, 
       24.148145657226703`}, {60., 24.148145657226703`}, {60., 25.}, {
       56.421974580955585`, 25.}, {56.421974580955585`, 
       24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{200., -25.}, {200., -16.666666666666668`}, {
       200., -8.333333333333336}, {200., -3.552713678800501*^-15}, {200., 
       8.333333333333329}, {200., 16.666666666666657`}, {200., 
       24.999999999999993`}, {200., 25.}, {200., 16.666666666666668`}, {200., 
       8.333333333333336}, {200., 3.552713678800501*^-15}, {
       200., -8.333333333333329}, {200., -16.666666666666657`}, {
       200., -24.999999999999993`}, {200., -25.}}, {{200., 0.}, {200., 0.}, {
       200., 0.}, {200., 0.}, {200., 0.}, {200., 0.}, {200., 0.}, {200., 
       0.}, {200., 0.}, {200., 0.}, {200., 0.}, {200., 0.}, {200., 0.}, {200.,
        0.}, {200., 0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQGZDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0APwBxjg==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmVmYGBQBGImKEYBDWYHeP9e+ak40dsBxkdVYHTAiveh8aQ5Xg4w
Pqq89oFTUWtXnn3i6QDjo8orHQgLDduwOQUmr4QmL3Sg8fNEBQ5JmLwQmjwD
AyOYhMmjAyEHNP1o6pQc0OxHk9d2QHM/mryRA5r/UeUbzBzQwg+dD/WPn0Op
w9pKxR2mOMLTzyHg+JtPb9UNcYSnnwOnyQr/q/WaOMLTz8F5S6Qi81MFHOHp
57CbX+ZKy1WBA9jD0w/Oxx6ecP04whNuP47whLsfR3jC/Y8Rnmjhh86H+i/T
waxv0+OC35ro5sHlO54ne1mZKqO7By5/SrLnTJGaNLp/oOGV6WDnX8SkGyuI
Hh4H/oNBhoPWQ7U6k48McHnU8M1E4yPCE03/AfTwRLMfLg8LTzT3w+Vh4Ynm
f7g8anjCw+8AAG6B6Zk=
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQzfv3yk/Fid4ODCDQYHbAiveh8aQ5XhA+g9GBU1Fr
V5594gnlax8ICw3bsDkFxlc60Ph5ogKHJIwvdIARTMP4DAxo8g5o+h3QzHdA
s98BzX1QcT+HUoe1lYo7TA/A+AHH33x6q24I53OarPC/Wq8J5ztviVRkfqoA
5+/ml7nSclUAzmdAAXB5BzT9cD7UfDgfaj+6+6D8TAezvk2PC35rwvkdz5O9
rEyV4fxTkj1nitSkHRihfDv/IibdWEGH/2CQ4aD1UK3O5CMDXD3MpWjyB9D0
H0AzH86H2g/nQ913AAAxR4wA
      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5633675264083643`*^9, 3.566086980774961*^9, 
  3.566101732823641*^9, 3.566139175927506*^9, 3.6147077893270082`*^9},
 CellTags->{
  "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"},
 CellLabel->
  "During evaluation of \
In[7]:=",ExpressionUUID->"2ff772c7-f46b-4d90-ac24-db9ca5717551"],

Cell[BoxData["\<\"-traced system-\"\>"], "Output",
 CellChangeTimes->{3.563367526413289*^9, 3.5660869807834377`*^9, 
  3.5661017328308372`*^9, 3.566139175934704*^9, 3.614707789331315*^9},
 CellTags->{
  "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"},
 CellLabel->"Out[7]=",ExpressionUUID->"7c91bc79-09f1-4b33-b1bc-0df23b38a0d8"]
}, Open  ]],

Cell[TextData[{
 "If you are unsure of what new values can be assigned to an option, you can \
use the ",
 StyleBox["?", "Input"],
 " command and the option\[CloseCurlyQuote]s name to determine what values \
can be assigned to that option."
}], "Text",
 CellTags->{
  "Using Options", "Rayica User Guide Introduction", "RG1.", 
   "RG1.7"},ExpressionUUID->"b92c4fea-2385-4575-a331-9f47851bad97"],

Cell[CellGroupData[{

Cell["?PlotType", "Input",
 CellTags->{
  "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"},
 CellLabel->"In[8]:=",ExpressionUUID->"f10454f4-a19f-41ea-8804-aceb1d31c86d"],

Cell[BoxData[
 StyleBox["\<\"PlotType is an option of DrawSystem/AnalyzeSystem, TurboPlot, \
and ShowSystem that designates the display form of the graphics rendering. \
\\n\\nPlotType takes TopView, FrontView, SideView, Full3D, RealTime3D, Off, \
Surface, and ShadowProject as values. \\n\\nA list of one or two points \
specify a direction and center to project the graphics. The points can be \
specified as rules RaySelect -> sel, ComponentSelect -> sel and SurfaceSelect \
-> sel, with sel being a list of selection properties passed to the \
designated functions. See also: CreateStereoView and ProjectGraphics3D.\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6147077895896883`*^9},
 CellTags->{
  "Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7",
    "Using Options"},ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"6bb1aa19-e7dd-4535-b457-9728b6bd06b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s high-level functions"
}], "Subsection",
 Evaluatable->False,
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "1.8", "High-Level Functions", "Rayica's High-Level Functions", 
   "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has a number of functions available for high-level calculations. Some (but \
not all) of these functions are shown in the following table."
}], "Text",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"96d3fc89-4f11-4a94-b332-e31880fe2590"],

Cell[TextData[{
 StyleBox["AnalyzeSystem[", "Input",
  FontFamily->"Courier"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " is used to trace rays through optical components and render the results \
for illustration purposes. This is also called ",
 StyleBox["DrawSystem", "Input"],
 ".\n",
 StyleBox["PropagateSystem[", "Input",
  FontFamily->"Courier"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " is used by ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " to trace rays through optical components. This method is much slower than ",
 StyleBox["TurboTrace", "Input"],
 ".\n",
 StyleBox["TurboTrace[", "Input"],
 StyleBox["optics",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " produces an accelerated ray trace of a system of light sources and optical \
elements.\n",
 StyleBox["TurboPlot[", "Input"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " works with ",
 StyleBox["TurboTrace", "Input"],
 " to perform accelerated ray-tracing and rendering of a system of light \
sources and optical elements.\n",
 StyleBox["ShowSystem[", "Input",
  FontFamily->"Courier"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " takes a ",
 StyleBox["system ",
  FontSlant->"Italic"],
 "of rays and/or components and generates a graphical display of the ",
 StyleBox["system",
  FontSlant->"Italic"],
 ". ",
 StyleBox["ShowSystem", "Input"],
 " works with ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " results.\n",
 StyleBox["ReadRays[", "Input",
  FontFamily->"Courier"],
 StyleBox["results",
  FontSlant->"Italic"],
 ", ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 ", ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " takes ray-traced ",
 StyleBox["results",
  FontSlant->"Italic"],
 " from ",
 StyleBox["AnalyzeSystem", "Input"],
 "/",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 " and returns a list of values for the ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 " and ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 " given.\n",
 StyleBox["OptimizeSystem[", "Input"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " optimizes the performance of an optical system for a specified set of \
symbolic input parameters.\n",
 StyleBox["FindFocus[", "Input"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " determines the minimum spot size for a locus of rays at the last reported \
surface in the system and plots the results.\n",
 StyleBox["FindSpotSize[", "Input"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " determines the spot size for a locus of rays at the last reported surface \
in the system and plots the results.\n",
 StyleBox["FindIntensity[", "Input",
  FontWeight->"Bold"],
 StyleBox["system",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 " calculates the intensity function for each optical surface that gets \
reported from the ray trace of the ",
 StyleBox["system",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["ModulationTransferFunction[", "Input",
  FontWeight->"Bold"],
 StyleBox["intensitydata",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 " calculates the modulation and phase transfer functions of an optical \
system for a given object source input.\n",
 StyleBox["Resonate[", "Input"],
 StyleBox["listofcomponents",
  FontSlant->"Italic"],
 ", ",
 StyleBox["objectname",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is a generic building block that causes a ray to be nonsequentially traced \
within all of the surfaces defined by ",
 StyleBox["listofcomponents",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["TransferTraits[", "Input"],
 StyleBox["donor-component",
  FontSlant->"Italic"],
 ", ",
 StyleBox["recipient-component",
  FontSlant->"Italic"],
 ", ",
 StyleBox["surfacenumbers",
  FontSlant->"Italic"],
 ", ",
 StyleBox["opts",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is a function that transfers the surface traits of a donor component \
surface into the surfaces (specified by ",
 StyleBox["surfacenumbers",
  FontSlant->"Italic"],
 ") of a recipient component."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"d0491aa2-cbdf-42fd-85b3-1a702665c886"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s most important high-level functions."
}], "Commentary",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"223397e7-31c7-4429-a46a-a3d5f8837777"],

Cell[TextData[{
 "In various ways, these high-level functions assist the user in conducting \
the ray trace and interpreting the traced results. At the heart of every high \
level function in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " is the ray-trace calculation. For this, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " offers two parallel ways to trace rays through a system of optical \
elements in three-dimensional space, using either ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " or ",
 StyleBox["TurboTrace", "Input"],
 ". In many cases, however, the ray-trace needs to be accompanied by a \
graphical rendering of the traced system. In such instances, either ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 "  or ",
 StyleBox["TurboPlot", "Input"],
 " is called instead of ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " or ",
 StyleBox["TurboTrace", "Input"],
 ". In other instances, ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 " is used to render isolated components or to rerender the results after the \
initial trace has taken place. ",
 StyleBox["ReadRays", "Input",
  FontFamily->"Courier"],
 " is used to extract numerical information from the traces previously \
conducted by ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 "/",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 ". The last five functions (",
 StyleBox["OptimizeSystem", "Input"],
 " , ",
 StyleBox["FindFocus", "Input"],
 ", ",
 StyleBox["FindIntensity", "Input",
  FontWeight->"Bold"],
 ", ",
 StyleBox["ModulationTransferFunction", "Input",
  FontWeight->"Bold"],
 ", and ",
 StyleBox["TransferTraits", "Input"],
 ") are the highest level functions of all and perform very specific tasks, \
as indicated by their given names."
}], "Text",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"2801ba38-1670-4ec0-be89-130ee69482c6"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " offers four simple command tools that provide an overview of the functions \
used in the ",
 StyleBox["Optica ",
  FontSlant->"Italic"],
 "package: ",
 StyleBox["SourceFunctions", "Input"],
 ", ",
 StyleBox["ComponentFunctions", "Input"],
 ", ",
 StyleBox["MoveFunctions", "Input"],
 ", and ",
 StyleBox["OpticaFunctions", "Input"],
 ". These four commands create a list of the available light sources, optical \
components, move functions, and available optical functions respectively. For \
example, at any time that you wish while working with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", you can access a listing of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s primary high-level functions with the ",
 StyleBox["OpticaFunctions", "Input"],
 " command:"
}], "Text",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"2aac3485-7adc-42ac-8fe9-0f6b80a73898"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["OpticaFunctions", "Input"]], "Input",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},
 CellLabel->"In[9]:=",ExpressionUUID->"03e61a5c-2d76-42f7-8f63-a22c86e3aa11"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     ButtonBox[
      StyleBox["\<\"AddSurfaceRoughness\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AddSurfaceRoughness", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"FindSpotSize\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"FindSpotSize", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ReadData\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ReadData", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AnalyzeSystem\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AnalyzeSystem", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Fresnel\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Fresnel", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ReadRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ReadRays", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"ArrangeSystem\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ArrangeSystem", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Hole\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Hole", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Resonate\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Resonate", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CombineSurfaces\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CombineSurfaces", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ManipulateSystem\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ManipulateSystem", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SearchData\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"SearchData", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"ConstructMeritFunction\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ConstructMeritFunction", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MeldSurfaces\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"MeldSurfaces", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ShowSystem\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ShowSystem", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"DataToOptica\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"DataToOptica", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ModulationTransferFunction\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ModulationTransferFunction", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"TransferTraits\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"TransferTraits", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"DrillHole\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"DrillHole", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Move\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Move", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"TurboPlot\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"TurboPlot", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"FindFocus\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"FindFocus", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MoveSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"MoveSurface", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"TurboTrace\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"TurboTrace", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"FindIntensity\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"FindIntensity", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"OptimizeSystem\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"OptimizeSystem", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]}
   },
   AutoDelete->False,
   GridBoxBackground->{"Columns" -> {{
        GrayLevel[0.930022]}}},
   GridBoxDividers->{
    "Columns" -> {True, {False}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {1, 1, 1, {1.05}},
      "RowsIndexed" -> {}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.56336752681883*^9, 3.566086981775215*^9, 
  3.566101733478932*^9, 3.566139176500705*^9, 3.614707789755921*^9},
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},
 CellLabel->"Out[9]=",ExpressionUUID->"e70dce45-423a-49c4-993e-46f4773bad3d"]
}, Open  ]],

Cell[TextData[{
 "In Mathmatica, ",
 StyleBox["OpticaFunctions", "Input",
  FontSlant->"Plain"],
 " gives you hyperlinks to ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s most important high-level functions. Clicking on any name will give you \
a description of its use."
}], "Commentary",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"2d4d4264-4d40-40c7-96cc-f946b789a556"],

Cell["\<\
Further, each of these lists is hyperlinked to the definitions of the \
different items contained in them. All you need to do is click on an item in \
the list to have its description displayed. In this Guide, we will explore \
many of these different functions in some detail. In some instances, this \
discussion serves as the primary reference for the subject matter. In other \
instances, however, the subject is discussed in more detail elsewhere. Next, \
we will learn how to create models of optical components and light sources.\
\>", "Text",
 CellTags->{
  "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", 
   "RG1.8"},ExpressionUUID->"04677792-97c0-428e-a416-043a30fdab99"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Rayica User Guide Introduction", 
   "RG1."},ExpressionUUID->"65448239-c679-424f-b8b0-8efa2aa4a94c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2. Modeling Optical Components and Light Sources", "Section",
 Evaluatable->False,
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "2.", "Ray", "Component", "Components and Sources", "2. Introduction", 
   "2.1", "2.2", "2.3", "2.4", "RG2.", 
   "RG2.0"},ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has its own language for describing optical systems. In general, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " considers an optical system to be a collection of light sources and \
optical components. There are many different types of components and light \
sources in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " and each type is specified by a particular function. For example, a \
parallel light sheet is modeled by the ",
 StyleBox["LineOfRays", "Input"],
 " function while a mirror is modeled by the ",
 StyleBox["Mirror", "Input"],
 " function. After evaluation, these functions generate one of two special \
data structures that carry the optical properties",
 StyleBox[".",
  FontSlant->"Italic"],
 " In particular, all component functions create a ",
 StyleBox["Component", "Input",
  FontFamily->"Courier"],
 " object, while all light source functions create a ",
 StyleBox["Source", "Input",
  FontFamily->"Courier"],
 " object. In this section, you will learn how to use component functions and \
light source functions to model optical components and light sources. Later \
on, you will learn how to define an optical system by listing together a \
combination of light sources and optical components. In particular, you will \
see that you can specify an optical system by placing your light sources and \
components in a list whose order describes the order of the light propagation \
through the optical components."
}], "Text",
 CellTags->{
  "Components and Sources", "2. Introduction", "RG2.", 
   "RG2.0"},ExpressionUUID->"3a3fa262-4e29-486e-8f42-6aba6019448f"],

Cell[CellGroupData[{

Cell["Coordinates", "Subsubsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Components and Sources", "2. Introduction", "RG2.", 
   "RG2.0"},ExpressionUUID->"b23d5c84-e672-4ff2-9bd7-b56a49123486"],

Cell[TextData[{
 "In ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", the X-axis runs in the horizontal direction, parallel to the computer \
screen, and is the default optical axis for optical systems, components \
within systems, and surfaces within components. The Z-axis encompasses the \
vertical direction and the Y-axis is right-handed with respect to the X and Z \
directions. Within an optical system, components and rays are located using \
the system's \"world\" coordinate system. Each surface within a component has \
its own local coordinate system and carries a three-dimensional rotation \
matrix plus a three-dimensional translation vector to transform a point or \
ray from the \[OpenCurlyDoubleQuote]world\[CloseCurlyDoubleQuote] coordinate \
system into the surface's local coordinate system, and back. This \
world-to-surface transform (matrix plus vector) is derived by combining the \
world-to-component and component-to-surface transforms during component \
initialization."
}], "Text",
 CellTags->{
  "Components and Sources", "2. Introduction", "RG2.", 
   "RG2.0"},ExpressionUUID->"0a9fdeff-c71d-4bda-8c34-871b949d40e1"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"7d0d805f-4722-4877-902c-6e903b587b3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modeling a light source", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Components and Sources", "Modeling a light source", "RG2.", "RG2.1", 
   "2.1"},ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541"],

Cell[TextData[{
 "Next, we will take a closer look at light source functions.",
 StyleBox[" Optica",
  FontSlant->"Italic"],
 " has a built-in series of functions that model different patterns of ray \
light sources.  Here is a list of the most common built-in light source \
functions."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"5e956b8d-0a1d-4670-9ef7-316f471bb0aa"],

Cell[TextData[{
 StyleBox["SingleRay[", "Input",
  FontFamily->"Courier"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " constructs a single ray of light with its starting position at the origin \
and is directed down the positive ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis. \n",
 StyleBox["CircleOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", ",
 StyleBox["size",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of rays distributed on the surface of a tube that points \
down the positive x-axis.\n",
 StyleBox["ConeOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", ",
 StyleBox["spread",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of rays distributed along a funnel-shaped surface that \
is oriented down the positive x-axis.\n",
 StyleBox["WedgeOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", ",
 StyleBox["spread",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of rays in the x-y plane that fan out with their chief \
direction oriented down the positive x-axis and are distributed across the \
y-coordinate with the specified fan spread.\n",
 StyleBox["LineOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", ",
 StyleBox["linewidth",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of rays in the x-y plane that point down the positive \
x-axis and are distributed along the y-coordinate with the specified \
linewidth.\n",
 StyleBox["GridOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", ",
 StyleBox["size",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of rays distributed throughout a tube-shaped volume that \
points down the positive x-axis.\n",
 StyleBox["PointOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", ",
 StyleBox["spread",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of rays distributed throughout a funnel-shaped volume \
that is oriented down the positive x-axis.\n",
 StyleBox["CustomRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", {{",
 StyleBox["name",
  FontSlant->"Italic"],
 ", ",
 StyleBox["vector",
  FontSlant->"Italic"],
 "}..}, ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of user-defined rays.\n",
 StyleBox["GaussianBeam[", "Input"],
 StyleBox["beamspotsize",
  FontSlant->"Italic"],
 ", ",
 StyleBox["fulldivergence",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " and ",
 StyleBox["GaussianBeam[", "Input"],
 StyleBox["complexbeamparameter",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is a light source that takes either the output beam spotsize radius \
(specified at 1/e of the axial value of the electric field amplitude peak in \
the starting plane) and far-field beam fulldivergence (specified as the full \
angle in radians at 1/e^2) or the complex beam parameter as input and creates \
an extended point source ray model of a Gaussian laser beam.\n",
 StyleBox["RainbowOfRays[", "Input"],
 StyleBox["seed",
  FontSlant->"Italic"],
 ", {",
 StyleBox["minwavelength",
  FontSlant->"Italic"],
 ", ",
 StyleBox["maxwavelength",
  FontSlant->"Italic"],
 "}, ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " initializes a set of overlapping rays that point down the positive x-axis \
and are distributed over the specified range of wavelengths, given in microns."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"163be0ce-c836-4a05-b602-043cfeb767c5"],

Cell["Ten commonly used light source functions.", "Commentary",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"27a68c2a-97e8-4545-9c15-783313072250"],

Cell[TextData[{
 "At any time that you wish while working with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", you can access a listing of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s main high-level light source functions with the ",
 StyleBox["SourceFunctions", "Input"],
 " command:"
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"0d4877d2-630c-4e99-8871-bfb21f4e30b2"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SourceFunctions", "Input"]], "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"},
 CellLabel->"In[10]:=",ExpressionUUID->"8f30dbd1-2c32-4f9c-9b9c-6b2fa197b05a"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     ButtonBox[
      StyleBox["\<\"CircleOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CircleOfRays", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"LineOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"LineOfRays", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"ConeOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ConeOfRays", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PointOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"PointOfRays", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CustomRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"CustomRays", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RainbowOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"RainbowOfRays", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"GaussianBeam\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"GaussianBeam", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SingleRay\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"SingleRay", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"GridOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"GridOfRays", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"WedgeOfRays\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"WedgeOfRays", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]}
   },
   AutoDelete->False,
   GridBoxBackground->{"Columns" -> {{
        GrayLevel[0.930022]}}},
   GridBoxDividers->{
    "Columns" -> {True, {False}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {1, 1, 1, {1.05}},
      "RowsIndexed" -> {}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.563367526868037*^9, 3.5660869818206177`*^9, 
  3.566101733534189*^9, 3.566139176565667*^9, 3.6147077898049726`*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.1"},
 CellLabel->"Out[10]=",ExpressionUUID->"98f38436-b1e7-4aef-a162-3c76193a021f"]
}, Open  ]],

Cell[TextData[{
 "In Mathmatica, ",
 StyleBox["SourceFunctions", "Input",
  FontSlant->"Plain"],
 " gives you hyperlinks to ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s most important light-source functions. Clicking on any name will give \
you a description of its use."
}], "Commentary",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"634fbaf7-e6e1-48c2-8a43-5d6fe3abb5e0"],

Cell[TextData[{
 "Most light sources in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " generate multiple rays of light. However, the simplest type of light \
source is the ",
 StyleBox["SingleRay", "Input",
  FontFamily->"Courier"],
 StyleBox[" function. ",
  FontFamily->"Times New Roman"],
 "This is designed for applications that require a single ray to be traced. \
When multiple rays are required, you could in principle specify a list of ",
 StyleBox["SingleRay", "Input"],
 " functions for each ray, but it is always faster and more memory efficient \
to use one of the other built-in light source functions instead."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"bb566f6b-daf3-4983-869d-a2f2b0573f0b"],

Cell[TextData[{
 "In ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", each light source function generates the information needed to describe a \
particular pattern of geometric rays. You can either store this generated \
information in an intermediate variable or immediately use it in a ray-trace \
calculation.  Here is how you evaluate the ",
 StyleBox["SingleRay", "Input",
  FontFamily->"Courier"],
 StyleBox[" function and assign its information to a variable called ",
  FontFamily->"Times New Roman"],
 StyleBox["lightsource", "Input",
  FontFamily->"Courier"],
 StyleBox[".",
  FontFamily->"Times New Roman"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"f6d83e78-531c-4ffa-ac13-f9f2557d1e00"],

Cell[CellGroupData[{

Cell["lightsource = SingleRay[]", "Input",
 CellMargins->{{20, Inherited}, {Inherited, Inherited}},
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"},
 CellLabel->"In[11]:=",ExpressionUUID->"3c66cd45-fbcd-4b97-a7ff-ed3bf9d5a639"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"SingleRay", "[", "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367526963016*^9, 3.5660869819741592`*^9, 
  3.566101733643022*^9, 3.566139176658956*^9, 3.614707789890162*^9},
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"},
 CellLabel->"Out[11]=",ExpressionUUID->"cbee1408-a603-4db7-a141-fc74ed03cd9f"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " normally hides the contents of its light sources by echoing the function \
input back to the screen. For a first-time user of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", this can be a bit disconcerting since it appears that nothing has \
occurred at all. For this reason, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " changes the returned text color (typically to green) for valid entries \
instead of using the default black color of ordinary ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " output. This color change indicates that the input has been correctly \
evaluated by ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". If there is no color change, then the function has not been recognized by \
",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " and, most likely, there has been a typographical mistake. In addition, if \
you use ",
 StyleBox["InputForm", "Input"],
 ", as shown below, you can see that the ",
 StyleBox["SingleRay", "Input"],
 " function has actually generated a hidden packet of information that is \
encapsulated by a ",
 StyleBox["Source", "Input"],
 " object."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"83e9195b-377a-46f7-940b-d5f912ae28cd"],

Cell[CellGroupData[{

Cell["lightsource//InputForm", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"},
 CellLabel->"In[12]:=",ExpressionUUID->"44acd788-f49f-4b3c-ada7-aaa673fd1ee2"],

Cell["\<\
Source[{}, SourceDescription :> SourceDescription[SingleRay[{Ray[]}, 1, \
SourceTransformation -> 
     {{0., 0., 0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}}, \
SymbolicSourceTransformation -> 
     {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}]], SourceTransformation \
:> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
 SymbolicSourceTransformation :> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SourceLevel :> {1, 1}, NumberOfRays :> 1, 
 BirthPoint :> {0, 0, 0}, CoordinateSystem :> CartesianCoordinates, \
StartAtBirthPoint :> True, MonteCarlo :> False, SourceID :> 6916, 
 SourceFraction :> 1, SourceOffset :> 0, GridSpacing :> (#1 & ), PowerOutput \
:> PowerOutput, SymbolicValues :> {}]\
\>", "Output",
 CellChangeTimes->{3.563367527046775*^9, 3.566086982105217*^9, 
  3.566101733746883*^9, 3.566139176759231*^9, 3.6147077899863453`*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.1"},
 CellLabel->
  "Out[12]//InputForm=",ExpressionUUID->"efe3dfab-e4d5-413f-be0c-\
367f2a295ab4"]
}, Open  ]],

Cell[TextData[{
 "Because the ",
 StyleBox["Source", "Input"],
 " object is automatically created by all of the built-in light source \
functions, the user of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " never has to worry about the contents of this object. In fact, unless you \
use ",
 StyleBox["InputForm", "Input"],
 ", as demonstrated here, you will never even see the contents of another ",
 StyleBox["Source", "Input"],
 " object again after this discussion! Nevertheless, it is helpful to \
understand what happens when you evaluate a light source function (ie: it \
creates a ",
 StyleBox["Source", "Input"],
 " object.) This information is used later by ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " for ray-tracing. In the previous result, the \"SingleRay[ ]\" returned to \
the screen merely identified the type of function that generated the ",
 StyleBox["Source", "Input"],
 " object, namely by ",
 StyleBox["SingleRay", "Input"],
 "! In advanced forms of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", this \"self-echoing\" feature enables ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " to support GUI-mouse gestures in addition to the textual entry of optics. \
For the basic ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " operation discussed here, however, we will only consider the textual entry \
of optics."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"194aaa1b-e39b-483d-98c9-86fbf1a155d7"],

Cell[TextData[{
 "A ",
 StyleBox["Source", "Input"],
 " object is not directly used for the ray-trace calculation. Rather, the ",
 StyleBox["Source", "Input"],
 " information is only used at the start of the ray trace to initiate the \
rays for the trace. Essentially, the ",
 StyleBox["Source", "Input"],
 " object informs ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " how create the required rays at the start of the ray trace. In particular, \
the ",
 StyleBox["Source", "Input"],
 " object indicates which type of function has created it (",
 StyleBox["SingleRay", "Input"],
 " in this case) and includes special instructions about how many rays are to \
be created as well as how to configure the created rays into a particular \
spatial pattern. All of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s light source functions generate a ",
 StyleBox["Source", "Input"],
 " object in the same fashion as ",
 StyleBox["SingleRay", "Input"],
 ". Each light source function always creates a single ",
 StyleBox["Source", "Input"],
 " object regardless of the actual number of rays used in the trace. After a \
ray trace has been carried out, specific information is usually returned \
about the optical surface intersections encountered by the rays in the trace. \
However, ",
 StyleBox["Source", "Input"],
 " objects are only used to initiate the trace and are not used to store the \
resulting information from the ray trace. Instead, the traced rays are stored \
either as ",
 StyleBox["Ray", "Input"],
 " objects (with ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 "/",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 ") or as ",
 StyleBox["TurboRays", "Input"],
 " objects (with ",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 "). In the next section, you will learn more about ",
 StyleBox["Ray", "Input"],
 " and ",
 StyleBox["TurboRays", "Input"],
 " objects and how they get created from ",
 StyleBox["Source", "Input"],
 " objects by the ray-trace functions of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.1"},ExpressionUUID->"2db9e75b-e121-4086-8722-eee8505e9120"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"e89a6918-b041-49fc-8ab5-cdb7ffb5adfd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Ray versus TurboRays", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", 
   "2.2"},ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd"],

Cell[TextData[{
 "In this section, we will examine how ",
 StyleBox["PropagateSystem", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " store ray information as either ",
 StyleBox["Ray", "Input"],
 " or ",
 StyleBox["TurboRays", "Input"],
 " objects. In general, however, the user of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will never work directly with ",
 StyleBox["Ray", "Input"],
 " and ",
 StyleBox["TurboRays", "Input"],
 " objects. As such, the following discussion is simply provided to help the \
user gain further insight into how ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s handles the ray-trace information. For the most part, these mechanisms \
are hidden away from the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " user. If you are learning about ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " for the very first time, you can ",
 ButtonBox["skip",
  BaseStyle->"Hyperlink",
  ButtonData:>"How Optica manages default light source settings"],
 " this section without penalty."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"3dae03d0-b7a4-4671-b970-ff4fb797fb9f"],

Cell[TextData[{
 "At the start of a ray-trace, both ",
 StyleBox["PropagateSystem", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " use the ",
 StyleBox["CreateRays", "Input"],
 " function to convert ",
 StyleBox["Source", "Input"],
 " objects into either ",
 StyleBox["Ray", "Input"],
 " or ",
 StyleBox["TurboRay", "Input"],
 " objects. This initializes the ray information for the trace."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"07b827ce-dce5-4812-850d-a7d45348011b"],

Cell[TextData[{
 StyleBox["CreateRays[", "Input"],
 StyleBox["source",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is used by ",
 StyleBox["PropagateSystem", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " to generate either ",
 StyleBox["Ray", "Input"],
 " objects or a ",
 StyleBox["TurboRays", "Input"],
 " object that represents a set of rays for the given light source.\n\n",
 StyleBox["Ray[", "Input"],
 StyleBox["rules",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " contains ",
 StyleBox["rules",
  FontSlant->"Italic"],
 " that is used by ",
 StyleBox["PropagateSystem", "Input"],
 " to characterize a single ray segment of light between two optical \
surfaces.\n\n",
 StyleBox["TurboRays[", "Input"],
 StyleBox["{", "Text"],
 StyleBox["raysegment1",
  FontSlant->"Italic"],
 ", ",
 StyleBox["raysegment2",
  FontSlant->"Italic"],
 ", ...}",
 StyleBox["]", "Input"],
 " gives a collection of ray segment parameters for use with ",
 StyleBox["TurboTrace", "Input"],
 "."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab"],

Cell[TextData[{
 "The ",
 StyleBox["Ray", "Input"],
 " and ",
 StyleBox["TurboRays", "Input"],
 " objects offer two parallel ways of storing the same information about \
rays. In particular, the ",
 StyleBox["Ray", "Input"],
 " object is used by ",
 StyleBox["PropagateSystem", "Input"],
 " to hold ray information, while the ",
 StyleBox["TurboRays", "Input"],
 " object is used instead by ",
 StyleBox["TurboTrace", "Input"],
 ". As an example, we will use the ",
 StyleBox["WedgeOfRays", "Input"],
 " function to generate three rays. First, we will assign the ",
 StyleBox["WedgeOfRays", "Input"],
 " result into a variable, called ",
 StyleBox["wedgeofrays", "Input"],
 "."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"ec17fe0d-d65b-4b4b-aec1-5b1491287176"],

Cell[CellGroupData[{

Cell["wedgeofrays = WedgeOfRays[10]", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->"In[13]:=",ExpressionUUID->"ccde2674-390a-4365-96e1-7846afb2c154"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"WedgeOfRays", "[", "10", "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367527083404*^9, 3.56608698217163*^9, 
  3.566101733793371*^9, 3.566139176814377*^9, 3.6147077900214443`*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->"Out[13]=",ExpressionUUID->"de932cca-b2d3-496e-be44-bc5e187564af"]
}, Open  ]],

Cell[TextData[{
 "With ",
 StyleBox["InputForm", "Input"],
 ", we can see that, like ",
 StyleBox["SingleRay", "Input"],
 ", ",
 StyleBox["WedgeOfRays", "Input"],
 " also creates a single ",
 StyleBox["Source", "Input"],
 " object. However, this ",
 StyleBox["Source", "Input"],
 " object defines a wedge-shaped pattern of three rays."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"e2f135df-65eb-45c1-8caf-4fc68baa3243"],

Cell[CellGroupData[{

Cell["wedgeofrays//InputForm", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->"In[14]:=",ExpressionUUID->"26ac156b-7290-47db-8499-89f9e7408435"],

Cell["\<\
Source[{}, SourceDescription :> SourceDescription[WedgeOfRays[{Ray[]}, 10, \
SourceTransformation -> 
     {{0., 0., 0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}}, \
SymbolicSourceTransformation -> 
     {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}]], SourceTransformation \
:> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}}, 
 SymbolicSourceTransformation :> {{0, 0, 0}, {{1, 0, 0}, {0, 1, 0}, {0, 0, \
1}}}, SourceLevel :> {1, 1}, NumberOfRays :> 3, 
 BirthPoint :> {0, 0, 0}, CoordinateSystem :> PolarCoordinates, \
StartAtBirthPoint :> True, MonteCarlo :> False, SourceID :> 6917, 
 SourceFraction :> 1, SourceOffset :> 0, GridSpacing :> (#1 & ), PowerOutput \
:> 100, SymbolicValues :> {}]\
\>", "Output",
 CellChangeTimes->{3.56336752713239*^9, 3.5660869822065*^9, 
  3.566101733843527*^9, 3.566139176860121*^9, 3.614707790078781*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->
  "Out[14]//InputForm=",ExpressionUUID->"b59b4740-4088-412d-9344-\
67d755cedbec"]
}, Open  ]],

Cell[TextData[{
 "Next, we will demonstrate how ",
 StyleBox["CreateRays", "Input"],
 " is used by ",
 StyleBox["PropagateSystem", "Input"],
 " to initialize the ray information as ",
 StyleBox["Ray", "Input"],
 " objects. When we apply ",
 StyleBox["CreateRays", "Input"],
 " to ",
 StyleBox["wedgeofrays", "Input"],
 ", there are three ",
 StyleBox["Ray", "Input"],
 " objects generated."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"ae70480d-bef9-4f92-901c-c4f9883b9009"],

Cell[CellGroupData[{

Cell["CreateRays[wedgeofrays]//InputForm", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->"In[15]:=",ExpressionUUID->"26204c28-0611-4bdb-8ee8-f41e1974186f"],

Cell["\<\
{Ray[RaySourceNumber -> {{1, 3}, {1, 0}}, SourceID :> 6917, Intensity :> \
100., IntensityScale :> 1., OpticalMedium :> Air, 
  Polarization :> {0., 1., 0.}, RayEnd :> {0., 0., 0.}, RayLabelPositions :> \
{{0., 0., 0.}}, RayLength :> 0., RayLineRGB :> Automatic, 
  RayPointRGB :> {0., 0., 0.}, RayStart :> {0., 0., 0.}, RayTilt :> \
{0.9961946980917455, 0.08715574274765817, 0.}, 
  RefractiveIndex :> 1.00026945145708, RotationMatrix :> \
{{0.9961946980917455, 0.08715574274765817, 0.}, {-0.08715574274765817, 
    0.9961946980917455, 0.}, {0., 0., 1.}}, SourceTransformation :> {{0., 0., \
0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}}, 
  WaveFrontID :> {{6917, 0}}], Ray[RaySourceNumber -> {{2, 3}, {2, 0}}, \
SourceID :> 6917, Intensity :> 100., IntensityScale :> 1., 
  OpticalMedium :> Air, Polarization :> {0., 1., 0.}, RayEnd :> {0., 0., 0.}, \
RayLabelPositions :> {{0., 0., 0.}}, RayLength :> 0., 
  RayLineRGB :> Automatic, RayPointRGB :> {0., 0., 0.}, RayStart :> {0., 0., \
0.}, RayTilt :> {1., 0., 0.}, 
  RefractiveIndex :> 1.00026945145708, RotationMatrix :> {{1., 0., 0.}, {0., \
1., 0.}, {0., 0., 1.}}, 
  SourceTransformation :> {{0., 0., 0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., \
0., 1.}}}, WaveFrontID :> {{6917, 0}}], 
 Ray[RaySourceNumber -> {{3, 3}, {3, 0}}, SourceID :> 6917, Intensity :> \
100., IntensityScale :> 1., OpticalMedium :> Air, 
  Polarization :> {0., 1., 0.}, RayEnd :> {0., 0., 0.}, RayLabelPositions :> \
{{0., 0., 0.}}, RayLength :> 0., RayLineRGB :> Automatic, 
  RayPointRGB :> {0., 0., 0.}, RayStart :> {0., 0., 0.}, RayTilt :> \
{0.9961946980917455, -0.08715574274765817, 0.}, 
  RefractiveIndex :> 1.00026945145708, RotationMatrix :> \
{{0.9961946980917455, -0.08715574274765817, 0.}, {0.08715574274765817, 
    0.9961946980917455, 0.}, {0., 0., 1.}}, SourceTransformation :> {{0., 0., \
0.}, {{1., 0., 0.}, {0., 1., 0.}, {0., 0., 1.}}}, 
  WaveFrontID :> {{6917, 0}}]}\
\>", "Output",
 CellChangeTimes->{3.563367527185725*^9, 3.566086982238537*^9, 
  3.566101733893765*^9, 3.56613917691076*^9, 3.614707790120624*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->
  "Out[15]//InputForm=",ExpressionUUID->"1e7fbbbe-ac15-463a-b599-\
8d861ee982fb"]
}, Open  ]],

Cell[TextData[{
 "Here, each ",
 StyleBox["Ray", "Input"],
 " object represents a different ray segment. When ",
 StyleBox["TurboTrace", "Input"],
 " is used for ray-tracing, it works instead with a ",
 StyleBox["TurboRays", "Input"],
 " object. The ",
 StyleBox["OutputType", "Input"],
 " option is used with ",
 StyleBox["CreateRays", "Input"],
 " to determine whether ",
 StyleBox["CreateRays", "Input"],
 " generates a ",
 StyleBox["Ray", "Input"],
 " object or a ",
 StyleBox["TurboRays", "Input"],
 " object from the ",
 StyleBox["Source", "Input"],
 " information. By default, ",
 StyleBox["CreateRays", "Input"],
 " creates ",
 StyleBox["Ray", "Input"],
 " objects. However, when ",
 StyleBox["TurboTrace", "Input"],
 " calls ",
 StyleBox["CreateRays", "Input"],
 ", it passes ",
 StyleBox["OutputType -> TurboRays", "Input"],
 " to obtain a ",
 StyleBox["TurboRays", "Input"],
 " object. Next we apply ",
 StyleBox["CreateRays", "Input"],
 " to ",
 StyleBox["wedgeofrays", "Input"],
 " for a second time with ",
 StyleBox["OutputType -> TurboRays", "Input"],
 "."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"06637bc5-a376-4811-8505-c4e6bcc7afba"],

Cell[CellGroupData[{

Cell["CreateRays[wedgeofrays, OutputType -> TurboRays]//InputForm", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->"In[16]:=",ExpressionUUID->"c14e6e5e-b415-4b18-87dd-2a3d5e9dfadf"],

Cell["\<\
TurboRays[{{0., 0., 0., 0., 0., 0., 0.9961946980917455, 0.08715574274765817, \
0., -0.08715574274765817, 0.9961946980917455, 0., 0., 0., 1., 
  0.532, 100., 0.33333333333333337, 0., 1.00026945145708, 0., 0., 0., 0., 0., \
0., 0., 6917., 6917., 1., 3., 1., 0., 1., 0., 0., 0., 1., 
  0.}, {0., 0., 0., 0., 0., 0., 1., 0., 0., 0., 1., 0., 0., 0., 1., 0.532, \
100., 0.33333333333333337, 0., 1.00026945145708, 0., 0., 0., 0., 
  0., 0., 0., 6917., 6917., 2., 3., 2., 0., 1., 0., 0., 0., 1., 0.}, {0., 0., \
0., 0., 0., 0., 0.9961946980917455, -0.08715574274765817, 0., 
  0.08715574274765817, 0.9961946980917455, 0., 0., 0., 1., 0.532, 100., \
0.33333333333333337, 0., 1.00026945145708, 0., 0., 0., 0., 0., 0., 
  0., 6917., 6917., 3., 3., 3., 0., 1., 0., 0., 0., 1., 0.}}]\
\>", "Output",
 CellChangeTimes->{3.5633675272346363`*^9, 3.566086982272994*^9, 
  3.566101733943651*^9, 3.566139176961081*^9, 3.614707790157422*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.2"},
 CellLabel->
  "Out[16]//InputForm=",ExpressionUUID->"35245519-99f9-4861-a0fc-\
d218481c739f"]
}, Open  ]],

Cell[TextData[{
 "This time, only a single ",
 StyleBox["TurboRays", "Input"],
 " object is produced that contains three sets of numbers. In this case, each \
set of numbers represents a different ray segment. From this, we can see that \
",
 StyleBox["TurboRays", "Input"],
 " is much more efficient at holding information than ",
 StyleBox["Ray", "Input"],
 " objects! This is gives ",
 StyleBox["TurboTrace", "Input"],
 " the ability to work with very large ray-data sets and consume less memory. \
However, the ",
 StyleBox["Ray", "Input"],
 " object is much more flexible at holding different sorts of optical \
parameters, such as user-defined parameters. This, in turn, gives ",
 StyleBox["PropagateSystem", "Input"],
 " added flexibility over ",
 StyleBox["TurboTrace", "Input"],
 " for tracing customized information. In general, however, the user of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will never work directly with ",
 StyleBox["Ray", "Input"],
 " and ",
 StyleBox["TurboRays", "Input"],
 " objects and these conversions happen transparently. In the next section, \
we will learn about ",
 StyleBox["Options[Ray]", "Input"],
 ". ",
 StyleBox["Options[Ray]", "Input"],
 "is used by ",
 StyleBox["CreateRays", "Input"],
 " to fill in any essential ray parameters missing from the specified ",
 StyleBox["Source", "Input"],
 " object during its ray creation."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.2"},ExpressionUUID->"78c6969c-cf10-4e6b-b4db-fe4cd0465117"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"e4f9b90a-8b43-46b2-a164-64cf7a7d1efd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "How ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " manages default light source settings"
}], "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "How Rayica manages default light source settings", 
   "Components and Sources", "RG2.", "RG2.3", 
   "2.3"},ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa"],

Cell[TextData[{
 "In ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " as well as ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", most built-in functions have a way to pass default settings about certain \
parameters. This relieves the user from always having to specify all possible \
parameters required by the function to operate. Such default parameters are \
referred to as \"options\" because you can optionally decide to change the \
setting of such a parameter (but you don't have too!) As you will see \
shortly, each option follows the pattern: ",
 StyleBox["optionlabel",
  FontSlant->"Italic"],
 " -> ",
 StyleBox["optionvalue",
  FontSlant->"Italic"],
 ". (Such a pattern is also called a \"rule\" because it is internally \
evaluated by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " as: ",
 StyleBox["Rule[", "Input"],
 StyleBox["optionlabel",
  FontSlant->"Italic"],
 ", ",
 StyleBox["optionvalue",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 ".) As with all other types of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s light source functions, ",
 StyleBox["SingleRay[]", "Input"],
 " has many options that help describe the generated ray."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.3"},ExpressionUUID->"f7db2f37-f6c0-4557-a85c-9e4ca13ee1d9"],

Cell[TextData[{
 "Since all types of light sources must make the same basic assumptions about \
their created rays, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " uses a single location, called ",
 StyleBox["Options[Ray]", "Input"],
 ", to store this information.  The most important of these settings include \
physical attributes, such as: wavelength, polarization, intensity, and \
optical length. However, there are also a number of other non-physical \
attributes as well. You can check these default assumptions by examining the \
contents of ",
 StyleBox["Options[Ray]", "Input"],
 "."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.3"},ExpressionUUID->"7fd2b89a-85a7-4bac-9b28-1d4e4e9630e0"],

Cell[CellGroupData[{

Cell["Options[Ray]", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"},
 CellLabel->"In[17]:=",ExpressionUUID->"dc651577-4f0a-49cd-a800-e175d4bf5069"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ComponentIncrement", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentNumber", "\[Rule]", "ComponentNumber"}], ",", 
   RowBox[{"ConfinedNumber", "\[Rule]", "ConfinedNumber"}], ",", 
   RowBox[{"ConfinedPosition", "\[Rule]", "ConfinedPosition"}], ",", 
   RowBox[{"DiffractionMismatch", "\[Rule]", "DiffractionMismatch"}], ",", 
   RowBox[{"DiffractionOrderNumber", "\[Rule]", "DiffractionOrderNumber"}], 
   ",", 
   RowBox[{"GenerationNumber", "\[Rule]", "GenerationNumber"}], ",", 
   RowBox[{"Intensity", "\[Rule]", "100.`"}], ",", 
   RowBox[{"IntensityScale", "\[Rule]", "1.`"}], ",", 
   RowBox[{"InternalDirectionChange", "\[Rule]", "False"}], ",", 
   RowBox[{"IntersectionNumber", "\[Rule]", "IntersectionNumber"}], ",", 
   RowBox[{"IntrinsicMedium", "\[Rule]", "Air"}], ",", 
   RowBox[{"NewAuthorizedOptions", "\[Rule]", "NewAuthorizedOptions"}], ",", 
   RowBox[{"OffAxis", "\[Rule]", "OffAxis"}], ",", 
   RowBox[{"OpticalLength", "\[Rule]", "0.`"}], ",", 
   RowBox[{"OpticalMedium", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PhaseShift", "\[Rule]", "0.`"}], ",", 
   RowBox[{"Polarization", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"RayEnd", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"RayLabelPositions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], "}"}]}], ",", 
   RowBox[{"RayLabels", "\[Rule]", 
    RowBox[{"{", "\<\"\"\>", "}"}]}], ",", 
   RowBox[{"RayLength", "\[Rule]", "0.`"}], ",", 
   RowBox[{"RayLineRGB", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"RayLineStyle", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"RayLineThickness", "\[Rule]", "0.5`"}], ",", 
   RowBox[{"RayPointRGB", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"RayPointSize", "\[Rule]", "2.`"}], ",", 
   RowBox[{"RayPointStyle", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"RaySourceNumber", "\[Rule]", "RaySourceNumber"}], ",", 
   RowBox[{"RayStart", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"RayTilt", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"RefractiveIndex", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"RotationMatrix", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"SourceID", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"SourceTransformation", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"SurfaceBoundary", "\[Rule]", "SurfaceBoundary"}], ",", 
   RowBox[{"SurfaceCoordinates", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"SurfaceID", "\[Rule]", "SurfaceID"}], ",", 
   RowBox[{"SurfaceIncrement", "\[Rule]", "1"}], ",", 
   RowBox[{"SurfaceNormalMatrix", "\[Rule]", "SurfaceNormalMatrix"}], ",", 
   RowBox[{"SurfaceNumber", "\[Rule]", "SurfaceNumber"}], ",", 
   RowBox[{"SymbolicWaveLength", "\[Rule]", "SymbolicWaveLength"}], ",", 
   RowBox[{"Temperature", "\[Rule]", "20.`"}], ",", 
   RowBox[{"Tension", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"101300.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "101300.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "0.`", ",", "101300.`"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"UnconfinedIncrement", "\[Rule]", "1"}], ",", 
   RowBox[{"UnconfinedPath", "\[Rule]", "UnconfinedPath"}], ",", 
   RowBox[{"UnconfinedPosition", "\[Rule]", "UnconfinedPosition"}], ",", 
   RowBox[{"WaveFrontID", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"WaveLength", "\[Rule]", "0.532`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563367527286007*^9, 3.56608698230584*^9, 
  3.56610173399961*^9, 3.566139177012648*^9, 3.6147077902072353`*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.3"},
 CellLabel->"Out[17]=",ExpressionUUID->"623a4163-fa46-4247-ad2b-263ba7b59c86"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Options[Ray]", "Input"],
 " applies to all of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s light sources since it determines what default values will be used by \
the rays at the start of the trace. In some cases, a parameter many not have \
a specific initial setting. In such cases, the ",
 StyleBox["optionvalue",
  FontSlant->"Italic"],
 " is given the same name as the ",
 StyleBox["optionlabel",
  FontSlant->"Italic"],
 ". In other cases, the ",
 StyleBox["optionvalue",
  FontSlant->"Italic"],
 " can simply be written as ",
 StyleBox["Automatic", "Input"],
 ". In such a case, the option value is dynamically assigned. Regardless of \
its setting, every possible option parameter is listed in ",
 StyleBox["Options", "Input"],
 " for the benefit of the user to know either that it exists or that it can \
be altered with a user-specified value."
}], "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.3"},ExpressionUUID->"c380cecc-f3c6-42a5-a0c4-0d6ef93e9822"],

Cell["\<\
In order to specify a new ray parameter setting, you simply pass the changed \
option setting as a parameter. For example, to change the wavelength setting \
to 0.633 microns, you would use:\
\>", "Text",
 CellTags->{
  "Components and Sources", "RG2.", 
   "RG2.3"},ExpressionUUID->"ff5b866d-87d0-457e-81c5-34d395797f94"],

Cell[CellGroupData[{

Cell["SingleRay[WaveLength -> .633]", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"},
 CellLabel->"In[18]:=",ExpressionUUID->"d0320a23-7f02-4e4a-88e6-aacdfcd7a573"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"SingleRay", "[", 
     RowBox[{"WaveLength", "\[Rule]", "0.633`"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367527320627*^9, 3.566086982575227*^9, 
  3.566101734047027*^9, 3.566139177060725*^9, 3.6147077903245707`*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.3"},
 CellLabel->"Out[18]=",ExpressionUUID->"bae2cc55-2bed-4232-892f-843be9ddaa2e"]
}, Open  ]],

Cell[TextData[{
 "In this case, a subsequent ray-trace would use this new wavelength setting. \
In addition, ",
 StyleBox["SingleRay", "Input"],
 " also has its own set of options that specifically applies to only the ",
 StyleBox["SingleRay", "Input"],
 " function. These are found in ",
 StyleBox["Options[SingleRay]", "Input"],
 ":"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.3"},ExpressionUUID->"2dd4bb18-47b5-4437-9dce-4eb4c658c3c4"],

Cell[CellGroupData[{

Cell["Options[SingleRay]", "Input",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"},
 CellLabel->"In[19]:=",ExpressionUUID->"b70d0283-7f35-4b33-9bcb-39989eb809fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"NumberOfRays", "\[Rule]", "1"}], ",", 
   RowBox[{"BirthPoint", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"SymbolicBirthPoint", "\[Rule]", "BirthPoint"}], ",", 
   RowBox[{"CoordinateSystem", "\[Rule]", "CartesianCoordinates"}], ",", 
   RowBox[{"StartAtBirthPoint", "\[Rule]", "True"}], ",", 
   RowBox[{"BalancePhaseFront", "\[Rule]", "True"}], ",", 
   RowBox[{"MonteCarlo", "\[Rule]", "False"}], ",", 
   RowBox[{"SourceOffset", "\[Rule]", "0"}], ",", 
   RowBox[{"SourceFraction", "\[Rule]", "1"}], ",", 
   RowBox[{"GridSpacing", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}], ",", 
   RowBox[{"IntensityFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}], ",", 
   RowBox[{"PolarizationFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#1", "&"}], ")"}]}], ",", 
   RowBox[{"SourceID", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5633675273681393`*^9, 3.566086982605236*^9, 
  3.566101734093987*^9, 3.566139177111434*^9, 3.614707790355319*^9},
 CellTags->{"Components and Sources", "RG2.", "RG2.3"},
 CellLabel->"Out[19]=",ExpressionUUID->"df31c411-7635-43b3-af9e-e120b2b1bff3"]
}, Open  ]],

Cell[TextData[{
 "In the same manner as ",
 StyleBox["SingleRay", "Input"],
 ", all other built-in light source functions also have their own specific \
option settings that are accessed with their function name, given by ",
 StyleBox["Options[", "Input"],
 StyleBox["function",
  FontSlant->"Italic"],
 " ",
 StyleBox["name",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 ".  In fact, a good way to learn more about any unfamiliar function in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " (or ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ") is to have a look at its built-in options because this often gives you a \
clue about the range of behaviors that the function can exhibit. You can \
learn more about ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s built-in light source functions in ",
 ButtonBox["Section 1.3.4",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"General Architecture"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "Components and Sources", "RG2.", 
   "RG2.3"},ExpressionUUID->"13fe18f5-4bd8-4d78-a9c2-bc1b9650fca4"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"e9fedc5c-f759-4cd7-a3b7-2ab02f59cb2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Modeling an optical component", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Modeling an optical component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has many more functions for modelling optical components than it has for \
light sources. In fact, there are presently 122 component functions in common \
use.  At any time that you wish while working with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", you can access a listing of the component functions with the ",
 StyleBox["ComponentFunctions", "Input"],
 " command:"
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8"],

Cell[CellGroupData[{

Cell["ComponentFunctions", "Input",
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"In[20]:=",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     ButtonBox[
      StyleBox["\<\"ABCDOptic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ABCDOptic", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomDiffuserMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomDiffuserMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"HollowCornerCube\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"HollowCornerCube", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RodLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"RodLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AnamorphicOptic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AnamorphicOptic", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomFiber\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"CustomFiber", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"JonesMatrixOptic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"JonesMatrixOptic", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RodMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"RodMirror", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AnamorphicPrisms\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AnamorphicPrisms", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomFiberMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomFiberMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"LensDoublet\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"LensDoublet", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RoofPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"RoofPrism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"ApertureStop\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ApertureStop", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomGrating\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomGrating", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"LensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"LensSurface", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SchmidtLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"SchmidtLens", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AsphericLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AsphericLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomGratingMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomGratingMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"LensTriplet\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"LensTriplet", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SchmidtLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SchmidtLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AsphericLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AsphericLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"CustomLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"LinearPolarizer\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"LinearPolarizer", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Screen\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Screen", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"AsphericMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"AsphericMirror", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Mirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Mirror", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SlabPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"SlabPrism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"Baffle\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Baffle", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomMirror", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MirrorSpan\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"MirrorSpan", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SnowConeLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SnowConeLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BaffleSpan\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"BaffleSpan", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"CustomPrism", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ParabolicDiffuser\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ParabolicDiffuser", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SolidCornerCube\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SolidCornerCube", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BaffleWithHole\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BaffleWithHole", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CustomScreen\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomScreen", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ParabolicDiffuserMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ParabolicDiffuserMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Solitaire\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Solitaire", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BallBaffle\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"BallBaffle", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CylinderGraphic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CylinderGraphic", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ParabolicLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ParabolicLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphereGraphic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphereGraphic", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BallLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"BallLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CylindricalBaffle\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CylindricalBaffle", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ParabolicMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ParabolicMirror", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalBaffle\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalBaffle", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BallMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"BallMirror", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CylindricalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CylindricalLens", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PechanPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"PechanPrism", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalBeamSplitter\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalBeamSplitter", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BeamSplitter\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BeamSplitter", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CylindricalLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CylindricalLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PellinBrocaPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PellinBrocaPrism", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalDiffuser\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalDiffuser", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BeamSplitterCube\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BeamSplitterCube", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CylindricalMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CylindricalMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PentaPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"PentaPrism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalDiffuserMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalDiffuserMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BiConcaveCylindricalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BiConcaveCylindricalLens", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"CylindricalScreen\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CylindricalScreen", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PinHole\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"PinHole", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalGratingMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalGratingMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BiConcaveLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BiConcaveLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Diffuser\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Diffuser", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Pipe\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Pipe", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BiConvexCylindricalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BiConvexCylindricalLens", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"DiffuserMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"DiffuserMirror", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PlanoConcaveCylindricalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PlanoConcaveCylindricalLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BiConvexLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BiConvexLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"DirectVisionPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"DirectVisionPrism", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PlanoConcaveLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PlanoConcaveLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalMirror", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BirefringentLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"BirefringentLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"DovePrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"DovePrism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PlanoConvexCylindricalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PlanoConvexCylindricalLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SphericalScreen\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SphericalScreen", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"Boundary\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Boundary", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"DTIRCLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"DTIRCLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PlanoConvexLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PlanoConvexLens", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SquareConeMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SquareConeMirror", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"Box\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Box", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"DTIRCLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"DTIRCLensSurface", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PolarizingBeamSplitterCube\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PolarizingBeamSplitterCube", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"SurfaceFacet\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"SurfaceFacet", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"BoxGraphic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"BoxGraphic", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"EyeModel\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"EyeModel", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PolarizingPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PolarizingPrism", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ThickLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ThickLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CircleGraphic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CircleGraphic", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Fiber\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Fiber", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PolygonalMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PolygonalMirror", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ThinLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"ThinLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"ClearBoundary\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ClearBoundary", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"FreeFormOptic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"FreeFormOptic", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PolygonGraphic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"PolygonGraphic", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ToroidalLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ToroidalLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CompoundLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CompoundLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"FresnelRhomb\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"FresnelRhomb", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"PorroPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"PorroPrism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ToroidalLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ToroidalLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"ConjugateMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ConjugateMirror", "Optica`Optica`"}}, LongForm -> False],
      
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"FunnelLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"FunnelLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Prism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Prism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ToroidalMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ToroidalMirror", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CustomBaffle\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomBaffle", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"FunnelLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"FunnelLensSurface", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RectangleGraphic\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"RectangleGraphic", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"WedgePrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"WedgePrism", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CustomBeamSplitter\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomBeamSplitter", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Grating\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Grating", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RetardationPlate\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"RetardationPlate", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Window\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Window", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CustomBirefringentLensSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomBirefringentLensSurface", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"GratingMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"GratingMirror", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"ReversionPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"ReversionPrism", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"WinstonConeMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"WinstonConeMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CustomConjugateMirror\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomConjugateMirror", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"GRINLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"GRINLens", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RhomboidPrism\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"RhomboidPrism", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"CustomDiffuser\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"CustomDiffuser", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"HalfBallLens\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"HalfBallLens", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"RodBaffle\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"RodBaffle", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"", "Optica`Optica`"}}, LongForm -> 
        False],
      Evaluator->Automatic,
      Method->"Preemptive"]}
   },
   AutoDelete->False,
   GridBoxBackground->{"Columns" -> {{
        GrayLevel[0.930022]}}},
   GridBoxDividers->{
    "Columns" -> {True, {False}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {1, 1, 1, {1.05}},
      "RowsIndexed" -> {}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.563367527428443*^9, 3.566086982669011*^9, 
  3.5661017341675797`*^9, 3.5661391771781*^9, 3.614707790420466*^9},
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"Out[20]=",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc"]
}, Open  ]],

Cell[TextData[{
 "In Mathmatica, ",
 StyleBox["ComponentFunctions", "Input",
  FontSlant->"Plain"],
 " gives you h",
 StyleBox["yperlinks to ",
  FontSlant->"Italic"],
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s current component functions. Clicking on any name will give you a \
description of its use."
}], "Commentary",
 CellTags->{
  "Components and Sources", "2.4", "Component", "RG2.", 
   "RG2.4"},ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb"],

Cell[TextData[{
 " In addition to ones listed here, you can build your own custom component \
functions as well as download new functions from the ",
 "Optica Software",
 " web-site (www.opticasoftware.com). One of the most frequently used \
component functions is ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0"],

Cell[TextData[{
 StyleBox["PlanoConvexLens[", "Input",
  FontFamily->"Courier"],
 " ",
 StyleBox["focallength",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " refers to a lens with a planar surface on one side and a convex spherical \
surface on the other side."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8"],

Cell[TextData[{
 "Here is how you evaluate the ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 StyleBox[" function.",
  FontFamily->"Times New Roman"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238"],

Cell[CellGroupData[{

Cell["PlanoConvexLens[100, 50, 10]", "Input",
 PageBreakWithin->Automatic,
 GroupPageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"In[21]:=",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"PlanoConvexLens", "[", 
     RowBox[{"100", ",", "50", ",", "10"}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367527531116*^9, 3.5660869830180492`*^9, 
  3.566101734385837*^9, 3.5661391773781424`*^9, 3.614707790545308*^9},
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"Out[21]=",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca"]
}, Open  ]],

Cell[TextData[{
 "In the same fashion that ray source functions create ",
 StyleBox["Source", "Input",
  FontFamily->"Courier"],
 StyleBox[" objects, every component function creates a ",
  FontFamily->"Times New Roman"],
 StyleBox["Component", "Input",
  FontFamily->"Courier"],
 StyleBox[" object. In this ",
  FontFamily->"Times New Roman"],
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 StyleBox[" example, ",
  FontFamily->"Times New Roman"],
 "hidden behind the \"PlanoConvexLens[100,50,10]\" output returned to the \
screen is a very large expression that is encapsulated with the ",
 StyleBox["Component", "Input"],
 " head. It contains detailed information to describe a plano-convex lens \
having a focal length of 100 millimeters, a circular aperture 50 millimeters \
in diameter, and a lens center thickness of 10 millimeters. Instead of \
showing this entire expression, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " always hides the content",
 StyleBox["s of ",
  FontFamily->"Times New Roman"],
 StyleBox["Component", "Input",
  FontFamily->"Courier"],
 " by outputting back to the screen a description of how the component was \
generated. Here again, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " indicates a valid entry by returning the text in a different color from \
black."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930"],

Cell[TextData[{
 "As with light source functions and the ",
 StyleBox["Source", "Input"],
 " object, since the ",
 StyleBox["Component", "Input"],
 " object is automatically created by the built-in component functions, the \
user of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will never need to worry about the details of this ",
 StyleBox["Component", "Input"],
 " object. In fact, unless you use ",
 StyleBox["InputForm", "Input"],
 ", as demonstrated previously with the ",
 StyleBox["Source", "Input"],
 " object, the contents of the ",
 StyleBox["Component", "Input"],
 " object are always hidden. Nevertheless, it is helpful to understand what \
happens when you evaluate a component function."
}], "Text",
 CellTags->{
  "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"eef9b50e-e13a-421f-9021-c75994b22de3"],

Cell[TextData[{
 "As with light sources, you can us",
 StyleBox["e these generated ",
  FontFamily->"Times New Roman"],
 StyleBox["Component", "Input",
  FontFamily->"Courier"],
 StyleBox[" ",
  FontFamily->"Times New Roman"],
 "objects immediately after creating them for doing ray tracing and \
rendering, or you can assign them to a variable for future work. While ",
 StyleBox["focallength",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", and ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 " are all parameters given explicitly to the ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 StyleBox[" function,",
  FontFamily->"Times New Roman"],
 " other implicit parameters, such as the type of refractive material are \
kept as options of ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 StyleBox[". ",
  FontFamily->"Times New Roman"],
 "You can use ",
 StyleBox["Options[", "Input"],
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 StyleBox["]", "Input"],
 " to access the default options of ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6"],

Cell[CellGroupData[{

Cell["Options[PlanoConvexLens]", "Input",
 PageBreakWithin->Automatic,
 GroupPageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"In[22]:=",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Labels", "\[Rule]", "\<\"L\"\>"}], ",", 
   RowBox[{"LabelPositions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentDescription", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
   RowBox[{"Temperature", "\[Rule]", "Temperature"}], ",", 
   RowBox[{"Tension", "\[Rule]", "Tension"}], ",", 
   RowBox[{"Transmittance", "\[Rule]", "Transmittance"}], ",", 
   RowBox[{"Reflectance", "\[Rule]", "Reflectance"}], ",", 
   RowBox[{"GraphicDesign", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"CurvatureDirection", "\[Rule]", "Front"}], ",", 
   RowBox[{"DesignWaveLength", "\[Rule]", "0.5461`"}], ",", 
   RowBox[{"OffAxis", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"SwitchDirectionOnReflection", "\[Rule]", "False"}], ",", 
   RowBox[{"Resonate", "\[Rule]", "True"}], ",", 
   RowBox[{"Automatic", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Empty"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Sketch", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Empty"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Wire", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Solid", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Fill"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Empty"}]}], "}"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367527569088*^9, 3.5660869830602283`*^9, 
  3.566101734546069*^9, 3.566139177566935*^9, 3.614707790577235*^9},
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"Out[22]=",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e"]
}, Open  ]],

Cell[TextData[{
 "Notice the option ",
 StyleBox["ComponentMedium -> BK7", "Input",
  FontFamily->"Courier"],
 StyleBox[".",
  FontFamily->"Times New Roman"],
 " This option indicates that the refractive material of the planoconvex lens \
is assumed to be made of BK7 glass material. Here, the ",
 StyleBox["BK7", "Input"],
 " symbol specifies a particular wavelength-dependent model for the \
refractive index. However, you can also specify a fixed numeric value for ",
 StyleBox["ComponentMedium", "Input",
  FontFamily->"Courier"],
 ", as shown below. In this case, the refractive index is held constant for \
all wavelength values."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Component", "Components and Sources", "2.4", "RG2.", 
   "RG2.4"},ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2"],

Cell[CellGroupData[{

Cell[TextData[{
 "PlanoConvexLens[100, 50, 10, ",
 StyleBox["ComponentMedium -> ", "Input",
  FontFamily->"Courier"],
 "1.5]"
}], "Input",
 CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"In[23]:=",ExpressionUUID->"86d06f27-cac4-455d-963a-9c1e384be627"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"PlanoConvexLens", "[", 
     RowBox[{"100", ",", "50", ",", "10", ",", 
      RowBox[{"{", 
       RowBox[{"ComponentMedium", "\[Rule]", "1.5`"}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5633675277628813`*^9, 3.566086983207683*^9, 
  3.5661017348528*^9, 3.566139177864779*^9, 3.6147077907808123`*^9},
 CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"},
 CellLabel->"Out[23]=",ExpressionUUID->"b7c3aa15-7beb-46bd-ad1e-9086c3bfae34"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "Components and Sources", 
   "RG2."},ExpressionUUID->"ee8c6ee2-63b1-40ce-a0a3-a0d34bd8fb34"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "3. Introduction to ",
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and ",
 StyleBox["TurboPlot",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "3.", "Introduction to AnalyzeSystem and TurboPlot", 
   "RG3."},ExpressionUUID->"f36ffa46-c6d2-439a-9436-fd7c63745e3d"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has two parallel methods for doing ray-tracing and rendering of optical \
systems. One method uses the ",
 StyleBox["AnalyzeSystem", "Input"],
 StyleBox[" function ",
  FontFamily->"Times New Roman"],
 "(originally known as ",
 StyleBox["DrawSystem", "Input"],
 "), while the second method uses the ",
 StyleBox["TurboPlot", "Input"],
 " function. Each method offers similar functionally in a parallel way. ",
 StyleBox["AnalyzeSystem", "Input"],
 " is good for generating illustrations for publication and tracing small \
numbers of rays while ",
 StyleBox["TurboPlot", "Input"],
 " is best for working with large numbers of rays.  After making some initial \
comparisons between these two methods, we will next consider the use of ",
 StyleBox["AnalyzeSystem", "Input"],
 ". The application of ",
 StyleBox["TurboPlot", "Input"],
 " will be explored further in Section 15."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Introduction to AnalyzeSystem and TurboPlot", 
   "RG3."},ExpressionUUID->"8c47ee91-acd1-4aff-8716-af3ea27f1b84"],

Cell[TextData[{
 StyleBox["AnalyzeSystem[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " uses ",
 StyleBox["PropagateSystem", "Input"],
 " and ",
 StyleBox["ShowSystem", "Input"],
 " to trace rays through optical components and render the results.\n\n",
 StyleBox["TurboPlot[", "Input"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " works with ",
 StyleBox["TurboTrace", "Input"],
 " to perform accelerated ray-tracing and rendering of a system of light \
sources and optical elements."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Introduction to AnalyzeSystem and TurboPlot", 
   "RG3."},ExpressionUUID->"261340f7-80cc-4036-9f76-943150729697"],

Cell[TextData[{
 "Both ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " call other intermediate functions for their internal operations of \
ray-tracing and graphical rendering. They simply provide a single convenient \
interface for the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " user to conduct the ray-tracing and rendering. Both ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " are used in the same fashion, as each accepts a list of light source and \
component functions for input. One key difference between ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " is that ",
 StyleBox["AnalyzeSystem", "Input"],
 " uses the interpreted language of Mathematica for ray-tracing while ",
 StyleBox["TurboPlot", "Input"],
 " uses a highly-efficient, compiled function, which is more time-consuming \
to create initially but then performs the actual ray trace much faster. As a \
result of this, when only a small number of rays are needed, ",
 StyleBox["AnalyzeSystem", "Input"],
 " can sometimes deliver a result more quickly than ",
 StyleBox["TurboPlot", "Input"],
 ". In addition, ",
 StyleBox["AnalyzeSystem", "Input"],
 " often works better than ",
 StyleBox["TurboPlot", "Input"],
 " for the creation of optical schematics and illustrations for publication, \
since it is tailored for such purposes. However, it is always more \
advantageous to use ",
 StyleBox["TurboPlot", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " when large numbers of rays or iterative processes are required."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Introduction to AnalyzeSystem and TurboPlot", 
   "RG3."},ExpressionUUID->"6225c1c0-5cd6-48f5-850b-53c0f81f7cc6"],

Cell[TextData[{
 "We will now consider ",
 StyleBox["AnalyzeSystem", "Input"],
 " in more detail. When no light sources are included, ",
 StyleBox["AnalyzeSystem", "Input"],
 " simply renders the optical components present. Here we use ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " to render a plano-convex lens."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Introduction to AnalyzeSystem and TurboPlot", 
   "RG3."},ExpressionUUID->"ec9c95de-5825-40d9-a289-df1341e2c666"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[PlanoConvexLens[100, 50, 10], Axes -> True]"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."},
 CellLabel->"In[24]:=",ExpressionUUID->"1726bb25-462a-4549-bd93-8573fad0fabc"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Line3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563007, -24.14814565722671}, {
       10., 6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461096, -12.50000000000001}, {
       10., 21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367527947302*^9, 3.5660869835078993`*^9, 
  3.5661017351266623`*^9, 3.5661391781161957`*^9, 3.614707790928802*^9},
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."},
 CellLabel->
  "During evaluation of \
In[24]:=",ExpressionUUID->"666eb69d-8757-4ccf-9432-9f88066ccff9"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"PlanoConvexLens", "[", 
        RowBox[{"100", ",", "50", ",", "10"}], "]"}], "}"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.563367527947302*^9, 3.5660869835078993`*^9, 
  3.5661017351266623`*^9, 3.5661391781161957`*^9, 3.614707790935546*^9},
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."},
 CellLabel->
  "During evaluation of \
In[24]:=",ExpressionUUID->"f2f0a085-d829-463d-9de9-2ce44ffc6b56"],

Cell[BoxData["\<\"-rendered element-\"\>"], "Output",
 CellChangeTimes->{3.5633675279558687`*^9, 3.566086983525285*^9, 
  3.5661017351453247`*^9, 3.566139178134605*^9, 3.6147077909371758`*^9},
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."},
 CellLabel->"Out[24]=",ExpressionUUID->"29727901-5758-4d7f-9da3-179fef404a45"]
}, Open  ]],

Cell[TextData[{
 "Here, ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 " is created with its first surface at the origin and its second surface \
positioned down the positive ",
 StyleBox["x",
  FontSlant->"Italic"],
 " axis. In general, the ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 " parameter of ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 " may designate a circle, rectangle, or polygon, depending on the number and \
type of elements listed by it. Here we created a circular lens that has a \
diameter of 50 millimeters by using ",
 StyleBox["50",
  FontFamily->"Courier"],
 " in the ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 " parameter. After rendering the plano-convex lens, ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " first echoes back the input expression, and then returns the actual \
information (hidden within the -rendered element- expression). Shortly, in \
Section 7, we will use ",
 StyleBox["AnalyzeSystem", "Input"],
 " for ray-tracing as well as rendering, but first we must learn how to \
position optical components and light sources in three-dimensional space."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Introduction to AnalyzeSystem and TurboPlot", 
   "RG3."},ExpressionUUID->"52d1cb2a-fcf5-454d-aae0-8a2cdb930012"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"6f19e759-f76b-41fc-\
aa73-ce032764c1fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "4. The ",
 StyleBox["Move",
  FontFamily->"Courier"],
 " Function"
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "4.", 
   "RG4."},ExpressionUUID->"e79ee304-6444-418c-a347-afc29e47298d"],

Cell[TextData[{
 "To put an optical element at a location other than ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 0, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0, and ",
 StyleBox["z",
  FontSlant->"Italic"],
 " = 0, you will need to use one of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s positioning directives. The most important positioning directive in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " is the ",
 StyleBox["Move", "Input"],
 " function. You can use ",
 StyleBox["Move", "Input",
  FontFamily->"Courier"],
 " to position both light sources and rays in space. The basic definition for \
",
 StyleBox["Move", "Input",
  FontFamily->"Courier"],
 " is shown below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"9e0ee182-ff3f-43f3-a9dc-be44675bfa86"],

Cell[TextData[{
 StyleBox["Move[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x, y",
  FontSlant->"Italic"],
 StyleBox["}", "Input",
  FontWeight->"Plain"],
 StyleBox[",",
  FontSlant->"Italic"],
 " ",
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " is used to move the relative position and orientation of a set of \
components and rays within a horizontal plane."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"5f9681df-c37c-4521-9524-cfd663be2990"],

Cell[TextData[{
 "Here, the ",
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 " determines the angular orientation of the object set within the horizontal \
plane. You can use the ",
 StyleBox["TwistAngle", "Input",
  FontFamily->"Courier"],
 StyleBox[" ", "Input"],
 StyleBox["->", "Input",
  FontFamily->"Courier"],
 " ",
 StyleBox["angle",
  FontSlant->"Italic"],
 " option to specify a rotation angle around the axis of orientation. Next we \
will use ",
 StyleBox["Move", "Input",
  FontFamily->"Courier"],
 " together with ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " to draw two lenses spaced apart from each other. Place the first one at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 0, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0, with no rotation, and a second one at ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 100, ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 10, with a 45-degree rotation."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"7e8db4f2-fbe3-4f2b-9a30-04dacb450d99"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[{\n\tPlanoConvexLens[100, 50, 10],\n\tMove[PlanoConvexLens[100, 50, 10], \
{100, 10}, 45]}, Axes -> True]"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Move", "RG4."},
 CellLabel->"In[25]:=",ExpressionUUID->"6b5272ea-3406-4e38-bc14-4af8d413c5fe"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{6.421974580955592, -25., 0.}, {10., -25., 
      6.123233995736766*^-15}, {10., -16.66666666666667, 
      5.102694996447306*^-15}, {2.7504488342847893`, -16.666666666666668`, 
      0.}, {6.421974580955592, -25., 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, -16.666666666666668`, 0.}, {
      10., -16.66666666666667, 5.102694996447306*^-15}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      0.6737579958920605, -8.333333333333336, 0.}, {
      2.7504488342847893`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{0.6737579958920605, -8.333333333333336, 0.}, {
      10., -8.333333333333336, 4.0821559971578446`*^-15}, {
      10., -7.105427357601002*^-15, 3.061616997868384*^-15}, {0., 0., 0.}, {
      0.6737579958920605, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {10., 0., 3.061616997868383*^-15}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {0.6737579958920605, 
      8.333333333333329, 0.}, {0., 0., 0.}}], 
     Polygon3DBox[{{0.6737579958920605, 8.333333333333329, 0.}, {10., 
      8.333333333333332, 2.0410779985789223`*^-15}, {10., 16.666666666666664`,
       1.0205389992894613`*^-15}, {2.7504488342847893`, 16.666666666666664`, 
      0.}, {0.6737579958920605, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{2.7504488342847893`, 16.666666666666664`, 0.}, {10., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {10., 
      24.999999999999996`, 5.098616525425841*^-31}, {6.421974580955592, 
      24.999999999999993`, 0.}, {2.7504488342847893`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMYWB5ggIIJM1oCXzOwOaxeBQIG
cHGGMzve5vQ/tV8DFldAiKOAD3vQ1a+AqHeACTdAzYeIG8DFYe759x8ELBwY
UIAKzJ0Y4qvRzIGJr0GzF9WcDzbo4iuw+gsmboAhDnUnXBxXeAIAMVpU9w==

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{6.421974580955592, 0., -25.}, {10., 
        3.061616997868383*^-15, -25.}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {6.421974580955592, 
        0., -25.}}], 
       Polygon3DBox[{{2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}, {10., 
        2.551347498223653*^-15, -16.66666666666667}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {2.7504488342847893`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}, {10., 
        2.0410779985789223`*^-15, -8.333333333333336}, {10., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {0.6737579958920605, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {10., 
        1.5308084989341915`*^-15, 0.}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {0., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}, {10., 1.0205389992894611`*^-15, 
        8.333333333333332}, {10., 5.102694996447307*^-16, 
        16.666666666666664`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {0.6737579958920605, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {10., 5.102694996447308*^-16, 
        16.666666666666664`}, {10., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {6.421974580955592, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {2.7504488342847893`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA44dVhKaoOkAwMKsDwwYUZL4GsGNrj46lUgYHCA
4cyOtzn9T+1h4mvA4goHGLCCD3vQ1a+AqHdoQDMfIm7ggO6ef/9BwALKV0F3
J4Y41J0Y4lB34jDngw26+AoUf6GLG2CIQ915AFd4AgBzJFT3
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{6.421974580955592, 25., 0.}, {10., 25., 0.}, {10., 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 
       24.148145657226706`, 6.4704761275630185`}, {6.421974580955592, 25., 
       0.}}], Line3DBox[{{6.421974580955592, 24.148145657226706`, 
       6.4704761275630185`}, {10., 24.148145657226706`, 
       6.4704761275630185`}, {10., 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461097, 
       12.499999999999998`}, {10., 21.65063509461097, 12.499999999999998`}, {
       10., 17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}, {6.421974580955592, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{6.421974580955592, 17.67766952966369, 
       17.677669529663685`}, {10., 17.67766952966369, 17.677669529663685`}, {
       10., 12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       12.500000000000004`, 21.650635094610966`}, {6.421974580955592, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{6.421974580955592, 12.500000000000004`, 
       21.650635094610966`}, {10., 12.500000000000004`, 
       21.650635094610966`}, {10., 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 6.470476127563024, 24.148145657226706`}, {
       6.421974580955592, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563024, 
       24.148145657226706`}, {10., 6.470476127563024, 24.148145657226706`}, {
       10., 7.0819236220599744`*^-15, 25.}, {6.421974580955592, 
       7.0819236220599744`*^-15, 25.}, {6.421974580955592, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, 1.5308084989341915`*^-15, 25.}, {10., 
       1.5308084989341915`*^-15, 25.}, {10., -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {6.421974580955592, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{6.421974580955592, -6.470476127563016, 
       24.148145657226706`}, {10., -6.470476127563016, 24.148145657226706`}, {
       10., -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}, {
       6.421974580955592, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{6.421974580955592, -12.499999999999995`, 
       21.65063509461097}, {10., -12.499999999999995`, 21.65063509461097}, {
       10., -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}, {
       6.421974580955592, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{6.421974580955592, -17.677669529663685`, 
       17.67766952966369}, {10., -17.677669529663685`, 17.67766952966369}, {
       10., -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -21.65063509461097, 12.499999999999998`}, {
       6.421974580955592, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{6.421974580955599, -21.650635094610962`, 
       12.500000000000009`}, {10., -21.650635094610962`, 
       12.500000000000009`}, {10., -24.148145657226706`, 6.470476127563026}, {
       6.421974580955592, -24.148145657226706`, 6.470476127563026}, {
       6.421974580955599, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{6.421974580955592, -24.148145657226706`, 
       6.470476127563026}, {10., -24.148145657226706`, 6.470476127563026}, {
       10., -25., 3.061616997868383*^-15}, {6.421974580955592, -25., 
       3.061616997868383*^-15}, {6.421974580955592, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{6.421974580955592, -25., 3.061616997868383*^-15}, {
       10., -25., 3.061616997868383*^-15}, {
       10., -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -24.148145657226706`, -6.47047612756302}, {
       6.421974580955592, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       6.421974580955592, -24.14814565722671, -6.470476127563009}, {
       10., -24.14814565722671, -6.470476127563009}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       6.421974580955592, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       6.421974580955592, -21.65063509461097, -12.499999999999993`}, {
       10., -21.65063509461097, -12.499999999999993`}, {
       10., -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -17.677669529663692`, -17.677669529663685`}, {
       6.421974580955592, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}, {
       10., -17.677669529663696`, -17.677669529663678`}, {
       10., -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       6.421974580955592, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       6.421974580955592, -12.50000000000001, -21.65063509461096}, {
       10., -12.50000000000001, -21.65063509461096}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       6.421974580955592, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       6.421974580955592, -6.470476127563038, -24.148145657226703`}, {
       10., -6.470476127563038, -24.148145657226703`}, {
       10., -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -2.6796885989305705`*^-14, -25.}, {
       6.421974580955592, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{6.421974580955592, -4.592425496802574*^-15, -25.}, {
       10., -4.592425496802574*^-15, -25.}, {10., 
       6.470476127563007, -24.14814565722671}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}, {
       6.421974580955592, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{6.421974580955592, 6.470476127563007, -24.14814565722671}, {
       10., 6.470476127563007, -24.14814565722671}, {10., 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {6.421974580955592, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}, {10., 
       12.499999999999984`, -21.650635094610976`}, {10., 
       17.67766952966367, -17.67766952966371}, {6.421974580955599, 
       17.67766952966367, -17.67766952966371}, {6.421974580955592, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}, {10., 
       17.677669529663685`, -17.677669529663692`}, {10., 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}, {6.421974580955592, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{6.421974580955592, 21.65063509461096, -12.50000000000001}, {
       10., 21.65063509461096, -12.50000000000001}, {10., 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {6.421974580955592, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{6.421974580955592, 
       24.148145657226703`, -6.470476127563039}, {10., 
       24.148145657226703`, -6.470476127563039}, {10., 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       25., -2.8327694488239898`*^-14}, {6.421974580955592, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{122.21869130446503`, -3.1366477548623486`, 0.}, {
      124.74873734152916`, -0.6066017177982097, 6.123233995736766*^-15}, {
      118.85618083164127`, 5.285954792089681, 5.102694996447306*^-15}, {
      113.7299740418052, 0.15974800225361463`, 0.}, {
      122.21869130446503`, -3.1366477548623486`, 0.}}], 
     Polygon3DBox[{{113.7299740418052, 0.15974800225361463`, 0.}, {
      118.85618083164127`, 5.285954792089681, 5.102694996447306*^-15}, {
      112.96362432175337`, 11.17851130197758, 4.0821559971578446`*^-15}, {
      106.36897535766184`, 4.583862337886039, 0.}, {113.7299740418052, 
      0.15974800225361463`, 0.}}], 
     Polygon3DBox[{{106.36897535766184`, 4.583862337886039, 0.}, {
      112.96362432175337`, 11.17851130197758, 4.0821559971578446`*^-15}, {
      107.07106781186548`, 17.071067811865472`, 3.061616997868384*^-15}, {
      100., 10., 0.}, {106.36897535766184`, 4.583862337886039, 0.}}], 
     Polygon3DBox[{{100., 10., 0.}, {107.07106781186548`, 17.071067811865476`,
       3.061616997868383*^-15}, {101.17851130197758`, 22.96362432175337, 
      2.0410779985789223`*^-15}, {94.58386233788605, 16.368975357661824`, 
      0.}, {100., 10., 0.}}], 
     Polygon3DBox[{{94.58386233788605, 16.368975357661824`, 0.}, {
      101.17851130197758`, 22.96362432175337, 2.0410779985789223`*^-15}, {
      95.28595479208968, 28.856180831641264`, 1.0205389992894613`*^-15}, {
      90.15974800225362, 23.7299740418052, 0.}, {94.58386233788605, 
      16.368975357661824`, 0.}}], 
     Polygon3DBox[{{90.15974800225362, 23.7299740418052, 0.}, {
      95.28595479208968, 28.856180831641264`, 1.0205389992894615`*^-15}, {
      89.39339828220179, 34.748737341529164`, 5.098616525425841*^-31}, {
      86.86335224513765, 32.218691304465025`, 0.}, {90.15974800225362, 
      23.7299740418052, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZWu8D5vzfOQWKp4fFb4pwHGKDgnhz30+15MQ4M
rxfHzS86Yg8TZ+i56DV3epTDjggrpgehQg4MKCASyleBi/csVWaIWxru8Eff
Tbs0zgAu/i1wvb9lV5hDSbXOlPu7zOHi14uOaTpuD3VI81kg/E/aAS7+T+xv
vm5kmMOWKbwLrsU7wsUtuEJEfS+FOzTE7F+ld9sGLl70d9WuHO9Ihxn9yaIb
vpnBxdd8YEzoORLlsPEQe4OhkCFc/NnjCNY1tjEOk16HX02NVoOLy19fv+r0
tliHrsUOoRdVROHiUafYAl7rxzscaChh9Mh8vB8mjis8AbaKZEY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{104.54102177480134`, 14.541021774801337`, -25.}, {
        107.07106781186548`, 17.07106781186548, -25.}, {107.07106781186548`, 
        17.07106781186548, -16.66666666666667}, {101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}, {104.54102177480134`, 
        14.541021774801337`, -25.}}], 
       Polygon3DBox[{{101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}, {107.07106781186548`, 
        17.07106781186548, -16.66666666666667}, {107.07106781186548`, 
        17.071067811865476`, -8.333333333333336}, {100.47641884777394`, 
        10.476418847773935`, -8.333333333333336}, {101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}}], 
       Polygon3DBox[{{100.47641884777394`, 
        10.476418847773935`, -8.333333333333336}, {107.07106781186548`, 
        17.071067811865476`, -8.333333333333336}, {107.07106781186548`, 
        17.071067811865476`, -7.105427357601002*^-15}, {100., 10., 0.}, {
        100.47641884777394`, 10.476418847773935`, -8.333333333333336}}], 
       Polygon3DBox[{{100., 10., 0.}, {107.07106781186548`, 
        17.071067811865476`, 0.}, {107.07106781186548`, 17.071067811865476`, 
        8.333333333333332}, {100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}, {100., 10., 0.}}], 
       Polygon3DBox[{{100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}, {107.07106781186548`, 17.071067811865476`, 
        8.333333333333332}, {107.07106781186548`, 17.071067811865476`, 
        16.666666666666664`}, {101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}, {100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}}], 
       Polygon3DBox[{{101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}, {107.07106781186548`, 17.071067811865476`, 
        16.666666666666664`}, {107.07106781186548`, 17.071067811865476`, 
        24.999999999999996`}, {104.54102177480134`, 14.541021774801337`, 
        24.999999999999993`}, {101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG71OS25QCnKQSMl6hyDqK4DAxhYHsiyiJ1VURPp
4HP45aUjj9UdVq8CAYMDx2ZULa2Vi3TQOXZF++1nFYc1YHGFAxB9kVD9KlD6
wx509Ssg6h3QzYeIGzigu+fffxCwcFjzgTGh50iUw4ZD7A2GQoYwd2KIQ92J
IQ51Jw5zPtigi0PdeQC7uAGGONSdB3CFJwBC85gn
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{86.86335224513765, 32.218691304465025`, 0.}, {
       89.39339828220179, 34.748737341529164`, 0.}, {89.99575026456, 
       34.14638535917096, 6.4704761275630185`}, {87.46570422749586, 
       31.616339322106818`, 6.4704761275630185`}, {86.86335224513765, 
       32.218691304465025`, 0.}}], 
      Line3DBox[{{87.46570422749586, 31.616339322106818`, 
       6.4704761275630185`}, {89.99575026456, 34.14638535917096, 
       6.4704761275630185`}, {91.76175691947061, 32.38037870426034, 
       12.499999999999998`}, {89.23171088240647, 29.8503326671962, 
       12.499999999999998`}, {87.46570422749586, 31.616339322106818`, 
       6.4704761275630185`}}], 
      Line3DBox[{{89.23171088240647, 29.8503326671962, 12.499999999999998`}, {
       91.76175691947061, 32.38037870426034, 12.499999999999998`}, {
       94.57106781186548, 29.571067811865476`, 17.677669529663685`}, {
       92.04102177480134, 27.041021774801337`, 17.677669529663685`}, {
       89.23171088240647, 29.8503326671962, 12.499999999999998`}}], 
      Line3DBox[{{92.04102177480134, 27.041021774801337`, 
       17.677669529663685`}, {94.57106781186548, 29.571067811865476`, 
       17.677669529663685`}, {98.23223304703363, 25.90990257669732, 
       21.650635094610966`}, {95.70218700996949, 23.37985653963318, 
       21.650635094610966`}, {92.04102177480134, 27.041021774801337`, 
       17.677669529663685`}}], 
      Line3DBox[{{95.70218700996949, 23.37985653963318, 
       21.650635094610966`}, {98.23223304703363, 25.90990257669732, 
       21.650635094610966`}, {102.49575026455999`, 21.646385359170964`, 
       24.148145657226706`}, {99.96570422749586, 19.116339322106825`, 
       24.148145657226706`}, {95.70218700996949, 23.37985653963318, 
       21.650635094610966`}}], 
      Line3DBox[{{99.96570422749586, 19.116339322106825`, 
       24.148145657226706`}, {102.49575026455999`, 21.646385359170964`, 
       24.148145657226706`}, {107.07106781186548`, 17.07106781186548, 25.}, {
       104.54102177480134`, 14.541021774801344`, 25.}, {99.96570422749586, 
       19.116339322106825`, 24.148145657226706`}}], 
      Line3DBox[{{104.54102177480134`, 14.541021774801337`, 25.}, {
       107.07106781186548`, 17.071067811865476`, 25.}, {111.64638535917095`, 
       12.495750264559994`, 24.148145657226706`}, {109.11633932210681`, 
       9.965704227495856, 24.148145657226706`}, {104.54102177480134`, 
       14.541021774801337`, 25.}}], 
      Line3DBox[{{109.11633932210681`, 9.965704227495856, 
       24.148145657226706`}, {111.64638535917095`, 12.495750264559994`, 
       24.148145657226706`}, {115.90990257669732`, 8.232233047033636, 
       21.65063509461097}, {113.37985653963317`, 5.702187009969499, 
       21.65063509461097}, {109.11633932210681`, 9.965704227495856, 
       24.148145657226706`}}], 
      Line3DBox[{{113.37985653963317`, 5.702187009969499, 
       21.65063509461097}, {115.90990257669732`, 8.232233047033636, 
       21.65063509461097}, {119.57106781186548`, 4.571067811865479, 
       17.67766952966369}, {117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}, {113.37985653963317`, 5.702187009969499, 
       21.65063509461097}}], 
      Line3DBox[{{117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}, {119.57106781186548`, 4.571067811865479, 
       17.67766952966369}, {122.38037870426034`, 1.7617569194706117`, 
       12.499999999999998`}, {119.85033266719621`, -0.7682891175935254, 
       12.499999999999998`}, {117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}}], 
      Line3DBox[{{119.8503326671962, -0.7682891175935147, 
       12.500000000000009`}, {122.38037870426034`, 1.761756919470617, 
       12.500000000000009`}, {124.14638535917095`, -0.004249735440005509, 
       6.470476127563026}, {121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}, {119.8503326671962, -0.7682891175935147, 
       12.500000000000009`}}], 
      Line3DBox[{{121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}, {124.14638535917095`, -0.004249735440005509, 
       6.470476127563026}, {124.74873734152916`, -0.6066017177982097, 
       3.061616997868383*^-15}, {122.21869130446503`, -3.1366477548623486`, 
       3.061616997868383*^-15}, {121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}}], 
      Line3DBox[{{122.21869130446503`, -3.1366477548623486`, 
       3.061616997868383*^-15}, {124.74873734152916`, -0.6066017177982097, 
       3.061616997868383*^-15}, {
       124.14638535917095`, -0.004249735440005509, -6.47047612756302}, {
       121.61633932210681`, -2.5342957725041444`, -6.47047612756302}, {
       122.21869130446503`, -3.1366477548623486`, 3.061616997868383*^-15}}], 
      Line3DBox[{{
       121.61633932210681`, -2.534295772504148, -6.470476127563009}, {
       124.14638535917096`, -0.0042497354400090614`, -6.470476127563009}, {
       122.38037870426034`, 1.7617569194706117`, -12.499999999999993`}, {
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}, {
       121.61633932210681`, -2.534295772504148, -6.470476127563009}}], 
      Line3DBox[{{
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}, {
       122.38037870426034`, 1.7617569194706117`, -12.499999999999993`}, {
       119.57106781186548`, 4.571067811865474, -17.677669529663685`}, {
       117.04102177480134`, 2.0410217748013366`, -17.677669529663685`}, {
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}}], 
      Line3DBox[{{117.04102177480134`, 
       2.0410217748013366`, -17.677669529663678`}, {119.57106781186548`, 
       4.571067811865472, -17.677669529663678`}, {115.90990257669733`, 
       8.232233047033624, -21.65063509461096}, {113.3798565396332, 
       5.702187009969485, -21.65063509461096}, {117.04102177480134`, 
       2.0410217748013366`, -17.677669529663678`}}], 
      Line3DBox[{{113.3798565396332, 5.702187009969485, -21.65063509461096}, {
       115.90990257669733`, 8.232233047033624, -21.65063509461096}, {
       111.64638535917098`, 12.49575026455998, -24.148145657226703`}, {
       109.11633932210684`, 9.965704227495841, -24.148145657226703`}, {
       113.3798565396332, 5.702187009969485, -21.65063509461096}}], 
      Line3DBox[{{109.11633932210684`, 
       9.965704227495841, -24.148145657226703`}, {111.64638535917098`, 
       12.49575026455998, -24.148145657226703`}, {107.07106781186549`, 
       17.071067811865458`, -25.}, {104.54102177480137`, 
       14.541021774801315`, -25.}, {109.11633932210684`, 
       9.965704227495841, -24.148145657226703`}}], 
      Line3DBox[{{104.54102177480134`, 14.541021774801337`, -25.}, {
       107.07106781186548`, 17.071067811865472`, -25.}, {102.49575026456, 
       21.64638535917095, -24.14814565722671}, {99.96570422749586, 
       19.11633932210681, -24.14814565722671}, {104.54102177480134`, 
       14.541021774801337`, -25.}}], 
      Line3DBox[{{99.96570422749586, 19.11633932210681, -24.14814565722671}, {
       102.49575026456, 21.64638535917095, -24.14814565722671}, {
       98.23223304703365, 25.909902576697306`, -21.650635094610976`}, {
       95.7021870099695, 23.379856539633167`, -21.650635094610976`}, {
       99.96570422749586, 19.11633932210681, -24.14814565722671}}], 
      Line3DBox[{{95.7021870099695, 
       23.379856539633167`, -21.650635094610976`}, {98.23223304703365, 
       25.909902576697306`, -21.650635094610976`}, {94.57106781186549, 
       29.57106781186546, -17.67766952966371}, {92.04102177480135, 
       27.04102177480133, -17.67766952966371}, {95.7021870099695, 
       23.379856539633167`, -21.650635094610976`}}], 
      Line3DBox[{{92.04102177480134, 
       27.041021774801337`, -17.677669529663692`}, {94.57106781186548, 
       29.571067811865472`, -17.677669529663692`}, {91.76175691947061, 
       32.38037870426033, -12.50000000000001}, {89.23171088240647, 
       29.85033266719619, -12.50000000000001}, {92.04102177480134, 
       27.041021774801337`, -17.677669529663692`}}], 
      Line3DBox[{{89.23171088240647, 29.85033266719619, -12.50000000000001}, {
       91.76175691947061, 32.38037870426033, -12.50000000000001}, {
       89.99575026456, 34.14638535917095, -6.470476127563039}, {
       87.46570422749586, 31.61633932210681, -6.470476127563039}, {
       89.23171088240647, 29.85033266719619, -12.50000000000001}}], 
      Line3DBox[{{87.46570422749586, 31.61633932210681, -6.470476127563039}, {
       89.99575026456, 34.14638535917095, -6.470476127563039}, {
       89.39339828220179, 34.748737341529164`, -2.8327694488239898`*^-14}, {
       86.86335224513765, 32.218691304465025`, -2.8327694488239898`*^-14}, {
       87.46570422749586, 31.61633932210681, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56336752844967*^9, 3.566086983936491*^9, 
  3.566101735809802*^9, 3.566139178690258*^9, 3.6147077912577553`*^9},
 CellTags->{"Move", "RG4."},
 CellLabel->
  "During evaluation of \
In[25]:=",ExpressionUUID->"f2905d4c-0a2b-409a-a72a-a56e8893f778"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"PlanoConvexLens", "[", 
           RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"100.`", ",", "10.`"}], "}"}], ",", "45.`"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.56336752844967*^9, 3.566086983936491*^9, 
  3.566101735809802*^9, 3.566139178690258*^9, 3.614707791265469*^9},
 CellTags->{"Move", "RG4."},
 CellLabel->
  "During evaluation of \
In[25]:=",ExpressionUUID->"9a43684d-2201-4b5a-9a78-d826030078b5"],

Cell[BoxData["\<\"-rendered system without rays-\"\>"], "Output",
 CellChangeTimes->{3.563367528459015*^9, 3.566086983955832*^9, 
  3.566101735825879*^9, 3.5661391787071657`*^9, 3.614707791267146*^9},
 CellTags->{"Move", "RG4."},
 CellLabel->"Out[25]=",ExpressionUUID->"b55e7357-d863-4697-8813-7f7cc22a5135"]
}, Open  ]],

Cell[TextData[{
 "Note that, again, the text output returned to the screen mimics the \
original input expressions, when, in fact, a great quantity of information is \
hidden behind the \"-rendered system without rays-\" statement. Although only \
a single format has been shown previously for ",
 StyleBox["Move", "Input"],
 ", there are actually a variety of input formats used with ",
 StyleBox["Move", "Input"],
 ". These are shown below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"3015ad87-e28b-447b-9c45-8090fc0f0d9a"],

Cell[TextData[{
 StyleBox["Move[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x, y",
  FontSlant->"Italic"],
 StyleBox["}", "Input",
  FontWeight->"Plain"],
 StyleBox[",",
  FontSlant->"Italic"],
 " ",
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["x,",
  FontSlant->"Italic"],
 " ",
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x, y",
  FontSlant->"Italic"],
 StyleBox["}", "Input",
  FontWeight->"Plain"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x, y, z",
  FontSlant->"Italic"],
 StyleBox["}", "Input",
  FontWeight->"Plain"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[", y, z",
  FontSlant->"Italic"],
 StyleBox["}, ", "Input",
  FontWeight->"Plain"],
 StyleBox["axisvector",
  FontSlant->"Italic"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[", y, z",
  FontSlant->"Italic"],
 StyleBox["}, ", "Input",
  FontWeight->"Plain"],
 StyleBox["axisvector",
  FontSlant->"Italic"],
 StyleBox[", ", "Input",
  FontWeight->"Plain"],
 StyleBox["twistangle",
  FontSlant->"Italic"],
 StyleBox["]\nMove[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[", y, z",
  FontSlant->"Italic"],
 StyleBox["}, ", "Input",
  FontWeight->"Plain"],
 StyleBox["rotationmatrix",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"]
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"2eda5272-ff28-49d0-af7c-f78001c32ec2"],

Cell[TextData[{
 "Common input formats for ",
 StyleBox["Move", "Input",
  FontSlant->"Plain"],
 ". Although not shown, these formats all accept options."
}], "Commentary",
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"7709d5f4-20e7-46c4-a5c1-f6761964cc32"],

Cell[TextData[{
 "Including the ",
 StyleBox["Move", "Input"],
 " function, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has eight positioning directives. At any time that you wish while working \
with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", you can access a listing of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s positioning functions with the ",
 StyleBox["MoveFunctions", "Input"],
 " command:"
}], "Text",
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"ba405f05-8953-47a7-97ad-0df30ed40a7b"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["MoveFunctions", "Input"]], "Input",
 CellTags->{"Move", "RG4."},
 CellLabel->"In[26]:=",ExpressionUUID->"90ddc9bd-c7cd-4c1e-af5a-3b8f958d6218"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     ButtonBox[
      StyleBox["\<\"Move\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Move", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MoveDirected\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"MoveDirected", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MoveReflected\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{
        "celltag", {"MoveReflected", "Optica`Optica`"}}, LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Rotate\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Rotate", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]},
    {
     ButtonBox[
      StyleBox["\<\"MoveAligned\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"MoveAligned", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MoveLinear\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"MoveLinear", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"MoveSurface\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"MoveSurface", "Optica`Optica`"}},
         LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"], 
     ButtonBox[
      StyleBox["\<\"Translate\"\>",
       StripOnInput->False,
       FontVariations->{"Underline"->True},
       FontColor->RGBColor[0, 0, 1]],
      Appearance->{Automatic, None},
      ButtonFunction:>
       Internal`PutInformation[{"celltag", {"Translate", "Optica`Optica`"}}, 
        LongForm -> False],
      Evaluator->Automatic,
      Method->"Preemptive"]}
   },
   AutoDelete->False,
   GridBoxBackground->{"Columns" -> {{
        GrayLevel[0.930022]}}},
   GridBoxDividers->{
    "Columns" -> {True, {False}, True}, "ColumnsIndexed" -> {}, 
     "Rows" -> {True, {False}, True}, "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{All}}, "ColumnsIndexed" -> {}, "Rows" -> {1, 1, 1, {1.05}},
      "RowsIndexed" -> {}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.563367528515088*^9, 3.5660869841986523`*^9, 
  3.56610173602113*^9, 3.5661391789943533`*^9, 3.6147077913923407`*^9},
 CellTags->{"Move", "RG4."},
 CellLabel->"Out[26]=",ExpressionUUID->"83fbebe7-5ac1-4249-96b0-6497e0927650"]
}, Open  ]],

Cell[TextData[{
 "In Mathmatica, ",
 StyleBox["MoveFunctions", "Input",
  FontSlant->"Plain"],
 " gives you hyperlinks to ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s most important positioning functions. Clicking on any name will give you \
a description of its use."
}], "Commentary",
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"f7bcd3be-e8bb-4554-9d2c-ae586a1da6eb"],

Cell[TextData[{
 "You can learn more about how to use ",
 StyleBox["Move", "Input"],
 " and the other directives in ",
 ButtonBox["Chapter 2",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"Move Discussion"],
 ", the Placement Directives chapter, of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " discussion."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Move", "RG4."},ExpressionUUID->"c4e24659-88c0-410a-a21f-b62e1ff992ad"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"57d0a25f-679e-425d-\
8d87-f73ab60c1c03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "5. Using ",
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " for Ray Tracing"
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", 
   "RG5.1"},ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6"],

Cell[CellGroupData[{

Cell["Tracing a single ray", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", 
   "RG5.1"},ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a"],

Cell[TextData[{
 "We are almost ready to use ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " for ray-tracing. First, however, we need to consider a boundary to contain \
the rays. Otherwise, the traced rays will terminate on the last surface of \
the last optical component in the system. The easiest way to define a \
boundary is with the ",
 StyleBox["Boundary", "Input",
  FontFamily->"Courier"],
 StyleBox[" function. Before continuing with the ray trace, lets first \
examine the ",
  FontFamily->"Times New Roman"],
 StyleBox["Boundary", "Input",
  FontFamily->"Courier"],
 StyleBox[" function in more detail.",
  FontFamily->"Times New Roman"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", 
   "RG5.1"},ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24"],

Cell[TextData[{
 StyleBox["Boundary[", "Input",
  FontFamily->"Courier"],
 StyleBox["boundaryparameters",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " denotes a rectangular box that absorbs rays intercepted by its walls."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", 
   "RG5.1"},ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2"],

Cell[TextData[{
 "There are three methods for specifying ",
 StyleBox["boundaryparameters",
  FontSlant->"Italic"],
 ": ",
 StyleBox["Boundary[", "Input",
  FontFamily->"Courier"],
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x1",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y1",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z1",
  FontSlant->"Italic"],
 StyleBox["}",
  FontFamily->"Courier"],
 StyleBox[", ",
  FontFamily->"Times New Roman"],
 StyleBox["{",
  FontFamily->"Courier"],
 StyleBox["x2",
  FontSlant->"Italic"],
 ", ",
 StyleBox["y2",
  FontSlant->"Italic"],
 ", ",
 StyleBox["z2",
  FontSlant->"Italic"],
 StyleBox["}",
  FontFamily->"Courier"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " uses the coordinates of top and bottom opposite corners of a rectangular \
box",
 StyleBox[",",
  FontSlant->"Italic"],
 " ",
 StyleBox["Boundary[", "Input",
  FontFamily->"Courier"],
 StyleBox["side",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " assumes a cube boundary, and ",
 StyleBox["Boundary", "Input",
  FontFamily->"Courier"],
 StyleBox["[", "Input",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["aside",
  FontSlant->"Italic"],
 ", ",
 StyleBox["bside",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " assumes a three-dimensional box having a length specified by ",
 StyleBox["aside",
  FontSlant->"Italic"],
 ", a width specified by ",
 StyleBox["bside",
  FontSlant->"Italic"],
 ", and a height specified by ",
 StyleBox["bside",
  FontSlant->"Italic"],
 ". ",
 "Optical",
 " systems propagating rays usually have at least one boundary component \
listed at the end. In this example, we will use ",
 StyleBox["Boundary[200]", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", 
   "RG5.1"},ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96"],

Cell[TextData[{
 "We can now use ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " for ray tracing. For this, we will trace a single ray through a lens using \
the ",
 StyleBox["SingleRay", "Input",
  FontFamily->"Courier"],
 ", ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["Boundary", "Input"],
 " functions. This time we will store the ray-trace result in a variable \
called ",
 StyleBox["trace", "Input"],
 ". This will allow us to examine the traced information later on with other \
functions."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", 
   "RG5.1"},ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["trace = ",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[{\n\tSingleRay[],\n\tMove[PlanoConvexLens[100, 50, 10], {100, 10}, 45],\n\t\
Boundary[200, 70]}]"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"},
 CellLabel->"In[27]:=",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{122.21869130446503`, -3.1366477548623486`, 0.}, {
      124.74873734152916`, -0.6066017177982097, 6.123233995736766*^-15}, {
      118.85618083164127`, 5.285954792089681, 5.102694996447306*^-15}, {
      113.7299740418052, 0.15974800225361463`, 0.}, {
      122.21869130446503`, -3.1366477548623486`, 0.}}], 
     Polygon3DBox[{{113.7299740418052, 0.15974800225361463`, 0.}, {
      118.85618083164127`, 5.285954792089681, 5.102694996447306*^-15}, {
      112.96362432175337`, 11.17851130197758, 4.0821559971578446`*^-15}, {
      106.36897535766184`, 4.583862337886039, 0.}, {113.7299740418052, 
      0.15974800225361463`, 0.}}], 
     Polygon3DBox[{{106.36897535766184`, 4.583862337886039, 0.}, {
      112.96362432175337`, 11.17851130197758, 4.0821559971578446`*^-15}, {
      107.07106781186548`, 17.071067811865472`, 3.061616997868384*^-15}, {
      100., 10., 0.}, {106.36897535766184`, 4.583862337886039, 0.}}], 
     Polygon3DBox[{{100., 10., 0.}, {107.07106781186548`, 17.071067811865476`,
       3.061616997868383*^-15}, {101.17851130197758`, 22.96362432175337, 
      2.0410779985789223`*^-15}, {94.58386233788605, 16.368975357661824`, 
      0.}, {100., 10., 0.}}], 
     Polygon3DBox[{{94.58386233788605, 16.368975357661824`, 0.}, {
      101.17851130197758`, 22.96362432175337, 2.0410779985789223`*^-15}, {
      95.28595479208968, 28.856180831641264`, 1.0205389992894613`*^-15}, {
      90.15974800225362, 23.7299740418052, 0.}, {94.58386233788605, 
      16.368975357661824`, 0.}}], 
     Polygon3DBox[{{90.15974800225362, 23.7299740418052, 0.}, {
      95.28595479208968, 28.856180831641264`, 1.0205389992894615`*^-15}, {
      89.39339828220179, 34.748737341529164`, 5.098616525425841*^-31}, {
      86.86335224513765, 32.218691304465025`, 0.}, {90.15974800225362, 
      23.7299740418052, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZWu8D5vzfOQWKp4fFb4pwHGKDgnhz30+15MQ4M
rxfHzS86Yg8TZ+i56DV3epTDjggrpgehQg4MKCASyleBi/csVWaIWxru8Eff
Tbs0zgAu/i1wvb9lV5hDSbXOlPu7zOHi14uOaTpuD3VI81kg/E/aAS7+T+xv
vm5kmMOWKbwLrsU7wsUtuEJEfS+FOzTE7F+ld9sGLl70d9WuHO9Ihxn9yaIb
vpnBxdd8YEzoORLlsPEQe4OhkCFc/NnjCNY1tjEOk16HX02NVoOLy19fv+r0
tliHrsUOoRdVROHiUafYAl7rxzscaChh9Mh8vB8mjis8AbaKZEY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{104.54102177480134`, 14.541021774801337`, -25.}, {
        107.07106781186548`, 17.07106781186548, -25.}, {107.07106781186548`, 
        17.07106781186548, -16.66666666666667}, {101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}, {104.54102177480134`, 
        14.541021774801337`, -25.}}], 
       Polygon3DBox[{{101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}, {107.07106781186548`, 
        17.07106781186548, -16.66666666666667}, {107.07106781186548`, 
        17.071067811865476`, -8.333333333333336}, {100.47641884777394`, 
        10.476418847773935`, -8.333333333333336}, {101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}}], 
       Polygon3DBox[{{100.47641884777394`, 
        10.476418847773935`, -8.333333333333336}, {107.07106781186548`, 
        17.071067811865476`, -8.333333333333336}, {107.07106781186548`, 
        17.071067811865476`, -7.105427357601002*^-15}, {100., 10., 0.}, {
        100.47641884777394`, 10.476418847773935`, -8.333333333333336}}], 
       Polygon3DBox[{{100., 10., 0.}, {107.07106781186548`, 
        17.071067811865476`, 0.}, {107.07106781186548`, 17.071067811865476`, 
        8.333333333333332}, {100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}, {100., 10., 0.}}], 
       Polygon3DBox[{{100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}, {107.07106781186548`, 17.071067811865476`, 
        8.333333333333332}, {107.07106781186548`, 17.071067811865476`, 
        16.666666666666664`}, {101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}, {100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}}], 
       Polygon3DBox[{{101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}, {107.07106781186548`, 17.071067811865476`, 
        16.666666666666664`}, {107.07106781186548`, 17.071067811865476`, 
        24.999999999999996`}, {104.54102177480134`, 14.541021774801337`, 
        24.999999999999993`}, {101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG71OS25QCnKQSMl6hyDqK4DAxhYHsiyiJ1VURPp
4HP45aUjj9UdVq8CAYMDx2ZULa2Vi3TQOXZF++1nFYc1YHGFAxB9kVD9KlD6
wx509Ssg6h3QzYeIGzigu+fffxCwcFjzgTGh50iUw4ZD7A2GQoYwd2KIQ92J
IQ51Jw5zPtigi0PdeQC7uAGGONSdB3CFJwBC85gn
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{86.86335224513765, 32.218691304465025`, 0.}, {
       89.39339828220179, 34.748737341529164`, 0.}, {89.99575026456, 
       34.14638535917096, 6.4704761275630185`}, {87.46570422749586, 
       31.616339322106818`, 6.4704761275630185`}, {86.86335224513765, 
       32.218691304465025`, 0.}}], 
      Line3DBox[{{87.46570422749586, 31.616339322106818`, 
       6.4704761275630185`}, {89.99575026456, 34.14638535917096, 
       6.4704761275630185`}, {91.76175691947061, 32.38037870426034, 
       12.499999999999998`}, {89.23171088240647, 29.8503326671962, 
       12.499999999999998`}, {87.46570422749586, 31.616339322106818`, 
       6.4704761275630185`}}], 
      Line3DBox[{{89.23171088240647, 29.8503326671962, 12.499999999999998`}, {
       91.76175691947061, 32.38037870426034, 12.499999999999998`}, {
       94.57106781186548, 29.571067811865476`, 17.677669529663685`}, {
       92.04102177480134, 27.041021774801337`, 17.677669529663685`}, {
       89.23171088240647, 29.8503326671962, 12.499999999999998`}}], 
      Line3DBox[{{92.04102177480134, 27.041021774801337`, 
       17.677669529663685`}, {94.57106781186548, 29.571067811865476`, 
       17.677669529663685`}, {98.23223304703363, 25.90990257669732, 
       21.650635094610966`}, {95.70218700996949, 23.37985653963318, 
       21.650635094610966`}, {92.04102177480134, 27.041021774801337`, 
       17.677669529663685`}}], 
      Line3DBox[{{95.70218700996949, 23.37985653963318, 
       21.650635094610966`}, {98.23223304703363, 25.90990257669732, 
       21.650635094610966`}, {102.49575026455999`, 21.646385359170964`, 
       24.148145657226706`}, {99.96570422749586, 19.116339322106825`, 
       24.148145657226706`}, {95.70218700996949, 23.37985653963318, 
       21.650635094610966`}}], 
      Line3DBox[{{99.96570422749586, 19.116339322106825`, 
       24.148145657226706`}, {102.49575026455999`, 21.646385359170964`, 
       24.148145657226706`}, {107.07106781186548`, 17.07106781186548, 25.}, {
       104.54102177480134`, 14.541021774801344`, 25.}, {99.96570422749586, 
       19.116339322106825`, 24.148145657226706`}}], 
      Line3DBox[{{104.54102177480134`, 14.541021774801337`, 25.}, {
       107.07106781186548`, 17.071067811865476`, 25.}, {111.64638535917095`, 
       12.495750264559994`, 24.148145657226706`}, {109.11633932210681`, 
       9.965704227495856, 24.148145657226706`}, {104.54102177480134`, 
       14.541021774801337`, 25.}}], 
      Line3DBox[{{109.11633932210681`, 9.965704227495856, 
       24.148145657226706`}, {111.64638535917095`, 12.495750264559994`, 
       24.148145657226706`}, {115.90990257669732`, 8.232233047033636, 
       21.65063509461097}, {113.37985653963317`, 5.702187009969499, 
       21.65063509461097}, {109.11633932210681`, 9.965704227495856, 
       24.148145657226706`}}], 
      Line3DBox[{{113.37985653963317`, 5.702187009969499, 
       21.65063509461097}, {115.90990257669732`, 8.232233047033636, 
       21.65063509461097}, {119.57106781186548`, 4.571067811865479, 
       17.67766952966369}, {117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}, {113.37985653963317`, 5.702187009969499, 
       21.65063509461097}}], 
      Line3DBox[{{117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}, {119.57106781186548`, 4.571067811865479, 
       17.67766952966369}, {122.38037870426034`, 1.7617569194706117`, 
       12.499999999999998`}, {119.85033266719621`, -0.7682891175935254, 
       12.499999999999998`}, {117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}}], 
      Line3DBox[{{119.8503326671962, -0.7682891175935147, 
       12.500000000000009`}, {122.38037870426034`, 1.761756919470617, 
       12.500000000000009`}, {124.14638535917095`, -0.004249735440005509, 
       6.470476127563026}, {121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}, {119.8503326671962, -0.7682891175935147, 
       12.500000000000009`}}], 
      Line3DBox[{{121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}, {124.14638535917095`, -0.004249735440005509, 
       6.470476127563026}, {124.74873734152916`, -0.6066017177982097, 
       3.061616997868383*^-15}, {122.21869130446503`, -3.1366477548623486`, 
       3.061616997868383*^-15}, {121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}}], 
      Line3DBox[{{122.21869130446503`, -3.1366477548623486`, 
       3.061616997868383*^-15}, {124.74873734152916`, -0.6066017177982097, 
       3.061616997868383*^-15}, {
       124.14638535917095`, -0.004249735440005509, -6.47047612756302}, {
       121.61633932210681`, -2.5342957725041444`, -6.47047612756302}, {
       122.21869130446503`, -3.1366477548623486`, 3.061616997868383*^-15}}], 
      Line3DBox[{{
       121.61633932210681`, -2.534295772504148, -6.470476127563009}, {
       124.14638535917096`, -0.0042497354400090614`, -6.470476127563009}, {
       122.38037870426034`, 1.7617569194706117`, -12.499999999999993`}, {
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}, {
       121.61633932210681`, -2.534295772504148, -6.470476127563009}}], 
      Line3DBox[{{
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}, {
       122.38037870426034`, 1.7617569194706117`, -12.499999999999993`}, {
       119.57106781186548`, 4.571067811865474, -17.677669529663685`}, {
       117.04102177480134`, 2.0410217748013366`, -17.677669529663685`}, {
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}}], 
      Line3DBox[{{117.04102177480134`, 
       2.0410217748013366`, -17.677669529663678`}, {119.57106781186548`, 
       4.571067811865472, -17.677669529663678`}, {115.90990257669733`, 
       8.232233047033624, -21.65063509461096}, {113.3798565396332, 
       5.702187009969485, -21.65063509461096}, {117.04102177480134`, 
       2.0410217748013366`, -17.677669529663678`}}], 
      Line3DBox[{{113.3798565396332, 5.702187009969485, -21.65063509461096}, {
       115.90990257669733`, 8.232233047033624, -21.65063509461096}, {
       111.64638535917098`, 12.49575026455998, -24.148145657226703`}, {
       109.11633932210684`, 9.965704227495841, -24.148145657226703`}, {
       113.3798565396332, 5.702187009969485, -21.65063509461096}}], 
      Line3DBox[{{109.11633932210684`, 
       9.965704227495841, -24.148145657226703`}, {111.64638535917098`, 
       12.49575026455998, -24.148145657226703`}, {107.07106781186549`, 
       17.071067811865458`, -25.}, {104.54102177480137`, 
       14.541021774801315`, -25.}, {109.11633932210684`, 
       9.965704227495841, -24.148145657226703`}}], 
      Line3DBox[{{104.54102177480134`, 14.541021774801337`, -25.}, {
       107.07106781186548`, 17.071067811865472`, -25.}, {102.49575026456, 
       21.64638535917095, -24.14814565722671}, {99.96570422749586, 
       19.11633932210681, -24.14814565722671}, {104.54102177480134`, 
       14.541021774801337`, -25.}}], 
      Line3DBox[{{99.96570422749586, 19.11633932210681, -24.14814565722671}, {
       102.49575026456, 21.64638535917095, -24.14814565722671}, {
       98.23223304703365, 25.909902576697306`, -21.650635094610976`}, {
       95.7021870099695, 23.379856539633167`, -21.650635094610976`}, {
       99.96570422749586, 19.11633932210681, -24.14814565722671}}], 
      Line3DBox[{{95.7021870099695, 
       23.379856539633167`, -21.650635094610976`}, {98.23223304703365, 
       25.909902576697306`, -21.650635094610976`}, {94.57106781186549, 
       29.57106781186546, -17.67766952966371}, {92.04102177480135, 
       27.04102177480133, -17.67766952966371}, {95.7021870099695, 
       23.379856539633167`, -21.650635094610976`}}], 
      Line3DBox[{{92.04102177480134, 
       27.041021774801337`, -17.677669529663692`}, {94.57106781186548, 
       29.571067811865472`, -17.677669529663692`}, {91.76175691947061, 
       32.38037870426033, -12.50000000000001}, {89.23171088240647, 
       29.85033266719619, -12.50000000000001}, {92.04102177480134, 
       27.041021774801337`, -17.677669529663692`}}], 
      Line3DBox[{{89.23171088240647, 29.85033266719619, -12.50000000000001}, {
       91.76175691947061, 32.38037870426033, -12.50000000000001}, {
       89.99575026456, 34.14638535917095, -6.470476127563039}, {
       87.46570422749586, 31.61633932210681, -6.470476127563039}, {
       89.23171088240647, 29.85033266719619, -12.50000000000001}}], 
      Line3DBox[{{87.46570422749586, 31.61633932210681, -6.470476127563039}, {
       89.99575026456, 34.14638535917095, -6.470476127563039}, {
       89.39339828220179, 34.748737341529164`, -2.8327694488239898`*^-14}, {
       86.86335224513765, 32.218691304465025`, -2.8327694488239898`*^-14}, {
       87.46570422749586, 31.61633932210681, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 35., -35.}, {200., -35., -35.}, {200., -35., 35.}, {
       200., 35., 35.}, {200., 35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -35., -35.}, {0., -35., -35.}, {0., -35., 35.}, {
       200., -35., 35.}, {200., -35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -35, -35}, {0, 35, -35}, {0, 35, 35}, {0, -35, 35}, {
       0, -35, -35}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 35., -35.}, {200., 35., -35.}, {200., 35., 35.}, {0., 
       35., 35.}, {0., 35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -35., -35.}, {200., 35., -35.}, {0., 35., -35.}, {
       0., -35., -35.}, {200., -35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 35., 35.}, {200., -35., 35.}, {0., -35., 35.}, {0., 
       35., 35.}, {200., 35., 35.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{0., 0., 0.}, {114.05667518480516`, 0., 0.}}, {{
      114.05667518480516`, 0., 0.}, {120.65883339458972`, 3.4833022291412306`,
       0.}}, {{120.65883339458972`, 3.4833022291412306`, 0.}, {200., 
      29.774999858971334`, 0.}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     Point3DBox[{{114.05667518480516`, 0., 0.}, {120.65883339458972`, 
      3.4833022291412306`, 0.}, {200., 29.774999858971334`, 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367528905547*^9, 3.566086984564972*^9, 
  3.566101736687639*^9, 3.566139179763863*^9, 3.6147077917868443`*^9},
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"},
 CellLabel->
  "During evaluation of \
In[27]:=",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SingleRay", "[", "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"PlanoConvexLens", "[", 
           RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"100.`", ",", "10.`"}], "}"}], ",", "45.`"}], "]"}], ",", 
        RowBox[{"Boundary", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", "35"}], ",", 
            RowBox[{"-", "35"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"200", ",", "35", ",", "35"}], "}"}]}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.563367528905547*^9, 3.566086984564972*^9, 
  3.566101736687639*^9, 3.566139179763863*^9, 3.6147077918110113`*^9},
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"},
 CellLabel->
  "During evaluation of \
In[27]:=",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6"],

Cell[BoxData["\<\"-3 ray/surface intersections-\"\>"], "Output",
 CellChangeTimes->{3.5633675289376574`*^9, 3.566086984618245*^9, 
  3.56610173672821*^9, 3.5661391797947598`*^9, 3.614707791812735*^9},
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"},
 CellLabel->"Out[27]=",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6"]
}, Open  ]],

Cell[TextData[{
 "By default, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " always takes the x-axis to be the optical axis. This means that, by \
default, all of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s built-in light source functions automatically direct their rays along \
the positive x-axis. In this example, the ",
 StyleBox["SingleRay", "Input"],
 " function has generated a ray that is exactly co-linear with the x-axis. In \
other, more complex light source functions, only the chief ray is precisely \
co-linear with the x-axis. Of course, you can always choose a different \
optical axis by re-aligning the light source and optics with a positioning \
directive such as ",
 StyleBox["Move", "Input"],
 "."
}], "Text",
 CellTags->{
  "AnalyzeSystem", "5.1", "RG5.", 
   "RG5.1"},ExpressionUUID->"7369556e-547f-4c48-9122-ce4aa18cf0e1"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->"RG5.",ExpressionUUID->"b0feb3b6-78fc-4c46-97e7-8d25b7f404cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working with the ray-trace data", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", 
   "RG5.", "RG5.2"},ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330"],

Cell[TextData[{
 "After calculating and rendering the ray trace, ",
 StyleBox["AnalyzeSystem", "Input"],
 " passes back a data object that holds the ray-trace information. You can \
use this returned information to make further plots or exact numeric \
information about the generated ray trace. In general, depending on whether \
",
 StyleBox["AnalyzeSystem", "Input"],
 " or ",
 StyleBox["TurboPlot", "Input"],
 " was used, the final ray-trace data is held in either an ",
 StyleBox["OpticalSystem", "Input"],
 " object (as in this case) or a ",
 StyleBox["TurboSystem", "Input"],
 " object (with ",
 StyleBox["TurboPlot", "Input"],
 "). However, as discussed before with ",
 StyleBox["Component", "Input"],
 " and ",
 StyleBox["Source", "Input"],
 ", the information held in these returned objects are always hidden from the \
user. Rather than directly viewing these objects, you will normally examine \
the ray-trace results with one of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s ray-trace diagnostic functions. These are listed below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", 
   "RG5.2"},ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281"],

Cell[TextData[{
 StyleBox["ShowSystem[", "Input",
  FontFamily->"Courier"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " takes a ",
 StyleBox["system ",
  FontSlant->"Italic"],
 "of rays and/or components and generates a graphical display of the ",
 StyleBox["system",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["ReadRays[", "Input",
  FontFamily->"Courier"],
 StyleBox["results",
  FontSlant->"Italic"],
 ", ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 ", ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " takes ray-traced ",
 StyleBox["results",
  FontSlant->"Italic"],
 " from ",
 StyleBox["AnalyzeSystem", "Input"],
 "/",
 StyleBox["PropagateSystem", "Input"],
 " as well as ",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 " and returns a list of values for ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 " given.\n",
 StyleBox["FindFocus[", "Input"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " determines the minimum spot size for a locus of rays at the last reported \
surface in the system and plots the results.\n",
 StyleBox["FindSpotSize[", "Input"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " determines the spot size for a locus of rays at the last reported surface \
in the system and plots the results.\n",
 StyleBox["FindIntensity[", "Input",
  FontWeight->"Bold"],
 StyleBox["system",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 " calculates the intensity function for each optical surface that gets \
reported from the ray trace of the ",
 StyleBox["system",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["ModulationTransferFunction[", "Input",
  FontWeight->"Bold"],
 StyleBox["intensitydata",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 " calculates the modulation and phase transfer functions of an optical \
system for a given object source input."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "AnalyzeSystem", "5.2", "RG5.", 
   "RG5.2"},ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s ray-trace diagnostic functions."
}], "Commentary",
 CellTags->{
  "AnalyzeSystem", "5.2", "RG5.", 
   "RG5.2"},ExpressionUUID->"26b43ee4-7126-4285-afb4-1c0266581bb3"],

Cell[TextData[{
 "In addition to the diagnostic functions listed in the above box, you can \
also reuse the ray-trace functions, ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 ", to make different visualizations of previously ray-traced information. \
There are also two other important high-level functions, ",
 StyleBox["OptimizeSystem", "Input"],
 " and ",
 StyleBox["FindIntensity", "Input"],
 ", that take an untraced optical system and perform their own internal \
ray-trace calculations. Many examples of these different functions are \
presented throughout the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " documentation. In the next section, we will examine the ",
 StyleBox["ShowSystem", "Input"],
 " function and use it to rerender the previous ",
 StyleBox["trace", "Input"],
 " result."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", 
   "RG5.2"},ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->"RG5.",ExpressionUUID->"a371b2c7-e818-4fbb-8cf6-e8cc10f8b2bb"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "6. The ",
 StyleBox["ShowSystem",
  FontFamily->"Courier New"],
 " Function"
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", "6.", 
   "RG6."},ExpressionUUID->"64a2e08a-22da-4300-95b9-1ad25b5ce535"],

Cell[TextData[{
 "After making the ray-trace with ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " , you can redisplay the results more quickly with ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 ". Here we use the previous ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " output, stored in the ",
 StyleBox["trace", "Input"],
 " variable, as the input to ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 StyleBox[". (",
  FontFamily->"Times New Roman"],
 "We will suppress the printed output text by including a semicolon at the \
end of the input expression.",
 StyleBox[")",
  FontFamily->"Times New Roman"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", 
   "RG6."},ExpressionUUID->"a762463d-3045-4825-87b2-14bb8f507bfc"],

Cell[CellGroupData[{

Cell[TextData[{
 "ShowSystem[",
 StyleBox["trace",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", PlotType->TopView, Axes->True, MinimumArrowLength->0];"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", "PlotType", "TopView", "RG6."},
 CellLabel->"In[28]:=",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{122.21869130446503`, -3.1366477548623486`}, {
      124.74873734152916`, -0.6066017177982097}, {118.85618083164127`, 
      5.285954792089681}, {113.7299740418052, 0.15974800225361463`}, {
      122.21869130446503`, -3.1366477548623486`}}], 
     PolygonBox[{{113.7299740418052, 0.15974800225361463`}, {
      118.85618083164127`, 5.285954792089681}, {112.96362432175337`, 
      11.17851130197758}, {106.36897535766184`, 4.583862337886039}, {
      113.7299740418052, 0.15974800225361463`}}], 
     PolygonBox[{{106.36897535766184`, 4.583862337886039}, {
      112.96362432175337`, 11.17851130197758}, {107.07106781186548`, 
      17.071067811865472`}, {100., 10.}, {106.36897535766184`, 
      4.583862337886039}}], 
     PolygonBox[{{100., 10.}, {107.07106781186548`, 17.071067811865476`}, {
      101.17851130197758`, 22.96362432175337}, {94.58386233788605, 
      16.368975357661824`}, {100., 10.}}], 
     PolygonBox[{{94.58386233788605, 16.368975357661824`}, {
      101.17851130197758`, 22.96362432175337}, {95.28595479208968, 
      28.856180831641264`}, {90.15974800225362, 23.7299740418052}, {
      94.58386233788605, 16.368975357661824`}}], 
     PolygonBox[{{90.15974800225362, 23.7299740418052}, {95.28595479208968, 
      28.856180831641264`}, {89.39339828220179, 34.748737341529164`}, {
      86.86335224513765, 32.218691304465025`}, {90.15974800225362, 
      23.7299740418052}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{122.21869130446503`, -3.1366477548623486`}, {
       113.7299740418052, 0.15974800225361463`}, {106.36897535766184`, 
       4.583862337886039}, {100., 10.}, {94.58386233788605, 
       16.368975357661824`}, {90.15974800225362, 23.729974041805193`}, {
       86.86335224513765, 32.218691304465025`}, {89.39339828220179, 
       34.748737341529164`}, {95.28595479208968, 28.856180831641268`}, {
       101.17851130197758`, 22.96362432175337}, {107.07106781186548`, 
       17.07106781186548}, {112.96362432175337`, 11.178511301977583`}, {
       118.85618083164125`, 5.285954792089692}, {
       124.74873734152916`, -0.6066017177982062}, {
       122.21869130446503`, -3.1366477548623486`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{104.54102177480134`, 14.541021774801337`}, {
        107.07106781186548`, 17.07106781186548}, {107.07106781186548`, 
        17.07106781186548}, {101.94486102202941`, 11.944861022029407`}, {
        104.54102177480134`, 14.541021774801337`}}], 
       PolygonBox[{{101.94486102202941`, 11.944861022029407`}, {
        107.07106781186548`, 17.07106781186548}, {107.07106781186548`, 
        17.071067811865476`}, {100.47641884777394`, 10.476418847773935`}, {
        101.94486102202941`, 11.944861022029407`}}], 
       PolygonBox[{{100.47641884777394`, 10.476418847773935`}, {
        107.07106781186548`, 17.071067811865476`}, {107.07106781186548`, 
        17.071067811865476`}, {100., 10.}, {100.47641884777394`, 
        10.476418847773935`}}], 
       PolygonBox[{{100., 10.}, {107.07106781186548`, 17.071067811865476`}, {
        107.07106781186548`, 17.071067811865476`}, {100.47641884777394`, 
        10.476418847773935`}, {100., 10.}}], 
       PolygonBox[{{100.47641884777394`, 10.476418847773935`}, {
        107.07106781186548`, 17.071067811865476`}, {107.07106781186548`, 
        17.071067811865476`}, {101.94486102202941`, 11.944861022029407`}, {
        100.47641884777394`, 10.476418847773935`}}], 
       PolygonBox[{{101.94486102202941`, 11.944861022029407`}, {
        107.07106781186548`, 17.071067811865476`}, {107.07106781186548`, 
        17.071067811865476`}, {104.54102177480134`, 14.541021774801337`}, {
        101.94486102202941`, 11.944861022029407`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{104.54102177480134`, 14.541021774801337`}, {
         101.94486102202941`, 11.944861022029407`}, {100.47641884777394`, 
         10.476418847773935`}, {100., 10.}, {100.47641884777394`, 
         10.476418847773935`}, {101.94486102202941`, 11.944861022029407`}, {
         104.54102177480134`, 14.541021774801337`}, {107.07106781186548`, 
         17.071067811865476`}, {107.07106781186548`, 17.071067811865476`}, {
         107.07106781186548`, 17.071067811865476`}, {107.07106781186548`, 
         17.071067811865476`}, {107.07106781186548`, 17.071067811865476`}, {
         107.07106781186548`, 17.071067811865476`}, {107.07106781186548`, 
         17.071067811865476`}, {104.54102177480134`, 
         14.541021774801337`}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{86.86335224513765, 32.218691304465025`}, {89.39339828220179, 
       34.748737341529164`}, {89.99575026456, 34.14638535917096}, {
       87.46570422749586, 31.616339322106818`}, {86.86335224513765, 
       32.218691304465025`}}], 
      LineBox[{{87.46570422749586, 31.616339322106818`}, {89.99575026456, 
       34.14638535917096}, {91.76175691947061, 32.38037870426034}, {
       89.23171088240647, 29.8503326671962}, {87.46570422749586, 
       31.616339322106818`}}], 
      LineBox[{{89.23171088240647, 29.8503326671962}, {91.76175691947061, 
       32.38037870426034}, {94.57106781186548, 29.571067811865476`}, {
       92.04102177480134, 27.041021774801337`}, {89.23171088240647, 
       29.8503326671962}}], 
      LineBox[{{92.04102177480134, 27.041021774801337`}, {94.57106781186548, 
       29.571067811865476`}, {98.23223304703363, 25.90990257669732}, {
       95.70218700996949, 23.37985653963318}, {92.04102177480134, 
       27.041021774801337`}}], 
      LineBox[{{95.70218700996949, 23.37985653963318}, {98.23223304703363, 
       25.90990257669732}, {102.49575026455999`, 21.646385359170964`}, {
       99.96570422749586, 19.116339322106825`}, {95.70218700996949, 
       23.37985653963318}}], 
      LineBox[{{99.96570422749586, 19.116339322106825`}, {102.49575026455999`,
        21.646385359170964`}, {107.07106781186548`, 17.07106781186548}, {
       104.54102177480134`, 14.541021774801344`}, {99.96570422749586, 
       19.116339322106825`}}], 
      LineBox[{{104.54102177480134`, 14.541021774801337`}, {
       107.07106781186548`, 17.071067811865476`}, {111.64638535917095`, 
       12.495750264559994`}, {109.11633932210681`, 9.965704227495856}, {
       104.54102177480134`, 14.541021774801337`}}], 
      LineBox[{{109.11633932210681`, 9.965704227495856}, {111.64638535917095`,
        12.495750264559994`}, {115.90990257669732`, 8.232233047033636}, {
       113.37985653963317`, 5.702187009969499}, {109.11633932210681`, 
       9.965704227495856}}], 
      LineBox[{{113.37985653963317`, 5.702187009969499}, {115.90990257669732`,
        8.232233047033636}, {119.57106781186548`, 4.571067811865479}, {
       117.04102177480134`, 2.0410217748013366`}, {113.37985653963317`, 
       5.702187009969499}}], 
      LineBox[{{117.04102177480134`, 2.0410217748013366`}, {
       119.57106781186548`, 4.571067811865479}, {122.38037870426034`, 
       1.7617569194706117`}, {119.85033266719621`, -0.7682891175935254}, {
       117.04102177480134`, 2.0410217748013366`}}], 
      LineBox[{{119.8503326671962, -0.7682891175935147}, {122.38037870426034`,
        1.761756919470617}, {124.14638535917095`, -0.004249735440005509}, {
       121.61633932210681`, -2.5342957725041444`}, {
       119.8503326671962, -0.7682891175935147}}], 
      LineBox[{{121.61633932210681`, -2.5342957725041444`}, {
       124.14638535917095`, -0.004249735440005509}, {
       124.74873734152916`, -0.6066017177982097}, {
       122.21869130446503`, -3.1366477548623486`}, {
       121.61633932210681`, -2.5342957725041444`}}], 
      LineBox[{{122.21869130446503`, -3.1366477548623486`}, {
       124.74873734152916`, -0.6066017177982097}, {
       124.14638535917095`, -0.004249735440005509}, {
       121.61633932210681`, -2.5342957725041444`}, {
       122.21869130446503`, -3.1366477548623486`}}], 
      LineBox[{{121.61633932210681`, -2.534295772504148}, {
       124.14638535917096`, -0.0042497354400090614`}, {122.38037870426034`, 
       1.7617569194706117`}, {119.85033266719621`, -0.7682891175935254}, {
       121.61633932210681`, -2.534295772504148}}], 
      LineBox[{{119.85033266719621`, -0.7682891175935254}, {
       122.38037870426034`, 1.7617569194706117`}, {119.57106781186548`, 
       4.571067811865474}, {117.04102177480134`, 2.0410217748013366`}, {
       119.85033266719621`, -0.7682891175935254}}], 
      LineBox[{{117.04102177480134`, 2.0410217748013366`}, {
       119.57106781186548`, 4.571067811865472}, {115.90990257669733`, 
       8.232233047033624}, {113.3798565396332, 5.702187009969485}, {
       117.04102177480134`, 2.0410217748013366`}}], 
      LineBox[{{113.3798565396332, 5.702187009969485}, {115.90990257669733`, 
       8.232233047033624}, {111.64638535917098`, 12.49575026455998}, {
       109.11633932210684`, 9.965704227495841}, {113.3798565396332, 
       5.702187009969485}}], 
      LineBox[{{109.11633932210684`, 9.965704227495841}, {111.64638535917098`,
        12.49575026455998}, {107.07106781186549`, 17.071067811865458`}, {
       104.54102177480137`, 14.541021774801315`}, {109.11633932210684`, 
       9.965704227495841}}], 
      LineBox[{{104.54102177480134`, 14.541021774801337`}, {
       107.07106781186548`, 17.071067811865472`}, {102.49575026456, 
       21.64638535917095}, {99.96570422749586, 19.11633932210681}, {
       104.54102177480134`, 14.541021774801337`}}], 
      LineBox[{{99.96570422749586, 19.11633932210681}, {102.49575026456, 
       21.64638535917095}, {98.23223304703365, 25.909902576697306`}, {
       95.7021870099695, 23.379856539633167`}, {99.96570422749586, 
       19.11633932210681}}], 
      LineBox[{{95.7021870099695, 23.379856539633167`}, {98.23223304703365, 
       25.909902576697306`}, {94.57106781186549, 29.57106781186546}, {
       92.04102177480135, 27.04102177480133}, {95.7021870099695, 
       23.379856539633167`}}], 
      LineBox[{{92.04102177480134, 27.041021774801337`}, {94.57106781186548, 
       29.571067811865472`}, {91.76175691947061, 32.38037870426033}, {
       89.23171088240647, 29.85033266719619}, {92.04102177480134, 
       27.041021774801337`}}], 
      LineBox[{{89.23171088240647, 29.85033266719619}, {91.76175691947061, 
       32.38037870426033}, {89.99575026456, 34.14638535917095}, {
       87.46570422749586, 31.61633932210681}, {89.23171088240647, 
       29.85033266719619}}], 
      LineBox[{{87.46570422749586, 31.61633932210681}, {89.99575026456, 
       34.14638535917095}, {89.39339828220179, 34.748737341529164`}, {
       86.86335224513765, 32.218691304465025`}, {87.46570422749586, 
       31.61633932210681}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 35.}, {200., -35.}, {200., -35.}, {200., 35.}, {200., 
       35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -35.}, {0., -35.}, {0., -35.}, {200., -35.}, {
       200., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -35}, {0, 35}, {0, 35}, {0, -35}, {0, -35}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 35.}, {200., 35.}, {200., 35.}, {0., 35.}, {0., 35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., -35.}, {200., 35.}, {0., 35.}, {0., -35.}, {
       200., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{200., 35.}, {200., -35.}, {0., -35.}, {0., 35.}, {200., 
       35.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {114.05667518480516`, 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{114.05667518480516`, 0.}, {120.65883339458972`, 
       3.4833022291412306`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{120.65883339458972`, 3.4833022291412306`}, {200., 
       29.774999858971334`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{114.05667518480516`, 0.}, {120.65883339458972`, 
      3.4833022291412306`}, {200., 29.774999858971334`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Axes:>True,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367528999919*^9, 3.566086984686965*^9, 
  3.566101737068534*^9, 3.56613918009656*^9, 3.614707791880066*^9},
 CellTags->{
  "ShowSystem", "component rendering", "PlotType", "TopView", "RG6."},
 CellLabel->
  "During evaluation of \
In[28]:=",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb"]
}, Open  ]],

Cell[TextData[{
 "Here the rendered result shows three arrows that correspond with the three \
ray segments previously calculated by ",
 StyleBox["AnalyzeSystem", "Input"],
 " during the trace. ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 " and ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " both use the same options for graphical rendering. Although there are a \
great many options available for graphical rendering, some of most important \
options are listed in the following table."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", 
   "RG6."},ExpressionUUID->"30f2a5f0-70af-48be-a362-2f0d0ed3bc92"],

Cell[TextData[Cell[BoxData[
 TagBox[GridBox[{
    {"AppendGraphics", "PrependGraphics"},
    {"Axes", "RayChoice"},
    {"ColorView", "ShowArrows"},
    {"CreateStereoView", "ShowClones"},
    {"DefaultStyle", "ShowComponents"},
    {"GraphicDesign", "ShowLabels"},
    {"MinimumArrowLength", "ShowRange"},
    {"PlotType", "ShowText"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$]]]],ExpressionUUID->"225ec23c-c852-4465-9694-22bfad7bfd17"]], \
"FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 TextAlignment->Center,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", "PlotType", 
   "RG6."},ExpressionUUID->"4d2d16ec-590d-4087-a948-7eca66168471"],

Cell["Important rendering options.", "Commentary",
 CellTags->{
  "ShowSystem", 
   "RG6."},ExpressionUUID->"accb7d7d-bdeb-4ef8-ab85-02949feef222"],

Cell[TextData[{
 "In most instances, only one or two rendering options will be needed to \
display any particular result. In the previous ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 " example, we used three different rendering options: ",
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Axes", "Input"],
 ", and ",
 StyleBox["MinimumArrowLength", "Input"],
 ". Of these three options, however, only the ",
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 " option is frequently required. As such, we will now examine the ",
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 " option in more detail."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", 
   "RG6."},ExpressionUUID->"1164e3f4-4cce-443b-a3eb-b8e6ed0b0d18"],

Cell[TextData[{
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 " is an option of ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " , ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["TurboPlot", "Input"],
 " that designates the display form of the graphics rendering for the optical \
system."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", "PlotType", 
   "RG6."},ExpressionUUID->"81b20859-5e84-4947-9587-7215471a8f59"],

Cell[TextData[{
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 " can take eight different settings, as listed below."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", 
   "RG6."},ExpressionUUID->"666c3868-dbeb-4e1e-8f1f-c61134156135"],

Cell[TextData[{
 StyleBox["TopView", "Input"],
 " gives a two-dimensional orthoscopic rendering showing a projection onto \
the x-y plane of the optical system.\n",
 StyleBox["FrontView", "Input"],
 " gives a two-dimensional orthoscopic rendering showing a projection onto \
the y-z plane of the optical system.\n",
 StyleBox["SideView", "Input"],
 " gives a two-dimensional orthoscopic rendering showing a projection onto \
the x-z plane of the optical system.\n",
 StyleBox["Full3D", "Input"],
 " gives the full three-dimensional rendering of the optical system.\n",
 StyleBox["RealTime3D", "Input"],
 " allows the rendered three-dimensional graphics to be rotated \
interactively.\n",
 StyleBox["Off", "Input"],
 " designates no graphical output.\n",
 StyleBox["Surface", "Input"],
 " gives a two-dimensional plot that shows selected intersection points \
between rays and one or more optical surfaces.\n",
 StyleBox["ShadowProject", "Input"],
 " gives a three-dimensional rendering of the optical system along with \
two-dimensional projections of the system onto the sides of a box."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Ray", "ShowSystem", 
   "RG6."},ExpressionUUID->"0936f727-cc05-485f-a077-877a4972781b"],

Cell[TextData[{
 "Settings of ",
 StyleBox["PlotType", "Input"],
 "."
}], "Commentary",
 CellTags->{
  "ShowSystem", 
   "RG6."},ExpressionUUID->"c0abbaea-40b0-43c3-92b0-8d371ecf8e2c"],

Cell[TextData[{
 "Finally, we will demonstrate ",
 StyleBox["ShowSystem", "Input"],
 " once again with the same ",
 StyleBox["trace", "Input"],
 " result. This time, however, we will use ",
 StyleBox["PlotType -> RealTime3D", "Input"],
 ". This option setting allows you to interactively rotate the ray-trace plot \
in three-dimensions with the mouse."
}], "Text",
 CellTags->{
  "ShowSystem", 
   "RG6."},ExpressionUUID->"61d6452e-a86b-42c5-97dc-5a2e42ff0159"],

Cell[CellGroupData[{

Cell[TextData[{
 "ShowSystem[",
 StyleBox["trace",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", PlotType -> ",
 StyleBox["RealTime3D", "Input"],
 "];"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ShowSystem", "component rendering", "PlotType", "TopView", "RG6."},
 CellLabel->"In[29]:=",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{122.21869130446503`, -3.1366477548623486`, 0.}, {
      124.74873734152916`, -0.6066017177982097, 6.123233995736766*^-15}, {
      118.85618083164127`, 5.285954792089681, 5.102694996447306*^-15}, {
      113.7299740418052, 0.15974800225361463`, 0.}, {
      122.21869130446503`, -3.1366477548623486`, 0.}}], 
     Polygon3DBox[{{113.7299740418052, 0.15974800225361463`, 0.}, {
      118.85618083164127`, 5.285954792089681, 5.102694996447306*^-15}, {
      112.96362432175337`, 11.17851130197758, 4.0821559971578446`*^-15}, {
      106.36897535766184`, 4.583862337886039, 0.}, {113.7299740418052, 
      0.15974800225361463`, 0.}}], 
     Polygon3DBox[{{106.36897535766184`, 4.583862337886039, 0.}, {
      112.96362432175337`, 11.17851130197758, 4.0821559971578446`*^-15}, {
      107.07106781186548`, 17.071067811865472`, 3.061616997868384*^-15}, {
      100., 10., 0.}, {106.36897535766184`, 4.583862337886039, 0.}}], 
     Polygon3DBox[{{100., 10., 0.}, {107.07106781186548`, 17.071067811865476`,
       3.061616997868383*^-15}, {101.17851130197758`, 22.96362432175337, 
      2.0410779985789223`*^-15}, {94.58386233788605, 16.368975357661824`, 
      0.}, {100., 10., 0.}}], 
     Polygon3DBox[{{94.58386233788605, 16.368975357661824`, 0.}, {
      101.17851130197758`, 22.96362432175337, 2.0410779985789223`*^-15}, {
      95.28595479208968, 28.856180831641264`, 1.0205389992894613`*^-15}, {
      90.15974800225362, 23.7299740418052, 0.}, {94.58386233788605, 
      16.368975357661824`, 0.}}], 
     Polygon3DBox[{{90.15974800225362, 23.7299740418052, 0.}, {
      95.28595479208968, 28.856180831641264`, 1.0205389992894615`*^-15}, {
      89.39339828220179, 34.748737341529164`, 5.098616525425841*^-31}, {
      86.86335224513765, 32.218691304465025`, 0.}, {90.15974800225362, 
      23.7299740418052, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIDZWu8D5vzfOQWKp4fFb4pwHGKDgnhz30+15MQ4M
rxfHzS86Yg8TZ+i56DV3epTDjggrpgehQg4MKCASyleBi/csVWaIWxru8Eff
Tbs0zgAu/i1wvb9lV5hDSbXOlPu7zOHi14uOaTpuD3VI81kg/E/aAS7+T+xv
vm5kmMOWKbwLrsU7wsUtuEJEfS+FOzTE7F+ld9sGLl70d9WuHO9Ihxn9yaIb
vpnBxdd8YEzoORLlsPEQe4OhkCFc/NnjCNY1tjEOk16HX02NVoOLy19fv+r0
tliHrsUOoRdVROHiUafYAl7rxzscaChh9Mh8vB8mjis8AbaKZEY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{104.54102177480134`, 14.541021774801337`, -25.}, {
        107.07106781186548`, 17.07106781186548, -25.}, {107.07106781186548`, 
        17.07106781186548, -16.66666666666667}, {101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}, {104.54102177480134`, 
        14.541021774801337`, -25.}}], 
       Polygon3DBox[{{101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}, {107.07106781186548`, 
        17.07106781186548, -16.66666666666667}, {107.07106781186548`, 
        17.071067811865476`, -8.333333333333336}, {100.47641884777394`, 
        10.476418847773935`, -8.333333333333336}, {101.94486102202941`, 
        11.944861022029407`, -16.666666666666668`}}], 
       Polygon3DBox[{{100.47641884777394`, 
        10.476418847773935`, -8.333333333333336}, {107.07106781186548`, 
        17.071067811865476`, -8.333333333333336}, {107.07106781186548`, 
        17.071067811865476`, -7.105427357601002*^-15}, {100., 10., 0.}, {
        100.47641884777394`, 10.476418847773935`, -8.333333333333336}}], 
       Polygon3DBox[{{100., 10., 0.}, {107.07106781186548`, 
        17.071067811865476`, 0.}, {107.07106781186548`, 17.071067811865476`, 
        8.333333333333332}, {100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}, {100., 10., 0.}}], 
       Polygon3DBox[{{100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}, {107.07106781186548`, 17.071067811865476`, 
        8.333333333333332}, {107.07106781186548`, 17.071067811865476`, 
        16.666666666666664`}, {101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}, {100.47641884777394`, 10.476418847773935`, 
        8.333333333333329}}], 
       Polygon3DBox[{{101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}, {107.07106781186548`, 17.071067811865476`, 
        16.666666666666664`}, {107.07106781186548`, 17.071067811865476`, 
        24.999999999999996`}, {104.54102177480134`, 14.541021774801337`, 
        24.999999999999993`}, {101.94486102202941`, 11.944861022029407`, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIG71OS25QCnKQSMl6hyDqK4DAxhYHsiyiJ1VURPp
4HP45aUjj9UdVq8CAYMDx2ZULa2Vi3TQOXZF++1nFYc1YHGFAxB9kVD9KlD6
wx509Ssg6h3QzYeIGzigu+fffxCwcFjzgTGh50iUw4ZD7A2GQoYwd2KIQ92J
IQ51Jw5zPtigi0PdeQC7uAGGONSdB3CFJwBC85gn
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{86.86335224513765, 32.218691304465025`, 0.}, {
       89.39339828220179, 34.748737341529164`, 0.}, {89.99575026456, 
       34.14638535917096, 6.4704761275630185`}, {87.46570422749586, 
       31.616339322106818`, 6.4704761275630185`}, {86.86335224513765, 
       32.218691304465025`, 0.}}], 
      Line3DBox[{{87.46570422749586, 31.616339322106818`, 
       6.4704761275630185`}, {89.99575026456, 34.14638535917096, 
       6.4704761275630185`}, {91.76175691947061, 32.38037870426034, 
       12.499999999999998`}, {89.23171088240647, 29.8503326671962, 
       12.499999999999998`}, {87.46570422749586, 31.616339322106818`, 
       6.4704761275630185`}}], 
      Line3DBox[{{89.23171088240647, 29.8503326671962, 12.499999999999998`}, {
       91.76175691947061, 32.38037870426034, 12.499999999999998`}, {
       94.57106781186548, 29.571067811865476`, 17.677669529663685`}, {
       92.04102177480134, 27.041021774801337`, 17.677669529663685`}, {
       89.23171088240647, 29.8503326671962, 12.499999999999998`}}], 
      Line3DBox[{{92.04102177480134, 27.041021774801337`, 
       17.677669529663685`}, {94.57106781186548, 29.571067811865476`, 
       17.677669529663685`}, {98.23223304703363, 25.90990257669732, 
       21.650635094610966`}, {95.70218700996949, 23.37985653963318, 
       21.650635094610966`}, {92.04102177480134, 27.041021774801337`, 
       17.677669529663685`}}], 
      Line3DBox[{{95.70218700996949, 23.37985653963318, 
       21.650635094610966`}, {98.23223304703363, 25.90990257669732, 
       21.650635094610966`}, {102.49575026455999`, 21.646385359170964`, 
       24.148145657226706`}, {99.96570422749586, 19.116339322106825`, 
       24.148145657226706`}, {95.70218700996949, 23.37985653963318, 
       21.650635094610966`}}], 
      Line3DBox[{{99.96570422749586, 19.116339322106825`, 
       24.148145657226706`}, {102.49575026455999`, 21.646385359170964`, 
       24.148145657226706`}, {107.07106781186548`, 17.07106781186548, 25.}, {
       104.54102177480134`, 14.541021774801344`, 25.}, {99.96570422749586, 
       19.116339322106825`, 24.148145657226706`}}], 
      Line3DBox[{{104.54102177480134`, 14.541021774801337`, 25.}, {
       107.07106781186548`, 17.071067811865476`, 25.}, {111.64638535917095`, 
       12.495750264559994`, 24.148145657226706`}, {109.11633932210681`, 
       9.965704227495856, 24.148145657226706`}, {104.54102177480134`, 
       14.541021774801337`, 25.}}], 
      Line3DBox[{{109.11633932210681`, 9.965704227495856, 
       24.148145657226706`}, {111.64638535917095`, 12.495750264559994`, 
       24.148145657226706`}, {115.90990257669732`, 8.232233047033636, 
       21.65063509461097}, {113.37985653963317`, 5.702187009969499, 
       21.65063509461097}, {109.11633932210681`, 9.965704227495856, 
       24.148145657226706`}}], 
      Line3DBox[{{113.37985653963317`, 5.702187009969499, 
       21.65063509461097}, {115.90990257669732`, 8.232233047033636, 
       21.65063509461097}, {119.57106781186548`, 4.571067811865479, 
       17.67766952966369}, {117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}, {113.37985653963317`, 5.702187009969499, 
       21.65063509461097}}], 
      Line3DBox[{{117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}, {119.57106781186548`, 4.571067811865479, 
       17.67766952966369}, {122.38037870426034`, 1.7617569194706117`, 
       12.499999999999998`}, {119.85033266719621`, -0.7682891175935254, 
       12.499999999999998`}, {117.04102177480134`, 2.0410217748013366`, 
       17.67766952966369}}], 
      Line3DBox[{{119.8503326671962, -0.7682891175935147, 
       12.500000000000009`}, {122.38037870426034`, 1.761756919470617, 
       12.500000000000009`}, {124.14638535917095`, -0.004249735440005509, 
       6.470476127563026}, {121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}, {119.8503326671962, -0.7682891175935147, 
       12.500000000000009`}}], 
      Line3DBox[{{121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}, {124.14638535917095`, -0.004249735440005509, 
       6.470476127563026}, {124.74873734152916`, -0.6066017177982097, 
       3.061616997868383*^-15}, {122.21869130446503`, -3.1366477548623486`, 
       3.061616997868383*^-15}, {121.61633932210681`, -2.5342957725041444`, 
       6.470476127563026}}], 
      Line3DBox[{{122.21869130446503`, -3.1366477548623486`, 
       3.061616997868383*^-15}, {124.74873734152916`, -0.6066017177982097, 
       3.061616997868383*^-15}, {
       124.14638535917095`, -0.004249735440005509, -6.47047612756302}, {
       121.61633932210681`, -2.5342957725041444`, -6.47047612756302}, {
       122.21869130446503`, -3.1366477548623486`, 3.061616997868383*^-15}}], 
      Line3DBox[{{
       121.61633932210681`, -2.534295772504148, -6.470476127563009}, {
       124.14638535917096`, -0.0042497354400090614`, -6.470476127563009}, {
       122.38037870426034`, 1.7617569194706117`, -12.499999999999993`}, {
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}, {
       121.61633932210681`, -2.534295772504148, -6.470476127563009}}], 
      Line3DBox[{{
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}, {
       122.38037870426034`, 1.7617569194706117`, -12.499999999999993`}, {
       119.57106781186548`, 4.571067811865474, -17.677669529663685`}, {
       117.04102177480134`, 2.0410217748013366`, -17.677669529663685`}, {
       119.85033266719621`, -0.7682891175935254, -12.499999999999993`}}], 
      Line3DBox[{{117.04102177480134`, 
       2.0410217748013366`, -17.677669529663678`}, {119.57106781186548`, 
       4.571067811865472, -17.677669529663678`}, {115.90990257669733`, 
       8.232233047033624, -21.65063509461096}, {113.3798565396332, 
       5.702187009969485, -21.65063509461096}, {117.04102177480134`, 
       2.0410217748013366`, -17.677669529663678`}}], 
      Line3DBox[{{113.3798565396332, 5.702187009969485, -21.65063509461096}, {
       115.90990257669733`, 8.232233047033624, -21.65063509461096}, {
       111.64638535917098`, 12.49575026455998, -24.148145657226703`}, {
       109.11633932210684`, 9.965704227495841, -24.148145657226703`}, {
       113.3798565396332, 5.702187009969485, -21.65063509461096}}], 
      Line3DBox[{{109.11633932210684`, 
       9.965704227495841, -24.148145657226703`}, {111.64638535917098`, 
       12.49575026455998, -24.148145657226703`}, {107.07106781186549`, 
       17.071067811865458`, -25.}, {104.54102177480137`, 
       14.541021774801315`, -25.}, {109.11633932210684`, 
       9.965704227495841, -24.148145657226703`}}], 
      Line3DBox[{{104.54102177480134`, 14.541021774801337`, -25.}, {
       107.07106781186548`, 17.071067811865472`, -25.}, {102.49575026456, 
       21.64638535917095, -24.14814565722671}, {99.96570422749586, 
       19.11633932210681, -24.14814565722671}, {104.54102177480134`, 
       14.541021774801337`, -25.}}], 
      Line3DBox[{{99.96570422749586, 19.11633932210681, -24.14814565722671}, {
       102.49575026456, 21.64638535917095, -24.14814565722671}, {
       98.23223304703365, 25.909902576697306`, -21.650635094610976`}, {
       95.7021870099695, 23.379856539633167`, -21.650635094610976`}, {
       99.96570422749586, 19.11633932210681, -24.14814565722671}}], 
      Line3DBox[{{95.7021870099695, 
       23.379856539633167`, -21.650635094610976`}, {98.23223304703365, 
       25.909902576697306`, -21.650635094610976`}, {94.57106781186549, 
       29.57106781186546, -17.67766952966371}, {92.04102177480135, 
       27.04102177480133, -17.67766952966371}, {95.7021870099695, 
       23.379856539633167`, -21.650635094610976`}}], 
      Line3DBox[{{92.04102177480134, 
       27.041021774801337`, -17.677669529663692`}, {94.57106781186548, 
       29.571067811865472`, -17.677669529663692`}, {91.76175691947061, 
       32.38037870426033, -12.50000000000001}, {89.23171088240647, 
       29.85033266719619, -12.50000000000001}, {92.04102177480134, 
       27.041021774801337`, -17.677669529663692`}}], 
      Line3DBox[{{89.23171088240647, 29.85033266719619, -12.50000000000001}, {
       91.76175691947061, 32.38037870426033, -12.50000000000001}, {
       89.99575026456, 34.14638535917095, -6.470476127563039}, {
       87.46570422749586, 31.61633932210681, -6.470476127563039}, {
       89.23171088240647, 29.85033266719619, -12.50000000000001}}], 
      Line3DBox[{{87.46570422749586, 31.61633932210681, -6.470476127563039}, {
       89.99575026456, 34.14638535917095, -6.470476127563039}, {
       89.39339828220179, 34.748737341529164`, -2.8327694488239898`*^-14}, {
       86.86335224513765, 32.218691304465025`, -2.8327694488239898`*^-14}, {
       87.46570422749586, 31.61633932210681, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 35., -35.}, {200., -35., -35.}, {200., -35., 35.}, {
       200., 35., 35.}, {200., 35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -35., -35.}, {0., -35., -35.}, {0., -35., 35.}, {
       200., -35., 35.}, {200., -35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -35, -35}, {0, 35, -35}, {0, 35, 35}, {0, -35, 35}, {
       0, -35, -35}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 35., -35.}, {200., 35., -35.}, {200., 35., 35.}, {0., 
       35., 35.}, {0., 35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -35., -35.}, {200., 35., -35.}, {0., 35., -35.}, {
       0., -35., -35.}, {200., -35., -35.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 35., 35.}, {200., -35., 35.}, {0., -35., 35.}, {0., 
       35., 35.}, {200., 35., 35.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], 
     Line3DBox[{{{0., 0., 0.}, {114.05667518480516`, 0., 0.}}, {{
      114.05667518480516`, 0., 0.}, {120.65883339458972`, 3.4833022291412306`,
       0.}}, {{120.65883339458972`, 3.4833022291412306`, 0.}, {200., 
      29.774999858971334`, 0.}}}]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     Point3DBox[{{114.05667518480516`, 0., 0.}, {120.65883339458972`, 
      3.4833022291412306`, 0.}, {200., 29.774999858971334`, 0.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56336752926534*^9, 3.566086984766678*^9, 
  3.566101737409513*^9, 3.566139180222722*^9, 3.6147077919996243`*^9},
 CellTags->{
  "ShowSystem", "component rendering", "PlotType", "TopView", "RG6."},
 CellLabel->
  "During evaluation of \
In[29]:=",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb"]
}, Open  ]],

Cell["\<\
You can use the mouse to interactively grab and rotate this three-dimensional \
graphic in real time.\
\>", "Commentary",
 CellTags->{
  "ShowSystem", 
   "RG6."},ExpressionUUID->"ba2e33a9-701f-45ed-9ae6-785a655b2088"],

Cell[TextData[{
 "Before concluding this brief introduction to ",
 StyleBox["ShowSystem", "Input"],
 ", there is one final comment worth mentioning about the use of ",
 StyleBox["ShowSystem", "Input"],
 " with ",
 StyleBox["TurboPlot", "Input"],
 " results. Although you can always use ",
 StyleBox["ShowSystem", "Input"],
 " to render results created by ",
 StyleBox["TurboPlot", "Input"],
 ", ",
 StyleBox["ShowSystem", "Input"],
 " will normally call ",
 StyleBox["TurboPlot", "Input"],
 " to render ",
 StyleBox["TraceTrace", "Input"],
 " data rather than doing the work itself. This is because ",
 StyleBox["ShowSystem", "Input"],
 " is not efficient at directly displaying the large numbers of rays that are \
often associated with ",
 StyleBox["TurboPlot", "Input"],
 " calculations. ",
 StyleBox["TurboPlot", "Input"],
 ", on the other hand, is optimized for the rendering of ",
 StyleBox["TurboTrace", "Input"],
 " results. This will be demonstrated in ",
 ButtonBox["Section 14",
  BaseStyle->"Hyperlink",
  ButtonData:>"14."],
 "."
}], "Text",
 CellTags->{
  "ShowSystem", 
   "RG6."},ExpressionUUID->"b9ee1085-a4db-4909-8120-573cd6b1d0cb"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"cf788e64-fa61-4fd6-\
bfab-7cc276a4538f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7. Tracing a Cone of Rays", "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ConeOfRays", "7.", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"ef5cb7f7-4a2e-41b7-a582-7cd49609ad04"],

Cell[TextData[{
 "To propagate several rays through a lens, you can use one of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s other built-in ray source functions. Here we use ",
 StyleBox["ConeOfRays", "Input",
  FontFamily->"Courier",
  FontVariations->{"CompatibilityType"->0}],
 " with ",
 StyleBox["AnalyzeSystem", "Input"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"9c94a08d-a3e8-4d8e-acb6-662ceb40fb6c"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[{ConeOfRays[20, NumberOfRays->7],\n\tMove[PlanoConvexLens[100, 50, 10], \
100],\n\tBoundary[{0,-25,-25}, {200,25,25}]}];"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->"In[30]:=",ExpressionUUID->"fed97f40-88bc-4f03-9201-d0237877757f"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 25., -25.}, {200., -25., -25.}, {200., -25., 25.}, {
       200., 25., 25.}, {200., 25., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -25., -25.}, {0., -25., -25.}, {0., -25., 25.}, {
       200., -25., 25.}, {200., -25., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -25, -25}, {0, 25, -25}, {0, 25, 25}, {0, -25, 25}, {
       0, -25, -25}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 25., -25.}, {200., 25., -25.}, {200., 25., 25.}, {0., 
       25., 25.}, {0., 25., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., -25., -25.}, {200., 25., -25.}, {0., 25., -25.}, {
       0., -25., -25.}, {200., -25., -25.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{200., 25., 25.}, {200., -25., 25.}, {0., -25., 25.}, {0., 
       25., 25.}, {200., 25., 25.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGAQBWImIAaxcYEjVtHRWZcjHVS3d+SKmhsdwKMUDPZB1dfd
LkmQeat2IES6Y/klfx2c+mDmixvv3h9ULODAe93o0pp9hgTVP42XOOtSauBQ
wddfvM1CnqD651D1uRD1DoTUG6O6B6d6mH9roP4Nh/jXAW+4NUQ7SKYtc2WT
RIjjDTeg+rTbzAzux9UOZHQHikkp6hzAG25A9Sv7PknqRgg4VFv8jE1ZaHgA
b7gB1Z/xzPwoHWXg8O6v+VIDVvkDeMMNqP4cVP1jiHoHvOEGVH8U1T0OuMIN
pj4F6t9siH/h4ujhBgGZDhFle3WL0/Qxwhk93GDqIyUiF+w6pHzgVI4nh3C6
Bs5wg6mX31D8dl00j8M73XuWj6bp4Qw3mPpZqrV1nPE6Dpt+/34l81IKrh49
3NDVL4eoxxluMPW+qO7BH25A9eFQ/56F+NcBAE9dIqU=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAQBWJmID5iFR2ddTnSQXV7R66oudEBBijYBxWvu12SIPNW
7UCIdMfyS/46B2DqxY137w8qFnDgvW50ac0+Q7j403iJsy6lBg4VfP3F2yzk
4eLPoeK5EHEHmLgxqjkOMHtroPaGQ+x1ADuqIdpBMm2ZK5skwp0w8bTbzAzu
x9UOZHQHikkp6hyAia/s+ySpGyHgUG3xMzZloSFc/Ixn5kfpKAOHd3/Nlxqw
ysPFz0HFH0PE4fYeRTUHLp4CtTcbYi9EnCHTIaJsr25xmj6qO4HikRKRC3Yd
Uj5wKseTQzhd4wBMXH5D8dt10TwO73TvWT6apgcXn6VaW8cZr+Ow6ffvVzIv
pTDEl0PE4fb6opoDFw+H2nsWYq8DAJDtrFo=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367529657278*^9, 3.566086985183359*^9, 
  3.566101738528035*^9, 3.566139181054163*^9, 3.614707792519451*^9},
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->
  "During evaluation of \
In[30]:=",ExpressionUUID->"37191ea6-48c5-4143-badd-2a16889b8e71"]
}, Open  ]],

Cell[TextData[{
 "Note that this time, in order to position the ",
 StyleBox["PlanoConvexLens", "Input"],
 ", we have passed the single numeric parameter of 100 to the ",
 StyleBox["Move", "Input"],
 " function. When only single number is given to ",
 StyleBox["Move", "Input"],
 ", the ",
 StyleBox["PlanoConvexLens", "Input"],
 " is simply displaced along the x-axis by the given amount."
}], "Text",
 CellTags->{
  "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"8d708064-4943-4d97-9338-80fdec46d92e"],

Cell[TextData[{
 "You can change the way a component function is rendered with the ",
 StyleBox["GraphicDesign", "Input",
  FontFamily->"Courier"],
 " option."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"24b310c7-f413-4438-a984-916a3d387316"],

Cell[TextData[{
 StyleBox["GraphicDesign", "Input",
  FontFamily->"Courier"],
 StyleBox[" -> ", "Input"],
 StyleBox["style",
  FontSlant->"Italic"],
 " is an option of all rendered components the designates the ",
 StyleBox["style",
  FontSlant->"Italic"],
 " of rendering.  "
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459"],

Cell[TextData[{
 StyleBox["GraphicDesign", "Input",
  FontFamily->"Courier"],
 " can be set to a number of different style settings. These include: ",
 StyleBox["Automatic", "Input",
  FontFamily->"Courier"],
 StyleBox[",",
  FontFamily->"Times New Roman"],
 " ",
 StyleBox["Sketch", "Input",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Wire", "Input",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Solid", "Input",
  FontFamily->"Courier"],
 ", or ",
 StyleBox["Off/False", "Input",
  FontFamily->"Courier"],
 ". In most cases, ",
 StyleBox["GraphicDesign", "Input"],
 " is used by component functions and is not passed directly to high-level \
rendering functions such as ",
 StyleBox["ShowSystem", "Input"],
 " or ",
 StyleBox["AnalyzeSystem", "Input"],
 ". Here we use ",
 StyleBox["GraphicDesign -> Wire", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["PlanoConvexLens", "Input",
  FontFamily->"Courier"],
 " and ",
 StyleBox["GraphicDesign -> Off", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["Boundary", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"e506ddcd-0879-41ab-9c62-f1893312d38a"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[{ConeOfRays[20, NumberOfRays -> 7],\n\tMove[PlanoConvexLens[100, 50, 10, \
GraphicDesign -> Wire], 100],\n\tBoundary[{0,-25,-25}, {200,25,25}, \
GraphicDesign -> Off]}];"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->"In[31]:=",ExpressionUUID->"78ae942a-cb18-4547-b900-445b13070a83"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         "]]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.333333333333332, 0.}, {100.67375799589207`, 8.049381885742235, 
       2.156825375854339}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 8.333333333333332, 0.}, {
       102.75044883428481`, 16.666666666666664`, 0.}, {102.75044883428481`, 
       16.09876377148447, 4.313650751708678}, {100.67375799589207`, 
       8.049381885742235, 2.156825375854339}, {100.67375799589207`, 
       8.333333333333332, 0.}}], 
      Line3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
       106.4219745809556, 25., 0.}, {106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {102.75044883428481`, 16.666666666666664`, 0.}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.049381885742235, 2.156825375854339}, {100.67375799589209`, 
       7.216878364870323, 4.166666666666666}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 8.049381885742235, 
       2.156825375854339}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {100.67375799589209`, 7.216878364870323, 
       4.166666666666666}, {100.67375799589207`, 8.049381885742235, 
       2.156825375854339}}], 
      Line3DBox[{{102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       7.216878364870323, 4.166666666666666}, {100.67375799589207`, 
       5.892556509887896, 5.8925565098878945`}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 7.216878364870323, 
       4.166666666666666}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}, {100.67375799589209`, 7.216878364870323, 
       4.166666666666666}}], 
      Line3DBox[{{102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.892556509887896, 5.8925565098878945`}, {100.67375799589209`, 
       4.166666666666668, 7.216878364870322}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {100.67375799589209`, 4.166666666666668, 
       7.216878364870322}, {100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}}], 
      Line3DBox[{{102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       4.166666666666668, 7.216878364870322}, {100.67375799589207`, 
       2.156825375854341, 8.049381885742235}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 4.166666666666668, 
       7.216878364870322}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {100.67375799589207`, 2.156825375854341, 
       8.049381885742235}, {100.67375799589209`, 4.166666666666668, 
       7.216878364870322}}], 
      Line3DBox[{{102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       2.156825375854341, 8.049381885742235}, {100.67375799589207`, 
       2.3606412073533245`*^-15, 8.333333333333332}, {100.00000000000001`, 0.,
        0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 2.156825375854341, 
       8.049381885742235}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {102.75044883428481`, 4.721282414706649*^-15, 
       16.666666666666664`}, {100.67375799589207`, 2.3606412073533245`*^-15, 
       8.333333333333332}, {100.67375799589207`, 2.156825375854341, 
       8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {106.4219745809556, 7.0819236220599744`*^-15, 
       25.}, {102.75044883428481`, 4.721282414706649*^-15, 
       16.666666666666664`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.102694996447305*^-16, 8.333333333333332}, {
       100.67375799589207`, -2.1568253758543383`, 8.049381885742235}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 5.102694996447305*^-16, 
       8.333333333333332}, {102.75044883428481`, 1.020538999289461*^-15, 
       16.666666666666664`}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}, {100.67375799589207`, 5.102694996447305*^-16, 
       8.333333333333332}}], 
      Line3DBox[{{102.75044883428481`, 1.020538999289461*^-15, 
       16.666666666666664`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}, {106.4219745809556, -6.470476127563016, 24.148145657226706`}, {
       102.75044883428481`, -4.313650751708677, 16.09876377148447}, {
       102.75044883428481`, 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -2.1568253758543383`, 8.049381885742235}, {
       100.67375799589209`, -4.166666666666664, 7.216878364870323}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {100.67375799589209`, -4.166666666666664, 
       7.216878364870323}, {100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -4.166666666666664, 7.216878364870323}, {
       100.67375799589207`, -5.8925565098878945`, 5.892556509887896}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, -4.166666666666664, 
       7.216878364870323}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}, {100.67375799589209`, -4.166666666666664, 
       7.216878364870323}}], 
      Line3DBox[{{102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -5.8925565098878945`, 5.892556509887896}, {
       100.67375799589209`, -7.216878364870323, 4.166666666666666}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {102.75044883428481`, -14.433756729740645`, 
       8.333333333333332}, {100.67375799589209`, -7.216878364870323, 
       4.166666666666666}, {100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}}], 
      Line3DBox[{{102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {106.4219745809556, -21.65063509461097, 
       12.499999999999998`}, {102.75044883428481`, -14.433756729740645`, 
       8.333333333333332}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -7.21687836487032, 4.16666666666667}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, -7.21687836487032, 4.16666666666667}, {
       102.7504488342848, -14.43375672974064, 8.33333333333334}, {
       102.75044883428481`, -16.09876377148447, 4.313650751708684}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.67375799589209`, -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{102.7504488342848, -14.43375672974064, 8.33333333333334}, {
       106.4219745809556, -21.650635094610962`, 12.500000000000009`}, {
       106.4219745809556, -24.148145657226706`, 6.470476127563026}, {
       102.75044883428481`, -16.09876377148447, 4.313650751708684}, {
       102.7504488342848, -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -8.049381885742235, 
       2.156825375854342}, {102.75044883428481`, -16.09876377148447, 
       4.313650751708684}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {100.67375799589207`, -8.333333333333332, 
       1.020538999289461*^-15}, {100.67375799589207`, -8.049381885742235, 
       2.156825375854342}}], 
      Line3DBox[{{102.75044883428481`, -16.09876377148447, 
       4.313650751708684}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {102.75044883428481`, -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}, {
       100.67375799589207`, -8.049381885742235, -2.15682537585434}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -8.333333333333332, 
       1.020538999289461*^-15}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {
       102.75044883428481`, -16.09876377148447, -4.31365075170868}, {
       100.67375799589207`, -8.049381885742235, -2.15682537585434}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       102.75044883428481`, -16.09876377148447, -4.31365075170868}, {
       102.75044883428481`, -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.049381885742235, -2.156825375854336}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -8.049381885742235, -2.156825375854336}, {
       102.75044883428481`, -16.09876377148447, -4.313650751708672}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.67375799589207`, -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{
       102.75044883428481`, -16.09876377148447, -4.313650751708672}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       102.75044883428481`, -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.67375799589207`, -5.892556509887897, -5.8925565098878945`}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       102.75044883428481`, -11.785113019775794`, -11.785113019775789`}, {
       100.67375799589207`, -5.892556509887897, -5.8925565098878945`}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       102.75044883428481`, -11.785113019775794`, -11.785113019775789`}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -5.892556509887898, -5.892556509887893}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -5.892556509887898, -5.892556509887893}, {
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.67375799589207`, -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.67375799589207`, -8.932295329768568*^-15, -8.333333333333332}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       102.75044883428481`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{100.67375799589207`, -8.932295329768568*^-15, -8.333333333333332}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       102.75044883428481`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{102.75044883428481`, -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}, {
       100.67375799589207`, 2.1568253758543356`, -8.049381885742235}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}, {
       102.75044883428481`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{102.75044883428481`, 4.313650751708671, -16.09876377148447}, {
       100.67375799589207`, 2.1568253758543356`, -8.049381885742235}, {
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{
       102.75044883428481`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{106.4219745809556, -4.592425496802574*^-15, -25.}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {
       102.75044883428481`, -3.0616169978683826`*^-15, \
-16.666666666666664`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.67375799589207`, 
       5.89255650988789, -5.892556509887903}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {102.75044883428481`, 
       11.78511301977578, -11.785113019775807`}, {100.67375799589207`, 
       5.89255650988789, -5.892556509887903}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {102.75044883428481`, 
       11.78511301977578, -11.785113019775807`}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}, {102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.67375799589207`, 
       8.333333333333332, -9.442564829413298*^-15}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {102.75044883428481`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {100.67375799589207`, 
       8.333333333333332, -9.442564829413298*^-15}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {102.75044883428481`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{110., 0., 0.}, {110., 8.333333333333332, 0.}, {110., 
       8.049381885742235, 2.156825375854339}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 8.333333333333332, 0.}, {110., 
       16.666666666666664`, 0.}, {110., 16.09876377148447, 
       4.313650751708678}, {110., 8.049381885742235, 2.156825375854339}, {
       110., 8.333333333333332, 0.}}], 
      Line3DBox[{{110., 16.666666666666664`, 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {110., 16.09876377148447, 
       4.313650751708678}, {110., 16.666666666666664`, 0.}}], 
      Line3DBox[{{110., 0., 0.}, {110., 8.049381885742235, 
       2.156825375854339}, {110., 7.216878364870323, 4.166666666666666}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 8.049381885742235, 2.156825375854339}, {110., 
       16.09876377148447, 4.313650751708678}, {110., 14.433756729740645`, 
       8.333333333333332}, {110., 7.216878364870323, 4.166666666666666}, {
       110., 8.049381885742235, 2.156825375854339}}], 
      Line3DBox[{{110., 16.09876377148447, 4.313650751708678}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {110., 21.65063509461097, 
       12.499999999999998`}, {110., 14.433756729740645`, 8.333333333333332}, {
       110., 16.09876377148447, 4.313650751708678}}], 
      Line3DBox[{{110., 0., 0.}, {110., 7.216878364870323, 
       4.166666666666666}, {110., 5.892556509887896, 5.8925565098878945`}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 7.216878364870323, 4.166666666666666}, {110., 
       14.433756729740645`, 8.333333333333332}, {110., 11.785113019775793`, 
       11.785113019775789`}, {110., 5.892556509887896, 5.8925565098878945`}, {
       110., 7.216878364870323, 4.166666666666666}}], 
      Line3DBox[{{110., 14.433756729740645`, 8.333333333333332}, {110., 
       21.65063509461097, 12.499999999999998`}, {110., 17.67766952966369, 
       17.677669529663685`}, {110., 11.785113019775793`, 
       11.785113019775789`}, {110., 14.433756729740645`, 8.333333333333332}}],
       Line3DBox[{{110., 0., 0.}, {110., 5.892556509887896, 
       5.8925565098878945`}, {110., 4.166666666666668, 7.216878364870322}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 5.892556509887896, 5.8925565098878945`}, {110., 
       11.785113019775793`, 11.785113019775789`}, {110., 8.333333333333336, 
       14.433756729740644`}, {110., 4.166666666666668, 7.216878364870322}, {
       110., 5.892556509887896, 5.8925565098878945`}}], 
      Line3DBox[{{110., 11.785113019775793`, 11.785113019775789`}, {110., 
       17.67766952966369, 17.677669529663685`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 8.333333333333336, 14.433756729740644`}, {
       110., 11.785113019775793`, 11.785113019775789`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 4.166666666666668, 
       7.216878364870322}, {110., 2.156825375854341, 8.049381885742235}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 4.166666666666668, 7.216878364870322}, {110., 
       8.333333333333336, 14.433756729740644`}, {110., 4.313650751708682, 
       16.09876377148447}, {110., 2.156825375854341, 8.049381885742235}, {
       110., 4.166666666666668, 7.216878364870322}}], 
      Line3DBox[{{110., 8.333333333333336, 14.433756729740644`}, {110., 
       12.500000000000004`, 21.650635094610966`}, {110., 6.470476127563024, 
       24.148145657226706`}, {110., 4.313650751708682, 16.09876377148447}, {
       110., 8.333333333333336, 14.433756729740644`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 2.156825375854341, 
       8.049381885742235}, {110., 2.3606412073533245`*^-15, 
       8.333333333333332}, {110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 2.156825375854341, 8.049381885742235}, {110., 
       4.313650751708682, 16.09876377148447}, {110., 4.721282414706649*^-15, 
       16.666666666666664`}, {110., 2.3606412073533245`*^-15, 
       8.333333333333332}, {110., 2.156825375854341, 8.049381885742235}}], 
      Line3DBox[{{110., 4.313650751708682, 16.09876377148447}, {110., 
       6.470476127563024, 24.148145657226706`}, {110., 
       7.0819236220599744`*^-15, 25.}, {110., 4.721282414706649*^-15, 
       16.666666666666664`}, {110., 4.313650751708682, 16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., 5.102694996447305*^-16, 
       8.333333333333332}, {110., -2.1568253758543383`, 8.049381885742235}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 5.102694996447305*^-16, 8.333333333333332}, {110., 
       1.020538999289461*^-15, 16.666666666666664`}, {
       110., -4.313650751708677, 16.09876377148447}, {
       110., -2.1568253758543383`, 8.049381885742235}, {110., 
       5.102694996447305*^-16, 8.333333333333332}}], 
      Line3DBox[{{110., 1.020538999289461*^-15, 16.666666666666664`}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -4.313650751708677, 16.09876377148447}, {
       110., 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -2.1568253758543383`, 
       8.049381885742235}, {110., -4.166666666666664, 7.216878364870323}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -2.1568253758543383`, 8.049381885742235}, {
       110., -4.313650751708677, 16.09876377148447}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -4.166666666666664, 7.216878364870323}, {
       110., -2.1568253758543383`, 8.049381885742235}}], 
      Line3DBox[{{110., -4.313650751708677, 16.09876377148447}, {
       110., -6.470476127563016, 24.148145657226706`}, {
       110., -12.499999999999995`, 21.65063509461097}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -4.313650751708677, 16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., -4.166666666666664, 
       7.216878364870323}, {110., -5.8925565098878945`, 5.892556509887896}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -4.166666666666664, 7.216878364870323}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -5.8925565098878945`, 5.892556509887896}, {
       110., -4.166666666666664, 7.216878364870323}}], 
      Line3DBox[{{110., -8.333333333333329, 14.433756729740645`}, {
       110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -8.333333333333329, 14.433756729740645`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -5.8925565098878945`, 
       5.892556509887896}, {110., -7.216878364870323, 4.166666666666666}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -5.8925565098878945`, 5.892556509887896}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -14.433756729740645`, 8.333333333333332}, {
       110., -7.216878364870323, 4.166666666666666}, {
       110., -5.8925565098878945`, 5.892556509887896}}], 
      Line3DBox[{{110., -11.785113019775789`, 11.785113019775793`}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       110., -14.433756729740645`, 8.333333333333332}, {
       110., -11.785113019775789`, 11.785113019775793`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -7.21687836487032, 
       4.16666666666667}, {110., -8.049381885742235, 2.156825375854342}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -7.21687836487032, 4.16666666666667}, {
       110., -14.43375672974064, 8.33333333333334}, {110., -16.09876377148447,
        4.313650751708684}, {110., -8.049381885742235, 2.156825375854342}, {
       110., -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{110., -14.43375672974064, 8.33333333333334}, {
       110., -21.650635094610962`, 12.500000000000009`}, {
       110., -24.148145657226706`, 6.470476127563026}, {
       110., -16.09876377148447, 4.313650751708684}, {
       110., -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{110., 0., 0.}, {110., -8.049381885742235, 
       2.156825375854342}, {110., -8.333333333333332, 
       1.020538999289461*^-15}, {110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -8.049381885742235, 2.156825375854342}, {
       110., -16.09876377148447, 4.313650751708684}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -8.333333333333332, 1.020538999289461*^-15}, {
       110., -8.049381885742235, 2.156825375854342}}], 
      Line3DBox[{{110., -16.09876377148447, 4.313650751708684}, {
       110., -24.148145657226706`, 6.470476127563026}, {110., -25., 
       3.061616997868383*^-15}, {110., -16.666666666666664`, 
       2.041077998578922*^-15}, {110., -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{110., 0., 0.}, {110., -8.333333333333332, 
       1.020538999289461*^-15}, {
       110., -8.049381885742235, -2.15682537585434}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -8.333333333333332, 1.020538999289461*^-15}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -16.09876377148447, -4.31365075170868}, {
       110., -8.049381885742235, -2.15682537585434}, {
       110., -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       110., -16.09876377148447, -4.31365075170868}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -8.049381885742235, -2.156825375854336}, {
       110., -7.216878364870323, -4.166666666666664}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -8.049381885742235, -2.156825375854336}, {
       110., -16.09876377148447, -4.313650751708672}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -7.216878364870323, -4.166666666666664}, {
       110., -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{110., -16.09876377148447, -4.313650751708672}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -7.216878364870323, -4.166666666666664}, {
       110., -5.892556509887897, -5.8925565098878945`}, {110., 0., 0.}, {110.,
        0., 0.}}], 
      Line3DBox[{{110., -7.216878364870323, -4.166666666666664}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -11.785113019775794`, -11.785113019775789`}, {
       110., -5.892556509887897, -5.8925565098878945`}, {
       110., -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{110., -14.433756729740645`, -8.333333333333329}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       110., -11.785113019775794`, -11.785113019775789`}, {
       110., -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -5.892556509887898, -5.892556509887893}, {
       110., -4.16666666666667, -7.216878364870319}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -5.892556509887898, -5.892556509887893}, {
       110., -11.785113019775796`, -11.785113019775785`}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -4.16666666666667, -7.216878364870319}, {
       110., -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{110., -11.785113019775796`, -11.785113019775785`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -4.16666666666667, -7.216878364870319}, {
       110., -2.156825375854346, -8.049381885742234}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -4.16666666666667, -7.216878364870319}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -2.156825375854346, -8.049381885742234}, {
       110., -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{110., -8.33333333333334, -14.433756729740638`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -2.156825375854346, -8.049381885742234}, {
       110., -8.932295329768568*^-15, -8.333333333333332}, {110., 0., 0.}, {
       110., 0., 0.}}], 
      Line3DBox[{{110., -2.156825375854346, -8.049381885742234}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       110., -8.932295329768568*^-15, -8.333333333333332}, {
       110., -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{110., -4.313650751708692, -16.098763771484467`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       110., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       110., -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -1.5308084989341913`*^-15, -8.333333333333332}, {110., 
       2.1568253758543356`, -8.049381885742235}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{
       110., -1.5308084989341913`*^-15, -8.333333333333332}, {
       110., -3.0616169978683826`*^-15, -16.666666666666664`}, {110., 
       4.313650751708671, -16.09876377148447}, {110., 
       2.1568253758543356`, -8.049381885742235}, {
       110., -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{110., -3.0616169978683826`*^-15, -16.666666666666664`}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {110., 
       4.313650751708671, -16.09876377148447}, {
       110., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       2.1568253758543356`, -8.049381885742235}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 2.1568253758543356`, -8.049381885742235}, {
       110., 4.313650751708671, -16.09876377148447}, {110., 
       8.333333333333321, -14.43375672974065}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{110., 4.313650751708671, -16.09876377148447}, {110., 
       6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       8.333333333333321, -14.43375672974065}, {110., 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 
       5.89255650988789, -5.892556509887903}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 4.166666666666661, -7.216878364870325}, {110.,
        8.333333333333321, -14.43375672974065}, {110., 
       11.78511301977578, -11.785113019775807`}, {110., 
       5.89255650988789, -5.892556509887903}, {110., 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{110., 8.333333333333321, -14.43375672974065}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {110., 
       11.78511301977578, -11.785113019775807`}, {110., 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       5.8925565098878945`, -5.892556509887897}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 0., 0.}, {110., 0., 
       0.}}], 
      Line3DBox[{{110., 5.8925565098878945`, -5.892556509887897}, {110., 
       11.785113019775789`, -11.785113019775794`}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{110., 11.785113019775789`, -11.785113019775794`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 7.216878364870319, -4.16666666666667}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       16.098763771484467`, -4.313650751708693}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{110., 14.433756729740638`, -8.33333333333334}, {110., 
       21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       16.098763771484467`, -4.313650751708693}, {110., 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 
       8.333333333333332, -9.442564829413298*^-15}, {110., 0., 0.}, {110., 0.,
        0.}}], Line3DBox[{{110., 8.049381885742234, -2.1568253758543463`}, {
       110., 16.098763771484467`, -4.313650751708693}, {110., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {110., 
       8.333333333333332, -9.442564829413298*^-15}, {110., 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{110., 16.098763771484467`, -4.313650751708693}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {110., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {110., 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGAQBWImIAaxcYEjVtHRWZcjHVS3d+SKmhsdwKMUDPZB1dfd
LkmQeat2IES6Y/klfx2c+mDmixvv3h9ULODAe93o0pp9hgTVP42XOOtSauBQ
wddfvM1CnqD651D1uRD1DoTUG6O6B6d6mH9roP4Nh/jXAW+4NUQ7SKYtc2WT
RIjjDTeg+rTbzAzux9UOZHQHikkp6hzAG25A9Sv7PknqRgg4VFv8jE1ZaHgA
b7gB1Z/xzPwoHWXg8O6v+VIDVvkDeMMNqP4cVP1jiHoHvOEGVH8U1T0OuMIN
pj4F6t9siH/h4ujhBgGZDhFle3WL0/Qxwhk93GDqIyUiF+w6pHzgVI4nh3C6
Bs5wg6mX31D8dl00j8M73XuWj6bp4Qw3mPpZqrV1nPE6Dpt+/34l81IKrh49
3NDVL4eoxxluMPW+qO7BH25A9eFQ/56F+NcBAE9dIqU=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAQBWJmID5iFR2ddTnSQXV7R66oudEBBijYBxWvu12SIPNW
7UCIdMfyS/46B2DqxY137w8qFnDgvW50ac0+Q7j403iJsy6lBg4VfP3F2yzk
4eLPoeK5EHEHmLgxqjkOMHtroPaGQ+x1ADuqIdpBMm2ZK5skwp0w8bTbzAzu
x9UOZHQHikkp6hyAia/s+ySpGyHgUG3xMzZloSFc/Ixn5kfpKAOHd3/Nlxqw
ysPFz0HFH0PE4fYeRTUHLp4CtTcbYi9EnCHTIaJsr25xmj6qO4HikRKRC3Yd
Uj5wKseTQzhd4wBMXH5D8dt10TwO73TvWT6apgcXn6VaW8cZr+Ow6ffvVzIv
pTDEl0PE4fb6opoDFw+H2nsWYq8DAJDtrFo=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367530055173*^9, 3.566086985800482*^9, 
  3.566101739800008*^9, 3.5661391823723373`*^9, 3.614707793151453*^9},
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->
  "During evaluation of \
In[31]:=",ExpressionUUID->"b1b87736-fe15-4098-9aab-1bb1ba1e1fba"]
}, Open  ]],

Cell[TextData[{
 "Now we use ",
 StyleBox["PlotType -> SideView", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 " to look at the rendered result from the side."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"072f6e22-85e4-42b4-8783-7cc94a7c1fd3"],

Cell[CellGroupData[{

Cell["ShowSystem[%, PlotType -> SideView];", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->"In[32]:=",ExpressionUUID->"21c87232-2508-40e4-a406-184ea43091fe"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, 0.}, {110., 6.123233995736766*^-15}, {
      110., 5.102694996447306*^-15}, {102.75044883428481`, 0.}, {
      106.4219745809556, 0.}}], 
     PolygonBox[{{102.75044883428481`, 0.}, {110., 5.102694996447306*^-15}, {
      110., 4.0821559971578446`*^-15}, {100.67375799589207`, 0.}, {
      102.75044883428481`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 0.}, {110., 
      4.0821559971578446`*^-15}, {110., 3.061616997868384*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, 0.}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 3.061616997868383*^-15}, {
      110., 2.0410779985789223`*^-15}, {100.67375799589207`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 0.}, {110., 
      2.0410779985789223`*^-15}, {110., 1.0205389992894613`*^-15}, {
      102.75044883428481`, 0.}, {100.67375799589207`, 0.}}], 
     PolygonBox[{{102.75044883428481`, 0.}, {110., 
      1.0205389992894615`*^-15}, {110., 5.098616525425841*^-31}, {
      106.4219745809556, 0.}, {102.75044883428481`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
       100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
       100.67375799589207`, 0.}, {102.7504488342848, 0.}, {106.4219745809556, 
       0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110.,
        0.}, {110., 0.}, {106.4219745809556, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
        110., -16.66666666666667}, {
        102.75044883428481`, -16.666666666666668`}, {
        106.4219745809556, -25.}}], 
       PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
        110., -16.66666666666667}, {110., -8.333333333333336}, {
        100.67375799589207`, -8.333333333333336}, {
        102.75044883428481`, -16.666666666666668`}}], 
       PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
        110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
        100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}],
        PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
        8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
        100.00000000000001`, 0.}}], 
       PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
        8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`,
         16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
       PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
        16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556,
         24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, -25.}, {
         102.75044883428481`, -16.666666666666668`}, {
         100.67375799589207`, -8.333333333333336}, {
         100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
         8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
         106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
         16.666666666666668`}, {110., 8.333333333333336}, {110., 
         3.552713678800501*^-15}, {110., -8.333333333333329}, {
         110., -16.666666666666657`}, {110., -24.999999999999993`}, {
         106.4219745809556, -25.}}]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 0.}, {
       100.67375799589207`, 2.156825375854339}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 0.}, {102.75044883428481`, 0.}, {
       102.75044883428481`, 4.313650751708678}, {100.67375799589207`, 
       2.156825375854339}, {100.67375799589207`, 0.}}], 
      LineBox[{{102.75044883428481`, 0.}, {106.4219745809556, 0.}, {
       106.4219745809556, 6.4704761275630185`}, {102.75044883428481`, 
       4.313650751708678}, {102.75044883428481`, 0.}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       2.156825375854339}, {100.67375799589209`, 4.166666666666666}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 2.156825375854339}, {102.75044883428481`,
        4.313650751708678}, {102.75044883428481`, 8.333333333333332}, {
       100.67375799589209`, 4.166666666666666}, {100.67375799589207`, 
       2.156825375854339}}], 
      LineBox[{{102.75044883428481`, 4.313650751708678}, {106.4219745809556, 
       6.4704761275630185`}, {106.4219745809556, 12.499999999999998`}, {
       102.75044883428481`, 8.333333333333332}, {102.75044883428481`, 
       4.313650751708678}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       4.166666666666666}, {100.67375799589207`, 5.8925565098878945`}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 4.166666666666666}, {102.75044883428481`,
        8.333333333333332}, {102.7504488342848, 11.785113019775789`}, {
       100.67375799589207`, 5.8925565098878945`}, {100.67375799589209`, 
       4.166666666666666}}], 
      LineBox[{{102.75044883428481`, 8.333333333333332}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 17.677669529663685`}, {
       102.7504488342848, 11.785113019775789`}, {102.75044883428481`, 
       8.333333333333332}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.8925565098878945`}, {100.67375799589209`, 7.216878364870322}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.8925565098878945`}, {102.7504488342848,
        11.785113019775789`}, {102.75044883428481`, 14.433756729740644`}, {
       100.67375799589209`, 7.216878364870322}, {100.67375799589207`, 
       5.8925565098878945`}}], 
      LineBox[{{102.7504488342848, 11.785113019775789`}, {106.4219745809556, 
       17.677669529663685`}, {106.4219745809556, 21.650635094610966`}, {
       102.75044883428481`, 14.433756729740644`}, {102.7504488342848, 
       11.785113019775789`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       7.216878364870322}, {100.67375799589207`, 8.049381885742235}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 7.216878364870322}, {102.75044883428481`,
        14.433756729740644`}, {102.75044883428481`, 16.09876377148447}, {
       100.67375799589207`, 8.049381885742235}, {100.67375799589209`, 
       7.216878364870322}}], 
      LineBox[{{102.75044883428481`, 14.433756729740644`}, {106.4219745809556,
        21.650635094610966`}, {106.4219745809556, 24.148145657226706`}, {
       102.75044883428481`, 16.09876377148447}, {102.75044883428481`, 
       14.433756729740644`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.049381885742235}, {100.67375799589207`, 8.333333333333332}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.049381885742235}, {102.75044883428481`,
        16.09876377148447}, {102.75044883428481`, 16.666666666666664`}, {
       100.67375799589207`, 8.333333333333332}, {100.67375799589207`, 
       8.049381885742235}}], 
      LineBox[{{102.75044883428481`, 16.09876377148447}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 25.}, {102.75044883428481`, 
       16.666666666666664`}, {102.75044883428481`, 16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.333333333333332}, {100.67375799589207`, 8.049381885742235}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.333333333333332}, {102.75044883428481`,
        16.666666666666664`}, {102.75044883428481`, 16.09876377148447}, {
       100.67375799589207`, 8.049381885742235}, {100.67375799589207`, 
       8.333333333333332}}], 
      LineBox[{{102.75044883428481`, 16.666666666666664`}, {106.4219745809556,
        25.}, {106.4219745809556, 24.148145657226706`}, {102.75044883428481`, 
       16.09876377148447}, {102.75044883428481`, 16.666666666666664`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.049381885742235}, {100.67375799589209`, 7.216878364870323}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.049381885742235}, {102.75044883428481`,
        16.09876377148447}, {102.75044883428481`, 14.433756729740645`}, {
       100.67375799589209`, 7.216878364870323}, {100.67375799589207`, 
       8.049381885742235}}], 
      LineBox[{{102.75044883428481`, 16.09876377148447}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 21.65063509461097}, {
       102.75044883428481`, 14.433756729740645`}, {102.75044883428481`, 
       16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       7.216878364870323}, {100.67375799589207`, 5.892556509887896}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 7.216878364870323}, {102.75044883428481`,
        14.433756729740645`}, {102.7504488342848, 11.785113019775793`}, {
       100.67375799589207`, 5.892556509887896}, {100.67375799589209`, 
       7.216878364870323}}], 
      LineBox[{{102.75044883428481`, 14.433756729740645`}, {106.4219745809556,
        21.65063509461097}, {106.4219745809556, 17.67766952966369}, {
       102.7504488342848, 11.785113019775793`}, {102.75044883428481`, 
       14.433756729740645`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.892556509887896}, {100.67375799589209`, 4.166666666666666}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.892556509887896}, {102.7504488342848, 
       11.785113019775793`}, {102.75044883428481`, 8.333333333333332}, {
       100.67375799589209`, 4.166666666666666}, {100.67375799589207`, 
       5.892556509887896}}], 
      LineBox[{{102.7504488342848, 11.785113019775793`}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 12.499999999999998`}, {
       102.75044883428481`, 8.333333333333332}, {102.7504488342848, 
       11.785113019775793`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       4.16666666666667}, {100.67375799589207`, 2.156825375854342}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 4.16666666666667}, {102.7504488342848, 
       8.33333333333334}, {102.75044883428481`, 4.313650751708684}, {
       100.67375799589207`, 2.156825375854342}, {100.67375799589209`, 
       4.16666666666667}}], 
      LineBox[{{102.7504488342848, 8.33333333333334}, {106.4219745809556, 
       12.500000000000009`}, {106.4219745809556, 6.470476127563026}, {
       102.75044883428481`, 4.313650751708684}, {102.7504488342848, 
       8.33333333333334}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       2.156825375854342}, {100.67375799589207`, 1.020538999289461*^-15}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 2.156825375854342}, {102.75044883428481`,
        4.313650751708684}, {102.75044883428481`, 2.041077998578922*^-15}, {
       100.67375799589207`, 1.020538999289461*^-15}, {100.67375799589207`, 
       2.156825375854342}}], 
      LineBox[{{102.75044883428481`, 4.313650751708684}, {106.4219745809556, 
       6.470476127563026}, {106.4219745809556, 3.061616997868383*^-15}, {
       102.75044883428481`, 2.041077998578922*^-15}, {102.75044883428481`, 
       4.313650751708684}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       1.020538999289461*^-15}, {100.67375799589207`, -2.15682537585434}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 1.020538999289461*^-15}, {
       102.75044883428481`, 2.041077998578922*^-15}, {
       102.75044883428481`, -4.31365075170868}, {
       100.67375799589207`, -2.15682537585434}, {100.67375799589207`, 
       1.020538999289461*^-15}}], 
      LineBox[{{102.75044883428481`, 2.041077998578922*^-15}, {
       106.4219745809556, 3.061616997868383*^-15}, {
       106.4219745809556, -6.47047612756302}, {
       102.75044883428481`, -4.31365075170868}, {102.75044883428481`, 
       2.041077998578922*^-15}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -2.156825375854336}, {
       100.67375799589209`, -4.166666666666664}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -2.156825375854336}, {
       102.75044883428481`, -4.313650751708672}, {
       102.75044883428481`, -8.333333333333329}, {
       100.67375799589209`, -4.166666666666664}, {
       100.67375799589207`, -2.156825375854336}}], 
      LineBox[{{102.75044883428481`, -4.313650751708672}, {
       106.4219745809556, -6.470476127563009}, {
       106.4219745809556, -12.499999999999993`}, {
       102.75044883428481`, -8.333333333333329}, {
       102.75044883428481`, -4.313650751708672}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -4.166666666666664}, {
       100.67375799589207`, -5.8925565098878945`}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -4.166666666666664}, {
       102.75044883428481`, -8.333333333333329}, {
       102.75044883428481`, -11.785113019775789`}, {
       100.67375799589207`, -5.8925565098878945`}, {
       100.67375799589209`, -4.166666666666664}}], 
      LineBox[{{102.75044883428481`, -8.333333333333329}, {
       106.4219745809556, -12.499999999999993`}, {
       106.4219745809556, -17.677669529663685`}, {
       102.75044883428481`, -11.785113019775789`}, {
       102.75044883428481`, -8.333333333333329}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -5.892556509887893}, {
       100.67375799589209`, -7.216878364870319}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -5.892556509887893}, {
       102.75044883428481`, -11.785113019775785`}, {
       102.7504488342848, -14.433756729740638`}, {
       100.67375799589209`, -7.216878364870319}, {
       100.67375799589207`, -5.892556509887893}}], 
      LineBox[{{102.75044883428481`, -11.785113019775785`}, {
       106.4219745809556, -17.677669529663678`}, {
       106.4219745809556, -21.65063509461096}, {
       102.7504488342848, -14.433756729740638`}, {
       102.75044883428481`, -11.785113019775785`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -7.216878364870319}, {
       100.67375799589207`, -8.049381885742234}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -7.216878364870319}, {
       102.7504488342848, -14.433756729740638`}, {
       102.75044883428481`, -16.098763771484467`}, {
       100.67375799589207`, -8.049381885742234}, {
       100.67375799589209`, -7.216878364870319}}], 
      LineBox[{{102.7504488342848, -14.433756729740638`}, {
       106.4219745809556, -21.65063509461096}, {
       106.4219745809556, -24.148145657226703`}, {
       102.75044883428481`, -16.098763771484467`}, {
       102.7504488342848, -14.433756729740638`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.049381885742234}, {
       100.67375799589207`, -8.333333333333332}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.049381885742234}, {
       102.75044883428481`, -16.098763771484467`}, {
       102.75044883428481`, -16.666666666666664`}, {
       100.67375799589207`, -8.333333333333332}, {
       100.67375799589207`, -8.049381885742234}}], 
      LineBox[{{102.75044883428481`, -16.098763771484467`}, {
       106.4219745809556, -24.148145657226703`}, {106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666664`}, {
       102.75044883428481`, -16.098763771484467`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.333333333333332}, {
       100.67375799589207`, -8.049381885742235}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.333333333333332}, {
       102.75044883428481`, -16.666666666666664`}, {
       102.75044883428481`, -16.09876377148447}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589207`, -8.333333333333332}}], 
      LineBox[{{102.75044883428481`, -16.666666666666664`}, {
       106.4219745809556, -25.}, {106.4219745809556, -24.14814565722671}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -16.666666666666664`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589207`, -7.216878364870325}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.049381885742235}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -14.43375672974065}, {
       100.67375799589207`, -7.216878364870325}, {
       100.67375799589207`, -8.049381885742235}}], 
      LineBox[{{102.75044883428481`, -16.09876377148447}, {
       106.4219745809556, -24.14814565722671}, {
       106.4219745809556, -21.650635094610976`}, {
       102.75044883428481`, -14.43375672974065}, {
       102.75044883428481`, -16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -7.216878364870325}, {
       100.67375799589207`, -5.892556509887903}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -7.216878364870325}, {
       102.75044883428481`, -14.43375672974065}, {
       102.75044883428481`, -11.785113019775807`}, {
       100.67375799589207`, -5.892556509887903}, {
       100.67375799589207`, -7.216878364870325}}], 
      LineBox[{{102.75044883428481`, -14.43375672974065}, {
       106.4219745809556, -21.650635094610976`}, {
       106.4219745809556, -17.67766952966371}, {
       102.75044883428481`, -11.785113019775807`}, {
       102.75044883428481`, -14.43375672974065}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -5.892556509887897}, {
       100.67375799589209`, -4.16666666666667}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -5.892556509887897}, {
       102.75044883428481`, -11.785113019775794`}, {
       102.7504488342848, -8.33333333333334}, {
       100.67375799589209`, -4.16666666666667}, {
       100.67375799589207`, -5.892556509887897}}], 
      LineBox[{{102.75044883428481`, -11.785113019775794`}, {
       106.4219745809556, -17.677669529663692`}, {
       106.4219745809556, -12.50000000000001}, {
       102.7504488342848, -8.33333333333334}, {
       102.75044883428481`, -11.785113019775794`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -4.16666666666667}, {
       100.67375799589207`, -2.1568253758543463`}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -4.16666666666667}, {
       102.7504488342848, -8.33333333333334}, {
       102.75044883428481`, -4.313650751708693}, {
       100.67375799589207`, -2.1568253758543463`}, {
       100.67375799589209`, -4.16666666666667}}], 
      LineBox[{{102.7504488342848, -8.33333333333334}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -6.470476127563039}, {
       102.75044883428481`, -4.313650751708693}, {
       102.7504488342848, -8.33333333333334}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -2.1568253758543463`}, {
       100.67375799589207`, -9.442564829413298*^-15}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -2.1568253758543463`}, {
       102.75044883428481`, -4.313650751708693}, {
       102.75044883428481`, -1.8885129658826596`*^-14}, {
       100.67375799589207`, -9.442564829413298*^-15}, {
       100.67375799589207`, -2.1568253758543463`}}], 
      LineBox[{{102.75044883428481`, -4.313650751708693}, {
       106.4219745809556, -6.470476127563039}, {
       106.4219745809556, -2.8327694488239898`*^-14}, {
       102.75044883428481`, -1.8885129658826596`*^-14}, {
       102.75044883428481`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{110., 0.}, {110., 0.}, {110., 2.156825375854339}, {110., 
       0.}, {110., 0.}}], 
      LineBox[{{110., 0.}, {110., 0.}, {110., 4.313650751708678}, {110., 
       2.156825375854339}, {110., 0.}}], 
      LineBox[{{110., 0.}, {110., 0.}, {110., 6.4704761275630185`}, {110., 
       4.313650751708678}, {110., 0.}}], 
      LineBox[{{110., 0.}, {110., 2.156825375854339}, {110., 
       4.166666666666666}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 2.156825375854339}, {110., 4.313650751708678}, {110., 
       8.333333333333332}, {110., 4.166666666666666}, {110., 
       2.156825375854339}}], 
      LineBox[{{110., 4.313650751708678}, {110., 6.4704761275630185`}, {110., 
       12.499999999999998`}, {110., 8.333333333333332}, {110., 
       4.313650751708678}}], 
      LineBox[{{110., 0.}, {110., 4.166666666666666}, {110., 
       5.8925565098878945`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 4.166666666666666}, {110., 8.333333333333332}, {110., 
       11.785113019775789`}, {110., 5.8925565098878945`}, {110., 
       4.166666666666666}}], 
      LineBox[{{110., 8.333333333333332}, {110., 12.499999999999998`}, {110., 
       17.677669529663685`}, {110., 11.785113019775789`}, {110., 
       8.333333333333332}}], 
      LineBox[{{110., 0.}, {110., 5.8925565098878945`}, {110., 
       7.216878364870322}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.8925565098878945`}, {110., 11.785113019775789`}, {
       110., 14.433756729740644`}, {110., 7.216878364870322}, {110., 
       5.8925565098878945`}}], 
      LineBox[{{110., 11.785113019775789`}, {110., 17.677669529663685`}, {
       110., 21.650635094610966`}, {110., 14.433756729740644`}, {110., 
       11.785113019775789`}}], 
      LineBox[{{110., 0.}, {110., 7.216878364870322}, {110., 
       8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 7.216878364870322}, {110., 14.433756729740644`}, {110., 
       16.09876377148447}, {110., 8.049381885742235}, {110., 
       7.216878364870322}}], 
      LineBox[{{110., 14.433756729740644`}, {110., 21.650635094610966`}, {
       110., 24.148145657226706`}, {110., 16.09876377148447}, {110., 
       14.433756729740644`}}], 
      LineBox[{{110., 0.}, {110., 8.049381885742235}, {110., 
       8.333333333333332}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.049381885742235}, {110., 16.09876377148447}, {110., 
       16.666666666666664`}, {110., 8.333333333333332}, {110., 
       8.049381885742235}}], 
      LineBox[{{110., 16.09876377148447}, {110., 24.148145657226706`}, {110., 
       25.}, {110., 16.666666666666664`}, {110., 16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., 8.333333333333332}, {110., 
       8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.333333333333332}, {110., 16.666666666666664`}, {110., 
       16.09876377148447}, {110., 8.049381885742235}, {110., 
       8.333333333333332}}], 
      LineBox[{{110., 16.666666666666664`}, {110., 25.}, {110., 
       24.148145657226706`}, {110., 16.09876377148447}, {110., 
       16.666666666666664`}}], 
      LineBox[{{110., 0.}, {110., 8.049381885742235}, {110., 
       7.216878364870323}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.049381885742235}, {110., 16.09876377148447}, {110., 
       14.433756729740645`}, {110., 7.216878364870323}, {110., 
       8.049381885742235}}], 
      LineBox[{{110., 16.09876377148447}, {110., 24.148145657226706`}, {110., 
       21.65063509461097}, {110., 14.433756729740645`}, {110., 
       16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., 7.216878364870323}, {110., 
       5.892556509887896}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 7.216878364870323}, {110., 14.433756729740645`}, {110., 
       11.785113019775793`}, {110., 5.892556509887896}, {110., 
       7.216878364870323}}], 
      LineBox[{{110., 14.433756729740645`}, {110., 21.65063509461097}, {110., 
       17.67766952966369}, {110., 11.785113019775793`}, {110., 
       14.433756729740645`}}], 
      LineBox[{{110., 0.}, {110., 5.892556509887896}, {110., 
       4.166666666666666}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.892556509887896}, {110., 11.785113019775793`}, {110., 
       8.333333333333332}, {110., 4.166666666666666}, {110., 
       5.892556509887896}}], 
      LineBox[{{110., 11.785113019775793`}, {110., 17.67766952966369}, {110., 
       12.499999999999998`}, {110., 8.333333333333332}, {110., 
       11.785113019775793`}}], 
      LineBox[{{110., 0.}, {110., 4.16666666666667}, {110., 
       2.156825375854342}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 4.16666666666667}, {110., 8.33333333333334}, {110., 
       4.313650751708684}, {110., 2.156825375854342}, {110., 
       4.16666666666667}}], 
      LineBox[{{110., 8.33333333333334}, {110., 12.500000000000009`}, {110., 
       6.470476127563026}, {110., 4.313650751708684}, {110., 
       8.33333333333334}}], 
      LineBox[{{110., 0.}, {110., 2.156825375854342}, {110., 
       1.020538999289461*^-15}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 2.156825375854342}, {110., 4.313650751708684}, {110., 
       2.041077998578922*^-15}, {110., 1.020538999289461*^-15}, {110., 
       2.156825375854342}}], 
      LineBox[{{110., 4.313650751708684}, {110., 6.470476127563026}, {110., 
       3.061616997868383*^-15}, {110., 2.041077998578922*^-15}, {110., 
       4.313650751708684}}], 
      LineBox[{{110., 0.}, {110., 1.020538999289461*^-15}, {
       110., -2.15682537585434}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 1.020538999289461*^-15}, {110., 
       2.041077998578922*^-15}, {110., -4.31365075170868}, {
       110., -2.15682537585434}, {110., 1.020538999289461*^-15}}], 
      LineBox[{{110., 2.041077998578922*^-15}, {110., 
       3.061616997868383*^-15}, {110., -6.47047612756302}, {
       110., -4.31365075170868}, {110., 2.041077998578922*^-15}}], 
      LineBox[{{110., 0.}, {110., -2.156825375854336}, {
       110., -4.166666666666664}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -2.156825375854336}, {110., -4.313650751708672}, {
       110., -8.333333333333329}, {110., -4.166666666666664}, {
       110., -2.156825375854336}}], 
      LineBox[{{110., -4.313650751708672}, {110., -6.470476127563009}, {
       110., -12.499999999999993`}, {110., -8.333333333333329}, {
       110., -4.313650751708672}}], 
      LineBox[{{110., 0.}, {110., -4.166666666666664}, {
       110., -5.8925565098878945`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -4.166666666666664}, {110., -8.333333333333329}, {
       110., -11.785113019775789`}, {110., -5.8925565098878945`}, {
       110., -4.166666666666664}}], 
      LineBox[{{110., -8.333333333333329}, {110., -12.499999999999993`}, {
       110., -17.677669529663685`}, {110., -11.785113019775789`}, {
       110., -8.333333333333329}}], 
      LineBox[{{110., 0.}, {110., -5.892556509887893}, {
       110., -7.216878364870319}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -5.892556509887893}, {110., -11.785113019775785`}, {
       110., -14.433756729740638`}, {110., -7.216878364870319}, {
       110., -5.892556509887893}}], 
      LineBox[{{110., -11.785113019775785`}, {110., -17.677669529663678`}, {
       110., -21.65063509461096}, {110., -14.433756729740638`}, {
       110., -11.785113019775785`}}], 
      LineBox[{{110., 0.}, {110., -7.216878364870319}, {
       110., -8.049381885742234}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -7.216878364870319}, {110., -14.433756729740638`}, {
       110., -16.098763771484467`}, {110., -8.049381885742234}, {
       110., -7.216878364870319}}], 
      LineBox[{{110., -14.433756729740638`}, {110., -21.65063509461096}, {
       110., -24.148145657226703`}, {110., -16.098763771484467`}, {
       110., -14.433756729740638`}}], 
      LineBox[{{110., 0.}, {110., -8.049381885742234}, {
       110., -8.333333333333332}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.049381885742234}, {110., -16.098763771484467`}, {
       110., -16.666666666666664`}, {110., -8.333333333333332}, {
       110., -8.049381885742234}}], 
      LineBox[{{110., -16.098763771484467`}, {110., -24.148145657226703`}, {
       110., -25.}, {110., -16.666666666666664`}, {
       110., -16.098763771484467`}}], 
      LineBox[{{110., 0.}, {110., -8.333333333333332}, {
       110., -8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.333333333333332}, {110., -16.666666666666664`}, {
       110., -16.09876377148447}, {110., -8.049381885742235}, {
       110., -8.333333333333332}}], 
      LineBox[{{110., -16.666666666666664`}, {110., -25.}, {
       110., -24.14814565722671}, {110., -16.09876377148447}, {
       110., -16.666666666666664`}}], 
      LineBox[{{110., 0.}, {110., -8.049381885742235}, {
       110., -7.216878364870325}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.049381885742235}, {110., -16.09876377148447}, {
       110., -14.43375672974065}, {110., -7.216878364870325}, {
       110., -8.049381885742235}}], 
      LineBox[{{110., -16.09876377148447}, {110., -24.14814565722671}, {
       110., -21.650635094610976`}, {110., -14.43375672974065}, {
       110., -16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., -7.216878364870325}, {
       110., -5.892556509887903}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -7.216878364870325}, {110., -14.43375672974065}, {
       110., -11.785113019775807`}, {110., -5.892556509887903}, {
       110., -7.216878364870325}}], 
      LineBox[{{110., -14.43375672974065}, {110., -21.650635094610976`}, {
       110., -17.67766952966371}, {110., -11.785113019775807`}, {
       110., -14.43375672974065}}], 
      LineBox[{{110., 0.}, {110., -5.892556509887897}, {
       110., -4.16666666666667}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -5.892556509887897}, {110., -11.785113019775794`}, {
       110., -8.33333333333334}, {110., -4.16666666666667}, {
       110., -5.892556509887897}}], 
      LineBox[{{110., -11.785113019775794`}, {110., -17.677669529663692`}, {
       110., -12.50000000000001}, {110., -8.33333333333334}, {
       110., -11.785113019775794`}}], 
      LineBox[{{110., 0.}, {110., -4.16666666666667}, {
       110., -2.1568253758543463`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -4.16666666666667}, {110., -8.33333333333334}, {
       110., -4.313650751708693}, {110., -2.1568253758543463`}, {
       110., -4.16666666666667}}], 
      LineBox[{{110., -8.33333333333334}, {110., -12.50000000000001}, {
       110., -6.470476127563039}, {110., -4.313650751708693}, {
       110., -8.33333333333334}}], 
      LineBox[{{110., 0.}, {110., -2.1568253758543463`}, {
       110., -9.442564829413298*^-15}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -2.1568253758543463`}, {110., -4.313650751708693}, {
       110., -1.8885129658826596`*^-14}, {110., -9.442564829413298*^-15}, {
       110., -2.1568253758543463`}}], 
      LineBox[{{110., -4.313650751708693}, {110., -6.470476127563039}, {
       110., -2.8327694488239898`*^-14}, {110., -1.8885129658826596`*^-14}, {
       110., -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 0.}, {110., 0.}, {110., 
       6.4704761275630185`}, {106.4219745809556, 6.4704761275630185`}, {
       106.4219745809556, 0.}}], 
      LineBox[{{106.4219745809556, 6.4704761275630185`}, {110., 
       6.4704761275630185`}, {110., 12.499999999999998`}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 6.4704761275630185`}}], 
      LineBox[{{106.4219745809556, 12.499999999999998`}, {110., 
       12.499999999999998`}, {110., 17.677669529663685`}, {106.4219745809556, 
       17.677669529663685`}, {106.4219745809556, 12.499999999999998`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.650635094610966`}, {106.4219745809556, 
       21.650635094610966`}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.650635094610966`}, {110., 
       21.650635094610966`}, {110., 24.148145657226706`}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 21.650635094610966`}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.499999999999998`}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000009`}, {110., 
       12.500000000000009`}, {110., 6.470476127563026}, {106.4219745809556, 
       6.470476127563026}, {106.4219745809556, 12.500000000000009`}}], 
      LineBox[{{106.4219745809556, 6.470476127563026}, {110., 
       6.470476127563026}, {110., 3.061616997868383*^-15}, {106.4219745809556,
        3.061616997868383*^-15}, {106.4219745809556, 6.470476127563026}}], 
      LineBox[{{106.4219745809556, 3.061616997868383*^-15}, {110., 
       3.061616997868383*^-15}, {110., -6.47047612756302}, {
       106.4219745809556, -6.47047612756302}, {106.4219745809556, 
       3.061616997868383*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563009}, {
       110., -6.470476127563009}, {110., -12.499999999999993`}, {
       106.4219745809556, -12.499999999999993`}, {
       106.4219745809556, -6.470476127563009}}], 
      LineBox[{{106.4219745809556, -12.499999999999993`}, {
       110., -12.499999999999993`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999993`}}], 
      LineBox[{{106.4219745809556, -17.677669529663678`}, {
       110., -17.677669529663678`}, {110., -21.65063509461096}, {
       106.4219745809556, -21.65063509461096}, {
       106.4219745809556, -17.677669529663678`}}], 
      LineBox[{{106.4219745809556, -21.65063509461096}, {
       110., -21.65063509461096}, {110., -24.148145657226703`}, {
       106.4219745809556, -24.148145657226703`}, {
       106.4219745809556, -21.65063509461096}}], 
      LineBox[{{106.4219745809556, -24.148145657226703`}, {
       110., -24.148145657226703`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226703`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.14814565722671}, {106.4219745809556, -24.14814565722671}, {
       106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.650635094610976`}, {
       106.4219745809556, -21.650635094610976`}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.650635094610976`}, {
       110., -21.650635094610976`}, {110., -17.67766952966371}, {
       106.4219745809556, -17.67766952966371}, {
       106.4219745809556, -21.650635094610976`}}], 
      LineBox[{{106.4219745809556, -17.677669529663692`}, {
       110., -17.677669529663692`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663692`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563039}, {
       106.4219745809556, -6.470476127563039}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563039}, {
       110., -6.470476127563039}, {110., -2.8327694488239898`*^-14}, {
       106.4219745809556, -2.8327694488239898`*^-14}, {
       106.4219745809556, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {103.30336650761734`, 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761726`, -14.155904040684312`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, -17.744824540531273`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, -7.805383496862866}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 7.805383496862857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 17.744824540531273`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761726`, 14.155904040684318`}}]}, 
     {Arrowheads[Small], ArrowBox[{{103.30336650761734`, 0.}, {110., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761726`, -14.155904040684312`}, {
       110., -14.06465215440194}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, -17.744824540531273`}, {
       110., -17.630437730164413`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, -7.805383496862866}, {
       110., -7.755068379919505}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 7.805383496862857}, {110., 
       7.7550683799194955`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 17.744824540531273`}, {110., 
       17.630437730164413`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761726`, 14.155904040684318`}, {110., 
       14.064652154401946`}}]}, 
     {Arrowheads[Small], ArrowBox[{{110., 0.}, {200., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -14.06465215440194}, {200., -12.201317080462463`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -17.630437730164413`}, {200., -15.294694717761526`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -7.755068379919505}, {200., -6.727649375562509}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 7.7550683799194955`}, {200., 6.727649375562499}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 17.630437730164413`}, {200., 15.294694717761526`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 14.064652154401946`}, {200., 
       12.201317080462468`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQfcQqOjrrcqQDAxTsg/JDpDuWX/LXOQCT571udGnN
PkM4v4Kvv3ibhTycnwvhO6Cpd4CZFw4xD2JPQzTcPhg/oztQTEpR5wCMX23x
MzZloSGc/+6v+VIDVnk4/zGE74CmHs7PhpgHtScT1T4g/1SOJ4dwusYBGP+d
7j3LR9P04PxNv3+/knkpBecvh/Ad0NTD+Wch5jkAAJiGZ2E=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367530219675*^9, 3.5660869859071703`*^9, 
  3.5661017404494123`*^9, 3.566139182740925*^9, 3.6147077932661257`*^9},
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->
  "During evaluation of \
In[32]:=",ExpressionUUID->"af61dccd-7843-4695-8d08-5324bb57a8b7"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["%",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " symbol feeds the output from the previous result into the expression \
input. In this example, the output from ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " of the last example has been used as input to ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 StyleBox[".",
  FontFamily->"Times New Roman"],
 " You can also view the result from the front with ",
 StyleBox["PlotType -> FrontView", "Input"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "Tracing a Cone of Rays", 
   "RG7."},ExpressionUUID->"566e4a0b-26a1-49bf-a5d6-8f6376ae9285"],

Cell[CellGroupData[{

Cell["ShowSystem[%, PlotType -> FrontView];", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->"In[33]:=",ExpressionUUID->"43392047-6d38-472c-b510-86ef1a1bb072"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{-25., 0.}, {-25., 
      6.123233995736766*^-15}, {-16.66666666666667, 
      5.102694996447306*^-15}, {-16.666666666666668`, 0.}, {-25., 0.}}], 
     PolygonBox[{{-16.666666666666668`, 0.}, {-16.66666666666667, 
      5.102694996447306*^-15}, {-8.333333333333336, 
      4.0821559971578446`*^-15}, {-8.333333333333336, 
      0.}, {-16.666666666666668`, 0.}}], 
     PolygonBox[{{-8.333333333333336, 0.}, {-8.333333333333336, 
      4.0821559971578446`*^-15}, {-7.105427357601002*^-15, 
      3.061616997868384*^-15}, {0., 0.}, {-8.333333333333336, 0.}}], 
     PolygonBox[{{0., 0.}, {0., 3.061616997868383*^-15}, {8.333333333333332, 
      2.0410779985789223`*^-15}, {8.333333333333329, 0.}, {0., 0.}}], 
     PolygonBox[{{8.333333333333329, 0.}, {8.333333333333332, 
      2.0410779985789223`*^-15}, {16.666666666666664`, 
      1.0205389992894613`*^-15}, {16.666666666666664`, 0.}, {
      8.333333333333329, 0.}}], 
     PolygonBox[{{16.666666666666664`, 0.}, {16.666666666666664`, 
      1.0205389992894615`*^-15}, {24.999999999999996`, 
      5.098616525425841*^-31}, {24.999999999999993`, 0.}, {
      16.666666666666664`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{-25., 0.}, {-16.666666666666668`, 0.}, {-8.333333333333336, 
       0.}, {-3.552713678800501*^-15, 0.}, {8.333333333333329, 0.}, {
       16.666666666666657`, 0.}, {24.999999999999993`, 0.}, {25., 0.}, {
       16.666666666666668`, 0.}, {8.333333333333336, 0.}, {
       3.552713678800501*^-15, 0.}, {-8.333333333333329, 
       0.}, {-16.666666666666657`, 0.}, {-24.999999999999993`, 0.}, {-25., 
       0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{0., -25.}, {3.061616997868383*^-15, -25.}, {
        2.551347498223653*^-15, -16.66666666666667}, {
        5.102694996447305*^-16, -16.666666666666668`}, {0., -25.}}], 
       PolygonBox[{{5.102694996447305*^-16, -16.666666666666668`}, {
        2.551347498223653*^-15, -16.66666666666667}, {
        2.0410779985789223`*^-15, -8.333333333333336}, {
        1.020538999289461*^-15, -8.333333333333336}, {
        5.102694996447305*^-16, -16.666666666666668`}}], 
       PolygonBox[{{1.020538999289461*^-15, -8.333333333333336}, {
        2.0410779985789223`*^-15, -8.333333333333336}, {
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        1.5308084989341915`*^-15, 0.}, {
        1.020538999289461*^-15, -8.333333333333336}}], 
       PolygonBox[{{1.5308084989341915`*^-15, 0.}, {1.5308084989341915`*^-15, 
        0.}, {1.0205389992894611`*^-15, 8.333333333333332}, {
        2.041077998578922*^-15, 8.333333333333329}, {1.5308084989341915`*^-15,
         0.}}], PolygonBox[{{2.041077998578922*^-15, 8.333333333333329}, {
        1.0205389992894611`*^-15, 8.333333333333332}, {5.102694996447307*^-16,
         16.666666666666664`}, {2.5513474982236525`*^-15, 
        16.666666666666664`}, {2.041077998578922*^-15, 8.333333333333329}}], 
       PolygonBox[{{2.5513474982236525`*^-15, 16.666666666666664`}, {
        5.102694996447308*^-16, 16.666666666666664`}, {
        2.5493082627129206`*^-31, 24.999999999999996`}, {
        3.0616169978683826`*^-15, 24.999999999999993`}, {
        2.5513474982236525`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{0., -25.}, {0., -16.666666666666668`}, {
         0., -8.333333333333336}, {0., -3.552713678800501*^-15}, {0., 
         8.333333333333329}, {0., 16.666666666666657`}, {0., 
         24.999999999999993`}, {0., 25.}, {0., 16.666666666666668`}, {0., 
         8.333333333333336}, {0., 3.552713678800501*^-15}, {
         0., -8.333333333333329}, {0., -16.666666666666657`}, {
         0., -24.999999999999993`}, {0., -25.}}]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 0.}, {8.333333333333332, 0.}, {8.049381885742235, 
       2.156825375854339}, {0., 0.}, {0., 0.}}], 
      LineBox[{{8.333333333333332, 0.}, {16.666666666666664`, 0.}, {
       16.09876377148447, 4.313650751708678}, {8.049381885742235, 
       2.156825375854339}, {8.333333333333332, 0.}}], 
      LineBox[{{16.666666666666664`, 0.}, {25., 0.}, {24.148145657226706`, 
       6.4704761275630185`}, {16.09876377148447, 4.313650751708678}, {
       16.666666666666664`, 0.}}], 
      LineBox[{{0., 0.}, {8.049381885742235, 2.156825375854339}, {
       7.216878364870323, 4.166666666666666}, {0., 0.}, {0., 0.}}], 
      LineBox[{{8.049381885742235, 2.156825375854339}, {16.09876377148447, 
       4.313650751708678}, {14.433756729740645`, 8.333333333333332}, {
       7.216878364870323, 4.166666666666666}, {8.049381885742235, 
       2.156825375854339}}], 
      LineBox[{{16.09876377148447, 4.313650751708678}, {24.148145657226706`, 
       6.4704761275630185`}, {21.65063509461097, 12.499999999999998`}, {
       14.433756729740645`, 8.333333333333332}, {16.09876377148447, 
       4.313650751708678}}], 
      LineBox[{{0., 0.}, {7.216878364870323, 4.166666666666666}, {
       5.892556509887896, 5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
      LineBox[{{7.216878364870323, 4.166666666666666}, {14.433756729740645`, 
       8.333333333333332}, {11.785113019775793`, 11.785113019775789`}, {
       5.892556509887896, 5.8925565098878945`}, {7.216878364870323, 
       4.166666666666666}}], 
      LineBox[{{14.433756729740645`, 8.333333333333332}, {21.65063509461097, 
       12.499999999999998`}, {17.67766952966369, 17.677669529663685`}, {
       11.785113019775793`, 11.785113019775789`}, {14.433756729740645`, 
       8.333333333333332}}], 
      LineBox[{{0., 0.}, {5.892556509887896, 5.8925565098878945`}, {
       4.166666666666668, 7.216878364870322}, {0., 0.}, {0., 0.}}], 
      LineBox[{{5.892556509887896, 5.8925565098878945`}, {11.785113019775793`,
        11.785113019775789`}, {8.333333333333336, 14.433756729740644`}, {
       4.166666666666668, 7.216878364870322}, {5.892556509887896, 
       5.8925565098878945`}}], 
      LineBox[{{11.785113019775793`, 11.785113019775789`}, {17.67766952966369,
        17.677669529663685`}, {12.500000000000004`, 21.650635094610966`}, {
       8.333333333333336, 14.433756729740644`}, {11.785113019775793`, 
       11.785113019775789`}}], 
      LineBox[{{0., 0.}, {4.166666666666668, 7.216878364870322}, {
       2.156825375854341, 8.049381885742235}, {0., 0.}, {0., 0.}}], 
      LineBox[{{4.166666666666668, 7.216878364870322}, {8.333333333333336, 
       14.433756729740644`}, {4.313650751708682, 16.09876377148447}, {
       2.156825375854341, 8.049381885742235}, {4.166666666666668, 
       7.216878364870322}}], 
      LineBox[{{8.333333333333336, 14.433756729740644`}, {12.500000000000004`,
        21.650635094610966`}, {6.470476127563024, 24.148145657226706`}, {
       4.313650751708682, 16.09876377148447}, {8.333333333333336, 
       14.433756729740644`}}], 
      LineBox[{{0., 0.}, {2.156825375854341, 8.049381885742235}, {
       2.3606412073533245`*^-15, 8.333333333333332}, {0., 0.}, {0., 0.}}], 
      LineBox[{{2.156825375854341, 8.049381885742235}, {4.313650751708682, 
       16.09876377148447}, {4.721282414706649*^-15, 16.666666666666664`}, {
       2.3606412073533245`*^-15, 8.333333333333332}, {2.156825375854341, 
       8.049381885742235}}], 
      LineBox[{{4.313650751708682, 16.09876377148447}, {6.470476127563024, 
       24.148145657226706`}, {7.0819236220599744`*^-15, 25.}, {
       4.721282414706649*^-15, 16.666666666666664`}, {4.313650751708682, 
       16.09876377148447}}], 
      LineBox[{{0., 0.}, {5.102694996447305*^-16, 
       8.333333333333332}, {-2.1568253758543383`, 8.049381885742235}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{5.102694996447305*^-16, 8.333333333333332}, {
       1.020538999289461*^-15, 16.666666666666664`}, {-4.313650751708677, 
       16.09876377148447}, {-2.1568253758543383`, 8.049381885742235}, {
       5.102694996447305*^-16, 8.333333333333332}}], 
      LineBox[{{1.020538999289461*^-15, 16.666666666666664`}, {
       1.5308084989341915`*^-15, 25.}, {-6.470476127563016, 
       24.148145657226706`}, {-4.313650751708677, 16.09876377148447}, {
       1.020538999289461*^-15, 16.666666666666664`}}], 
      LineBox[{{0., 0.}, {-2.1568253758543383`, 
       8.049381885742235}, {-4.166666666666664, 7.216878364870323}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-2.1568253758543383`, 8.049381885742235}, {-4.313650751708677,
        16.09876377148447}, {-8.333333333333329, 
       14.433756729740645`}, {-4.166666666666664, 
       7.216878364870323}, {-2.1568253758543383`, 8.049381885742235}}], 
      LineBox[{{-4.313650751708677, 16.09876377148447}, {-6.470476127563016, 
       24.148145657226706`}, {-12.499999999999995`, 
       21.65063509461097}, {-8.333333333333329, 
       14.433756729740645`}, {-4.313650751708677, 16.09876377148447}}], 
      LineBox[{{0., 0.}, {-4.166666666666664, 
       7.216878364870323}, {-5.8925565098878945`, 5.892556509887896}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-4.166666666666664, 7.216878364870323}, {-8.333333333333329, 
       14.433756729740645`}, {-11.785113019775789`, 
       11.785113019775793`}, {-5.8925565098878945`, 
       5.892556509887896}, {-4.166666666666664, 7.216878364870323}}], 
      LineBox[{{-8.333333333333329, 
       14.433756729740645`}, {-12.499999999999995`, 
       21.65063509461097}, {-17.677669529663685`, 
       17.67766952966369}, {-11.785113019775789`, 
       11.785113019775793`}, {-8.333333333333329, 14.433756729740645`}}], 
      LineBox[{{0., 0.}, {-5.8925565098878945`, 
       5.892556509887896}, {-7.216878364870323, 4.166666666666666}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-5.8925565098878945`, 
       5.892556509887896}, {-11.785113019775789`, 
       11.785113019775793`}, {-14.433756729740645`, 
       8.333333333333332}, {-7.216878364870323, 
       4.166666666666666}, {-5.8925565098878945`, 5.892556509887896}}], 
      LineBox[{{-11.785113019775789`, 
       11.785113019775793`}, {-17.677669529663685`, 
       17.67766952966369}, {-21.65063509461097, 
       12.499999999999998`}, {-14.433756729740645`, 
       8.333333333333332}, {-11.785113019775789`, 11.785113019775793`}}], 
      LineBox[{{0., 0.}, {-7.21687836487032, 
       4.16666666666667}, {-8.049381885742235, 2.156825375854342}, {0., 0.}, {
       0., 0.}}], 
      LineBox[{{-7.21687836487032, 4.16666666666667}, {-14.43375672974064, 
       8.33333333333334}, {-16.09876377148447, 
       4.313650751708684}, {-8.049381885742235, 
       2.156825375854342}, {-7.21687836487032, 4.16666666666667}}], 
      LineBox[{{-14.43375672974064, 8.33333333333334}, {-21.650635094610962`, 
       12.500000000000009`}, {-24.148145657226706`, 
       6.470476127563026}, {-16.09876377148447, 
       4.313650751708684}, {-14.43375672974064, 8.33333333333334}}], 
      LineBox[{{0., 0.}, {-8.049381885742235, 
       2.156825375854342}, {-8.333333333333332, 1.020538999289461*^-15}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-8.049381885742235, 2.156825375854342}, {-16.09876377148447, 
       4.313650751708684}, {-16.666666666666664`, 
       2.041077998578922*^-15}, {-8.333333333333332, 
       1.020538999289461*^-15}, {-8.049381885742235, 2.156825375854342}}], 
      LineBox[{{-16.09876377148447, 4.313650751708684}, {-24.148145657226706`,
        6.470476127563026}, {-25., 
       3.061616997868383*^-15}, {-16.666666666666664`, 
       2.041077998578922*^-15}, {-16.09876377148447, 4.313650751708684}}], 
      LineBox[{{0., 0.}, {-8.333333333333332, 
       1.020538999289461*^-15}, {-8.049381885742235, -2.15682537585434}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-8.333333333333332, 
       1.020538999289461*^-15}, {-16.666666666666664`, 
       2.041077998578922*^-15}, {-16.09876377148447, -4.31365075170868}, \
{-8.049381885742235, -2.15682537585434}, {-8.333333333333332, 
       1.020538999289461*^-15}}], 
      LineBox[{{-16.666666666666664`, 2.041077998578922*^-15}, {-25., 
       3.061616997868383*^-15}, {-24.148145657226706`, -6.47047612756302}, \
{-16.09876377148447, -4.31365075170868}, {-16.666666666666664`, 
       2.041077998578922*^-15}}], 
      LineBox[{{0., 
       0.}, {-8.049381885742235, -2.156825375854336}, {-7.216878364870323, \
-4.166666666666664}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-8.049381885742235, -2.156825375854336}, {-16.09876377148447, \
-4.313650751708672}, {-14.433756729740645`, -8.333333333333329}, \
{-7.216878364870323, -4.166666666666664}, {-8.049381885742235, \
-2.156825375854336}}], 
      LineBox[{{-16.09876377148447, -4.313650751708672}, {-24.14814565722671, \
-6.470476127563009}, {-21.65063509461097, -12.499999999999993`}, \
{-14.433756729740645`, -8.333333333333329}, {-16.09876377148447, \
-4.313650751708672}}], 
      LineBox[{{0., 
       0.}, {-7.216878364870323, -4.166666666666664}, {-5.892556509887897, \
-5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-7.216878364870323, -4.166666666666664}, \
{-14.433756729740645`, -8.333333333333329}, {-11.785113019775794`, \
-11.785113019775789`}, {-5.892556509887897, -5.8925565098878945`}, \
{-7.216878364870323, -4.166666666666664}}], 
      LineBox[{{-14.433756729740645`, -8.333333333333329}, \
{-21.65063509461097, -12.499999999999993`}, {-17.677669529663692`, \
-17.677669529663685`}, {-11.785113019775794`, -11.785113019775789`}, \
{-14.433756729740645`, -8.333333333333329}}], 
      LineBox[{{0., 
       0.}, {-5.892556509887898, -5.892556509887893}, {-4.16666666666667, \
-7.216878364870319}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-5.892556509887898, -5.892556509887893}, \
{-11.785113019775796`, -11.785113019775785`}, {-8.33333333333334, \
-14.433756729740638`}, {-4.16666666666667, -7.216878364870319}, \
{-5.892556509887898, -5.892556509887893}}], 
      LineBox[{{-11.785113019775796`, -11.785113019775785`}, \
{-17.677669529663696`, -17.677669529663678`}, {-12.50000000000001, \
-21.65063509461096}, {-8.33333333333334, -14.433756729740638`}, \
{-11.785113019775796`, -11.785113019775785`}}], 
      LineBox[{{0., 
       0.}, {-4.16666666666667, -7.216878364870319}, {-2.156825375854346, \
-8.049381885742234}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-4.16666666666667, -7.216878364870319}, {-8.33333333333334, \
-14.433756729740638`}, {-4.313650751708692, -16.098763771484467`}, \
{-2.156825375854346, -8.049381885742234}, {-4.16666666666667, \
-7.216878364870319}}], 
      LineBox[{{-8.33333333333334, -14.433756729740638`}, \
{-12.50000000000001, -21.65063509461096}, {-6.470476127563038, \
-24.148145657226703`}, {-4.313650751708692, -16.098763771484467`}, \
{-8.33333333333334, -14.433756729740638`}}], 
      LineBox[{{0., 
       0.}, {-2.156825375854346, -8.049381885742234}, \
{-8.932295329768568*^-15, -8.333333333333332}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-2.156825375854346, -8.049381885742234}, {-4.313650751708692, \
-16.098763771484467`}, {-1.7864590659537137`*^-14, -16.666666666666664`}, \
{-8.932295329768568*^-15, -8.333333333333332}, {-2.156825375854346, \
-8.049381885742234}}], 
      LineBox[{{-4.313650751708692, -16.098763771484467`}, \
{-6.470476127563038, -24.148145657226703`}, {-2.6796885989305705`*^-14, \
-25.}, {-1.7864590659537137`*^-14, -16.666666666666664`}, \
{-4.313650751708692, -16.098763771484467`}}], 
      LineBox[{{0., 0.}, {-1.5308084989341913`*^-15, -8.333333333333332}, {
       2.1568253758543356`, -8.049381885742235}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-1.5308084989341913`*^-15, -8.333333333333332}, \
{-3.0616169978683826`*^-15, -16.666666666666664`}, {
       4.313650751708671, -16.09876377148447}, {
       2.1568253758543356`, -8.049381885742235}, {-1.5308084989341913`*^-15, \
-8.333333333333332}}], 
      LineBox[{{-3.0616169978683826`*^-15, -16.666666666666664`}, \
{-4.592425496802574*^-15, -25.}, {6.470476127563007, -24.14814565722671}, {
       4.313650751708671, -16.09876377148447}, {-3.0616169978683826`*^-15, \
-16.666666666666664`}}], 
      LineBox[{{0., 0.}, {2.1568253758543356`, -8.049381885742235}, {
       4.166666666666661, -7.216878364870325}, {0., 0.}, {0., 0.}}], 
      LineBox[{{2.1568253758543356`, -8.049381885742235}, {
       4.313650751708671, -16.09876377148447}, {
       8.333333333333321, -14.43375672974065}, {
       4.166666666666661, -7.216878364870325}, {
       2.1568253758543356`, -8.049381885742235}}], 
      LineBox[{{4.313650751708671, -16.09876377148447}, {
       6.470476127563007, -24.14814565722671}, {
       12.499999999999984`, -21.650635094610976`}, {
       8.333333333333321, -14.43375672974065}, {
       4.313650751708671, -16.09876377148447}}], 
      LineBox[{{0., 0.}, {4.166666666666661, -7.216878364870325}, {
       5.89255650988789, -5.892556509887903}, {0., 0.}, {0., 0.}}], 
      LineBox[{{4.166666666666661, -7.216878364870325}, {
       8.333333333333321, -14.43375672974065}, {
       11.78511301977578, -11.785113019775807`}, {
       5.89255650988789, -5.892556509887903}, {
       4.166666666666661, -7.216878364870325}}], 
      LineBox[{{8.333333333333321, -14.43375672974065}, {
       12.499999999999984`, -21.650635094610976`}, {
       17.67766952966367, -17.67766952966371}, {
       11.78511301977578, -11.785113019775807`}, {
       8.333333333333321, -14.43375672974065}}], 
      LineBox[{{0., 0.}, {5.8925565098878945`, -5.892556509887897}, {
       7.216878364870319, -4.16666666666667}, {0., 0.}, {0., 0.}}], 
      LineBox[{{5.8925565098878945`, -5.892556509887897}, {
       11.785113019775789`, -11.785113019775794`}, {
       14.433756729740638`, -8.33333333333334}, {
       7.216878364870319, -4.16666666666667}, {
       5.8925565098878945`, -5.892556509887897}}], 
      LineBox[{{11.785113019775789`, -11.785113019775794`}, {
       17.677669529663685`, -17.677669529663692`}, {
       21.65063509461096, -12.50000000000001}, {
       14.433756729740638`, -8.33333333333334}, {
       11.785113019775789`, -11.785113019775794`}}], 
      LineBox[{{0., 0.}, {7.216878364870319, -4.16666666666667}, {
       8.049381885742234, -2.1568253758543463`}, {0., 0.}, {0., 0.}}], 
      LineBox[{{7.216878364870319, -4.16666666666667}, {
       14.433756729740638`, -8.33333333333334}, {
       16.098763771484467`, -4.313650751708693}, {
       8.049381885742234, -2.1568253758543463`}, {
       7.216878364870319, -4.16666666666667}}], 
      LineBox[{{14.433756729740638`, -8.33333333333334}, {
       21.65063509461096, -12.50000000000001}, {
       24.148145657226703`, -6.470476127563039}, {
       16.098763771484467`, -4.313650751708693}, {
       14.433756729740638`, -8.33333333333334}}], 
      LineBox[{{0., 0.}, {8.049381885742234, -2.1568253758543463`}, {
       8.333333333333332, -9.442564829413298*^-15}, {0., 0.}, {0., 0.}}], 
      LineBox[{{8.049381885742234, -2.1568253758543463`}, {
       16.098763771484467`, -4.313650751708693}, {
       16.666666666666664`, -1.8885129658826596`*^-14}, {
       8.333333333333332, -9.442564829413298*^-15}, {
       8.049381885742234, -2.1568253758543463`}}], 
      LineBox[{{16.098763771484467`, -4.313650751708693}, {
       24.148145657226703`, -6.470476127563039}, {
       25., -2.8327694488239898`*^-14}, {
       16.666666666666664`, -1.8885129658826596`*^-14}, {
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 0.}, {8.333333333333332, 0.}, {8.049381885742235, 
       2.156825375854339}, {0., 0.}, {0., 0.}}], 
      LineBox[{{8.333333333333332, 0.}, {16.666666666666664`, 0.}, {
       16.09876377148447, 4.313650751708678}, {8.049381885742235, 
       2.156825375854339}, {8.333333333333332, 0.}}], 
      LineBox[{{16.666666666666664`, 0.}, {25., 0.}, {24.148145657226706`, 
       6.4704761275630185`}, {16.09876377148447, 4.313650751708678}, {
       16.666666666666664`, 0.}}], 
      LineBox[{{0., 0.}, {8.049381885742235, 2.156825375854339}, {
       7.216878364870323, 4.166666666666666}, {0., 0.}, {0., 0.}}], 
      LineBox[{{8.049381885742235, 2.156825375854339}, {16.09876377148447, 
       4.313650751708678}, {14.433756729740645`, 8.333333333333332}, {
       7.216878364870323, 4.166666666666666}, {8.049381885742235, 
       2.156825375854339}}], 
      LineBox[{{16.09876377148447, 4.313650751708678}, {24.148145657226706`, 
       6.4704761275630185`}, {21.65063509461097, 12.499999999999998`}, {
       14.433756729740645`, 8.333333333333332}, {16.09876377148447, 
       4.313650751708678}}], 
      LineBox[{{0., 0.}, {7.216878364870323, 4.166666666666666}, {
       5.892556509887896, 5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
      LineBox[{{7.216878364870323, 4.166666666666666}, {14.433756729740645`, 
       8.333333333333332}, {11.785113019775793`, 11.785113019775789`}, {
       5.892556509887896, 5.8925565098878945`}, {7.216878364870323, 
       4.166666666666666}}], 
      LineBox[{{14.433756729740645`, 8.333333333333332}, {21.65063509461097, 
       12.499999999999998`}, {17.67766952966369, 17.677669529663685`}, {
       11.785113019775793`, 11.785113019775789`}, {14.433756729740645`, 
       8.333333333333332}}], 
      LineBox[{{0., 0.}, {5.892556509887896, 5.8925565098878945`}, {
       4.166666666666668, 7.216878364870322}, {0., 0.}, {0., 0.}}], 
      LineBox[{{5.892556509887896, 5.8925565098878945`}, {11.785113019775793`,
        11.785113019775789`}, {8.333333333333336, 14.433756729740644`}, {
       4.166666666666668, 7.216878364870322}, {5.892556509887896, 
       5.8925565098878945`}}], 
      LineBox[{{11.785113019775793`, 11.785113019775789`}, {17.67766952966369,
        17.677669529663685`}, {12.500000000000004`, 21.650635094610966`}, {
       8.333333333333336, 14.433756729740644`}, {11.785113019775793`, 
       11.785113019775789`}}], 
      LineBox[{{0., 0.}, {4.166666666666668, 7.216878364870322}, {
       2.156825375854341, 8.049381885742235}, {0., 0.}, {0., 0.}}], 
      LineBox[{{4.166666666666668, 7.216878364870322}, {8.333333333333336, 
       14.433756729740644`}, {4.313650751708682, 16.09876377148447}, {
       2.156825375854341, 8.049381885742235}, {4.166666666666668, 
       7.216878364870322}}], 
      LineBox[{{8.333333333333336, 14.433756729740644`}, {12.500000000000004`,
        21.650635094610966`}, {6.470476127563024, 24.148145657226706`}, {
       4.313650751708682, 16.09876377148447}, {8.333333333333336, 
       14.433756729740644`}}], 
      LineBox[{{0., 0.}, {2.156825375854341, 8.049381885742235}, {
       2.3606412073533245`*^-15, 8.333333333333332}, {0., 0.}, {0., 0.}}], 
      LineBox[{{2.156825375854341, 8.049381885742235}, {4.313650751708682, 
       16.09876377148447}, {4.721282414706649*^-15, 16.666666666666664`}, {
       2.3606412073533245`*^-15, 8.333333333333332}, {2.156825375854341, 
       8.049381885742235}}], 
      LineBox[{{4.313650751708682, 16.09876377148447}, {6.470476127563024, 
       24.148145657226706`}, {7.0819236220599744`*^-15, 25.}, {
       4.721282414706649*^-15, 16.666666666666664`}, {4.313650751708682, 
       16.09876377148447}}], 
      LineBox[{{0., 0.}, {5.102694996447305*^-16, 
       8.333333333333332}, {-2.1568253758543383`, 8.049381885742235}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{5.102694996447305*^-16, 8.333333333333332}, {
       1.020538999289461*^-15, 16.666666666666664`}, {-4.313650751708677, 
       16.09876377148447}, {-2.1568253758543383`, 8.049381885742235}, {
       5.102694996447305*^-16, 8.333333333333332}}], 
      LineBox[{{1.020538999289461*^-15, 16.666666666666664`}, {
       1.5308084989341915`*^-15, 25.}, {-6.470476127563016, 
       24.148145657226706`}, {-4.313650751708677, 16.09876377148447}, {
       1.020538999289461*^-15, 16.666666666666664`}}], 
      LineBox[{{0., 0.}, {-2.1568253758543383`, 
       8.049381885742235}, {-4.166666666666664, 7.216878364870323}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-2.1568253758543383`, 8.049381885742235}, {-4.313650751708677,
        16.09876377148447}, {-8.333333333333329, 
       14.433756729740645`}, {-4.166666666666664, 
       7.216878364870323}, {-2.1568253758543383`, 8.049381885742235}}], 
      LineBox[{{-4.313650751708677, 16.09876377148447}, {-6.470476127563016, 
       24.148145657226706`}, {-12.499999999999995`, 
       21.65063509461097}, {-8.333333333333329, 
       14.433756729740645`}, {-4.313650751708677, 16.09876377148447}}], 
      LineBox[{{0., 0.}, {-4.166666666666664, 
       7.216878364870323}, {-5.8925565098878945`, 5.892556509887896}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-4.166666666666664, 7.216878364870323}, {-8.333333333333329, 
       14.433756729740645`}, {-11.785113019775789`, 
       11.785113019775793`}, {-5.8925565098878945`, 
       5.892556509887896}, {-4.166666666666664, 7.216878364870323}}], 
      LineBox[{{-8.333333333333329, 
       14.433756729740645`}, {-12.499999999999995`, 
       21.65063509461097}, {-17.677669529663685`, 
       17.67766952966369}, {-11.785113019775789`, 
       11.785113019775793`}, {-8.333333333333329, 14.433756729740645`}}], 
      LineBox[{{0., 0.}, {-5.8925565098878945`, 
       5.892556509887896}, {-7.216878364870323, 4.166666666666666}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-5.8925565098878945`, 
       5.892556509887896}, {-11.785113019775789`, 
       11.785113019775793`}, {-14.433756729740645`, 
       8.333333333333332}, {-7.216878364870323, 
       4.166666666666666}, {-5.8925565098878945`, 5.892556509887896}}], 
      LineBox[{{-11.785113019775789`, 
       11.785113019775793`}, {-17.677669529663685`, 
       17.67766952966369}, {-21.65063509461097, 
       12.499999999999998`}, {-14.433756729740645`, 
       8.333333333333332}, {-11.785113019775789`, 11.785113019775793`}}], 
      LineBox[{{0., 0.}, {-7.21687836487032, 
       4.16666666666667}, {-8.049381885742235, 2.156825375854342}, {0., 0.}, {
       0., 0.}}], 
      LineBox[{{-7.21687836487032, 4.16666666666667}, {-14.43375672974064, 
       8.33333333333334}, {-16.09876377148447, 
       4.313650751708684}, {-8.049381885742235, 
       2.156825375854342}, {-7.21687836487032, 4.16666666666667}}], 
      LineBox[{{-14.43375672974064, 8.33333333333334}, {-21.650635094610962`, 
       12.500000000000009`}, {-24.148145657226706`, 
       6.470476127563026}, {-16.09876377148447, 
       4.313650751708684}, {-14.43375672974064, 8.33333333333334}}], 
      LineBox[{{0., 0.}, {-8.049381885742235, 
       2.156825375854342}, {-8.333333333333332, 1.020538999289461*^-15}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-8.049381885742235, 2.156825375854342}, {-16.09876377148447, 
       4.313650751708684}, {-16.666666666666664`, 
       2.041077998578922*^-15}, {-8.333333333333332, 
       1.020538999289461*^-15}, {-8.049381885742235, 2.156825375854342}}], 
      LineBox[{{-16.09876377148447, 4.313650751708684}, {-24.148145657226706`,
        6.470476127563026}, {-25., 
       3.061616997868383*^-15}, {-16.666666666666664`, 
       2.041077998578922*^-15}, {-16.09876377148447, 4.313650751708684}}], 
      LineBox[{{0., 0.}, {-8.333333333333332, 
       1.020538999289461*^-15}, {-8.049381885742235, -2.15682537585434}, {0., 
       0.}, {0., 0.}}], 
      LineBox[{{-8.333333333333332, 
       1.020538999289461*^-15}, {-16.666666666666664`, 
       2.041077998578922*^-15}, {-16.09876377148447, -4.31365075170868}, \
{-8.049381885742235, -2.15682537585434}, {-8.333333333333332, 
       1.020538999289461*^-15}}], 
      LineBox[{{-16.666666666666664`, 2.041077998578922*^-15}, {-25., 
       3.061616997868383*^-15}, {-24.148145657226706`, -6.47047612756302}, \
{-16.09876377148447, -4.31365075170868}, {-16.666666666666664`, 
       2.041077998578922*^-15}}], 
      LineBox[{{0., 
       0.}, {-8.049381885742235, -2.156825375854336}, {-7.216878364870323, \
-4.166666666666664}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-8.049381885742235, -2.156825375854336}, {-16.09876377148447, \
-4.313650751708672}, {-14.433756729740645`, -8.333333333333329}, \
{-7.216878364870323, -4.166666666666664}, {-8.049381885742235, \
-2.156825375854336}}], 
      LineBox[{{-16.09876377148447, -4.313650751708672}, {-24.14814565722671, \
-6.470476127563009}, {-21.65063509461097, -12.499999999999993`}, \
{-14.433756729740645`, -8.333333333333329}, {-16.09876377148447, \
-4.313650751708672}}], 
      LineBox[{{0., 
       0.}, {-7.216878364870323, -4.166666666666664}, {-5.892556509887897, \
-5.8925565098878945`}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-7.216878364870323, -4.166666666666664}, \
{-14.433756729740645`, -8.333333333333329}, {-11.785113019775794`, \
-11.785113019775789`}, {-5.892556509887897, -5.8925565098878945`}, \
{-7.216878364870323, -4.166666666666664}}], 
      LineBox[{{-14.433756729740645`, -8.333333333333329}, \
{-21.65063509461097, -12.499999999999993`}, {-17.677669529663692`, \
-17.677669529663685`}, {-11.785113019775794`, -11.785113019775789`}, \
{-14.433756729740645`, -8.333333333333329}}], 
      LineBox[{{0., 
       0.}, {-5.892556509887898, -5.892556509887893}, {-4.16666666666667, \
-7.216878364870319}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-5.892556509887898, -5.892556509887893}, \
{-11.785113019775796`, -11.785113019775785`}, {-8.33333333333334, \
-14.433756729740638`}, {-4.16666666666667, -7.216878364870319}, \
{-5.892556509887898, -5.892556509887893}}], 
      LineBox[{{-11.785113019775796`, -11.785113019775785`}, \
{-17.677669529663696`, -17.677669529663678`}, {-12.50000000000001, \
-21.65063509461096}, {-8.33333333333334, -14.433756729740638`}, \
{-11.785113019775796`, -11.785113019775785`}}], 
      LineBox[{{0., 
       0.}, {-4.16666666666667, -7.216878364870319}, {-2.156825375854346, \
-8.049381885742234}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-4.16666666666667, -7.216878364870319}, {-8.33333333333334, \
-14.433756729740638`}, {-4.313650751708692, -16.098763771484467`}, \
{-2.156825375854346, -8.049381885742234}, {-4.16666666666667, \
-7.216878364870319}}], 
      LineBox[{{-8.33333333333334, -14.433756729740638`}, \
{-12.50000000000001, -21.65063509461096}, {-6.470476127563038, \
-24.148145657226703`}, {-4.313650751708692, -16.098763771484467`}, \
{-8.33333333333334, -14.433756729740638`}}], 
      LineBox[{{0., 
       0.}, {-2.156825375854346, -8.049381885742234}, \
{-8.932295329768568*^-15, -8.333333333333332}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-2.156825375854346, -8.049381885742234}, {-4.313650751708692, \
-16.098763771484467`}, {-1.7864590659537137`*^-14, -16.666666666666664`}, \
{-8.932295329768568*^-15, -8.333333333333332}, {-2.156825375854346, \
-8.049381885742234}}], 
      LineBox[{{-4.313650751708692, -16.098763771484467`}, \
{-6.470476127563038, -24.148145657226703`}, {-2.6796885989305705`*^-14, \
-25.}, {-1.7864590659537137`*^-14, -16.666666666666664`}, \
{-4.313650751708692, -16.098763771484467`}}], 
      LineBox[{{0., 0.}, {-1.5308084989341913`*^-15, -8.333333333333332}, {
       2.1568253758543356`, -8.049381885742235}, {0., 0.}, {0., 0.}}], 
      LineBox[{{-1.5308084989341913`*^-15, -8.333333333333332}, \
{-3.0616169978683826`*^-15, -16.666666666666664`}, {
       4.313650751708671, -16.09876377148447}, {
       2.1568253758543356`, -8.049381885742235}, {-1.5308084989341913`*^-15, \
-8.333333333333332}}], 
      LineBox[{{-3.0616169978683826`*^-15, -16.666666666666664`}, \
{-4.592425496802574*^-15, -25.}, {6.470476127563007, -24.14814565722671}, {
       4.313650751708671, -16.09876377148447}, {-3.0616169978683826`*^-15, \
-16.666666666666664`}}], 
      LineBox[{{0., 0.}, {2.1568253758543356`, -8.049381885742235}, {
       4.166666666666661, -7.216878364870325}, {0., 0.}, {0., 0.}}], 
      LineBox[{{2.1568253758543356`, -8.049381885742235}, {
       4.313650751708671, -16.09876377148447}, {
       8.333333333333321, -14.43375672974065}, {
       4.166666666666661, -7.216878364870325}, {
       2.1568253758543356`, -8.049381885742235}}], 
      LineBox[{{4.313650751708671, -16.09876377148447}, {
       6.470476127563007, -24.14814565722671}, {
       12.499999999999984`, -21.650635094610976`}, {
       8.333333333333321, -14.43375672974065}, {
       4.313650751708671, -16.09876377148447}}], 
      LineBox[{{0., 0.}, {4.166666666666661, -7.216878364870325}, {
       5.89255650988789, -5.892556509887903}, {0., 0.}, {0., 0.}}], 
      LineBox[{{4.166666666666661, -7.216878364870325}, {
       8.333333333333321, -14.43375672974065}, {
       11.78511301977578, -11.785113019775807`}, {
       5.89255650988789, -5.892556509887903}, {
       4.166666666666661, -7.216878364870325}}], 
      LineBox[{{8.333333333333321, -14.43375672974065}, {
       12.499999999999984`, -21.650635094610976`}, {
       17.67766952966367, -17.67766952966371}, {
       11.78511301977578, -11.785113019775807`}, {
       8.333333333333321, -14.43375672974065}}], 
      LineBox[{{0., 0.}, {5.8925565098878945`, -5.892556509887897}, {
       7.216878364870319, -4.16666666666667}, {0., 0.}, {0., 0.}}], 
      LineBox[{{5.8925565098878945`, -5.892556509887897}, {
       11.785113019775789`, -11.785113019775794`}, {
       14.433756729740638`, -8.33333333333334}, {
       7.216878364870319, -4.16666666666667}, {
       5.8925565098878945`, -5.892556509887897}}], 
      LineBox[{{11.785113019775789`, -11.785113019775794`}, {
       17.677669529663685`, -17.677669529663692`}, {
       21.65063509461096, -12.50000000000001}, {
       14.433756729740638`, -8.33333333333334}, {
       11.785113019775789`, -11.785113019775794`}}], 
      LineBox[{{0., 0.}, {7.216878364870319, -4.16666666666667}, {
       8.049381885742234, -2.1568253758543463`}, {0., 0.}, {0., 0.}}], 
      LineBox[{{7.216878364870319, -4.16666666666667}, {
       14.433756729740638`, -8.33333333333334}, {
       16.098763771484467`, -4.313650751708693}, {
       8.049381885742234, -2.1568253758543463`}, {
       7.216878364870319, -4.16666666666667}}], 
      LineBox[{{14.433756729740638`, -8.33333333333334}, {
       21.65063509461096, -12.50000000000001}, {
       24.148145657226703`, -6.470476127563039}, {
       16.098763771484467`, -4.313650751708693}, {
       14.433756729740638`, -8.33333333333334}}], 
      LineBox[{{0., 0.}, {8.049381885742234, -2.1568253758543463`}, {
       8.333333333333332, -9.442564829413298*^-15}, {0., 0.}, {0., 0.}}], 
      LineBox[{{8.049381885742234, -2.1568253758543463`}, {
       16.098763771484467`, -4.313650751708693}, {
       16.666666666666664`, -1.8885129658826596`*^-14}, {
       8.333333333333332, -9.442564829413298*^-15}, {
       8.049381885742234, -2.1568253758543463`}}], 
      LineBox[{{16.098763771484467`, -4.313650751708693}, {
       24.148145657226703`, -6.470476127563039}, {
       25., -2.8327694488239898`*^-14}, {
       16.666666666666664`, -1.8885129658826596`*^-14}, {
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{25., 0.}, {25., 0.}, {24.148145657226706`, 
       6.4704761275630185`}, {24.148145657226706`, 6.4704761275630185`}, {25.,
        0.}}], LineBox[{{24.148145657226706`, 6.4704761275630185`}, {
       24.148145657226706`, 6.4704761275630185`}, {21.65063509461097, 
       12.499999999999998`}, {21.65063509461097, 12.499999999999998`}, {
       24.148145657226706`, 6.4704761275630185`}}], 
      LineBox[{{21.65063509461097, 12.499999999999998`}, {21.65063509461097, 
       12.499999999999998`}, {17.67766952966369, 17.677669529663685`}, {
       17.67766952966369, 17.677669529663685`}, {21.65063509461097, 
       12.499999999999998`}}], 
      LineBox[{{17.67766952966369, 17.677669529663685`}, {17.67766952966369, 
       17.677669529663685`}, {12.500000000000004`, 21.650635094610966`}, {
       12.500000000000004`, 21.650635094610966`}, {17.67766952966369, 
       17.677669529663685`}}], 
      LineBox[{{12.500000000000004`, 21.650635094610966`}, {
       12.500000000000004`, 21.650635094610966`}, {6.470476127563024, 
       24.148145657226706`}, {6.470476127563024, 24.148145657226706`}, {
       12.500000000000004`, 21.650635094610966`}}], 
      LineBox[{{6.470476127563024, 24.148145657226706`}, {6.470476127563024, 
       24.148145657226706`}, {7.0819236220599744`*^-15, 25.}, {
       7.0819236220599744`*^-15, 25.}, {6.470476127563024, 
       24.148145657226706`}}], 
      LineBox[{{1.5308084989341915`*^-15, 25.}, {1.5308084989341915`*^-15, 
       25.}, {-6.470476127563016, 24.148145657226706`}, {-6.470476127563016, 
       24.148145657226706`}, {1.5308084989341915`*^-15, 25.}}], 
      LineBox[{{-6.470476127563016, 24.148145657226706`}, {-6.470476127563016,
        24.148145657226706`}, {-12.499999999999995`, 
       21.65063509461097}, {-12.499999999999995`, 
       21.65063509461097}, {-6.470476127563016, 24.148145657226706`}}], 
      LineBox[{{-12.499999999999995`, 
       21.65063509461097}, {-12.499999999999995`, 
       21.65063509461097}, {-17.677669529663685`, 
       17.67766952966369}, {-17.677669529663685`, 
       17.67766952966369}, {-12.499999999999995`, 21.65063509461097}}], 
      LineBox[{{-17.677669529663685`, 
       17.67766952966369}, {-17.677669529663685`, 
       17.67766952966369}, {-21.65063509461097, 
       12.499999999999998`}, {-21.65063509461097, 
       12.499999999999998`}, {-17.677669529663685`, 17.67766952966369}}], 
      LineBox[{{-21.650635094610962`, 
       12.500000000000009`}, {-21.650635094610962`, 
       12.500000000000009`}, {-24.148145657226706`, 
       6.470476127563026}, {-24.148145657226706`, 
       6.470476127563026}, {-21.650635094610962`, 12.500000000000009`}}], 
      LineBox[{{-24.148145657226706`, 
       6.470476127563026}, {-24.148145657226706`, 6.470476127563026}, {-25., 
       3.061616997868383*^-15}, {-25., 
       3.061616997868383*^-15}, {-24.148145657226706`, 6.470476127563026}}], 
      LineBox[{{-25., 3.061616997868383*^-15}, {-25., 
       3.061616997868383*^-15}, {-24.148145657226706`, -6.47047612756302}, \
{-24.148145657226706`, -6.47047612756302}, {-25., 3.061616997868383*^-15}}], 
      LineBox[{{-24.14814565722671, -6.470476127563009}, {-24.14814565722671, \
-6.470476127563009}, {-21.65063509461097, -12.499999999999993`}, \
{-21.65063509461097, -12.499999999999993`}, {-24.14814565722671, \
-6.470476127563009}}], 
      LineBox[{{-21.65063509461097, -12.499999999999993`}, \
{-21.65063509461097, -12.499999999999993`}, {-17.677669529663692`, \
-17.677669529663685`}, {-17.677669529663692`, -17.677669529663685`}, \
{-21.65063509461097, -12.499999999999993`}}], 
      LineBox[{{-17.677669529663696`, -17.677669529663678`}, \
{-17.677669529663696`, -17.677669529663678`}, {-12.50000000000001, \
-21.65063509461096}, {-12.50000000000001, -21.65063509461096}, \
{-17.677669529663696`, -17.677669529663678`}}], 
      LineBox[{{-12.50000000000001, -21.65063509461096}, {-12.50000000000001, \
-21.65063509461096}, {-6.470476127563038, -24.148145657226703`}, \
{-6.470476127563038, -24.148145657226703`}, {-12.50000000000001, \
-21.65063509461096}}], 
      LineBox[{{-6.470476127563038, -24.148145657226703`}, \
{-6.470476127563038, -24.148145657226703`}, {-2.6796885989305705`*^-14, \
-25.}, {-2.6796885989305705`*^-14, -25.}, {-6.470476127563038, \
-24.148145657226703`}}], 
      LineBox[{{-4.592425496802574*^-15, -25.}, {-4.592425496802574*^-15, \
-25.}, {6.470476127563007, -24.14814565722671}, {
       6.470476127563007, -24.14814565722671}, {-4.592425496802574*^-15, \
-25.}}], LineBox[{{6.470476127563007, -24.14814565722671}, {
       6.470476127563007, -24.14814565722671}, {
       12.499999999999984`, -21.650635094610976`}, {
       12.499999999999984`, -21.650635094610976`}, {
       6.470476127563007, -24.14814565722671}}], 
      LineBox[{{12.499999999999984`, -21.650635094610976`}, {
       12.499999999999984`, -21.650635094610976`}, {
       17.67766952966367, -17.67766952966371}, {
       17.67766952966367, -17.67766952966371}, {
       12.499999999999984`, -21.650635094610976`}}], 
      LineBox[{{17.677669529663685`, -17.677669529663692`}, {
       17.677669529663685`, -17.677669529663692`}, {
       21.65063509461096, -12.50000000000001}, {
       21.65063509461096, -12.50000000000001}, {
       17.677669529663685`, -17.677669529663692`}}], 
      LineBox[{{21.65063509461096, -12.50000000000001}, {
       21.65063509461096, -12.50000000000001}, {
       24.148145657226703`, -6.470476127563039}, {
       24.148145657226703`, -6.470476127563039}, {
       21.65063509461096, -12.50000000000001}}], 
      LineBox[{{24.148145657226703`, -6.470476127563039}, {
       24.148145657226703`, -6.470476127563039}, {
       25., -2.8327694488239898`*^-14}, {25., -2.8327694488239898`*^-14}, {
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {-18.21517071330813, 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {-11.463107122673815`, -14.155904040684312`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {4.112620349694018, -17.744824540531273`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {16.45808107228358, -7.805383496862866}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {16.458081072283587`, 7.805383496862857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {4.112620349694043, 17.744824540531273`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {-11.463107122673811`, 14.155904040684318`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-18.21517071330813, 0.}, {-18.09775195419761, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-11.463107122673815`, -14.155904040684312`}, \
{-11.389213562460736`, -14.06465215440194}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{4.112620349694018, -17.744824540531273`}, {
       4.086109548024674, -17.630437730164413`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{16.45808107228358, -7.805383496862866}, {
       16.351988876538414`, -7.755068379919505}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{16.458081072283587`, 7.805383496862857}, {16.35198887653842, 
       7.7550683799194955`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{4.112620349694043, 17.744824540531273`}, {4.086109548024699, 
       17.630437730164413`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-11.463107122673811`, 
       14.155904040684318`}, {-11.389213562460732`, 14.064652154401946`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-18.09775195419761, 0.}, {-15.700097493531914`, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-11.389213562460736`, -14.06465215440194}, \
{-9.88033009612643, -12.201317080462463`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{4.086109548024674, -17.630437730164413`}, {
       3.544767241566674, -15.294694717761526`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{16.351988876538414`, -7.755068379919505}, {
       14.185619309212417`, -6.727649375562509}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{16.35198887653842, 7.7550683799194955`}, {
       14.185619309212417`, 6.727649375562499}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{4.086109548024699, 17.630437730164413`}, {
       3.5447672415666944`, 15.294694717761526`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{-11.389213562460732`, 
       14.064652154401946`}, {-9.880330096126427, 12.201317080462468`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQrbq9I1fU3OgAAxTU3S5JkHmrdiBEumP5JX+dA+LG
u/cHFQs48F43urRmn+GBp/ESZ11KDRwq+PqLt1nIH3gO5edC+A7GqOodaqDm
hUPMc5BMW+bKJomwL+02M4P7cbUDGd2BYlKKOgdW9n2S1I0QcKi2+BmbstDw
wBnPzI/SUQYO7/6aLzVglT9wDsp/DOE7HEVV75ACNS8bYp5DRNle3eI0fbh9
kRKRC3YdUj5wKseTQzhd44D8huK366J5HN7p3rN8NE3vwCzV2jrOeB2HTb9/
v5J5KQXnL4fwHXxR1TuEQ807CzHPAQBlF4dD
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367530317142*^9, 3.566086986010274*^9, 
  3.566101740973756*^9, 3.56613918297773*^9, 3.614707793388194*^9},
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."},
 CellLabel->
  "During evaluation of \
In[33]:=",ExpressionUUID->"0a748db5-bcea-4a91-831b-278c5989b2ec"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"49c80eb8-69b3-49c3-\
afc0-0193bec43fa0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8. Adding a Cylindrical Lens to the System", "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "cylindrical lens", "8.", "Adding a Cylindrical Lens", 
   "RG8."},ExpressionUUID->"811accef-54a1-49dd-aafb-3af96471eef6"],

Cell[TextData[{
 "For some additional interest, you can place a cylindrical lens directly \
behind the plano-convex lens. The cylindrical lens component is created with ",
 StyleBox["PlanoConvexCylindricalLens", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "cylindrical lens", "Adding a Cylindrical Lens", 
   "RG8."},ExpressionUUID->"de0b999c-b77b-4599-9529-4cf305828fbf"],

Cell[TextData[{
 StyleBox["PlanoConvexCylindricalLens[", "Input"],
 StyleBox["focallength",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " denotes a lens with a planar surface on one side and a convex cylindrical \
surface on the other side."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "PlanoConvexCylindricalLens", "Adding a Cylindrical Lens", 
   "RG8."},ExpressionUUID->"cefabc0f-b2ba-4081-a914-a90102a52410"],

Cell[TextData[{
 "Here we use ",
 StyleBox["{50,50}",
  FontFamily->"Courier"],
 " in the ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 " parameter of ",
 StyleBox["PlanoConvexCylindricalLens", "Input",
  FontFamily->"Courier"],
 " to make a rectangular-edged cylindrical lens."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "cylindrical lens", "Adding a Cylindrical Lens", 
   "RG8."},ExpressionUUID->"2a020f65-57b9-4d9c-a7ad-1909426b6614"],

Cell[CellGroupData[{

Cell[TextData[{
 "opticalsystem = ",
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[{\n\tConeOfRays[20, NumberOfRays -> 7],\n\tMove[PlanoConvexLens[100, 50, \
10, GraphicDesign -> Wire], 100],\n\tMove[PlanoConvexCylindricalLens[100, \
{50,50}, 10, GraphicDesign -> Wire], 130],\n\tBoundary[{0,-30,-30}, \
{250,30,30}]}];"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."},
 CellLabel->"In[34]:=",ExpressionUUID->"8bec4a81-f674-4133-b165-e68c0b8dc5f6"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         "]]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.333333333333332, 0.}, {100.67375799589207`, 8.049381885742235, 
       2.156825375854339}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 8.333333333333332, 0.}, {
       102.75044883428481`, 16.666666666666664`, 0.}, {102.75044883428481`, 
       16.09876377148447, 4.313650751708678}, {100.67375799589207`, 
       8.049381885742235, 2.156825375854339}, {100.67375799589207`, 
       8.333333333333332, 0.}}], 
      Line3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
       106.4219745809556, 25., 0.}, {106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {102.75044883428481`, 16.666666666666664`, 0.}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.049381885742235, 2.156825375854339}, {100.67375799589209`, 
       7.216878364870323, 4.166666666666666}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 8.049381885742235, 
       2.156825375854339}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {100.67375799589209`, 7.216878364870323, 
       4.166666666666666}, {100.67375799589207`, 8.049381885742235, 
       2.156825375854339}}], 
      Line3DBox[{{102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       7.216878364870323, 4.166666666666666}, {100.67375799589207`, 
       5.892556509887896, 5.8925565098878945`}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 7.216878364870323, 
       4.166666666666666}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}, {100.67375799589209`, 7.216878364870323, 
       4.166666666666666}}], 
      Line3DBox[{{102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.892556509887896, 5.8925565098878945`}, {100.67375799589209`, 
       4.166666666666668, 7.216878364870322}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {100.67375799589209`, 4.166666666666668, 
       7.216878364870322}, {100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}}], 
      Line3DBox[{{102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       4.166666666666668, 7.216878364870322}, {100.67375799589207`, 
       2.156825375854341, 8.049381885742235}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 4.166666666666668, 
       7.216878364870322}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {100.67375799589207`, 2.156825375854341, 
       8.049381885742235}, {100.67375799589209`, 4.166666666666668, 
       7.216878364870322}}], 
      Line3DBox[{{102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       2.156825375854341, 8.049381885742235}, {100.67375799589207`, 
       2.3606412073533245`*^-15, 8.333333333333332}, {100.00000000000001`, 0.,
        0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 2.156825375854341, 
       8.049381885742235}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {102.75044883428481`, 4.721282414706649*^-15, 
       16.666666666666664`}, {100.67375799589207`, 2.3606412073533245`*^-15, 
       8.333333333333332}, {100.67375799589207`, 2.156825375854341, 
       8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {106.4219745809556, 7.0819236220599744`*^-15, 
       25.}, {102.75044883428481`, 4.721282414706649*^-15, 
       16.666666666666664`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.102694996447305*^-16, 8.333333333333332}, {
       100.67375799589207`, -2.1568253758543383`, 8.049381885742235}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 5.102694996447305*^-16, 
       8.333333333333332}, {102.75044883428481`, 1.020538999289461*^-15, 
       16.666666666666664`}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}, {100.67375799589207`, 5.102694996447305*^-16, 
       8.333333333333332}}], 
      Line3DBox[{{102.75044883428481`, 1.020538999289461*^-15, 
       16.666666666666664`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}, {106.4219745809556, -6.470476127563016, 24.148145657226706`}, {
       102.75044883428481`, -4.313650751708677, 16.09876377148447}, {
       102.75044883428481`, 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -2.1568253758543383`, 8.049381885742235}, {
       100.67375799589209`, -4.166666666666664, 7.216878364870323}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {100.67375799589209`, -4.166666666666664, 
       7.216878364870323}, {100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -4.166666666666664, 7.216878364870323}, {
       100.67375799589207`, -5.8925565098878945`, 5.892556509887896}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, -4.166666666666664, 
       7.216878364870323}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}, {100.67375799589209`, -4.166666666666664, 
       7.216878364870323}}], 
      Line3DBox[{{102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -5.8925565098878945`, 5.892556509887896}, {
       100.67375799589209`, -7.216878364870323, 4.166666666666666}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {102.75044883428481`, -14.433756729740645`, 
       8.333333333333332}, {100.67375799589209`, -7.216878364870323, 
       4.166666666666666}, {100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}}], 
      Line3DBox[{{102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {106.4219745809556, -21.65063509461097, 
       12.499999999999998`}, {102.75044883428481`, -14.433756729740645`, 
       8.333333333333332}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -7.21687836487032, 4.16666666666667}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, -7.21687836487032, 4.16666666666667}, {
       102.7504488342848, -14.43375672974064, 8.33333333333334}, {
       102.75044883428481`, -16.09876377148447, 4.313650751708684}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.67375799589209`, -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{102.7504488342848, -14.43375672974064, 8.33333333333334}, {
       106.4219745809556, -21.650635094610962`, 12.500000000000009`}, {
       106.4219745809556, -24.148145657226706`, 6.470476127563026}, {
       102.75044883428481`, -16.09876377148447, 4.313650751708684}, {
       102.7504488342848, -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -8.049381885742235, 
       2.156825375854342}, {102.75044883428481`, -16.09876377148447, 
       4.313650751708684}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {100.67375799589207`, -8.333333333333332, 
       1.020538999289461*^-15}, {100.67375799589207`, -8.049381885742235, 
       2.156825375854342}}], 
      Line3DBox[{{102.75044883428481`, -16.09876377148447, 
       4.313650751708684}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {102.75044883428481`, -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}, {
       100.67375799589207`, -8.049381885742235, -2.15682537585434}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -8.333333333333332, 
       1.020538999289461*^-15}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {
       102.75044883428481`, -16.09876377148447, -4.31365075170868}, {
       100.67375799589207`, -8.049381885742235, -2.15682537585434}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       102.75044883428481`, -16.09876377148447, -4.31365075170868}, {
       102.75044883428481`, -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.049381885742235, -2.156825375854336}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -8.049381885742235, -2.156825375854336}, {
       102.75044883428481`, -16.09876377148447, -4.313650751708672}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.67375799589207`, -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{
       102.75044883428481`, -16.09876377148447, -4.313650751708672}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       102.75044883428481`, -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.67375799589207`, -5.892556509887897, -5.8925565098878945`}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       102.75044883428481`, -11.785113019775794`, -11.785113019775789`}, {
       100.67375799589207`, -5.892556509887897, -5.8925565098878945`}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       102.75044883428481`, -11.785113019775794`, -11.785113019775789`}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -5.892556509887898, -5.892556509887893}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -5.892556509887898, -5.892556509887893}, {
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.67375799589207`, -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.67375799589207`, -8.932295329768568*^-15, -8.333333333333332}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       102.75044883428481`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{100.67375799589207`, -8.932295329768568*^-15, -8.333333333333332}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       102.75044883428481`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{102.75044883428481`, -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}, {
       100.67375799589207`, 2.1568253758543356`, -8.049381885742235}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}, {
       102.75044883428481`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{102.75044883428481`, 4.313650751708671, -16.09876377148447}, {
       100.67375799589207`, 2.1568253758543356`, -8.049381885742235}, {
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{
       102.75044883428481`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{106.4219745809556, -4.592425496802574*^-15, -25.}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {
       102.75044883428481`, -3.0616169978683826`*^-15, \
-16.666666666666664`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.67375799589207`, 
       5.89255650988789, -5.892556509887903}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {102.75044883428481`, 
       11.78511301977578, -11.785113019775807`}, {100.67375799589207`, 
       5.89255650988789, -5.892556509887903}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {102.75044883428481`, 
       11.78511301977578, -11.785113019775807`}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}, {102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.67375799589207`, 
       8.333333333333332, -9.442564829413298*^-15}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {102.75044883428481`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {100.67375799589207`, 
       8.333333333333332, -9.442564829413298*^-15}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {102.75044883428481`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{110., 0., 0.}, {110., 8.333333333333332, 0.}, {110., 
       8.049381885742235, 2.156825375854339}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 8.333333333333332, 0.}, {110., 
       16.666666666666664`, 0.}, {110., 16.09876377148447, 
       4.313650751708678}, {110., 8.049381885742235, 2.156825375854339}, {
       110., 8.333333333333332, 0.}}], 
      Line3DBox[{{110., 16.666666666666664`, 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {110., 16.09876377148447, 
       4.313650751708678}, {110., 16.666666666666664`, 0.}}], 
      Line3DBox[{{110., 0., 0.}, {110., 8.049381885742235, 
       2.156825375854339}, {110., 7.216878364870323, 4.166666666666666}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 8.049381885742235, 2.156825375854339}, {110., 
       16.09876377148447, 4.313650751708678}, {110., 14.433756729740645`, 
       8.333333333333332}, {110., 7.216878364870323, 4.166666666666666}, {
       110., 8.049381885742235, 2.156825375854339}}], 
      Line3DBox[{{110., 16.09876377148447, 4.313650751708678}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {110., 21.65063509461097, 
       12.499999999999998`}, {110., 14.433756729740645`, 8.333333333333332}, {
       110., 16.09876377148447, 4.313650751708678}}], 
      Line3DBox[{{110., 0., 0.}, {110., 7.216878364870323, 
       4.166666666666666}, {110., 5.892556509887896, 5.8925565098878945`}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 7.216878364870323, 4.166666666666666}, {110., 
       14.433756729740645`, 8.333333333333332}, {110., 11.785113019775793`, 
       11.785113019775789`}, {110., 5.892556509887896, 5.8925565098878945`}, {
       110., 7.216878364870323, 4.166666666666666}}], 
      Line3DBox[{{110., 14.433756729740645`, 8.333333333333332}, {110., 
       21.65063509461097, 12.499999999999998`}, {110., 17.67766952966369, 
       17.677669529663685`}, {110., 11.785113019775793`, 
       11.785113019775789`}, {110., 14.433756729740645`, 8.333333333333332}}],
       Line3DBox[{{110., 0., 0.}, {110., 5.892556509887896, 
       5.8925565098878945`}, {110., 4.166666666666668, 7.216878364870322}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 5.892556509887896, 5.8925565098878945`}, {110., 
       11.785113019775793`, 11.785113019775789`}, {110., 8.333333333333336, 
       14.433756729740644`}, {110., 4.166666666666668, 7.216878364870322}, {
       110., 5.892556509887896, 5.8925565098878945`}}], 
      Line3DBox[{{110., 11.785113019775793`, 11.785113019775789`}, {110., 
       17.67766952966369, 17.677669529663685`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 8.333333333333336, 14.433756729740644`}, {
       110., 11.785113019775793`, 11.785113019775789`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 4.166666666666668, 
       7.216878364870322}, {110., 2.156825375854341, 8.049381885742235}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 4.166666666666668, 7.216878364870322}, {110., 
       8.333333333333336, 14.433756729740644`}, {110., 4.313650751708682, 
       16.09876377148447}, {110., 2.156825375854341, 8.049381885742235}, {
       110., 4.166666666666668, 7.216878364870322}}], 
      Line3DBox[{{110., 8.333333333333336, 14.433756729740644`}, {110., 
       12.500000000000004`, 21.650635094610966`}, {110., 6.470476127563024, 
       24.148145657226706`}, {110., 4.313650751708682, 16.09876377148447}, {
       110., 8.333333333333336, 14.433756729740644`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 2.156825375854341, 
       8.049381885742235}, {110., 2.3606412073533245`*^-15, 
       8.333333333333332}, {110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 2.156825375854341, 8.049381885742235}, {110., 
       4.313650751708682, 16.09876377148447}, {110., 4.721282414706649*^-15, 
       16.666666666666664`}, {110., 2.3606412073533245`*^-15, 
       8.333333333333332}, {110., 2.156825375854341, 8.049381885742235}}], 
      Line3DBox[{{110., 4.313650751708682, 16.09876377148447}, {110., 
       6.470476127563024, 24.148145657226706`}, {110., 
       7.0819236220599744`*^-15, 25.}, {110., 4.721282414706649*^-15, 
       16.666666666666664`}, {110., 4.313650751708682, 16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., 5.102694996447305*^-16, 
       8.333333333333332}, {110., -2.1568253758543383`, 8.049381885742235}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 5.102694996447305*^-16, 8.333333333333332}, {110., 
       1.020538999289461*^-15, 16.666666666666664`}, {
       110., -4.313650751708677, 16.09876377148447}, {
       110., -2.1568253758543383`, 8.049381885742235}, {110., 
       5.102694996447305*^-16, 8.333333333333332}}], 
      Line3DBox[{{110., 1.020538999289461*^-15, 16.666666666666664`}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -4.313650751708677, 16.09876377148447}, {
       110., 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -2.1568253758543383`, 
       8.049381885742235}, {110., -4.166666666666664, 7.216878364870323}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -2.1568253758543383`, 8.049381885742235}, {
       110., -4.313650751708677, 16.09876377148447}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -4.166666666666664, 7.216878364870323}, {
       110., -2.1568253758543383`, 8.049381885742235}}], 
      Line3DBox[{{110., -4.313650751708677, 16.09876377148447}, {
       110., -6.470476127563016, 24.148145657226706`}, {
       110., -12.499999999999995`, 21.65063509461097}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -4.313650751708677, 16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., -4.166666666666664, 
       7.216878364870323}, {110., -5.8925565098878945`, 5.892556509887896}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -4.166666666666664, 7.216878364870323}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -5.8925565098878945`, 5.892556509887896}, {
       110., -4.166666666666664, 7.216878364870323}}], 
      Line3DBox[{{110., -8.333333333333329, 14.433756729740645`}, {
       110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -8.333333333333329, 14.433756729740645`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -5.8925565098878945`, 
       5.892556509887896}, {110., -7.216878364870323, 4.166666666666666}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -5.8925565098878945`, 5.892556509887896}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -14.433756729740645`, 8.333333333333332}, {
       110., -7.216878364870323, 4.166666666666666}, {
       110., -5.8925565098878945`, 5.892556509887896}}], 
      Line3DBox[{{110., -11.785113019775789`, 11.785113019775793`}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       110., -14.433756729740645`, 8.333333333333332}, {
       110., -11.785113019775789`, 11.785113019775793`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -7.21687836487032, 
       4.16666666666667}, {110., -8.049381885742235, 2.156825375854342}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -7.21687836487032, 4.16666666666667}, {
       110., -14.43375672974064, 8.33333333333334}, {110., -16.09876377148447,
        4.313650751708684}, {110., -8.049381885742235, 2.156825375854342}, {
       110., -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{110., -14.43375672974064, 8.33333333333334}, {
       110., -21.650635094610962`, 12.500000000000009`}, {
       110., -24.148145657226706`, 6.470476127563026}, {
       110., -16.09876377148447, 4.313650751708684}, {
       110., -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{110., 0., 0.}, {110., -8.049381885742235, 
       2.156825375854342}, {110., -8.333333333333332, 
       1.020538999289461*^-15}, {110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -8.049381885742235, 2.156825375854342}, {
       110., -16.09876377148447, 4.313650751708684}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -8.333333333333332, 1.020538999289461*^-15}, {
       110., -8.049381885742235, 2.156825375854342}}], 
      Line3DBox[{{110., -16.09876377148447, 4.313650751708684}, {
       110., -24.148145657226706`, 6.470476127563026}, {110., -25., 
       3.061616997868383*^-15}, {110., -16.666666666666664`, 
       2.041077998578922*^-15}, {110., -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{110., 0., 0.}, {110., -8.333333333333332, 
       1.020538999289461*^-15}, {
       110., -8.049381885742235, -2.15682537585434}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -8.333333333333332, 1.020538999289461*^-15}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -16.09876377148447, -4.31365075170868}, {
       110., -8.049381885742235, -2.15682537585434}, {
       110., -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       110., -16.09876377148447, -4.31365075170868}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -8.049381885742235, -2.156825375854336}, {
       110., -7.216878364870323, -4.166666666666664}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -8.049381885742235, -2.156825375854336}, {
       110., -16.09876377148447, -4.313650751708672}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -7.216878364870323, -4.166666666666664}, {
       110., -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{110., -16.09876377148447, -4.313650751708672}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -7.216878364870323, -4.166666666666664}, {
       110., -5.892556509887897, -5.8925565098878945`}, {110., 0., 0.}, {110.,
        0., 0.}}], 
      Line3DBox[{{110., -7.216878364870323, -4.166666666666664}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -11.785113019775794`, -11.785113019775789`}, {
       110., -5.892556509887897, -5.8925565098878945`}, {
       110., -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{110., -14.433756729740645`, -8.333333333333329}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       110., -11.785113019775794`, -11.785113019775789`}, {
       110., -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -5.892556509887898, -5.892556509887893}, {
       110., -4.16666666666667, -7.216878364870319}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -5.892556509887898, -5.892556509887893}, {
       110., -11.785113019775796`, -11.785113019775785`}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -4.16666666666667, -7.216878364870319}, {
       110., -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{110., -11.785113019775796`, -11.785113019775785`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -4.16666666666667, -7.216878364870319}, {
       110., -2.156825375854346, -8.049381885742234}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -4.16666666666667, -7.216878364870319}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -2.156825375854346, -8.049381885742234}, {
       110., -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{110., -8.33333333333334, -14.433756729740638`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -2.156825375854346, -8.049381885742234}, {
       110., -8.932295329768568*^-15, -8.333333333333332}, {110., 0., 0.}, {
       110., 0., 0.}}], 
      Line3DBox[{{110., -2.156825375854346, -8.049381885742234}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       110., -8.932295329768568*^-15, -8.333333333333332}, {
       110., -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{110., -4.313650751708692, -16.098763771484467`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       110., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       110., -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -1.5308084989341913`*^-15, -8.333333333333332}, {110., 
       2.1568253758543356`, -8.049381885742235}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{
       110., -1.5308084989341913`*^-15, -8.333333333333332}, {
       110., -3.0616169978683826`*^-15, -16.666666666666664`}, {110., 
       4.313650751708671, -16.09876377148447}, {110., 
       2.1568253758543356`, -8.049381885742235}, {
       110., -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{110., -3.0616169978683826`*^-15, -16.666666666666664`}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {110., 
       4.313650751708671, -16.09876377148447}, {
       110., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       2.1568253758543356`, -8.049381885742235}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 2.1568253758543356`, -8.049381885742235}, {
       110., 4.313650751708671, -16.09876377148447}, {110., 
       8.333333333333321, -14.43375672974065}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{110., 4.313650751708671, -16.09876377148447}, {110., 
       6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       8.333333333333321, -14.43375672974065}, {110., 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 
       5.89255650988789, -5.892556509887903}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 4.166666666666661, -7.216878364870325}, {110.,
        8.333333333333321, -14.43375672974065}, {110., 
       11.78511301977578, -11.785113019775807`}, {110., 
       5.89255650988789, -5.892556509887903}, {110., 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{110., 8.333333333333321, -14.43375672974065}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {110., 
       11.78511301977578, -11.785113019775807`}, {110., 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       5.8925565098878945`, -5.892556509887897}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 0., 0.}, {110., 0., 
       0.}}], 
      Line3DBox[{{110., 5.8925565098878945`, -5.892556509887897}, {110., 
       11.785113019775789`, -11.785113019775794`}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{110., 11.785113019775789`, -11.785113019775794`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 7.216878364870319, -4.16666666666667}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       16.098763771484467`, -4.313650751708693}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{110., 14.433756729740638`, -8.33333333333334}, {110., 
       21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       16.098763771484467`, -4.313650751708693}, {110., 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 
       8.333333333333332, -9.442564829413298*^-15}, {110., 0., 0.}, {110., 0.,
        0.}}], Line3DBox[{{110., 8.049381885742234, -2.1568253758543463`}, {
       110., 16.098763771484467`, -4.313650751708693}, {110., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {110., 
       8.333333333333332, -9.442564829413298*^-15}, {110., 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{110., 16.098763771484467`, -4.313650751708693}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {110., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {110., 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 
      6.123233995736766*^-15}, {140., -16.66666666666667, 
      5.102694996447306*^-15}, {132.7504488342848, -16.666666666666668`, 
      0.}, {136.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{132.7504488342848, -16.666666666666668`, 0.}, {
      140., -16.66666666666667, 5.102694996447306*^-15}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      130.67375799589206`, -8.333333333333336, 0.}, {
      132.7504488342848, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{130.67375799589206`, -8.333333333333336, 0.}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      140., -7.105427357601002*^-15, 3.061616997868384*^-15}, {130., 0., 
      0.}, {130.67375799589206`, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{130., 0., 0.}, {140., 0., 3.061616997868383*^-15}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {130.67375799589206`, 
      8.333333333333329, 0.}, {130., 0., 0.}}], 
     Polygon3DBox[{{130.67375799589206`, 8.333333333333329, 0.}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {140., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {132.7504488342848, 
      16.666666666666664`, 0.}, {130.67375799589206`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{132.7504488342848, 16.666666666666664`, 0.}, {
      140., 16.666666666666664`, 1.0205389992894615`*^-15}, {140., 
      24.999999999999996`, 5.098616525425841*^-31}, {136.4219745809556, 
      24.999999999999993`, 0.}, {132.7504488342848, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA6Wu3ahgTfRgQEMLA8wQEGykNta5hkJDqtXgYAB
XPzMjrc5/aEJDmvA4gpwcTBwSICa82EPuvoVEPUOMPEkqPkQcQO4OMw9//6D
gAVcHAwa4O7EEF+NZg5MfA2avajmfLBBF1+BzV9wcQMMcag74eK4whMASr9a
Hg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{130., 0., -25.}, {140., 3.061616997868383*^-15, -25.}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}, {130., 0., -25.}}], 
       Polygon3DBox[{{130., 5.102694996447305*^-16, -16.666666666666668`}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {140., 
        2.0410779985789223`*^-15, -8.333333333333336}, {130., 
        1.020538999289461*^-15, -8.333333333333336}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{130., 1.020538999289461*^-15, -8.333333333333336}, {
        140., 2.0410779985789223`*^-15, -8.333333333333336}, {140., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {130., 
        1.5308084989341915`*^-15, 0.}, {130., 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{130., 1.5308084989341915`*^-15, 0.}, {140., 
        1.5308084989341915`*^-15, 0.}, {140., 1.0205389992894611`*^-15, 
        8.333333333333332}, {130., 2.041077998578922*^-15, 
        8.333333333333329}, {130., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{130., 2.041077998578922*^-15, 8.333333333333329}, {140.,
         1.0205389992894611`*^-15, 8.333333333333332}, {140., 
        5.102694996447307*^-16, 16.666666666666664`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}, {130., 
        2.041077998578922*^-15, 8.333333333333329}}], 
       Polygon3DBox[{{130., 2.5513474982236525`*^-15, 16.666666666666664`}, {
        140., 5.102694996447308*^-16, 16.666666666666664`}, {140., 
        2.5493082627129206`*^-31, 24.999999999999996`}, {130., 
        3.0616169978683826`*^-15, 24.999999999999993`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihwSHBgQAGWB9DFV68CAQMM8TVgcQUMcQj4sAdd
fAVEvQN2cQMM8X//QcACwm9IRHcnhvhqZHOQxNcg24thzgcbdPEVyP7CEDfA
EIe68wC6+6HuPAAAPE1IaA==
         "]]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{136.4219745809556, -25., -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       136.4219745809556, -25., -16.666666666666664`}, {
       136.4219745809556, -25., -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -8.33333333333333}, {
       136.4219745809556, -25., -8.33333333333333}, {
       136.4219745809556, -25., -16.666666666666664`}}], 
      Line3DBox[{{136.4219745809556, -25., -8.333333333333332}, {
       132.7504488342848, -16.666666666666664`, -8.333333333333332}, {
       132.7504488342848, -16.666666666666664`, 1.7763568394002505`*^-15}, {
       136.4219745809556, -25., 1.7763568394002505`*^-15}, {
       136.4219745809556, -25., -8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, -25., 0.}, {
       132.7504488342848, -16.666666666666664`, 0.}, {
       132.7504488342848, -16.666666666666664`, 8.333333333333334}, {
       136.4219745809556, -25., 8.333333333333334}, {136.4219745809556, -25., 
       0.}}], Line3DBox[{{136.4219745809556, -25., 8.333333333333336}, {
       132.7504488342848, -16.666666666666664`, 8.333333333333336}, {
       132.7504488342848, -16.666666666666664`, 16.66666666666667}, {
       136.4219745809556, -25., 16.66666666666667}, {136.4219745809556, -25., 
       8.333333333333336}}], 
      Line3DBox[{{136.4219745809556, -25., 16.66666666666667}, {
       132.7504488342848, -16.666666666666664`, 16.66666666666667}, {
       132.7504488342848, -16.666666666666664`, 25.000000000000007`}, {
       136.4219745809556, -25., 25.000000000000007`}, {
       136.4219745809556, -25., 16.66666666666667}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, -25.}, {
       130.67375799589206`, -8.33333333333333, -25.}, {
       130.67375799589206`, -8.33333333333333, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -25.}}], 
      Line3DBox[{{
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}}], 
      Line3DBox[{{
       132.7504488342848, -16.666666666666664`, -8.333333333333332}, {
       130.67375799589206`, -8.33333333333333, -8.333333333333332}, {
       130.67375799589206`, -8.33333333333333, 1.7763568394002505`*^-15}, {
       132.7504488342848, -16.666666666666664`, 1.7763568394002505`*^-15}, {
       132.7504488342848, -16.666666666666664`, -8.333333333333332}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, 0.}, {
       130.67375799589206`, -8.33333333333333, 0.}, {
       130.67375799589206`, -8.33333333333333, 8.333333333333334}, {
       132.7504488342848, -16.666666666666664`, 8.333333333333334}, {
       132.7504488342848, -16.666666666666664`, 0.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, 
       8.333333333333336}, {130.67375799589206`, -8.33333333333333, 
       8.333333333333336}, {130.67375799589206`, -8.33333333333333, 
       16.66666666666667}, {132.7504488342848, -16.666666666666664`, 
       16.66666666666667}, {132.7504488342848, -16.666666666666664`, 
       8.333333333333336}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, 
       16.66666666666667}, {130.67375799589206`, -8.33333333333333, 
       16.66666666666667}, {130.67375799589206`, -8.33333333333333, 
       25.000000000000007`}, {132.7504488342848, -16.666666666666664`, 
       25.000000000000007`}, {132.7504488342848, -16.666666666666664`, 
       16.66666666666667}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, -25.}, {130., 
       1.7763568394002505`*^-15, -25.}, {130., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {
       130.67375799589206`, -8.333333333333332, -16.666666666666664`}, {
       130.67375799589206`, -8.333333333333332, -25.}}], 
      Line3DBox[{{
       130.67375799589206`, -8.333333333333332, -16.666666666666664`}, {130., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {130., 
       1.7763568394002505`*^-15, -8.33333333333333}, {
       130.67375799589206`, -8.333333333333332, -8.33333333333333}, {
       130.67375799589206`, -8.333333333333332, -16.666666666666664`}}], 
      Line3DBox[{{
       130.67375799589206`, -8.333333333333332, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332, 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332, -8.333333333333332}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, 0.}, {130., 
       1.7763568394002505`*^-15, 0.}, {130., 1.7763568394002505`*^-15, 
       8.333333333333334}, {130.67375799589206`, -8.333333333333332, 
       8.333333333333334}, {130.67375799589206`, -8.333333333333332, 0.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, 
       8.333333333333336}, {130., 1.7763568394002505`*^-15, 
       8.333333333333336}, {130., 1.7763568394002505`*^-15, 
       16.66666666666667}, {130.67375799589206`, -8.333333333333332, 
       16.66666666666667}, {130.67375799589206`, -8.333333333333332, 
       8.333333333333336}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, 
       16.66666666666667}, {130., 1.7763568394002505`*^-15, 
       16.66666666666667}, {130., 1.7763568394002505`*^-15, 
       25.000000000000007`}, {130.67375799589206`, -8.333333333333332, 
       25.000000000000007`}, {130.67375799589206`, -8.333333333333332, 
       16.66666666666667}}], 
      Line3DBox[{{130., 0., -25.}, {130.67375799589206`, 
       8.333333333333334, -25.}, {130.67375799589206`, 
       8.333333333333334, -16.666666666666664`}, {130., 
       0., -16.666666666666664`}, {130., 0., -25.}}], 
      Line3DBox[{{130., 0., -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333334, -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333334, -8.33333333333333}, {130., 0., -8.33333333333333}, {
       130., 0., -16.666666666666664`}}], 
      Line3DBox[{{130., 0., -8.333333333333332}, {130.67375799589206`, 
       8.333333333333334, -8.333333333333332}, {130.67375799589206`, 
       8.333333333333334, 1.7763568394002505`*^-15}, {130., 0., 
       1.7763568394002505`*^-15}, {130., 0., -8.333333333333332}}], 
      Line3DBox[{{130., 0., 0.}, {130.67375799589206`, 8.333333333333334, 
       0.}, {130.67375799589206`, 8.333333333333334, 8.333333333333334}, {
       130., 0., 8.333333333333334}, {130., 0., 0.}}], 
      Line3DBox[{{130., 0., 8.333333333333336}, {130.67375799589206`, 
       8.333333333333334, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333334, 16.66666666666667}, {130., 0., 16.66666666666667}, {
       130., 0., 8.333333333333336}}], 
      Line3DBox[{{130., 0., 16.66666666666667}, {130.67375799589206`, 
       8.333333333333334, 16.66666666666667}, {130.67375799589206`, 
       8.333333333333334, 25.000000000000007`}, {130., 0., 
       25.000000000000007`}, {130., 0., 16.66666666666667}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, -25.}, {
       132.7504488342848, 16.66666666666667, -25.}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333336, -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333336, -25.}}], 
      Line3DBox[{{130.67375799589206`, 
       8.333333333333336, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -8.33333333333333}, {130.67375799589206`, 
       8.333333333333336, -8.33333333333333}, {130.67375799589206`, 
       8.333333333333336, -16.666666666666664`}}], 
      Line3DBox[{{130.67375799589206`, 
       8.333333333333336, -8.333333333333332}, {132.7504488342848, 
       16.66666666666667, -8.333333333333332}, {132.7504488342848, 
       16.66666666666667, 1.7763568394002505`*^-15}, {130.67375799589206`, 
       8.333333333333336, 1.7763568394002505`*^-15}, {130.67375799589206`, 
       8.333333333333336, -8.333333333333332}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, 0.}, {
       132.7504488342848, 16.66666666666667, 0.}, {132.7504488342848, 
       16.66666666666667, 8.333333333333334}, {130.67375799589206`, 
       8.333333333333336, 8.333333333333334}, {130.67375799589206`, 
       8.333333333333336, 0.}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, 
       8.333333333333336}, {132.7504488342848, 16.66666666666667, 
       8.333333333333336}, {132.7504488342848, 16.66666666666667, 
       16.66666666666667}, {130.67375799589206`, 8.333333333333336, 
       16.66666666666667}, {130.67375799589206`, 8.333333333333336, 
       8.333333333333336}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667, 
       25.000000000000007`}, {130.67375799589206`, 8.333333333333336, 
       25.000000000000007`}, {130.67375799589206`, 8.333333333333336, 
       16.66666666666667}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, -25.}, {
       136.4219745809556, 25.000000000000007`, -25.}, {136.4219745809556, 
       25.000000000000007`, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -25.}}], 
      Line3DBox[{{132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {136.4219745809556, 
       25.000000000000007`, -16.666666666666664`}, {136.4219745809556, 
       25.000000000000007`, -8.33333333333333}, {132.7504488342848, 
       16.66666666666667, -8.33333333333333}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, -8.333333333333332}, {
       136.4219745809556, 25.000000000000007`, -8.333333333333332}, {
       136.4219745809556, 25.000000000000007`, 1.7763568394002505`*^-15}, {
       132.7504488342848, 16.66666666666667, 1.7763568394002505`*^-15}, {
       132.7504488342848, 16.66666666666667, -8.333333333333332}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, 0.}, {
       136.4219745809556, 25.000000000000007`, 0.}, {136.4219745809556, 
       25.000000000000007`, 8.333333333333334}, {132.7504488342848, 
       16.66666666666667, 8.333333333333334}, {132.7504488342848, 
       16.66666666666667, 0.}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, 8.333333333333336}, {
       136.4219745809556, 25.000000000000007`, 8.333333333333336}, {
       136.4219745809556, 25.000000000000007`, 16.66666666666667}, {
       132.7504488342848, 16.66666666666667, 16.66666666666667}, {
       132.7504488342848, 16.66666666666667, 8.333333333333336}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, 16.66666666666667}, {
       136.4219745809556, 25.000000000000007`, 16.66666666666667}, {
       136.4219745809556, 25.000000000000007`, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667, 16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{140., -25., -25.}, {140., -16.666666666666664`, -25.}, {
       140., -16.666666666666664`, -16.666666666666664`}, {
       140., -25., -16.666666666666664`}, {140., -25., -25.}}], 
      Line3DBox[{{140., -25., -16.666666666666664`}, {
       140., -16.666666666666664`, -16.666666666666664`}, {
       140., -16.666666666666664`, -8.33333333333333}, {
       140., -25., -8.33333333333333}, {140., -25., -16.666666666666664`}}], 
      Line3DBox[{{140., -25., -8.333333333333332}, {
       140., -16.666666666666664`, -8.333333333333332}, {
       140., -16.666666666666664`, 1.7763568394002505`*^-15}, {140., -25., 
       1.7763568394002505`*^-15}, {140., -25., -8.333333333333332}}], 
      Line3DBox[{{140., -25., 0.}, {140., -16.666666666666664`, 0.}, {
       140., -16.666666666666664`, 8.333333333333334}, {140., -25., 
       8.333333333333334}, {140., -25., 0.}}], 
      Line3DBox[{{140., -25., 8.333333333333336}, {140., -16.666666666666664`,
        8.333333333333336}, {140., -16.666666666666664`, 16.66666666666667}, {
       140., -25., 16.66666666666667}, {140., -25., 8.333333333333336}}], 
      Line3DBox[{{140., -25., 16.66666666666667}, {140., -16.666666666666664`,
        16.66666666666667}, {140., -16.666666666666664`, 
       25.000000000000007`}, {140., -25., 25.000000000000007`}, {140., -25., 
       16.66666666666667}}], 
      Line3DBox[{{140., -16.666666666666664`, -25.}, {
       140., -8.33333333333333, -25.}, {
       140., -8.33333333333333, -16.666666666666664`}, {
       140., -16.666666666666664`, -16.666666666666664`}, {
       140., -16.666666666666664`, -25.}}], 
      Line3DBox[{{140., -16.666666666666664`, -16.666666666666664`}, {
       140., -8.33333333333333, -16.666666666666664`}, {
       140., -8.33333333333333, -8.33333333333333}, {
       140., -16.666666666666664`, -8.33333333333333}, {
       140., -16.666666666666664`, -16.666666666666664`}}], 
      Line3DBox[{{140., -16.666666666666664`, -8.333333333333332}, {
       140., -8.33333333333333, -8.333333333333332}, {140., -8.33333333333333,
        1.7763568394002505`*^-15}, {140., -16.666666666666664`, 
       1.7763568394002505`*^-15}, {
       140., -16.666666666666664`, -8.333333333333332}}], 
      Line3DBox[{{140., -16.666666666666664`, 0.}, {140., -8.33333333333333, 
       0.}, {140., -8.33333333333333, 8.333333333333334}, {
       140., -16.666666666666664`, 8.333333333333334}, {
       140., -16.666666666666664`, 0.}}], 
      Line3DBox[{{140., -16.666666666666664`, 8.333333333333336}, {
       140., -8.33333333333333, 8.333333333333336}, {140., -8.33333333333333, 
       16.66666666666667}, {140., -16.666666666666664`, 16.66666666666667}, {
       140., -16.666666666666664`, 8.333333333333336}}], 
      Line3DBox[{{140., -16.666666666666664`, 16.66666666666667}, {
       140., -8.33333333333333, 16.66666666666667}, {140., -8.33333333333333, 
       25.000000000000007`}, {140., -16.666666666666664`, 
       25.000000000000007`}, {140., -16.666666666666664`, 
       16.66666666666667}}], 
      Line3DBox[{{140., -8.333333333333332, -25.}, {140., 
       1.7763568394002505`*^-15, -25.}, {140., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {
       140., -8.333333333333332, -16.666666666666664`}, {
       140., -8.333333333333332, -25.}}], 
      Line3DBox[{{140., -8.333333333333332, -16.666666666666664`}, {140., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {140., 
       1.7763568394002505`*^-15, -8.33333333333333}, {
       140., -8.333333333333332, -8.33333333333333}, {
       140., -8.333333333333332, -16.666666666666664`}}], 
      Line3DBox[{{140., -8.333333333333332, -8.333333333333332}, {140., 
       1.7763568394002505`*^-15, -8.333333333333332}, {140., 
       1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
       140., -8.333333333333332, 1.7763568394002505`*^-15}, {
       140., -8.333333333333332, -8.333333333333332}}], 
      Line3DBox[{{140., -8.333333333333332, 0.}, {140., 
       1.7763568394002505`*^-15, 0.}, {140., 1.7763568394002505`*^-15, 
       8.333333333333334}, {140., -8.333333333333332, 8.333333333333334}, {
       140., -8.333333333333332, 0.}}], 
      Line3DBox[{{140., -8.333333333333332, 8.333333333333336}, {140., 
       1.7763568394002505`*^-15, 8.333333333333336}, {140., 
       1.7763568394002505`*^-15, 16.66666666666667}, {
       140., -8.333333333333332, 16.66666666666667}, {
       140., -8.333333333333332, 8.333333333333336}}], 
      Line3DBox[{{140., -8.333333333333332, 16.66666666666667}, {140., 
       1.7763568394002505`*^-15, 16.66666666666667}, {140., 
       1.7763568394002505`*^-15, 25.000000000000007`}, {
       140., -8.333333333333332, 25.000000000000007`}, {
       140., -8.333333333333332, 16.66666666666667}}], 
      Line3DBox[{{140., 0., -25.}, {140., 8.333333333333334, -25.}, {140., 
       8.333333333333334, -16.666666666666664`}, {140., 
       0., -16.666666666666664`}, {140., 0., -25.}}], 
      Line3DBox[{{140., 0., -16.666666666666664`}, {140., 
       8.333333333333334, -16.666666666666664`}, {140., 
       8.333333333333334, -8.33333333333333}, {140., 0., -8.33333333333333}, {
       140., 0., -16.666666666666664`}}], 
      Line3DBox[{{140., 0., -8.333333333333332}, {140., 
       8.333333333333334, -8.333333333333332}, {140., 8.333333333333334, 
       1.7763568394002505`*^-15}, {140., 0., 1.7763568394002505`*^-15}, {140.,
        0., -8.333333333333332}}], 
      Line3DBox[{{140., 0., 0.}, {140., 8.333333333333334, 0.}, {140., 
       8.333333333333334, 8.333333333333334}, {140., 0., 8.333333333333334}, {
       140., 0., 0.}}], 
      Line3DBox[{{140., 0., 8.333333333333336}, {140., 8.333333333333334, 
       8.333333333333336}, {140., 8.333333333333334, 16.66666666666667}, {
       140., 0., 16.66666666666667}, {140., 0., 8.333333333333336}}], 
      Line3DBox[{{140., 0., 16.66666666666667}, {140., 8.333333333333334, 
       16.66666666666667}, {140., 8.333333333333334, 25.000000000000007`}, {
       140., 0., 25.000000000000007`}, {140., 0., 16.66666666666667}}], 
      Line3DBox[{{140., 8.333333333333336, -25.}, {140., 
       16.66666666666667, -25.}, {140., 
       16.66666666666667, -16.666666666666664`}, {140., 
       8.333333333333336, -16.666666666666664`}, {140., 
       8.333333333333336, -25.}}], 
      Line3DBox[{{140., 8.333333333333336, -16.666666666666664`}, {140., 
       16.66666666666667, -16.666666666666664`}, {140., 
       16.66666666666667, -8.33333333333333}, {140., 
       8.333333333333336, -8.33333333333333}, {140., 
       8.333333333333336, -16.666666666666664`}}], 
      Line3DBox[{{140., 8.333333333333336, -8.333333333333332}, {140., 
       16.66666666666667, -8.333333333333332}, {140., 16.66666666666667, 
       1.7763568394002505`*^-15}, {140., 8.333333333333336, 
       1.7763568394002505`*^-15}, {140., 
       8.333333333333336, -8.333333333333332}}], 
      Line3DBox[{{140., 8.333333333333336, 0.}, {140., 16.66666666666667, 
       0.}, {140., 16.66666666666667, 8.333333333333334}, {140., 
       8.333333333333336, 8.333333333333334}, {140., 8.333333333333336, 0.}}],
       Line3DBox[{{140., 8.333333333333336, 8.333333333333336}, {140., 
       16.66666666666667, 8.333333333333336}, {140., 16.66666666666667, 
       16.66666666666667}, {140., 8.333333333333336, 16.66666666666667}, {
       140., 8.333333333333336, 8.333333333333336}}], 
      Line3DBox[{{140., 8.333333333333336, 16.66666666666667}, {140., 
       16.66666666666667, 16.66666666666667}, {140., 16.66666666666667, 
       25.000000000000007`}, {140., 8.333333333333336, 25.000000000000007`}, {
       140., 8.333333333333336, 16.66666666666667}}], 
      Line3DBox[{{140., 16.66666666666667, -25.}, {140., 
       25.000000000000007`, -25.}, {140., 
       25.000000000000007`, -16.666666666666664`}, {140., 
       16.66666666666667, -16.666666666666664`}, {140., 
       16.66666666666667, -25.}}], 
      Line3DBox[{{140., 16.66666666666667, -16.666666666666664`}, {140., 
       25.000000000000007`, -16.666666666666664`}, {140., 
       25.000000000000007`, -8.33333333333333}, {140., 
       16.66666666666667, -8.33333333333333}, {140., 
       16.66666666666667, -16.666666666666664`}}], 
      Line3DBox[{{140., 16.66666666666667, -8.333333333333332}, {140., 
       25.000000000000007`, -8.333333333333332}, {140., 25.000000000000007`, 
       1.7763568394002505`*^-15}, {140., 16.66666666666667, 
       1.7763568394002505`*^-15}, {140., 
       16.66666666666667, -8.333333333333332}}], 
      Line3DBox[{{140., 16.66666666666667, 0.}, {140., 25.000000000000007`, 
       0.}, {140., 25.000000000000007`, 8.333333333333334}, {140., 
       16.66666666666667, 8.333333333333334}, {140., 16.66666666666667, 0.}}],
       Line3DBox[{{140., 16.66666666666667, 8.333333333333336}, {140., 
       25.000000000000007`, 8.333333333333336}, {140., 25.000000000000007`, 
       16.66666666666667}, {140., 16.66666666666667, 16.66666666666667}, {
       140., 16.66666666666667, 8.333333333333336}}], 
      Line3DBox[{{140., 16.66666666666667, 16.66666666666667}, {140., 
       25.000000000000007`, 16.66666666666667}, {140., 25.000000000000007`, 
       25.000000000000007`}, {140., 16.66666666666667, 25.000000000000007`}, {
       140., 16.66666666666667, 16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{136.4219745809556, -25., 25.}, {140., -25., 25.}, {
       140., -16.666666666666668`, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}, {
       136.4219745809556, -25., 25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666668`, 25.}, {
       140., -16.666666666666668`, 25.}, {140., -8.333333333333336, 25.}, {
       130.67375799589206`, -8.333333333333336, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333334, 25.}, {
       140., -8.333333333333334, 25.}, {140., -1.3877787807814457`*^-15, 
       25.}, {130., -1.3877787807814457`*^-15, 25.}, {
       130.67375799589206`, -8.333333333333334, 25.}}], 
      Line3DBox[{{130., 0., 25.}, {140., 0., 25.}, {140., 8.333333333333332, 
       25.}, {130.67375799589206`, 8.333333333333332, 25.}, {130., 0., 25.}}],
       Line3DBox[{{130.67375799589206`, 8.333333333333332, 25.}, {140., 
       8.333333333333332, 25.}, {140., 16.666666666666664`, 25.}, {
       132.7504488342848, 16.666666666666664`, 25.}, {130.67375799589206`, 
       8.333333333333332, 25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666664`, 25.}, {140., 
       16.666666666666664`, 25.}, {140., 24.999999999999993`, 25.}, {
       136.4219745809556, 24.999999999999993`, 25.}, {132.7504488342848, 
       16.666666666666664`, 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 25.}, {140., 25., 25.}, {140., 25., 
       16.666666666666668`}, {136.4219745809556, 25., 16.666666666666668`}, {
       136.4219745809556, 25., 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 16.666666666666668`}, {140., 25., 
       16.666666666666668`}, {140., 25., 8.333333333333336}, {
       136.4219745809556, 25., 8.333333333333336}, {136.4219745809556, 25., 
       16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, 25., 8.333333333333334}, {140., 25., 
       8.333333333333334}, {140., 25., 1.3877787807814457`*^-15}, {
       136.4219745809556, 25., 1.3877787807814457`*^-15}, {136.4219745809556, 
       25., 8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, 25., 0.}, {140., 25., 0.}, {140., 
       25., -8.333333333333332}, {136.4219745809556, 
       25., -8.333333333333332}, {136.4219745809556, 25., 0.}}], 
      Line3DBox[{{136.4219745809556, 25., -8.333333333333332}, {140., 
       25., -8.333333333333332}, {140., 25., -16.666666666666664`}, {
       136.4219745809556, 25., -16.666666666666664`}, {136.4219745809556, 
       25., -8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, 25., -16.666666666666664`}, {140., 
       25., -16.666666666666664`}, {140., 25., -24.999999999999993`}, {
       136.4219745809556, 25., -24.999999999999993`}, {136.4219745809556, 
       25., -16.666666666666664`}}], 
      Line3DBox[{{136.4219745809556, 25., -25.}, {140., 25., -25.}, {140., 
       16.666666666666668`, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}, {136.4219745809556, 25., -25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666668`, -25.}, {140., 
       16.666666666666668`, -25.}, {140., 8.333333333333336, -25.}, {
       130.67375799589206`, 8.333333333333336, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333334, -25.}, {140., 
       8.333333333333334, -25.}, {140., 1.3877787807814457`*^-15, -25.}, {
       130., 1.3877787807814457`*^-15, -25.}, {130.67375799589206`, 
       8.333333333333334, -25.}}], 
      Line3DBox[{{130., 0., -25.}, {140., 0., -25.}, {
       140., -8.333333333333332, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}, {130., 0., -25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, -25.}, {
       140., -8.333333333333332, -25.}, {140., -16.666666666666664`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, -25.}, {
       140., -16.666666666666664`, -25.}, {
       140., -24.999999999999993`, -25.}, {
       136.4219745809556, -24.999999999999993`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -25.}, {140., -25., -25.}, {
       140., -25., -16.666666666666668`}, {
       136.4219745809556, -25., -16.666666666666668`}, {
       136.4219745809556, -25., -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -16.666666666666668`}, {
       140., -25., -16.666666666666668`}, {140., -25., -8.333333333333336}, {
       136.4219745809556, -25., -8.333333333333336}, {
       136.4219745809556, -25., -16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, -25., -8.333333333333334}, {
       140., -25., -8.333333333333334}, {
       140., -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 0.}, {140., -25.,
        8.333333333333332}, {136.4219745809556, -25., 8.333333333333332}, {
       136.4219745809556, -25., 0.}}], 
      Line3DBox[{{136.4219745809556, -25., 8.333333333333332}, {140., -25., 
       8.333333333333332}, {140., -25., 16.666666666666664`}, {
       136.4219745809556, -25., 16.666666666666664`}, {
       136.4219745809556, -25., 8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, -25., 16.666666666666664`}, {140., -25., 
       16.666666666666664`}, {140., -25., 24.999999999999993`}, {
       136.4219745809556, -25., 24.999999999999993`}, {
       136.4219745809556, -25., 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., 30., -30.}, {250., -30., -30.}, {250., -30., 30.}, {
       250., 30., 30.}, {250., 30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., -30., -30.}, {0., -30., -30.}, {0., -30., 30.}, {
       250., -30., 30.}, {250., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -30, -30}, {0, 30, -30}, {0, 30, 30}, {0, -30, 30}, {
       0, -30, -30}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 30., -30.}, {250., 30., -30.}, {250., 30., 30.}, {0., 
       30., 30.}, {0., 30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., -30., -30.}, {250., 30., -30.}, {0., 30., -30.}, {
       0., -30., -30.}, {250., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., 30., 30.}, {250., -30., 30.}, {0., -30., 30.}, {0., 
       30., 30.}, {250., 30., 30.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBQBmImIAaxcYEjVtHRWZcjHVS3d+SKmhsdwKMUDPZB1dfd
LkmQeat2IES6Y/klfx2c+mDmixvv3h9ULODAe93o0pp9hgTVP42XOOtSauBQ
wddfvM1CnqD651D1uRD1DoTUG6O6B6d6mH9roP4Nh/jXAW+4NUQ7SKYtc2WT
RIjjDTeg+rTbzAzux9UOZHQHikkp6hzAG25A9Sv7PknqRgg4VFv8jE1ZaHgA
b7gB1Z/xzPwoHWXg8O6v+VIDVvkDeMMNqP4cVP1jiHoHvOEGVH8U1T0OuMIN
pj4F6t9siH/h4ujhdsLOTVVpYYLDyx52vzfVaOkGS7i92/iA429qgoP2iTcP
MwTVDvzgN2dqdtDGGW629+Zo3HZJcNhzomCjzA5+B2ediZ2N0ohwRg+3+XsO
Ff3tS3DQ6Yq+6z9f36Fq/WPNrn+ycPXo4QZTrw9Vnw9RjzPc7KDu+YTqHpzh
9hbqX02of39D/OuAP9wSHf6+09on2mYAF8cfbokOScynJn6ZqHKg6cLab+eY
tAmEW6IDF8eXyWoRvA6p644r5nwwIBBuiQ4ezxNL/h3UdXC71d2hcUT2AP5w
S3Twhqq3hqgnEG6JDnao7sEZbjD18VD/tkD8CxdHDzcwcMh3mHB6i22FtbQD
ejijhxtMfUvsgd3KD/gdrFYE1Wlnq+EMN5j6KRfVv6z/9nX/1MlNGes0deDq
0cMNpj7i0SsnBgGJA1NuXg9cs1wCrh493GDqk6DquyDqcYYbTP0BVPfgDzeg
+gaof20g/nUAAEZkMtA=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGBQBmJmID5iFR2ddTnSQXV7R66oudEBBijYBxWvu12SIPNW
7UCIdMfyS/46B2DqxY137w8qFnDgvW50ac0+Q7j403iJsy6lBg4VfP3F2yzk
4eLPoeK5EHEHmLgxqjkOMHtroPaGQ+x1ADuqIdpBMm2ZK5skwp0w8bTbzAzu
x9UOZHQHikkp6hyAia/s+ySpGyHgUG3xMzZloSFc/Ixn5kfpKAOHd3/Nlxqw
ysPFz0HFH0PE4fYeRTUHLp4CtTcbYq/DCTs3VaWFCQ4ve9j93lQbwt35buMD
jr+pCQ7aJ948zBBUO/CD35yp2UH7gO29ORq3XRIc9pwo2Cizg9/BWWdiZ6O0
4YH5ew4V/e1LcNDpir7rP1/foWr9Y82uf7JwcX2oeD5E3MEOas4nVHMc3kLt
1YTa+xtiL9T9iQ5/32ntE20zQAvPRIck5lMTv0xUOdB0Ye23c0zaB2DiXBxf
JqtF8DqkrjuumPPBAC7u8Tyx5N9BXQe3W90dGkdk4eLeUHFriDjcXjtUc+Di
8VB7WyD2QsQd8h0mnN5iW2Et7YDiTqB4S+yB3coP+B2sVgTVaWerHYCJT7mo
/mX9t6/7p05uylinqQMXj3j0yolBQOLAlJvXA9csl4CLJ0HFuyDicHsPoJoD
F2+A2msDsdcBAM/YNy4=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367530946371*^9, 3.5660869866687593`*^9, 
  3.566101742509116*^9, 3.56613918498705*^9, 3.61470779419755*^9},
 CellTags->{
  "cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."},
 CellLabel->
  "During evaluation of \
In[34]:=",ExpressionUUID->"0eb413d0-0c48-47c6-8df0-2f898569bd3d"]
}, Open  ]],

Cell["Again, you can see different views of the system.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "cylindrical lens", "Adding a Cylindrical Lens", 
   "RG8."},ExpressionUUID->"09cb721d-419f-47bb-9788-3802a696cbee"],

Cell[CellGroupData[{

Cell["ShowSystem[opticalsystem, PlotType -> SideView];", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."},
 CellLabel->"In[35]:=",ExpressionUUID->"5e6666c8-aa0e-4d60-801e-bbc7eef0bf62"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, 0.}, {110., 6.123233995736766*^-15}, {
      110., 5.102694996447306*^-15}, {102.75044883428481`, 0.}, {
      106.4219745809556, 0.}}], 
     PolygonBox[{{102.75044883428481`, 0.}, {110., 5.102694996447306*^-15}, {
      110., 4.0821559971578446`*^-15}, {100.67375799589207`, 0.}, {
      102.75044883428481`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 0.}, {110., 
      4.0821559971578446`*^-15}, {110., 3.061616997868384*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, 0.}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 3.061616997868383*^-15}, {
      110., 2.0410779985789223`*^-15}, {100.67375799589207`, 0.}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 0.}, {110., 
      2.0410779985789223`*^-15}, {110., 1.0205389992894613`*^-15}, {
      102.75044883428481`, 0.}, {100.67375799589207`, 0.}}], 
     PolygonBox[{{102.75044883428481`, 0.}, {110., 
      1.0205389992894615`*^-15}, {110., 5.098616525425841*^-31}, {
      106.4219745809556, 0.}, {102.75044883428481`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
       100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
       100.67375799589207`, 0.}, {102.7504488342848, 0.}, {106.4219745809556, 
       0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110.,
        0.}, {110., 0.}, {106.4219745809556, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
        110., -16.66666666666667}, {
        102.75044883428481`, -16.666666666666668`}, {
        106.4219745809556, -25.}}], 
       PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
        110., -16.66666666666667}, {110., -8.333333333333336}, {
        100.67375799589207`, -8.333333333333336}, {
        102.75044883428481`, -16.666666666666668`}}], 
       PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
        110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
        100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}],
        PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
        8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
        100.00000000000001`, 0.}}], 
       PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
        8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`,
         16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
       PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
        16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556,
         24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, -25.}, {
         102.75044883428481`, -16.666666666666668`}, {
         100.67375799589207`, -8.333333333333336}, {
         100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
         8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
         106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
         16.666666666666668`}, {110., 8.333333333333336}, {110., 
         3.552713678800501*^-15}, {110., -8.333333333333329}, {
         110., -16.666666666666657`}, {110., -24.999999999999993`}, {
         106.4219745809556, -25.}}]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 0.}, {
       100.67375799589207`, 2.156825375854339}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 0.}, {102.75044883428481`, 0.}, {
       102.75044883428481`, 4.313650751708678}, {100.67375799589207`, 
       2.156825375854339}, {100.67375799589207`, 0.}}], 
      LineBox[{{102.75044883428481`, 0.}, {106.4219745809556, 0.}, {
       106.4219745809556, 6.4704761275630185`}, {102.75044883428481`, 
       4.313650751708678}, {102.75044883428481`, 0.}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       2.156825375854339}, {100.67375799589209`, 4.166666666666666}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 2.156825375854339}, {102.75044883428481`,
        4.313650751708678}, {102.75044883428481`, 8.333333333333332}, {
       100.67375799589209`, 4.166666666666666}, {100.67375799589207`, 
       2.156825375854339}}], 
      LineBox[{{102.75044883428481`, 4.313650751708678}, {106.4219745809556, 
       6.4704761275630185`}, {106.4219745809556, 12.499999999999998`}, {
       102.75044883428481`, 8.333333333333332}, {102.75044883428481`, 
       4.313650751708678}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       4.166666666666666}, {100.67375799589207`, 5.8925565098878945`}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 4.166666666666666}, {102.75044883428481`,
        8.333333333333332}, {102.7504488342848, 11.785113019775789`}, {
       100.67375799589207`, 5.8925565098878945`}, {100.67375799589209`, 
       4.166666666666666}}], 
      LineBox[{{102.75044883428481`, 8.333333333333332}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 17.677669529663685`}, {
       102.7504488342848, 11.785113019775789`}, {102.75044883428481`, 
       8.333333333333332}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.8925565098878945`}, {100.67375799589209`, 7.216878364870322}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.8925565098878945`}, {102.7504488342848,
        11.785113019775789`}, {102.75044883428481`, 14.433756729740644`}, {
       100.67375799589209`, 7.216878364870322}, {100.67375799589207`, 
       5.8925565098878945`}}], 
      LineBox[{{102.7504488342848, 11.785113019775789`}, {106.4219745809556, 
       17.677669529663685`}, {106.4219745809556, 21.650635094610966`}, {
       102.75044883428481`, 14.433756729740644`}, {102.7504488342848, 
       11.785113019775789`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       7.216878364870322}, {100.67375799589207`, 8.049381885742235}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 7.216878364870322}, {102.75044883428481`,
        14.433756729740644`}, {102.75044883428481`, 16.09876377148447}, {
       100.67375799589207`, 8.049381885742235}, {100.67375799589209`, 
       7.216878364870322}}], 
      LineBox[{{102.75044883428481`, 14.433756729740644`}, {106.4219745809556,
        21.650635094610966`}, {106.4219745809556, 24.148145657226706`}, {
       102.75044883428481`, 16.09876377148447}, {102.75044883428481`, 
       14.433756729740644`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.049381885742235}, {100.67375799589207`, 8.333333333333332}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.049381885742235}, {102.75044883428481`,
        16.09876377148447}, {102.75044883428481`, 16.666666666666664`}, {
       100.67375799589207`, 8.333333333333332}, {100.67375799589207`, 
       8.049381885742235}}], 
      LineBox[{{102.75044883428481`, 16.09876377148447}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 25.}, {102.75044883428481`, 
       16.666666666666664`}, {102.75044883428481`, 16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.333333333333332}, {100.67375799589207`, 8.049381885742235}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.333333333333332}, {102.75044883428481`,
        16.666666666666664`}, {102.75044883428481`, 16.09876377148447}, {
       100.67375799589207`, 8.049381885742235}, {100.67375799589207`, 
       8.333333333333332}}], 
      LineBox[{{102.75044883428481`, 16.666666666666664`}, {106.4219745809556,
        25.}, {106.4219745809556, 24.148145657226706`}, {102.75044883428481`, 
       16.09876377148447}, {102.75044883428481`, 16.666666666666664`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.049381885742235}, {100.67375799589209`, 7.216878364870323}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.049381885742235}, {102.75044883428481`,
        16.09876377148447}, {102.75044883428481`, 14.433756729740645`}, {
       100.67375799589209`, 7.216878364870323}, {100.67375799589207`, 
       8.049381885742235}}], 
      LineBox[{{102.75044883428481`, 16.09876377148447}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 21.65063509461097}, {
       102.75044883428481`, 14.433756729740645`}, {102.75044883428481`, 
       16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       7.216878364870323}, {100.67375799589207`, 5.892556509887896}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 7.216878364870323}, {102.75044883428481`,
        14.433756729740645`}, {102.7504488342848, 11.785113019775793`}, {
       100.67375799589207`, 5.892556509887896}, {100.67375799589209`, 
       7.216878364870323}}], 
      LineBox[{{102.75044883428481`, 14.433756729740645`}, {106.4219745809556,
        21.65063509461097}, {106.4219745809556, 17.67766952966369}, {
       102.7504488342848, 11.785113019775793`}, {102.75044883428481`, 
       14.433756729740645`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.892556509887896}, {100.67375799589209`, 4.166666666666666}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.892556509887896}, {102.7504488342848, 
       11.785113019775793`}, {102.75044883428481`, 8.333333333333332}, {
       100.67375799589209`, 4.166666666666666}, {100.67375799589207`, 
       5.892556509887896}}], 
      LineBox[{{102.7504488342848, 11.785113019775793`}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 12.499999999999998`}, {
       102.75044883428481`, 8.333333333333332}, {102.7504488342848, 
       11.785113019775793`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       4.16666666666667}, {100.67375799589207`, 2.156825375854342}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 4.16666666666667}, {102.7504488342848, 
       8.33333333333334}, {102.75044883428481`, 4.313650751708684}, {
       100.67375799589207`, 2.156825375854342}, {100.67375799589209`, 
       4.16666666666667}}], 
      LineBox[{{102.7504488342848, 8.33333333333334}, {106.4219745809556, 
       12.500000000000009`}, {106.4219745809556, 6.470476127563026}, {
       102.75044883428481`, 4.313650751708684}, {102.7504488342848, 
       8.33333333333334}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       2.156825375854342}, {100.67375799589207`, 1.020538999289461*^-15}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 2.156825375854342}, {102.75044883428481`,
        4.313650751708684}, {102.75044883428481`, 2.041077998578922*^-15}, {
       100.67375799589207`, 1.020538999289461*^-15}, {100.67375799589207`, 
       2.156825375854342}}], 
      LineBox[{{102.75044883428481`, 4.313650751708684}, {106.4219745809556, 
       6.470476127563026}, {106.4219745809556, 3.061616997868383*^-15}, {
       102.75044883428481`, 2.041077998578922*^-15}, {102.75044883428481`, 
       4.313650751708684}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       1.020538999289461*^-15}, {100.67375799589207`, -2.15682537585434}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 1.020538999289461*^-15}, {
       102.75044883428481`, 2.041077998578922*^-15}, {
       102.75044883428481`, -4.31365075170868}, {
       100.67375799589207`, -2.15682537585434}, {100.67375799589207`, 
       1.020538999289461*^-15}}], 
      LineBox[{{102.75044883428481`, 2.041077998578922*^-15}, {
       106.4219745809556, 3.061616997868383*^-15}, {
       106.4219745809556, -6.47047612756302}, {
       102.75044883428481`, -4.31365075170868}, {102.75044883428481`, 
       2.041077998578922*^-15}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -2.156825375854336}, {
       100.67375799589209`, -4.166666666666664}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -2.156825375854336}, {
       102.75044883428481`, -4.313650751708672}, {
       102.75044883428481`, -8.333333333333329}, {
       100.67375799589209`, -4.166666666666664}, {
       100.67375799589207`, -2.156825375854336}}], 
      LineBox[{{102.75044883428481`, -4.313650751708672}, {
       106.4219745809556, -6.470476127563009}, {
       106.4219745809556, -12.499999999999993`}, {
       102.75044883428481`, -8.333333333333329}, {
       102.75044883428481`, -4.313650751708672}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -4.166666666666664}, {
       100.67375799589207`, -5.8925565098878945`}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -4.166666666666664}, {
       102.75044883428481`, -8.333333333333329}, {
       102.75044883428481`, -11.785113019775789`}, {
       100.67375799589207`, -5.8925565098878945`}, {
       100.67375799589209`, -4.166666666666664}}], 
      LineBox[{{102.75044883428481`, -8.333333333333329}, {
       106.4219745809556, -12.499999999999993`}, {
       106.4219745809556, -17.677669529663685`}, {
       102.75044883428481`, -11.785113019775789`}, {
       102.75044883428481`, -8.333333333333329}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -5.892556509887893}, {
       100.67375799589209`, -7.216878364870319}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -5.892556509887893}, {
       102.75044883428481`, -11.785113019775785`}, {
       102.7504488342848, -14.433756729740638`}, {
       100.67375799589209`, -7.216878364870319}, {
       100.67375799589207`, -5.892556509887893}}], 
      LineBox[{{102.75044883428481`, -11.785113019775785`}, {
       106.4219745809556, -17.677669529663678`}, {
       106.4219745809556, -21.65063509461096}, {
       102.7504488342848, -14.433756729740638`}, {
       102.75044883428481`, -11.785113019775785`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -7.216878364870319}, {
       100.67375799589207`, -8.049381885742234}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -7.216878364870319}, {
       102.7504488342848, -14.433756729740638`}, {
       102.75044883428481`, -16.098763771484467`}, {
       100.67375799589207`, -8.049381885742234}, {
       100.67375799589209`, -7.216878364870319}}], 
      LineBox[{{102.7504488342848, -14.433756729740638`}, {
       106.4219745809556, -21.65063509461096}, {
       106.4219745809556, -24.148145657226703`}, {
       102.75044883428481`, -16.098763771484467`}, {
       102.7504488342848, -14.433756729740638`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.049381885742234}, {
       100.67375799589207`, -8.333333333333332}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.049381885742234}, {
       102.75044883428481`, -16.098763771484467`}, {
       102.75044883428481`, -16.666666666666664`}, {
       100.67375799589207`, -8.333333333333332}, {
       100.67375799589207`, -8.049381885742234}}], 
      LineBox[{{102.75044883428481`, -16.098763771484467`}, {
       106.4219745809556, -24.148145657226703`}, {106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666664`}, {
       102.75044883428481`, -16.098763771484467`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.333333333333332}, {
       100.67375799589207`, -8.049381885742235}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.333333333333332}, {
       102.75044883428481`, -16.666666666666664`}, {
       102.75044883428481`, -16.09876377148447}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589207`, -8.333333333333332}}], 
      LineBox[{{102.75044883428481`, -16.666666666666664`}, {
       106.4219745809556, -25.}, {106.4219745809556, -24.14814565722671}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -16.666666666666664`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589207`, -7.216878364870325}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.049381885742235}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -14.43375672974065}, {
       100.67375799589207`, -7.216878364870325}, {
       100.67375799589207`, -8.049381885742235}}], 
      LineBox[{{102.75044883428481`, -16.09876377148447}, {
       106.4219745809556, -24.14814565722671}, {
       106.4219745809556, -21.650635094610976`}, {
       102.75044883428481`, -14.43375672974065}, {
       102.75044883428481`, -16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -7.216878364870325}, {
       100.67375799589207`, -5.892556509887903}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -7.216878364870325}, {
       102.75044883428481`, -14.43375672974065}, {
       102.75044883428481`, -11.785113019775807`}, {
       100.67375799589207`, -5.892556509887903}, {
       100.67375799589207`, -7.216878364870325}}], 
      LineBox[{{102.75044883428481`, -14.43375672974065}, {
       106.4219745809556, -21.650635094610976`}, {
       106.4219745809556, -17.67766952966371}, {
       102.75044883428481`, -11.785113019775807`}, {
       102.75044883428481`, -14.43375672974065}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -5.892556509887897}, {
       100.67375799589209`, -4.16666666666667}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -5.892556509887897}, {
       102.75044883428481`, -11.785113019775794`}, {
       102.7504488342848, -8.33333333333334}, {
       100.67375799589209`, -4.16666666666667}, {
       100.67375799589207`, -5.892556509887897}}], 
      LineBox[{{102.75044883428481`, -11.785113019775794`}, {
       106.4219745809556, -17.677669529663692`}, {
       106.4219745809556, -12.50000000000001}, {
       102.7504488342848, -8.33333333333334}, {
       102.75044883428481`, -11.785113019775794`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -4.16666666666667}, {
       100.67375799589207`, -2.1568253758543463`}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -4.16666666666667}, {
       102.7504488342848, -8.33333333333334}, {
       102.75044883428481`, -4.313650751708693}, {
       100.67375799589207`, -2.1568253758543463`}, {
       100.67375799589209`, -4.16666666666667}}], 
      LineBox[{{102.7504488342848, -8.33333333333334}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -6.470476127563039}, {
       102.75044883428481`, -4.313650751708693}, {
       102.7504488342848, -8.33333333333334}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -2.1568253758543463`}, {
       100.67375799589207`, -9.442564829413298*^-15}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -2.1568253758543463`}, {
       102.75044883428481`, -4.313650751708693}, {
       102.75044883428481`, -1.8885129658826596`*^-14}, {
       100.67375799589207`, -9.442564829413298*^-15}, {
       100.67375799589207`, -2.1568253758543463`}}], 
      LineBox[{{102.75044883428481`, -4.313650751708693}, {
       106.4219745809556, -6.470476127563039}, {
       106.4219745809556, -2.8327694488239898`*^-14}, {
       102.75044883428481`, -1.8885129658826596`*^-14}, {
       102.75044883428481`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{110., 0.}, {110., 0.}, {110., 2.156825375854339}, {110., 
       0.}, {110., 0.}}], 
      LineBox[{{110., 0.}, {110., 0.}, {110., 4.313650751708678}, {110., 
       2.156825375854339}, {110., 0.}}], 
      LineBox[{{110., 0.}, {110., 0.}, {110., 6.4704761275630185`}, {110., 
       4.313650751708678}, {110., 0.}}], 
      LineBox[{{110., 0.}, {110., 2.156825375854339}, {110., 
       4.166666666666666}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 2.156825375854339}, {110., 4.313650751708678}, {110., 
       8.333333333333332}, {110., 4.166666666666666}, {110., 
       2.156825375854339}}], 
      LineBox[{{110., 4.313650751708678}, {110., 6.4704761275630185`}, {110., 
       12.499999999999998`}, {110., 8.333333333333332}, {110., 
       4.313650751708678}}], 
      LineBox[{{110., 0.}, {110., 4.166666666666666}, {110., 
       5.8925565098878945`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 4.166666666666666}, {110., 8.333333333333332}, {110., 
       11.785113019775789`}, {110., 5.8925565098878945`}, {110., 
       4.166666666666666}}], 
      LineBox[{{110., 8.333333333333332}, {110., 12.499999999999998`}, {110., 
       17.677669529663685`}, {110., 11.785113019775789`}, {110., 
       8.333333333333332}}], 
      LineBox[{{110., 0.}, {110., 5.8925565098878945`}, {110., 
       7.216878364870322}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.8925565098878945`}, {110., 11.785113019775789`}, {
       110., 14.433756729740644`}, {110., 7.216878364870322}, {110., 
       5.8925565098878945`}}], 
      LineBox[{{110., 11.785113019775789`}, {110., 17.677669529663685`}, {
       110., 21.650635094610966`}, {110., 14.433756729740644`}, {110., 
       11.785113019775789`}}], 
      LineBox[{{110., 0.}, {110., 7.216878364870322}, {110., 
       8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 7.216878364870322}, {110., 14.433756729740644`}, {110., 
       16.09876377148447}, {110., 8.049381885742235}, {110., 
       7.216878364870322}}], 
      LineBox[{{110., 14.433756729740644`}, {110., 21.650635094610966`}, {
       110., 24.148145657226706`}, {110., 16.09876377148447}, {110., 
       14.433756729740644`}}], 
      LineBox[{{110., 0.}, {110., 8.049381885742235}, {110., 
       8.333333333333332}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.049381885742235}, {110., 16.09876377148447}, {110., 
       16.666666666666664`}, {110., 8.333333333333332}, {110., 
       8.049381885742235}}], 
      LineBox[{{110., 16.09876377148447}, {110., 24.148145657226706`}, {110., 
       25.}, {110., 16.666666666666664`}, {110., 16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., 8.333333333333332}, {110., 
       8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.333333333333332}, {110., 16.666666666666664`}, {110., 
       16.09876377148447}, {110., 8.049381885742235}, {110., 
       8.333333333333332}}], 
      LineBox[{{110., 16.666666666666664`}, {110., 25.}, {110., 
       24.148145657226706`}, {110., 16.09876377148447}, {110., 
       16.666666666666664`}}], 
      LineBox[{{110., 0.}, {110., 8.049381885742235}, {110., 
       7.216878364870323}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.049381885742235}, {110., 16.09876377148447}, {110., 
       14.433756729740645`}, {110., 7.216878364870323}, {110., 
       8.049381885742235}}], 
      LineBox[{{110., 16.09876377148447}, {110., 24.148145657226706`}, {110., 
       21.65063509461097}, {110., 14.433756729740645`}, {110., 
       16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., 7.216878364870323}, {110., 
       5.892556509887896}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 7.216878364870323}, {110., 14.433756729740645`}, {110., 
       11.785113019775793`}, {110., 5.892556509887896}, {110., 
       7.216878364870323}}], 
      LineBox[{{110., 14.433756729740645`}, {110., 21.65063509461097}, {110., 
       17.67766952966369}, {110., 11.785113019775793`}, {110., 
       14.433756729740645`}}], 
      LineBox[{{110., 0.}, {110., 5.892556509887896}, {110., 
       4.166666666666666}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.892556509887896}, {110., 11.785113019775793`}, {110., 
       8.333333333333332}, {110., 4.166666666666666}, {110., 
       5.892556509887896}}], 
      LineBox[{{110., 11.785113019775793`}, {110., 17.67766952966369}, {110., 
       12.499999999999998`}, {110., 8.333333333333332}, {110., 
       11.785113019775793`}}], 
      LineBox[{{110., 0.}, {110., 4.16666666666667}, {110., 
       2.156825375854342}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 4.16666666666667}, {110., 8.33333333333334}, {110., 
       4.313650751708684}, {110., 2.156825375854342}, {110., 
       4.16666666666667}}], 
      LineBox[{{110., 8.33333333333334}, {110., 12.500000000000009`}, {110., 
       6.470476127563026}, {110., 4.313650751708684}, {110., 
       8.33333333333334}}], 
      LineBox[{{110., 0.}, {110., 2.156825375854342}, {110., 
       1.020538999289461*^-15}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 2.156825375854342}, {110., 4.313650751708684}, {110., 
       2.041077998578922*^-15}, {110., 1.020538999289461*^-15}, {110., 
       2.156825375854342}}], 
      LineBox[{{110., 4.313650751708684}, {110., 6.470476127563026}, {110., 
       3.061616997868383*^-15}, {110., 2.041077998578922*^-15}, {110., 
       4.313650751708684}}], 
      LineBox[{{110., 0.}, {110., 1.020538999289461*^-15}, {
       110., -2.15682537585434}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 1.020538999289461*^-15}, {110., 
       2.041077998578922*^-15}, {110., -4.31365075170868}, {
       110., -2.15682537585434}, {110., 1.020538999289461*^-15}}], 
      LineBox[{{110., 2.041077998578922*^-15}, {110., 
       3.061616997868383*^-15}, {110., -6.47047612756302}, {
       110., -4.31365075170868}, {110., 2.041077998578922*^-15}}], 
      LineBox[{{110., 0.}, {110., -2.156825375854336}, {
       110., -4.166666666666664}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -2.156825375854336}, {110., -4.313650751708672}, {
       110., -8.333333333333329}, {110., -4.166666666666664}, {
       110., -2.156825375854336}}], 
      LineBox[{{110., -4.313650751708672}, {110., -6.470476127563009}, {
       110., -12.499999999999993`}, {110., -8.333333333333329}, {
       110., -4.313650751708672}}], 
      LineBox[{{110., 0.}, {110., -4.166666666666664}, {
       110., -5.8925565098878945`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -4.166666666666664}, {110., -8.333333333333329}, {
       110., -11.785113019775789`}, {110., -5.8925565098878945`}, {
       110., -4.166666666666664}}], 
      LineBox[{{110., -8.333333333333329}, {110., -12.499999999999993`}, {
       110., -17.677669529663685`}, {110., -11.785113019775789`}, {
       110., -8.333333333333329}}], 
      LineBox[{{110., 0.}, {110., -5.892556509887893}, {
       110., -7.216878364870319}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -5.892556509887893}, {110., -11.785113019775785`}, {
       110., -14.433756729740638`}, {110., -7.216878364870319}, {
       110., -5.892556509887893}}], 
      LineBox[{{110., -11.785113019775785`}, {110., -17.677669529663678`}, {
       110., -21.65063509461096}, {110., -14.433756729740638`}, {
       110., -11.785113019775785`}}], 
      LineBox[{{110., 0.}, {110., -7.216878364870319}, {
       110., -8.049381885742234}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -7.216878364870319}, {110., -14.433756729740638`}, {
       110., -16.098763771484467`}, {110., -8.049381885742234}, {
       110., -7.216878364870319}}], 
      LineBox[{{110., -14.433756729740638`}, {110., -21.65063509461096}, {
       110., -24.148145657226703`}, {110., -16.098763771484467`}, {
       110., -14.433756729740638`}}], 
      LineBox[{{110., 0.}, {110., -8.049381885742234}, {
       110., -8.333333333333332}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.049381885742234}, {110., -16.098763771484467`}, {
       110., -16.666666666666664`}, {110., -8.333333333333332}, {
       110., -8.049381885742234}}], 
      LineBox[{{110., -16.098763771484467`}, {110., -24.148145657226703`}, {
       110., -25.}, {110., -16.666666666666664`}, {
       110., -16.098763771484467`}}], 
      LineBox[{{110., 0.}, {110., -8.333333333333332}, {
       110., -8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.333333333333332}, {110., -16.666666666666664`}, {
       110., -16.09876377148447}, {110., -8.049381885742235}, {
       110., -8.333333333333332}}], 
      LineBox[{{110., -16.666666666666664`}, {110., -25.}, {
       110., -24.14814565722671}, {110., -16.09876377148447}, {
       110., -16.666666666666664`}}], 
      LineBox[{{110., 0.}, {110., -8.049381885742235}, {
       110., -7.216878364870325}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.049381885742235}, {110., -16.09876377148447}, {
       110., -14.43375672974065}, {110., -7.216878364870325}, {
       110., -8.049381885742235}}], 
      LineBox[{{110., -16.09876377148447}, {110., -24.14814565722671}, {
       110., -21.650635094610976`}, {110., -14.43375672974065}, {
       110., -16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., -7.216878364870325}, {
       110., -5.892556509887903}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -7.216878364870325}, {110., -14.43375672974065}, {
       110., -11.785113019775807`}, {110., -5.892556509887903}, {
       110., -7.216878364870325}}], 
      LineBox[{{110., -14.43375672974065}, {110., -21.650635094610976`}, {
       110., -17.67766952966371}, {110., -11.785113019775807`}, {
       110., -14.43375672974065}}], 
      LineBox[{{110., 0.}, {110., -5.892556509887897}, {
       110., -4.16666666666667}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -5.892556509887897}, {110., -11.785113019775794`}, {
       110., -8.33333333333334}, {110., -4.16666666666667}, {
       110., -5.892556509887897}}], 
      LineBox[{{110., -11.785113019775794`}, {110., -17.677669529663692`}, {
       110., -12.50000000000001}, {110., -8.33333333333334}, {
       110., -11.785113019775794`}}], 
      LineBox[{{110., 0.}, {110., -4.16666666666667}, {
       110., -2.1568253758543463`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -4.16666666666667}, {110., -8.33333333333334}, {
       110., -4.313650751708693}, {110., -2.1568253758543463`}, {
       110., -4.16666666666667}}], 
      LineBox[{{110., -8.33333333333334}, {110., -12.50000000000001}, {
       110., -6.470476127563039}, {110., -4.313650751708693}, {
       110., -8.33333333333334}}], 
      LineBox[{{110., 0.}, {110., -2.1568253758543463`}, {
       110., -9.442564829413298*^-15}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -2.1568253758543463`}, {110., -4.313650751708693}, {
       110., -1.8885129658826596`*^-14}, {110., -9.442564829413298*^-15}, {
       110., -2.1568253758543463`}}], 
      LineBox[{{110., -4.313650751708693}, {110., -6.470476127563039}, {
       110., -2.8327694488239898`*^-14}, {110., -1.8885129658826596`*^-14}, {
       110., -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 0.}, {110., 0.}, {110., 
       6.4704761275630185`}, {106.4219745809556, 6.4704761275630185`}, {
       106.4219745809556, 0.}}], 
      LineBox[{{106.4219745809556, 6.4704761275630185`}, {110., 
       6.4704761275630185`}, {110., 12.499999999999998`}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 6.4704761275630185`}}], 
      LineBox[{{106.4219745809556, 12.499999999999998`}, {110., 
       12.499999999999998`}, {110., 17.677669529663685`}, {106.4219745809556, 
       17.677669529663685`}, {106.4219745809556, 12.499999999999998`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.650635094610966`}, {106.4219745809556, 
       21.650635094610966`}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.650635094610966`}, {110., 
       21.650635094610966`}, {110., 24.148145657226706`}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 21.650635094610966`}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.499999999999998`}, {106.4219745809556, 
       12.499999999999998`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000009`}, {110., 
       12.500000000000009`}, {110., 6.470476127563026}, {106.4219745809556, 
       6.470476127563026}, {106.4219745809556, 12.500000000000009`}}], 
      LineBox[{{106.4219745809556, 6.470476127563026}, {110., 
       6.470476127563026}, {110., 3.061616997868383*^-15}, {106.4219745809556,
        3.061616997868383*^-15}, {106.4219745809556, 6.470476127563026}}], 
      LineBox[{{106.4219745809556, 3.061616997868383*^-15}, {110., 
       3.061616997868383*^-15}, {110., -6.47047612756302}, {
       106.4219745809556, -6.47047612756302}, {106.4219745809556, 
       3.061616997868383*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563009}, {
       110., -6.470476127563009}, {110., -12.499999999999993`}, {
       106.4219745809556, -12.499999999999993`}, {
       106.4219745809556, -6.470476127563009}}], 
      LineBox[{{106.4219745809556, -12.499999999999993`}, {
       110., -12.499999999999993`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999993`}}], 
      LineBox[{{106.4219745809556, -17.677669529663678`}, {
       110., -17.677669529663678`}, {110., -21.65063509461096}, {
       106.4219745809556, -21.65063509461096}, {
       106.4219745809556, -17.677669529663678`}}], 
      LineBox[{{106.4219745809556, -21.65063509461096}, {
       110., -21.65063509461096}, {110., -24.148145657226703`}, {
       106.4219745809556, -24.148145657226703`}, {
       106.4219745809556, -21.65063509461096}}], 
      LineBox[{{106.4219745809556, -24.148145657226703`}, {
       110., -24.148145657226703`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226703`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.14814565722671}, {106.4219745809556, -24.14814565722671}, {
       106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.650635094610976`}, {
       106.4219745809556, -21.650635094610976`}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.650635094610976`}, {
       110., -21.650635094610976`}, {110., -17.67766952966371}, {
       106.4219745809556, -17.67766952966371}, {
       106.4219745809556, -21.650635094610976`}}], 
      LineBox[{{106.4219745809556, -17.677669529663692`}, {
       110., -17.677669529663692`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663692`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563039}, {
       106.4219745809556, -6.470476127563039}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563039}, {
       110., -6.470476127563039}, {110., -2.8327694488239898`*^-14}, {
       106.4219745809556, -2.8327694488239898`*^-14}, {
       106.4219745809556, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{136.4219745809556, 0.}, {140., 6.123233995736766*^-15}, {
      140., 5.102694996447306*^-15}, {132.7504488342848, 0.}, {
      136.4219745809556, 0.}}], 
     PolygonBox[{{132.7504488342848, 0.}, {140., 5.102694996447306*^-15}, {
      140., 4.0821559971578446`*^-15}, {130.67375799589206`, 0.}, {
      132.7504488342848, 0.}}], 
     PolygonBox[{{130.67375799589206`, 0.}, {140., 
      4.0821559971578446`*^-15}, {140., 3.061616997868384*^-15}, {130., 0.}, {
      130.67375799589206`, 0.}}], 
     PolygonBox[{{130., 0.}, {140., 3.061616997868383*^-15}, {140., 
      2.0410779985789223`*^-15}, {130.67375799589206`, 0.}, {130., 0.}}], 
     PolygonBox[{{130.67375799589206`, 0.}, {140., 
      2.0410779985789223`*^-15}, {140., 1.0205389992894613`*^-15}, {
      132.7504488342848, 0.}, {130.67375799589206`, 0.}}], 
     PolygonBox[{{132.7504488342848, 0.}, {140., 1.0205389992894615`*^-15}, {
      140., 5.098616525425841*^-31}, {136.4219745809556, 0.}, {
      132.7504488342848, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{136.4219745809556, 0.}, {132.7504488342848, 0.}, {
       130.67375799589206`, 0.}, {130., 0.}, {130.67375799589206`, 0.}, {
       132.75044883428478`, 0.}, {136.4219745809556, 0.}, {140., 0.}, {140., 
       0.}, {140., 0.}, {140., 0.}, {140., 0.}, {140., 0.}, {140., 0.}, {
       136.4219745809556, 0.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{130., -25.}, {140., -25.}, {140., -16.66666666666667}, {
        130., -16.666666666666668`}, {130., -25.}}], 
       PolygonBox[{{130., -16.666666666666668`}, {140., -16.66666666666667}, {
        140., -8.333333333333336}, {130., -8.333333333333336}, {
        130., -16.666666666666668`}}], 
       PolygonBox[{{130., -8.333333333333336}, {140., -8.333333333333336}, {
        140., -7.105427357601002*^-15}, {130., 0.}, {
        130., -8.333333333333336}}], 
       PolygonBox[{{130., 0.}, {140., 0.}, {140., 8.333333333333332}, {130., 
        8.333333333333329}, {130., 0.}}], 
       PolygonBox[{{130., 8.333333333333329}, {140., 8.333333333333332}, {
        140., 16.666666666666664`}, {130., 16.666666666666664`}, {130., 
        8.333333333333329}}], 
       PolygonBox[{{130., 16.666666666666664`}, {140., 16.666666666666664`}, {
        140., 24.999999999999996`}, {130., 24.999999999999993`}, {130., 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{130., -25.}, {130., -16.666666666666668`}, {
         130., -8.333333333333336}, {130., -3.552713678800501*^-15}, {130., 
         8.333333333333329}, {130., 16.666666666666657`}, {130., 
         24.999999999999993`}, {140., 25.}, {140., 16.666666666666668`}, {
         140., 8.333333333333336}, {140., 3.552713678800501*^-15}, {
         140., -8.333333333333329}, {140., -16.666666666666657`}, {
         140., -24.999999999999993`}, {130., -25.}}]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{136.4219745809556, -25.}, {132.7504488342848, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       136.4219745809556, -16.666666666666664`}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -8.33333333333333}, {
       136.4219745809556, -8.33333333333333}, {
       136.4219745809556, -16.666666666666664`}}], 
      LineBox[{{136.4219745809556, -8.333333333333332}, {
       132.7504488342848, -8.333333333333332}, {132.7504488342848, 
       1.7763568394002505`*^-15}, {136.4219745809556, 
       1.7763568394002505`*^-15}, {136.4219745809556, -8.333333333333332}}], 
      LineBox[{{136.4219745809556, 0.}, {132.7504488342848, 0.}, {
       132.7504488342848, 8.333333333333334}, {136.4219745809556, 
       8.333333333333334}, {136.4219745809556, 0.}}], 
      LineBox[{{136.4219745809556, 8.333333333333336}, {132.7504488342848, 
       8.333333333333336}, {132.7504488342848, 16.66666666666667}, {
       136.4219745809556, 16.66666666666667}, {136.4219745809556, 
       8.333333333333336}}], 
      LineBox[{{136.4219745809556, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 25.000000000000007`}, {
       136.4219745809556, 25.000000000000007`}, {136.4219745809556, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, -25.}, {130.67375799589206`, -25.}, {
       130.67375799589206`, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {132.7504488342848, -25.}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}, {130.67375799589206`, 
       1.7763568394002505`*^-15}, {132.7504488342848, 
       1.7763568394002505`*^-15}, {132.7504488342848, -8.333333333333332}}], 
      LineBox[{{132.7504488342848, 0.}, {130.67375799589206`, 0.}, {
       130.67375799589206`, 8.333333333333334}, {132.7504488342848, 
       8.333333333333334}, {132.7504488342848, 0.}}], 
      LineBox[{{132.7504488342848, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}, {130.67375799589206`, 16.66666666666667}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       8.333333333333336}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {130.67375799589206`, 
       16.66666666666667}, {130.67375799589206`, 25.000000000000007`}, {
       132.7504488342848, 25.000000000000007`}, {132.7504488342848, 
       16.66666666666667}}], 
      LineBox[{{130.67375799589206`, -25.}, {130., -25.}, {
       130., -16.666666666666664`}, {
       130.67375799589206`, -16.666666666666664`}, {
       130.67375799589206`, -25.}}], 
      LineBox[{{130.67375799589206`, -16.666666666666664`}, {
       130., -16.666666666666664`}, {130., -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -16.666666666666664`}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {
       130., -8.333333333333332}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130.67375799589206`, 0.}, {130., 0.}, {130., 
       8.333333333333334}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 0.}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {130., 
       8.333333333333336}, {130., 16.66666666666667}, {130.67375799589206`, 
       16.66666666666667}, {130.67375799589206`, 8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 16.66666666666667}, {130., 
       16.66666666666667}, {130., 25.000000000000007`}, {130.67375799589206`, 
       25.000000000000007`}, {130.67375799589206`, 16.66666666666667}}], 
      LineBox[{{130., -25.}, {130.67375799589206`, -25.}, {
       130.67375799589206`, -16.666666666666664`}, {
       130., -16.666666666666664`}, {130., -25.}}], 
      LineBox[{{130., -16.666666666666664`}, {
       130.67375799589206`, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {130., -8.33333333333333}, {
       130., -16.666666666666664`}}], 
      LineBox[{{130., -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}, {130.67375799589206`, 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130., -8.333333333333332}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 0.}, {130.67375799589206`, 
       8.333333333333334}, {130., 8.333333333333334}, {130., 0.}}], 
      LineBox[{{130., 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}, {130.67375799589206`, 16.66666666666667}, {130., 
       16.66666666666667}, {130., 8.333333333333336}}], 
      LineBox[{{130., 16.66666666666667}, {130.67375799589206`, 
       16.66666666666667}, {130.67375799589206`, 25.000000000000007`}, {130., 
       25.000000000000007`}, {130., 16.66666666666667}}], 
      LineBox[{{130.67375799589206`, -25.}, {132.7504488342848, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -16.666666666666664`}, {
       130.67375799589206`, -25.}}], 
      LineBox[{{130.67375799589206`, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -16.666666666666664`}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {
       132.7504488342848, -8.333333333333332}, {132.7504488342848, 
       1.7763568394002505`*^-15}, {130.67375799589206`, 
       1.7763568394002505`*^-15}, {130.67375799589206`, -8.333333333333332}}],
       LineBox[{{130.67375799589206`, 0.}, {132.7504488342848, 0.}, {
       132.7504488342848, 8.333333333333334}, {130.67375799589206`, 
       8.333333333333334}, {130.67375799589206`, 0.}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       8.333333333333336}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 16.66666666666667}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 25.000000000000007`}, {
       130.67375799589206`, 25.000000000000007`}, {130.67375799589206`, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, -25.}, {136.4219745809556, -25.}, {
       136.4219745809556, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {132.7504488342848, -25.}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       136.4219745809556, -16.666666666666664`}, {
       136.4219745809556, -8.33333333333333}, {
       132.7504488342848, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -8.333333333333332}, {
       136.4219745809556, -8.333333333333332}, {136.4219745809556, 
       1.7763568394002505`*^-15}, {132.7504488342848, 
       1.7763568394002505`*^-15}, {132.7504488342848, -8.333333333333332}}], 
      LineBox[{{132.7504488342848, 0.}, {136.4219745809556, 0.}, {
       136.4219745809556, 8.333333333333334}, {132.7504488342848, 
       8.333333333333334}, {132.7504488342848, 0.}}], 
      LineBox[{{132.7504488342848, 8.333333333333336}, {136.4219745809556, 
       8.333333333333336}, {136.4219745809556, 16.66666666666667}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       8.333333333333336}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       16.66666666666667}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 25.000000000000007`}, {132.7504488342848, 
       16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{140., -25.}, {140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -16.666666666666664`}, {
       140., -8.33333333333333}, {140., -8.33333333333333}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., -8.333333333333332}, {140., 
       1.7763568394002505`*^-15}, {140., 1.7763568394002505`*^-15}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 8.333333333333336}, {140., 
       16.66666666666667}, {140., 16.66666666666667}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 16.66666666666667}, {140., 
       25.000000000000007`}, {140., 25.000000000000007`}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., -25.}, {140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -16.666666666666664`}, {
       140., -8.33333333333333}, {140., -8.33333333333333}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., -8.333333333333332}, {140., 
       1.7763568394002505`*^-15}, {140., 1.7763568394002505`*^-15}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 8.333333333333336}, {140., 
       16.66666666666667}, {140., 16.66666666666667}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 16.66666666666667}, {140., 
       25.000000000000007`}, {140., 25.000000000000007`}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., -25.}, {140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -16.666666666666664`}, {
       140., -8.33333333333333}, {140., -8.33333333333333}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., -8.333333333333332}, {140., 
       1.7763568394002505`*^-15}, {140., 1.7763568394002505`*^-15}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 8.333333333333336}, {140., 
       16.66666666666667}, {140., 16.66666666666667}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 16.66666666666667}, {140., 
       25.000000000000007`}, {140., 25.000000000000007`}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., -25.}, {140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -16.666666666666664`}, {
       140., -8.33333333333333}, {140., -8.33333333333333}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., -8.333333333333332}, {140., 
       1.7763568394002505`*^-15}, {140., 1.7763568394002505`*^-15}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 8.333333333333336}, {140., 
       16.66666666666667}, {140., 16.66666666666667}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 16.66666666666667}, {140., 
       25.000000000000007`}, {140., 25.000000000000007`}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., -25.}, {140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -16.666666666666664`}, {
       140., -8.33333333333333}, {140., -8.33333333333333}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., -8.333333333333332}, {140., 
       1.7763568394002505`*^-15}, {140., 1.7763568394002505`*^-15}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 8.333333333333336}, {140., 
       16.66666666666667}, {140., 16.66666666666667}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 16.66666666666667}, {140., 
       25.000000000000007`}, {140., 25.000000000000007`}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., -25.}, {140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -16.666666666666664`}, {
       140., -8.33333333333333}, {140., -8.33333333333333}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., -8.333333333333332}, {140., 
       1.7763568394002505`*^-15}, {140., 1.7763568394002505`*^-15}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 8.333333333333336}, {140., 
       16.66666666666667}, {140., 16.66666666666667}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 16.66666666666667}, {140., 
       25.000000000000007`}, {140., 25.000000000000007`}, {140., 
       16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       132.7504488342848, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{132.7504488342848, 25.}, {140., 25.}, {140., 25.}, {
       130.67375799589206`, 25.}, {132.7504488342848, 25.}}], 
      LineBox[{{130.67375799589206`, 25.}, {140., 25.}, {140., 25.}, {130., 
       25.}, {130.67375799589206`, 25.}}], 
      LineBox[{{130., 25.}, {140., 25.}, {140., 25.}, {130.67375799589206`, 
       25.}, {130., 25.}}], 
      LineBox[{{130.67375799589206`, 25.}, {140., 25.}, {140., 25.}, {
       132.7504488342848, 25.}, {130.67375799589206`, 25.}}], 
      LineBox[{{132.7504488342848, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {132.7504488342848, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 
       16.666666666666668`}, {136.4219745809556, 16.666666666666668`}, {
       136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 16.666666666666668`}, {140., 
       16.666666666666668`}, {140., 8.333333333333336}, {136.4219745809556, 
       8.333333333333336}, {136.4219745809556, 16.666666666666668`}}], 
      LineBox[{{136.4219745809556, 8.333333333333334}, {140., 
       8.333333333333334}, {140., 1.3877787807814457`*^-15}, {
       136.4219745809556, 1.3877787807814457`*^-15}, {136.4219745809556, 
       8.333333333333334}}], 
      LineBox[{{136.4219745809556, 0.}, {140., 0.}, {
       140., -8.333333333333332}, {136.4219745809556, -8.333333333333332}, {
       136.4219745809556, 0.}}], 
      LineBox[{{136.4219745809556, -8.333333333333332}, {
       140., -8.333333333333332}, {140., -16.666666666666664`}, {
       136.4219745809556, -16.666666666666664`}, {
       136.4219745809556, -8.333333333333332}}], 
      LineBox[{{136.4219745809556, -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -24.999999999999993`}, {
       136.4219745809556, -24.999999999999993`}, {
       136.4219745809556, -16.666666666666664`}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       132.7504488342848, -25.}, {136.4219745809556, -25.}}], 
      LineBox[{{132.7504488342848, -25.}, {140., -25.}, {140., -25.}, {
       130.67375799589206`, -25.}, {132.7504488342848, -25.}}], 
      LineBox[{{130.67375799589206`, -25.}, {140., -25.}, {140., -25.}, {
       130., -25.}, {130.67375799589206`, -25.}}], 
      LineBox[{{130., -25.}, {140., -25.}, {140., -25.}, {
       130.67375799589206`, -25.}, {130., -25.}}], 
      LineBox[{{130.67375799589206`, -25.}, {140., -25.}, {140., -25.}, {
       132.7504488342848, -25.}, {130.67375799589206`, -25.}}], 
      LineBox[{{132.7504488342848, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {132.7504488342848, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {
       140., -16.666666666666668`}, {
       136.4219745809556, -16.666666666666668`}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -16.666666666666668`}, {
       140., -16.666666666666668`}, {140., -8.333333333333336}, {
       136.4219745809556, -8.333333333333336}, {
       136.4219745809556, -16.666666666666668`}}], 
      LineBox[{{136.4219745809556, -8.333333333333334}, {
       140., -8.333333333333334}, {140., -1.3877787807814457`*^-15}, {
       136.4219745809556, -1.3877787807814457`*^-15}, {
       136.4219745809556, -8.333333333333334}}], 
      LineBox[{{136.4219745809556, 0.}, {140., 0.}, {140., 
       8.333333333333332}, {136.4219745809556, 8.333333333333332}, {
       136.4219745809556, 0.}}], 
      LineBox[{{136.4219745809556, 8.333333333333332}, {140., 
       8.333333333333332}, {140., 16.666666666666664`}, {136.4219745809556, 
       16.666666666666664`}, {136.4219745809556, 8.333333333333332}}], 
      LineBox[{{136.4219745809556, 16.666666666666664`}, {140., 
       16.666666666666664`}, {140., 24.999999999999993`}, {136.4219745809556, 
       24.999999999999993`}, {136.4219745809556, 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -30.}, {250., -30.}, {250., 30.}, {250., 30.}, {
       250., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -30.}, {0., -30.}, {0., 30.}, {250., 30.}, {
       250., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -30}, {0, -30}, {0, 30}, {0, 30}, {0, -30}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., -30.}, {250., -30.}, {250., 30.}, {0., 30.}, {
       0., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -30.}, {250., -30.}, {0., -30.}, {0., -30.}, {
       250., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., 30.}, {250., 30.}, {0., 30.}, {0., 30.}, {250., 
       30.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {103.30336650761734`, 0.}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761726`, -14.155904040684312`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, -17.744824540531273`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, -7.805383496862866}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 7.805383496862857}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 17.744824540531273`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761726`, 14.155904040684318`}}]}, 
     {Arrowheads[Small], ArrowBox[{{103.30336650761734`, 0.}, {110., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761726`, -14.155904040684312`}, {
       110., -14.06465215440194}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, -17.744824540531273`}, {
       110., -17.630437730164413`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, -7.805383496862866}, {
       110., -7.755068379919505}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 7.805383496862857}, {110., 
       7.7550683799194955`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 17.744824540531273`}, {110., 
       17.630437730164413`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761726`, 14.155904040684318`}, {110., 
       14.064652154401946`}}]}, 
     {Arrowheads[Small], ArrowBox[{{110., 0.}, {133.0354181644418, 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -14.06465215440194}, {
       131.1871380222869, -13.625999516698343`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -17.630437730164413`}, {
       130.15175276411347`, -17.107445333426096`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -7.755068379919505}, {
       132.4684385112241, -7.498573927423303}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 7.7550683799194955`}, {132.4684385112241, 
       7.498573927423293}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 17.630437730164413`}, {130.1517527641135, 
       17.107445333426096`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 14.064652154401946`}, {131.18713802228686`, 
       13.625999516698348`}}]}, 
     {Arrowheads[Small], ArrowBox[{{133.0354181644418, 0.}, {140., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{131.1871380222869, -13.625999516698343`}, {
       140., -13.505485256879414`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{130.15175276411347`, -17.107445333426096`}, {
       140., -16.939149962663937`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{132.4684385112241, -7.498573927423303}, {
       140., -7.441560872589042}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{132.4684385112241, 7.498573927423293}, {140., 
       7.441560872589032}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{130.1517527641135, 17.107445333426096`}, {140., 
       16.939149962663937`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{131.18713802228686`, 13.625999516698348`}, {140., 
       13.505485256879417`}}]}, 
     {Arrowheads[Small], ArrowBox[{{140., 0.}, {250., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., -13.505485256879414`}, {250., -11.209316203680022`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., -16.939149962663937`}, {250., -14.08140875429107}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., -7.441560872589042}, {250., -6.163743284987863}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 7.441560872589032}, {250., 6.163743284987854}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 16.939149962663937`}, {250., 14.08140875429107}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 13.505485256879417`}, {250., 
       11.209316203680025`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQfcQqOjrrcqQDAxTsg/JDpDuWX/LXOQCT571udGnN
PkM4v4Kvv3ibhTycnwvhO6Cpd4CZFw4xD2JPQzTcPhg/oztQTEpR5wCMX23x
MzZloSGc/+6v+VIDVnk4/zGE74CmHs7PhpjncMLOTVVpYQLcvncbH3D8TU1w
+MFvztTsoH3A9t4cjdsuCQ7OOhM7G6UND8zfc6job1+CQ9X6x5pd/2Th/HwI
38EOVb3DW6h5vyHmQe1PRPNfokPThbXfzjFpH4DxU9cdV8z5YADnu93q7tA4
IgvnW0P4Dmjq4fwWiHkQvkM+qn1AvtWKoDrtbLUDMP7UyU0Z6zR14PwpN68H
rlkuAed3QfgOaOrhfBuIeQ4AjXq3iQ==
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L2\"\>", {135., -30.709792981621252}, {0., 0.}], 
    InsetBox["\<\"L1\"\>", {105., -30.709792981621252}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56336753108139*^9, 3.566086986993932*^9, 
  3.566101742910981*^9, 3.566139185434449*^9, 3.614707794425819*^9},
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."},
 CellLabel->
  "During evaluation of \
In[35]:=",ExpressionUUID->"3dab169f-74d4-49da-ad43-db9c6f5ac4cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ShowSystem[opticalsystem, PlotType -> TopView];", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."},
 CellLabel->"In[36]:=",ExpressionUUID->"861c617d-2d33-4fa6-a2ed-2b5e8e334a04"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{106.4219745809556, -25.}, {110., -25.}, {
      110., -16.66666666666667}, {
      102.75044883428481`, -16.666666666666668`}, {106.4219745809556, -25.}}],
      PolygonBox[{{102.75044883428481`, -16.666666666666668`}, {
      110., -16.66666666666667}, {110., -8.333333333333336}, {
      100.67375799589207`, -8.333333333333336}, {
      102.75044883428481`, -16.666666666666668`}}], 
     PolygonBox[{{100.67375799589207`, -8.333333333333336}, {
      110., -8.333333333333336}, {110., -7.105427357601002*^-15}, {
      100.00000000000001`, 0.}, {100.67375799589207`, -8.333333333333336}}], 
     PolygonBox[{{100.00000000000001`, 0.}, {110., 0.}, {110., 
      8.333333333333332}, {100.67375799589207`, 8.333333333333329}, {
      100.00000000000001`, 0.}}], 
     PolygonBox[{{100.67375799589207`, 8.333333333333329}, {110., 
      8.333333333333332}, {110., 16.666666666666664`}, {102.75044883428481`, 
      16.666666666666664`}, {100.67375799589207`, 8.333333333333329}}], 
     PolygonBox[{{102.75044883428481`, 16.666666666666664`}, {110., 
      16.666666666666664`}, {110., 24.999999999999996`}, {106.4219745809556, 
      24.999999999999993`}, {102.75044883428481`, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666668`}, {
       100.67375799589207`, -8.333333333333336}, {
       100.00000000000001`, -3.552713678800501*^-15}, {100.67375799589207`, 
       8.333333333333329}, {102.7504488342848, 16.666666666666657`}, {
       106.4219745809556, 24.999999999999993`}, {110., 25.}, {110., 
       16.666666666666668`}, {110., 8.333333333333336}, {110., 
       3.552713678800501*^-15}, {110., -8.333333333333329}, {
       110., -16.666666666666657`}, {110., -24.999999999999993`}, {
       106.4219745809556, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{106.4219745809556, 0.}, {110., 3.061616997868383*^-15}, {
        110., 2.551347498223653*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}, {106.4219745809556, 0.}}], 
       PolygonBox[{{102.75044883428481`, 5.102694996447305*^-16}, {110., 
        2.551347498223653*^-15}, {110., 2.0410779985789223`*^-15}, {
        100.67375799589207`, 1.020538999289461*^-15}, {102.75044883428481`, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{100.67375799589207`, 1.020538999289461*^-15}, {110., 
        2.0410779985789223`*^-15}, {110., 1.530808498934192*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15}, {100.67375799589207`, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{100.00000000000001`, 1.5308084989341915`*^-15}, {110., 
        1.5308084989341915`*^-15}, {110., 1.0205389992894611`*^-15}, {
        100.67375799589207`, 2.041077998578922*^-15}, {100.00000000000001`, 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{100.67375799589207`, 2.041077998578922*^-15}, {110., 
        1.0205389992894611`*^-15}, {110., 5.102694996447307*^-16}, {
        102.75044883428481`, 2.5513474982236525`*^-15}, {100.67375799589207`, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{102.75044883428481`, 2.5513474982236525`*^-15}, {110., 
        5.102694996447308*^-16}, {110., 2.5493082627129206`*^-31}, {
        106.4219745809556, 3.0616169978683826`*^-15}, {102.75044883428481`, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{106.4219745809556, 0.}, {102.75044883428481`, 0.}, {
         100.67375799589207`, 0.}, {100.00000000000001`, 0.}, {
         100.67375799589207`, 0.}, {102.7504488342848, 0.}, {
         106.4219745809556, 0.}, {110., 0.}, {110., 0.}, {110., 0.}, {110., 
         0.}, {110., 0.}, {110., 0.}, {110., 0.}, {106.4219745809556, 
         0.}}]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.333333333333332}, {100.67375799589207`, 8.049381885742235}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.333333333333332}, {102.75044883428481`,
        16.666666666666664`}, {102.75044883428481`, 16.09876377148447}, {
       100.67375799589207`, 8.049381885742235}, {100.67375799589207`, 
       8.333333333333332}}], 
      LineBox[{{102.75044883428481`, 16.666666666666664`}, {106.4219745809556,
        25.}, {106.4219745809556, 24.148145657226706`}, {102.75044883428481`, 
       16.09876377148447}, {102.75044883428481`, 16.666666666666664`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.049381885742235}, {100.67375799589209`, 7.216878364870323}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.049381885742235}, {102.75044883428481`,
        16.09876377148447}, {102.75044883428481`, 14.433756729740645`}, {
       100.67375799589209`, 7.216878364870323}, {100.67375799589207`, 
       8.049381885742235}}], 
      LineBox[{{102.75044883428481`, 16.09876377148447}, {106.4219745809556, 
       24.148145657226706`}, {106.4219745809556, 21.65063509461097}, {
       102.75044883428481`, 14.433756729740645`}, {102.75044883428481`, 
       16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       7.216878364870323}, {100.67375799589207`, 5.892556509887896}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 7.216878364870323}, {102.75044883428481`,
        14.433756729740645`}, {102.7504488342848, 11.785113019775793`}, {
       100.67375799589207`, 5.892556509887896}, {100.67375799589209`, 
       7.216878364870323}}], 
      LineBox[{{102.75044883428481`, 14.433756729740645`}, {106.4219745809556,
        21.65063509461097}, {106.4219745809556, 17.67766952966369}, {
       102.7504488342848, 11.785113019775793`}, {102.75044883428481`, 
       14.433756729740645`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.892556509887896}, {100.67375799589209`, 4.166666666666668}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.892556509887896}, {102.7504488342848, 
       11.785113019775793`}, {102.75044883428481`, 8.333333333333336}, {
       100.67375799589209`, 4.166666666666668}, {100.67375799589207`, 
       5.892556509887896}}], 
      LineBox[{{102.7504488342848, 11.785113019775793`}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 12.500000000000004`}, {
       102.75044883428481`, 8.333333333333336}, {102.7504488342848, 
       11.785113019775793`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       4.166666666666668}, {100.67375799589207`, 2.156825375854341}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 4.166666666666668}, {102.75044883428481`,
        8.333333333333336}, {102.75044883428481`, 4.313650751708682}, {
       100.67375799589207`, 2.156825375854341}, {100.67375799589209`, 
       4.166666666666668}}], 
      LineBox[{{102.75044883428481`, 8.333333333333336}, {106.4219745809556, 
       12.500000000000004`}, {106.4219745809556, 6.470476127563024}, {
       102.75044883428481`, 4.313650751708682}, {102.75044883428481`, 
       8.333333333333336}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       2.156825375854341}, {100.67375799589207`, 2.3606412073533245`*^-15}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 2.156825375854341}, {102.75044883428481`,
        4.313650751708682}, {102.75044883428481`, 4.721282414706649*^-15}, {
       100.67375799589207`, 2.3606412073533245`*^-15}, {100.67375799589207`, 
       2.156825375854341}}], 
      LineBox[{{102.75044883428481`, 4.313650751708682}, {106.4219745809556, 
       6.470476127563024}, {106.4219745809556, 7.0819236220599744`*^-15}, {
       102.75044883428481`, 4.721282414706649*^-15}, {102.75044883428481`, 
       4.313650751708682}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.102694996447305*^-16}, {100.67375799589207`, -2.1568253758543383`}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.102694996447305*^-16}, {
       102.75044883428481`, 1.020538999289461*^-15}, {
       102.75044883428481`, -4.313650751708677}, {
       100.67375799589207`, -2.1568253758543383`}, {100.67375799589207`, 
       5.102694996447305*^-16}}], 
      LineBox[{{102.75044883428481`, 1.020538999289461*^-15}, {
       106.4219745809556, 1.5308084989341915`*^-15}, {
       106.4219745809556, -6.470476127563016}, {
       102.75044883428481`, -4.313650751708677}, {102.75044883428481`, 
       1.020538999289461*^-15}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -2.1568253758543383`}, {
       100.67375799589209`, -4.166666666666664}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -2.1568253758543383`}, {
       102.75044883428481`, -4.313650751708677}, {
       102.75044883428481`, -8.333333333333329}, {
       100.67375799589209`, -4.166666666666664}, {
       100.67375799589207`, -2.1568253758543383`}}], 
      LineBox[{{102.75044883428481`, -4.313650751708677}, {
       106.4219745809556, -6.470476127563016}, {
       106.4219745809556, -12.499999999999995`}, {
       102.75044883428481`, -8.333333333333329}, {
       102.75044883428481`, -4.313650751708677}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -4.166666666666664}, {
       100.67375799589207`, -5.8925565098878945`}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -4.166666666666664}, {
       102.75044883428481`, -8.333333333333329}, {
       102.7504488342848, -11.785113019775789`}, {
       100.67375799589207`, -5.8925565098878945`}, {
       100.67375799589209`, -4.166666666666664}}], 
      LineBox[{{102.75044883428481`, -8.333333333333329}, {
       106.4219745809556, -12.499999999999995`}, {
       106.4219745809556, -17.677669529663685`}, {
       102.7504488342848, -11.785113019775789`}, {
       102.75044883428481`, -8.333333333333329}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -5.8925565098878945`}, {
       100.67375799589209`, -7.216878364870323}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -5.8925565098878945`}, {
       102.7504488342848, -11.785113019775789`}, {
       102.75044883428481`, -14.433756729740645`}, {
       100.67375799589209`, -7.216878364870323}, {
       100.67375799589207`, -5.8925565098878945`}}], 
      LineBox[{{102.7504488342848, -11.785113019775789`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097}, {
       102.75044883428481`, -14.433756729740645`}, {
       102.7504488342848, -11.785113019775789`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -7.21687836487032}, {
       100.67375799589207`, -8.049381885742235}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -7.21687836487032}, {
       102.7504488342848, -14.43375672974064}, {
       102.75044883428481`, -16.09876377148447}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589209`, -7.21687836487032}}], 
      LineBox[{{102.7504488342848, -14.43375672974064}, {
       106.4219745809556, -21.650635094610962`}, {
       106.4219745809556, -24.148145657226706`}, {
       102.75044883428481`, -16.09876377148447}, {
       102.7504488342848, -14.43375672974064}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589207`, -8.333333333333332}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.049381885742235}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -16.666666666666664`}, {
       100.67375799589207`, -8.333333333333332}, {
       100.67375799589207`, -8.049381885742235}}], 
      LineBox[{{102.75044883428481`, -16.09876377148447}, {
       106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}, {
       102.75044883428481`, -16.666666666666664`}, {
       102.75044883428481`, -16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.333333333333332}, {
       100.67375799589207`, -8.049381885742235}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.333333333333332}, {
       102.75044883428481`, -16.666666666666664`}, {
       102.75044883428481`, -16.09876377148447}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589207`, -8.333333333333332}}], 
      LineBox[{{102.75044883428481`, -16.666666666666664`}, {
       106.4219745809556, -25.}, {106.4219745809556, -24.148145657226706`}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -16.666666666666664`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -8.049381885742235}, {
       100.67375799589209`, -7.216878364870323}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -8.049381885742235}, {
       102.75044883428481`, -16.09876377148447}, {
       102.75044883428481`, -14.433756729740645`}, {
       100.67375799589209`, -7.216878364870323}, {
       100.67375799589207`, -8.049381885742235}}], 
      LineBox[{{102.75044883428481`, -16.09876377148447}, {
       106.4219745809556, -24.14814565722671}, {
       106.4219745809556, -21.65063509461097}, {
       102.75044883428481`, -14.433756729740645`}, {
       102.75044883428481`, -16.09876377148447}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -7.216878364870323}, {
       100.67375799589207`, -5.892556509887897}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -7.216878364870323}, {
       102.75044883428481`, -14.433756729740645`}, {
       102.75044883428481`, -11.785113019775794`}, {
       100.67375799589207`, -5.892556509887897}, {
       100.67375799589209`, -7.216878364870323}}], 
      LineBox[{{102.75044883428481`, -14.433756729740645`}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -17.677669529663692`}, {
       102.75044883428481`, -11.785113019775794`}, {
       102.75044883428481`, -14.433756729740645`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -5.892556509887898}, {
       100.67375799589209`, -4.16666666666667}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -5.892556509887898}, {
       102.75044883428481`, -11.785113019775796`}, {
       102.7504488342848, -8.33333333333334}, {
       100.67375799589209`, -4.16666666666667}, {
       100.67375799589207`, -5.892556509887898}}], 
      LineBox[{{102.75044883428481`, -11.785113019775796`}, {
       106.4219745809556, -17.677669529663696`}, {
       106.4219745809556, -12.50000000000001}, {
       102.7504488342848, -8.33333333333334}, {
       102.75044883428481`, -11.785113019775796`}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589209`, -4.16666666666667}, {
       100.67375799589207`, -2.156825375854346}, {100.00000000000001`, 0.}, {
       100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, -4.16666666666667}, {
       102.7504488342848, -8.33333333333334}, {
       102.75044883428481`, -4.313650751708692}, {
       100.67375799589207`, -2.156825375854346}, {
       100.67375799589209`, -4.16666666666667}}], 
      LineBox[{{102.7504488342848, -8.33333333333334}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -6.470476127563038}, {
       102.75044883428481`, -4.313650751708692}, {
       102.7504488342848, -8.33333333333334}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -2.156825375854346}, {
       100.67375799589207`, -8.932295329768568*^-15}, {100.00000000000001`, 
       0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, -2.156825375854346}, {
       102.75044883428481`, -4.313650751708692}, {
       102.75044883428481`, -1.7864590659537137`*^-14}, {
       100.67375799589207`, -8.932295329768568*^-15}, {
       100.67375799589207`, -2.156825375854346}}], 
      LineBox[{{102.75044883428481`, -4.313650751708692}, {
       106.4219745809556, -6.470476127563038}, {
       106.4219745809556, -2.6796885989305705`*^-14}, {
       102.75044883428481`, -1.7864590659537137`*^-14}, {
       102.75044883428481`, -4.313650751708692}}], 
      LineBox[{{100.00000000000001`, 0.}, {
       100.67375799589207`, -1.5308084989341913`*^-15}, {100.67375799589207`, 
       2.1568253758543356`}, {100.00000000000001`, 0.}, {100.00000000000001`, 
       0.}}], LineBox[{{100.67375799589207`, -1.5308084989341913`*^-15}, {
       102.75044883428481`, -3.0616169978683826`*^-15}, {102.75044883428481`, 
       4.313650751708671}, {100.67375799589207`, 2.1568253758543356`}, {
       100.67375799589207`, -1.5308084989341913`*^-15}}], 
      LineBox[{{102.75044883428481`, -3.0616169978683826`*^-15}, {
       106.4219745809556, -4.592425496802574*^-15}, {106.4219745809556, 
       6.470476127563007}, {102.75044883428481`, 4.313650751708671}, {
       102.75044883428481`, -3.0616169978683826`*^-15}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       2.1568253758543356`}, {100.67375799589207`, 4.166666666666661}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 2.1568253758543356`}, {
       102.75044883428481`, 4.313650751708671}, {102.75044883428481`, 
       8.333333333333321}, {100.67375799589207`, 4.166666666666661}, {
       100.67375799589207`, 2.1568253758543356`}}], 
      LineBox[{{102.75044883428481`, 4.313650751708671}, {106.4219745809556, 
       6.470476127563007}, {106.4219745809556, 12.499999999999984`}, {
       102.75044883428481`, 8.333333333333321}, {102.75044883428481`, 
       4.313650751708671}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       4.166666666666661}, {100.67375799589207`, 5.89255650988789}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 4.166666666666661}, {102.75044883428481`,
        8.333333333333321}, {102.75044883428481`, 11.78511301977578}, {
       100.67375799589207`, 5.89255650988789}, {100.67375799589207`, 
       4.166666666666661}}], 
      LineBox[{{102.75044883428481`, 8.333333333333321}, {106.4219745809556, 
       12.499999999999984`}, {106.4219745809556, 17.67766952966367}, {
       102.75044883428481`, 11.78511301977578}, {102.75044883428481`, 
       8.333333333333321}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       5.8925565098878945`}, {100.67375799589209`, 7.216878364870319}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 5.8925565098878945`}, {
       102.75044883428481`, 11.785113019775789`}, {102.7504488342848, 
       14.433756729740638`}, {100.67375799589209`, 7.216878364870319}, {
       100.67375799589207`, 5.8925565098878945`}}], 
      LineBox[{{102.75044883428481`, 11.785113019775789`}, {106.4219745809556,
        17.677669529663685`}, {106.4219745809556, 21.65063509461096}, {
       102.7504488342848, 14.433756729740638`}, {102.75044883428481`, 
       11.785113019775789`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589209`, 
       7.216878364870319}, {100.67375799589207`, 8.049381885742234}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589209`, 7.216878364870319}, {102.7504488342848, 
       14.433756729740638`}, {102.75044883428481`, 16.098763771484467`}, {
       100.67375799589207`, 8.049381885742234}, {100.67375799589209`, 
       7.216878364870319}}], 
      LineBox[{{102.7504488342848, 14.433756729740638`}, {106.4219745809556, 
       21.65063509461096}, {106.4219745809556, 24.148145657226703`}, {
       102.75044883428481`, 16.098763771484467`}, {102.7504488342848, 
       14.433756729740638`}}], 
      LineBox[{{100.00000000000001`, 0.}, {100.67375799589207`, 
       8.049381885742234}, {100.67375799589207`, 8.333333333333332}, {
       100.00000000000001`, 0.}, {100.00000000000001`, 0.}}], 
      LineBox[{{100.67375799589207`, 8.049381885742234}, {102.75044883428481`,
        16.098763771484467`}, {102.75044883428481`, 16.666666666666664`}, {
       100.67375799589207`, 8.333333333333332}, {100.67375799589207`, 
       8.049381885742234}}], 
      LineBox[{{102.75044883428481`, 16.098763771484467`}, {106.4219745809556,
        24.148145657226703`}, {106.4219745809556, 25.}, {102.75044883428481`, 
       16.666666666666664`}, {102.75044883428481`, 16.098763771484467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{110., 0.}, {110., 8.333333333333332}, {110., 
       8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.333333333333332}, {110., 16.666666666666664`}, {110., 
       16.09876377148447}, {110., 8.049381885742235}, {110., 
       8.333333333333332}}], 
      LineBox[{{110., 16.666666666666664`}, {110., 25.}, {110., 
       24.148145657226706`}, {110., 16.09876377148447}, {110., 
       16.666666666666664`}}], 
      LineBox[{{110., 0.}, {110., 8.049381885742235}, {110., 
       7.216878364870323}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.049381885742235}, {110., 16.09876377148447}, {110., 
       14.433756729740645`}, {110., 7.216878364870323}, {110., 
       8.049381885742235}}], 
      LineBox[{{110., 16.09876377148447}, {110., 24.148145657226706`}, {110., 
       21.65063509461097}, {110., 14.433756729740645`}, {110., 
       16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., 7.216878364870323}, {110., 
       5.892556509887896}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 7.216878364870323}, {110., 14.433756729740645`}, {110., 
       11.785113019775793`}, {110., 5.892556509887896}, {110., 
       7.216878364870323}}], 
      LineBox[{{110., 14.433756729740645`}, {110., 21.65063509461097}, {110., 
       17.67766952966369}, {110., 11.785113019775793`}, {110., 
       14.433756729740645`}}], 
      LineBox[{{110., 0.}, {110., 5.892556509887896}, {110., 
       4.166666666666668}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.892556509887896}, {110., 11.785113019775793`}, {110., 
       8.333333333333336}, {110., 4.166666666666668}, {110., 
       5.892556509887896}}], 
      LineBox[{{110., 11.785113019775793`}, {110., 17.67766952966369}, {110., 
       12.500000000000004`}, {110., 8.333333333333336}, {110., 
       11.785113019775793`}}], 
      LineBox[{{110., 0.}, {110., 4.166666666666668}, {110., 
       2.156825375854341}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 4.166666666666668}, {110., 8.333333333333336}, {110., 
       4.313650751708682}, {110., 2.156825375854341}, {110., 
       4.166666666666668}}], 
      LineBox[{{110., 8.333333333333336}, {110., 12.500000000000004`}, {110., 
       6.470476127563024}, {110., 4.313650751708682}, {110., 
       8.333333333333336}}], 
      LineBox[{{110., 0.}, {110., 2.156825375854341}, {110., 
       2.3606412073533245`*^-15}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 2.156825375854341}, {110., 4.313650751708682}, {110., 
       4.721282414706649*^-15}, {110., 2.3606412073533245`*^-15}, {110., 
       2.156825375854341}}], 
      LineBox[{{110., 4.313650751708682}, {110., 6.470476127563024}, {110., 
       7.0819236220599744`*^-15}, {110., 4.721282414706649*^-15}, {110., 
       4.313650751708682}}], 
      LineBox[{{110., 0.}, {110., 5.102694996447305*^-16}, {
       110., -2.1568253758543383`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.102694996447305*^-16}, {110., 
       1.020538999289461*^-15}, {110., -4.313650751708677}, {
       110., -2.1568253758543383`}, {110., 5.102694996447305*^-16}}], 
      LineBox[{{110., 1.020538999289461*^-15}, {110., 
       1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
       110., -4.313650751708677}, {110., 1.020538999289461*^-15}}], 
      LineBox[{{110., 0.}, {110., -2.1568253758543383`}, {
       110., -4.166666666666664}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -2.1568253758543383`}, {110., -4.313650751708677}, {
       110., -8.333333333333329}, {110., -4.166666666666664}, {
       110., -2.1568253758543383`}}], 
      LineBox[{{110., -4.313650751708677}, {110., -6.470476127563016}, {
       110., -12.499999999999995`}, {110., -8.333333333333329}, {
       110., -4.313650751708677}}], 
      LineBox[{{110., 0.}, {110., -4.166666666666664}, {
       110., -5.8925565098878945`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -4.166666666666664}, {110., -8.333333333333329}, {
       110., -11.785113019775789`}, {110., -5.8925565098878945`}, {
       110., -4.166666666666664}}], 
      LineBox[{{110., -8.333333333333329}, {110., -12.499999999999995`}, {
       110., -17.677669529663685`}, {110., -11.785113019775789`}, {
       110., -8.333333333333329}}], 
      LineBox[{{110., 0.}, {110., -5.8925565098878945`}, {
       110., -7.216878364870323}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -5.8925565098878945`}, {110., -11.785113019775789`}, {
       110., -14.433756729740645`}, {110., -7.216878364870323}, {
       110., -5.8925565098878945`}}], 
      LineBox[{{110., -11.785113019775789`}, {110., -17.677669529663685`}, {
       110., -21.65063509461097}, {110., -14.433756729740645`}, {
       110., -11.785113019775789`}}], 
      LineBox[{{110., 0.}, {110., -7.21687836487032}, {
       110., -8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -7.21687836487032}, {110., -14.43375672974064}, {
       110., -16.09876377148447}, {110., -8.049381885742235}, {
       110., -7.21687836487032}}], 
      LineBox[{{110., -14.43375672974064}, {110., -21.650635094610962`}, {
       110., -24.148145657226706`}, {110., -16.09876377148447}, {
       110., -14.43375672974064}}], 
      LineBox[{{110., 0.}, {110., -8.049381885742235}, {
       110., -8.333333333333332}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.049381885742235}, {110., -16.09876377148447}, {
       110., -16.666666666666664`}, {110., -8.333333333333332}, {
       110., -8.049381885742235}}], 
      LineBox[{{110., -16.09876377148447}, {110., -24.148145657226706`}, {
       110., -25.}, {110., -16.666666666666664`}, {
       110., -16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., -8.333333333333332}, {
       110., -8.049381885742235}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.333333333333332}, {110., -16.666666666666664`}, {
       110., -16.09876377148447}, {110., -8.049381885742235}, {
       110., -8.333333333333332}}], 
      LineBox[{{110., -16.666666666666664`}, {110., -25.}, {
       110., -24.148145657226706`}, {110., -16.09876377148447}, {
       110., -16.666666666666664`}}], 
      LineBox[{{110., 0.}, {110., -8.049381885742235}, {
       110., -7.216878364870323}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -8.049381885742235}, {110., -16.09876377148447}, {
       110., -14.433756729740645`}, {110., -7.216878364870323}, {
       110., -8.049381885742235}}], 
      LineBox[{{110., -16.09876377148447}, {110., -24.14814565722671}, {
       110., -21.65063509461097}, {110., -14.433756729740645`}, {
       110., -16.09876377148447}}], 
      LineBox[{{110., 0.}, {110., -7.216878364870323}, {
       110., -5.892556509887897}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -7.216878364870323}, {110., -14.433756729740645`}, {
       110., -11.785113019775794`}, {110., -5.892556509887897}, {
       110., -7.216878364870323}}], 
      LineBox[{{110., -14.433756729740645`}, {110., -21.65063509461097}, {
       110., -17.677669529663692`}, {110., -11.785113019775794`}, {
       110., -14.433756729740645`}}], 
      LineBox[{{110., 0.}, {110., -5.892556509887898}, {
       110., -4.16666666666667}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -5.892556509887898}, {110., -11.785113019775796`}, {
       110., -8.33333333333334}, {110., -4.16666666666667}, {
       110., -5.892556509887898}}], 
      LineBox[{{110., -11.785113019775796`}, {110., -17.677669529663696`}, {
       110., -12.50000000000001}, {110., -8.33333333333334}, {
       110., -11.785113019775796`}}], 
      LineBox[{{110., 0.}, {110., -4.16666666666667}, {
       110., -2.156825375854346}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -4.16666666666667}, {110., -8.33333333333334}, {
       110., -4.313650751708692}, {110., -2.156825375854346}, {
       110., -4.16666666666667}}], 
      LineBox[{{110., -8.33333333333334}, {110., -12.50000000000001}, {
       110., -6.470476127563038}, {110., -4.313650751708692}, {
       110., -8.33333333333334}}], 
      LineBox[{{110., 0.}, {110., -2.156825375854346}, {
       110., -8.932295329768568*^-15}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -2.156825375854346}, {110., -4.313650751708692}, {
       110., -1.7864590659537137`*^-14}, {110., -8.932295329768568*^-15}, {
       110., -2.156825375854346}}], 
      LineBox[{{110., -4.313650751708692}, {110., -6.470476127563038}, {
       110., -2.6796885989305705`*^-14}, {110., -1.7864590659537137`*^-14}, {
       110., -4.313650751708692}}], 
      LineBox[{{110., 0.}, {110., -1.5308084989341913`*^-15}, {110., 
       2.1568253758543356`}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., -1.5308084989341913`*^-15}, {
       110., -3.0616169978683826`*^-15}, {110., 4.313650751708671}, {110., 
       2.1568253758543356`}, {110., -1.5308084989341913`*^-15}}], 
      LineBox[{{110., -3.0616169978683826`*^-15}, {
       110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {110., 
       4.313650751708671}, {110., -3.0616169978683826`*^-15}}], 
      LineBox[{{110., 0.}, {110., 2.1568253758543356`}, {110., 
       4.166666666666661}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 2.1568253758543356`}, {110., 4.313650751708671}, {110., 
       8.333333333333321}, {110., 4.166666666666661}, {110., 
       2.1568253758543356`}}], 
      LineBox[{{110., 4.313650751708671}, {110., 6.470476127563007}, {110., 
       12.499999999999984`}, {110., 8.333333333333321}, {110., 
       4.313650751708671}}], 
      LineBox[{{110., 0.}, {110., 4.166666666666661}, {110., 
       5.89255650988789}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 4.166666666666661}, {110., 8.333333333333321}, {110., 
       11.78511301977578}, {110., 5.89255650988789}, {110., 
       4.166666666666661}}], 
      LineBox[{{110., 8.333333333333321}, {110., 12.499999999999984`}, {110., 
       17.67766952966367}, {110., 11.78511301977578}, {110., 
       8.333333333333321}}], 
      LineBox[{{110., 0.}, {110., 5.8925565098878945`}, {110., 
       7.216878364870319}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 5.8925565098878945`}, {110., 11.785113019775789`}, {
       110., 14.433756729740638`}, {110., 7.216878364870319}, {110., 
       5.8925565098878945`}}], 
      LineBox[{{110., 11.785113019775789`}, {110., 17.677669529663685`}, {
       110., 21.65063509461096}, {110., 14.433756729740638`}, {110., 
       11.785113019775789`}}], 
      LineBox[{{110., 0.}, {110., 7.216878364870319}, {110., 
       8.049381885742234}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 7.216878364870319}, {110., 14.433756729740638`}, {110., 
       16.098763771484467`}, {110., 8.049381885742234}, {110., 
       7.216878364870319}}], 
      LineBox[{{110., 14.433756729740638`}, {110., 21.65063509461096}, {110., 
       24.148145657226703`}, {110., 16.098763771484467`}, {110., 
       14.433756729740638`}}], 
      LineBox[{{110., 0.}, {110., 8.049381885742234}, {110., 
       8.333333333333332}, {110., 0.}, {110., 0.}}], 
      LineBox[{{110., 8.049381885742234}, {110., 16.098763771484467`}, {110., 
       16.666666666666664`}, {110., 8.333333333333332}, {110., 
       8.049381885742234}}], 
      LineBox[{{110., 16.098763771484467`}, {110., 24.148145657226703`}, {
       110., 25.}, {110., 16.666666666666664`}, {110., 
       16.098763771484467`}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{106.4219745809556, 25.}, {110., 25.}, {110., 
       24.148145657226706`}, {106.4219745809556, 24.148145657226706`}, {
       106.4219745809556, 25.}}], 
      LineBox[{{106.4219745809556, 24.148145657226706`}, {110., 
       24.148145657226706`}, {110., 21.65063509461097}, {106.4219745809556, 
       21.65063509461097}, {106.4219745809556, 24.148145657226706`}}], 
      LineBox[{{106.4219745809556, 21.65063509461097}, {110., 
       21.65063509461097}, {110., 17.67766952966369}, {106.4219745809556, 
       17.67766952966369}, {106.4219745809556, 21.65063509461097}}], 
      LineBox[{{106.4219745809556, 17.67766952966369}, {110., 
       17.67766952966369}, {110., 12.500000000000004`}, {106.4219745809556, 
       12.500000000000004`}, {106.4219745809556, 17.67766952966369}}], 
      LineBox[{{106.4219745809556, 12.500000000000004`}, {110., 
       12.500000000000004`}, {110., 6.470476127563024}, {106.4219745809556, 
       6.470476127563024}, {106.4219745809556, 12.500000000000004`}}], 
      LineBox[{{106.4219745809556, 6.470476127563024}, {110., 
       6.470476127563024}, {110., 7.0819236220599744`*^-15}, {
       106.4219745809556, 7.0819236220599744`*^-15}, {106.4219745809556, 
       6.470476127563024}}], 
      LineBox[{{106.4219745809556, 1.5308084989341915`*^-15}, {110., 
       1.5308084989341915`*^-15}, {110., -6.470476127563016}, {
       106.4219745809556, -6.470476127563016}, {106.4219745809556, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{106.4219745809556, -6.470476127563016}, {
       110., -6.470476127563016}, {110., -12.499999999999995`}, {
       106.4219745809556, -12.499999999999995`}, {
       106.4219745809556, -6.470476127563016}}], 
      LineBox[{{106.4219745809556, -12.499999999999995`}, {
       110., -12.499999999999995`}, {110., -17.677669529663685`}, {
       106.4219745809556, -17.677669529663685`}, {
       106.4219745809556, -12.499999999999995`}}], 
      LineBox[{{106.4219745809556, -17.677669529663685`}, {
       110., -17.677669529663685`}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -17.677669529663685`}}], 
      LineBox[{{106.4219745809556, -21.650635094610962`}, {
       110., -21.650635094610962`}, {110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {
       106.4219745809556, -21.650635094610962`}}], 
      LineBox[{{106.4219745809556, -24.148145657226706`}, {
       110., -24.148145657226706`}, {110., -25.}, {106.4219745809556, -25.}, {
       106.4219745809556, -24.148145657226706`}}], 
      LineBox[{{106.4219745809556, -25.}, {110., -25.}, {
       110., -24.148145657226706`}, {
       106.4219745809556, -24.148145657226706`}, {106.4219745809556, -25.}}], 
      LineBox[{{106.4219745809556, -24.14814565722671}, {
       110., -24.14814565722671}, {110., -21.65063509461097}, {
       106.4219745809556, -21.65063509461097}, {
       106.4219745809556, -24.14814565722671}}], 
      LineBox[{{106.4219745809556, -21.65063509461097}, {
       110., -21.65063509461097}, {110., -17.677669529663692`}, {
       106.4219745809556, -17.677669529663692`}, {
       106.4219745809556, -21.65063509461097}}], 
      LineBox[{{106.4219745809556, -17.677669529663696`}, {
       110., -17.677669529663696`}, {110., -12.50000000000001}, {
       106.4219745809556, -12.50000000000001}, {
       106.4219745809556, -17.677669529663696`}}], 
      LineBox[{{106.4219745809556, -12.50000000000001}, {
       110., -12.50000000000001}, {110., -6.470476127563038}, {
       106.4219745809556, -6.470476127563038}, {
       106.4219745809556, -12.50000000000001}}], 
      LineBox[{{106.4219745809556, -6.470476127563038}, {
       110., -6.470476127563038}, {110., -2.6796885989305705`*^-14}, {
       106.4219745809556, -2.6796885989305705`*^-14}, {
       106.4219745809556, -6.470476127563038}}], 
      LineBox[{{106.4219745809556, -4.592425496802574*^-15}, {
       110., -4.592425496802574*^-15}, {110., 6.470476127563007}, {
       106.4219745809556, 6.470476127563007}, {
       106.4219745809556, -4.592425496802574*^-15}}], 
      LineBox[{{106.4219745809556, 6.470476127563007}, {110., 
       6.470476127563007}, {110., 12.499999999999984`}, {106.4219745809556, 
       12.499999999999984`}, {106.4219745809556, 6.470476127563007}}], 
      LineBox[{{106.4219745809556, 12.499999999999984`}, {110., 
       12.499999999999984`}, {110., 17.67766952966367}, {106.4219745809556, 
       17.67766952966367}, {106.4219745809556, 12.499999999999984`}}], 
      LineBox[{{106.4219745809556, 17.677669529663685`}, {110., 
       17.677669529663685`}, {110., 21.65063509461096}, {106.4219745809556, 
       21.65063509461096}, {106.4219745809556, 17.677669529663685`}}], 
      LineBox[{{106.4219745809556, 21.65063509461096}, {110., 
       21.65063509461096}, {110., 24.148145657226703`}, {106.4219745809556, 
       24.148145657226703`}, {106.4219745809556, 21.65063509461096}}], 
      LineBox[{{106.4219745809556, 24.148145657226703`}, {110., 
       24.148145657226703`}, {110., 25.}, {106.4219745809556, 25.}, {
       106.4219745809556, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{136.4219745809556, -25.}, {140., -25.}, {
      140., -16.66666666666667}, {132.7504488342848, -16.666666666666668`}, {
      136.4219745809556, -25.}}], 
     PolygonBox[{{132.7504488342848, -16.666666666666668`}, {
      140., -16.66666666666667}, {140., -8.333333333333336}, {
      130.67375799589206`, -8.333333333333336}, {
      132.7504488342848, -16.666666666666668`}}], 
     PolygonBox[{{130.67375799589206`, -8.333333333333336}, {
      140., -8.333333333333336}, {140., -7.105427357601002*^-15}, {130., 
      0.}, {130.67375799589206`, -8.333333333333336}}], 
     PolygonBox[{{130., 0.}, {140., 0.}, {140., 8.333333333333332}, {
      130.67375799589206`, 8.333333333333329}, {130., 0.}}], 
     PolygonBox[{{130.67375799589206`, 8.333333333333329}, {140., 
      8.333333333333332}, {140., 16.666666666666664`}, {132.7504488342848, 
      16.666666666666664`}, {130.67375799589206`, 8.333333333333329}}], 
     PolygonBox[{{132.7504488342848, 16.666666666666664`}, {140., 
      16.666666666666664`}, {140., 24.999999999999996`}, {136.4219745809556, 
      24.999999999999993`}, {132.7504488342848, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666668`}, {
       130.67375799589206`, -8.333333333333336}, {
       130., -3.552713678800501*^-15}, {130.67375799589206`, 
       8.333333333333329}, {132.75044883428478`, 16.666666666666657`}, {
       136.4219745809556, 24.999999999999993`}, {140., 25.}, {140., 
       16.666666666666668`}, {140., 8.333333333333336}, {140., 
       3.552713678800501*^-15}, {140., -8.333333333333329}, {
       140., -16.666666666666657`}, {140., -24.999999999999993`}, {
       136.4219745809556, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{130., 0.}, {140., 3.061616997868383*^-15}, {140., 
        2.551347498223653*^-15}, {130., 5.102694996447305*^-16}, {130., 0.}}],
        PolygonBox[{{130., 5.102694996447305*^-16}, {140., 
        2.551347498223653*^-15}, {140., 2.0410779985789223`*^-15}, {130., 
        1.020538999289461*^-15}, {130., 5.102694996447305*^-16}}], 
       PolygonBox[{{130., 1.020538999289461*^-15}, {140., 
        2.0410779985789223`*^-15}, {140., 1.530808498934192*^-15}, {130., 
        1.5308084989341915`*^-15}, {130., 1.020538999289461*^-15}}], 
       PolygonBox[{{130., 1.5308084989341915`*^-15}, {140., 
        1.5308084989341915`*^-15}, {140., 1.0205389992894611`*^-15}, {130., 
        2.041077998578922*^-15}, {130., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{130., 2.041077998578922*^-15}, {140., 
        1.0205389992894611`*^-15}, {140., 5.102694996447307*^-16}, {130., 
        2.5513474982236525`*^-15}, {130., 2.041077998578922*^-15}}], 
       PolygonBox[{{130., 2.5513474982236525`*^-15}, {140., 
        5.102694996447308*^-16}, {140., 2.5493082627129206`*^-31}, {130., 
        3.0616169978683826`*^-15}, {130., 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{130., 0.}, {130., 0.}, {130., 0.}, {130., 0.}, {130., 0.}, {
         130., 0.}, {130., 0.}, {140., 0.}, {140., 0.}, {140., 0.}, {140., 
         0.}, {140., 0.}, {140., 0.}, {140., 0.}, {130., 0.}}]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {136.4219745809556, -25.}, {
       136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {136.4219745809556, -25.}, {
       136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {136.4219745809556, -25.}, {
       136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {136.4219745809556, -25.}, {
       136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {136.4219745809556, -25.}, {
       136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {136.4219745809556, -25.}, {
       136.4219745809556, -25.}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333}, {
       130.67375799589206`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15}, {130., 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 8.333333333333334}, {130., 0.}, {130., 0.}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 8.333333333333334}, {130., 0.}, {130., 0.}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 8.333333333333334}, {130., 0.}, {130., 0.}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 8.333333333333334}, {130., 0.}, {130., 0.}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 8.333333333333334}, {130., 0.}, {130., 0.}}], 
      LineBox[{{130., 0.}, {130.67375799589206`, 8.333333333333334}, {
       130.67375799589206`, 8.333333333333334}, {130., 0.}, {130., 0.}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{130.67375799589206`, 8.333333333333336}, {132.7504488342848, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667}, {
       130.67375799589206`, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       25.000000000000007`}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       25.000000000000007`}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       25.000000000000007`}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       25.000000000000007`}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       25.000000000000007`}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}}], 
      LineBox[{{132.7504488342848, 16.66666666666667}, {136.4219745809556, 
       25.000000000000007`}, {136.4219745809556, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667}, {132.7504488342848, 
       16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}, {140., -25.}}], 
      LineBox[{{140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}, {140., -25.}}], 
      LineBox[{{140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}, {140., -25.}}], 
      LineBox[{{140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}, {140., -25.}}], 
      LineBox[{{140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}, {140., -25.}}], 
      LineBox[{{140., -25.}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -25.}, {140., -25.}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -8.33333333333333}, {
       140., -8.33333333333333}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -8.33333333333333}, {
       140., -8.33333333333333}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -8.33333333333333}, {
       140., -8.33333333333333}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -8.33333333333333}, {
       140., -8.33333333333333}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -8.33333333333333}, {
       140., -8.33333333333333}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -16.666666666666664`}, {140., -8.33333333333333}, {
       140., -8.33333333333333}, {140., -16.666666666666664`}, {
       140., -16.666666666666664`}}], 
      LineBox[{{140., -8.333333333333332}, {140., 1.7763568394002505`*^-15}, {
       140., 1.7763568394002505`*^-15}, {140., -8.333333333333332}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., -8.333333333333332}, {140., 1.7763568394002505`*^-15}, {
       140., 1.7763568394002505`*^-15}, {140., -8.333333333333332}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., -8.333333333333332}, {140., 1.7763568394002505`*^-15}, {
       140., 1.7763568394002505`*^-15}, {140., -8.333333333333332}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., -8.333333333333332}, {140., 1.7763568394002505`*^-15}, {
       140., 1.7763568394002505`*^-15}, {140., -8.333333333333332}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., -8.333333333333332}, {140., 1.7763568394002505`*^-15}, {
       140., 1.7763568394002505`*^-15}, {140., -8.333333333333332}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., -8.333333333333332}, {140., 1.7763568394002505`*^-15}, {
       140., 1.7763568394002505`*^-15}, {140., -8.333333333333332}, {
       140., -8.333333333333332}}], 
      LineBox[{{140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}, {140., 0.}}], 
      LineBox[{{140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}, {140., 0.}}], 
      LineBox[{{140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}, {140., 0.}}], 
      LineBox[{{140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}, {140., 0.}}], 
      LineBox[{{140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}, {140., 0.}}], 
      LineBox[{{140., 0.}, {140., 8.333333333333334}, {140., 
       8.333333333333334}, {140., 0.}, {140., 0.}}], 
      LineBox[{{140., 8.333333333333336}, {140., 16.66666666666667}, {140., 
       16.66666666666667}, {140., 8.333333333333336}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 8.333333333333336}, {140., 16.66666666666667}, {140., 
       16.66666666666667}, {140., 8.333333333333336}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 8.333333333333336}, {140., 16.66666666666667}, {140., 
       16.66666666666667}, {140., 8.333333333333336}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 8.333333333333336}, {140., 16.66666666666667}, {140., 
       16.66666666666667}, {140., 8.333333333333336}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 8.333333333333336}, {140., 16.66666666666667}, {140., 
       16.66666666666667}, {140., 8.333333333333336}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 8.333333333333336}, {140., 16.66666666666667}, {140., 
       16.66666666666667}, {140., 8.333333333333336}, {140., 
       8.333333333333336}}], 
      LineBox[{{140., 16.66666666666667}, {140., 25.000000000000007`}, {140., 
       25.000000000000007`}, {140., 16.66666666666667}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., 16.66666666666667}, {140., 25.000000000000007`}, {140., 
       25.000000000000007`}, {140., 16.66666666666667}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., 16.66666666666667}, {140., 25.000000000000007`}, {140., 
       25.000000000000007`}, {140., 16.66666666666667}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., 16.66666666666667}, {140., 25.000000000000007`}, {140., 
       25.000000000000007`}, {140., 16.66666666666667}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., 16.66666666666667}, {140., 25.000000000000007`}, {140., 
       25.000000000000007`}, {140., 16.66666666666667}, {140., 
       16.66666666666667}}], 
      LineBox[{{140., 16.66666666666667}, {140., 25.000000000000007`}, {140., 
       25.000000000000007`}, {140., 16.66666666666667}, {140., 
       16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {
       140., -16.666666666666668`}, {
       132.7504488342848, -16.666666666666668`}, {136.4219745809556, -25.}}], 
      LineBox[{{132.7504488342848, -16.666666666666668`}, {
       140., -16.666666666666668`}, {140., -8.333333333333336}, {
       130.67375799589206`, -8.333333333333336}, {
       132.7504488342848, -16.666666666666668`}}], 
      LineBox[{{130.67375799589206`, -8.333333333333334}, {
       140., -8.333333333333334}, {140., -1.3877787807814457`*^-15}, {
       130., -1.3877787807814457`*^-15}, {
       130.67375799589206`, -8.333333333333334}}], 
      LineBox[{{130., 0.}, {140., 0.}, {140., 8.333333333333332}, {
       130.67375799589206`, 8.333333333333332}, {130., 0.}}], 
      LineBox[{{130.67375799589206`, 8.333333333333332}, {140., 
       8.333333333333332}, {140., 16.666666666666664`}, {132.7504488342848, 
       16.666666666666664`}, {130.67375799589206`, 8.333333333333332}}], 
      LineBox[{{132.7504488342848, 16.666666666666664`}, {140., 
       16.666666666666664`}, {140., 24.999999999999993`}, {136.4219745809556, 
       24.999999999999993`}, {132.7504488342848, 16.666666666666664`}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 25.}, {
       136.4219745809556, 25.}, {136.4219745809556, 25.}}], 
      LineBox[{{136.4219745809556, 25.}, {140., 25.}, {140., 
       16.666666666666668`}, {132.7504488342848, 16.666666666666668`}, {
       136.4219745809556, 25.}}], 
      LineBox[{{132.7504488342848, 16.666666666666668`}, {140., 
       16.666666666666668`}, {140., 8.333333333333336}, {130.67375799589206`, 
       8.333333333333336}, {132.7504488342848, 16.666666666666668`}}], 
      LineBox[{{130.67375799589206`, 8.333333333333334}, {140., 
       8.333333333333334}, {140., 1.3877787807814457`*^-15}, {130., 
       1.3877787807814457`*^-15}, {130.67375799589206`, 8.333333333333334}}], 
      LineBox[{{130., 0.}, {140., 0.}, {140., -8.333333333333332}, {
       130.67375799589206`, -8.333333333333332}, {130., 0.}}], 
      LineBox[{{130.67375799589206`, -8.333333333333332}, {
       140., -8.333333333333332}, {140., -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`}, {
       130.67375799589206`, -8.333333333333332}}], 
      LineBox[{{132.7504488342848, -16.666666666666664`}, {
       140., -16.666666666666664`}, {140., -24.999999999999993`}, {
       136.4219745809556, -24.999999999999993`}, {
       132.7504488342848, -16.666666666666664`}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {136.4219745809556, -25.}}], 
      LineBox[{{136.4219745809556, -25.}, {140., -25.}, {140., -25.}, {
       136.4219745809556, -25.}, {136.4219745809556, -25.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., 30.}, {250., -30.}, {250., -30.}, {250., 30.}, {250., 
       30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -30.}, {0., -30.}, {0., -30.}, {250., -30.}, {
       250., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -30}, {0, 30}, {0, 30}, {0, -30}, {0, -30}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 30.}, {250., 30.}, {250., 30.}, {0., 30.}, {0., 30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., -30.}, {250., 30.}, {0., 30.}, {0., -30.}, {
       250., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{250., 30.}, {250., -30.}, {0., -30.}, {0., 30.}, {250., 
       30.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., 0.}, {103.30336650761734`, -18.21517071330813}}], 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761726`, -11.463107122673815`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 4.112620349694018}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 16.45808107228358}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 16.458081072283587`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761734`, 4.112620349694043}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., 0.}, {103.30336650761726`, -11.463107122673811`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, -18.21517071330813}, {
       110., -18.09775195419761}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761726`, -11.463107122673815`}, {
       110., -11.389213562460736`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 4.112620349694018}, {110., 
       4.086109548024674}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 16.45808107228358}, {110., 
       16.351988876538414`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 16.458081072283587`}, {110., 
       16.35198887653842}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761734`, 4.112620349694043}, {110., 
       4.086109548024699}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{103.30336650761726`, -11.463107122673811`}, {
       110., -11.389213562460732`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -18.09775195419761}, {
       133.0354181644418, -17.484074475139014`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -11.389213562460736`}, {
       131.1871380222869, -11.034003315118829`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 4.086109548024674}, {130.15175276411347`, 
       3.9648984777969343`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 16.351988876538414`}, {132.4684385112241, 
       15.811156194137844`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 16.35198887653842}, {132.4684385112241, 
       15.81115619413785}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., 4.086109548024699}, {130.1517527641135, 
       3.9648984777969583`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{110., -11.389213562460732`}, {
       131.18713802228686`, -11.034003315118825`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{133.0354181644418, -17.484074475139014`}, {
       140., -16.523769269449065`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{131.1871380222869, -11.034003315118829`}, {
       140., -10.285069042119805`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{130.15175276411347`, 3.9648984777969343`}, {140., 
       3.668042331585643}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{132.4684385112241, 15.811156194137844`}, {140., 
       14.878894459677795`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{132.4684385112241, 15.81115619413785}, {140., 
       14.8788944596778}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{130.1517527641135, 3.9648984777969583`}, {140., 
       3.6680423315856663`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{131.18713802228686`, -11.034003315118825`}, {
       140., -10.2850690421198}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., -16.523769269449065`}, {250., 
       6.8080758706663715`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., -10.285069042119805`}, {250., 3.984443156059287}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 3.668042331585643}, {250., -1.3727263963056417`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 14.878894459677795`}, {250., -6.015625997148696}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 14.8788944596778}, {250., -6.015625997148705}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., 3.6680423315856663`}, {
       250., -1.3727263963056515`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{140., -10.2850690421198}, {250., 3.9844431560592852`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQfcQqOjrrcqSD6vaOXFFzowP7oPy62yUJMm/VDsDk
xY137w8qFnCA8Z/GS5x1KTWA85+j8Y2h6mHm1UDNYwCBhmgHybRlrmySRnB+
2m1mBvfjCPmVfZ8kdSMEHGD8M56ZH6WjDOD8c2j8o2jqU6DmnbBzU1VamODw
sofd70214YF3Gx9w/E1NcNA+8eZhhqDaAdt7czRuuyQ47DlRsFFmB7/D/D2H
iv72JTjodEXf9Z+vD+frQ/l2UPWfoOrfQs3ThJoHsT/R4e87rX2ibQZwfhLz
qYlfJqrA+VwcXyarRfA6wPgezxNL/h3UhfO90fh2aOrjkc1zyHeYcHqLbYW1
tAOM3xJ7YLfyA344f8pF9S/rv33dD+NHPHrlxCAgAdefhMY/gKa+AWoeAIhz
zOM=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L2\"\>", {135., -30.693465035711835}, {0., 0.}], 
    InsetBox["\<\"L1\"\>", {105., -30.693465035711835}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367531305318*^9, 3.5660869871524563`*^9, 
  3.566101743177252*^9, 3.5661391857263937`*^9, 3.61470779460662*^9},
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."},
 CellLabel->
  "During evaluation of \
In[36]:=",ExpressionUUID->"d723f22c-56c9-45ab-9326-3be74b4f57f2"]
}, Open  ]],

Cell[TextData[{
 "Notice that in the two previous graphics, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has automatically attached labels to the two lenses, L1 and L2. This \
feature can be helpful to make illustrations in publications. You can learn \
more about ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s treatment of graphics in ",
 ButtonBox["Chapter 6",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"Visualizing Overview"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide. You can make exact positional measurements in the two-dimensional \
fields by clicking the graphics display cell and then holding down the \
Command key while moving the cursor over the image. The cursor coordinates \
are displayed in the bottom corner of the window. More accurate measurements \
can be taken by expanding the graphic display size. By examining the ",
 StyleBox["TopView",
  FontFamily->"Courier"],
 " image, you can measure the focus position to be ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 218 millimeters."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "cylindrical lens", "Adding a Cylindrical Lens", 
   "RG8."},ExpressionUUID->"f46b8f25-0f6f-43f7-9dcf-10d7b52d732b"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"b259f704-e50e-4139-\
a571-9e943a1cff62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "9. The ",
 StyleBox["RayChoice",
  FontFamily->"Courier New"],
 " Option"
}], "Section",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "9.", 
   "RG9."},ExpressionUUID->"23359498-8046-434a-af0c-e565df2d8892"],

Cell[TextData[{
 "You can use the ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 " option to display portions of the ray-tracing result. Here we define ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "RG9."},ExpressionUUID->"0d1a8e3f-4e1d-4dc4-a61a-e7f9b3ef5afb"],

Cell[TextData[{
 StyleBox["RayChoice ->", "Input",
  FontFamily->"Courier"],
 StyleBox[" ",
  FontFamily->"Courier"],
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 " uses ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 " to selectively display ray segments in ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " and ",
 StyleBox["ShowSystem", "Input",
  FontFamily->"Courier"],
 "."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "RG9."},ExpressionUUID->"34779028-9be1-4672-b9ce-24514fb1786e"],

Cell[TextData[{
 "Next we will use ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 " to examine the ray segments after the cylindrical lens in the system. Use ",
 StyleBox["RayChoice->{ComponentNumber->3}", "Input",
  FontFamily->"Courier"],
 " to view the ray segments immediately following the cylindrical lens. In \
general, you can use ",
 StyleBox["ComponentNumber", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 " to choose ray segments associated with any particular component."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "RG9."},ExpressionUUID->"f42d6be7-cbe5-44e4-b7ee-1e7ef7b86e0a"],

Cell[CellGroupData[{

Cell["ShowSystem[opticalsystem, RayChoice->{ComponentNumber->3}];", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"RayChoice", "RG9."},
 CellLabel->"In[37]:=",ExpressionUUID->"01fb40b3-1e7d-4bf2-967e-eea9be9f6230"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         "]]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.333333333333332, 0.}, {100.67375799589207`, 8.049381885742235, 
       2.156825375854339}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 8.333333333333332, 0.}, {
       102.75044883428481`, 16.666666666666664`, 0.}, {102.75044883428481`, 
       16.09876377148447, 4.313650751708678}, {100.67375799589207`, 
       8.049381885742235, 2.156825375854339}, {100.67375799589207`, 
       8.333333333333332, 0.}}], 
      Line3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
       106.4219745809556, 25., 0.}, {106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {102.75044883428481`, 16.666666666666664`, 0.}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.049381885742235, 2.156825375854339}, {100.67375799589209`, 
       7.216878364870323, 4.166666666666666}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 8.049381885742235, 
       2.156825375854339}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {100.67375799589209`, 7.216878364870323, 
       4.166666666666666}, {100.67375799589207`, 8.049381885742235, 
       2.156825375854339}}], 
      Line3DBox[{{102.75044883428481`, 16.09876377148447, 
       4.313650751708678}, {106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {102.75044883428481`, 16.09876377148447, 
       4.313650751708678}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       7.216878364870323, 4.166666666666666}, {100.67375799589207`, 
       5.892556509887896, 5.8925565098878945`}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 7.216878364870323, 
       4.166666666666666}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}, {100.67375799589209`, 7.216878364870323, 
       4.166666666666666}}], 
      Line3DBox[{{102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}, {106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {102.75044883428481`, 14.433756729740645`, 
       8.333333333333332}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.892556509887896, 5.8925565098878945`}, {100.67375799589209`, 
       4.166666666666668, 7.216878364870322}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {100.67375799589209`, 4.166666666666668, 
       7.216878364870322}, {100.67375799589207`, 5.892556509887896, 
       5.8925565098878945`}}], 
      Line3DBox[{{102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}, {106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {102.7504488342848, 11.785113019775793`, 
       11.785113019775789`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       4.166666666666668, 7.216878364870322}, {100.67375799589207`, 
       2.156825375854341, 8.049381885742235}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 4.166666666666668, 
       7.216878364870322}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {100.67375799589207`, 2.156825375854341, 
       8.049381885742235}, {100.67375799589209`, 4.166666666666668, 
       7.216878364870322}}], 
      Line3DBox[{{102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}, {106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {102.75044883428481`, 8.333333333333336, 
       14.433756729740644`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       2.156825375854341, 8.049381885742235}, {100.67375799589207`, 
       2.3606412073533245`*^-15, 8.333333333333332}, {100.00000000000001`, 0.,
        0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 2.156825375854341, 
       8.049381885742235}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {102.75044883428481`, 4.721282414706649*^-15, 
       16.666666666666664`}, {100.67375799589207`, 2.3606412073533245`*^-15, 
       8.333333333333332}, {100.67375799589207`, 2.156825375854341, 
       8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, 4.313650751708682, 
       16.09876377148447}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {106.4219745809556, 7.0819236220599744`*^-15, 
       25.}, {102.75044883428481`, 4.721282414706649*^-15, 
       16.666666666666664`}, {102.75044883428481`, 4.313650751708682, 
       16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.102694996447305*^-16, 8.333333333333332}, {
       100.67375799589207`, -2.1568253758543383`, 8.049381885742235}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 5.102694996447305*^-16, 
       8.333333333333332}, {102.75044883428481`, 1.020538999289461*^-15, 
       16.666666666666664`}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}, {100.67375799589207`, 5.102694996447305*^-16, 
       8.333333333333332}}], 
      Line3DBox[{{102.75044883428481`, 1.020538999289461*^-15, 
       16.666666666666664`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}, {106.4219745809556, -6.470476127563016, 24.148145657226706`}, {
       102.75044883428481`, -4.313650751708677, 16.09876377148447}, {
       102.75044883428481`, 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -2.1568253758543383`, 8.049381885742235}, {
       100.67375799589209`, -4.166666666666664, 7.216878364870323}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {100.67375799589209`, -4.166666666666664, 
       7.216878364870323}, {100.67375799589207`, -2.1568253758543383`, 
       8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, -4.313650751708677, 
       16.09876377148447}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {102.75044883428481`, -4.313650751708677, 
       16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -4.166666666666664, 7.216878364870323}, {
       100.67375799589207`, -5.8925565098878945`, 5.892556509887896}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, -4.166666666666664, 
       7.216878364870323}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}, {100.67375799589209`, -4.166666666666664, 
       7.216878364870323}}], 
      Line3DBox[{{102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {102.75044883428481`, -8.333333333333329, 
       14.433756729740645`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -5.8925565098878945`, 5.892556509887896}, {
       100.67375799589209`, -7.216878364870323, 4.166666666666666}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {102.75044883428481`, -14.433756729740645`, 
       8.333333333333332}, {100.67375799589209`, -7.216878364870323, 
       4.166666666666666}, {100.67375799589207`, -5.8925565098878945`, 
       5.892556509887896}}], 
      Line3DBox[{{102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}, {106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {106.4219745809556, -21.65063509461097, 
       12.499999999999998`}, {102.75044883428481`, -14.433756729740645`, 
       8.333333333333332}, {102.7504488342848, -11.785113019775789`, 
       11.785113019775793`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -7.21687836487032, 4.16666666666667}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, -7.21687836487032, 4.16666666666667}, {
       102.7504488342848, -14.43375672974064, 8.33333333333334}, {
       102.75044883428481`, -16.09876377148447, 4.313650751708684}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.67375799589209`, -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{102.7504488342848, -14.43375672974064, 8.33333333333334}, {
       106.4219745809556, -21.650635094610962`, 12.500000000000009`}, {
       106.4219745809556, -24.148145657226706`, 6.470476127563026}, {
       102.75044883428481`, -16.09876377148447, 4.313650751708684}, {
       102.7504488342848, -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.049381885742235, 2.156825375854342}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -8.049381885742235, 
       2.156825375854342}, {102.75044883428481`, -16.09876377148447, 
       4.313650751708684}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {100.67375799589207`, -8.333333333333332, 
       1.020538999289461*^-15}, {100.67375799589207`, -8.049381885742235, 
       2.156825375854342}}], 
      Line3DBox[{{102.75044883428481`, -16.09876377148447, 
       4.313650751708684}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {102.75044883428481`, -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}, {
       100.67375799589207`, -8.049381885742235, -2.15682537585434}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, -8.333333333333332, 
       1.020538999289461*^-15}, {102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {
       102.75044883428481`, -16.09876377148447, -4.31365075170868}, {
       100.67375799589207`, -8.049381885742235, -2.15682537585434}, {
       100.67375799589207`, -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{102.75044883428481`, -16.666666666666664`, 
       2.041077998578922*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       102.75044883428481`, -16.09876377148447, -4.31365075170868}, {
       102.75044883428481`, -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -8.049381885742235, -2.156825375854336}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -8.049381885742235, -2.156825375854336}, {
       102.75044883428481`, -16.09876377148447, -4.313650751708672}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.67375799589207`, -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{
       102.75044883428481`, -16.09876377148447, -4.313650751708672}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       102.75044883428481`, -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       100.67375799589207`, -5.892556509887897, -5.8925565098878945`}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589209`, -7.216878364870323, -4.166666666666664}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       102.75044883428481`, -11.785113019775794`, -11.785113019775789`}, {
       100.67375799589207`, -5.892556509887897, -5.8925565098878945`}, {
       100.67375799589209`, -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       102.75044883428481`, -11.785113019775794`, -11.785113019775789`}, {
       102.75044883428481`, -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -5.892556509887898, -5.892556509887893}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -5.892556509887898, -5.892556509887893}, {
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.67375799589207`, -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       102.75044883428481`, -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589209`, -4.16666666666667, -7.216878364870319}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.67375799589209`, -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{
       102.7504488342848, -8.33333333333334, -14.433756729740638`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       102.7504488342848, -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       100.67375799589207`, -8.932295329768568*^-15, -8.333333333333332}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -2.156825375854346, -8.049381885742234}, {
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       102.75044883428481`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{100.67375799589207`, -8.932295329768568*^-15, -8.333333333333332}, {
       100.67375799589207`, -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{
       102.75044883428481`, -4.313650751708692, -16.098763771484467`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       102.75044883428481`, -1.7864590659537137`*^-14, -16.666666666666664`}, \
{102.75044883428481`, -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}, {
       100.67375799589207`, 2.1568253758543356`, -8.049381885742235}, {
       100.00000000000001`, 0., 0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}, {
       102.75044883428481`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{102.75044883428481`, 4.313650751708671, -16.09876377148447}, {
       100.67375799589207`, 2.1568253758543356`, -8.049381885742235}, {
       100.67375799589207`, -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{
       102.75044883428481`, -3.0616169978683826`*^-15, -16.666666666666664`}, \
{106.4219745809556, -4.592425496802574*^-15, -25.}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {
       102.75044883428481`, -3.0616169978683826`*^-15, \
-16.666666666666664`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.67375799589207`, 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{102.75044883428481`, 
       4.313650751708671, -16.09876377148447}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {102.75044883428481`, 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {100.67375799589207`, 
       5.89255650988789, -5.892556509887903}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       4.166666666666661, -7.216878364870325}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {102.75044883428481`, 
       11.78511301977578, -11.785113019775807`}, {100.67375799589207`, 
       5.89255650988789, -5.892556509887903}, {100.67375799589207`, 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{102.75044883428481`, 
       8.333333333333321, -14.43375672974065}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {102.75044883428481`, 
       11.78511301977578, -11.785113019775807`}, {102.75044883428481`, 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.00000000000001`, 0., 0.}, {
       100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}, {102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.67375799589207`, 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {102.75044883428481`, 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589209`, 
       7.216878364870319, -4.16666666666667}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.67375799589209`, 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{102.7504488342848, 
       14.433756729740638`, -8.33333333333334}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {102.7504488342848, 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{100.00000000000001`, 0., 0.}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {100.67375799589207`, 
       8.333333333333332, -9.442564829413298*^-15}, {100.00000000000001`, 0., 
       0.}, {100.00000000000001`, 0., 0.}}], 
      Line3DBox[{{100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {102.75044883428481`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {100.67375799589207`, 
       8.333333333333332, -9.442564829413298*^-15}, {100.67375799589207`, 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {102.75044883428481`, 
       16.666666666666664`, -1.8885129658826596`*^-14}, {102.75044883428481`, 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{110., 0., 0.}, {110., 8.333333333333332, 0.}, {110., 
       8.049381885742235, 2.156825375854339}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 8.333333333333332, 0.}, {110., 
       16.666666666666664`, 0.}, {110., 16.09876377148447, 
       4.313650751708678}, {110., 8.049381885742235, 2.156825375854339}, {
       110., 8.333333333333332, 0.}}], 
      Line3DBox[{{110., 16.666666666666664`, 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {110., 16.09876377148447, 
       4.313650751708678}, {110., 16.666666666666664`, 0.}}], 
      Line3DBox[{{110., 0., 0.}, {110., 8.049381885742235, 
       2.156825375854339}, {110., 7.216878364870323, 4.166666666666666}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 8.049381885742235, 2.156825375854339}, {110., 
       16.09876377148447, 4.313650751708678}, {110., 14.433756729740645`, 
       8.333333333333332}, {110., 7.216878364870323, 4.166666666666666}, {
       110., 8.049381885742235, 2.156825375854339}}], 
      Line3DBox[{{110., 16.09876377148447, 4.313650751708678}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {110., 21.65063509461097, 
       12.499999999999998`}, {110., 14.433756729740645`, 8.333333333333332}, {
       110., 16.09876377148447, 4.313650751708678}}], 
      Line3DBox[{{110., 0., 0.}, {110., 7.216878364870323, 
       4.166666666666666}, {110., 5.892556509887896, 5.8925565098878945`}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 7.216878364870323, 4.166666666666666}, {110., 
       14.433756729740645`, 8.333333333333332}, {110., 11.785113019775793`, 
       11.785113019775789`}, {110., 5.892556509887896, 5.8925565098878945`}, {
       110., 7.216878364870323, 4.166666666666666}}], 
      Line3DBox[{{110., 14.433756729740645`, 8.333333333333332}, {110., 
       21.65063509461097, 12.499999999999998`}, {110., 17.67766952966369, 
       17.677669529663685`}, {110., 11.785113019775793`, 
       11.785113019775789`}, {110., 14.433756729740645`, 8.333333333333332}}],
       Line3DBox[{{110., 0., 0.}, {110., 5.892556509887896, 
       5.8925565098878945`}, {110., 4.166666666666668, 7.216878364870322}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 5.892556509887896, 5.8925565098878945`}, {110., 
       11.785113019775793`, 11.785113019775789`}, {110., 8.333333333333336, 
       14.433756729740644`}, {110., 4.166666666666668, 7.216878364870322}, {
       110., 5.892556509887896, 5.8925565098878945`}}], 
      Line3DBox[{{110., 11.785113019775793`, 11.785113019775789`}, {110., 
       17.67766952966369, 17.677669529663685`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 8.333333333333336, 14.433756729740644`}, {
       110., 11.785113019775793`, 11.785113019775789`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 4.166666666666668, 
       7.216878364870322}, {110., 2.156825375854341, 8.049381885742235}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 4.166666666666668, 7.216878364870322}, {110., 
       8.333333333333336, 14.433756729740644`}, {110., 4.313650751708682, 
       16.09876377148447}, {110., 2.156825375854341, 8.049381885742235}, {
       110., 4.166666666666668, 7.216878364870322}}], 
      Line3DBox[{{110., 8.333333333333336, 14.433756729740644`}, {110., 
       12.500000000000004`, 21.650635094610966`}, {110., 6.470476127563024, 
       24.148145657226706`}, {110., 4.313650751708682, 16.09876377148447}, {
       110., 8.333333333333336, 14.433756729740644`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 2.156825375854341, 
       8.049381885742235}, {110., 2.3606412073533245`*^-15, 
       8.333333333333332}, {110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 2.156825375854341, 8.049381885742235}, {110., 
       4.313650751708682, 16.09876377148447}, {110., 4.721282414706649*^-15, 
       16.666666666666664`}, {110., 2.3606412073533245`*^-15, 
       8.333333333333332}, {110., 2.156825375854341, 8.049381885742235}}], 
      Line3DBox[{{110., 4.313650751708682, 16.09876377148447}, {110., 
       6.470476127563024, 24.148145657226706`}, {110., 
       7.0819236220599744`*^-15, 25.}, {110., 4.721282414706649*^-15, 
       16.666666666666664`}, {110., 4.313650751708682, 16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., 5.102694996447305*^-16, 
       8.333333333333332}, {110., -2.1568253758543383`, 8.049381885742235}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., 5.102694996447305*^-16, 8.333333333333332}, {110., 
       1.020538999289461*^-15, 16.666666666666664`}, {
       110., -4.313650751708677, 16.09876377148447}, {
       110., -2.1568253758543383`, 8.049381885742235}, {110., 
       5.102694996447305*^-16, 8.333333333333332}}], 
      Line3DBox[{{110., 1.020538999289461*^-15, 16.666666666666664`}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -4.313650751708677, 16.09876377148447}, {
       110., 1.020538999289461*^-15, 16.666666666666664`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -2.1568253758543383`, 
       8.049381885742235}, {110., -4.166666666666664, 7.216878364870323}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -2.1568253758543383`, 8.049381885742235}, {
       110., -4.313650751708677, 16.09876377148447}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -4.166666666666664, 7.216878364870323}, {
       110., -2.1568253758543383`, 8.049381885742235}}], 
      Line3DBox[{{110., -4.313650751708677, 16.09876377148447}, {
       110., -6.470476127563016, 24.148145657226706`}, {
       110., -12.499999999999995`, 21.65063509461097}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -4.313650751708677, 16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., -4.166666666666664, 
       7.216878364870323}, {110., -5.8925565098878945`, 5.892556509887896}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -4.166666666666664, 7.216878364870323}, {
       110., -8.333333333333329, 14.433756729740645`}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -5.8925565098878945`, 5.892556509887896}, {
       110., -4.166666666666664, 7.216878364870323}}], 
      Line3DBox[{{110., -8.333333333333329, 14.433756729740645`}, {
       110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -8.333333333333329, 14.433756729740645`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -5.8925565098878945`, 
       5.892556509887896}, {110., -7.216878364870323, 4.166666666666666}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -5.8925565098878945`, 5.892556509887896}, {
       110., -11.785113019775789`, 11.785113019775793`}, {
       110., -14.433756729740645`, 8.333333333333332}, {
       110., -7.216878364870323, 4.166666666666666}, {
       110., -5.8925565098878945`, 5.892556509887896}}], 
      Line3DBox[{{110., -11.785113019775789`, 11.785113019775793`}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       110., -14.433756729740645`, 8.333333333333332}, {
       110., -11.785113019775789`, 11.785113019775793`}}], 
      Line3DBox[{{110., 0., 0.}, {110., -7.21687836487032, 
       4.16666666666667}, {110., -8.049381885742235, 2.156825375854342}, {
       110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -7.21687836487032, 4.16666666666667}, {
       110., -14.43375672974064, 8.33333333333334}, {110., -16.09876377148447,
        4.313650751708684}, {110., -8.049381885742235, 2.156825375854342}, {
       110., -7.21687836487032, 4.16666666666667}}], 
      Line3DBox[{{110., -14.43375672974064, 8.33333333333334}, {
       110., -21.650635094610962`, 12.500000000000009`}, {
       110., -24.148145657226706`, 6.470476127563026}, {
       110., -16.09876377148447, 4.313650751708684}, {
       110., -14.43375672974064, 8.33333333333334}}], 
      Line3DBox[{{110., 0., 0.}, {110., -8.049381885742235, 
       2.156825375854342}, {110., -8.333333333333332, 
       1.020538999289461*^-15}, {110., 0., 0.}, {110., 0., 0.}}], 
      Line3DBox[{{110., -8.049381885742235, 2.156825375854342}, {
       110., -16.09876377148447, 4.313650751708684}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -8.333333333333332, 1.020538999289461*^-15}, {
       110., -8.049381885742235, 2.156825375854342}}], 
      Line3DBox[{{110., -16.09876377148447, 4.313650751708684}, {
       110., -24.148145657226706`, 6.470476127563026}, {110., -25., 
       3.061616997868383*^-15}, {110., -16.666666666666664`, 
       2.041077998578922*^-15}, {110., -16.09876377148447, 
       4.313650751708684}}], 
      Line3DBox[{{110., 0., 0.}, {110., -8.333333333333332, 
       1.020538999289461*^-15}, {
       110., -8.049381885742235, -2.15682537585434}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -8.333333333333332, 1.020538999289461*^-15}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -16.09876377148447, -4.31365075170868}, {
       110., -8.049381885742235, -2.15682537585434}, {
       110., -8.333333333333332, 1.020538999289461*^-15}}], 
      Line3DBox[{{110., -16.666666666666664`, 2.041077998578922*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       110., -16.09876377148447, -4.31365075170868}, {
       110., -16.666666666666664`, 2.041077998578922*^-15}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -8.049381885742235, -2.156825375854336}, {
       110., -7.216878364870323, -4.166666666666664}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -8.049381885742235, -2.156825375854336}, {
       110., -16.09876377148447, -4.313650751708672}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -7.216878364870323, -4.166666666666664}, {
       110., -8.049381885742235, -2.156825375854336}}], 
      Line3DBox[{{110., -16.09876377148447, -4.313650751708672}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -16.09876377148447, -4.313650751708672}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -7.216878364870323, -4.166666666666664}, {
       110., -5.892556509887897, -5.8925565098878945`}, {110., 0., 0.}, {110.,
        0., 0.}}], 
      Line3DBox[{{110., -7.216878364870323, -4.166666666666664}, {
       110., -14.433756729740645`, -8.333333333333329}, {
       110., -11.785113019775794`, -11.785113019775789`}, {
       110., -5.892556509887897, -5.8925565098878945`}, {
       110., -7.216878364870323, -4.166666666666664}}], 
      Line3DBox[{{110., -14.433756729740645`, -8.333333333333329}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       110., -11.785113019775794`, -11.785113019775789`}, {
       110., -14.433756729740645`, -8.333333333333329}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -5.892556509887898, -5.892556509887893}, {
       110., -4.16666666666667, -7.216878364870319}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -5.892556509887898, -5.892556509887893}, {
       110., -11.785113019775796`, -11.785113019775785`}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -4.16666666666667, -7.216878364870319}, {
       110., -5.892556509887898, -5.892556509887893}}], 
      Line3DBox[{{110., -11.785113019775796`, -11.785113019775785`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -11.785113019775796`, -11.785113019775785`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -4.16666666666667, -7.216878364870319}, {
       110., -2.156825375854346, -8.049381885742234}, {110., 0., 0.}, {110., 
       0., 0.}}], 
      Line3DBox[{{110., -4.16666666666667, -7.216878364870319}, {
       110., -8.33333333333334, -14.433756729740638`}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -2.156825375854346, -8.049381885742234}, {
       110., -4.16666666666667, -7.216878364870319}}], 
      Line3DBox[{{110., -8.33333333333334, -14.433756729740638`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -8.33333333333334, -14.433756729740638`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -2.156825375854346, -8.049381885742234}, {
       110., -8.932295329768568*^-15, -8.333333333333332}, {110., 0., 0.}, {
       110., 0., 0.}}], 
      Line3DBox[{{110., -2.156825375854346, -8.049381885742234}, {
       110., -4.313650751708692, -16.098763771484467`}, {
       110., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       110., -8.932295329768568*^-15, -8.333333333333332}, {
       110., -2.156825375854346, -8.049381885742234}}], 
      Line3DBox[{{110., -4.313650751708692, -16.098763771484467`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       110., -1.7864590659537137`*^-14, -16.666666666666664`}, {
       110., -4.313650751708692, -16.098763771484467`}}], 
      Line3DBox[{{110., 0., 0.}, {
       110., -1.5308084989341913`*^-15, -8.333333333333332}, {110., 
       2.1568253758543356`, -8.049381885742235}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{
       110., -1.5308084989341913`*^-15, -8.333333333333332}, {
       110., -3.0616169978683826`*^-15, -16.666666666666664`}, {110., 
       4.313650751708671, -16.09876377148447}, {110., 
       2.1568253758543356`, -8.049381885742235}, {
       110., -1.5308084989341913`*^-15, -8.333333333333332}}], 
      Line3DBox[{{110., -3.0616169978683826`*^-15, -16.666666666666664`}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {110., 
       4.313650751708671, -16.09876377148447}, {
       110., -3.0616169978683826`*^-15, -16.666666666666664`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       2.1568253758543356`, -8.049381885742235}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 2.1568253758543356`, -8.049381885742235}, {
       110., 4.313650751708671, -16.09876377148447}, {110., 
       8.333333333333321, -14.43375672974065}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 
       2.1568253758543356`, -8.049381885742235}}], 
      Line3DBox[{{110., 4.313650751708671, -16.09876377148447}, {110., 
       6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       8.333333333333321, -14.43375672974065}, {110., 
       4.313650751708671, -16.09876377148447}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       4.166666666666661, -7.216878364870325}, {110., 
       5.89255650988789, -5.892556509887903}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 4.166666666666661, -7.216878364870325}, {110.,
        8.333333333333321, -14.43375672974065}, {110., 
       11.78511301977578, -11.785113019775807`}, {110., 
       5.89255650988789, -5.892556509887903}, {110., 
       4.166666666666661, -7.216878364870325}}], 
      Line3DBox[{{110., 8.333333333333321, -14.43375672974065}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {110., 
       11.78511301977578, -11.785113019775807`}, {110., 
       8.333333333333321, -14.43375672974065}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       5.8925565098878945`, -5.892556509887897}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 0., 0.}, {110., 0., 
       0.}}], 
      Line3DBox[{{110., 5.8925565098878945`, -5.892556509887897}, {110., 
       11.785113019775789`, -11.785113019775794`}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 
       5.8925565098878945`, -5.892556509887897}}], 
      Line3DBox[{{110., 11.785113019775789`, -11.785113019775794`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       11.785113019775789`, -11.785113019775794`}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       7.216878364870319, -4.16666666666667}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 0., 0.}, {110., 0., 
       0.}}], Line3DBox[{{110., 7.216878364870319, -4.16666666666667}, {110., 
       14.433756729740638`, -8.33333333333334}, {110., 
       16.098763771484467`, -4.313650751708693}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 
       7.216878364870319, -4.16666666666667}}], 
      Line3DBox[{{110., 14.433756729740638`, -8.33333333333334}, {110., 
       21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       16.098763771484467`, -4.313650751708693}, {110., 
       14.433756729740638`, -8.33333333333334}}], 
      Line3DBox[{{110., 0., 0.}, {110., 
       8.049381885742234, -2.1568253758543463`}, {110., 
       8.333333333333332, -9.442564829413298*^-15}, {110., 0., 0.}, {110., 0.,
        0.}}], Line3DBox[{{110., 8.049381885742234, -2.1568253758543463`}, {
       110., 16.098763771484467`, -4.313650751708693}, {110., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {110., 
       8.333333333333332, -9.442564829413298*^-15}, {110., 
       8.049381885742234, -2.1568253758543463`}}], 
      Line3DBox[{{110., 16.098763771484467`, -4.313650751708693}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {110., 
       16.666666666666664`, -1.8885129658826596`*^-14}, {110., 
       16.098763771484467`, -4.313650751708693}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 
      6.123233995736766*^-15}, {140., -16.66666666666667, 
      5.102694996447306*^-15}, {132.7504488342848, -16.666666666666668`, 
      0.}, {136.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{132.7504488342848, -16.666666666666668`, 0.}, {
      140., -16.66666666666667, 5.102694996447306*^-15}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      130.67375799589206`, -8.333333333333336, 0.}, {
      132.7504488342848, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{130.67375799589206`, -8.333333333333336, 0.}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      140., -7.105427357601002*^-15, 3.061616997868384*^-15}, {130., 0., 
      0.}, {130.67375799589206`, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{130., 0., 0.}, {140., 0., 3.061616997868383*^-15}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {130.67375799589206`, 
      8.333333333333329, 0.}, {130., 0., 0.}}], 
     Polygon3DBox[{{130.67375799589206`, 8.333333333333329, 0.}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {140., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {132.7504488342848, 
      16.666666666666664`, 0.}, {130.67375799589206`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{132.7504488342848, 16.666666666666664`, 0.}, {
      140., 16.666666666666664`, 1.0205389992894615`*^-15}, {140., 
      24.999999999999996`, 5.098616525425841*^-31}, {136.4219745809556, 
      24.999999999999993`, 0.}, {132.7504488342848, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA6Wu3ahgTfRgQEMLA8wQEGykNta5hkJDqtXgYAB
XPzMjrc5/aEJDmvA4gpwcTBwSICa82EPuvoVEPUOMPEkqPkQcQO4OMw9//6D
gAVcHAwa4O7EEF+NZg5MfA2avajmfLBBF1+BzV9wcQMMcag74eK4whMASr9a
Hg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{130., 0., -25.}, {140., 3.061616997868383*^-15, -25.}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}, {130., 0., -25.}}], 
       Polygon3DBox[{{130., 5.102694996447305*^-16, -16.666666666666668`}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {140., 
        2.0410779985789223`*^-15, -8.333333333333336}, {130., 
        1.020538999289461*^-15, -8.333333333333336}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{130., 1.020538999289461*^-15, -8.333333333333336}, {
        140., 2.0410779985789223`*^-15, -8.333333333333336}, {140., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {130., 
        1.5308084989341915`*^-15, 0.}, {130., 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{130., 1.5308084989341915`*^-15, 0.}, {140., 
        1.5308084989341915`*^-15, 0.}, {140., 1.0205389992894611`*^-15, 
        8.333333333333332}, {130., 2.041077998578922*^-15, 
        8.333333333333329}, {130., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{130., 2.041077998578922*^-15, 8.333333333333329}, {140.,
         1.0205389992894611`*^-15, 8.333333333333332}, {140., 
        5.102694996447307*^-16, 16.666666666666664`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}, {130., 
        2.041077998578922*^-15, 8.333333333333329}}], 
       Polygon3DBox[{{130., 2.5513474982236525`*^-15, 16.666666666666664`}, {
        140., 5.102694996447308*^-16, 16.666666666666664`}, {140., 
        2.5493082627129206`*^-31, 24.999999999999996`}, {130., 
        3.0616169978683826`*^-15, 24.999999999999993`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihwSHBgQAGWB9DFV68CAQMM8TVgcQUMcQj4sAdd
fAVEvQN2cQMM8X//QcACwm9IRHcnhvhqZHOQxNcg24thzgcbdPEVyP7CEDfA
EIe68wC6+6HuPAAAPE1IaA==
         "]]}}}}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{136.4219745809556, -25., -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       136.4219745809556, -25., -16.666666666666664`}, {
       136.4219745809556, -25., -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -8.33333333333333}, {
       136.4219745809556, -25., -8.33333333333333}, {
       136.4219745809556, -25., -16.666666666666664`}}], 
      Line3DBox[{{136.4219745809556, -25., -8.333333333333332}, {
       132.7504488342848, -16.666666666666664`, -8.333333333333332}, {
       132.7504488342848, -16.666666666666664`, 1.7763568394002505`*^-15}, {
       136.4219745809556, -25., 1.7763568394002505`*^-15}, {
       136.4219745809556, -25., -8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, -25., 0.}, {
       132.7504488342848, -16.666666666666664`, 0.}, {
       132.7504488342848, -16.666666666666664`, 8.333333333333334}, {
       136.4219745809556, -25., 8.333333333333334}, {136.4219745809556, -25., 
       0.}}], Line3DBox[{{136.4219745809556, -25., 8.333333333333336}, {
       132.7504488342848, -16.666666666666664`, 8.333333333333336}, {
       132.7504488342848, -16.666666666666664`, 16.66666666666667}, {
       136.4219745809556, -25., 16.66666666666667}, {136.4219745809556, -25., 
       8.333333333333336}}], 
      Line3DBox[{{136.4219745809556, -25., 16.66666666666667}, {
       132.7504488342848, -16.666666666666664`, 16.66666666666667}, {
       132.7504488342848, -16.666666666666664`, 25.000000000000007`}, {
       136.4219745809556, -25., 25.000000000000007`}, {
       136.4219745809556, -25., 16.66666666666667}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, -25.}, {
       130.67375799589206`, -8.33333333333333, -25.}, {
       130.67375799589206`, -8.33333333333333, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       132.7504488342848, -16.666666666666664`, -25.}}], 
      Line3DBox[{{
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333, -16.666666666666664`}, {
       130.67375799589206`, -8.33333333333333, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`, -8.33333333333333}, {
       132.7504488342848, -16.666666666666664`, -16.666666666666664`}}], 
      Line3DBox[{{
       132.7504488342848, -16.666666666666664`, -8.333333333333332}, {
       130.67375799589206`, -8.33333333333333, -8.333333333333332}, {
       130.67375799589206`, -8.33333333333333, 1.7763568394002505`*^-15}, {
       132.7504488342848, -16.666666666666664`, 1.7763568394002505`*^-15}, {
       132.7504488342848, -16.666666666666664`, -8.333333333333332}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, 0.}, {
       130.67375799589206`, -8.33333333333333, 0.}, {
       130.67375799589206`, -8.33333333333333, 8.333333333333334}, {
       132.7504488342848, -16.666666666666664`, 8.333333333333334}, {
       132.7504488342848, -16.666666666666664`, 0.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, 
       8.333333333333336}, {130.67375799589206`, -8.33333333333333, 
       8.333333333333336}, {130.67375799589206`, -8.33333333333333, 
       16.66666666666667}, {132.7504488342848, -16.666666666666664`, 
       16.66666666666667}, {132.7504488342848, -16.666666666666664`, 
       8.333333333333336}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, 
       16.66666666666667}, {130.67375799589206`, -8.33333333333333, 
       16.66666666666667}, {130.67375799589206`, -8.33333333333333, 
       25.000000000000007`}, {132.7504488342848, -16.666666666666664`, 
       25.000000000000007`}, {132.7504488342848, -16.666666666666664`, 
       16.66666666666667}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, -25.}, {130., 
       1.7763568394002505`*^-15, -25.}, {130., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {
       130.67375799589206`, -8.333333333333332, -16.666666666666664`}, {
       130.67375799589206`, -8.333333333333332, -25.}}], 
      Line3DBox[{{
       130.67375799589206`, -8.333333333333332, -16.666666666666664`}, {130., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {130., 
       1.7763568394002505`*^-15, -8.33333333333333}, {
       130.67375799589206`, -8.333333333333332, -8.33333333333333}, {
       130.67375799589206`, -8.333333333333332, -16.666666666666664`}}], 
      Line3DBox[{{
       130.67375799589206`, -8.333333333333332, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15, -8.333333333333332}, {130., 
       1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332, 1.7763568394002505`*^-15}, {
       130.67375799589206`, -8.333333333333332, -8.333333333333332}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, 0.}, {130., 
       1.7763568394002505`*^-15, 0.}, {130., 1.7763568394002505`*^-15, 
       8.333333333333334}, {130.67375799589206`, -8.333333333333332, 
       8.333333333333334}, {130.67375799589206`, -8.333333333333332, 0.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, 
       8.333333333333336}, {130., 1.7763568394002505`*^-15, 
       8.333333333333336}, {130., 1.7763568394002505`*^-15, 
       16.66666666666667}, {130.67375799589206`, -8.333333333333332, 
       16.66666666666667}, {130.67375799589206`, -8.333333333333332, 
       8.333333333333336}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, 
       16.66666666666667}, {130., 1.7763568394002505`*^-15, 
       16.66666666666667}, {130., 1.7763568394002505`*^-15, 
       25.000000000000007`}, {130.67375799589206`, -8.333333333333332, 
       25.000000000000007`}, {130.67375799589206`, -8.333333333333332, 
       16.66666666666667}}], 
      Line3DBox[{{130., 0., -25.}, {130.67375799589206`, 
       8.333333333333334, -25.}, {130.67375799589206`, 
       8.333333333333334, -16.666666666666664`}, {130., 
       0., -16.666666666666664`}, {130., 0., -25.}}], 
      Line3DBox[{{130., 0., -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333334, -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333334, -8.33333333333333}, {130., 0., -8.33333333333333}, {
       130., 0., -16.666666666666664`}}], 
      Line3DBox[{{130., 0., -8.333333333333332}, {130.67375799589206`, 
       8.333333333333334, -8.333333333333332}, {130.67375799589206`, 
       8.333333333333334, 1.7763568394002505`*^-15}, {130., 0., 
       1.7763568394002505`*^-15}, {130., 0., -8.333333333333332}}], 
      Line3DBox[{{130., 0., 0.}, {130.67375799589206`, 8.333333333333334, 
       0.}, {130.67375799589206`, 8.333333333333334, 8.333333333333334}, {
       130., 0., 8.333333333333334}, {130., 0., 0.}}], 
      Line3DBox[{{130., 0., 8.333333333333336}, {130.67375799589206`, 
       8.333333333333334, 8.333333333333336}, {130.67375799589206`, 
       8.333333333333334, 16.66666666666667}, {130., 0., 16.66666666666667}, {
       130., 0., 8.333333333333336}}], 
      Line3DBox[{{130., 0., 16.66666666666667}, {130.67375799589206`, 
       8.333333333333334, 16.66666666666667}, {130.67375799589206`, 
       8.333333333333334, 25.000000000000007`}, {130., 0., 
       25.000000000000007`}, {130., 0., 16.66666666666667}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, -25.}, {
       132.7504488342848, 16.66666666666667, -25.}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333336, -16.666666666666664`}, {130.67375799589206`, 
       8.333333333333336, -25.}}], 
      Line3DBox[{{130.67375799589206`, 
       8.333333333333336, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -8.33333333333333}, {130.67375799589206`, 
       8.333333333333336, -8.33333333333333}, {130.67375799589206`, 
       8.333333333333336, -16.666666666666664`}}], 
      Line3DBox[{{130.67375799589206`, 
       8.333333333333336, -8.333333333333332}, {132.7504488342848, 
       16.66666666666667, -8.333333333333332}, {132.7504488342848, 
       16.66666666666667, 1.7763568394002505`*^-15}, {130.67375799589206`, 
       8.333333333333336, 1.7763568394002505`*^-15}, {130.67375799589206`, 
       8.333333333333336, -8.333333333333332}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, 0.}, {
       132.7504488342848, 16.66666666666667, 0.}, {132.7504488342848, 
       16.66666666666667, 8.333333333333334}, {130.67375799589206`, 
       8.333333333333336, 8.333333333333334}, {130.67375799589206`, 
       8.333333333333336, 0.}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, 
       8.333333333333336}, {132.7504488342848, 16.66666666666667, 
       8.333333333333336}, {132.7504488342848, 16.66666666666667, 
       16.66666666666667}, {130.67375799589206`, 8.333333333333336, 
       16.66666666666667}, {130.67375799589206`, 8.333333333333336, 
       8.333333333333336}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333336, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667, 
       16.66666666666667}, {132.7504488342848, 16.66666666666667, 
       25.000000000000007`}, {130.67375799589206`, 8.333333333333336, 
       25.000000000000007`}, {130.67375799589206`, 8.333333333333336, 
       16.66666666666667}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, -25.}, {
       136.4219745809556, 25.000000000000007`, -25.}, {136.4219745809556, 
       25.000000000000007`, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {132.7504488342848, 
       16.66666666666667, -25.}}], 
      Line3DBox[{{132.7504488342848, 
       16.66666666666667, -16.666666666666664`}, {136.4219745809556, 
       25.000000000000007`, -16.666666666666664`}, {136.4219745809556, 
       25.000000000000007`, -8.33333333333333}, {132.7504488342848, 
       16.66666666666667, -8.33333333333333}, {132.7504488342848, 
       16.66666666666667, -16.666666666666664`}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, -8.333333333333332}, {
       136.4219745809556, 25.000000000000007`, -8.333333333333332}, {
       136.4219745809556, 25.000000000000007`, 1.7763568394002505`*^-15}, {
       132.7504488342848, 16.66666666666667, 1.7763568394002505`*^-15}, {
       132.7504488342848, 16.66666666666667, -8.333333333333332}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, 0.}, {
       136.4219745809556, 25.000000000000007`, 0.}, {136.4219745809556, 
       25.000000000000007`, 8.333333333333334}, {132.7504488342848, 
       16.66666666666667, 8.333333333333334}, {132.7504488342848, 
       16.66666666666667, 0.}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, 8.333333333333336}, {
       136.4219745809556, 25.000000000000007`, 8.333333333333336}, {
       136.4219745809556, 25.000000000000007`, 16.66666666666667}, {
       132.7504488342848, 16.66666666666667, 16.66666666666667}, {
       132.7504488342848, 16.66666666666667, 8.333333333333336}}], 
      Line3DBox[{{132.7504488342848, 16.66666666666667, 16.66666666666667}, {
       136.4219745809556, 25.000000000000007`, 16.66666666666667}, {
       136.4219745809556, 25.000000000000007`, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667, 25.000000000000007`}, {
       132.7504488342848, 16.66666666666667, 16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{140., -25., -25.}, {140., -16.666666666666664`, -25.}, {
       140., -16.666666666666664`, -16.666666666666664`}, {
       140., -25., -16.666666666666664`}, {140., -25., -25.}}], 
      Line3DBox[{{140., -25., -16.666666666666664`}, {
       140., -16.666666666666664`, -16.666666666666664`}, {
       140., -16.666666666666664`, -8.33333333333333}, {
       140., -25., -8.33333333333333}, {140., -25., -16.666666666666664`}}], 
      Line3DBox[{{140., -25., -8.333333333333332}, {
       140., -16.666666666666664`, -8.333333333333332}, {
       140., -16.666666666666664`, 1.7763568394002505`*^-15}, {140., -25., 
       1.7763568394002505`*^-15}, {140., -25., -8.333333333333332}}], 
      Line3DBox[{{140., -25., 0.}, {140., -16.666666666666664`, 0.}, {
       140., -16.666666666666664`, 8.333333333333334}, {140., -25., 
       8.333333333333334}, {140., -25., 0.}}], 
      Line3DBox[{{140., -25., 8.333333333333336}, {140., -16.666666666666664`,
        8.333333333333336}, {140., -16.666666666666664`, 16.66666666666667}, {
       140., -25., 16.66666666666667}, {140., -25., 8.333333333333336}}], 
      Line3DBox[{{140., -25., 16.66666666666667}, {140., -16.666666666666664`,
        16.66666666666667}, {140., -16.666666666666664`, 
       25.000000000000007`}, {140., -25., 25.000000000000007`}, {140., -25., 
       16.66666666666667}}], 
      Line3DBox[{{140., -16.666666666666664`, -25.}, {
       140., -8.33333333333333, -25.}, {
       140., -8.33333333333333, -16.666666666666664`}, {
       140., -16.666666666666664`, -16.666666666666664`}, {
       140., -16.666666666666664`, -25.}}], 
      Line3DBox[{{140., -16.666666666666664`, -16.666666666666664`}, {
       140., -8.33333333333333, -16.666666666666664`}, {
       140., -8.33333333333333, -8.33333333333333}, {
       140., -16.666666666666664`, -8.33333333333333}, {
       140., -16.666666666666664`, -16.666666666666664`}}], 
      Line3DBox[{{140., -16.666666666666664`, -8.333333333333332}, {
       140., -8.33333333333333, -8.333333333333332}, {140., -8.33333333333333,
        1.7763568394002505`*^-15}, {140., -16.666666666666664`, 
       1.7763568394002505`*^-15}, {
       140., -16.666666666666664`, -8.333333333333332}}], 
      Line3DBox[{{140., -16.666666666666664`, 0.}, {140., -8.33333333333333, 
       0.}, {140., -8.33333333333333, 8.333333333333334}, {
       140., -16.666666666666664`, 8.333333333333334}, {
       140., -16.666666666666664`, 0.}}], 
      Line3DBox[{{140., -16.666666666666664`, 8.333333333333336}, {
       140., -8.33333333333333, 8.333333333333336}, {140., -8.33333333333333, 
       16.66666666666667}, {140., -16.666666666666664`, 16.66666666666667}, {
       140., -16.666666666666664`, 8.333333333333336}}], 
      Line3DBox[{{140., -16.666666666666664`, 16.66666666666667}, {
       140., -8.33333333333333, 16.66666666666667}, {140., -8.33333333333333, 
       25.000000000000007`}, {140., -16.666666666666664`, 
       25.000000000000007`}, {140., -16.666666666666664`, 
       16.66666666666667}}], 
      Line3DBox[{{140., -8.333333333333332, -25.}, {140., 
       1.7763568394002505`*^-15, -25.}, {140., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {
       140., -8.333333333333332, -16.666666666666664`}, {
       140., -8.333333333333332, -25.}}], 
      Line3DBox[{{140., -8.333333333333332, -16.666666666666664`}, {140., 
       1.7763568394002505`*^-15, -16.666666666666664`}, {140., 
       1.7763568394002505`*^-15, -8.33333333333333}, {
       140., -8.333333333333332, -8.33333333333333}, {
       140., -8.333333333333332, -16.666666666666664`}}], 
      Line3DBox[{{140., -8.333333333333332, -8.333333333333332}, {140., 
       1.7763568394002505`*^-15, -8.333333333333332}, {140., 
       1.7763568394002505`*^-15, 1.7763568394002505`*^-15}, {
       140., -8.333333333333332, 1.7763568394002505`*^-15}, {
       140., -8.333333333333332, -8.333333333333332}}], 
      Line3DBox[{{140., -8.333333333333332, 0.}, {140., 
       1.7763568394002505`*^-15, 0.}, {140., 1.7763568394002505`*^-15, 
       8.333333333333334}, {140., -8.333333333333332, 8.333333333333334}, {
       140., -8.333333333333332, 0.}}], 
      Line3DBox[{{140., -8.333333333333332, 8.333333333333336}, {140., 
       1.7763568394002505`*^-15, 8.333333333333336}, {140., 
       1.7763568394002505`*^-15, 16.66666666666667}, {
       140., -8.333333333333332, 16.66666666666667}, {
       140., -8.333333333333332, 8.333333333333336}}], 
      Line3DBox[{{140., -8.333333333333332, 16.66666666666667}, {140., 
       1.7763568394002505`*^-15, 16.66666666666667}, {140., 
       1.7763568394002505`*^-15, 25.000000000000007`}, {
       140., -8.333333333333332, 25.000000000000007`}, {
       140., -8.333333333333332, 16.66666666666667}}], 
      Line3DBox[{{140., 0., -25.}, {140., 8.333333333333334, -25.}, {140., 
       8.333333333333334, -16.666666666666664`}, {140., 
       0., -16.666666666666664`}, {140., 0., -25.}}], 
      Line3DBox[{{140., 0., -16.666666666666664`}, {140., 
       8.333333333333334, -16.666666666666664`}, {140., 
       8.333333333333334, -8.33333333333333}, {140., 0., -8.33333333333333}, {
       140., 0., -16.666666666666664`}}], 
      Line3DBox[{{140., 0., -8.333333333333332}, {140., 
       8.333333333333334, -8.333333333333332}, {140., 8.333333333333334, 
       1.7763568394002505`*^-15}, {140., 0., 1.7763568394002505`*^-15}, {140.,
        0., -8.333333333333332}}], 
      Line3DBox[{{140., 0., 0.}, {140., 8.333333333333334, 0.}, {140., 
       8.333333333333334, 8.333333333333334}, {140., 0., 8.333333333333334}, {
       140., 0., 0.}}], 
      Line3DBox[{{140., 0., 8.333333333333336}, {140., 8.333333333333334, 
       8.333333333333336}, {140., 8.333333333333334, 16.66666666666667}, {
       140., 0., 16.66666666666667}, {140., 0., 8.333333333333336}}], 
      Line3DBox[{{140., 0., 16.66666666666667}, {140., 8.333333333333334, 
       16.66666666666667}, {140., 8.333333333333334, 25.000000000000007`}, {
       140., 0., 25.000000000000007`}, {140., 0., 16.66666666666667}}], 
      Line3DBox[{{140., 8.333333333333336, -25.}, {140., 
       16.66666666666667, -25.}, {140., 
       16.66666666666667, -16.666666666666664`}, {140., 
       8.333333333333336, -16.666666666666664`}, {140., 
       8.333333333333336, -25.}}], 
      Line3DBox[{{140., 8.333333333333336, -16.666666666666664`}, {140., 
       16.66666666666667, -16.666666666666664`}, {140., 
       16.66666666666667, -8.33333333333333}, {140., 
       8.333333333333336, -8.33333333333333}, {140., 
       8.333333333333336, -16.666666666666664`}}], 
      Line3DBox[{{140., 8.333333333333336, -8.333333333333332}, {140., 
       16.66666666666667, -8.333333333333332}, {140., 16.66666666666667, 
       1.7763568394002505`*^-15}, {140., 8.333333333333336, 
       1.7763568394002505`*^-15}, {140., 
       8.333333333333336, -8.333333333333332}}], 
      Line3DBox[{{140., 8.333333333333336, 0.}, {140., 16.66666666666667, 
       0.}, {140., 16.66666666666667, 8.333333333333334}, {140., 
       8.333333333333336, 8.333333333333334}, {140., 8.333333333333336, 0.}}],
       Line3DBox[{{140., 8.333333333333336, 8.333333333333336}, {140., 
       16.66666666666667, 8.333333333333336}, {140., 16.66666666666667, 
       16.66666666666667}, {140., 8.333333333333336, 16.66666666666667}, {
       140., 8.333333333333336, 8.333333333333336}}], 
      Line3DBox[{{140., 8.333333333333336, 16.66666666666667}, {140., 
       16.66666666666667, 16.66666666666667}, {140., 16.66666666666667, 
       25.000000000000007`}, {140., 8.333333333333336, 25.000000000000007`}, {
       140., 8.333333333333336, 16.66666666666667}}], 
      Line3DBox[{{140., 16.66666666666667, -25.}, {140., 
       25.000000000000007`, -25.}, {140., 
       25.000000000000007`, -16.666666666666664`}, {140., 
       16.66666666666667, -16.666666666666664`}, {140., 
       16.66666666666667, -25.}}], 
      Line3DBox[{{140., 16.66666666666667, -16.666666666666664`}, {140., 
       25.000000000000007`, -16.666666666666664`}, {140., 
       25.000000000000007`, -8.33333333333333}, {140., 
       16.66666666666667, -8.33333333333333}, {140., 
       16.66666666666667, -16.666666666666664`}}], 
      Line3DBox[{{140., 16.66666666666667, -8.333333333333332}, {140., 
       25.000000000000007`, -8.333333333333332}, {140., 25.000000000000007`, 
       1.7763568394002505`*^-15}, {140., 16.66666666666667, 
       1.7763568394002505`*^-15}, {140., 
       16.66666666666667, -8.333333333333332}}], 
      Line3DBox[{{140., 16.66666666666667, 0.}, {140., 25.000000000000007`, 
       0.}, {140., 25.000000000000007`, 8.333333333333334}, {140., 
       16.66666666666667, 8.333333333333334}, {140., 16.66666666666667, 0.}}],
       Line3DBox[{{140., 16.66666666666667, 8.333333333333336}, {140., 
       25.000000000000007`, 8.333333333333336}, {140., 25.000000000000007`, 
       16.66666666666667}, {140., 16.66666666666667, 16.66666666666667}, {
       140., 16.66666666666667, 8.333333333333336}}], 
      Line3DBox[{{140., 16.66666666666667, 16.66666666666667}, {140., 
       25.000000000000007`, 16.66666666666667}, {140., 25.000000000000007`, 
       25.000000000000007`}, {140., 16.66666666666667, 25.000000000000007`}, {
       140., 16.66666666666667, 16.66666666666667}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{136.4219745809556, -25., 25.}, {140., -25., 25.}, {
       140., -16.666666666666668`, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}, {
       136.4219745809556, -25., 25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666668`, 25.}, {
       140., -16.666666666666668`, 25.}, {140., -8.333333333333336, 25.}, {
       130.67375799589206`, -8.333333333333336, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333334, 25.}, {
       140., -8.333333333333334, 25.}, {140., -1.3877787807814457`*^-15, 
       25.}, {130., -1.3877787807814457`*^-15, 25.}, {
       130.67375799589206`, -8.333333333333334, 25.}}], 
      Line3DBox[{{130., 0., 25.}, {140., 0., 25.}, {140., 8.333333333333332, 
       25.}, {130.67375799589206`, 8.333333333333332, 25.}, {130., 0., 25.}}],
       Line3DBox[{{130.67375799589206`, 8.333333333333332, 25.}, {140., 
       8.333333333333332, 25.}, {140., 16.666666666666664`, 25.}, {
       132.7504488342848, 16.666666666666664`, 25.}, {130.67375799589206`, 
       8.333333333333332, 25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666664`, 25.}, {140., 
       16.666666666666664`, 25.}, {140., 24.999999999999993`, 25.}, {
       136.4219745809556, 24.999999999999993`, 25.}, {132.7504488342848, 
       16.666666666666664`, 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 25.}, {140., 25., 25.}, {140., 25., 
       16.666666666666668`}, {136.4219745809556, 25., 16.666666666666668`}, {
       136.4219745809556, 25., 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 16.666666666666668`}, {140., 25., 
       16.666666666666668`}, {140., 25., 8.333333333333336}, {
       136.4219745809556, 25., 8.333333333333336}, {136.4219745809556, 25., 
       16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, 25., 8.333333333333334}, {140., 25., 
       8.333333333333334}, {140., 25., 1.3877787807814457`*^-15}, {
       136.4219745809556, 25., 1.3877787807814457`*^-15}, {136.4219745809556, 
       25., 8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, 25., 0.}, {140., 25., 0.}, {140., 
       25., -8.333333333333332}, {136.4219745809556, 
       25., -8.333333333333332}, {136.4219745809556, 25., 0.}}], 
      Line3DBox[{{136.4219745809556, 25., -8.333333333333332}, {140., 
       25., -8.333333333333332}, {140., 25., -16.666666666666664`}, {
       136.4219745809556, 25., -16.666666666666664`}, {136.4219745809556, 
       25., -8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, 25., -16.666666666666664`}, {140., 
       25., -16.666666666666664`}, {140., 25., -24.999999999999993`}, {
       136.4219745809556, 25., -24.999999999999993`}, {136.4219745809556, 
       25., -16.666666666666664`}}], 
      Line3DBox[{{136.4219745809556, 25., -25.}, {140., 25., -25.}, {140., 
       16.666666666666668`, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}, {136.4219745809556, 25., -25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666668`, -25.}, {140., 
       16.666666666666668`, -25.}, {140., 8.333333333333336, -25.}, {
       130.67375799589206`, 8.333333333333336, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333334, -25.}, {140., 
       8.333333333333334, -25.}, {140., 1.3877787807814457`*^-15, -25.}, {
       130., 1.3877787807814457`*^-15, -25.}, {130.67375799589206`, 
       8.333333333333334, -25.}}], 
      Line3DBox[{{130., 0., -25.}, {140., 0., -25.}, {
       140., -8.333333333333332, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}, {130., 0., -25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, -25.}, {
       140., -8.333333333333332, -25.}, {140., -16.666666666666664`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, -25.}, {
       140., -16.666666666666664`, -25.}, {
       140., -24.999999999999993`, -25.}, {
       136.4219745809556, -24.999999999999993`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -25.}, {140., -25., -25.}, {
       140., -25., -16.666666666666668`}, {
       136.4219745809556, -25., -16.666666666666668`}, {
       136.4219745809556, -25., -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -16.666666666666668`}, {
       140., -25., -16.666666666666668`}, {140., -25., -8.333333333333336}, {
       136.4219745809556, -25., -8.333333333333336}, {
       136.4219745809556, -25., -16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, -25., -8.333333333333334}, {
       140., -25., -8.333333333333334}, {
       140., -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 0.}, {140., -25.,
        8.333333333333332}, {136.4219745809556, -25., 8.333333333333332}, {
       136.4219745809556, -25., 0.}}], 
      Line3DBox[{{136.4219745809556, -25., 8.333333333333332}, {140., -25., 
       8.333333333333332}, {140., -25., 16.666666666666664`}, {
       136.4219745809556, -25., 16.666666666666664`}, {
       136.4219745809556, -25., 8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, -25., 16.666666666666664`}, {140., -25., 
       16.666666666666664`}, {140., -25., 24.999999999999993`}, {
       136.4219745809556, -25., 24.999999999999993`}, {
       136.4219745809556, -25., 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., 30., -30.}, {250., -30., -30.}, {250., -30., 30.}, {
       250., 30., 30.}, {250., 30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., -30., -30.}, {0., -30., -30.}, {0., -30., 30.}, {
       250., -30., 30.}, {250., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0, -30, -30}, {0, 30, -30}, {0, 30, 30}, {0, -30, 30}, {
       0, -30, -30}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{0., 30., -30.}, {250., 30., -30.}, {250., 30., 30.}, {0., 
       30., 30.}, {0., 30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., -30., -30.}, {250., 30., -30.}, {0., 30., -30.}, {
       0., -30., -30.}, {250., -30., -30.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{250., 30., 30.}, {250., -30., 30.}, {0., -30., 30.}, {0., 
       30., 30.}, {250., 30., 30.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGBgB2ImIAaxwaAh0eHvO619om0GBxiQgUO+w4TTW2wrrKUd
UMSB6pOYT038MlHlQNOFtd/OMWkfgKlviT2wW/kBv4PViqA67Wy1AzD1XBxf
JqtF8DqkrjuumPPBAK5+ykX1L+u/fd0/dXJTxjpNHbh6j+eJJf8O6jq43eru
0DgiC1cf8eiVE4OAxIEpN68HrlkuAVfvDVVvDVHvAFOfBFXfBVHvAFNvh+oe
uPoDqO6Bq4+H+rcF4l+4+gaof20g/nUAABMTdcY=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     Point3DBox[{{250., 6.8080758706663715`, 0.}, {250., 
      3.984443156059287, -11.209316203680022`}, {
      250., -1.3727263963056417`, -14.08140875429107}, {
      250., -6.015625997148696, -6.163743284987863}, {
      250., -6.015625997148705, 6.163743284987854}, {
      250., -1.3727263963056515`, 14.08140875429107}, {250., 
      3.9844431560592852`, 11.209316203680025`}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367531439005*^9, 3.566086987287944*^9, 
  3.566101743445808*^9, 3.566139185968411*^9, 3.61470779476933*^9},
 CellTags->{"RayChoice", "RG9."},
 CellLabel->
  "During evaluation of \
In[37]:=",ExpressionUUID->"d7fc8bc8-e503-4e02-a570-e01b7182818a"]
}, Open  ]],

Cell[TextData[{
 "You can also use ",
 StyleBox["PlotType->Surface", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 " to look at the ray intersection points on any surface in the ray-tracing \
result. We now define ",
 StyleBox["Surface", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "RG9."},ExpressionUUID->"921d688e-0d66-4016-be31-dc9862d3972f"],

Cell[TextData[{
 StyleBox["Surface", "Input",
  FontFamily->"Courier"],
 " is a value of ",
 StyleBox["PlotType", "Input",
  FontFamily->"Courier"],
 " giving a two-dimensional plot showing selected intersection points between \
rays and one or more optical surfaces."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "Surface", 
   "RG9."},ExpressionUUID->"ab90f6a7-a383-4ac1-80ec-3fa98fb9b1f4"],

Cell[TextData[{
 "Next use ",
 StyleBox["RayChoice->{ComponentNumber->2}", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["PlotType->Surface", "Input",
  FontFamily->"Courier"],
 " to view the intersection points on the two surfaces of the cylindrical \
lens."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "RayChoice", "Surface", "ComponentNumber", 
   "RG9."},ExpressionUUID->"41a7f206-e13a-4409-be36-f56525db8c24"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[opticalsystem, PlotType->Surface, RayChoice->{ComponentNumber->2}];\
\>", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."},
 CellLabel->"In[38]:=",ExpressionUUID->"47b9e46a-25c0-4cb3-b662-0d37b89eb12d"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-17.484074475139014`, 0}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-11.03400331511883, -13.625999516698345`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{3.9648984777969347`, -17.1074453334261}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{15.811156194137844`, -7.498573927423302}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{15.81115619413785, 7.498573927423292}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{3.9648984777969583`, 17.1074453334261}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-11.034003315118827`, 13.62599951669835}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{-16.523769269449065`, 0}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-10.285069042119805`, -13.505485256879414`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{3.668042331585643, -16.939149962663937`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{14.878894459677795`, -7.441560872589042}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{14.8788944596778, 7.441560872589032}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{3.6680423315856663`, 16.939149962663937`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-10.2850690421198, 13.505485256879417`}], 
     {RGBColor[0, 0, 0], Thickness[
       NCache[
        Rational[1, 5000], 0.0002]], 
      LineBox[{{-25., -25.}, {25., -25.}, {25., 25.}, {-25., 
       25.}, {-25., -25.}}], 
      LineBox[{{-25., -25.}, {25., -25.}, {25., 25.}, {-25., 
       25.}, {-25., -25.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367531518503*^9, 3.5660869873748693`*^9, 
  3.5661017436040163`*^9, 3.56613918613977*^9, 3.614707794872945*^9},
 CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."},
 CellLabel->
  "During evaluation of \
In[38]:=",ExpressionUUID->"15442f90-5536-464e-8ab9-90af301ef1ce"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"3f256fca-30a0-473e-\
a808-d951fc8ebfa3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "10. Using ",
 StyleBox["Screen",
  FontFamily->"Courier New"],
 " to Look at the Focal Plane"
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Screen", "focal plane of system", "10.", "Using Screen", 
   "RG10."},ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b"],

Cell[TextData[{
 "The ",
 StyleBox["Screen", "Input",
  FontFamily->"Courier"],
 " component function models a single surface that samples rays at a given \
plane in space. You can use ",
 StyleBox["Screen", "Input",
  FontFamily->"Courier"],
 " to look at the focal plane of a system or to get the planar cross-section \
of ray information anywhere in the system. More advanced screens can have \
curved surfaces and circular or polygonal boundaries. Here is the definition \
of ",
 StyleBox["Screen", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Screen", "focal plane of system", "Using Screen", 
   "RG10."},ExpressionUUID->"4574287a-8995-4e63-99d6-4237667227af"],

Cell[TextData[{
 StyleBox["Screen[", "Input",
  FontFamily->"Courier"],
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " denotes a planar component that intersects rays without disturbing them."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Screen", "focal plane of system", "Using Screen", 
   "RG10."},ExpressionUUID->"cb264467-9607-4491-9e2a-150017352ac3"],

Cell[TextData[{
 "Next we use ",
 StyleBox["Screen", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " to inspect the focal plane of the optical system from Section 9. Here we \
use ",
 StyleBox["Move", "Input",
  FontFamily->"Courier"],
 " to place the screen at the focal position ",
 StyleBox["x",
  FontSlant->"Italic"],
 " = 218 as measured previously."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Screen", "focal plane of system", "Using Screen", 
   "RG10."},ExpressionUUID->"4f17e7e8-b7ef-46c4-bbe9-62737fdd5493"],

Cell[CellGroupData[{

Cell[TextData[{
 "screensystem = ",
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "[{\n\tConeOfRays[20, NumberOfRays -> 7],\n\tMove[PlanoConvexLens[100, 50, \
10], 100],\n\tMove[PlanoConvexCylindricalLens[100, {50,50}, 10], 130],\n\t\
Move[Screen[{50,50}], 218],\n\tBoundary[{-100,-100,-100}, {250,200,200}, \
GraphicDesign -> False]}];"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", 
   "RG10."},
 CellLabel->"In[39]:=",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{106.4219745809556, -25., 0.}, {110., -25., 
      6.123233995736766*^-15}, {110., -16.66666666666667, 
      5.102694996447306*^-15}, {102.75044883428481`, -16.666666666666668`, 
      0.}, {106.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{102.75044883428481`, -16.666666666666668`, 0.}, {
      110., -16.66666666666667, 5.102694996447306*^-15}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      100.67375799589207`, -8.333333333333336, 0.}, {
      102.75044883428481`, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{100.67375799589207`, -8.333333333333336, 0.}, {
      110., -8.333333333333336, 4.0821559971578446`*^-15}, {
      110., -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      100.00000000000001`, 0., 0.}, {100.67375799589207`, -8.333333333333336, 
      0.}}], Polygon3DBox[{{100.00000000000001`, 0., 0.}, {110., 0., 
      3.061616997868383*^-15}, {110., 8.333333333333332, 
      2.0410779985789223`*^-15}, {100.67375799589207`, 8.333333333333329, 
      0.}, {100.00000000000001`, 0., 0.}}], 
     Polygon3DBox[{{100.67375799589207`, 8.333333333333329, 0.}, {110., 
      8.333333333333332, 2.0410779985789223`*^-15}, {110., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {102.75044883428481`, 
      16.666666666666664`, 0.}, {100.67375799589207`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{102.75044883428481`, 16.666666666666664`, 0.}, {
      110., 16.666666666666664`, 1.0205389992894615`*^-15}, {110., 
      24.999999999999996`, 5.098616525425841*^-31}, {106.4219745809556, 
      24.999999999999993`, 0.}, {102.75044883428481`, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYwsDzAAAXHVHqi2DdEOqxeBQIG
cPGZhbdvymlHOqwBiyvAxRnBZCTUnA970NWvgKh3gIkfhZoPETeAi8Pc8+8/
CFjAxcGgIRrmTgzx1WjmwMTXoNmLas4HG3TxFWj+QhU3wBCHuhMujis8AaDR
WYY=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{106.4219745809556, 0., -25.}, {110., 
        3.061616997868383*^-15, -25.}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {106.4219745809556, 
        0., -25.}}], 
       Polygon3DBox[{{102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}, {110., 
        2.551347498223653*^-15, -16.66666666666667}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {102.75044883428481`, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{100.67375799589207`, 
        1.020538999289461*^-15, -8.333333333333336}, {110., 
        2.0410779985789223`*^-15, -8.333333333333336}, {110., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {
        100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        100.67375799589207`, 1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{100.00000000000001`, 1.5308084989341915`*^-15, 0.}, {
        110., 1.5308084989341915`*^-15, 0.}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {100.00000000000001`, 1.5308084989341915`*^-15, 
        0.}}], Polygon3DBox[{{100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}, {110., 1.0205389992894611`*^-15, 
        8.333333333333332}, {110., 5.102694996447307*^-16, 
        16.666666666666664`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {100.67375799589207`, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {110., 5.102694996447308*^-16, 
        16.666666666666664`}, {110., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {106.4219745809556, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {102.75044883428481`, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIF5ms2Yh4+woBwYUYHngmEpPFPuGSLj46lUgYHBg
ZuHtm3LaCPE1YHGFA4xgXiSaOR/2oKtfAVHvcBTNfIi4gQO6e/79BwELCL8h
Gt2dGOJQd2KIQ92Jw5wPNujiUHcewC5ugCEOdecBXOEJAOKbWYY=
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{106.4219745809556, 25., 0.}, {110., 25., 0.}, {110., 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 
       24.148145657226706`, 6.4704761275630185`}, {106.4219745809556, 25., 
       0.}}], Line3DBox[{{106.4219745809556, 24.148145657226706`, 
       6.4704761275630185`}, {110., 24.148145657226706`, 
       6.4704761275630185`}, {110., 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461097, 
       12.499999999999998`}, {110., 21.65063509461097, 12.499999999999998`}, {
       110., 17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}, {106.4219745809556, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{106.4219745809556, 17.67766952966369, 
       17.677669529663685`}, {110., 17.67766952966369, 17.677669529663685`}, {
       110., 12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       12.500000000000004`, 21.650635094610966`}, {106.4219745809556, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{106.4219745809556, 12.500000000000004`, 
       21.650635094610966`}, {110., 12.500000000000004`, 
       21.650635094610966`}, {110., 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 6.470476127563024, 24.148145657226706`}, {
       106.4219745809556, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563024, 
       24.148145657226706`}, {110., 6.470476127563024, 24.148145657226706`}, {
       110., 7.0819236220599744`*^-15, 25.}, {106.4219745809556, 
       7.0819236220599744`*^-15, 25.}, {106.4219745809556, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, 1.5308084989341915`*^-15, 25.}, {110., 
       1.5308084989341915`*^-15, 25.}, {110., -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {106.4219745809556, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{106.4219745809556, -6.470476127563016, 
       24.148145657226706`}, {110., -6.470476127563016, 
       24.148145657226706`}, {110., -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {106.4219745809556, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{106.4219745809556, -12.499999999999995`, 
       21.65063509461097}, {110., -12.499999999999995`, 21.65063509461097}, {
       110., -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}, {
       106.4219745809556, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{106.4219745809556, -17.677669529663685`, 
       17.67766952966369}, {110., -17.677669529663685`, 17.67766952966369}, {
       110., -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -21.65063509461097, 12.499999999999998`}, {
       106.4219745809556, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {110., -21.650635094610962`, 
       12.500000000000009`}, {110., -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {106.4219745809556, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{106.4219745809556, -24.148145657226706`, 
       6.470476127563026}, {110., -24.148145657226706`, 6.470476127563026}, {
       110., -25., 3.061616997868383*^-15}, {106.4219745809556, -25., 
       3.061616997868383*^-15}, {106.4219745809556, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{106.4219745809556, -25., 3.061616997868383*^-15}, {
       110., -25., 3.061616997868383*^-15}, {
       110., -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -24.148145657226706`, -6.47047612756302}, {
       106.4219745809556, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       106.4219745809556, -24.14814565722671, -6.470476127563009}, {
       110., -24.14814565722671, -6.470476127563009}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       106.4219745809556, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       106.4219745809556, -21.65063509461097, -12.499999999999993`}, {
       110., -21.65063509461097, -12.499999999999993`}, {
       110., -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -17.677669529663692`, -17.677669529663685`}, {
       106.4219745809556, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}, {
       110., -17.677669529663696`, -17.677669529663678`}, {
       110., -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       106.4219745809556, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       106.4219745809556, -12.50000000000001, -21.65063509461096}, {
       110., -12.50000000000001, -21.65063509461096}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       106.4219745809556, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       106.4219745809556, -6.470476127563038, -24.148145657226703`}, {
       110., -6.470476127563038, -24.148145657226703`}, {
       110., -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -2.6796885989305705`*^-14, -25.}, {
       106.4219745809556, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{106.4219745809556, -4.592425496802574*^-15, -25.}, {
       110., -4.592425496802574*^-15, -25.}, {110., 
       6.470476127563007, -24.14814565722671}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}, {
       106.4219745809556, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{106.4219745809556, 6.470476127563007, -24.14814565722671}, {
       110., 6.470476127563007, -24.14814565722671}, {110., 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {106.4219745809556, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}, {110., 
       12.499999999999984`, -21.650635094610976`}, {110., 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       17.67766952966367, -17.67766952966371}, {106.4219745809556, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}, {110., 
       17.677669529663685`, -17.677669529663692`}, {110., 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}, {106.4219745809556, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{106.4219745809556, 21.65063509461096, -12.50000000000001}, {
       110., 21.65063509461096, -12.50000000000001}, {110., 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {106.4219745809556, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{106.4219745809556, 
       24.148145657226703`, -6.470476127563039}, {110., 
       24.148145657226703`, -6.470476127563039}, {110., 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       25., -2.8327694488239898`*^-14}, {106.4219745809556, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 
      6.123233995736766*^-15}, {140., -16.66666666666667, 
      5.102694996447306*^-15}, {132.7504488342848, -16.666666666666668`, 
      0.}, {136.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{132.7504488342848, -16.666666666666668`, 0.}, {
      140., -16.66666666666667, 5.102694996447306*^-15}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      130.67375799589206`, -8.333333333333336, 0.}, {
      132.7504488342848, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{130.67375799589206`, -8.333333333333336, 0.}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      140., -7.105427357601002*^-15, 3.061616997868384*^-15}, {130., 0., 
      0.}, {130.67375799589206`, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{130., 0., 0.}, {140., 0., 3.061616997868383*^-15}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {130.67375799589206`, 
      8.333333333333329, 0.}, {130., 0., 0.}}], 
     Polygon3DBox[{{130.67375799589206`, 8.333333333333329, 0.}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {140., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {132.7504488342848, 
      16.666666666666664`, 0.}, {130.67375799589206`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{132.7504488342848, 16.666666666666664`, 0.}, {
      140., 16.666666666666664`, 1.0205389992894615`*^-15}, {140., 
      24.999999999999996`, 5.098616525425841*^-31}, {136.4219745809556, 
      24.999999999999993`, 0.}, {132.7504488342848, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA6Wu3ahgTfRgQEMLA8wQEGykNta5hkJDqtXgYAB
XPzMjrc5/aEJDmvA4gpwcTBwSICa82EPuvoVEPUOMPEkqPkQcQO4OMw9//6D
gAVcHAwa4O7EEF+NZg5MfA2avajmfLBBF1+BzV9wcQMMcag74eK4whMASr9a
Hg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{130., 0., -25.}, {140., 3.061616997868383*^-15, -25.}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}, {130., 0., -25.}}], 
       Polygon3DBox[{{130., 5.102694996447305*^-16, -16.666666666666668`}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {140., 
        2.0410779985789223`*^-15, -8.333333333333336}, {130., 
        1.020538999289461*^-15, -8.333333333333336}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{130., 1.020538999289461*^-15, -8.333333333333336}, {
        140., 2.0410779985789223`*^-15, -8.333333333333336}, {140., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {130., 
        1.5308084989341915`*^-15, 0.}, {130., 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{130., 1.5308084989341915`*^-15, 0.}, {140., 
        1.5308084989341915`*^-15, 0.}, {140., 1.0205389992894611`*^-15, 
        8.333333333333332}, {130., 2.041077998578922*^-15, 
        8.333333333333329}, {130., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{130., 2.041077998578922*^-15, 8.333333333333329}, {140.,
         1.0205389992894611`*^-15, 8.333333333333332}, {140., 
        5.102694996447307*^-16, 16.666666666666664`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}, {130., 
        2.041077998578922*^-15, 8.333333333333329}}], 
       Polygon3DBox[{{130., 2.5513474982236525`*^-15, 16.666666666666664`}, {
        140., 5.102694996447308*^-16, 16.666666666666664`}, {140., 
        2.5493082627129206`*^-31, 24.999999999999996`}, {130., 
        3.0616169978683826`*^-15, 24.999999999999993`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihwSHBgQAGWB9DFV68CAQMM8TVgcQUMcQj4sAdd
fAVEvQN2cQMM8X//QcACwm9IRHcnhvhqZHOQxNcg24thzgcbdPEVyP7CEDfA
EIe68wC6+6HuPAAAPE1IaA==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{136.4219745809556, -25., 25.}, {140., -25., 25.}, {
       140., -16.666666666666668`, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}, {
       136.4219745809556, -25., 25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666668`, 25.}, {
       140., -16.666666666666668`, 25.}, {140., -8.333333333333336, 25.}, {
       130.67375799589206`, -8.333333333333336, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333334, 25.}, {
       140., -8.333333333333334, 25.}, {140., -1.3877787807814457`*^-15, 
       25.}, {130., -1.3877787807814457`*^-15, 25.}, {
       130.67375799589206`, -8.333333333333334, 25.}}], 
      Line3DBox[{{130., 0., 25.}, {140., 0., 25.}, {140., 8.333333333333332, 
       25.}, {130.67375799589206`, 8.333333333333332, 25.}, {130., 0., 25.}}],
       Line3DBox[{{130.67375799589206`, 8.333333333333332, 25.}, {140., 
       8.333333333333332, 25.}, {140., 16.666666666666664`, 25.}, {
       132.7504488342848, 16.666666666666664`, 25.}, {130.67375799589206`, 
       8.333333333333332, 25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666664`, 25.}, {140., 
       16.666666666666664`, 25.}, {140., 24.999999999999993`, 25.}, {
       136.4219745809556, 24.999999999999993`, 25.}, {132.7504488342848, 
       16.666666666666664`, 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 25.}, {140., 25., 25.}, {140., 25., 
       16.666666666666668`}, {136.4219745809556, 25., 16.666666666666668`}, {
       136.4219745809556, 25., 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 16.666666666666668`}, {140., 25., 
       16.666666666666668`}, {140., 25., 8.333333333333336}, {
       136.4219745809556, 25., 8.333333333333336}, {136.4219745809556, 25., 
       16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, 25., 8.333333333333334}, {140., 25., 
       8.333333333333334}, {140., 25., 1.3877787807814457`*^-15}, {
       136.4219745809556, 25., 1.3877787807814457`*^-15}, {136.4219745809556, 
       25., 8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, 25., 0.}, {140., 25., 0.}, {140., 
       25., -8.333333333333332}, {136.4219745809556, 
       25., -8.333333333333332}, {136.4219745809556, 25., 0.}}], 
      Line3DBox[{{136.4219745809556, 25., -8.333333333333332}, {140., 
       25., -8.333333333333332}, {140., 25., -16.666666666666664`}, {
       136.4219745809556, 25., -16.666666666666664`}, {136.4219745809556, 
       25., -8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, 25., -16.666666666666664`}, {140., 
       25., -16.666666666666664`}, {140., 25., -24.999999999999993`}, {
       136.4219745809556, 25., -24.999999999999993`}, {136.4219745809556, 
       25., -16.666666666666664`}}], 
      Line3DBox[{{136.4219745809556, 25., -25.}, {140., 25., -25.}, {140., 
       16.666666666666668`, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}, {136.4219745809556, 25., -25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666668`, -25.}, {140., 
       16.666666666666668`, -25.}, {140., 8.333333333333336, -25.}, {
       130.67375799589206`, 8.333333333333336, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333334, -25.}, {140., 
       8.333333333333334, -25.}, {140., 1.3877787807814457`*^-15, -25.}, {
       130., 1.3877787807814457`*^-15, -25.}, {130.67375799589206`, 
       8.333333333333334, -25.}}], 
      Line3DBox[{{130., 0., -25.}, {140., 0., -25.}, {
       140., -8.333333333333332, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}, {130., 0., -25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, -25.}, {
       140., -8.333333333333332, -25.}, {140., -16.666666666666664`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, -25.}, {
       140., -16.666666666666664`, -25.}, {
       140., -24.999999999999993`, -25.}, {
       136.4219745809556, -24.999999999999993`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -25.}, {140., -25., -25.}, {
       140., -25., -16.666666666666668`}, {
       136.4219745809556, -25., -16.666666666666668`}, {
       136.4219745809556, -25., -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -16.666666666666668`}, {
       140., -25., -16.666666666666668`}, {140., -25., -8.333333333333336}, {
       136.4219745809556, -25., -8.333333333333336}, {
       136.4219745809556, -25., -16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, -25., -8.333333333333334}, {
       140., -25., -8.333333333333334}, {
       140., -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 0.}, {140., -25.,
        8.333333333333332}, {136.4219745809556, -25., 8.333333333333332}, {
       136.4219745809556, -25., 0.}}], 
      Line3DBox[{{136.4219745809556, -25., 8.333333333333332}, {140., -25., 
       8.333333333333332}, {140., -25., 16.666666666666664`}, {
       136.4219745809556, -25., 16.666666666666664`}, {
       136.4219745809556, -25., 8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, -25., 16.666666666666664`}, {140., -25., 
       16.666666666666664`}, {140., -25., 24.999999999999993`}, {
       136.4219745809556, -25., 24.999999999999993`}, {
       136.4219745809556, -25., 16.666666666666664`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihwyHaAMCwPMCADoPjqVSBggCG+BiyugCEOYXzY
gy6+AqLeAbu4AYb4v/8gYIEhDnUnhvhqHOaswWEv1J02ONyJ4a8VOMIB6k4M
cag74eIApfhHRg==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihwyHZgQAGWB9DFV68CAQMM8TVgcQUMcQj4sAdd
fAVEvQN2cQMM8X//QcACQxzqTgzx1TjMWYPDXqg7bXC4E8NfK3CEA9SdGOJQ
dx4AAOfCR0Y=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], 
     Line3DBox[{{218., -25., -25.}, {218., 25., -25.}, {218., 25., 25.}, {
      218., -25., 25.}, {218., -25., -25.}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDQAmImIAaxcYEjVtHRWZcjHVS3d+SKmhsdwKMUDPZB1dfd
LkmQeat2IES6Y/klfx2c+mDmixvv3h9ULODAe93o0pp9hgTVP42XOOtSauBQ
wddfvM1CnqD651D1uRD1DoTUG6O6B6d6mH9roP4Nh/jXAW+4NUQ7SKYtc2WT
RIjjDTeg+rTbzAzux9UOZHQHikkp6hzAG25A9Sv7PknqRgg4VFv8jE1ZaHgA
b7gB1Z/xzPwoHWXg8O6v+VIDVvkDeMMNqP4cVP1jiHoHvOEGVH8U1T0OuMIN
pj4F6t9siH/h4ujhdsLOTVVpYYLDyx52vzfVaOkGS7i92/iA429qgoP2iTcP
MwTVDvzgN2dqdtDGGW629+Zo3HZJcNhzomCjzA5+B2ediZ2N0ohwRg+3+XsO
Ff3tS3DQ6Yq+6z9f36Fq/WPNrn+ycPXo4QZTrw9Vnw9RjzPc7KDu+YTqHpzh
9hbqX02of39D/OuAP9wSHf6+09on2mYAF8cfbokOScynJn6ZqHKg6cLab+eY
tAmEW6IDF8eXyWoRvA6p644r5nwwIBBuiQ4ezxNL/h3UdXC71d2hcUT2AP5w
S3Twhqq3hqgnEG6JDnao7sEZbjD18VD/tkD8CxdHDzcwcMh2YChZu4xDYao9
ejijhxtcvUZ6NWvY0f0yXw806BxUxxluMPUNitfWR/7ebm+iba4fclkXZ7jB
zTf4fiNCaIO9o4rGiSAVKbh69HCDq9eHqDeDqMcZbjjcgz/ckPwrB/EvQhxb
uDnkO0w4vcW2wlraASOcsYUbUH1D7IHdyg/4HWxWBNVpZ6vhDzeQ+ovqX9Z/
+7p/wuSmjHWaOvjDDag+4tErJwYBiQMTbl4PXLNcAqEeW7gB1SdA1XdA1OMP
N6D6A1D3TIG4h0C4IfzrAPGvAwD935NT
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAmJmID5iFR2ddTnSQXV7R66oudEBBijYBxWvu12SIPNW
7UCIdMfyS/46B2DqxY137w8qFnDgvW50ac0+Q7j403iJsy6lBg4VfP3F2yzk
4eLPoeK5EHEHmLgxqjkOMHtroPaGQ+x1ADuqIdpBMm2ZK5skwp0w8bTbzAzu
x9UOZHQHikkp6hyAia/s+ySpGyHgUG3xMzZloSFc/Ixn5kfpKAOHd3/Nlxqw
ysPFz0HFH0PE4fYeRTUHLp4CtTcbYq/DCTs3VaWFCQ4ve9j93lQbwt35buMD
jr+pCQ7aJ948zBBUO/CD35yp2UH7gO29ORq3XRIc9pwo2Cizg9/BWWdiZ6O0
4YH5ew4V/e1LcNDpir7rP1/foWr9Y82uf7JwcX2oeD5E3MEOas4nVHMc3kLt
1YTa+xtiL9T9iQ5/32ntE20zQAvPRIck5lMTv0xUOdB0Ye23c0zaB2DiXBxf
JqtF8DqkrjuumPPBAC7u8Tyx5N9BXQe3W90dGkdk4eLeUHFriDjcXjtUc+Di
8VB7WyD2QsQdsh0YStYu41CYao/iTpC4Rno1a9jR/TJfDzToHFQ/ABNvULy2
PvL3dnsTbXP9kMu6cHEGg+83IoQ22DuqaJwIUpFCiOtDxM0g4g44zHFAt1cO
Yi9UPN9hwuktthXW0g6o7sx3aIg9sFv5Ab+DzYqgOu1stQNw8YvqX9Z/+7p/
wuSmjHWaOnDxiEevnBgEJA5MuHk9cM1yCbh4AlS8AyIOt/cA1JwpEHMc0O11
gNjrAACGn2dj
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367532193466*^9, 3.5660869880339108`*^9, 
  3.566101744884391*^9, 3.5661391877175293`*^9, 3.614707795658176*^9},
 CellTags->{
  "Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", 
   "RG10."},
 CellLabel->
  "During evaluation of \
In[39]:=",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642"]
}, Open  ]],

Cell[TextData[{
 "By using ",
 StyleBox["PlotType->Surface", "Input",
  FontFamily->"Courier"],
 " with ",
 StyleBox["RayChoice->{ComponentNumber->3}", "Input",
  FontFamily->"Courier"],
 ", you can clearly see ray intersection points at the screen surface."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "Screen", "focal plane of system", "Using Screen", 
   "RG10."},ExpressionUUID->"045101ea-2a75-4098-a7f0-05d2a696de23"],

Cell[CellGroupData[{

Cell["\<\
ShowSystem[screensystem, PlotType->Surface, RayChoice->{ComponentNumber->3}];\
\
\>", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."},
 CellLabel->"In[40]:=",ExpressionUUID->"da50deaa-c72e-495c-92e8-001633150ed5"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], PointBox[{0.020630011723699937`, 0}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-0.16668766522917622`, -11.877292655519845`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.09367905180818603, -14.912751651272266`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.06277995392810176, -6.53547203774457}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.06277995392809821, 6.53547203774456}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{0.09367905180818559, 14.912751651272266`}]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsolutePointSize[2.], 
     PointBox[{-0.16668766522917622`, 11.877292655519849`}], 
     {RGBColor[0, 0, 0], Thickness[
       NCache[
        Rational[1, 5000], 0.0002]], 
      LineBox[{{-25., -25.}, {25., -25.}, {25., 25.}, {-25., 
       25.}, {-25., -25.}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}, {}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367532391665*^9, 3.566086988294866*^9, 
  3.56610174512291*^9, 3.566139188024479*^9, 3.614707795791597*^9},
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."},
 CellLabel->
  "During evaluation of \
In[40]:=",ExpressionUUID->"a8b69489-f5d3-4bd3-9d7e-48f0bdb29221"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"ac6416fe-20af-42a9-\
a43d-d1e28b756094"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "11. The ",
 StyleBox["ShowRange ",
  FontFamily->"Courier New"],
 "Option"
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ShowRange", "11.", "RG10.", 
   "RG11."},ExpressionUUID->"c348ff48-a54b-4c54-9da9-e9c1ed3d78d5"],

Cell[TextData[{
 "Another useful option is ",
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 ". You can use ",
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 " to zoom in on a particular portion of the system."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowRange", "RG10.", 
   "RG11."},ExpressionUUID->"52816333-8b27-4409-b845-2b916f72b70f"],

Cell[TextData[{
 StyleBox["ShowRange -> ", "Input",
  FontFamily->"Courier"],
 StyleBox["values",
  FontSlant->"Italic"],
 " uses ",
 StyleBox["ComponentNumber", "Input",
  FontFamily->"Courier"],
 " values to select the components and ray segments displayed."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ShowRange", "RG10.", 
   "RG11."},ExpressionUUID->"83ed5ffd-df16-4b3f-8c0a-adc45f84e000"],

Cell[TextData[{
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 " can take either the value ",
 StyleBox["All", "Input",
  FontFamily->"Courier"],
 " or a list of the ",
 StyleBox["ComponentNumber", "Input",
  FontFamily->"Courier"],
 " values. Here we examine the ray segments connected with the cylindrical \
lens."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowRange", "RG10.", 
   "RG11."},ExpressionUUID->"5b155320-e592-41f5-b201-2e505ba64340"],

Cell[CellGroupData[{

Cell["ShowSystem[screensystem, ShowRange -> {2}];", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ShowRange", "RG10.", "RG11."},
 CellLabel->"In[41]:=",ExpressionUUID->"2a1441a5-322d-4c6b-ae11-20370f92fa09"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 
      6.123233995736766*^-15}, {140., -16.66666666666667, 
      5.102694996447306*^-15}, {132.7504488342848, -16.666666666666668`, 
      0.}, {136.4219745809556, -25., 0.}}], 
     Polygon3DBox[{{132.7504488342848, -16.666666666666668`, 0.}, {
      140., -16.66666666666667, 5.102694996447306*^-15}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      130.67375799589206`, -8.333333333333336, 0.}, {
      132.7504488342848, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{130.67375799589206`, -8.333333333333336, 0.}, {
      140., -8.333333333333336, 4.0821559971578446`*^-15}, {
      140., -7.105427357601002*^-15, 3.061616997868384*^-15}, {130., 0., 
      0.}, {130.67375799589206`, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{130., 0., 0.}, {140., 0., 3.061616997868383*^-15}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {130.67375799589206`, 
      8.333333333333329, 0.}, {130., 0., 0.}}], 
     Polygon3DBox[{{130.67375799589206`, 8.333333333333329, 0.}, {140., 
      8.333333333333332, 2.0410779985789223`*^-15}, {140., 
      16.666666666666664`, 1.0205389992894613`*^-15}, {132.7504488342848, 
      16.666666666666664`, 0.}, {130.67375799589206`, 8.333333333333329, 
      0.}}], Polygon3DBox[{{132.7504488342848, 16.666666666666664`, 0.}, {
      140., 16.666666666666664`, 1.0205389992894615`*^-15}, {140., 
      24.999999999999996`, 5.098616525425841*^-31}, {136.4219745809556, 
      24.999999999999993`, 0.}, {132.7504488342848, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIA6Wu3ahgTfRgQEMLA8wQEGykNta5hkJDqtXgYAB
XPzMjrc5/aEJDmvA4gpwcTBwSICa82EPuvoVEPUOMPEkqPkQcQO4OMw9//6D
gAVcHAwa4O7EEF+NZg5MfA2avajmfLBBF1+BzV9wcQMMcag74eK4whMASr9a
Hg==
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{130., 0., -25.}, {140., 3.061616997868383*^-15, -25.}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}, {130., 0., -25.}}], 
       Polygon3DBox[{{130., 5.102694996447305*^-16, -16.666666666666668`}, {
        140., 2.551347498223653*^-15, -16.66666666666667}, {140., 
        2.0410779985789223`*^-15, -8.333333333333336}, {130., 
        1.020538999289461*^-15, -8.333333333333336}, {130., 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{130., 1.020538999289461*^-15, -8.333333333333336}, {
        140., 2.0410779985789223`*^-15, -8.333333333333336}, {140., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {130., 
        1.5308084989341915`*^-15, 0.}, {130., 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{130., 1.5308084989341915`*^-15, 0.}, {140., 
        1.5308084989341915`*^-15, 0.}, {140., 1.0205389992894611`*^-15, 
        8.333333333333332}, {130., 2.041077998578922*^-15, 
        8.333333333333329}, {130., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{130., 2.041077998578922*^-15, 8.333333333333329}, {140.,
         1.0205389992894611`*^-15, 8.333333333333332}, {140., 
        5.102694996447307*^-16, 16.666666666666664`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}, {130., 
        2.041077998578922*^-15, 8.333333333333329}}], 
       Polygon3DBox[{{130., 2.5513474982236525`*^-15, 16.666666666666664`}, {
        140., 5.102694996447308*^-16, 16.666666666666664`}, {140., 
        2.5493082627129206`*^-31, 24.999999999999996`}, {130., 
        3.0616169978683826`*^-15, 24.999999999999993`}, {130., 
        2.5513474982236525`*^-15, 16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihwSHBgQAGWB9DFV68CAQMM8TVgcQUMcQj4sAdd
fAVEvQN2cQMM8X//QcACwm9IRHcnhvhqZHOQxNcg24thzgcbdPEVyP7CEDfA
EIe68wC6+6HuPAAAPE1IaA==
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{136.4219745809556, -25., 25.}, {140., -25., 25.}, {
       140., -16.666666666666668`, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}, {
       136.4219745809556, -25., 25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666668`, 25.}, {
       140., -16.666666666666668`, 25.}, {140., -8.333333333333336, 25.}, {
       130.67375799589206`, -8.333333333333336, 25.}, {
       132.7504488342848, -16.666666666666668`, 25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333334, 25.}, {
       140., -8.333333333333334, 25.}, {140., -1.3877787807814457`*^-15, 
       25.}, {130., -1.3877787807814457`*^-15, 25.}, {
       130.67375799589206`, -8.333333333333334, 25.}}], 
      Line3DBox[{{130., 0., 25.}, {140., 0., 25.}, {140., 8.333333333333332, 
       25.}, {130.67375799589206`, 8.333333333333332, 25.}, {130., 0., 25.}}],
       Line3DBox[{{130.67375799589206`, 8.333333333333332, 25.}, {140., 
       8.333333333333332, 25.}, {140., 16.666666666666664`, 25.}, {
       132.7504488342848, 16.666666666666664`, 25.}, {130.67375799589206`, 
       8.333333333333332, 25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666664`, 25.}, {140., 
       16.666666666666664`, 25.}, {140., 24.999999999999993`, 25.}, {
       136.4219745809556, 24.999999999999993`, 25.}, {132.7504488342848, 
       16.666666666666664`, 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 25.}, {140., 25., 25.}, {140., 25., 
       16.666666666666668`}, {136.4219745809556, 25., 16.666666666666668`}, {
       136.4219745809556, 25., 25.}}], 
      Line3DBox[{{136.4219745809556, 25., 16.666666666666668`}, {140., 25., 
       16.666666666666668`}, {140., 25., 8.333333333333336}, {
       136.4219745809556, 25., 8.333333333333336}, {136.4219745809556, 25., 
       16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, 25., 8.333333333333334}, {140., 25., 
       8.333333333333334}, {140., 25., 1.3877787807814457`*^-15}, {
       136.4219745809556, 25., 1.3877787807814457`*^-15}, {136.4219745809556, 
       25., 8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, 25., 0.}, {140., 25., 0.}, {140., 
       25., -8.333333333333332}, {136.4219745809556, 
       25., -8.333333333333332}, {136.4219745809556, 25., 0.}}], 
      Line3DBox[{{136.4219745809556, 25., -8.333333333333332}, {140., 
       25., -8.333333333333332}, {140., 25., -16.666666666666664`}, {
       136.4219745809556, 25., -16.666666666666664`}, {136.4219745809556, 
       25., -8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, 25., -16.666666666666664`}, {140., 
       25., -16.666666666666664`}, {140., 25., -24.999999999999993`}, {
       136.4219745809556, 25., -24.999999999999993`}, {136.4219745809556, 
       25., -16.666666666666664`}}], 
      Line3DBox[{{136.4219745809556, 25., -25.}, {140., 25., -25.}, {140., 
       16.666666666666668`, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}, {136.4219745809556, 25., -25.}}], 
      Line3DBox[{{132.7504488342848, 16.666666666666668`, -25.}, {140., 
       16.666666666666668`, -25.}, {140., 8.333333333333336, -25.}, {
       130.67375799589206`, 8.333333333333336, -25.}, {132.7504488342848, 
       16.666666666666668`, -25.}}], 
      Line3DBox[{{130.67375799589206`, 8.333333333333334, -25.}, {140., 
       8.333333333333334, -25.}, {140., 1.3877787807814457`*^-15, -25.}, {
       130., 1.3877787807814457`*^-15, -25.}, {130.67375799589206`, 
       8.333333333333334, -25.}}], 
      Line3DBox[{{130., 0., -25.}, {140., 0., -25.}, {
       140., -8.333333333333332, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}, {130., 0., -25.}}], 
      Line3DBox[{{130.67375799589206`, -8.333333333333332, -25.}, {
       140., -8.333333333333332, -25.}, {140., -16.666666666666664`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}, {
       130.67375799589206`, -8.333333333333332, -25.}}], 
      Line3DBox[{{132.7504488342848, -16.666666666666664`, -25.}, {
       140., -16.666666666666664`, -25.}, {
       140., -24.999999999999993`, -25.}, {
       136.4219745809556, -24.999999999999993`, -25.}, {
       132.7504488342848, -16.666666666666664`, -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -25.}, {140., -25., -25.}, {
       140., -25., -16.666666666666668`}, {
       136.4219745809556, -25., -16.666666666666668`}, {
       136.4219745809556, -25., -25.}}], 
      Line3DBox[{{136.4219745809556, -25., -16.666666666666668`}, {
       140., -25., -16.666666666666668`}, {140., -25., -8.333333333333336}, {
       136.4219745809556, -25., -8.333333333333336}, {
       136.4219745809556, -25., -16.666666666666668`}}], 
      Line3DBox[{{136.4219745809556, -25., -8.333333333333334}, {
       140., -25., -8.333333333333334}, {
       140., -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -1.3877787807814457`*^-15}, {
       136.4219745809556, -25., -8.333333333333334}}], 
      Line3DBox[{{136.4219745809556, -25., 0.}, {140., -25., 0.}, {140., -25.,
        8.333333333333332}, {136.4219745809556, -25., 8.333333333333332}, {
       136.4219745809556, -25., 0.}}], 
      Line3DBox[{{136.4219745809556, -25., 8.333333333333332}, {140., -25., 
       8.333333333333332}, {140., -25., 16.666666666666664`}, {
       136.4219745809556, -25., 16.666666666666664`}, {
       136.4219745809556, -25., 8.333333333333332}}], 
      Line3DBox[{{136.4219745809556, -25., 16.666666666666664`}, {140., -25., 
       16.666666666666664`}, {140., -25., 24.999999999999993`}, {
       136.4219745809556, -25., 24.999999999999993`}, {
       136.4219745809556, -25., 16.666666666666664`}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImIAaxwaAh2kEybZkrm6TRAZjQCTs3VaWFCQ4ve9j9
3lQbwsVh6tNuMzO4H1c7kNEdKCalqHPg3cYHHH9TExy0T7x5mCGoduAHvzlT
s4P2AZj6lX2fJHUjBByqLX7Gpiw0PGB7b47GbZcEhz0nCjbK7OB3cNaZ2Nko
bQhXf8Yz86N0lIHDu7/mSw1Y5Q/M33Oo6G9fgoNOV/Rd//n6DlXrH2t2/ZOF
qz8HVf8Yot4Bpl4fqj4fot4Bpv4oqnsc7KDu+YTqHrj6FKh/syH+dXgL9a8m
1L+/If51wB9uiQ5/32ntE20zgIvjD7dEhyTmUxO/TFQ50HRh7bdzTNoEwi3R
gYvjy2S1CF6H1HXHFXM+GBAIt0QHj+eJJf8O6jq43eru0DgiewB/uCU6eEPV
W0PUEwi3RAc7VPfgDDeY+niof1sg/nUAAHxUAvU=
      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmID5h56aqtDDB4WUPu9+basMDDFDwbuMDjr+pCQ7a
J948zBBUO/CD35yp2UH7gO29ORq3XRIc9pwo2Cizg9/BWWdiZ6O04YH5ew4V
/e1LcNDpir7rP1/foWr9Y82uf7JwcX2oeD5E3MEOas4nVHMc3kLt1YTa+xti
rwPYUQ2JDn/fae0TbTOAuxMmnsR8auKXiSoHmi6s/XaOSfsATJyL48tktQhe
h9R1xxVzPhjAxT2eJ5b8O6jr4Haru0PjiCxc3Bsqbg0Rh9trh2oOXDweam8L
xF4HALTyhxQ=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367532504776*^9, 3.566086988368058*^9, 
  3.566101745241798*^9, 3.566139188135947*^9, 3.6147077958673267`*^9},
 CellTags->{"ShowRange", "RG10.", "RG11."},
 CellLabel->
  "During evaluation of \
In[41]:=",ExpressionUUID->"877e34fe-4ce3-4102-a844-c6adfe1e2227"]
}, Open  ]],

Cell[TextData[{
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 " works differently from ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 " because ",
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 " displays selected components associated with the selected ray segments. In \
addition, ",
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 " only works with ",
 StyleBox["ComponentNumber", "Input",
  FontFamily->"Courier"],
 " values whereas ",
 StyleBox["RayChoice", "Input",
  FontFamily->"Courier"],
 " works with many different selection parameters. See ",
 ButtonBox["Section 6.4",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"6.4"],
 " in the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide for more discussion about ",
 StyleBox["ShowRange", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ShowRange", "RG10.", 
   "RG11."},ExpressionUUID->"0a819798-1313-47bc-b289-5b2becae311b"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"d4d6509b-1bb1-476c-\
99c4-a60ac1b3776c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "12. The ",
 StyleBox["ReadRays",
  FontFamily->"Courier New"],
 " Function"
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ReadRays", "12.", 
   "RG12."},ExpressionUUID->"bd0bb247-7bc3-4815-8b2b-9ad91600848b"],

Cell[TextData[{
 "It is often desirable to get specific numeric values for a selected set of \
parameters from the ray trace. This can be accomplished with ",
 StyleBox["ReadRays", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ReadRays", "RG12."},ExpressionUUID->"13dfbd3e-a75a-4c9a-bca5-1ac9141cc3d0"],

Cell[TextData[{
 StyleBox["ReadRays[", "Input",
  FontFamily->"Courier"],
 StyleBox["results",
  FontSlant->"Italic"],
 ", ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 ", ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " takes ray-traced ",
 StyleBox["results",
  FontSlant->"Italic"],
 " from ",
 StyleBox["AnalyzeSystem", "Input"],
 "/",
 StyleBox["PropagateSystem", "Input"],
 " and returns a list of values for ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 " and ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 " given."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ReadRays", "RG12."},ExpressionUUID->"ea5251f0-0c41-4a77-8e3b-bde02cad7014"],

Cell[TextData[{
 "Here we use ",
 StyleBox["ReadRays", "Input",
  FontFamily->"Courier"],
 " to examine the optical path-length of rays at the focal plane. Using the \
optical path-length parameter ",
 StyleBox["OpticalLength", "Input",
  FontFamily->"Courier"],
 ", you can use the ",
 StyleBox["ComponentNumber -> 3", "Input",
  FontFamily->"Courier"],
 " as a selection property to examine the optical path-length from the ray \
starting point to the surface of the screen component."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ReadRays", "RG12."},ExpressionUUID->"1050e920-03fb-4f3e-ae26-7e4e6e181dc9"],

Cell[CellGroupData[{

Cell["\<\
ReadRays[screensystem, OpticalLength, {ComponentNumber -> 3}]\
\>", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ReadRays", "RG12."},
 CellLabel->"In[42]:=",ExpressionUUID->"fe649223-7d68-4e85-b6f0-1d4135c645e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "228.591359124603`", ",", "228.43455070396408`", ",", "228.3688128926051`", 
   ",", "228.53755280486942`", ",", "228.53755280486942`", ",", 
   "228.36881289260504`", ",", "228.43455070396408`"}], "}"}]], "Output",
 CellChangeTimes->{3.563367532562498*^9, 3.566086988404028*^9, 
  3.566101745272376*^9, 3.566139188172488*^9, 3.61470779588776*^9},
 CellTags->{"ReadRays", "RG12."},
 CellLabel->"Out[42]=",ExpressionUUID->"2d332d18-8f36-4def-bdfb-fe46a3ca4054"]
}, Open  ]],

Cell[TextData[{
 "To see more decimal places, you can use ",
 StyleBox["InputForm", "Input",
  FontFamily->"Courier"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ReadRays", "InputForm", 
   "RG12."},ExpressionUUID->"47dff9d5-d9f6-4181-abad-0242b6d5c9ef"],

Cell[CellGroupData[{

Cell["InputForm[%]", "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ReadRays", "InputForm", "RG12."},
 CellLabel->"In[43]:=",ExpressionUUID->"a4c1ace1-3fbb-4027-9df6-3ef68a956e73"],

Cell["\<\
{228.591359124603, 228.43455070396408, 228.3688128926051, 228.53755280486942, \
228.53755280486942, 228.36881289260504, 228.43455070396408}\
\>", "Output",
 PageWidth->PaperWidth,
 Evaluatable->False,
 PageBreakWithin->Automatic,
 CellChangeTimes->{3.5633675326261053`*^9, 3.566086988447297*^9, 
  3.566101745319626*^9, 3.5661391882178926`*^9, 3.61470779591994*^9},
 LineSpacing->{1, 0},
 AspectRatioFixed->True,
 CellTags->{"ReadRays", "InputForm", "RG12."},
 CellLabel->
  "Out[43]//InputForm=",ExpressionUUID->"79a1d2f7-7f12-4630-9a60-\
449f5dd8dd21"]
}, Open  ]],

Cell[TextData[{
 "Note that, addition to working with ",
 StyleBox["AnalyzeSystem", "Input"],
 "/",
 StyleBox["PropagateSystem", "Input"],
 " , ",
 StyleBox["ReadRays", "Input"],
 " can also employed with results from ",
 StyleBox["TurboPlot", "Input"],
 "./",
 StyleBox["TurboTrace", "Input"],
 ". In such instances, however, ",
 StyleBox["ReadRays", "Input"],
 " makes an internal call to ",
 StyleBox["ReadTurboRays", "Input"],
 " for its results. ",
 StyleBox["ReadTurboRays", "Input"],
 " is discussed further in ",
 ButtonBox["Section 16",
  BaseStyle->"Hyperlink",
  ButtonData:>"16."],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ReadRays", "RG12."},ExpressionUUID->"d3a991ea-bb9d-471a-8006-f40e33774c4f"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"3b5c3ef3-45c4-4b44-\
8a67-3d791441bfcb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "13. The ",
 StyleBox["PropagateSystem",
  FontFamily->"Courier New"],
 " Function"
}], "Section",
 CellTags->{
  "PropagateSystem", "13.", 
   "RG13."},ExpressionUUID->"f16b8b76-3abc-432f-8b79-58f74680382d"],

Cell[TextData[{
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " is called internally by ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " to perform its ray-trace calculations. Here we define ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 StyleBox[".",
  FontFamily->"Times New Roman"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "PropagateSystem", 
   "RG13."},ExpressionUUID->"689a409b-f5af-413a-907b-9b9cec7d70ae"],

Cell[TextData[{
 StyleBox["PropagateSystem[", "Input",
  FontFamily->"Courier"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontFamily->"Courier"],
 " takes ",
 StyleBox["objectset",
  FontSlant->"Italic"],
 " made up of a mixed list of ",
 StyleBox["Source", "Input",
  FontFamily->"Courier"],
 ", ",
 StyleBox["Component", "Input",
  FontFamily->"Courier"],
 ", and ",
 StyleBox["OpticalSystem", "Input",
  FontFamily->"Courier"],
 " objects, traces the rays through the components, and returns the \
ray-tracing result as an ",
 StyleBox["OpticalSystem", "Input",
  FontFamily->"Courier"],
 " object carrying the final ray-trace information."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "PropagateSystem", 
   "RG13."},ExpressionUUID->"437f1c99-1fe9-4e37-aac6-8df84c32b157"],

Cell[TextData[{
 "Since ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " performs ray tracing without rendering the results, you can use ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " when you are interested only in quantitative results without the pictures. \
Here we use ",
 StyleBox["PropagateSystem", "Input"],
 " together with ",
 StyleBox["ReadRays", "Input"],
 " on the optical system shown previously."
}], "Text",
 CellTags->{
  "PropagateSystem", 
   "RG13."},ExpressionUUID->"e7af37bd-e79a-4c38-9b7d-354f4c5af775"],

Cell[CellGroupData[{

Cell[TextData[{
 "screensystem = ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 "[{\n\tConeOfRays[20, NumberOfRays -> 7],\n\tMove[PlanoConvexLens[100, 50, \
10], 100],\n\tMove[PlanoConvexCylindricalLens[100, {50,50}, 10], 130],\n\t\
Move[Screen[{50,50}], 218],\n\tBoundary[{-100,-100,-100}, {250,200,200}]}];",
 "\n",
 "ReadRays[screensystem, OpticalLength, {ComponentNumber -> 3}]"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."},
 CellLabel->"In[44]:=",ExpressionUUID->"7e6e0e5e-ff02-4193-8367-bfdbf2f121c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "228.591359124603`", ",", "228.43455070396408`", ",", "228.3688128926051`", 
   ",", "228.53755280486942`", ",", "228.53755280486942`", ",", 
   "228.36881289260504`", ",", "228.43455070396408`"}], "}"}]], "Output",
 CellChangeTimes->{3.563367533209168*^9, 3.566086988980445*^9, 
  3.5661017463072243`*^9, 3.566139189197938*^9, 3.614707796630507*^9},
 CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."},
 CellLabel->"Out[45]=",ExpressionUUID->"5ef2f2a4-82c6-4e09-ba33-6b110c9e82af"]
}, Open  ]],

Cell[TextData[{
 "Because ",
 StyleBox["AnalyzeSystem", "Input",
  FontFamily->"Courier"],
 " performs both the ray tracing and rendering, ",
 StyleBox["PropagateSystem", "Input",
  FontFamily->"Courier"],
 " is seldom used by the examples in this guide. Nevertheless, you can use ",
 StyleBox["PropagateSystem", "Input"],
 " in precisely the same fashion as ",
 StyleBox["AnalyzeSystem", "Input"],
 " for strictly numerical studies. Next, we will learn about ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " as high-speed alternatives to ",
 StyleBox["PropagateSystem", "Input"],
 " and ",
 StyleBox["AnalyzeSystem", "Input"],
 " when large numbers of rays or trace iterations are required."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "PropagateSystem", 
   "RG13."},ExpressionUUID->"7deed9e8-abe9-4501-81eb-e91376c45f45"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"04de5925-9e8f-4b1c-\
95d9-ed36b11f1035"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "14. Using ",
 StyleBox["TurboPlot",
  FontFamily->"Courier"],
 " for High-Speed Ray Tracing and Rendering"
}], "Section",
 CellTags->{
  "TurboPlot", "14.", "14. Introduction", "RG14.", 
   "RG14.0"},ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4"],

Cell[TextData[{
 "In Version 1, ",
 StyleBox["AnalyzeSystem", "Input"],
 "/",
 StyleBox["PropagateSystem", "Input"],
 " were the only functions available for ray-tracing. Now, however, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " offers an entirely new suite of functions for high-speed ray tracing of \
large ray data-sets. At the heart of this new capability is ",
 StyleBox["TurboTrace", "Input"],
 ". On most occasions, as with ",
 StyleBox["PropagateSystem", "Input"],
 ", ",
 StyleBox["TurboTrace", "Input"],
 " is not called directly by the user. Instead, either ",
 StyleBox["TurboPlot", "Input"],
 ", ",
 StyleBox["OptimizeSystem", "Input"],
 ", or ",
 StyleBox["FindIntensity", "Input"],
 " is employed. In this section, we will examine ",
 StyleBox["TurboPlot", "Input"],
 ". Then, in Sections16 and 17, ",
 StyleBox["OptimizeSystem", "Input"],
 " and ",
 StyleBox["FindIntensity", "Input"],
 " will be discussed."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", 
   "RG14.0"},ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90"],

Cell[TextData[{
 StyleBox["TurboTrace[", "Input"],
 StyleBox["optics",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " produces an accelerated ray trace of a system of light sources and optical \
elements.\n",
 StyleBox["\nTurboPlot[", "Input"],
 StyleBox["optics",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " works with ",
 StyleBox["TurboTrace", "Input"],
 " to perform accelerated ray-tracing and rendering of a system of light \
sources and optical elements."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "TurboPlot", "TurboTrace", "14. Introduction", "RG14.", 
   "RG14.0"},ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86"],

Cell[TextData[{
 "On the outside, ",
 StyleBox["TurboPlot", "Input"],
 " behaves in much the same fashion as ",
 StyleBox["AnalyzeSystem", "Input"],
 ". In particular, ",
 StyleBox["TurboPlot", "Input"],
 " also accepts a list of light source and optical component functions for \
its input, traces the rays through the components, and renders the results. \
",
 StyleBox["TurboPlot", "Input"],
 " also uses many of the same options as ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["ShowSystem", "Input"],
 " for rendering its information. Internally, however, ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " are designed with one objective in mind: namely, speed. For its ray-trace \
calculations, ",
 StyleBox["TurboPlot", "Input"],
 " depends on ",
 StyleBox["TurboTrace", "Input"],
 " just as ",
 StyleBox["AnalyzeSystem", "Input"],
 " uses ",
 StyleBox["PropagateSystem", "Input"],
 ". When it is called with a new optical system, ",
 StyleBox["TurboTrace", "Input"],
 " first constructs a compiled function, called a ",
 StyleBox["RayTraceFunction", "Input"],
 ", that performs the ray-trace calculation and is returned as a part of the \
ray-trace result. Initially, this construction process can consume a \
significant  amount of time and, for this reason, ",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 " can sometimes be slower than ",
 StyleBox["AnalyzeSystem", "Input"],
 "/",
 StyleBox["PropagateSystem", "Input"],
 " when only a small number of rays are traced. However, if a larger number \
of rays are needed or if many trace iterations are required, then ",
 StyleBox["TurboTrace", "Input"],
 "-based calculations are always the best way to go. As an example, consider \
the following optical system."
}], "Text",
 CellTags->{
  "TurboPlot", "14. Introduction", "RG14.", 
   "RG14.0"},ExpressionUUID->"29a70b22-afb3-4a67-9ca0-396573e8c165"],

Cell["\<\
system = {GaussianBeam[10, .1, NumberOfRays->11, FullForm->True],
\tMove[PlanoConvexLens[100,50,10],50],
\tMove[Screen[50],150]};\
\>", "Input",
 CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"},
 CellLabel->"In[46]:=",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc"],

Cell[TextData[{
 "This example uses the ",
 StyleBox["GaussianBeam", "Input"],
 " light source function. ",
 StyleBox["GaussianBeam", "Input"],
 " simulates the intensity and optical phase characteristics of a Gaussian \
laser beam (see ",
 ButtonBox["Section 2",
  BaseStyle->"Hyperlink",
  ButtonData:>"2."],
 "). In our system, the spot size and beam divergence were given by 10 and \
.1, respectively. Here, we used the ",
 StyleBox["FullForm -> True", "Input"],
 " option to specify a three-dimensional pattern of rays. (Otherwise, with \
the default setting of ",
 StyleBox["FullForm -> False", "Input"],
 ", ",
 StyleBox["GaussianBeam", "Input"],
 " only creates a fan of rays within a light-sheet.) Since we specified ",
 StyleBox["NumberOfRays -> 11", "Input"],
 " with ",
 StyleBox["FullForm -> True", "Input"],
 " in the ",
 StyleBox["GaussianBeam", "Input"],
 ", there will be in fact ",
 Cell[BoxData[
  SuperscriptBox["11", "2"]],ExpressionUUID->
  "29f5cf58-b09d-49e1-bbec-acac6b2cea97"],
 " = 121 rays created. This is because, for three-dimensional sources, ",
 StyleBox["NumberOfRays", "Input"],
 " refers to the number of rays along each dimension of the ray \
cross-section. If  ",
 StyleBox["FullForm -> False", "Input"],
 " were used instead to construct a two-dimensional fan of rays, then only 11 \
rays would have been initiated in total."
}], "Text",
 CellTags->{
  "TurboPlot", "14. Introduction", "RG14.", 
   "RG14.0"},ExpressionUUID->"0aa5efea-2314-4787-add1-c1cbe3b2041d"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "TurboPlot", 
   "RG14."},ExpressionUUID->"0b78c116-1673-43d7-b13b-269d0483e4c4"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["AnalyzeSystem", "Input"],
 " versus ",
 StyleBox["TurboPlot", "Input"]
}], "Subsection",
 CellTags->{
  "AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee"],

Cell[TextData[{
 "Let us first trace this system with ",
 StyleBox["AnalyzeSystem", "Input"],
 ", to get a timing baseline, and then follow this up with the use of ",
 StyleBox["TurboPlot", "Input"],
 " on the same system. We can use the ",
 StyleBox["Timing", "Input"],
 " function to measure the length of time for an activity to occur in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"5d45d815-e34a-4638-b9aa-6a2cae8bcc92"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Timing[AnalyzeSystem[system]]", "Input"]], "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[47]:=",ExpressionUUID->"735af2c0-1890-47d1-927f-6c25ec9a3696"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{56.42197458095559, -25., 0.}, {60., -25., 
      6.123233995736766*^-15}, {60., -16.66666666666667, 
      5.102694996447306*^-15}, {52.75044883428479, -16.666666666666668`, 
      0.}, {56.42197458095559, -25., 0.}}], 
     Polygon3DBox[{{52.75044883428479, -16.666666666666668`, 0.}, {
      60., -16.66666666666667, 5.102694996447306*^-15}, {
      60., -8.333333333333336, 4.0821559971578446`*^-15}, {
      50.67375799589206, -8.333333333333336, 0.}, {
      52.75044883428479, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{50.67375799589206, -8.333333333333336, 0.}, {
      60., -8.333333333333336, 4.0821559971578446`*^-15}, {
      60., -7.105427357601002*^-15, 3.061616997868384*^-15}, {50., 0., 0.}, {
      50.67375799589206, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{50., 0., 0.}, {60., 0., 3.061616997868383*^-15}, {60., 
      8.333333333333332, 2.0410779985789223`*^-15}, {50.67375799589206, 
      8.333333333333329, 0.}, {50., 0., 0.}}], 
     Polygon3DBox[{{50.67375799589206, 8.333333333333329, 0.}, {60., 
      8.333333333333332, 2.0410779985789223`*^-15}, {60., 16.666666666666664`,
       1.0205389992894613`*^-15}, {52.75044883428479, 16.666666666666664`, 
      0.}, {50.67375799589206, 8.333333333333329, 0.}}], 
     Polygon3DBox[{{52.75044883428479, 16.666666666666664`, 0.}, {60., 
      16.666666666666664`, 1.0205389992894615`*^-15}, {60., 
      24.999999999999996`, 5.098616525425841*^-31}, {56.42197458095559, 
      24.999999999999993`, 0.}, {52.75044883428479, 16.666666666666664`, 
      0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYAADywMMUNDpKbGVL8HLYfUqEDCA
ixs83rbZNszTYQ1YXAEuDgGeUHM+7EFXvwKi3gEm3gE1HyJuABeHuefffxCw
gItDgB/MnRjiq9HMgYmvQbMX1ZwPNujiK7D6CyZugCEOdSdcHFd4AgCmzVCy

       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{56.42197458095559, 0., -25.}, {60., 
        3.061616997868383*^-15, -25.}, {60., 
        2.551347498223653*^-15, -16.66666666666667}, {52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}, {56.42197458095559, 
        0., -25.}}], 
       Polygon3DBox[{{52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}, {60., 
        2.551347498223653*^-15, -16.66666666666667}, {60., 
        2.0410779985789223`*^-15, -8.333333333333336}, {50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}, {52.75044883428479, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}, {60., 
        2.0410779985789223`*^-15, -8.333333333333336}, {60., 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {50., 
        1.5308084989341915`*^-15, 0.}, {50.67375799589206, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{50., 1.5308084989341915`*^-15, 0.}, {60., 
        1.5308084989341915`*^-15, 0.}, {60., 1.0205389992894611`*^-15, 
        8.333333333333332}, {50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}, {50., 1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}, {60., 1.0205389992894611`*^-15, 
        8.333333333333332}, {60., 5.102694996447307*^-16, 
        16.666666666666664`}, {52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {50.67375799589206, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {60., 5.102694996447308*^-16, 
        16.666666666666664`}, {60., 2.5493082627129206`*^-31, 
        24.999999999999996`}, {56.42197458095559, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {52.75044883428479, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYEABlgc6PSW28iV4wcVXrwIBgwMG
j7dttg3zhIuvAYsrHIDwPNHM+bAHXf0KiHqHDjTzIeIGDuju+fcfBCygfD90
d2KIQ92JIQ51Jw5zPtigi69A8Re6uAGGONSdB3CFJwDol1Cy
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{56.42197458095559, 25., 0.}, {60., 25., 0.}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {56.42197458095559, 
       24.148145657226706`, 6.4704761275630185`}, {56.42197458095559, 25., 
       0.}}], Line3DBox[{{56.42197458095559, 24.148145657226706`, 
       6.4704761275630185`}, {60., 24.148145657226706`, 
       6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, 21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, 24.148145657226706`, 6.4704761275630185`}}], 
      Line3DBox[{{56.42197458095559, 21.65063509461097, 
       12.499999999999998`}, {60., 21.65063509461097, 12.499999999999998`}, {
       60., 17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       21.65063509461097, 12.499999999999998`}}], 
      Line3DBox[{{56.42197458095559, 17.67766952966369, 
       17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
       60., 12.500000000000004`, 21.650635094610966`}, {56.42197458095559, 
       12.500000000000004`, 21.650635094610966`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}}], 
      Line3DBox[{{56.42197458095559, 12.500000000000004`, 
       21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 12.500000000000004`, 21.650635094610966`}}], 
      Line3DBox[{{56.42197458095559, 6.470476127563024, 
       24.148145657226706`}, {60., 6.470476127563024, 24.148145657226706`}, {
       60., 7.0819236220599744`*^-15, 25.}, {56.42197458095559, 
       7.0819236220599744`*^-15, 25.}, {56.42197458095559, 6.470476127563024, 
       24.148145657226706`}}], 
      Line3DBox[{{56.42197458095559, 1.5308084989341915`*^-15, 25.}, {60., 
       1.5308084989341915`*^-15, 25.}, {60., -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, 1.5308084989341915`*^-15, 
       25.}}], Line3DBox[{{56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -6.470476127563016, 24.148145657226706`}}], 
      Line3DBox[{{56.42197458095559, -12.499999999999995`, 
       21.65063509461097}, {60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}}], 
      Line3DBox[{{56.42197458095559, -17.677669529663685`, 
       17.67766952966369}, {60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}}], 
      Line3DBox[{{56.4219745809556, -21.650635094610962`, 
       12.500000000000009`}, {60., -21.650635094610962`, 
       12.500000000000009`}, {60., -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -24.148145657226706`, 6.470476127563026}, {
       56.4219745809556, -21.650635094610962`, 12.500000000000009`}}], 
      Line3DBox[{{56.42197458095559, -24.148145657226706`, 
       6.470476127563026}, {60., -24.148145657226706`, 6.470476127563026}, {
       60., -25., 3.061616997868383*^-15}, {56.42197458095559, -25., 
       3.061616997868383*^-15}, {56.42197458095559, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{56.42197458095559, -25., 3.061616997868383*^-15}, {
       60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       56.42197458095559, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{56.42197458095559, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}, {
       56.42197458095559, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{56.42197458095559, 6.470476127563007, -24.14814565722671}, {
       60., 6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.4219745809556, 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{56.42197458095559, 21.65063509461096, -12.50000000000001}, {
       60., 21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOQAYVgeYEAGQPHVq0DAAEN8DVhcAUMcwviw
B118BUS9A3ZxAwzxf/9BwAJDHOpODPHVOMxZg8NeqDttcLgTw18rcIQD1J0Y
4lB3wsUBvq1OPw==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOTAgAIsD6CLr14FAgYY4mvA4goY4hDwYQ+6
+AqIegfs4gYY4v/+g4AFhjjUnRjiq3GYswaHvVB32uBwJ4a/VuAIB6g7McSh
7jwAAACGTj8=
       "]]}}, 
    {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGCQBGJmBig4kOQAYVg6MCADoLjH1Q3336haODjuKq078lDS
ASb+7HcL64Rlpg7/wUADLr4jTfhA9VpDh+1QGibOBGZoOjyF6oOJu0PNhdkD
Ez99/vz62ZNv26C4CyhuB1F/AF39X4g7DjxDMx/qjgM70NzzBKLuACvUXWj+
PeCJ5l+oOw5A3PXaBibuCVVvBnUXWvgc+AN1F0x8F9Q9W6E0TJwN4o4Dj6H6
YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZD4unnWjugboD
7i54fEHDPQLNv7B4goTP7z0Ad5DiKQ==
      "]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx9mHucz1Uax39jRu4z04zCYiaNaqZeKERqmEOWZmK0IyH0spghWpdV7krI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      "]]}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], Point3DBox[CompressedData["
1:eJx1lntwldUVxa8mbXhIuHJjLSNJJhKR2IFoeHSUQA5ICTdg2gYhpDyGBhIz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      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367535201743*^9, 3.5660869911164503`*^9, 
  3.566101750168541*^9, 3.5661391939059563`*^9, 3.614707799177256*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[47]:=",ExpressionUUID->"30129e9c-da09-4b82-99d7-c51a0ba85383"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"AnalyzeSystem", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"GaussianBeam", "[", 
         RowBox[{"10", ",", "0.1`", ",", 
          RowBox[{"NumberOfRays", "\[Rule]", "11"}], ",", 
          RowBox[{"FullForm", "\[Rule]", "True"}]}], "]"}], ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"PlanoConvexLens", "[", 
           RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "50.`"}], "]"}],
         ",", 
        RowBox[{"Move", "[", 
         RowBox[{
          RowBox[{"Screen", "[", "50", "]"}], ",", "150.`"}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"UpdateNumericParameters", "\[Rule]", "False"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Print",
 CellChangeTimes->{3.563367535201743*^9, 3.5660869911164503`*^9, 
  3.566101750168541*^9, 3.5661391939059563`*^9, 3.6147077993064013`*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[47]:=",ExpressionUUID->"8af346c3-607a-4d3c-b60b-37087ac743cf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.38898799999999988941112860629800707102`6.398813881553206", 
   ",", "\<\"-363 ray/surface intersections-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367535317547*^9, 3.566086991245563*^9, 
  3.566101750367915*^9, 3.566139194429562*^9, 3.614707799308114*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"Out[47]=",ExpressionUUID->"1be6b05a-38ba-4dd0-9c1b-bf8a553810e2"]
}, Open  ]],

Cell[TextData[{
 "In this ray-trace, it is evident that the ",
 StyleBox["GaussianBeam", "Input"],
 " with ",
 StyleBox["FullForm -> True", "Input"],
 " has produced a rectangular-shaped array of rays. Nevertheless, although it \
is not apparent from the rendering, the transverse intensity and optical \
phase profile of the traced rays have the radial symmetry of an actual \
Gaussian laser beam. Now we will use ",
 StyleBox["TurboPlot", "Input"],
 " on the same system."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"858724e0-3458-4097-a3ad-5905352e1e8a"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Timing[TurboPlot[system]]", "Input"]], "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[48]:=",ExpressionUUID->"4316b42e-16b4-4337-b1d0-5fcbb5018272"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyNkr9Lw0AYhk+Kmzg76qhQ7CQGTjhwaUQ6OIijFMTR2b+gaVbdXB2kig7+
2AJBtwYpOAnZKri4ObgU1Pbue1Mu8hI/CISHj4e7996l9tHOQU0pNTf+Zsff
5D883tusrW0bZSdIlTetgmeDwc3ZyUiDX/Um00hX6vVkZvSlo3Dhfn5/y1wK
h4H52T7z+3wxjeK4f9j+1KtvD7cbu2HBq/xsn/n9HFTybHP40D92mkaVhvnZ
fsmvMvGD95zHuPMMi/teCK/ys33m93nDdC1/Kd4XvMrP9sv+WPzg7h7r5jXP
n+6uz4Om9OdbeJXf7xsGvWsZP98pdz171+gd/B17vkeNHjE/22d+cOSOviDP
juRS9JH42T7zg7se55KDStCfzOeK+dm+n/NfHokHvfP9Q40e/e88033mB+9K
bugL8lyWdwFnfrYPf1zyg7senwboNfrclx6i18z/C6rAGhY=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYAADywMMUNDhKbGVL8HLYfUqEDCA
i+s/3rbZNszTYQ1YXAEu/h8MPKDmfNiDrn4FRL0DTLwdaj5E3AAu7gF1zz+w
eRZwcQjwg7kTQ3w1mjkw8TVo9qKa88EGXXwFmr9QxQ0wxKHuhIvjCk8ASLtW
ow==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYEABlgc6PCW28iV4wcVXrwIBgwP6
j7dttg3zhIuvAYsrHPgPBh5o5nzYg65+BUS9Qzua+RBxAwcPNPf8A5trAeX7
obsTQxzqTgxxqDtxmPPBBl0c6s4D2MUNMMSh7jyAKzwBioVWow==
       "], {{
       56.421974580955585`, 25., 0.}, {60., 25., 0.}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 
       24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 25., 
       0.}}, {{56.421974580955585`, 24.148145657226706`, 
       6.4704761275630185`}, {60., 24.148145657226706`, 
       6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, 24.148145657226706`, 6.4704761275630185`}}, {{
       56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {60., 
       21.65063509461097, 12.499999999999998`}, {60., 17.67766952966369, 
       17.677669529663685`}, {56.421974580955585`, 17.67766952966369, 
       17.677669529663685`}, {56.421974580955585`, 21.65063509461097, 
       12.499999999999998`}}, {{56.421974580955585`, 17.67766952966369, 
       17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
       60., 12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
       12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
       17.67766952966369, 17.677669529663685`}}, {{56.421974580955585`, 
       12.500000000000004`, 21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {
       56.421974580955585`, 12.500000000000004`, 21.650635094610966`}}, {{
       56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {60., 
       6.470476127563024, 24.148145657226706`}, {60., 
       7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
       7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
       6.470476127563024, 24.148145657226706`}}, {{56.421974580955585`, 
       1.5308084989341915`*^-15, 25.}, {60., 1.5308084989341915`*^-15, 25.}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
       56.421974580955585`, 1.5308084989341915`*^-15, 25.}}, {{
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
       56.421974580955585`, -6.470476127563016, 24.148145657226706`}}, {{
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
       56.421974580955585`, -12.499999999999995`, 21.65063509461097}}, {{
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, -21.65063509461097, 12.499999999999998`}, {
       56.421974580955585`, -17.677669529663685`, 17.67766952966369}}, {{
       56.42197458095559, -21.650635094610962`, 12.500000000000009`}, {
       60., -21.650635094610962`, 12.500000000000009`}, {
       60., -24.148145657226706`, 6.470476127563026}, {
       56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -21.650635094610962`, 12.500000000000009`}}, {{
       56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
       60., -24.148145657226706`, 6.470476127563026}, {60., -25., 
       3.061616997868383*^-15}, {56.421974580955585`, -25., 
       3.061616997868383*^-15}, {56.421974580955585`, -24.148145657226706`, 
       6.470476127563026}}, {{56.421974580955585`, -25., 
       3.061616997868383*^-15}, {60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.421974580955585`, -24.148145657226706`, -6.47047612756302}, {
       56.421974580955585`, -25., 3.061616997868383*^-15}}, {{
       56.421974580955585`, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
       56.421974580955585`, -24.14814565722671, -6.470476127563009}}, {{
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.421974580955585`, -17.677669529663692`, -17.677669529663685`}, {
       56.421974580955585`, -21.65063509461097, -12.499999999999993`}}, {{
       56.421974580955585`, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
       56.421974580955585`, -17.677669529663696`, -17.677669529663678`}}, {{
       56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
       56.421974580955585`, -12.50000000000001, -21.65063509461096}}, {{
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.421974580955585`, -2.6796885989305705`*^-14, -25.}, {
       56.421974580955585`, -6.470476127563038, -24.148145657226703`}}, {{
       56.421974580955585`, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.421974580955585`, 
       6.470476127563007, -24.14814565722671}, {
       56.421974580955585`, -4.592425496802574*^-15, -25.}}, {{
       56.421974580955585`, 6.470476127563007, -24.14814565722671}, {60., 
       6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
       6.470476127563007, -24.14814565722671}}, {{56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       17.67766952966367, -17.67766952966371}, {56.421974580955585`, 
       12.499999999999984`, -21.650635094610976`}}, {{56.421974580955585`, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
       21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
       17.677669529663685`, -17.677669529663692`}}, {{56.421974580955585`, 
       21.65063509461096, -12.50000000000001}, {60., 
       21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
       21.65063509461096, -12.50000000000001}}, {{56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
       25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
       24.148145657226703`, -6.470476127563039}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOQAYVgeYEAGQPHVq0DAAEN8DVhcAUMcwviw
B118BUS9A3ZxAwzxf/9BwAJDHOpODPHVOMxZg8NeqDttcLgTw18rcIQD1J0Y
4lB3wsUBvq1OPw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOTAgAIsD6CLr14FAgYY4mvA4goY4hDwYQ+6
+AqIegfs4gYY4v/+g4AFhjjUnRjiq3GYswaHvVB32uBwJ4a/VuAIB6g7McSh
7jwAAACGTj8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmBig4kOQAYVg6MCADoLjH1Q3336haODjuKq078lDS
ASb+7HcL64Rlpg7/wUADLr4jTfhA9VpDh+1QGibOBGZoOjyF6oOJu0PNhdkD
Ez99/vz62ZNv26C4CyhuB1F/AF39X4g7DjxDMx/qjgM70NzzBKLuACvUXWj+
PeCJ5l+oOw5A3PXaBibuCVVvBnUXWvgc+AN1F0x8F9Q9W6E0TJwN4o4Dj6H6
YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZD4unnWjugboD
7i54fEHDPQLNv7B4goTP7z0Ad5DiKQ==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx9mHt01cXVhk9ILCAQQhKFfCGJmKCJlouAqDU246WGhBBcQUQEWhaYiNIi
Lip3rEWlrdoWL2WhInJRrFUEEQpW4UwlgLZWq6ICRSOtH1QqGlsgQrmUZub5
nZw3TvPPsH7rZWfn3TN79jw9xt1aU5sai8UmpsRibU6t//135aqbOx79vCE+
eEPOA7ObCi1r/by/Dlq/sNLUPVVadc6IEst627a8oyf674qXD7G/6Hi4wFb1
vXjntiOFtkvdzh3zB1ea748b/tMxlxTZti/fsn9teYmduqvXkSc3vhc/fP+Q
Ac8f7WqnH/rV+Q/8u9Buv73fc+szKs2qmt5Pflqeby979JzvHri0xFad+8Mz
/3n/O/FJw6+q/dfRzrZ2XWXBjmOFdtSN6/qV76swg65bUFNdkm13/ePSfUv7
l9hpZRObli77c/zN6T1v73XsZPyuiRfdvOh4oT04uHHEU29WmA/sqPtG90yz
GS/0e/7F3iU2/++FWypPvBW/c8/Q3M2HGkpHXjlw94en9BP+3SdnxtYKE/M/
j/9p756MXon477v4ZRp/t4tviE/+k13+RvOvdPkb8sefr5w/Rv1Z4/wx+IP/
Fc5/o/5Pcv4b/Ke+Q1xdjdZ3gqur0foSlzoTn7jUufofy95sP217/Nn6u2a8
dKTAsr6x9tnqM2KV5lvPnexT3qvIsuL/Ret3LZ18vKs9tLiw14JjBZH/X5QM
uiJ7YL6tvO2eH3cqKrIL3z++ZvWjr8fP71+bsuxEZ9ureS2wk8YNm/63xytM
/wdv2vbzvGw7oHktsmNu2P2zjfVb4s889/ac3SdPxlc2rwV209Jz2796T4Xp
9NSv56/OSbOdm9cim9646vphc+rjdecdvOO2Iw2laVNSVp4dO8uumXF6Dzsn
sR/m95tSPaFbIv4LLn6Zxs908Q3xyd/l3dlo/i7vbEP++HOJ88eoP186fwz+
4P9K57tR/y91vkd1oL7Vrr5G63u6q290jtmf7EvOMfuTfck5Jn/yps7kT97U
+eUB9cW5HbfFXxtz2SsLTna1rLVfTL/vtZ9XmNtGVo+YWpxvWSd/Mnfo6yts
vHj12FQby7Cl7bqcdlZKN7t2wZ6t79VWmNsnxj99KDvb9u3xxEcf5ufbFxs+
br/oiZfiVRv/OnFMSswezN3eo2ObbnbgBXubsqorzKIROalbM9Ls91NXpJXk
5NvenVfP7JqxPj7tjVuuH3qsoXTakz1233BKP7/z0YUXXJ3YD69NunvAVV0T
8a9x8Y3GX+riG+KTf4nL32j+U13+hvzx5w/OF6P+/ND5EvmE/03Of6P+Vzn/
o3NGfWe6+hqtr3H1jfo0/Y2+Rp8e4/vbX3xfo08n7/8CyzlO3v9FlnOMP/hC
nfEHX6hzerfM3824c238pjur67amZFjWLQfylg/7doX5RUP6EJOebVn/+GX7
H2UueyZ+ek3mgfFtYrZD85ph/xQ/8/i751SYmg6/OjH79DQ7rHnNtqve+L+a
TnOfjB+pbzwx6kRD6fhLxkxZeEp/eO6+yW0LEvuhuOm18svaJ+Knu/hG449w
8Q3xyX+Cy9to/r90eUd/B/582/lj1J9+zp/oHOB/H+e/Uf8HOv+jPkp9b3L1
NVrfj1x9o3uY+5F7kXuY+5F7kXuY/knfpE9v9v0zg77s+zTni3PFOeZ8ca44
x/iP79QZ//GdOr/d7/hFH8x9OJ5yeZt5KakxyzruusaBszpXmMsLXvk0/o00
y/rsN266oPSuu+P3zV55ZMHJhtIHl4/OHHhKP+OuPXNebpvYD7HMlWbuaYn4
p7m4RuNf7eJGv4f8O7r8jeY/3OUf7VP8Oez8MerPJOdP1Ofwf5Xz36j/7v4q
MvhPfe9x9TXU97Cvb5arr9nh60v/Ya5izqL/MFdhE/cv9y73MPcv9y76qD/7
vkyfpj/Tl9Fzfjm3nGPOL+cWPfWlrtQ5qq+va+xrfz4uZU1pXlvsB4m/wMU3
Gj/NxY/+H/nf6PI3mn+Jyz/S488M549Rf/7o/In0+H+a89+o/w86/yM99R3l
6mu0vk+4+kZ67Q/M0dofmKO1PzBnaX/I8nOW9gfuYe0P3MPaH+jT2h/o09of
OMfaHzjH2h+os/YH6qz9QeMTl1X7g+ZPfyB/7Q/qD/0Bf7Q/qP/0B/zX/kB9
tT9QX50feCfp/MA7SecH5midH5ijdX5gztL5gTlL5wfuYZ0fuId1fqAOOj9Q
B50fOMc6P3COdX7Q+NSV+Do/aP7kzarzg/rD/IA/Oj+o/8wP+K/zg9aX+YH6
Tt3t5s9p/n3R5N/B78n7gndw7meu/xz074uL/TupTt4XvJP0fcEcre8L5mh9
X+CTvi/wSd8XnDN9X3DO9H1Bn9b3BX1a3xcan3NLfH1faP7Ulfz1faH+4Asr
/h/27wv1n/cF/lPfGf59ofXlfUF9lT/AOZQ/wDmUP/AOVv7AO1j5A+8k5Q/8
HcofOAfKHzgHyh/oo8ofujBnCX/gHlb+wD2s/EHjwx+Ir/xB8+fckr/yB/WH
uuKP8gf1H99ZlT9ofeEP1Ff5JBxL+SQcS/kkv0f5JL9H+STvYOWT7FPlk/Q5
5ZMf+j6nfJJ7kvuRuZl7Uvkkc5bySeYs5ZMan3uX+MonNX/6Mvkrn1R/OLf4
o3xS/aeu+K98UutLXVlDXNq5Um3OPpo77NaHiy1riEujr3i63biFDxXa3Lfv
nXnH9OIgl0Y/s/i+dmOvyrNdmqaMfmp8cZBLo789/5GHRk/Lspl1P9rQf3hx
kEujf+9QfdP8yal2SP/fXriuqjjIpdHzPSfn9fv3VRQHuTT6XS6+IX6IS6Of
5vI35B/i0ujvcP4Y/AlxafSDnf8G/0NcGn2Rq6vR+iqXRk9c6hzi0uh/s/vA
nCvuKLSsIS6N/pP9914xu2eevbK87Qc1kwqDXBr9dzaVVl49Pste3bwWBrk0
+nfe/jxr6+hUu715LQxyad0P0xdfv3bJDYVBLo3+AxffED/EpdG7vLMM+Ye4
NPq9zh+DPyEujf5Z53tUhxCXRp/v6hud4xCXRs++nOXPcYhLoydv6hzi0uif
a9ehd216nmUNcWn0dv/IOnNtlj3r43mPjD3RPcil0U/Ym3VL05BUu3hnXsG/
DnYPcmndD6PbFHzn/S+7B7k0+h+4+Ib4IS4t+RvyD3Fp9KucL5FPIS4dnRfn
f3TOQlwafbarr6G+IS6NPsv3Nfp0iEsn7/9CyzkOcWn0+EKdQ1wa/Z2PXj71
3Yosyxri0ui7vfOTS1ZfmWpzmtesIJfW/fDWRyNufObyrCCXRp/n4hvih7g0
+h+7vKO/I8Sl0Z/t/InOQYhLox/k/I/6aIhLoz/T1Te6h0NcGj33IvdwiEuj
f9/3ze2+T4e4NHrOFec4xKXR4zt1DnFp9F0fe/74sstSLWuIS+t++Nu2CeOX
X5oa5NLou7u4ppuPH+LS6HNd/tE+DXFp9EucP1GfC3Fp9Duc/wb/Q1wa/XWu
vsxBNsSlI//9XMWXEJdGz73LlxCXRk9f5kuIS6Pn3PLlf3PpakNd+RLi0uj1
S4hLo9/n4kffQ1wa/Z9d/tH3EJdG/z3nT/Q9xKXRz3T+R99DXBp9rqtv9D3E
pdHTH5ijQ1waPf1hp5+zQlwaPf2BezjEpdHTH+jTIS6NnnPLOQ5xafR8p84h
Lo0+z8dlDXHpyH/fH8g/xKXR0x/wJ8Sl0dMf8D/EpdHTHz7y9Q1xafTMD7yT
QlwaPfMDc3SIS6OX+SHIpdFz73IPh7h0tB98X6YOIS6t+4FzHOLS0X7wdSV+
iEujJ2/WEJdGz/zwe+9PiEujZ37A/xCXRs/8QH1DXBp9pn9f8A4OcWn0A/37
4l3/TgpxafTMzczRIS6NnrkKn0JcGj33LucsxKV1P9CnQ1waPeeW+CEujZ66
kn+IS6Pf4H1hDXFp9Bf79wX+h7g0et4XEecIcGn08Ac4R4hLo+fdyzs4xKXR
8y7inRTi0uiZmzkHIS6N/l0/V/l7LMildT9wD4e4NHr4A/FDXBo955b8Q1wa
PfwBf0JcGj2+s4a4NHr4A/UNcWn0cCs4VohLo4dr8HtCXBo97172aYhLo+dd
dIbvcyEujZ65mXsyxKV1PzBnhbg0eu5d4oe4NHr6MvmHuDR6zi3+hLg0euqK
/yEujZ66smrdWZs/23Hm2rrazPxZmZZV607/QF85fN6OeaPTbdWhYeXbjyT0
yqXR/67Nuj2LL2prB839fV3ayKxIr1wafd2Bkcc++e7J+LgBG/KGPpbQK5dG
v2Rz8W/mPP5FvGLmyHsnvZrQU/ek99MpfbRPcj7dOeathF65NPrnXfwyja9c
Gv0tLv+y8ZK/cmn0rzp/jPqjXBp9jfPfVIv/yqXRX+fqarS+yqXRU9cqX2f0
yqXRf3P1VyfuLuhsWdErl0a/97PKd5ZvaWuveiB9c581Cb1yafS19ctPXtgx
Zic0rxmRXrk0+g7dF42sPa8x3ql5Teipe9L7uMV+mHvtw/8/dkBCr1wavYvb
WJYu8ZVLR/vB5W80f+XS6Pc7f8wg8Ue5NPoBznej/iuXjvaPqy/7KNIrl0Zf
4fflK/4co1cujf4Knzd1Rq9cGv2i885+7Jd921lW9Mql0Vfdmru/a03MNp5T
0lA4K6FXLo1+VbejZ0y7tTHermfTkn5PJ/TUPYl/tNgPszefO2XLuoReuTT6
F138Mo2vXBp9ucvfaP7KpdEvcb6YxeKPcmn0lc5/85n4r1wafbWrL30o0iuX
Rn+j72v0afTKpdGz7znH6JVLo8eXIb7O6JVLo1/ebXuH3XNjlhW9cmn062ct
67Pyicb4S81rQk/dk/hWi/3w0s1vbb7wmYReuTT6TS5+mcZXLo1+hcvbaP7K
pdEfdP6YavFHuTT6ic5/X4eEXrk0+h+4+prJUl/l0ugH+Xtxkb+H0SuXRk/f
9H000iuXRs+54hyjVy6dXN+YXefrjF65NPqCNaOWnv9KY5xV90MSv2yxH44s
Sev0yJaEXrk0+hIXt6xI4iuXRr/R5R/tU/TKpdF3dP6YF8Qf5dLos5z/JlP8
Vy6N/vrZzfU1n2xNrq9yafTJcxU/rbk0+uR7N6FXLo0+uS8n9Mql0Sef24Re
uTT65Lom9LGv+2mxH1SvXBp926XN8ctUr1wa/csuf6N65dLo73b+tNIrl0b/
E+d/K71yafQrXH1b6ZVLo6c/rPZzNHrl0ui7+P7g92ekVy6Nnv6wxt/D6JVL
o6c/bPR9Gr1yafQ9/bkt9ucYPX95Up1b7IfkOrfm0uj7+rh9Jb5yafT0h02S
v3Jp9Om+P/xW/FEujf4M3x9yxH/l0ujpD//cmlxf5dLomR8m+XcSeuXS6Jkf
mKPRK5dGz/wwyM9Z6JVLo1/m792n/T0c7Qfh0ug3+L4c93XQ/ZB0jlvsh+Rz
3JpLo6euGl+5NHrmB81fuTR65oeh4o9yafTMD+q/cmn0zA/Tpb7KpdEP9u8L
69/B6JVLo+83070vVvzFvZPQK5dG7+dn6+fnSK9cGj1zFT6hVy6NnnuXe1j3
Q1KfbrEfkvt0ay6NnnObIfGVS6O/xtdV81cujb53b+fLN3sn+6NcGv0A57/5
tfivXDry078v6qW+yqXRwx+u9ZwDvXJp9Of5dy/vYPTKpdHzLuKdhF65NHrm
Zs4BeuXS6LP9XOXvsVb7IekebrEfku/h1lxa4pdlSnzl0ugn+nOr+SuXRv+5
5w9V4o9yafR9ve/qv3Jp9PCHsVJf5dLoh3tu5ddIr1wa/TWea/B70CuXRr/J
v3uH+H2KXrk0en9vxSf6PodeuTT6v/u5mXtS90PSnNViPyTPWa25NPqv/L2r
8ZVLo5/q+7Lmr1waPedW/VEujZ5zq/5/LZf+7/zg68r6H9MrnCQ=
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxtVn1U1uUZfhM2SBORF1OOAlPReF0hIbI1czyaCi/C2w5+IBObB4UxKbTj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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5633675358519278`*^9, 3.566086991752901*^9, 
  3.566101751351419*^9, 3.56613919595331*^9, 3.614707800068677*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[48]:=",ExpressionUUID->"a775210d-8ac8-4f96-881b-f0406171236d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.70343500000000003247180302423657849431`5.867823886485326", 
   ",", "\<\"-traced system-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367535854734*^9, 3.566086991760478*^9, 
  3.566101751358181*^9, 3.566139195961094*^9, 3.614707800071271*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"Out[48]=",ExpressionUUID->"2701a2cb-a51f-48fb-8a91-292322a5ed60"]
}, Open  ]],

Cell[TextData[{
 "Although the overall trace time depends on the particular computer in use \
(the author's computer is particularly slow by today's standards), the timing \
ratio from two different traces will remain fairly constant for different \
computer systems (but perhaps not for different ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " versions). In the previous example, we can see that ",
 StyleBox["TurboPlot", "Input"],
 ", in its default setting, is about four times faster than ",
 StyleBox["AnalyzeSystem", "Input"],
 ". Although this speed increase is useful, it is still not particularly \
dramatic. However, with ",
 StyleBox["TurboPlot", "Input"],
 ", most of this time was actually spent in the construction of the ",
 StyleBox["RayTraceFunction", "Input"],
 " source code and only a tiny fraction of the time was actually spent on the \
ray-trace. In particular, as the number of rays used in a trace is increased, \
the calculation time of ",
 StyleBox["TurboPlot", "Input"],
 ", relative to ",
 StyleBox["AnalyzeSystem", "Input"],
 ", improves. In addition, the trace speed of ",
 StyleBox["TurboPlot", "Input"],
 " depends on the option settings used in the trace. For some settings of ",
 StyleBox["TurboPlot", "Input"],
 ", the actual ray-tracing speed can be as much as 30 times faster than ",
 StyleBox["AnalyzeSystem", "Input"],
 ". This speed improvement with ",
 StyleBox["TurboPlot", "Input"],
 " becomes particularly clear when you run multiple traces of the same \
system, because ",
 StyleBox["TurboPlot", "Input"],
 " can reuse the ",
 StyleBox["RayTraceFunction", "Input"],
 " source code from a previous calculation (since this code is passed in the \
trace output). For example, what if we wished to observe how the trace \
appears for different lens focal lengths? With ",
 StyleBox["TurboPlot", "Input"],
 ", we can introduce a symbolic parameter, ",
 StyleBox["f", "Input"],
 ", that represents the lens focal length and then rerun the trace with \
different settings for ",
 StyleBox["f", "Input"],
 ". This is accomplished by including both a symbolic and a numeric setting \
",
 StyleBox["{f,100}", "Input"],
 " for the focal length parameter in ",
 StyleBox["PlanoConvexLens", "Input"],
 " as follows:"
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"7563334e-5902-41f8-a1df-a57b98fd95db"],

Cell["\<\
fsystem = {GaussianBeam[10,.1,NumberOfRays->11,FullForm->True],
\tMove[PlanoConvexLens[{f,100},50,10],50],
\tMove[Screen[50],150]};\
\>", "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[49]:=",ExpressionUUID->"82dd5976-98c4-4850-8129-65296a055626"],

Cell[TextData[{
 "When we call ",
 StyleBox["TurboPlot", "Input"],
 " the first time, the result is the same as before:"
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"8a0d808b-3acd-42e1-8a4e-3cbf9708bab9"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Timing[trace = TurboPlot[", "Input"],
 "fsystem",
 StyleBox[", ", "Input"],
 "PlotType->TopView",
 StyleBox["]]", "Input"]
}], "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[50]:=",ExpressionUUID->"4ba6f6b3-7128-4561-bf3a-51d141ee8235"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYCYq/KCGdmMx8HBjCwPACh/TD4a1aBgMGBTk+J
rXwJXg6roXx0/ejy6PpR+QoHDB5v22wb5gnno+tHl0fXj+pehr0QyhPGZ8Cu
HyGPph/OXwVR7wDTvwLKx2U+qjxCPyrfwAHmPxgfXT+6PLp+GP8/GFg4wML/
H5SPrh81fhD+O33+/PrZk1/bwPhaurp7GX8/s4Hpb+/qOpWedMgGXT+6PLp+
GL8DLP/IBuY/iPpLGOajy6Prh/HPgt172wYW/qehfOz6EfKo/r2NZv4lNP2P
CJj/CEM/jN8J9Q/Mf5rQ8EDXjy4P09+FFp43bt8+vGXdFEtY+J+Cxhe6fgBx
2VJS
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}, {{56.42197458095559, 0.}, {
       52.75044883428479, 0.}, {50.67375799589206, 0.}, {50., 0.}, {
       50.67375799589206, 0.}, {52.75044883428478, 0.}, {56.42197458095559, 
       0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 
       0.}, {60., 0.}, {56.42197458095559, 0.}}, {{56.42197458095559, 25.}, {
       60., 25.}, {60., 24.148145657226706`}, {56.42197458095559, 
       24.148145657226706`}, {56.42197458095559, 25.}}, {{56.42197458095559, 
       24.148145657226706`}, {60., 24.148145657226706`}, {60., 
       21.65063509461097}, {56.42197458095559, 21.65063509461097}, {
       56.42197458095559, 24.148145657226706`}}, {{56.42197458095559, 
       21.65063509461097}, {60., 21.65063509461097}, {60., 
       17.67766952966369}, {56.42197458095559, 17.67766952966369}, {
       56.42197458095559, 21.65063509461097}}, {{56.42197458095559, 
       17.67766952966369}, {60., 17.67766952966369}, {60., 
       12.500000000000004`}, {56.42197458095559, 12.500000000000004`}, {
       56.42197458095559, 17.67766952966369}}, {{56.42197458095559, 
       12.500000000000004`}, {60., 12.500000000000004`}, {60., 
       6.470476127563024}, {56.42197458095559, 6.470476127563024}, {
       56.42197458095559, 12.500000000000004`}}, {{56.42197458095559, 
       6.470476127563024}, {60., 6.470476127563024}, {60., 
       7.0819236220599744`*^-15}, {56.42197458095559, 
       7.0819236220599744`*^-15}, {56.42197458095559, 6.470476127563024}}, {{
       56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}, {{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}, {{
       56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}, {{
       56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}, {{
       56.4219745809556, -21.650635094610962`}, {60., -21.650635094610962`}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}, {{
       56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}, {{
       56.42197458095559, -25.}, {60., -25.}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.42197458095559, -25.}}, {{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}, {{
       56.42197458095559, -21.65063509461097}, {60., -21.65063509461097}, {
       60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}, {{
       56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}, {{
       56.42197458095559, -12.50000000000001}, {60., -12.50000000000001}, {
       60., -6.470476127563038}, {56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}, {{
       56.42197458095559, -6.470476127563038}, {60., -6.470476127563038}, {
       60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}, {{
       56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}, {{56.42197458095559, 
       6.470476127563007}, {60., 6.470476127563007}, {60., 
       12.499999999999984`}, {56.42197458095559, 12.499999999999984`}, {
       56.42197458095559, 6.470476127563007}}, {{56.42197458095559, 
       12.499999999999984`}, {60., 12.499999999999984`}, {60., 
       17.67766952966367}, {56.4219745809556, 17.67766952966367}, {
       56.42197458095559, 12.499999999999984`}}, {{56.42197458095559, 
       17.677669529663685`}, {60., 17.677669529663685`}, {60., 
       21.65063509461096}, {56.42197458095559, 21.65063509461096}, {
       56.42197458095559, 17.677669529663685`}}, {{56.42197458095559, 
       21.65063509461096}, {60., 21.65063509461096}, {60., 
       24.148145657226703`}, {56.42197458095559, 24.148145657226703`}, {
       56.42197458095559, 21.65063509461096}}, {{56.42197458095559, 
       24.148145657226703`}, {60., 24.148145657226703`}, {60., 25.}, {
       56.42197458095559, 25.}, {56.42197458095559, 24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}, {{150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150.,
        0.}, {150., 0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHkhwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAJP8g58=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJztlwlQlFcWhZvFuCEgjQKDgNqotI4bIOqI8blE7BbRQhFRyFgqiJKgllEE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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJzVlXtQ1FUUx1fdAkVWZFdlB3dJXZC1BASkDK0rKstvwc1ZXpJoDrrbJrro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      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367536572134*^9, 3.5660869923612947`*^9, 
  3.5661017526037292`*^9, 3.566139197099701*^9, 3.614707800859592*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[50]:=",ExpressionUUID->"d17e9029-8a30-4cfd-a2de-1ef7fd95dc7b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.58278900000000000147792889038100838661`5.786111259252688", 
   ",", "\<\"-traced system-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367536574979*^9, 3.566086992369005*^9, 
  3.5661017526105337`*^9, 3.566139197137041*^9, 3.614707800862639*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"Out[50]=",ExpressionUUID->"0654bc51-0d0e-44fc-9ad4-a4a620076efc"]
}, Open  ]],

Cell[TextData[{
 "After this trace has occurred once, we can then rerender the ray-trace \
information much more quickly by passing ",
 StyleBox["trace", "Input"],
 " back to ",
 StyleBox["TurboPlot", "Input"],
 "."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"b6867a6d-2e38-4d9a-8d99-c590923b8370"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Timing[TurboPlot[trace]]", "Input"]], "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[51]:=",ExpressionUUID->"dcf9a401-6d74-4dca-b0a9-dbfb831b5a69"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyFkr9Lw0AYhk+Kmzg76qhQyCQGTjhwSpEMDuIoBXF07l/QJqturg5SRQd/
bIGgW4sUnIRsLbi4OXQpqO3d955cji/54Eh4+Hi4vHk32mcHJw0hxMr8LM/P
4r3VOdprbO8roSfMhTOx5cPR6P7yfCbBb/uLCfKtZjNbmk1lEq09rR631A1x
GDg/t8/5Xb6e99J0cNr+lsHk+WH3MLK8zs/tc343B5G96Ry+iEdKlKba7++X
/GLo+GPVNx5l7jO233tNvM5fve/7XR6oRPN3+3/B6/zcftmfkh/8V8+O+iiK
18e7qxD9+SFe53f7hkHvYuXm+89Nzz4legd/V9/vRaJHnJ/b5/zgyB19QZ5d
ygWc83P7nB/c9LigHERmHhHlY7mo9vv7bs4+75EHvXP9Y+n2qO4+5X3fD55Q
brbXlOcm/Rdwzs/tw5+W/OCmxxcheo3+DKiH6DXn/wPKhPZR
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYAADywMMUNDpKbGVL8HLYfUqEDCA
ixs83rbZNszTYQ1YXAEuDgGeUHM+7EFXvwKi3gEm3gE1HyJuABeHuefffxCw
gItDgB/MnRjiq9HMgYmvQbMX1ZwPNujiK7D6CyZugCEOdSdcHFd4AgCmzVCy

       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPaqjHBmNvNxYEABlgc6PSW28iV4wcVXrwIBgwMG
j7dttg3zhIuvAYsrHIDwPNHM+bAHXf0KiHqHDjTzIeIGDuju+fcfBCygfD90
d2KIQ92JIQ51Jw5zPtigi69A8Re6uAGGONSdB3CFJwDol1Cy
       "], {{
       56.42197458095559, 25., 0.}, {60., 25., 0.}, {60., 24.148145657226706`,
        6.4704761275630185`}, {56.42197458095559, 24.148145657226706`, 
       6.4704761275630185`}, {56.42197458095559, 25., 0.}}, {{
       56.42197458095559, 24.148145657226706`, 6.4704761275630185`}, {60., 
       24.148145657226706`, 6.4704761275630185`}, {60., 21.65063509461097, 
       12.499999999999998`}, {56.42197458095559, 21.65063509461097, 
       12.499999999999998`}, {56.42197458095559, 24.148145657226706`, 
       6.4704761275630185`}}, {{56.42197458095559, 21.65063509461097, 
       12.499999999999998`}, {60., 21.65063509461097, 12.499999999999998`}, {
       60., 17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       17.67766952966369, 17.677669529663685`}, {56.42197458095559, 
       21.65063509461097, 12.499999999999998`}}, {{56.42197458095559, 
       17.67766952966369, 17.677669529663685`}, {60., 17.67766952966369, 
       17.677669529663685`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {56.42197458095559, 12.500000000000004`, 
       21.650635094610966`}, {56.42197458095559, 17.67766952966369, 
       17.677669529663685`}}, {{56.42197458095559, 12.500000000000004`, 
       21.650635094610966`}, {60., 12.500000000000004`, 
       21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 6.470476127563024, 24.148145657226706`}, {
       56.42197458095559, 12.500000000000004`, 21.650635094610966`}}, {{
       56.42197458095559, 6.470476127563024, 24.148145657226706`}, {60., 
       6.470476127563024, 24.148145657226706`}, {60., 
       7.0819236220599744`*^-15, 25.}, {56.42197458095559, 
       7.0819236220599744`*^-15, 25.}, {56.42197458095559, 6.470476127563024, 
       24.148145657226706`}}, {{56.42197458095559, 1.5308084989341915`*^-15, 
       25.}, {60., 1.5308084989341915`*^-15, 25.}, {60., -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, -6.470476127563016, 
       24.148145657226706`}, {56.42197458095559, 1.5308084989341915`*^-15, 
       25.}}, {{56.42197458095559, -6.470476127563016, 24.148145657226706`}, {
       60., -6.470476127563016, 24.148145657226706`}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}, {
       56.42197458095559, -6.470476127563016, 24.148145657226706`}}, {{
       56.42197458095559, -12.499999999999995`, 21.65063509461097}, {
       60., -12.499999999999995`, 21.65063509461097}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}, {
       56.42197458095559, -12.499999999999995`, 21.65063509461097}}, {{
       56.42197458095559, -17.677669529663685`, 17.67766952966369}, {
       60., -17.677669529663685`, 17.67766952966369}, {
       60., -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -21.65063509461097, 12.499999999999998`}, {
       56.42197458095559, -17.677669529663685`, 17.67766952966369}}, {{
       56.4219745809556, -21.650635094610962`, 12.500000000000009`}, {
       60., -21.650635094610962`, 12.500000000000009`}, {
       60., -24.148145657226706`, 6.470476127563026}, {
       56.42197458095559, -24.148145657226706`, 6.470476127563026}, {
       56.4219745809556, -21.650635094610962`, 12.500000000000009`}}, {{
       56.42197458095559, -24.148145657226706`, 6.470476127563026}, {
       60., -24.148145657226706`, 6.470476127563026}, {60., -25., 
       3.061616997868383*^-15}, {56.42197458095559, -25., 
       3.061616997868383*^-15}, {56.42197458095559, -24.148145657226706`, 
       6.470476127563026}}, {{56.42197458095559, -25., 
       3.061616997868383*^-15}, {60., -25., 3.061616997868383*^-15}, {
       60., -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -24.148145657226706`, -6.47047612756302}, {
       56.42197458095559, -25., 3.061616997868383*^-15}}, {{
       56.42197458095559, -24.14814565722671, -6.470476127563009}, {
       60., -24.14814565722671, -6.470476127563009}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       56.42197458095559, -24.14814565722671, -6.470476127563009}}, {{
       56.42197458095559, -21.65063509461097, -12.499999999999993`}, {
       60., -21.65063509461097, -12.499999999999993`}, {
       60., -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -17.677669529663692`, -17.677669529663685`}, {
       56.42197458095559, -21.65063509461097, -12.499999999999993`}}, {{
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}, {
       60., -17.677669529663696`, -17.677669529663678`}, {
       60., -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       56.42197458095559, -17.677669529663696`, -17.677669529663678`}}, {{
       56.42197458095559, -12.50000000000001, -21.65063509461096}, {
       60., -12.50000000000001, -21.65063509461096}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       56.42197458095559, -12.50000000000001, -21.65063509461096}}, {{
       56.42197458095559, -6.470476127563038, -24.148145657226703`}, {
       60., -6.470476127563038, -24.148145657226703`}, {
       60., -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -2.6796885989305705`*^-14, -25.}, {
       56.42197458095559, -6.470476127563038, -24.148145657226703`}}, {{
       56.42197458095559, -4.592425496802574*^-15, -25.}, {
       60., -4.592425496802574*^-15, -25.}, {60., 
       6.470476127563007, -24.14814565722671}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}, {
       56.42197458095559, -4.592425496802574*^-15, -25.}}, {{
       56.42197458095559, 6.470476127563007, -24.14814565722671}, {60., 
       6.470476127563007, -24.14814565722671}, {60., 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {56.42197458095559, 
       6.470476127563007, -24.14814565722671}}, {{56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}, {60., 
       12.499999999999984`, -21.650635094610976`}, {60., 
       17.67766952966367, -17.67766952966371}, {56.4219745809556, 
       17.67766952966367, -17.67766952966371}, {56.42197458095559, 
       12.499999999999984`, -21.650635094610976`}}, {{56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}, {60., 
       17.677669529663685`, -17.677669529663692`}, {60., 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}, {56.42197458095559, 
       17.677669529663685`, -17.677669529663692`}}, {{56.42197458095559, 
       21.65063509461096, -12.50000000000001}, {60., 
       21.65063509461096, -12.50000000000001}, {60., 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {56.42197458095559, 
       21.65063509461096, -12.50000000000001}}, {{56.42197458095559, 
       24.148145657226703`, -6.470476127563039}, {60., 
       24.148145657226703`, -6.470476127563039}, {60., 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       25., -2.8327694488239898`*^-14}, {56.42197458095559, 
       24.148145657226703`, -6.470476127563039}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOQAYVgeYEAGQPHVq0DAAEN8DVhcAUMcwviw
B118BUS9A3ZxAwzxf/9BwAJDHOpODPHVOMxZg8NeqDttcLgTw18rcIQD1J0Y
4lB3wsUBvq1OPw==
       "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmBig4kOTAgAIsD6CLr14FAgYY4mvA4goY4hDwYQ+6
+AqIegfs4gYY4v/+g4AFhjjUnRjiq3GYswaHvVB32uBwJ4a/VuAIB6g7McSh
7jwAAACGTj8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmBig4kOQAYVg6MCADoLjH1Q3336haODjuKq078lDS
ASb+7HcL64Rlpg7/wUADLr4jTfhA9VpDh+1QGibOBGZoOjyF6oOJu0PNhdkD
Ez99/vz62ZNv26C4CyhuB1F/AF39X4g7DjxDMx/qjgM70NzzBKLuACvUXWj+
PeCJ5l+oOw5A3PXaBibuCVVvBnUXWvgc+AN1F0x8F9Q9W6E0TJwN4o4Dj6H6
YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZD4unnWjugboD
7i54fEHDPQLNv7B4goTP7z0Ad5DiKQ==
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx9mHt01cXVhk9ILCAQQhKFfCGJmKCJlouAqDU246WGhBBcQUQEWhaYiNIi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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["

1:eJxtVn1U1uUZfhM2SBORF1OOAlPReF0hIbI1czyaCi/C2w5+IBObB4UxKbTj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      "]]}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367536854463*^9, 3.566086992685717*^9, 
  3.566101752797544*^9, 3.566139197701589*^9, 3.614707801087352*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[51]:=",ExpressionUUID->"17aad0ef-4d85-49dc-8687-7a9910b92579"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.11691899999999999515409854211611673236`5.088485005490688", 
   ",", "\<\"-traced system-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367536857909*^9, 3.56608699269375*^9, 
  3.5661017528044157`*^9, 3.566139197708816*^9, 3.614707801090967*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"Out[51]=",ExpressionUUID->"19a4ddc9-b309-4657-a005-e419ddaea093"]
}, Open  ]],

Cell[TextData[{
 "Because we have not changed any parameters, ",
 StyleBox["TurboPlot", "Input"],
 " has simply rerendered the previous calculation without rerunning the \
trace. In this instance, ",
 StyleBox["TurboPlot", "Input"],
 " takes the role of ",
 StyleBox["ShowSystem", "Input"],
 ", discussed previously in Section 7. However, we can also run a new ray \
trace with different symbolic parameter values at much greater speed. In \
order to accomplish this, we use the ",
 StyleBox["SymbolicValues", "Input"],
 " option."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"ba8154d8-97ee-46e3-af97-1bfcda3007ef"],

Cell[TextData[{
 StyleBox["SymbolicValues -> {", "Input"],
 StyleBox["symbol->value,...",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " is an option that attaches numerical values to the specified symbolic \
variable names."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "SymbolicValues", "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f"],

Cell[TextData[{
 "Next we will change the value for the lens focal length, ",
 StyleBox["f", "Input"],
 ", from 100 to 75."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"584eb23d-c0e4-4cf3-a9f3-f1123ef41b41"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Timing[TurboPlot[trace", "Input"],
 ", SymbolicValues->{f->75}, PlotType->TopView",
 StyleBox["]]", "Input"]
}], "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[52]:=",ExpressionUUID->"0c4146da-356c-4135-94fc-acd9c4891d21"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYC4h43azH3Hl8HBjCwPACh/TD4a1aBgMGBndtX
M8o88HJYDeWj60eXR9ePylc4wFTDpD612BPOR9ePLo+uH9W9DHv/g4EHjM+A
rh9dHk0/nL8Kot4Bpn8FlI/LfJg8un5UvoEDzH8wPrp+dHl0/TA+xB0WDrDw
/wflo+tHjR+E/06fP79+9uTXNjC+lq7uXsbfz2xg+tu7uk6lJx2yQdePLo+u
H8bvAMs/soH5D6L+Eob56PLo+mH8s2D33raBhf9pKB9dP7o8qn9vo5l/CU3/
IwLmP8LQD+N3Qv0D858mNDzQ9aPLw/R3oYXnjdu3D29ZN8USFv6noPGFrh8A
QgB0bA==
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{59.095919398253585`, -25.}, {
       53.75085469135906, -16.666666666666668`}, {
       50.90298926945981, -8.333333333333336}, {
       49.99999999999999, -3.552713678800501*^-15}, {50.90298926945981, 
       8.333333333333329}, {53.75085469135906, 16.666666666666657`}, {
       59.095919398253585`, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       59.095919398253585`, -25.}}, {{59.095919398253585`, 0.}, {
       53.75085469135906, 0.}, {50.90298926945981, 0.}, {49.99999999999999, 
       0.}, {50.90298926945981, 0.}, {53.75085469135906, 0.}, {
       59.095919398253585`, 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
       60., 0.}, {60., 0.}, {60., 0.}, {59.095919398253585`, 0.}}, {{
       59.095919398253585`, 25.}, {60., 25.}, {60., 24.148145657226706`}, {
       59.095919398253585`, 24.148145657226706`}, {59.095919398253585`, 
       25.}}, {{59.095919398253585`, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {59.095919398253585`, 
       21.65063509461097}, {59.095919398253585`, 24.148145657226706`}}, {{
       59.095919398253585`, 21.65063509461097}, {60., 21.65063509461097}, {
       60., 17.67766952966369}, {59.095919398253585`, 17.67766952966369}, {
       59.095919398253585`, 21.65063509461097}}, {{59.095919398253585`, 
       17.67766952966369}, {60., 17.67766952966369}, {60., 
       12.500000000000004`}, {59.095919398253585`, 12.500000000000004`}, {
       59.095919398253585`, 17.67766952966369}}, {{59.095919398253585`, 
       12.500000000000004`}, {60., 12.500000000000004`}, {60., 
       6.470476127563024}, {59.095919398253585`, 6.470476127563024}, {
       59.095919398253585`, 12.500000000000004`}}, {{59.095919398253585`, 
       6.470476127563024}, {60., 6.470476127563024}, {60., 
       7.0819236220599744`*^-15}, {59.095919398253585`, 
       7.0819236220599744`*^-15}, {59.095919398253585`, 
       6.470476127563024}}, {{59.095919398253585`, 
       1.5308084989341915`*^-15}, {60., 1.5308084989341915`*^-15}, {
       60., -6.470476127563016}, {59.095919398253585`, -6.470476127563016}, {
       59.095919398253585`, 1.5308084989341915`*^-15}}, {{
       59.095919398253585`, -6.470476127563016}, {60., -6.470476127563016}, {
       60., -12.499999999999995`}, {
       59.095919398253585`, -12.499999999999995`}, {
       59.095919398253585`, -6.470476127563016}}, {{
       59.095919398253585`, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       59.095919398253585`, -17.677669529663685`}, {
       59.095919398253585`, -12.499999999999995`}}, {{
       59.095919398253585`, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       59.095919398253585`, -21.65063509461097}, {
       59.095919398253585`, -17.677669529663685`}}, {{
       59.095919398253585`, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       59.095919398253585`, -24.148145657226706`}, {
       59.095919398253585`, -21.650635094610962`}}, {{
       59.095919398253585`, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {59.095919398253585`, -25.}, {
       59.095919398253585`, -24.148145657226706`}}, {{
       59.095919398253585`, -25.}, {60., -25.}, {60., -24.148145657226706`}, {
       59.095919398253585`, -24.148145657226706`}, {
       59.095919398253585`, -25.}}, {{
       59.095919398253585`, -24.14814565722671}, {60., -24.14814565722671}, {
       60., -21.65063509461097}, {59.095919398253585`, -21.65063509461097}, {
       59.095919398253585`, -24.14814565722671}}, {{
       59.095919398253585`, -21.65063509461097}, {60., -21.65063509461097}, {
       60., -17.677669529663692`}, {
       59.095919398253585`, -17.677669529663692`}, {
       59.095919398253585`, -21.65063509461097}}, {{
       59.095919398253585`, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       59.095919398253585`, -12.50000000000001}, {
       59.095919398253585`, -17.677669529663696`}}, {{
       59.095919398253585`, -12.50000000000001}, {60., -12.50000000000001}, {
       60., -6.470476127563038}, {59.095919398253585`, -6.470476127563038}, {
       59.095919398253585`, -12.50000000000001}}, {{
       59.095919398253585`, -6.470476127563038}, {60., -6.470476127563038}, {
       60., -2.6796885989305705`*^-14}, {
       59.095919398253585`, -2.6796885989305705`*^-14}, {
       59.095919398253585`, -6.470476127563038}}, {{
       59.095919398253585`, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       59.095919398253585`, 6.470476127563007}, {
       59.095919398253585`, -4.592425496802574*^-15}}, {{59.095919398253585`, 
       6.470476127563007}, {60., 6.470476127563007}, {60., 
       12.499999999999984`}, {59.095919398253585`, 12.499999999999984`}, {
       59.095919398253585`, 6.470476127563007}}, {{59.095919398253585`, 
       12.499999999999984`}, {60., 12.499999999999984`}, {60., 
       17.67766952966367}, {59.095919398253585`, 17.67766952966367}, {
       59.095919398253585`, 12.499999999999984`}}, {{59.09591939825359, 
       17.677669529663685`}, {60., 17.677669529663685`}, {60., 
       21.65063509461096}, {59.095919398253585`, 21.65063509461096}, {
       59.09591939825359, 17.677669529663685`}}, {{59.095919398253585`, 
       21.65063509461096}, {60., 21.65063509461096}, {60., 
       24.148145657226703`}, {59.095919398253585`, 24.148145657226703`}, {
       59.095919398253585`, 21.65063509461096}}, {{59.095919398253585`, 
       24.148145657226703`}, {60., 24.148145657226703`}, {60., 25.}, {
       59.095919398253585`, 25.}, {59.095919398253585`, 
       24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}, {{150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150.,
        0.}, {150., 0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHkhwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAJP8g58=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJztlwl0zXcWx19eFlsQSZBIJE9fZLFGRFSF/OYImlhiGNSeisSSaVG1RGsE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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJzVlXtQ1FUUx38uC6KCD1hoQYQlV3bXFwiIpih3RnzskkKSOvjAFZQxyPCR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      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367537029931*^9, 3.56608699287138*^9, 
  3.56610175315687*^9, 3.566139197979261*^9, 3.6147078012930117`*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[52]:=",ExpressionUUID->"c2262dfd-d7a6-4354-93bc-b64c5143062b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.1857930000000000136939348749365308322`5.289629260619477", 
   ",", "\<\"-traced system-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367537049914*^9, 3.566086992879706*^9, 
  3.56610175316361*^9, 3.5661391979870996`*^9, 3.614707801296754*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"Out[52]=",ExpressionUUID->"cd0d7832-4882-42ac-aeec-555723c25398"]
}, Open  ]],

Cell[TextData[{
 "This time, the overall trace and rendering time is 10 times shorter than ",
 StyleBox["AnalyzeSystem", "Input"],
 " could have managed (if it indeed accepted symbolic settings). In addition \
to using different symbolic settings, ",
 StyleBox["TurboPlot", "Input"],
 " also accepts new light sources on the fly without having to recompile the \
ray-trace information. This is accomplished by passing, to ",
 StyleBox["TurboPlot", "Input"],
 ", a new light source function as the first parameter and the previous trace \
result as the second parameter. Here, we swap the ",
 StyleBox["GaussianBeam", "Input"],
 " source with a ",
 StyleBox["LineOfRays", "Input"],
 " source as well as change the focal length value to ",
 StyleBox["f-> 90", "Input"],
 "."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"8df57715-fe35-4019-a07d-935cd5a2b382"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Timing[TurboPlot[LineOfRays[30,NumberOfRays->100], trace", "Input"],
 ", SymbolicValues->{f->90}, PlotType->TopView",
 StyleBox["]]", "Input"]
}], "Input",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"In[53]:=",ExpressionUUID->"c7a7c134-59da-4d2c-9066-7712b50842ab"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYC4tQ91mfYFvo4MICB5QEI7YfBX7MKBAwOhG3r
Cjre6eWwGspH148uj64fla9wIGl3wqEf8Z5wPrp+dHl0/ajuZdgLoTxhfAbs
+hHyaPrh/FUQ9Q4w/SugfFzmo8oj9KPyDRxg/oPx0fWjy6Prh/H/g4GFQwo0
/P9B+ej6UeMH4b/T58+vnz35tQ2Mr6Wru5fx9zMbmP72rq5T6UmHbND1o8uj
64fxO8Dyj2xg/oOov4RhPro8un4Y/yzYvbdtYOF/GsrHrh8hj+rf22jmX0LT
/4iA+Y8w9MP4nVD/wPynCQ0PdP3o8jD9XWjheeP27cNb1k2xhMXvKWh8oesH
AA2mbfg=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{57.25801995198052, -25.}, {
       53.07639533780154, -16.666666666666668`}, {
       50.749779031021504`, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.749779031021504`, 
       8.333333333333329}, {53.076395337801536`, 16.666666666666657`}, {
       57.258019951980515`, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       57.25801995198052, -25.}}, {{57.25801995198052, 0.}, {
       53.07639533780154, 0.}, {50.749779031021504`, 0.}, {50., 0.}, {
       50.749779031021504`, 0.}, {53.076395337801536`, 0.}, {
       57.258019951980515`, 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
       60., 0.}, {60., 0.}, {60., 0.}, {57.25801995198052, 0.}}, {{
       57.25801995198052, 25.}, {60., 25.}, {60., 24.148145657226706`}, {
       57.258019951980515`, 24.148145657226706`}, {57.25801995198052, 
       25.}}, {{57.258019951980515`, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {57.25801995198052, 
       21.65063509461097}, {57.258019951980515`, 24.148145657226706`}}, {{
       57.25801995198052, 21.65063509461097}, {60., 21.65063509461097}, {60., 
       17.67766952966369}, {57.25801995198052, 17.67766952966369}, {
       57.25801995198052, 21.65063509461097}}, {{57.25801995198052, 
       17.67766952966369}, {60., 17.67766952966369}, {60., 
       12.500000000000004`}, {57.25801995198052, 12.500000000000004`}, {
       57.25801995198052, 17.67766952966369}}, {{57.25801995198052, 
       12.500000000000004`}, {60., 12.500000000000004`}, {60., 
       6.470476127563024}, {57.25801995198052, 6.470476127563024}, {
       57.25801995198052, 12.500000000000004`}}, {{57.25801995198052, 
       6.470476127563024}, {60., 6.470476127563024}, {60., 
       7.0819236220599744`*^-15}, {57.25801995198052, 
       7.0819236220599744`*^-15}, {57.25801995198052, 6.470476127563024}}, {{
       57.25801995198052, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       57.25801995198052, -6.470476127563016}, {57.25801995198052, 
       1.5308084989341915`*^-15}}, {{57.25801995198052, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       57.25801995198052, -12.499999999999995`}, {
       57.25801995198052, -6.470476127563016}}, {{
       57.25801995198052, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       57.25801995198052, -17.677669529663685`}, {
       57.25801995198052, -12.499999999999995`}}, {{
       57.25801995198052, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       57.25801995198052, -21.65063509461097}, {
       57.25801995198052, -17.677669529663685`}}, {{
       57.25801995198052, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       57.25801995198052, -24.148145657226706`}, {
       57.25801995198052, -21.650635094610962`}}, {{
       57.25801995198052, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {57.25801995198052, -25.}, {
       57.25801995198052, -24.148145657226706`}}, {{
       57.25801995198052, -25.}, {60., -25.}, {60., -24.148145657226706`}, {
       57.258019951980515`, -24.148145657226706`}, {
       57.25801995198052, -25.}}, {{57.25801995198052, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       57.258019951980515`, -21.65063509461097}, {
       57.25801995198052, -24.14814565722671}}, {{
       57.258019951980515`, -21.65063509461097}, {60., -21.65063509461097}, {
       60., -17.677669529663692`}, {
       57.25801995198052, -17.677669529663692`}, {
       57.258019951980515`, -21.65063509461097}}, {{
       57.25801995198052, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       57.25801995198052, -12.50000000000001}, {
       57.25801995198052, -17.677669529663696`}}, {{
       57.25801995198052, -12.50000000000001}, {60., -12.50000000000001}, {
       60., -6.470476127563038}, {57.25801995198052, -6.470476127563038}, {
       57.25801995198052, -12.50000000000001}}, {{
       57.25801995198052, -6.470476127563038}, {60., -6.470476127563038}, {
       60., -2.6796885989305705`*^-14}, {
       57.25801995198052, -2.6796885989305705`*^-14}, {
       57.25801995198052, -6.470476127563038}}, {{
       57.25801995198052, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       57.25801995198052, 6.470476127563007}, {
       57.25801995198052, -4.592425496802574*^-15}}, {{57.25801995198052, 
       6.470476127563007}, {60., 6.470476127563007}, {60., 
       12.499999999999984`}, {57.25801995198052, 12.499999999999984`}, {
       57.25801995198052, 6.470476127563007}}, {{57.25801995198052, 
       12.499999999999984`}, {60., 12.499999999999984`}, {60., 
       17.67766952966367}, {57.25801995198052, 17.67766952966367}, {
       57.25801995198052, 12.499999999999984`}}, {{57.25801995198052, 
       17.677669529663685`}, {60., 17.677669529663685`}, {60., 
       21.65063509461096}, {57.258019951980515`, 21.65063509461096}, {
       57.25801995198052, 17.677669529663685`}}, {{57.258019951980515`, 
       21.65063509461096}, {60., 21.65063509461096}, {60., 
       24.148145657226703`}, {57.25801995198052, 24.148145657226703`}, {
       57.258019951980515`, 21.65063509461096}}, {{57.25801995198052, 
       24.148145657226703`}, {60., 24.148145657226703`}, {60., 25.}, {
       57.25801995198052, 25.}, {57.25801995198052, 24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}, {{150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150.,
        0.}, {150., 0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHkhwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAJP8g58=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJx1lwtUVVUax6+aAvkICZFAFFBAgdCpKXFE+RpTOYxuTEtrxtcI+ShLpsyQ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     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxdlX9cj+cax7+EiiRJfVeiH/qhWpw5U474Xo5Jd4dqMXEOcZRfY3QmllRK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      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367537190154*^9, 3.566086993031996*^9, 
  3.566101753482071*^9, 3.5661391982051497`*^9, 3.614707801541197*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->
  "During evaluation of \
In[53]:=",ExpressionUUID->"79dbe714-1168-4ff2-a903-f39e4fe98437"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.19824400000000000354738460828230017796`5.3177999652272785", 
   ",", "\<\"-traced system-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367537218192*^9, 3.566086993039508*^9, 
  3.566101753487461*^9, 3.5661391982417507`*^9, 3.614707801545744*^9},
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"},
 CellLabel->"Out[53]=",ExpressionUUID->"5c23b081-6025-46f9-8058-23f0ddb28122"]
}, Open  ]],

Cell[TextData[{
 "In addition to shorter computation times, ",
 StyleBox["TurboPlot", "Input"],
 " consumes far less memory than ",
 StyleBox["AnalyzeSystem", "Input"],
 ". In particular, the traced ray information is stored much more \
efficiently, by an order of magnitude in some cases, with ",
 StyleBox["TurboPlot", "Input"],
 "."
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"55aa0c10-0f2e-40e5-b147-d90827498dd5"],

Cell[TextData[{
 "Until now, the performance gains of ",
 StyleBox["TurboPlot", "Input"],
 " have been an order of magnitude better than ",
 StyleBox["AnalyzeSystem", "Input"],
 ". Next, we will introduce the ",
 StyleBox["CreateClones", "Input"],
 " option for modeling repetitive optical elements. In particular, with this \
option, we can obtain performance gains, in terms of both speed and memory, \
that are three orders in magnitude better than ",
 StyleBox["AnalyzeSystem", "Input"],
 "!"
}], "Text",
 CellTags->{
  "TurboPlot", "14.1", "RG14.", 
   "RG14.1"},ExpressionUUID->"d1849c45-2f29-4caa-9f87-63d7f316366a"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "TurboPlot", 
   "RG14."},ExpressionUUID->"43b79d3c-25d1-403a-95e3-08fa65c30a51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["CreateClones", "Input"]], "Subsection",
 CellTags->{
  "CreateClones", "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d"],

Cell[TextData[{
 "With ",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 ", ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " now has an enhanced capability for modeling repetitive optical elements. \
This feature is not present in ",
 StyleBox["AnalyzeSystem", "Input"],
 ", (although you can still display the results with ",
 StyleBox["ShowSystem", "Input"],
 " if you wish). This capability is managed with the ",
 StyleBox["CreateClones", "Input"],
 " option."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"a90ae5b6-7add-4130-878d-cf27bd3d377f"],

Cell[TextData[{
 StyleBox["CreateClones -> {{", "Input"],
 StyleBox["coordinates",
  FontSlant->"Italic"],
 ", ",
 StyleBox["rotationmatrix",
  FontSlant->"Italic"],
 ", ",
 StyleBox["componentnumber",
  FontSlant->"Italic"],
 ", ",
 StyleBox["scale",
  FontSlant->"Italic"],
 StyleBox["},", "Input"],
 " ...",
 StyleBox["}", "Input"],
 " specifies the placement of one or more phantom optical components to be \
used during the ray trace. These component aliases exhibit the ray-trace \
behavior of the original component members but do not consume additional \
computer memory. This permits the efficient nonsequential ray tracing of \
large arrays of optical elements."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "SymbolicValues", "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752"],

Cell[TextData[{
 StyleBox["CreateClones", "Input"],
 " accepts a wide range of data structures for managing different forms of \
repetitive elements. With the most general format of ",
 StyleBox["CreateClones", "Input"],
 ", it is possible to specify different three-dimensional ",
 StyleBox["coordinates",
  FontSlant->"Italic"],
 ", orientations (via ",
 StyleBox["rotationmatrix",
  FontSlant->"Italic"],
 "), and sizes (via ",
 StyleBox["scale",
  FontSlant->"Italic"],
 ") for every repeated element. In addition, you can specify a mixture of \
different components in ",
 StyleBox["CreateClones", "Input"],
 " (by passing the corresponding ",
 StyleBox["componentnumber",
  FontSlant->"Italic"],
 " of each template element",
 ").  For the purposes of this discussion, however, we will only demonstrate \
the simplest possible formulation for ",
 StyleBox["CreateClones", "Input"],
 ". In particular, we will specify the {x ,y} coordinates, for different \
clone positions, along the x and y dimensions of space and we will not alter \
the relative size or orientation of the cloned elements. As such, we need \
only to construct a list of two-dimensional positions for ",
 StyleBox["CreateClones", "Input"],
 ". Because no z coordinate is given, the resulting system will automatically \
use z=0 and bi-sect the x-y plane. However, you can also position your cloned \
elements in three-dimensions if you pass three-dimensional coordinates to ",
 StyleBox["CreateClones", "Input"],
 ". To generate a list of coordinates, we will use the ",
 StyleBox["Table", "Input"],
 " function of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". In addition, we will add a random perturbation to the coordinates with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s built-in ",
 StyleBox["Random", "Input"],
 " function."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"f2eb698c-dfad-4527-9f7b-106a2af4bfa3"],

Cell["\<\
positions = Apply[Join,
\tTable[
\t\t{Random[Real,{-.25,.25}]+x, Random[Real,{-.25,.25}]+y},
\t\t{x,-10,10,1},{y,-10,10,1}
\t]
];\
\>", "Input",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->"In[54]:=",ExpressionUUID->"3d9f37b8-a9c7-4b91-a648-ad87a2a1e908"],

Cell[TextData[{
 "Next, we use the ",
 StyleBox["ListPlot", "Input"],
 " function of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to examine the spatial distribution of coordinate points."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"d9110934-fde3-43cf-9643-be18578b550b"],

Cell["ListPlot[positions,AspectRatio->1];", "Input",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->"In[55]:=",ExpressionUUID->"1ecb9700-e924-4fa3-bdaf-531de38950d0"],

Cell[TextData[{
 "We will now use ",
 StyleBox["CreateClones", "Input"],
 " together with ",
 StyleBox["TurboPlot", "Input"],
 " to trace rays through a randomized array of spherical glass ball lenses. \
In order to model a ball lens in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", we will use the ",
 StyleBox["BallLens", "Input"],
 " component function."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"42dc2622-9471-42c3-a3f3-61f3f7d82508"],

Cell[TextData[{
 StyleBox["BallLens[", "Input"],
 StyleBox["diameter",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " denotes an entire spherical refractive component."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "BallLens", "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b"],

Cell[TextData[{
 "Finally, we trace the system with ",
 StyleBox["TurboPlot", "Input"],
 ". Here we use ",
 StyleBox["CreateClones->positions", "Input"],
 " to specify the spatial positions of the cloned lenses and the ",
 StyleBox["LineOfRays", "Input"],
 " function to generate the rays in the system."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"9242d2d5-8928-426b-b5ac-4a96ee390dbe"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{Move[LineOfRays[20,NumberOfRays->21],-12], BallLens[.6]},
\t\tCreateClones->positions, ShowClones->True, PlotType->TopView, 
\t\tRunningCommentary -> TurboTrace, ShowArrows->All];\
\>", "Input",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->"In[56]:=",ExpressionUUID->"eecc06bf-c7ed-45b9-a4f4-24ee8c6632e7"],

Cell[BoxData["\<\"RunningCommentary -> TurboTrace\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802244974*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"61a0f1ab-c69a-45ca-b951-868a02bace37"],

Cell[BoxData["\<\"Start TurboTrace.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802246853*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"b5d7340c-5ec3-4fe7-9d03-09cc88fbe637"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"SequentialTrace -> \"\>", "\[InvisibleSpace]", "False"}],
  SequenceForm["SequentialTrace -> ", False],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.61470780224823*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"2d34b417-9b1a-4ec2-9bbc-51a827395fef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"FilterTrace -> \"\>", "\[InvisibleSpace]", "True"}],
  SequenceForm["FilterTrace -> ", True],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078022542477`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"194685f5-51ca-400c-ac76-52d433b092e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{propsysopts, options} \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.067788441370517`"}], ",", 
            RowBox[{"-", "10.070268288620374`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.029266465077892`"}], ",", 
            RowBox[{"-", "9.116971210469123`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.248602154215964`"}], ",", 
            RowBox[{"-", "7.815151750681253`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.136665943451032`"}], ",", 
            RowBox[{"-", "7.1553909940415785`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.872527545912481`"}], ",", 
            RowBox[{"-", "6.016627036514356`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.942258051560092`"}], ",", 
            RowBox[{"-", "4.885860026189753`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.080430885052591`"}], ",", 
            RowBox[{"-", "3.750488978226729`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.162612637010305`"}], ",", 
            RowBox[{"-", "3.025087813260058`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.76170663192217`"}], ",", 
            RowBox[{"-", "2.169900704541826`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.771373613246904`"}], ",", 
            RowBox[{"-", "1.2433145939075423`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.104945011205247`"}], ",", 
            "0.0582591318748662`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.967929813486638`"}], ",", "0.8115566398550196`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.787156569834728`"}], ",", "1.8785274204952411`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.188663348408747`"}], ",", 
            "3.1785278503241425`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.788554415618766`"}], ",", "3.9436791711764947`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.801997404957715`"}], ",", "5.083918844365721`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.166026869706284`"}], ",", "6.21030620769085`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.109739353397623`"}], ",", "7.219778870555474`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.835595984653693`"}], ",", "8.21079518591758`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.197126716387318`"}], ",", "8.994866683815532`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.823889352731523`"}], ",", "10.130695890459405`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.175753103140414`"}], ",", 
            RowBox[{"-", "10.011818722276926`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.968944341526278`"}], ",", 
            RowBox[{"-", "9.177563241415461`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.957823289653774`"}], ",", 
            RowBox[{"-", "8.073375362131946`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.931787771691548`"}], ",", 
            RowBox[{"-", "6.8060906619107016`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.019159941245027`"}], ",", 
            RowBox[{"-", "6.001903212456088`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.893233356072784`"}], ",", 
            RowBox[{"-", "4.999769833087196`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.967162536287312`"}], ",", 
            RowBox[{"-", "3.8358220568218098`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.9772064863665`"}], ",", 
            RowBox[{"-", "2.9600760407780466`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.107423182889688`"}], ",", 
            RowBox[{"-", "1.8056009273772835`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.891610501712806`"}], ",", 
            RowBox[{"-", "0.9208712266956265`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.16029646650237`"}], ",", 
            RowBox[{"-", "0.0504676111928154`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.817721148981281`"}], ",", "1.198432882844968`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.234543363361958`"}], ",", "2.2113511110841104`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.098776807455005`"}], ",", "3.1259961242604284`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.026720073708182`"}], ",", "4.034726473216056`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.916989035763455`"}], ",", "5.18208678617113`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.757560132463155`"}], ",", "5.786629685672144`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.773755679690673`"}], ",", "6.931856619258327`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.040397596175842`"}], ",", "7.872451742493954`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.046549193324173`"}], ",", "9.141932660036373`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.182974413286153`"}], ",", "9.928052669871237`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.904938691611368`"}], ",", 
            RowBox[{"-", "10.187196113268`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.772677946783784`"}], ",", 
            RowBox[{"-", "8.771479718935947`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.837217542630086`"}], ",", 
            RowBox[{"-", "8.135628996112969`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.788134583421827`"}], ",", 
            RowBox[{"-", "7.232830830020058`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.9884407351750815`"}], ",", 
            RowBox[{"-", "6.011625120373396`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.011414509713644`"}], ",", 
            RowBox[{"-", "5.017557303236114`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.821451699411625`"}], ",", 
            RowBox[{"-", "3.9437119065445265`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.00385437725049`"}], ",", 
            RowBox[{"-", "3.054186988908258`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.797696019720953`"}], ",", 
            RowBox[{"-", "2.1255685258028536`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.213456781074647`"}], ",", 
            RowBox[{"-", "1.1766387314022118`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.001146826396779`"}], ",", 
            RowBox[{"-", "0.017501185839226996`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.780482367788494`"}], ",", "1.145308598726551`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.846208134785412`"}], ",", "1.919694927428773`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.75780442100471`"}], ",", "3.1667883176624985`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.758990592155326`"}], ",", "3.805323923541741`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.219669837582884`"}], ",", "5.149619147682556`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.020549856980244`"}], ",", "6.0669490439151375`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.95825532786924`"}], ",", "6.91717645091867`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.949098157568619`"}], ",", "7.760660950459664`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.20440095061875`"}], ",", "9.221363439826927`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.901402137847666`"}], ",", "10.136229476262518`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.240944169544102`"}], ",", 
            RowBox[{"-", "9.85199782877086`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.150255311450886`"}], ",", 
            RowBox[{"-", "9.096269337898256`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.210461801755607`"}], ",", 
            RowBox[{"-", "8.247306427497412`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.054047176665474`"}], ",", 
            RowBox[{"-", "6.765964265327028`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.202657380750897`"}], ",", 
            RowBox[{"-", "6.16409474515991`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.045056584510148`"}], ",", 
            RowBox[{"-", "4.8212881888687695`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.232987543168012`"}], ",", 
            RowBox[{"-", "4.0637138928424665`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.774506727529904`"}], ",", 
            RowBox[{"-", "3.1382372327839065`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.024732215298773`"}], ",", 
            RowBox[{"-", "2.2308903437611365`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.075408569961285`"}], ",", 
            RowBox[{"-", "1.1488981832435705`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.070331264680022`"}], ",", 
            RowBox[{"-", "0.2022537835880642`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.924006432113619`"}], ",", "0.964872340493912`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.079387095135921`"}], ",", "1.8997440451827963`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.023751120662733`"}], ",", "2.8111416783921674`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.118925293380313`"}], ",", "3.8970504726802075`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.21970394399726`"}], ",", "4.8271059437191965`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.166267912629416`"}], ",", "5.811145217840117`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.924647359487111`"}], ",", "6.898394132587965`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.183280369461404`"}], ",", "8.124859110682584`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.900140631957208`"}], ",", "8.786631365371871`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.908548154162632`"}], ",", "10.10574945444372`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.074732061995923`"}], ",", 
            RowBox[{"-", "9.814470451384558`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.0882168894826085`"}], ",", 
            RowBox[{"-", "8.941996761968216`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.900725629882303`"}], ",", 
            RowBox[{"-", "8.02934279187847`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.7588297943466875`"}], ",", 
            RowBox[{"-", "7.091740807151012`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.12697450921957`"}], ",", 
            RowBox[{"-", "6.090484470270637`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.889904500966375`"}], ",", 
            RowBox[{"-", "5.2387912798312195`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.15727056522231`"}], ",", 
            RowBox[{"-", "4.167590413989833`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.973636588336959`"}], ",", 
            RowBox[{"-", "2.7999364976713372`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.982623205735199`"}], ",", 
            RowBox[{"-", "1.8159845465777984`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.040356218875554`"}], ",", 
            RowBox[{"-", "1.174795608353921`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.832482573777991`"}], ",", 
            "0.14738408805032938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.8818080647129225`"}], ",", 
            "0.9694549372023589`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.007750511782069`"}], ",", "2.2118545394348867`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.043591175230314`"}], ",", "3.161451699170575`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.857024881899765`"}], ",", "3.991197331313356`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.0347613808836265`"}], ",", "5.003192506321587`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.980050372680195`"}], ",", "5.831681801583993`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.894856879917252`"}], ",", "6.991983786152806`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.072779807457884`"}], ",", "8.249272215573825`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.171220291580293`"}], ",", "9.041920283824144`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.840156601722685`"}], ",", "9.815256762151625`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.880864072704739`"}], ",", 
            RowBox[{"-", "10.033284107821935`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.757674027944693`"}], ",", 
            RowBox[{"-", "9.082127325898705`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.249056007991816`"}], ",", 
            RowBox[{"-", "7.752739045024295`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.999923516162625`"}], ",", 
            RowBox[{"-", "7.043981865333592`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.955464832761502`"}], ",", 
            RowBox[{"-", "6.164190744194869`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.892898634262861`"}], ",", 
            RowBox[{"-", "4.785179196646948`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.170703451877875`"}], ",", 
            RowBox[{"-", "3.9173832505164556`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.162848261582665`"}], ",", 
            RowBox[{"-", "2.8668609982309405`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.025846571960624`"}], ",", 
            RowBox[{"-", "2.159367036669262`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.840068454124782`"}], ",", 
            RowBox[{"-", "0.8661332138047662`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.104626280380331`"}], ",", 
            "0.04871267950659469`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.2499118524020965`"}], ",", 
            "1.0686100240436094`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.973762207675592`"}], ",", "1.83199678732853`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.242237824457403`"}], ",", "2.9007373499423146`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.9747061996837765`"}], ",", 
            "3.8347358323528242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.992314308294778`"}], ",", "5.194719215275906`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.769241366922275`"}], ",", "6.248926576547693`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.849415674031917`"}], ",", "7.2298984119228535`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.848537915044399`"}], ",", "7.916309827064149`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.936567412449252`"}], ",", "8.846759410153794`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.0726913430837755`"}], ",", "9.825676863733412`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.84649895832447`"}], ",", 
            RowBox[{"-", "10.03710737604144`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.218065062703444`"}], ",", 
            RowBox[{"-", "8.973035815773184`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.8465871059223735`"}], ",", 
            RowBox[{"-", "7.855717400085049`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.9943028550278523`"}], ",", 
            RowBox[{"-", "7.055032603101714`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.854349281464971`"}], ",", 
            RowBox[{"-", "6.0064547500273635`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.7695966553440763`"}], ",", 
            RowBox[{"-", "5.139768435454538`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.112034973170193`"}], ",", 
            RowBox[{"-", "3.9511739653032696`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.750355288421802`"}], ",", 
            RowBox[{"-", "3.138695012002232`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.012619299138276`"}], ",", 
            RowBox[{"-", "1.9310723772261231`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.151817373377403`"}], ",", 
            RowBox[{"-", "0.8050048390663809`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.826051886689025`"}], ",", 
            RowBox[{"-", "0.02783178737991715`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.8291260302936276`"}], ",", 
            "1.1193182972002083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.229552928364555`"}], ",", "1.7592755886615226`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.8610609675901832`"}], ",", 
            "2.8423541129733922`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.1329658224421815`"}], ",", 
            "3.8649929887465717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.116758112562331`"}], ",", "5.147386716075107`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.028616540977211`"}], ",", "6.121447738773935`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.097161457218254`"}], ",", "7.037155151529645`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.166581567807017`"}], ",", "7.822621704077205`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.096806168796452`"}], ",", "8.925850163531877`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.9039622686687414`"}], ",", 
            "10.003694081303328`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1949887954190497`"}], ",", 
            RowBox[{"-", "10.019144997401742`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.8279103819797164`"}], ",", 
            RowBox[{"-", "9.218474131316755`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.115862765125422`"}], ",", 
            RowBox[{"-", "7.888463294601951`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.8483574536151615`"}], ",", 
            RowBox[{"-", "7.227749719978277`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.004801797535239`"}], ",", 
            RowBox[{"-", "5.980817407575342`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.96539163117298`"}], ",", 
            RowBox[{"-", "4.842742708724849`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1380436849729083`"}], ",", 
            RowBox[{"-", "3.878204123650449`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1867750901957694`"}], ",", 
            RowBox[{"-", "3.2141904474987846`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.790882227754654`"}], ",", 
            RowBox[{"-", "2.1653592751800943`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.7701935223887517`"}], ",", 
            RowBox[{"-", "0.7868121515759894`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.944076058958202`"}], ",", 
            "0.15879056128802882`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1162312537200108`"}], ",", 
            "0.9594937671206825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.9990872635391526`"}], ",", "1.927935558689771`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.0383208717402943`"}], ",", "2.927967898437437`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1332244984137305`"}], ",", "4.066398853291721`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.939963418125133`"}], ",", "4.905717618415714`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.8784227008784917`"}], ",", 
            "5.7972162608670645`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.224571786952153`"}], ",", "6.998460327140564`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.9903790159055834`"}], ",", "7.925420384517514`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.7877966967563834`"}], ",", "8.962650774639348`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.949496788150929`"}], ",", "9.840779659697608`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7676031743676317`"}], ",", 
            RowBox[{"-", "10.000537073784662`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.755420729192727`"}], ",", 
            RowBox[{"-", "9.068010901590421`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9013719206476212`"}], ",", 
            RowBox[{"-", "8.210030840905345`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.0063334656535745`"}], ",", 
            RowBox[{"-", "7.245946460280192`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.113051048907327`"}], ",", 
            RowBox[{"-", "5.887998739342782`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.123108967239844`"}], ",", 
            RowBox[{"-", "5.062345313571914`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.923087630782194`"}], ",", 
            RowBox[{"-", "4.0437163577584965`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9946862663613525`"}], ",", 
            RowBox[{"-", "3.109561574438978`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9485158438300412`"}], ",", 
            RowBox[{"-", "1.7921766848990603`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7543072504557693`"}], ",", 
            RowBox[{"-", "0.7849819589564917`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9107191470736575`"}], ",", 
            RowBox[{"-", "0.004827459538408574`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.0548104623048404`"}], ",", 
            "1.1242383813459003`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.8931159727060258`"}], ",", 
            "2.2457096142462536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.0493897331121134`"}], ",", 
            "2.9422492829363214`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2417440520584044`"}], ",", "4.205740455151599`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7930562674585386`"}], ",", "4.938195743216513`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.8786930031510776`"}], ",", "5.84373919449438`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9199473002186944`"}], ",", 
            "6.7505410567884265`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2056053723688835`"}], ",", "8.137455552252877`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1752610338573417`"}], ",", "9.110102631227404`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.007089528538842`"}], ",", "10.179632237151937`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1709537834015726`"}], ",", 
            RowBox[{"-", "9.854915409816105`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8463703814651847`"}], ",", 
            RowBox[{"-", "9.065540303309655`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8661433210967322`"}], ",", 
            RowBox[{"-", "8.229153791162004`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.203254408759159`"}], ",", 
            RowBox[{"-", "7.061249917555908`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.066753587984619`"}], ",", 
            RowBox[{"-", "5.9214030740983254`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2115103567007544`"}], ",", 
            RowBox[{"-", "5.0169903727075065`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0236973205260804`"}], ",", 
            RowBox[{"-", "4.109598817314838`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0828173535496768`"}], ",", 
            RowBox[{"-", "3.110729567201887`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.853750020307386`"}], ",", 
            RowBox[{"-", "2.110139874103265`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1272119811807932`"}], ",", 
            RowBox[{"-", "0.9981851194547636`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.9284889864500441`"}], ",", 
            "0.029757494669330642`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8701224526419511`"}], ",", 
            "1.0721826433932993`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0075352030484714`"}], ",", 
            "2.1346729044854347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.7737520711767663`"}], ",", 
            "2.8877229467029535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8913918819517392`"}], ",", "4.113826695647439`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8204976624176072`"}], ",", "5.198972864258861`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0746382939671202`"}], ",", "5.785229769745764`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8589873057168529`"}], ",", "6.965963236966368`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.80094097344104`"}], ",", "8.144828587060603`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.026169952167176`"}], ",", "8.826692804168255`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.197190953133654`"}], ",", "10.004968461163868`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1489579709863827`"}], ",", 
            RowBox[{"-", "9.925122076376981`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.018701966683609905`"}], ",", 
            RowBox[{"-", "8.774789033505463`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.028835518344431654`"}], ",", 
            RowBox[{"-", "8.24730471977028`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.2388332363648616`", ",", 
            RowBox[{"-", "7.159461937990898`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.0050834471676653725`"}], ",", 
            RowBox[{"-", "5.885027666473235`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.11977488168339911`"}], ",", 
            RowBox[{"-", "5.023288633638336`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.0654142152499419`", ",", 
            RowBox[{"-", "3.8340005307320957`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.20486341228372118`", ",", 
            RowBox[{"-", "3.0585184033841006`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.1744015209667948`", ",", 
            RowBox[{"-", "2.0499637676984634`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2441956142752389`"}], ",", 
            RowBox[{"-", "0.9533469904447034`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.04942852686602922`"}], ",", 
            RowBox[{"-", "0.12665657186671792`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.2029953388584151`", ",", "0.7916845483914288`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.15047055587964653`"}], ",", 
            "2.048465504510264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.02830269445797501`"}], ",", 
            "2.816473581896892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.12836496246478513`", ",", "4.045770224280545`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.017135930822836626`"}], ",", 
            "5.2259355198877895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1165515903675495`"}], ",", "6.18079789075378`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.14736104913943754`"}], ",", 
            "6.999224153526125`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.06803419438250857`", ",", "7.764798421485875`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.10222446142315872`"}], ",", 
            "8.807742556910226`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.14363267341571379`", ",", "10.06476218918434`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.8919711528520802`", ",", 
            RowBox[{"-", "9.98891045264507`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.943061200281743`", ",", 
            RowBox[{"-", "9.058581238948943`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.938975813993665`", ",", 
            RowBox[{"-", "8.030595001036499`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.8435317561613895`", ",", 
            RowBox[{"-", "6.857046743459207`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2172785084516402`", ",", 
            RowBox[{"-", "6.097068582933391`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.9651667936966044`", ",", 
            RowBox[{"-", "5.152816967739752`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.9844144392744767`", ",", 
            RowBox[{"-", "4.07300410282118`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.831718384064154`", ",", 
            RowBox[{"-", "3.083614858493532`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.8817754884139142`", ",", 
            RowBox[{"-", "1.8222282563473053`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.0136841896816455`", ",", 
            RowBox[{"-", "1.0984132799794075`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2339999498370728`", ",", "0.12002918674246871`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.1200515162659315`", ",", "1.0868245308362534`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"1.0920287969849927`", ",", "1.8589396393875393`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.9269903159841886`", ",", "2.8954057697851963`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.9030529829913277`", ",", "4.1395346404240385`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.833458559822799`", ",", "5.002452513244403`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"0.9357744745396877`", ",", "5.986603223357429`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.1182917661261946`", ",", "6.905269480984155`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.201360035265211`", ",", "7.809607326178609`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.0365733820620406`", ",", "9.238884339477687`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.0695845468512966`", ",", "9.881835582525914`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.772889192380395`", ",", 
            RowBox[{"-", "9.912702380542905`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.0855845970142237`", ",", 
            RowBox[{"-", "8.988193604216555`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9028376761144636`", ",", 
            RowBox[{"-", "8.249526911379158`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.243555800029231`", ",", 
            RowBox[{"-", "7.097133243604093`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.225847360130275`", ",", 
            RowBox[{"-", "5.894932681164355`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.090502817037903`", ",", 
            RowBox[{"-", "4.986667884028131`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.142388800307476`", ",", 
            RowBox[{"-", "4.147385194408758`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9047283424982155`", ",", 
            RowBox[{"-", "3.2232711073855613`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.7740970341812814`", ",", 
            RowBox[{"-", "1.802654675392914`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9533683072330046`", ",", 
            RowBox[{"-", "0.7828784335641704`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9875236521192408`", ",", "0.20846098512939837`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.133783760381708`", ",", "1.085285983909915`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.9646344597388457`", ",", "1.8711633656723032`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"1.7981991633674843`", ",", "2.823479588126469`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.811796783624382`", ",", "3.8706902770514615`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.8046433633382535`", ",", "5.170612831730562`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.8359494234941072`", ",", "6.0156229582158165`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"1.9641405463003503`", ",", "6.907280715758694`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.9435606231866311`", ",", "7.913008152624575`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.8094122038021347`", ",", "8.880551823144256`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.9194635890053497`", ",", "9.96566282801749`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.10604389656913`", ",", 
            RowBox[{"-", "10.086569743291575`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.181939936886109`", ",", 
            RowBox[{"-", "8.99279815711191`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.222260136187422`", ",", 
            RowBox[{"-", "7.921855727201489`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.967305477147263`", ",", 
            RowBox[{"-", "7.113961522784213`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.174060972819938`", ",", 
            RowBox[{"-", "5.995335315327958`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.905508693522881`", ",", 
            RowBox[{"-", "5.2346517998356745`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.119417609481684`", ",", 
            RowBox[{"-", "3.9159481470585207`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.819559270028774`", ",", 
            RowBox[{"-", "3.000274758051491`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.9052770631813343`", ",", 
            RowBox[{"-", "2.0732288628172144`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.1259986468421426`", ",", 
            RowBox[{"-", "1.1632829106760658`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.8458648593791995`", ",", 
            RowBox[{"-", "0.20378068596146978`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.956535057836793`", ",", "1.1210542613064451`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"2.9898209628100694`", ",", "2.1327890573301045`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.0245951209506843`", ",", "2.8638524184183547`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.0175608266226472`", ",", "3.804644784531594`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"2.807289643803421`", ",", "5.227813941202567`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.0934998538027094`", ",", "6.049980099859552`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.15178095028054`", ",", "7.212465741038241`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.2240822443210253`", ",", "8.215928246918073`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.082221680251766`", ",", "8.962740499089733`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.068805181139691`", ",", "10.039157109735287`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.206223033409623`", ",", 
            RowBox[{"-", "10.123976590234202`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.9729403217604915`", ",", 
            RowBox[{"-", "9.007062204303242`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.9996879755728303`", ",", 
            RowBox[{"-", "7.995030851540647`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.233119358950423`", ",", 
            RowBox[{"-", "6.889851261633347`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.225092854622146`", ",", 
            RowBox[{"-", "6.1088832699590006`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.9655585323277753`", ",", 
            RowBox[{"-", "4.944496046164941`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.167803210818725`", ",", 
            RowBox[{"-", "4.086697211161568`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.1220586785250655`", ",", 
            RowBox[{"-", "3.2444761460244935`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.7660222605381852`", ",", 
            RowBox[{"-", "2.04916295219981`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.147976434204041`", ",", 
            RowBox[{"-", "1.2104043929425665`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.933800580286419`", ",", "0.2380965487104575`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.8291712530643496`", ",", "1.0004384973221458`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.9775775468767955`", ",", "2.112073138944659`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.106230931303857`", ",", "2.7575007016253887`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.227889571303965`", ",", "3.8571039904853053`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.1231115723534355`", ",", "4.8973519632587355`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.7527967166818197`", ",", "6.215987260444306`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.90755304002566`", ",", "7.091848009423677`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.8349935058630944`", ",", "8.052684471605874`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.035494361500595`", ",", "9.086324155448171`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.8189712453249096`", ",", "9.851847423805685`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.137517927296554`", ",", 
            RowBox[{"-", "9.953271451609263`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.1351706650384905`", ",", 
            RowBox[{"-", "9.136249124904774`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.0583466742322045`", ",", 
            RowBox[{"-", "8.203709948931408`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.907593118161695`", ",", 
            RowBox[{"-", "6.998322263849432`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.202115742928347`", ",", 
            RowBox[{"-", "6.211210650556797`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.929703546857729`", ",", 
            RowBox[{"-", "5.105426254334738`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.829004170574912`", ",", 
            RowBox[{"-", "3.858562613815533`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.92690683017591`", ",", 
            RowBox[{"-", "3.0714135147790436`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.171451130549252`", ",", 
            RowBox[{"-", "2.20041062323921`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.841913324312815`", ",", 
            RowBox[{"-", "0.8740979863849181`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.885956769048657`", ",", 
            RowBox[{"-", "0.03673477868738084`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.772942078987906`", ",", "1.0240545898093976`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.998438841752104`", ",", "2.166536672921882`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.887771413949415`", ",", "2.910303714714171`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.190092167519898`", ",", "4.1202466218532905`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.23017829578772`", ",", "5.158625978563602`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.237976424591552`", ",", "6.081457272410088`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.050474748929991`", ",", "7.01405223289834`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.15897225401664`", ",", "8.19001988622562`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.873567918754081`", ",", "8.835465747677384`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.237521123467388`", ",", "10.140430509464831`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.781654594441266`", ",", 
            RowBox[{"-", "10.040436265937698`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.101564354418731`", ",", 
            RowBox[{"-", "9.072834711847788`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.758712515453361`", ",", 
            RowBox[{"-", "7.814490855747096`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.853125512666628`", ",", 
            RowBox[{"-", "6.98937138476967`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.120941101503946`", ",", 
            RowBox[{"-", "5.974794570461267`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.913033345146729`", ",", 
            RowBox[{"-", "4.85961800662296`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.140762805716226`", ",", 
            RowBox[{"-", "3.883420549024869`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.9250569205551775`", ",", 
            RowBox[{"-", "3.1910752790330488`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.8402880567862345`", ",", 
            RowBox[{"-", "2.1474727819232093`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.0160846665385375`", ",", 
            RowBox[{"-", "1.1310951652586696`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.216720138032153`", ",", 
            RowBox[{"-", "0.2329385296005933`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.028563543071149`", ",", "0.9784743252764991`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.185065543590888`", ",", "2.0574977363371048`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.176999188652418`", ",", "2.801309037124287`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.176353028137527`", ",", "4.1219885920842`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.07387367598579`", ",", "5.040680421893957`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.805411926633582`", ",", "5.846783162545467`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.910840330839061`", ",", "7.150298428516917`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.914649120917356`", ",", "7.9802037115703355`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.235783410283884`", ",", "9.091373707549966`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.824361064131121`", ",", "9.877676493493546`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.969698743745346`", ",", 
            RowBox[{"-", "10.027531127191365`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.857640926098968`", ",", 
            RowBox[{"-", "9.13938497690586`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.191135200674197`", ",", 
            RowBox[{"-", "7.756005452467863`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.9225753825080805`", ",", 
            RowBox[{"-", "6.9468827132429665`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.76413601202178`", ",", 
            RowBox[{"-", "5.807314489592151`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.996222354370554`", ",", 
            RowBox[{"-", "4.818871305327167`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.94026233603599`", ",", 
            RowBox[{"-", "4.097994911486107`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.940810427736973`", ",", 
            RowBox[{"-", "2.915654467872633`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.7794220051969285`", ",", 
            RowBox[{"-", "1.9982933400030247`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.776161306819617`", ",", 
            RowBox[{"-", "1.145858179442969`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.793638594913045`", ",", "0.16033295244700957`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"7.2018002426884955`", ",", "1.2264653270634858`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"7.073939851167697`", ",", "1.9378640796383741`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.094159316589527`", ",", "3.115850303969347`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.1328046504935`", ",", "3.9438695321062376`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.921583934081446`", ",", "4.812733017212313`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.11866863847172`", ",", "6.001184021698388`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.175361579710892`", ",", "6.88160432253948`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.9284063024357305`", ",", "7.849178933184495`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.98455115197392`", ",", "9.047258790412112`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.898984297238802`", ",", "10.09747227318752`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.958389845154303`", ",", 
            RowBox[{"-", "10.056883030144919`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.855345702325758`", ",", 
            RowBox[{"-", "8.81286067925949`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.006589602465809`", ",", 
            RowBox[{"-", "8.033348357208403`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.03140585115806`", ",", 
            RowBox[{"-", "7.000724758897864`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.162430285876281`", ",", 
            RowBox[{"-", "5.899198661177751`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.14860120066456`", ",", 
            RowBox[{"-", "5.194594291004101`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.9908463517948345`", ",", 
            RowBox[{"-", "3.9619316783900644`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.7799325621928395`", ",", 
            RowBox[{"-", "2.9457783127024895`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.065484772083943`", ",", 
            RowBox[{"-", "2.093536000929544`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.10152625975711`", ",", 
            RowBox[{"-", "1.044957245886985`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.830933620110022`", ",", "0.1092052086583436`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.952541962518307`", ",", "1.1075704809254951`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.12254377495572`", ",", "1.916088238803262`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.847196260192549`", ",", "3.1704311601849846`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.865954172489911`", ",", "4.199436596011666`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.06579040903449`", ",", "4.921155919082849`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.953523886613629`", ",", "5.848635257189417`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.167189208369928`", ",", "6.86575021008695`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.212677534818795`", ",", "8.060566935579482`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.13725664617709`", ",", "9.06152852278944`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.897192762734853`", ",", "9.904102936509025`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.78573038641998`", ",", 
            RowBox[{"-", "10.143514231323577`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.81625914262483`", ",", 
            RowBox[{"-", "8.955102272149318`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.083188423901673`", ",", 
            RowBox[{"-", "8.001084712249071`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.943715367669112`", ",", 
            RowBox[{"-", "7.12119051095258`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.985992163709124`", ",", 
            RowBox[{"-", "5.921515872434056`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.8277611951792`", ",", 
            RowBox[{"-", "5.070627106964246`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.170201754674636`", ",", 
            RowBox[{"-", "4.092671791516905`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.12423730856557`", ",", 
            RowBox[{"-", "3.1692623641536635`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.753012546304706`", ",", 
            RowBox[{"-", "2.208422001603854`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.161559773746776`", ",", 
            RowBox[{"-", "0.979829299733145`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.865755900127617`", ",", 
            RowBox[{"-", "0.019950524393293173`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.014367011011924`", ",", "0.8660677637578298`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.830025513707637`", ",", "1.8735637069302828`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.948107868387092`", ",", "3.0711700359071483`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.996837089805965`", ",", "4.124648419179354`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.754392500717982`", ",", "4.942360546859729`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.760844926096839`", ",", "5.79616429161341`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.17663130553878`", ",", "6.762987653823975`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.840643171422204`", ",", "8.138836083130315`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.80239399697321`", ",", "9.182250017977639`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.837630625117496`", ",", "10.097258084734168`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.890834223226435`", ",", 
            RowBox[{"-", "10.087920682289216`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.22187472498988`", ",", 
            RowBox[{"-", "9.132791390872539`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.12646721221451`", ",", 
            RowBox[{"-", "8.203988446047047`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.141849211282242`", ",", 
            RowBox[{"-", "6.756355097802821`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.928359343827418`", ",", 
            RowBox[{"-", "6.025158481954195`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.895012121476277`", ",", 
            RowBox[{"-", "5.131003516982175`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.923966843109437`", ",", 
            RowBox[{"-", "4.217519028813923`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.884167195379437`", ",", 
            RowBox[{"-", "3.1771678085955855`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.997335537570656`", ",", 
            RowBox[{"-", "2.2305066826378983`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.793524023957234`", ",", 
            RowBox[{"-", "1.0660038917259`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.944941540597444`", ",", 
            RowBox[{"-", "0.1627567006155366`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.205893398839736`", ",", "1.0867380235399313`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"9.804107317371011`", ",", "2.17516398167368`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.234018673849858`", ",", "2.9695294144124693`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"9.927640105156499`", ",", "4.129152427720726`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.842169462567616`", ",", "4.97588451221529`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.249280761329082`", ",", "5.904310909674921`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.197157341091339`", ",", "6.856888029197466`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.075313918219646`", ",", "7.871829938488844`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.062990145711902`", ",", "8.784055837793051`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.82797838064899`", ",", "9.852336621126742`"}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"ShowArrows", "\[Rule]", "All"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Messages", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"WaveFrontID", "\[Rule]", "False"}], ",", 
       RowBox[{"MemoryConstrained", "\[Rule]", "False"}], ",", 
       RowBox[{"RayLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"QuickSurfaceSort", "\[Rule]", "False"}], ",", 
       RowBox[{"UpdateNumericParameters", "\[Rule]", "Automatic"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"SymbolicValues", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ReportedSurfaces", "\[Rule]", "All"}], ",", 
       RowBox[{"OutputType", "\[Rule]", "TurboSystem"}], ",", 
       RowBox[{"CreateClones", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.067788441370517`"}], ",", 
            RowBox[{"-", "10.070268288620374`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.029266465077892`"}], ",", 
            RowBox[{"-", "9.116971210469123`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.248602154215964`"}], ",", 
            RowBox[{"-", "7.815151750681253`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.136665943451032`"}], ",", 
            RowBox[{"-", "7.1553909940415785`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.872527545912481`"}], ",", 
            RowBox[{"-", "6.016627036514356`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.942258051560092`"}], ",", 
            RowBox[{"-", "4.885860026189753`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.080430885052591`"}], ",", 
            RowBox[{"-", "3.750488978226729`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.162612637010305`"}], ",", 
            RowBox[{"-", "3.025087813260058`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.76170663192217`"}], ",", 
            RowBox[{"-", "2.169900704541826`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.771373613246904`"}], ",", 
            RowBox[{"-", "1.2433145939075423`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.104945011205247`"}], ",", 
            "0.0582591318748662`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.967929813486638`"}], ",", "0.8115566398550196`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.787156569834728`"}], ",", "1.8785274204952411`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.188663348408747`"}], ",", 
            "3.1785278503241425`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.788554415618766`"}], ",", "3.9436791711764947`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.801997404957715`"}], ",", "5.083918844365721`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.166026869706284`"}], ",", "6.21030620769085`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.109739353397623`"}], ",", "7.219778870555474`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.835595984653693`"}], ",", "8.21079518591758`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "10.197126716387318`"}], ",", "8.994866683815532`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.823889352731523`"}], ",", "10.130695890459405`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.175753103140414`"}], ",", 
            RowBox[{"-", "10.011818722276926`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.968944341526278`"}], ",", 
            RowBox[{"-", "9.177563241415461`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.957823289653774`"}], ",", 
            RowBox[{"-", "8.073375362131946`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.931787771691548`"}], ",", 
            RowBox[{"-", "6.8060906619107016`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.019159941245027`"}], ",", 
            RowBox[{"-", "6.001903212456088`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.893233356072784`"}], ",", 
            RowBox[{"-", "4.999769833087196`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.967162536287312`"}], ",", 
            RowBox[{"-", "3.8358220568218098`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.9772064863665`"}], ",", 
            RowBox[{"-", "2.9600760407780466`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.107423182889688`"}], ",", 
            RowBox[{"-", "1.8056009273772835`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.891610501712806`"}], ",", 
            RowBox[{"-", "0.9208712266956265`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.16029646650237`"}], ",", 
            RowBox[{"-", "0.0504676111928154`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.817721148981281`"}], ",", "1.198432882844968`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.234543363361958`"}], ",", "2.2113511110841104`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.098776807455005`"}], ",", "3.1259961242604284`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.026720073708182`"}], ",", "4.034726473216056`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.916989035763455`"}], ",", "5.18208678617113`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.757560132463155`"}], ",", "5.786629685672144`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.773755679690673`"}], ",", "6.931856619258327`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.040397596175842`"}], ",", "7.872451742493954`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.046549193324173`"}], ",", "9.141932660036373`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "9.182974413286153`"}], ",", "9.928052669871237`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.904938691611368`"}], ",", 
            RowBox[{"-", "10.187196113268`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.772677946783784`"}], ",", 
            RowBox[{"-", "8.771479718935947`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.837217542630086`"}], ",", 
            RowBox[{"-", "8.135628996112969`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.788134583421827`"}], ",", 
            RowBox[{"-", "7.232830830020058`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.9884407351750815`"}], ",", 
            RowBox[{"-", "6.011625120373396`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.011414509713644`"}], ",", 
            RowBox[{"-", "5.017557303236114`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.821451699411625`"}], ",", 
            RowBox[{"-", "3.9437119065445265`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.00385437725049`"}], ",", 
            RowBox[{"-", "3.054186988908258`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.797696019720953`"}], ",", 
            RowBox[{"-", "2.1255685258028536`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.213456781074647`"}], ",", 
            RowBox[{"-", "1.1766387314022118`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.001146826396779`"}], ",", 
            RowBox[{"-", "0.017501185839226996`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.780482367788494`"}], ",", "1.145308598726551`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.846208134785412`"}], ",", "1.919694927428773`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.75780442100471`"}], ",", "3.1667883176624985`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.758990592155326`"}], ",", "3.805323923541741`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.219669837582884`"}], ",", "5.149619147682556`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.020549856980244`"}], ",", "6.0669490439151375`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.95825532786924`"}], ",", "6.91717645091867`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.949098157568619`"}], ",", "7.760660950459664`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8.20440095061875`"}], ",", "9.221363439826927`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.901402137847666`"}], ",", "10.136229476262518`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.240944169544102`"}], ",", 
            RowBox[{"-", "9.85199782877086`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.150255311450886`"}], ",", 
            RowBox[{"-", "9.096269337898256`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.210461801755607`"}], ",", 
            RowBox[{"-", "8.247306427497412`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.054047176665474`"}], ",", 
            RowBox[{"-", "6.765964265327028`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.202657380750897`"}], ",", 
            RowBox[{"-", "6.16409474515991`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.045056584510148`"}], ",", 
            RowBox[{"-", "4.8212881888687695`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.232987543168012`"}], ",", 
            RowBox[{"-", "4.0637138928424665`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.774506727529904`"}], ",", 
            RowBox[{"-", "3.1382372327839065`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.024732215298773`"}], ",", 
            RowBox[{"-", "2.2308903437611365`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.075408569961285`"}], ",", 
            RowBox[{"-", "1.1488981832435705`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.070331264680022`"}], ",", 
            RowBox[{"-", "0.2022537835880642`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.924006432113619`"}], ",", "0.964872340493912`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.079387095135921`"}], ",", "1.8997440451827963`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.023751120662733`"}], ",", "2.8111416783921674`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.118925293380313`"}], ",", "3.8970504726802075`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.21970394399726`"}], ",", "4.8271059437191965`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.166267912629416`"}], ",", "5.811145217840117`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.924647359487111`"}], ",", "6.898394132587965`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "7.183280369461404`"}], ",", "8.124859110682584`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.900140631957208`"}], ",", "8.786631365371871`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.908548154162632`"}], ",", "10.10574945444372`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.074732061995923`"}], ",", 
            RowBox[{"-", "9.814470451384558`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.0882168894826085`"}], ",", 
            RowBox[{"-", "8.941996761968216`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.900725629882303`"}], ",", 
            RowBox[{"-", "8.02934279187847`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.7588297943466875`"}], ",", 
            RowBox[{"-", "7.091740807151012`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.12697450921957`"}], ",", 
            RowBox[{"-", "6.090484470270637`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.889904500966375`"}], ",", 
            RowBox[{"-", "5.2387912798312195`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.15727056522231`"}], ",", 
            RowBox[{"-", "4.167590413989833`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.973636588336959`"}], ",", 
            RowBox[{"-", "2.7999364976713372`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.982623205735199`"}], ",", 
            RowBox[{"-", "1.8159845465777984`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.040356218875554`"}], ",", 
            RowBox[{"-", "1.174795608353921`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.832482573777991`"}], ",", 
            "0.14738408805032938`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.8818080647129225`"}], ",", 
            "0.9694549372023589`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.007750511782069`"}], ",", "2.2118545394348867`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.043591175230314`"}], ",", "3.161451699170575`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.857024881899765`"}], ",", "3.991197331313356`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.0347613808836265`"}], ",", "5.003192506321587`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.980050372680195`"}], ",", "5.831681801583993`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.894856879917252`"}], ",", "6.991983786152806`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.072779807457884`"}], ",", "8.249272215573825`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "6.171220291580293`"}], ",", "9.041920283824144`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.840156601722685`"}], ",", "9.815256762151625`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.880864072704739`"}], ",", 
            RowBox[{"-", "10.033284107821935`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.757674027944693`"}], ",", 
            RowBox[{"-", "9.082127325898705`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.249056007991816`"}], ",", 
            RowBox[{"-", "7.752739045024295`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.999923516162625`"}], ",", 
            RowBox[{"-", "7.043981865333592`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.955464832761502`"}], ",", 
            RowBox[{"-", "6.164190744194869`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.892898634262861`"}], ",", 
            RowBox[{"-", "4.785179196646948`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.170703451877875`"}], ",", 
            RowBox[{"-", "3.9173832505164556`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.162848261582665`"}], ",", 
            RowBox[{"-", "2.8668609982309405`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.025846571960624`"}], ",", 
            RowBox[{"-", "2.159367036669262`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.840068454124782`"}], ",", 
            RowBox[{"-", "0.8661332138047662`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.104626280380331`"}], ",", 
            "0.04871267950659469`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.2499118524020965`"}], ",", 
            "1.0686100240436094`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.973762207675592`"}], ",", "1.83199678732853`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.242237824457403`"}], ",", "2.9007373499423146`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.9747061996837765`"}], ",", 
            "3.8347358323528242`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.992314308294778`"}], ",", "5.194719215275906`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.769241366922275`"}], ",", "6.248926576547693`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.849415674031917`"}], ",", "7.2298984119228535`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.848537915044399`"}], ",", "7.916309827064149`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.936567412449252`"}], ",", "8.846759410153794`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "5.0726913430837755`"}], ",", "9.825676863733412`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.84649895832447`"}], ",", 
            RowBox[{"-", "10.03710737604144`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.218065062703444`"}], ",", 
            RowBox[{"-", "8.973035815773184`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.8465871059223735`"}], ",", 
            RowBox[{"-", "7.855717400085049`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.9943028550278523`"}], ",", 
            RowBox[{"-", "7.055032603101714`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.854349281464971`"}], ",", 
            RowBox[{"-", "6.0064547500273635`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.7695966553440763`"}], ",", 
            RowBox[{"-", "5.139768435454538`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.112034973170193`"}], ",", 
            RowBox[{"-", "3.9511739653032696`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.750355288421802`"}], ",", 
            RowBox[{"-", "3.138695012002232`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.012619299138276`"}], ",", 
            RowBox[{"-", "1.9310723772261231`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.151817373377403`"}], ",", 
            RowBox[{"-", "0.8050048390663809`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.826051886689025`"}], ",", 
            RowBox[{"-", "0.02783178737991715`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.8291260302936276`"}], ",", 
            "1.1193182972002083`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.229552928364555`"}], ",", "1.7592755886615226`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.8610609675901832`"}], ",", 
            "2.8423541129733922`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.1329658224421815`"}], ",", 
            "3.8649929887465717`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.116758112562331`"}], ",", "5.147386716075107`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.028616540977211`"}], ",", "6.121447738773935`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.097161457218254`"}], ",", "7.037155151529645`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.166581567807017`"}], ",", "7.822621704077205`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "4.096806168796452`"}], ",", "8.925850163531877`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.9039622686687414`"}], ",", 
            "10.003694081303328`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1949887954190497`"}], ",", 
            RowBox[{"-", "10.019144997401742`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.8279103819797164`"}], ",", 
            RowBox[{"-", "9.218474131316755`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.115862765125422`"}], ",", 
            RowBox[{"-", "7.888463294601951`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.8483574536151615`"}], ",", 
            RowBox[{"-", "7.227749719978277`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.004801797535239`"}], ",", 
            RowBox[{"-", "5.980817407575342`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.96539163117298`"}], ",", 
            RowBox[{"-", "4.842742708724849`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1380436849729083`"}], ",", 
            RowBox[{"-", "3.878204123650449`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1867750901957694`"}], ",", 
            RowBox[{"-", "3.2141904474987846`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.790882227754654`"}], ",", 
            RowBox[{"-", "2.1653592751800943`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.7701935223887517`"}], ",", 
            RowBox[{"-", "0.7868121515759894`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.944076058958202`"}], ",", 
            "0.15879056128802882`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1162312537200108`"}], ",", 
            "0.9594937671206825`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.9990872635391526`"}], ",", "1.927935558689771`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.0383208717402943`"}], ",", "2.927967898437437`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.1332244984137305`"}], ",", "4.066398853291721`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.939963418125133`"}], ",", "4.905717618415714`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.8784227008784917`"}], ",", 
            "5.7972162608670645`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "3.224571786952153`"}], ",", "6.998460327140564`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.9903790159055834`"}], ",", "7.925420384517514`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.7877966967563834`"}], ",", "8.962650774639348`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.949496788150929`"}], ",", "9.840779659697608`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7676031743676317`"}], ",", 
            RowBox[{"-", "10.000537073784662`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.755420729192727`"}], ",", 
            RowBox[{"-", "9.068010901590421`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9013719206476212`"}], ",", 
            RowBox[{"-", "8.210030840905345`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.0063334656535745`"}], ",", 
            RowBox[{"-", "7.245946460280192`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.113051048907327`"}], ",", 
            RowBox[{"-", "5.887998739342782`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.123108967239844`"}], ",", 
            RowBox[{"-", "5.062345313571914`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.923087630782194`"}], ",", 
            RowBox[{"-", "4.0437163577584965`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9946862663613525`"}], ",", 
            RowBox[{"-", "3.109561574438978`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9485158438300412`"}], ",", 
            RowBox[{"-", "1.7921766848990603`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7543072504557693`"}], ",", 
            RowBox[{"-", "0.7849819589564917`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9107191470736575`"}], ",", 
            RowBox[{"-", "0.004827459538408574`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.0548104623048404`"}], ",", 
            "1.1242383813459003`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.8931159727060258`"}], ",", 
            "2.2457096142462536`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.0493897331121134`"}], ",", 
            "2.9422492829363214`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2417440520584044`"}], ",", "4.205740455151599`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.7930562674585386`"}], ",", "4.938195743216513`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.8786930031510776`"}], ",", "5.84373919449438`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.9199473002186944`"}], ",", 
            "6.7505410567884265`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.2056053723688835`"}], ",", "8.137455552252877`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.1752610338573417`"}], ",", "9.110102631227404`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "2.007089528538842`"}], ",", "10.179632237151937`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1709537834015726`"}], ",", 
            RowBox[{"-", "9.854915409816105`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8463703814651847`"}], ",", 
            RowBox[{"-", "9.065540303309655`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8661433210967322`"}], ",", 
            RowBox[{"-", "8.229153791162004`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.203254408759159`"}], ",", 
            RowBox[{"-", "7.061249917555908`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.066753587984619`"}], ",", 
            RowBox[{"-", "5.9214030740983254`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.2115103567007544`"}], ",", 
            RowBox[{"-", "5.0169903727075065`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0236973205260804`"}], ",", 
            RowBox[{"-", "4.109598817314838`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0828173535496768`"}], ",", 
            RowBox[{"-", "3.110729567201887`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.853750020307386`"}], ",", 
            RowBox[{"-", "2.110139874103265`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.1272119811807932`"}], ",", 
            RowBox[{"-", "0.9981851194547636`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.9284889864500441`"}], ",", 
            "0.029757494669330642`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8701224526419511`"}], ",", 
            "1.0721826433932993`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0075352030484714`"}], ",", 
            "2.1346729044854347`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.7737520711767663`"}], ",", 
            "2.8877229467029535`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8913918819517392`"}], ",", "4.113826695647439`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8204976624176072`"}], ",", "5.198972864258861`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.0746382939671202`"}], ",", "5.785229769745764`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8589873057168529`"}], ",", "6.965963236966368`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.80094097344104`"}], ",", "8.144828587060603`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.026169952167176`"}], ",", "8.826692804168255`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1.197190953133654`"}], ",", "10.004968461163868`"}],
            "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1489579709863827`"}], ",", 
            RowBox[{"-", "9.925122076376981`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.018701966683609905`"}], ",", 
            RowBox[{"-", "8.774789033505463`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.028835518344431654`"}], ",", 
            RowBox[{"-", "8.24730471977028`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.2388332363648616`", ",", 
            RowBox[{"-", "7.159461937990898`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.0050834471676653725`"}], ",", 
            RowBox[{"-", "5.885027666473235`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.11977488168339911`"}], ",", 
            RowBox[{"-", "5.023288633638336`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.0654142152499419`", ",", 
            RowBox[{"-", "3.8340005307320957`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.20486341228372118`", ",", 
            RowBox[{"-", "3.0585184033841006`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.1744015209667948`", ",", 
            RowBox[{"-", "2.0499637676984634`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.2441956142752389`"}], ",", 
            RowBox[{"-", "0.9533469904447034`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.04942852686602922`"}], ",", 
            RowBox[{"-", "0.12665657186671792`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.2029953388584151`", ",", "0.7916845483914288`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.15047055587964653`"}], ",", 
            "2.048465504510264`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.02830269445797501`"}], ",", 
            "2.816473581896892`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.12836496246478513`", ",", "4.045770224280545`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.017135930822836626`"}], ",", 
            "5.2259355198877895`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1165515903675495`"}], ",", "6.18079789075378`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.14736104913943754`"}], ",", 
            "6.999224153526125`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.06803419438250857`", ",", "7.764798421485875`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.10222446142315872`"}], ",", 
            "8.807742556910226`"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.14363267341571379`", ",", "10.06476218918434`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.8919711528520802`", ",", 
            RowBox[{"-", "9.98891045264507`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.943061200281743`", ",", 
            RowBox[{"-", "9.058581238948943`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.938975813993665`", ",", 
            RowBox[{"-", "8.030595001036499`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.8435317561613895`", ",", 
            RowBox[{"-", "6.857046743459207`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2172785084516402`", ",", 
            RowBox[{"-", "6.097068582933391`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.9651667936966044`", ",", 
            RowBox[{"-", "5.152816967739752`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.9844144392744767`", ",", 
            RowBox[{"-", "4.07300410282118`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.831718384064154`", ",", 
            RowBox[{"-", "3.083614858493532`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.8817754884139142`", ",", 
            RowBox[{"-", "1.8222282563473053`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.0136841896816455`", ",", 
            RowBox[{"-", "1.0984132799794075`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.2339999498370728`", ",", "0.12002918674246871`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.1200515162659315`", ",", "1.0868245308362534`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"1.0920287969849927`", ",", "1.8589396393875393`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.9269903159841886`", ",", "2.8954057697851963`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.9030529829913277`", ",", "4.1395346404240385`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0.833458559822799`", ",", "5.002452513244403`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"0.9357744745396877`", ",", "5.986603223357429`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.1182917661261946`", ",", "6.905269480984155`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.201360035265211`", ",", "7.809607326178609`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.0365733820620406`", ",", "9.238884339477687`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.0695845468512966`", ",", "9.881835582525914`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.772889192380395`", ",", 
            RowBox[{"-", "9.912702380542905`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.0855845970142237`", ",", 
            RowBox[{"-", "8.988193604216555`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9028376761144636`", ",", 
            RowBox[{"-", "8.249526911379158`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.243555800029231`", ",", 
            RowBox[{"-", "7.097133243604093`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.225847360130275`", ",", 
            RowBox[{"-", "5.894932681164355`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.090502817037903`", ",", 
            RowBox[{"-", "4.986667884028131`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.142388800307476`", ",", 
            RowBox[{"-", "4.147385194408758`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9047283424982155`", ",", 
            RowBox[{"-", "3.2232711073855613`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.7740970341812814`", ",", 
            RowBox[{"-", "1.802654675392914`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9533683072330046`", ",", 
            RowBox[{"-", "0.7828784335641704`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1.9875236521192408`", ",", "0.20846098512939837`"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.133783760381708`", ",", "1.085285983909915`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.9646344597388457`", ",", "1.8711633656723032`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"1.7981991633674843`", ",", "2.823479588126469`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.811796783624382`", ",", "3.8706902770514615`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.8046433633382535`", ",", "5.170612831730562`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.8359494234941072`", ",", "6.0156229582158165`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"1.9641405463003503`", ",", "6.907280715758694`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.9435606231866311`", ",", "7.913008152624575`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.8094122038021347`", ",", "8.880551823144256`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1.9194635890053497`", ",", "9.96566282801749`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.10604389656913`", ",", 
            RowBox[{"-", "10.086569743291575`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.181939936886109`", ",", 
            RowBox[{"-", "8.99279815711191`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.222260136187422`", ",", 
            RowBox[{"-", "7.921855727201489`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.967305477147263`", ",", 
            RowBox[{"-", "7.113961522784213`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.174060972819938`", ",", 
            RowBox[{"-", "5.995335315327958`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.905508693522881`", ",", 
            RowBox[{"-", "5.2346517998356745`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.119417609481684`", ",", 
            RowBox[{"-", "3.9159481470585207`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.819559270028774`", ",", 
            RowBox[{"-", "3.000274758051491`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.9052770631813343`", ",", 
            RowBox[{"-", "2.0732288628172144`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.1259986468421426`", ",", 
            RowBox[{"-", "1.1632829106760658`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.8458648593791995`", ",", 
            RowBox[{"-", "0.20378068596146978`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"2.956535057836793`", ",", "1.1210542613064451`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"2.9898209628100694`", ",", "2.1327890573301045`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.0245951209506843`", ",", "2.8638524184183547`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.0175608266226472`", ",", "3.804644784531594`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"2.807289643803421`", ",", "5.227813941202567`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.0934998538027094`", ",", "6.049980099859552`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.15178095028054`", ",", "7.212465741038241`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.2240822443210253`", ",", "8.215928246918073`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.082221680251766`", ",", "8.962740499089733`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.068805181139691`", ",", "10.039157109735287`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.206223033409623`", ",", 
            RowBox[{"-", "10.123976590234202`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.9729403217604915`", ",", 
            RowBox[{"-", "9.007062204303242`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.9996879755728303`", ",", 
            RowBox[{"-", "7.995030851540647`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.233119358950423`", ",", 
            RowBox[{"-", "6.889851261633347`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.225092854622146`", ",", 
            RowBox[{"-", "6.1088832699590006`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.9655585323277753`", ",", 
            RowBox[{"-", "4.944496046164941`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.167803210818725`", ",", 
            RowBox[{"-", "4.086697211161568`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.1220586785250655`", ",", 
            RowBox[{"-", "3.2444761460244935`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.7660222605381852`", ",", 
            RowBox[{"-", "2.04916295219981`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.147976434204041`", ",", 
            RowBox[{"-", "1.2104043929425665`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"3.933800580286419`", ",", "0.2380965487104575`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.8291712530643496`", ",", "1.0004384973221458`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.9775775468767955`", ",", "2.112073138944659`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.106230931303857`", ",", "2.7575007016253887`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.227889571303965`", ",", "3.8571039904853053`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.1231115723534355`", ",", "4.8973519632587355`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"3.7527967166818197`", ",", "6.215987260444306`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.90755304002566`", ",", "7.091848009423677`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.8349935058630944`", ",", "8.052684471605874`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.035494361500595`", ",", "9.086324155448171`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"3.8189712453249096`", ",", "9.851847423805685`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.137517927296554`", ",", 
            RowBox[{"-", "9.953271451609263`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.1351706650384905`", ",", 
            RowBox[{"-", "9.136249124904774`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.0583466742322045`", ",", 
            RowBox[{"-", "8.203709948931408`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.907593118161695`", ",", 
            RowBox[{"-", "6.998322263849432`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.202115742928347`", ",", 
            RowBox[{"-", "6.211210650556797`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.929703546857729`", ",", 
            RowBox[{"-", "5.105426254334738`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.829004170574912`", ",", 
            RowBox[{"-", "3.858562613815533`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.92690683017591`", ",", 
            RowBox[{"-", "3.0714135147790436`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.171451130549252`", ",", 
            RowBox[{"-", "2.20041062323921`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.841913324312815`", ",", 
            RowBox[{"-", "0.8740979863849181`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.885956769048657`", ",", 
            RowBox[{"-", "0.03673477868738084`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"4.772942078987906`", ",", "1.0240545898093976`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.998438841752104`", ",", "2.166536672921882`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.887771413949415`", ",", "2.910303714714171`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.190092167519898`", ",", "4.1202466218532905`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.23017829578772`", ",", "5.158625978563602`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.237976424591552`", ",", "6.081457272410088`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.050474748929991`", ",", "7.01405223289834`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.15897225401664`", ",", "8.19001988622562`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"4.873567918754081`", ",", "8.835465747677384`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.237521123467388`", ",", "10.140430509464831`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.781654594441266`", ",", 
            RowBox[{"-", "10.040436265937698`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.101564354418731`", ",", 
            RowBox[{"-", "9.072834711847788`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.758712515453361`", ",", 
            RowBox[{"-", "7.814490855747096`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.853125512666628`", ",", 
            RowBox[{"-", "6.98937138476967`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.120941101503946`", ",", 
            RowBox[{"-", "5.974794570461267`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.913033345146729`", ",", 
            RowBox[{"-", "4.85961800662296`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.140762805716226`", ",", 
            RowBox[{"-", "3.883420549024869`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.9250569205551775`", ",", 
            RowBox[{"-", "3.1910752790330488`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"5.8402880567862345`", ",", 
            RowBox[{"-", "2.1474727819232093`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.0160846665385375`", ",", 
            RowBox[{"-", "1.1310951652586696`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.216720138032153`", ",", 
            RowBox[{"-", "0.2329385296005933`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.028563543071149`", ",", "0.9784743252764991`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.185065543590888`", ",", "2.0574977363371048`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.176999188652418`", ",", "2.801309037124287`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.176353028137527`", ",", "4.1219885920842`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.07387367598579`", ",", "5.040680421893957`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.805411926633582`", ",", "5.846783162545467`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.910840330839061`", ",", "7.150298428516917`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.914649120917356`", ",", "7.9802037115703355`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.235783410283884`", ",", "9.091373707549966`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"5.824361064131121`", ",", "9.877676493493546`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.969698743745346`", ",", 
            RowBox[{"-", "10.027531127191365`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.857640926098968`", ",", 
            RowBox[{"-", "9.13938497690586`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.191135200674197`", ",", 
            RowBox[{"-", "7.756005452467863`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.9225753825080805`", ",", 
            RowBox[{"-", "6.9468827132429665`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.76413601202178`", ",", 
            RowBox[{"-", "5.807314489592151`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.996222354370554`", ",", 
            RowBox[{"-", "4.818871305327167`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.94026233603599`", ",", 
            RowBox[{"-", "4.097994911486107`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.940810427736973`", ",", 
            RowBox[{"-", "2.915654467872633`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.7794220051969285`", ",", 
            RowBox[{"-", "1.9982933400030247`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.776161306819617`", ",", 
            RowBox[{"-", "1.145858179442969`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"6.793638594913045`", ",", "0.16033295244700957`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"7.2018002426884955`", ",", "1.2264653270634858`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"7.073939851167697`", ",", "1.9378640796383741`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.094159316589527`", ",", "3.115850303969347`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.1328046504935`", ",", "3.9438695321062376`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.921583934081446`", ",", "4.812733017212313`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.11866863847172`", ",", "6.001184021698388`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.175361579710892`", ",", "6.88160432253948`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.9284063024357305`", ",", "7.849178933184495`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.98455115197392`", ",", "9.047258790412112`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"6.898984297238802`", ",", "10.09747227318752`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.958389845154303`", ",", 
            RowBox[{"-", "10.056883030144919`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.855345702325758`", ",", 
            RowBox[{"-", "8.81286067925949`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.006589602465809`", ",", 
            RowBox[{"-", "8.033348357208403`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.03140585115806`", ",", 
            RowBox[{"-", "7.000724758897864`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.162430285876281`", ",", 
            RowBox[{"-", "5.899198661177751`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.14860120066456`", ",", 
            RowBox[{"-", "5.194594291004101`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.9908463517948345`", ",", 
            RowBox[{"-", "3.9619316783900644`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.7799325621928395`", ",", 
            RowBox[{"-", "2.9457783127024895`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.065484772083943`", ",", 
            RowBox[{"-", "2.093536000929544`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.10152625975711`", ",", 
            RowBox[{"-", "1.044957245886985`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"7.830933620110022`", ",", "0.1092052086583436`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.952541962518307`", ",", "1.1075704809254951`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.12254377495572`", ",", "1.916088238803262`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.847196260192549`", ",", "3.1704311601849846`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.865954172489911`", ",", "4.199436596011666`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.06579040903449`", ",", "4.921155919082849`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.953523886613629`", ",", "5.848635257189417`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.167189208369928`", ",", "6.86575021008695`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.212677534818795`", ",", "8.060566935579482`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.13725664617709`", ",", "9.06152852278944`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"7.897192762734853`", ",", "9.904102936509025`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.78573038641998`", ",", 
            RowBox[{"-", "10.143514231323577`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.81625914262483`", ",", 
            RowBox[{"-", "8.955102272149318`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.083188423901673`", ",", 
            RowBox[{"-", "8.001084712249071`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.943715367669112`", ",", 
            RowBox[{"-", "7.12119051095258`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.985992163709124`", ",", 
            RowBox[{"-", "5.921515872434056`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.8277611951792`", ",", 
            RowBox[{"-", "5.070627106964246`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.170201754674636`", ",", 
            RowBox[{"-", "4.092671791516905`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.12423730856557`", ",", 
            RowBox[{"-", "3.1692623641536635`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.753012546304706`", ",", 
            RowBox[{"-", "2.208422001603854`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.161559773746776`", ",", 
            RowBox[{"-", "0.979829299733145`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"8.865755900127617`", ",", 
            RowBox[{"-", "0.019950524393293173`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.014367011011924`", ",", "0.8660677637578298`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.830025513707637`", ",", "1.8735637069302828`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.948107868387092`", ",", "3.0711700359071483`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.996837089805965`", ",", "4.124648419179354`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.754392500717982`", ",", "4.942360546859729`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.760844926096839`", ",", "5.79616429161341`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.17663130553878`", ",", "6.762987653823975`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.840643171422204`", ",", "8.138836083130315`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.80239399697321`", ",", "9.182250017977639`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"8.837630625117496`", ",", "10.097258084734168`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.890834223226435`", ",", 
            RowBox[{"-", "10.087920682289216`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.22187472498988`", ",", 
            RowBox[{"-", "9.132791390872539`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.12646721221451`", ",", 
            RowBox[{"-", "8.203988446047047`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.141849211282242`", ",", 
            RowBox[{"-", "6.756355097802821`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.928359343827418`", ",", 
            RowBox[{"-", "6.025158481954195`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.895012121476277`", ",", 
            RowBox[{"-", "5.131003516982175`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.923966843109437`", ",", 
            RowBox[{"-", "4.217519028813923`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.884167195379437`", ",", 
            RowBox[{"-", "3.1771678085955855`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.997335537570656`", ",", 
            RowBox[{"-", "2.2305066826378983`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.793524023957234`", ",", 
            RowBox[{"-", "1.0660038917259`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"9.944941540597444`", ",", 
            RowBox[{"-", "0.1627567006155366`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"10.205893398839736`", ",", "1.0867380235399313`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"9.804107317371011`", ",", "2.17516398167368`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.234018673849858`", ",", "2.9695294144124693`"}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"9.927640105156499`", ",", "4.129152427720726`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.842169462567616`", ",", "4.97588451221529`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.249280761329082`", ",", "5.904310909674921`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.197157341091339`", ",", "6.856888029197466`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.075313918219646`", ",", "7.871829938488844`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"10.062990145711902`", ",", "8.784055837793051`"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"9.82797838064899`", ",", "9.852336621126742`"}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"ShowClones", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotType", "\[Rule]", "TopView"}], ",", 
       RowBox[{"RunningCommentary", "\[Rule]", "TurboTrace"}], ",", 
       RowBox[{"ShowArrows", "\[Rule]", "All"}], ",", 
       RowBox[{"RuntimeAttributes", "\[Rule]", 
        RowBox[{"{", "Listable", "}"}]}], ",", 
       RowBox[{"Parallelization", "\[Rule]", "False"}], ",", 
       RowBox[{"CompilationTarget", "\[Rule]", "\<\"MVM\"\>"}], ",", 
       RowBox[{"RuntimeOptions", "\[Rule]", "\<\"Speed\"\>"}], ",", 
       RowBox[{
       "Optica`Optica`Private`CompileOptimizations", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"CompilationOptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\<\"ExpressionOptimization\"\>", "\[Rule]", "False"}], ",", 
          RowBox[{"\<\"InlineCompiledFunctions\"\>", "\[Rule]", "False"}]}], 
         "}"}]}], ",", 
       RowBox[{"ReportedParameters", "\[Rule]", "All"}], ",", 
       RowBox[{"RayTracePrecision", "\[RuleDelayed]", "$MachinePrecision"}], 
       ",", 
       RowBox[{"Compiled", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ThresholdIntensity", "\[Rule]", "1"}], ",", 
       RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
       RowBox[{"EmbedRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"NumberOfNodes", "\[Rule]", "1"}], ",", 
       RowBox[{"RayPartitions", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedThresholdIntensity", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"EmbedGenerationLimit", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RemoveSurfaceBreaks", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ExternalSurfaceIntersectionFunction", "\[Rule]", "False"}], 
       ",", 
       RowBox[{"MinimumRayLength", "\[Rule]", "0.0001`"}], ",", 
       RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
       RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"CloneSortLength", "\[Rule]", "10"}], ",", 
       RowBox[{"CloneSortMethod", "\[Rule]", "1"}], ",", 
       RowBox[{"NumberOfRays", "\[Rule]", "NumberOfRays"}], ",", 
       RowBox[{"SymbolicRefractiveModels", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"ModularSystem", "\[Rule]", "False"}], ",", 
       RowBox[{"IndependentScattering", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"RaySelect", "\[Rule]", "False"}], ",", 
       RowBox[{"RayHistory", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
       RowBox[{"SurpressMissedRays", "\[Rule]", "False"}], ",", 
       RowBox[{"IntrinsicMedium", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
       RowBox[{"NewSources", "\[Rule]", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"TestGridMode", "\[Rule]", "False"}], ",", 
       RowBox[{"InterceptHole", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ReportedFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"CustomParameters", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "{propsysopts, options} ", {{
    Optica`Optica`ReportedSurfaces -> All, Optica`Optica`OutputType -> 
     Optica`Optica`TurboSystem, Optica`Optica`CreateClones -> CompressedData["

1:eJwVl3lcTO8Xx2fKt5pkZphhhhlmDVHZkmzdE0palBIR2pOUZKkkEiqytCAt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      "], Optica`Optica`ShowClones -> 
     True, Optica`Optica`PlotType -> Optica`Optica`TopView, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`ShowArrows -> All, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`SpatialScale -> 1, 
     Optica`Optica`NewSources -> {}, Optica`Optica`TestGridMode -> False, 
     Optica`Optica`InterceptHole -> Automatic, Messages -> Automatic, 
     Optica`Optica`WaveFrontID -> False, MemoryConstrained -> False, 
     Optica`Optica`RayLimit -> Automatic, Optica`Optica`QuickSurfaceSort -> 
     False, Optica`Optica`UpdateNumericParameters -> Automatic}, {
    Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`SymbolicValues -> {}, Optica`Optica`ReportedSurfaces -> 
     All, Optica`Optica`OutputType -> Optica`Optica`TurboSystem, 
     Optica`Optica`CreateClones -> CompressedData["
1:eJwVl3lcTO8Xx2fKt5pkZphhhhlmDVHZkmzdE0palBIR2pOUZKkkEiqytCAt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      "], Optica`Optica`ShowClones -> 
     True, Optica`Optica`PlotType -> Optica`Optica`TopView, 
     Optica`Optica`RunningCommentary -> Optica`Optica`TurboTrace, 
     Optica`Optica`ShowArrows -> All, RuntimeAttributes -> {Listable}, 
     Parallelization -> False, CompilationTarget -> "MVM", RuntimeOptions -> 
     "Speed", Optica`Optica`Private`CompileOptimizations -> False, 
     CompilationOptions -> {
      "ExpressionOptimization" -> False, "InlineCompiledFunctions" -> False}, 
     Optica`Optica`ReportedParameters -> All, 
     Optica`Optica`RayTracePrecision :> $MachinePrecision, Compiled -> 
     Automatic, Optica`Optica`ThresholdIntensity -> 1, 
     Optica`Optica`GenerationLimit -> 200, Optica`Optica`EmbedRays -> 
     Automatic, Optica`Optica`NumberOfNodes -> 1, Optica`Optica`RayPartitions -> 
     Automatic, Optica`Optica`EmbedThresholdIntensity -> Automatic, 
     Optica`Optica`EmbedGenerationLimit -> Automatic, 
     Optica`Optica`RemoveSurfaceBreaks -> Automatic, 
     Optica`Optica`ExternalSurfaceIntersectionFunction -> False, 
     Optica`Optica`MinimumRayLength -> 0.0001, Optica`Optica`FilterTrace -> 
     True, Optica`Optica`ScoutRays -> Automatic, Optica`Optica`ScoutTrace -> 
     Automatic, Optica`Optica`CloneSortLength -> 10, 
     Optica`Optica`CloneSortMethod -> 1, Optica`Optica`NumberOfRays -> 
     Optica`Optica`NumberOfRays, Optica`Optica`SymbolicRefractiveModels -> {},
      Optica`Optica`ModularSystem -> False, 
     Optica`Optica`IndependentScattering -> Automatic, 
     Optica`Optica`RaySelect -> False, Optica`Optica`RayHistory -> Automatic, 
     Optica`Optica`SequentialTrace -> False, Optica`Optica`SurpressMissedRays -> 
     False, Optica`Optica`IntrinsicMedium -> Automatic, 
     Optica`Optica`SpatialScale -> 1, Optica`Optica`NewSources -> {}, 
     Optica`Optica`TestGridMode -> False, Optica`Optica`InterceptHole -> 
     Automatic, Optica`Optica`ReportedFunction -> Identity, 
     Optica`Optica`CustomParameters -> {}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078022869577`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"9e5f9dee-8ead-479a-b7ab-b29ca9c88f05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "\[InvisibleSpace]", "\<\" grid nodes of active.\"\>"}],
  SequenceForm[1, " grid nodes of active."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802324634*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"5a157a4a-5cd0-4ff8-9446-a9a4d1cf4f63"],

Cell[BoxData["\<\"Begin constructing TurboRays.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802326853*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"a7ac1691-3058-41ef-b826-3e248fce341f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TurboRays constructed in \"\>", "\[InvisibleSpace]", 
   "0.0202430000000000005766498389903063071`4.326874788388971", 
   "\[InvisibleSpace]", "\<\" seconds.\"\>"}],
  SequenceForm[
  "TurboRays constructed in ", 
   0.0202430000000000005766498389903063071`4.326874788388971, " seconds."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078023294888`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"68ed0864-f5f9-4899-9e1d-f86d4eb9da48"],

Cell[BoxData["\<\"System split into rays and components.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802332129*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"a3c73fa8-cd00-4292-8000-e81065aa2e52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Compiled RayTraceFunction = \"\>", "\[InvisibleSpace]", 
   "Automatic"}],
  SequenceForm["Compiled RayTraceFunction = ", Automatic],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802334866*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"5e96a7e3-3195-49c5-a721-3e13d8eba6dd"],

Cell[BoxData["\<\"Creating TurboSurfaces from component list.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802339652*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"73b92b16-de30-4bf4-8330-439f37608ec1"],

Cell[BoxData["\<\"Constructing deflection function code.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802342092*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"116e553e-8c5d-4dc1-a5f3-801621bf9f27"],

Cell[BoxData["\<\"Installing symbolic surface parameters.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802344535*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"6276257f-c7ec-4594-ad4f-72208f6b4d0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Default numeric assignments to user-defined symbols in \
components = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}], "\[InvisibleSpace]", "\<\".\"\>"}],
  SequenceForm[
  "Default numeric assignments to user-defined symbols in components = ", {}, 
   "."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078023479023`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"5a6866f8-45c9-4989-b288-05184518c8f4"],

Cell[BoxData["\<\"TurboSurfaces generated.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802349596*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"b9cffd6e-5cfc-4fb1-a8d3-92d7bd52cace"],

Cell[BoxData["\<\"Constructing trace-code segments.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078023539343`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"b0d73961-ee2c-4ee2-b8a0-2f0c81abd029"],

Cell[BoxData["\<\"Constructing ray-trace code.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802590416*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"1ca37af5-a564-4e12-963d-e72507044653"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"customsymbols: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["customsymbols: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802593074*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"6b21dd82-13da-49a4-bfcc-1692d2a751f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"usersymbolicparameters: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"Hold", "[", "]"}], "}"}]}],
  SequenceForm["usersymbolicparameters: ", {
    Hold[]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802594778*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"6d322694-d70a-45fe-91ab-4a334dca967d"],

Cell[BoxData["\<\"Extracting symbolic Ray parameters.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078025962563`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"2602bd1b-8e54-4f2d-985e-854ee2ebdd2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Hold", "[", "]"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          TagBox[
           RowBox[{"Move", "[", 
            RowBox[{
             RowBox[{"LineOfRays", "[", 
              RowBox[{"20", ",", 
               RowBox[{"NumberOfRays", "\[Rule]", "21"}]}], "]"}], ",", 
             RowBox[{"-", "12.`"}]}], "]"}],
           HoldForm],
          FontColor->RGBColor[0., 0.392193, 0.]],
         DisplayForm], ",", "False", ",", "False", ",", "False", ",", "False",
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "12.`"}], ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1.`", ",", "0", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "1.`", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1.`"}], "}"}]}], "}"}]}], "}"}]}], 
       "}"}], "}"}]}], "}"}]}],
  SequenceForm[
  "{symbolicrayparameters, symbolicrayvalues, symbolicrayresults} ", {
    Hold[], {}, {{
      Optica`Optica`Source[{}, Optica`Optica`ComponentNumber :> 1, 
       Optica`Optica`GenerationNumber :> 0, Optica`Optica`SourceDescription :> 
       Optica`Optica`SourceDescription[
         Optica`Optica`LineOfRays[{
           Optica`Optica`Ray[]}, 20, Optica`Optica`NumberOfRays -> 21, 
          Optica`Optica`SourceTransformation -> {{-12., 0, 0}, {{1., 0, 0}, {
             0, 1., 0}, {0, 0, 1.}}}, 
          Optica`Optica`SymbolicSourceTransformation -> {{-12, 0, 0}, {{1, 0, 
            0}, {0, 1, 0}, {0, 0, 1}}}]], 
       Optica`Optica`SourceTransformation :> {{-12., 0, 0}, {{1., 0, 0}, {
          0, 1., 0}, {0, 0, 1.}}}, 
       Optica`Optica`SymbolicSourceTransformation :> {{-12, 0, 0}, {{1, 0, 
         0}, {0, 1, 0}, {0, 0, 1}}}, Optica`Optica`SourceLevel :> {1, 1}, 
       Optica`Optica`NumberOfRays :> 21, 
       Optica`Optica`BirthPoint :> {0, 0, 0}, Optica`Optica`CoordinateSystem :> 
       Optica`Optica`CartesianCoordinates, Optica`Optica`StartAtBirthPoint :> 
       True, Optica`Optica`MonteCarlo :> False, Optica`Optica`SourceID :> 
       14154, Optica`Optica`SourceFraction :> 1, Optica`Optica`SourceOffset :> 
       0, Optica`Optica`GridSpacing :> (#& ), Optica`Optica`PowerOutput :> 
       100, Optica`Optica`SymbolicValues -> {}], False, False, False, 
      False, {{-12., 0, 0}, {{1., 0, 0}, {0, 1., 0}, {0, 0, 1.}}}}}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802602995*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"24daf8aa-d778-478d-b1bb-3cb981a0470c"],

Cell[BoxData["\<\"RayTraceFunction(s) source code assembled.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802723791*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"dec65d5e-7134-4048-bd69-fcddd67bff86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayCount ->\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["RayCount ->", 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802726829*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"5def9516-870b-45c4-bb4d-185c5bf57e2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RayPartitions ->\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["RayPartitions ->", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802729456*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"569cd10d-ec2f-4e84-b8fa-4bbe68d67c43"],

Cell[BoxData["\<\"RayTraceFunction(s) compiled.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802871965*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"dbc020dc-58c1-450b-987e-0de518fcb018"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"OutputType -> \"\>", "\[InvisibleSpace]", "TurboSystem"}],
  SequenceForm["OutputType -> ", Optica`Optica`TurboSystem],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802874909*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"06ebf166-0ece-4a92-84a9-2078defc9ffd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedSurfaces -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedSurfaces -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802877537*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"4a173113-385f-46f7-9c3d-0b055bbb25e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ReportedParameters -> \"\>", "\[InvisibleSpace]", "All"}],
  SequenceForm["ReportedParameters -> ", All],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802880156*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"931ebe39-1913-4ea1-a5d6-0c9aefc4d074"],

Cell[BoxData["\<\"Tracing system.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707802882794*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"fc7c54b5-8308-460e-a42b-d07ec905a15a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"maximum used clone sort position = \"\>", "\[InvisibleSpace]", 
   "10"}],
  SequenceForm["maximum used clone sort position = ", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803136506*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"4060f68c-4778-4814-9ce7-8d1f7fd45431"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Histogram of used sort positions: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "93", ",", "63", ",", "28", ",", "19", ",", "14", ",", "0", ",", "2", ",",
      "2", ",", "1", ",", "1"}], "}"}]}],
  SequenceForm[
  "Histogram of used sort positions: ", {93, 63, 28, 19, 14, 0, 2, 2, 1, 1}],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803138542*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"c2df0822-6d87-4e5a-bdfe-fdb1e7570704"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ListPlot", "::", "optx"}], "MessageName"], ":", 
  " ", "\<\"Unknown option \[NoBreak]\\!\\(PlotJoined \[Rule] True\\)\
\[NoBreak] in \[NoBreak]\\!\\(ListPlot[\\(\\(\\(\\({93, 63, 28, 19, 14, 0, 2, \
2, 1, 1}\\)\\), \\(\\(PlotJoined \[Rule] True\\)\\), \\(\\(PlotRange \[Rule] \
All\\)\\)\\)\\)]\\)\[NoBreak]. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/optx\\\", ButtonNote -> \
\\\"ListPlot::optx\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.614707803210656*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"d47b94fb-92d1-4460-93e6-ffdef0044a62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"You may wish to set CloneSortLength -> \"\>", 
   "\[InvisibleSpace]", "11"}],
  SequenceForm["You may wish to set CloneSortLength -> ", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803233926*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"372e005e-ae85-45d5-b357-dccdbfec3b2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"System traced in \"\>", "\[InvisibleSpace]", 
   "0.35535299999999997444533050838799681515`5.5712598995219675", 
   "\[InvisibleSpace]", "\<\" seconds with \"\>", "\[InvisibleSpace]", "446", 
   "\[InvisibleSpace]", "\<\" ray segments getting reported.\"\>"}],
  SequenceForm[
  "System traced in ", 
   0.35535299999999997444533050838799681515`5.5712598995219675, 
   " seconds with ", 446, " ray segments getting reported."],
  Editable->False]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.6147078032369013`*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"2444f75e-2c81-4fc8-bcee-98bc3bccbf99"],

Cell[BoxData["\<\"Components stripped of non-graphical parameters.\"\>"], \
"Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803240687*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"cde16d7f-25f9-49c2-8d01-9591f38344b8"],

Cell[BoxData["\<\"Graphical options scanned.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803242951*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"1939d258-9116-4640-8d0a-a8e388c1c894"],

Cell[BoxData["\<\"Generating component graphics.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803245579*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"30244d4b-b1f1-4417-a269-c577adbf4778"],

Cell[BoxData["\<\"RenderComponent called.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803248929*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"3b6f39ab-476c-4aeb-8ace-ef042b612aa2"],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803250536*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"372b9b9a-5013-4ebb-9371-b8c7809d5a85"],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803253772*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"ccdfd2bb-c013-42e4-99bb-9aab14e88f10"],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803256764*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"07c418d1-350c-47f1-b1a3-2dbcf1f4738c"],

Cell[BoxData["\<\"DrawSimpleSurface Circle and Rectangle called.\"\>"], \
"Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707803259286*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"c9a2bb0f-da80-40ea-8eaa-0a1efb0c580f"],

Cell[BoxData["\<\"Clone graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707804034648*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"63686a72-2217-4f16-b1dc-3b9f396962c5"],

Cell[BoxData["\<\"Optical component graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707808030554*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"830aa83c-4800-4bb1-8ca2-22aff9582db6"],

Cell[BoxData["\<\"Ray graphics generated.\"\>"], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707808119652*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"1ed4033f-5589-4337-a159-deb93b7ea346"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJycnHV0Fdny/RM8IYQMBHdu4+5OgrszuDuDJDgMroHgLkPwwQYJ7tA4BHd3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    "]], 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], Arrowheads[Small], 
    ArrowBox[{{-12., -10.}, {-10.359442976076158`, -10.}}], 
    {Arrowheads[Small], 
     ArrowBox[{{-10.359442976076158`, -10.}, {-9.768591720991187, \
-10.048329224960932`}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -9.}, {-10.305523113724378`, -9.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.305523113724378`, -9.}, {-9.731374999176413, \
-9.081465231492784}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -8.}, {-10.484888261983212`, -8.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.484888261983212`, -8.}, {-9.953000776192134, \
-7.8663359797993335`}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -7.}, {-10.393285582159317`, -7.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.393285582159317`, -7.}, {-9.840099578497387, \
-7.110131838302859}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -6.}, {-10.172066427623605`, -6.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.172066427623605`, -6.}, {-9.57257366566891, \
-6.011366834348537}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -5.}, {-10.219696452612643`, -5.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.219696452612643`, -5.}, {-9.644274631512744, \
-4.920585828943411}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -4.}, {-10.246996938057574`, -4.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.246996938057574`, -4.}, {-9.785097114814006, \
-3.8031953740118927`}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -3.}, {-10.461561799286818`, -3.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.461561799286818`, -3.}, {-9.862717444347991, \
-3.017158537250619}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -2.}, {-10.008959034531712`, -2.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.008959034531712`, -2.}, {-9.465636447256886, \
-2.121501884801422}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., -1.}, {-9.946867226782006, -1.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.946867226782006, -1.}, {-9.476247531610301, \
-1.18945741297663}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 0.}, {-10.399233770000391`, 0.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.399233770000391`, 0.}, {-9.805501942511118, 
      0.03998760727941056}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 1.}, {-10.201358817719765`, 1.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.201358817719765`, 1.}, {-9.672430752624683, 
      0.8633283022747505}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 2.}, {-10.06146371962937, 2.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.06146371962937, 2.}, {-9.489413787102507, 
      1.9152593593342566`}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 3.}, {-10.429760438102177`, 3.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.429760438102177`, 3.}, {-9.892871180421485, 
      3.128457965588948}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 4.}, {-10.083220267458834`, 4.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.083220267458834`, 4.}, {-9.489075536270285, 
      3.961354035367728}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 5.}, {-10.090021062944906`, 5.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.090021062944906`, 5.}, {-9.503129268431296, 
      5.0578835420009325`}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 6.}, {-10.379969149320887`, 6.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.379969149320887`, 6.}, {-9.871009110547137, 
      6.1558587855230815`}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 7.}, {-10.31393839369253, 7.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.31393839369253, 7.}, {-9.814823017965647, 
      7.164784733637305}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 8.}, {-10.049056495273275`, 8.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.049056495273275`, 8.}, {-9.540585391609618, 
      8.156308949198731}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 9.}, {-10.497082794947081`, 9.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.497082794947081`, 9.}, {-9.897131117988984, 
      8.996491781235791}}]}, 
    {Arrowheads[Small], ArrowBox[{{-12., 10.}, {-10.093923765755166`, 10.}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-10.093923765755166`, 10.}, {-9.526459290310555, 
      10.091512246317253`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.768591720991187, -10.048329224960932`}, \
{-9.462904933017263, -10.098673927062688`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.462904933017263, -10.098673927062688`}, \
{-8.888771358416154, -10.099234271208566`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.731374999176413, -9.081465231492784}, {-9.266457727812579, \
-9.216109122913466}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.266457727812579, -9.216109122913466}, {-8.692990515796856, \
-9.295247080855274}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.953000776192134, -7.8663359797993335`}, \
{-7.305409958197581, -6.445949154080657}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.305409958197581, -6.445949154080657}, {-6.917283475494928, \
-6.071565105589891}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.840099578497387, -7.110131838302859}, {-7.989747814136089, \
-7.877298749578993}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.989747814136089, -7.877298749578993}, {-7.544733283328133, \
-8.202359484351767}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.57257366566891, -6.011366834348537}, {-9.318551307390809, \
-6.021003209245679}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.318551307390809, -6.021003209245679}, {-8.719893830969019, \
-6.022874508082926}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.644274631512744, -4.920585828943411}, {-9.0735236928599, \
-4.759987860326131}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.0735236928599, -4.759987860326131}, {-8.616365218004834, \
-4.884253452764812}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.785097114814006, -3.8031953740118927`}, \
{-9.184031594516888, -3.1773854391909553`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.184031594516888, -3.1773854391909553`}, \
{-8.769083779591773, -2.7440090629106257`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.862717444347991, -3.017158537250619}, {-9.262917777174016, \
-3.051558598159785}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.262917777174016, -3.051558598159785}, {-8.68139309167614, \
-3.010020364997777}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.465636447256886, -2.121501884801422}, {-8.093000427767171, \
-2.7677380725596743`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.093000427767171, -2.7677380725596743`}, \
{-7.7135947172475055`, -3.1300113238868863`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.476247531610301, -1.18945741297663}, {-9.144794079397078, \
-1.507937667813336}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.144794079397078, -1.507937667813336}, {-8.858448160223919, \
-1.9729671070211399`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.805501942511118, 0.03998760727941056}, {-9.42456066603123, 
      0.09153391290946539}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.42456066603123, 0.09153391290946539}, {-8.873756035465894, 
      0.038383845640655515`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.672430752624683, 0.8633283022747505}, {-8.280286149258343, 
      0.09241350122482195}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.280286149258343, 
      0.09241350122482195}, {-7.744888796703968, -0.1734877949374395}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.489413787102507, 1.9152593593342566`}, {-7.880885715976831,
       1.4280083823709162`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.880885715976831, 1.4280083823709162`}, {-7.48238704604149, 
      1.111556870584869}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.892871180421485, 3.128457965588948}, {-6.327619950117953, 
      4.938124400263225}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.327619950117953, 4.938124400263225}, {-5.778565757347039, 
      5.159281591400266}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.489075536270285, 3.961354035367728}, {-9.310716936948253, 
      3.938052890113947}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.310716936948253, 3.938052890113947}, {-8.737004588120147, 
      3.9568487651701085`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.503129268431296, 5.0578835420009325`}, {-9.209694516538244,
       5.116333447667298}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.209694516538244, 5.116333447667298}, {-8.622326199718982, 
      5.238423391093935}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.871009110547137, 6.1558587855230815`}, {-9.005212852011695,
       6.740996520282252}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.005212852011695, 6.740996520282252}, {-8.520263499955046, 
      7.092298866851911}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.814823017965647, 7.164784733637305}, {-9.201450375908623, 
      7.6193470168558415`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.201450375908623, 7.6193470168558415`}, {-8.781256105770257,
       8.023599643406842}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.540585391609618, 8.156308949198731}, {-8.354522884184703, 
      8.961626255229845}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.354522884184703, 8.961626255229845}, {-7.9363376269867905`,
       9.356055884022538}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.897131117988984, 8.996491781235791}, {-9.304976144500232, 
      8.989566289383768}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.304976144500232, 8.989566289383768}, {-8.750531913938927, 
      9.093211306346673}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.526459290310555, 10.091512246317253`}, {-9.402450943745784,
       10.132576635648853`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.402450943745784, 10.132576635648853`}, {-8.9170182357615, 
      10.066859411913814`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.888771358416154, -10.099234271208566`}, \
{-8.115410318036428, -9.973416566842271}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.115410318036428, -9.973416566842271}, {-7.622210705263053, \
-10.086872209160218`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.692990515796856, -9.295247080855274}, {-7.38324679131724, \
-9.28525338566337}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.38324679131724, -9.28525338566337}, {-6.854336553481821, \
-9.145585549046785}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.917283475494928, -6.071565105589891}, {-5.218392217534506, \
-3.1616742763532435`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.218392217534506, -3.1616742763532435`}, \
{-4.9856862143692116`, -2.624758521938074}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.544733283328133, -8.202359484351767}, {-7.510429644696556, \
-8.242914024811604}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.510429644696556, -8.242914024811604}, {-7.062069902078038, \
-8.508035873686525}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.719893830969019, -6.022874508082926}, {-8.28843099374351, \
-6.009207525691234}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.28843099374351, -6.009207525691234}, {-7.688734187196969, \
-5.998359182824783}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.616365218004834, -4.884253452764812}, {-7.484585828016435, \
-6.061545485667499}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.484585828016435, -6.061545485667499}, {-7.025088142398409, \
-6.405898726911488}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.769083779591773, -2.7440090629106257`}, \
{-8.078825362093873, -2.0208484567760925`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.078825362093873, -2.0208484567760925`}, \
{-7.621417595660874, -1.8828219146815144`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.68139309167614, -3.010020364997777}, {-8.275967279446336, \
-2.927875594099417}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.275967279446336, -2.927875594099417}, {-7.723848839780604, \
-2.9464980898229767`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.7135947172475055`, -3.1300113238868863`}, \
{-7.3630030039505625`, -3.793351210584909}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.3630030039505625`, -3.793351210584909}, \
{-7.089629255842613, -4.327244538982775}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.858448160223919, -1.97296710702114}, {-8.013963706737636, \
-4.717568134107403}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.013963706737636, -4.717568134107403}, \
{-7.8981240927020835`, -5.295343698535356}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.873756035465894, 
      0.038383845640655515`}, {-8.259581085640631, -0.16985516067769657`}}]}, \

    {Arrowheads[Small], 
     ArrowBox[{{-8.259581085640631, -0.16985516067769657`}, \
{-7.739547194168791, -0.16435360297351095`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.744888796703968, -0.1734877949374395}, \
{-7.326472090900457, -0.3584327743106098}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.326472090900457, -0.3584327743106098}, \
{-6.821877826487688, -0.37039327642186487`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.48238704604149, 
      1.111556870584869}, {-6.824934657658675, -0.029683492800773398`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.824934657658675, -0.029683492800773398`}, \
{-6.933902347014148, -0.4694375226601082}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.778565757347039, 5.159281591400266}, {-5.266985201550586, 
      5.3153670515518066`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.266985201550586, 5.3153670515518066`}, {-4.725270620835626,
       5.331422064508169}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.737004588120147, 
      3.9568487651701085`}, {-4.1908497584576265`, 4.856679942833542}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.1908497584576265`, 4.856679942833542}, {-3.817113802154179,
       5.161991072960063}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.622326199718982, 5.238423391093935}, {-8.496294963921692, 
      5.265716259955168}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.496294963921692, 5.265716259955168}, {-7.9407085257387235`,
       5.259984842054426}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.520263499955046, 7.092298866851911}, {-8.030606865008338, 
      7.471945986158355}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.030606865008338, 7.471945986158355}, {-7.684684475962259, 
      7.902383937230938}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.781256105770257, 8.023599643406842}, {-7.972045293844239, 
      9.031598193364658}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.972045293844239, 9.031598193364658}, {-8.047313089226884, 
      9.476947875588047}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.750531913938927, 9.093211306346673}, {-8.503004385644088, 
      9.192449972531072}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.503004385644088, 9.192449972531072}, {-7.93673407290684, 
      9.356842008523078}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.9170182357615, 10.066859411913814`}, {-7.176202384049536, 
      8.904061808748853}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.176202384049536, 8.904061808748853}, {-6.660807515338086, 
      8.605745602279864}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.854336553481821, -9.145585549046785}, \
{-6.3822164357877575`, -8.882295281480992}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.3822164357877575`, -8.882295281480992}, \
{-5.85600817247007, -8.752051739018441}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.9856862143692116`, -2.624758521938074}, \
{-4.931929235234821, -2.4442872603500883`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.931929235234821, -2.4442872603500883`}, \
{-4.894675861614502, -1.8895629508082548`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.062069902078038, -8.508035873686525}, {-6.227943135968421, \
-8.676522514548648}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.227943135968421, -8.676522514548648}, {-5.788251724942816, \
-8.946568420596648}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.688734187196969, -5.998359182824783}, {-7.452009906623435, \
-5.997291514252997}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.452009906623435, -5.997291514252997}, {-6.906740833106273, \
-6.114765272933999}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.025088142398409, -6.405898726911488}, \
{-6.0138934035773595`, -6.933808684876207}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.0138934035773595`, -6.933808684876207}, \
{-5.4897478348890205`, -7.224386572610836}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.621417595660874, -1.8828219146815144`}, \
{-7.189916993368359, -1.9804627312778058`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.189916993368359, -1.9804627312778058`}, \
{-6.724981424355502, -2.243115863336342}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.723848839780604, -2.9464980898229767`}, \
{-7.074189179603163, -3.1244376704952512`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.074189179603163, -3.1244376704952512`}, \
{-6.491287778097174, -3.2371666353001514`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.089629255842613, -4.327244538982775}, {-6.990993438230418, \
-4.526199767858496}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.990993438230418, -4.526199767858496}, {-6.868665294754508, \
-5.063952798769641}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.8981240927020835`, -5.295343698535356}, \
{-7.8544341875939985`, -5.743218255324457}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.8544341875939985`, -5.743218255324457}, \
{-7.9137084510644415`, -6.302167863720406}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.739547194168791, -0.16435360297351095`}, \
{-7.2944977437522445`, -0.0028812938600102367`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.2944977437522445`, -0.0028812938600102367`}, \
{-6.808236416982313, -0.05628703802485585}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.821877826487688, -0.37039327642186487`}, \
{-6.040777341247505, -0.06851702321318676}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.040777341247505, -0.06851702321318676}, \
{-5.5412029878110864`, 0.21919079246536832`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.933902347014148, -0.4694375226601082}, \
{-7.925041274796321, -1.094076659370217}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.925041274796321, -1.094076659370217}, {-8.452418221370246, \
-1.3580152184446412`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.725270620835626, 5.331422064508169}, {-4.397790800041693, 
      5.252365897669017}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.397790800041693, 5.252365897669017}, {-3.8226730798430233`,
       5.08810776930238}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.817113802154179, 5.161991072960063}, {-3.172350629091671, 
      6.703040370685839}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.172350629091671, 6.703040370685839}, {-3.067042703053075, 
      7.253773052491098}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.9407085257387235`, 5.259984842054426}, {-7.316149330513616,
       5.111180383645971}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.316149330513616, 5.111180383645971}, {-6.9202649022286264`,
       4.808768543012373}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.684684475962259, 7.902383937230938}, {-6.765150654192935, 
      9.84224014340815}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.765150654192935, 9.84224014340815}, {-6.733364820497899, 
      10.34928754100537}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.047313089226884, 9.476947875588047}, {-8.893519222918508, 
      10.00689233481998}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.893519222918508, 10.00689233481998}, {-9.403717868212311, 
      10.131208588089889`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.93673407290684, 9.356842008523078}, {-6.115186440575706, 
      9.695429437469478}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.115186440575706, 9.695429437469478}, {-5.5420816537928985`,
       9.849187948642149}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.660807515338086, 8.605745602279864}, {-6.310666836898511, 
      8.432055587968346}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.310666836898511, 8.432055587968346}, {-5.79643596568755, 
      8.132507147528573}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.85600817247007, -8.752051739018441}, {-4.451804696468366, \
-8.784977889571069}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.451804696468366, -8.784977889571069}, {-3.921285829387249, \
-8.929194206858236}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.894675861614502, -1.8895629508082548`}, \
{-5.017052485598191, -1.1083658552951716`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.017052485598191, -1.1083658552951716`}, \
{-4.939666419923897, -0.5831486820566895}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.788251724942816, -8.946568420596648}, {-5.095449912900023, \
-9.823634597477445}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.095449912900023, -9.823634597477445}, {-4.704570462118154, \
-10.276019690022702`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.906740833106273, -6.114765272933999}, {-5.246967142567797, \
-6.873777733031872}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.246967142567797, -6.873777733031872}, {-4.720701209489804, \
-7.153685572911362}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.4897478348890205`, -7.224386572610836}, \
{-4.064554677330149, -8.061848760665134}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.064554677330149, -8.061848760665134}, {-3.600953807655942, \
-8.02795062214965}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.724981424355502, -2.243115863336342}, \
{-6.2637759782373825`, -2.7236532463758545`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.2637759782373825`, -2.7236532463758545`}, \
{-5.801143770422997, -3.0453875676793962`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.491287778097174, -3.2371666353001514`}, \
{-3.2693178643923826`, -3.608450365905079}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.2693178643923826`, -3.608450365905079}, \
{-2.8385654314466873`, -3.860518658859144}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.868665294754508, -5.063952798769641}, {-6.887417716607448, \
-6.516495583844218}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.887417716607448, -6.516495583844218}, {-7.010838038415987, \
-7.0628362417271875`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.9137084510644415`, -6.302167863720406}, \
{-8.761184852459364, -8.961146988091798}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.761184852459364, -8.961146988091798}, {-9.021535831867771, \
-9.472917495056171}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.808236416982313, -0.05628703802485591}, \
{-4.213236932791755, -1.708019547010318}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.213236932791755, -1.708019547010318}, \
{-3.7469928542745414`, -2.070509071783379}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.5412029878110864`, 
      0.2191907924653682}, {-3.279746686771228, 2.0339086125810217`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.279746686771228, 
      2.0339086125810217`}, {-2.7997932116055617`, 2.152171775354009}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.452418221370246, -1.3580152184446412`}, \
{-8.951676049196594, -1.54919728008188}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.951676049196594, -1.54919728008188}, {-9.401744232018267, \
-1.863696710699764}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.8226730798430233`, 
      5.08810776930238}, {-3.2397807250724187`, 4.895249454542469}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.2397807250724187`, 4.895249454542469}, {-2.66678825601016, 
      4.781720316818226}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.067042703053075, 7.253773052491098}, {-3.0740985639478615`,
       7.637338734154987}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.0740985639478615`, 7.637338734154987}, {-3.023406442418176,
       8.223596824059532}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.9202649022286264`, 
      4.808768543012373}, {-6.1691312744958555`, 3.43392130018397}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.1691312744958555`, 3.43392130018397}, {-5.894109728762473, 
      2.901345380212573}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.403717868212311, 10.131208588089889`}, {-9.524033976045137,
       10.121381757527924`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.524033976045137, 
      10.121381757527924`}, {-10.121840133003968`, 10.095691140281161`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.5420816537928985`, 9.849187948642149}, {-5.359428152450581,
       9.91389252081391}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.359428152450581, 9.91389252081391}, {-4.810629333773718, 
      9.971702557624505}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.79643596568755, 8.132507147528573}, {-4.898928161865699, 
      7.525784392578426}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.898928161865699, 7.525784392578426}, {-4.574327990042213, 
      7.110203942054021}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.921285829387249, -8.929194206858236}, \
{-3.0607894841838648`, -9.407596641231864}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.0607894841838648`, -9.407596641231864}, \
{-2.5859657493715242`, -9.395851679930121}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.939666419923897, -0.5831486820566893}, {-4.128751118001602,
       1.1043247380500927`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.128751118001602, 
      1.1043247380500927`}, {-3.7440942496947938`, 1.4070153536470753`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.720701209489804, -7.153685572911362}, \
{-3.9969868058244176`, -7.596140956104909}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.9969868058244176`, -7.596140956104909}, \
{-3.571119151300413, -7.974534090732421}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.600953807655942, -8.02795062214965}, {-3.415713390952765, \
-7.878997451218996}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.415713390952765, -7.878997451218996}, \
{-2.9187960615920208`, -7.662267109049501}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.801143770422997, -3.0453875676793962`}, \
{-4.282537569628124, -3.7043362360131464`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.282537569628124, -3.7043362360131464`}, \
{-3.8217762384129537`, -4.02700184208435}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.8385654314466873`, -3.860518658859144}, \
{-2.181528507352845, -4.768088355569243}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.181528507352845, -4.768088355569243}, \
{-1.9180117087007988`, -5.281286206371244}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.010838038415987, -7.0628362417271875`}, \
{-7.668006208008914, -8.490332378379708}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-7.668006208008914, -8.490332378379708}, {-7.904555238907511, \
-9.04093914041182}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.021535831867771, -9.472917495056171}, {-9.19726529986169, \
-9.712591007330223}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.19726529986169, -9.712591007330223}, {-9.392845822782064, \
-10.218871254448334`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.7469928542745414`, -2.070509071783379}, \
{-1.9652116552246082`, -3.746688469228184}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.9652116552246082`, -3.746688469228184}, \
{-1.67246974185101, -4.208612306003675}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.7997932116055617`, 2.152171775354009}, {-2.08071656379228, 
      2.011602762095173}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.08071656379228, 2.011602762095173}, {-1.6112992702382134`, 
      2.142853665414071}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.401744232018267, -1.863696710699764}, {-9.517142759520748, \
-1.9961522878122884`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.517142759520748, -1.9961522878122884`}, \
{-9.94170551017631, -2.4099015458471245`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.66678825601016, 4.781720316818226}, {-2.0136003288323425`, 
      4.734823382772061}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.0136003288323425`, 
      4.734823382772061}, {-1.5028247806998536`, 4.862263641350153}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.023406442418176, 8.223596824059532}, {-2.9314767223915044`,
       8.699295405919644}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.9314767223915044`, 
      8.699295405919644}, {-2.7587670112387017`, 9.261242933543}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.894109728762473, 2.901345380212573}, {-5.136573648773741, 
      1.3463769255965072`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.136573648773741, 1.3463769255965072`}, {-5.071241110259282,
       0.8276188086391135}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.810629333773718, 9.971702557624505}, {-4.181197048674765, 
      9.889060418031967}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.181197048674765, 9.889060418031967}, {-3.6154439342971005`,
       9.921492069579685}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.574327990042213, 7.110203942054021}, {-4.275676366152798, 
      6.291628356895415}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.275676366152798, 6.291628356895415}, {-3.973373197022949, 
      5.8265779828667705`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.5859657493715242`, -9.395851679930121}, \
{-2.0554104697281956`, -9.06552985877292}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.0554104697281956`, -9.06552985877292}, \
{-1.5283628960927023`, -8.871937597879993}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.7440942496947933`, 
      1.4070153536470753`}, {-1.2380668695528376`, 1.9426959508198545`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.2380668695528376`, 
      1.9426959508198545`}, {-0.7083119275379781, 2.1562467634997904`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.571119151300413, -7.974534090732421}, {-2.828401610927563, \
-8.91847453349349}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.828401610927563, -8.91847453349349}, \
{-2.6048651587227414`, -9.41910022229758}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.9187960615920208`, -7.662267109049501}, \
{-2.0728810319869106`, -7.538472393173517}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.0728810319869106`, -7.538472393173517}, \
{-1.706426461219854, -7.238477277487386}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.8217762384129537`, -4.02700184208435}, \
{-3.2115081190638755`, -4.67120066026952}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.2115081190638755`, -4.67120066026952}, \
{-2.7732961340371656`, -5.073175605638776}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.9180117087007988`, -5.281286206371244}, \
{-1.3996391791571408`, -6.834461421472592}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.3996391791571408`, -6.834461421472592}, \
{-1.1419517654400686`, -7.354919776278407}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.67246974185101, -4.208612306003675}, {-1.463142474907339, \
-4.853646327554745}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.463142474907339, -4.853646327554745}, \
{-1.1696172190950958`, -5.314050913711446}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.6112992702382134`, 
      2.142853665414071}, {-1.0040538840626314`, 2.6954703134791558`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0040538840626314`, 
      2.6954703134791558`}, {-0.5546251328578771, 3.0926214213263377`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.5028247806998536`, 
      4.862263641350153}, {-1.1072101247059876`, 5.110678108080852}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.1072101247059876`, 
      5.110678108080852}, {-0.5801154980878074, 5.378462181690627}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.071241110259282, 0.8276188086391134}, {-5.171242255232185, 
      0.34122304153593735`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.171242255232185, 
      0.34122304153593735`}, {-5.2012559112383325`, -0.23529914144501024`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.6154439342971005`, 9.921492069579685}, {-3.182477070886539,
       10.029777511157446`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.182477070886539, 
      10.029777511157446`}, {-2.6764472064370626`, 9.965053252732824}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.973373197022949, 5.8265779828667705`}, {-3.190493074264571,
       5.070747589616871}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.190493074264571, 5.070747589616871}, {-2.7365512348886374`,
       4.685210285859714}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.5283628960927023`, -8.871937597879993}, \
{-0.9592068085559948, -8.787569188404921}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.9592068085559948, -8.787569188404921}, \
{-0.5525281774079946, -9.005069160482577}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.7083119275379781, 
      2.1562467634997904`}, {-0.11004735737095156`, 2.5278253356087084`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.11004735737095156`, 2.5278253356087084`}, {
      0.25073840264439967`, 2.926637396863073}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.706426461219854, -7.238477277487386}, \
{-1.3014218822843615`, -6.108300884814368}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.3014218822843615`, -6.108300884814368}, \
{-1.0098702936263926`, -5.626845285501664}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.7732961340371656`, -5.073175605638776}, \
{-2.125988401178725, -5.588277827632895}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.125988401178725, -5.588277827632895}, \
{-1.8479975119129126`, -6.0285214155439935`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.1419517654400686`, -7.354919776278407}, \
{-0.728635678583593, -7.9625236198563565`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.728635678583593, -7.9625236198563565`}, \
{-0.6599506531784128, -8.447063368043622}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.169617219095096, -5.314050913711446}, {
      0.5488436543930297, -6.913251037567044}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.5488436543930297, -6.913251037567044}, {
      1.0227253132508114`, -7.097649463929363}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.5546251328578771, 3.0926214213263377`}, {
      0.22543696472317348`, 3.761909296399395}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.22543696472317348`, 3.761909296399395}, {
      0.37855237211379406`, 4.21131858595507}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.5801154980878074, 5.378462181690627}, {0.6584009075183206, 
      5.8723057854253256`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.6584009075183206, 5.8723057854253256`}, {
      1.2148395383113417`, 6.096706312242904}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.2012559112383325`, -0.2352991414450103}, \
{-5.139862378194492, -0.8550155211086468}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.139862378194492, -0.8550155211086468}, \
{-4.806341643684343, -1.1642313557941364`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.6764472064370626`, 
      9.965053252732824}, {-1.1152385701260363`, 9.11316580690132}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.1152385701260363`, 9.11316580690132}, {-0.7411574202630817,
       8.733055970296014}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.7365512348886374`, 
      4.685210285859714}, {-2.4184412588772197`, 4.448182400991069}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.4184412588772197`, 
      4.448182400991069}, {-1.9857692468833412`, 4.0492895071979715`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.5525281774079946, -9.005069160482577}, \
{-0.2510874049838916, -9.64304127463509}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.2510874049838916, -9.64304127463509}, \
{-0.012805549167170555`, -10.192446819026747`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.2507384026443996, 2.926637396863073}, {0.7264027315063917, 
      3.897058479430202}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.7264027315063917, 3.897058479430202}, {1.0202531577765594`, 
      4.415694230209205}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0098702936263926`, -5.626845285501664}, \
{-0.41720764325984744`, -4.984125483343606}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.41720764325984744`, -4.984125483343606}, {
      0.0409579209651173, -4.7699805876690995`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.8479975119129124`, -6.0285214155439935`}, \
{-1.146211084026172, -9.055765177339367}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.146211084026172, -9.055765177339367}, \
{-0.7987773083167249, -9.3617410787784}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.6599506531784128, -8.447063368043622}, \
{-0.7674298209515061, -8.776112613021068}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.7674298209515061, -8.776112613021068}, \
{-0.943965825470351, -9.349221690272978}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.0227253132508114`, -7.097649463929363}, {
      1.9436195594517065`, -7.090948456766933}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.9436195594517065`, -7.090948456766933}, {
      2.543516894997167, -7.092301938848958}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.3785523721137941, 4.21131858595507}, {0.20870166725619949`, 
      5.02845797864856}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.20870166725619949`, 
      5.02845797864856}, {-0.027870737585871858`, 5.525743398242846}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.2148395383113417`, 6.096706312242904}, {3.6081590897690843`,
       7.072788561641514}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3.6081590897690843`, 7.072788561641514}, {4.172894389459852, 
      7.2318264659105305`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.806341643684343, -1.1642313557941364`}, \
{-1.2970337388679392`, -1.245491752232878}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.2970337388679392`, -1.245491752232878}, \
{-0.8330989377561928, -1.0573249341950812`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.7411574202630817, 8.733055970296014}, {-0.2319621932381744,
       7.763326207323237}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.2319621932381744, 7.763326207323237}, {
      0.16456352661780949`, 7.480752495589716}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.9857692468833412`, 
      4.0492895071979715`}, {-1.055187924674782, 2.991616451629117}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.055187924674782, 2.991616451629117}, {-0.6092606393538087, 
      2.636839370403441}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.0202531577765594`, 4.415694230209205}, {1.5047414910670724`,
       5.1629403478928735`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.5047414910670724`, 5.1629403478928735`}, {
      1.9206834332886662`, 5.447261891309486}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.04095792096511808, -4.7699805876690995`}, {
      8.99327116878904, -4.334943473267289}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.99327116878904, -4.334943473267289}, {
      9.467457685926528, -4.13315526142217}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.7987773083167247, -9.3617410787784}, {
      1.7207546171776547`, -9.617267132022306}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.7207546171776547`, -9.617267132022306}, {
      2.072801598316235, -9.919951433293166}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.943965825470351, -9.349221690272978}, \
{-1.0160225535529042`, -9.598017932176523}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0160225535529042`, -9.598017932176523}, \
{-1.2310169228976837`, -10.148841283590208`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.543516894997167, -7.092301938848958}, {
      2.6679857879278237`, -7.093769354857558}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.6679857879278237`, -7.093769354857558}, {
      3.267300460578694, -7.112226611842573}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.027870737585871885`, 
      5.525743398242846}, {-0.9747844400315853, 6.6892124037526335`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.9747844400315853, 
      6.6892124037526335`}, {-1.0828188563534464`, 7.165711671101953}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.172894389459852, 7.2318264659105305`}, {6.708094004682505, 
      7.645555527214807}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.708094004682505, 7.645555527214807}, {7.228405106921177, 
      7.85002587314865}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.8330989377561928, -1.0573249341950812`}, \
{-0.18236998075840233`, -0.3955925676668009}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.18236998075840233`, -0.3955925676668009}, {
      0.18056771347233275`, 0.0659615203007064}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.1645635266178096, 7.480752495589716}, {1.961702031550296, 
      7.207270805004678}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.961702031550296, 7.207270805004678}, {2.2608809229629867`, 
      6.863176873997271}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.6092606393538087, 
      2.636839370403441}, {-0.014745886003385611`, 2.3160076768625495`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.014745886003385611`, 2.3160076768625495`}, {
      0.0964991985947864, 1.8781542002030092`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.9206834332886662`, 5.447261891309486}, {4.938180499319601, 
      6.070393674878716}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.938180499319601, 6.070393674878716}, {5.528210227371653, 
      6.157380521311867}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3.267300460578694, -7.112226611842573}, {
      4.089409101191887, -7.153190134219555}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.089409101191887, -7.153190134219555}, {
      4.527263985682943, -6.948833789252856}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0828188563534464`, 
      7.165711671101953}, {-0.9133370364972347, 7.866679121827488}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.9133370364972347, 7.866679121827488}, {-0.7439446662981041,
       8.439364528792794}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.228405106921177, 7.85002587314865}, {8.780907156702817, 
      8.88302048117488}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.780907156702817, 8.88302048117488}, {9.078225530217392, 
      9.300220206025994}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.1805677134723327, 0.06596152030070646}, {0.8201919730829601,
       1.096003548327223}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.8201919730829601, 1.096003548327223}, {1.2339220985853956`, 
      1.3643736084463691`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.2608809229629867`, 6.863176873997271}, {2.3252194051374993`,
       1.316267355273373}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.3252194051374993`, 1.316267355273373}, {2.189826717266155, 
      0.7905671569177324}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.0964991985947865, 
      1.8781542002030092`}, {-0.9144663084151223, 0.3294295896343624}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.9144663084151223, 
      0.3294295896343624}, {-1.1279161404009637`, -0.19436035439012345`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5.528210227371653, 6.157380521311867}, {7.050816603431734, 
      6.293410135077964}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.050816603431734, 6.293410135077964}, {7.417764656536369, 
      6.024455720774117}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.527263985682943, -6.948833789252856}, {
      4.9557695203794285`, -6.3824226204534105`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.9557695203794285`, -6.3824226204534105`}, {
      5.3593476877106685`, -5.955714827616442}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.743944666298104, 
      8.439364528792794}, {-0.14796642329930432`, 10.135260180609528`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.14796642329930432`, 10.135260180609528`}, {
      0.25483619146606923`, 10.34339057534272}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.2339220985853956`, 1.3643736084463691`}, {4.945037134460002,
       1.8713278355570626`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.945037134460002, 1.8713278355570626`}, {5.298209580191754, 
      2.1782628988853663`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.189826717266155, 0.7905671569177324}, {2.028316781444218, 
      0.5056745793674071}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.028316781444218, 0.5056745793674071}, {
      1.8110454465773307`, -0.03414042246896515}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.1279161404009637`, -0.19436035439012345`}, \
{-1.2314470278910061`, -0.7168755834675886}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.2314470278910061`, -0.7168755834675886}, \
{-1.2295806241105847`, -1.280179199081824}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.417764656536369, 6.024455720774117}, {7.757929626859461, 
      4.47931281426062}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.757929626859461, 4.47931281426062}, {7.91644676751127, 
      3.903716292603177}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5.3593476877106685`, -5.955714827616442}, {
      6.6962381847530095`, -4.821953184441105}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.6962381847530095`, -4.821953184441105}, {
      7.187716977582011, -4.5879388275742485`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.2548361914660693, 10.34339057534272}, {0.9332129620361438, 
      10.149048589048807`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.9332129620361438, 10.149048589048807`}, {1.368240188263135, 
      9.853466446957777}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5.298209580191754, 2.1782628988853663`}, {6.0241001118269075`,
       4.7448382472282695`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.0241001118269075`, 4.7448382472282695`}, {6.165378841651967,
       5.326384472716492}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.8110454465773307`, -0.03414042246896498}, {
      1.077597054510899, -2.9117321094483084`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.077597054510899, -2.9117321094483084`}, {
      0.8100018720546995, -3.382827814606972}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.2295806241105847`, -1.280179199081824}, \
{-1.0957597719750514`, -1.9328511827048716`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0957597719750514`, -1.9328511827048716`}, \
{-0.8469424823802496, -2.4100626265369054`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.91644676751127, 3.903716292603177}, {8.115464801349578, 
      3.3047144049531942`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.115464801349578, 3.3047144049531942`}, {7.939442325019155, 
      2.8849654643054174`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.187716977582011, -4.5879388275742485`}, {
      8.922903498321059, -4.26250574691005}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.922903498321059, -4.26250574691005}, {
      9.46961093345212, -4.073853086359735}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.368240188263135, 9.853466446957777}, {1.896303179084646, 
      9.167692831038382}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.896303179084646, 9.167692831038382}, {2.032067416326305, 
      8.679492985149462}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.165378841651967, 5.326384472716492}, {6.654500459420056, 
      7.726804143452814}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.654500459420056, 7.726804143452814}, {6.934659203623653, 
      8.149113761483468}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.8100018720546995, -3.382827814606972}, {
      0.3653736780392276, -3.8290689302653873`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{
      0.3653736780392276, -3.8290689302653873`}, {-0.1043378862002125, \
-4.081354980971538}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.8469424823802496, -2.4100626265369054`}, {
      0.6878040200315552, -4.028034566504484}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.6878040200315552, -4.028034566504484}, {
      1.1507979504373769`, -4.322636887553284}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.939442325019155, 2.8849654643054174`}, {6.46607010509393, 
      2.1625521813381776`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.46607010509393, 2.1625521813381776`}, {5.919916620252093, 
      1.9171551253728005`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.032067416326305, 8.679492985149462}, {1.9785557477330742`, 
      8.210960063606832}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.9785557477330742`, 8.210960063606832}, {1.909820416399275, 
      7.614911526602161}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.934659203623653, 8.149113761483468}, {7.938779321885183, 
      8.836569078129017}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.938779321885183, 8.836569078129017}, {8.397022582715937, 
      9.211600699471512}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.10433788620021245`, -4.081354980971538}, \
{-0.7407939387200964, -4.209427052612962}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.7407939387200964, -4.209427052612962}, \
{-1.3056440902520916`, -4.212097690679708}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.1507979504373766`, -4.322636887553284}, {
      3.8572321727666625`, -5.224255585455802}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3.8572321727666625`, -5.224255585455802}, {
      4.25739966497194, -5.013985277683004}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{5.919916620252093, 1.9171551253728005`}, {4.080713708193101, 
      1.1639205858450214`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.080713708193101, 1.1639205858450214`}, {3.5453716002469093`,
       0.9031874970152065}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.909820416399275, 7.614911526602161}, {1.860198205354531, 
      7.18869853637193}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.860198205354531, 7.18869853637193}, {1.889537094605718, 
      6.61670486508413}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.3056440902520916`, -4.212097690679708}, \
{-1.641711758280497, -4.147772200333091}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.641711758280497, -4.147772200333091}, {-2.220259792998209, \
-4.002622489555824}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.25739966497194, -5.013985277683004}, {
      4.555806285979561, -3.982509843928294}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.555806285979561, -3.982509843928294}, {
      4.858063058808264, -3.5599732954958023`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{3.5453716002469093`, 0.9031874970152065}, {
      2.2867029227958344`, 0.18628523266366892`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{2.2867029227958344`, 0.18628523266366892`}, {
      1.7538762193875364`, 0.020288518551835832`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.889537094605718, 6.61670486508413}, {1.962581145134625, 
      6.287586939423546}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.962581145134625, 6.287586939423546}, {1.9495951402546023`, 
      5.7379817309782295`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.220259792998209, -4.002622489555824}, {-2.846577520581338, \
-3.8071585395873555`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.846577520581338, -3.8071585395873555`}, \
{-3.407735742153385, -3.746803232124697}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{4.858063058808264, -3.5599732954958023`}, {
      6.683687244147325, -2.2826080521210868`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{6.683687244147325, -2.2826080521210868`}, {
      7.050447885441589, -1.8696660791381237`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.7538762193875364`, 0.020288518551835832`}, {
      1.5085334577194334`, -0.0009309432583123889}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.5085334577194334`, -0.0009309432583123889}, {
      0.941814392505963, 0.05200272066411901}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.9495951402546023`, 5.7379817309782295`}, {1.874600220886574,
       5.462342223602488}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.874600220886574, 5.462342223602488}, {1.7231122772702852`, 
      4.881904186199159}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.407735742153385, -3.746803232124697}, \
{-3.8610119721600795`, -3.7868953819033737`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.8610119721600795`, -3.7868953819033737`}, \
{-4.411628623610599, -3.9355648456678893`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.050447885441589, -1.8696660791381237`}, {
      7.9686201892624515`, -0.15733260981219932`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.9686201892624515`, -0.15733260981219932`}, {
      8.01731684299406, 0.34428241773518986`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.9418143925059628, 0.05200272066411893}, {-1.925674376518472,
       0.8534545721035868}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.925674376518472, 
      0.8534545721035868}, {-2.3536530203167785`, 1.150565658472134}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.7231122772702852`, 4.881904186199159}, {1.2269855715089755`,
       2.89709297535037}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{1.2269855715089755`, 2.89709297535037}, {0.8726785692334291, 
      2.6003630031141904`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.411628623610599, -3.9355648456678893`}, \
{-8.72200739143555, -5.960667764820249}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.72200739143555, -5.960667764820249}, {-9.277824935002304, \
-6.153865118881836}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.01731684299406, 0.34428241773518986`}, {7.871237648575101, 
      0.8187978912736644}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.871237648575101, 0.8187978912736644}, {7.820553606722914, 
      1.3769755178762337`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.3536530203167785`, 1.150565658472134}, {-2.774845522457389,
       1.7286477227423167`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.774845522457389, 
      1.7286477227423167`}, {-3.1591962017433373`, 2.1816383925468816`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.8726785692334291, 2.6003630031141904`}, {
      0.10490614244542296`, 2.547669925353972}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{0.10490614244542296`, 
      2.547669925353972}, {-0.3224666445979456, 2.7575875017246747`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.277824935002304, -6.153865118881836}, {-9.68212640305679, \
-6.248461901880303}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.68212640305679, -6.248461901880303}, \
{-10.151102684280348`, -6.127963878050855}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.820553606722914, 1.3769755178762337`}, {7.865872625482147, 
      1.7607823437834162`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{7.865872625482147, 1.7607823437834162`}, {8.102882279413459, 
      2.215443254784357}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.1591962017433373`, 
      2.1816383925468816`}, {-3.6260534559974547`, 2.655883017371437}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.6260534559974547`, 2.655883017371437}, {-4.063124246452064,
       3.06409818016705}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.3224666445979456, 
      2.7575875017246747`}, {-1.0656476952308909`, 3.8696240921837974`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0656476952308909`, 
      3.8696240921837974`}, {-1.0861854618747675`, 4.341983355030353}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.102882279413459, 2.215443254784357}, {8.782963196938217, 
      2.820715973268821}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{8.782963196938217, 2.820715973268821}, {9.187479880450443, 
      3.2520043242507675`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.063124246452064, 3.06409818016705}, {-4.741337420944344, 
      3.646217893923437}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.741337420944344, 3.646217893923437}, {-5.200497565950315, 
      4.032266232341002}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.0861854618747675`, 
      4.341983355030353}, {-0.7786745714433672, 4.901902453309941}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.7786745714433672, 4.901902453309941}, {-0.6340563208354806,
       5.434003981664741}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{9.187479880450443, 3.2520043242507675`}, {9.710803926742532, 
      3.92183124758993}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{9.710803926742532, 3.92183124758993}, {10.101417602606439`, 
      4.373695637358687}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.200497565950315, 4.032266232341002}, {-6.015917099158688, 
      4.703784936199735}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.015917099158688, 4.703784936199735}, {-6.297365797055335, 
      5.148240500472201}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.6340563208354806, 5.434003981664741}, {-0.5943862146547587,
       6.8245904580846135`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.5943862146547587, 
      6.8245904580846135`}, {-0.8052422851931924, 7.2611097645910565`}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.297365797055335, 5.148240500472201}, {-6.69133842271149, 
      6.709802139065895}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.69133842271149, 6.709802139065895}, {-6.9481710300616255`, 
      7.197470438775369}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-0.8052422851931924, 
      7.2611097645910565`}, {-1.9098005819715715`, 8.087460292697576}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-1.9098005819715715`, 8.087460292697576}, {-2.419112885636187,
       8.348203130598186}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-6.9481710300616255`, 7.197470438775369}, {-8.77608698367178, 
      9.2717409538775}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-8.77608698367178, 9.2717409538775}, {-9.22712701759998, 
      9.381498203009096}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-2.419112885636187, 8.348203130598186}, {-3.8290400756094463`,
       8.790567794616459}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-3.8290400756094463`, 
      8.790567794616459}, {-4.3872774097413645`, 9.000859884128094}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.22712701759998, 9.381498203009096}, {-9.920779999149696, 
      9.11162494635823}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-9.920779999149696, 9.11162494635823}, {-10.477688922172609`, 
      8.888636515384468}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-4.3872774097413645`, 9.000859884128094}, {-5.66986996964164, 
      9.568269995432242}}]}, 
    {Arrowheads[Small], 
     ArrowBox[{{-5.66986996964164, 9.568269995432242}, {-6.129774507660284, 
      9.89349657657063}}], 
     {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJw9V2k4VW3YReZ5OMc5nOM4k/JWpJIM1X5SMoWQogxJGkyRIZIylAwJpTSb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       "]]}}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.566139438034231*^9, 3.614707815186466*^9},
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"},
 CellLabel->
  "During evaluation of \
In[56]:=",ExpressionUUID->"fdb36d72-ab79-4189-a843-7506cad40be2"]
}, Open  ]],

Cell[TextData[{
 "In this example, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has modelled a system of 882 optical surfaces. By using ",
 StyleBox["CreateClones", "Input"],
 ", this result is 1200 times faster than the same calculation would have \
been with ",
 StyleBox["AnalyzeSystem", "Input"],
 " and 66 times faster than ",
 StyleBox["TurboPlot", "Input"],
 " alone. In addition, in this example, ",
 StyleBox["CreateClones", "Input"],
 " has consumed only 1/400 of the memory that would otherwise have been \
required to describe the same optical system. The performance of ",
 StyleBox["CreateClones", "Input"],
 " improves even further as its number of repetitive elements is increased. \
In some cases, ",
 StyleBox["CreateClones", "Input"],
 " can reach efficiencies that are tens of thousands times better than \
otherwise possible. You can learn more about ",
 StyleBox["CreateClones", "Input"],
 " in ",
 ButtonBox["Chapter 7",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"7. All"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"9c4ed069-1dcb-4b31-b3b4-de62ad8e215e"],

Cell[TextData[{
 "In addition to the ",
 StyleBox["CreateClones", "Input"],
 " option, this example has used three other new options. These are defined \
below."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"0d7d4221-ebf2-4a36-a888-5a1eb445b649"],

Cell[TextData[{
 StyleBox["ShowClones -> True", "Input"],
 "/",
 StyleBox["False", "Input"],
 " is an option that denotes whether the phantom clones of optical components \
are rendered.\n",
 StyleBox["ShowArrows -> True", "Input"],
 "/",
 StyleBox["False", "Input"],
 "/",
 StyleBox["All", "Input"],
 "/",
 StyleBox["maxnumber",
  FontSlant->"Italic"],
 " is an option that switches between arrow and simple line rendering of \
rays.\n",
 StyleBox["RunningCommentary -> True", "Input"],
 "/",
 StyleBox["False", "Input"],
 "/",
 StyleBox["All", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 "/",
 StyleBox["ComponentFoundation", "Input"],
 " is an option of ",
 StyleBox["PropagateSystem", "Input"],
 ", ",
 StyleBox["TurboTrace", "Input"],
 ", and other ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " functions that controls reporting of the calculation process."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", 
   "RG14.", "RG14.2"},ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673"],

Cell[TextData[{
 "This section has provided a glimpse of new capabilities now made possible \
with ",
 StyleBox["TurboPlot", "Input"],
 " and ",
 StyleBox["CreateClones", "Input"],
 ". In the next section, we will see how ",
 StyleBox["OptimizeSystem", "Input"],
 " makes optimization problems easy to manage in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "TurboPlot", "14.2", "RG14.", 
   "RG14.2"},ExpressionUUID->"e2766717-50f1-411a-8db8-c3dba15ad878"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "TurboPlot", 
   "RG14."},ExpressionUUID->"bfafdff3-9501-4a72-ad94-f41a96b5bd5d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "15. Optimization with ",
 StyleBox["OptimizeSystem",
  FontFamily->"Courier"]
}], "Section",
 CellTags->{
  "OptimizeSystem", "15.", 
   "RG15."},ExpressionUUID->"5c62ed6d-b544-44e0-affc-dcff777c52d7"],

Cell[TextData[{
 "Previously, we learned how to incorporate used-defined symbolic parameters \
into optical systems. In particular, we saw how to assign a symbolic focal \
length to a lens and then assign different numeric values for different \
ray-trace calculations. ",
 StyleBox["OptimizeSystem", "Input"],
 " also uses such symbolic parameters in order to iteratively optimize some \
aspect of an optical system."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"419b7f51-9a7b-481a-b9c5-ae3663216c45"],

Cell[TextData[{
 StyleBox["OptimizeSystem[", "Input"],
 StyleBox["system",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " optimizes the performance of an optical system for a specified set of \
symbolic input parameters."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"188eecd5-87fc-44a1-97a8-d53de79f8064"],

Cell[TextData[{
 "While in its default operation, ",
 StyleBox["OptimizeSystem", "Input"],
 " tries to minimize the ray-locus spot-size on a last surface of the optical \
system, you can also customize ",
 StyleBox["OptimizeSystem", "Input"],
 " for nearly any other characteristic that you wish. In this section, \
however, we will stick with the default settings of ",
 StyleBox["OptimizeSystem", "Input"],
 " to find the best focus for a lens system. Next, we will create a \
double-surface lens with the ",
 StyleBox["SphericalLens", "Input"],
 " function."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"9de3c256-3fe2-4d8a-a0f5-0251a566a82a"],

Cell[TextData[{
 StyleBox["SphericalLens[", "Input"],
 StyleBox["r1",
  FontSlant->"Italic"],
 ", ",
 StyleBox["r2",
  FontSlant->"Italic"],
 ", ",
 StyleBox["aperture",
  FontSlant->"Italic"],
 ", ",
 StyleBox["thickness",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " denotes a lens having two spherical surfaces with radius of curvatures \
given by ",
 StyleBox["r1",
  FontSlant->"Italic"],
 " and ",
 StyleBox["r2.",
  FontSlant->"Italic"]
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "SphericalLens", "OptimizeSystem", 
   "RG15."},ExpressionUUID->"464f8f91-b6db-4961-a243-0eaa5ee35b2f"],

Cell[TextData[{
 "In this case, we will use two symbolic parameters, ",
 StyleBox["r1", "Input"],
 " and ",
 StyleBox["r2", "Input"],
 ", to represent the radius of curvature of each lens surface."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"2e5b0ef5-c7c3-44c6-ba4b-0e7f59661041"],

Cell["\<\
sphericalsystem = 
\t{GaussianBeam[10,.1,NumberOfRays->11],
\tMove[SphericalLens[{r1,100}, {r2,-100}, 50, 10],50],
\tMove[Screen[50],150]};\
\>", "Input",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."},
 CellLabel->"In[57]:=",ExpressionUUID->"cc023c24-24c2-4956-bf37-e220676eb9b5"],

Cell[TextData[{
 StyleBox["OptimizeSystem", "Input"],
 " uses the numeric value that accompanies every symbolic parameter as an \
initial starting value for the numeric minimization process. As a user, you \
can influence the minimization process through your choice of these settings. \
In this case, the initial numeric setting for ",
 StyleBox["r1", "Input"],
 " is 100 mm and for ",
 StyleBox["r2", "Input"],
 " is -100 mm. When we call ",
 StyleBox["TurboPlot", "Input"],
 " directly, we can trace of the lens system with its initial numeric \
settings."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"f106fd40-d378-4d6e-8a02-ef34ac16d402"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Timing[trace = TurboPlot[", "Input"],
 "sphericalsystem",
 StyleBox[", ", "Input"],
 "PlotType->TopView",
 StyleBox["]]", "Input"]
}], "Input",
 CellTags->{"OptimizeSystem", "RG15."},
 CellLabel->"In[58]:=",ExpressionUUID->"edc39bfb-d98f-454b-ba00-fa5626702911"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYC4jMiX7hKpnk5MICB5QGT19xfuzN94Px7mp7x
P3x8HdasAgGDA0rXti1g3+zpsBrKR9ePLo+u3+ZgWVrVZRhf4cARu86ZrTqe
cD66fnR5dP0Qe/2g9jPshVCeMD4Dun50eTT9DDDzV0HUO8D0r4DycZkPk0fX
D/M/hG/gAPMfjI+uH10eXT8sfv6DgYUDLPz/Qfno+lHjh4EBpv/0+fPrZ09+
bQMzX0tXdy/j72c2MP3tXV2n0pMO2aDrR5dH1w/zfwdY/pENzH8Q9ZcwzEeX
R9cPi5+zYPfetoGF/2koH10/ujxMP4yPav4lNP2PCJj/CEM/zP+dUP/A/KcJ
DQ90/ejyMP1dUP2w+Llx+/bhLeumWMLC/xQ0vtD1AwAsjqAo
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{53.17541634481458, -25.}, {
       51.39867028167306, -16.666666666666668`}, {
       50.34782714082169, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.34782714082169, 
       8.333333333333329}, {51.39867028167306, 16.666666666666657`}, {
       53.17541634481458, 24.999999999999993`}, {56.82458365518542, 25.}, {
       58.60132971832694, 16.666666666666668`}, {59.65217285917831, 
       8.333333333333336}, {60., 3.552713678800501*^-15}, {
       59.65217285917831, -8.333333333333329}, {
       58.60132971832694, -16.666666666666657`}, {
       56.82458365518542, -24.999999999999993`}, {
       53.17541634481458, -25.}}, {{53.17541634481458, 0.}, {
       51.39867028167306, 0.}, {50.34782714082169, 0.}, {50., 0.}, {
       50.34782714082169, 0.}, {51.39867028167306, 0.}, {53.17541634481458, 
       0.}, {56.82458365518542, 0.}, {58.60132971832694, 0.}, {
       59.65217285917831, 0.}, {60., 0.}, {59.65217285917831, 0.}, {
       58.60132971832694, 0.}, {56.82458365518542, 0.}, {53.17541634481458, 
       0.}}, {{53.17541634481458, 25.}, {56.82458365518542, 25.}, {
       56.82458365518542, 24.148145657226706`}, {53.17541634481458, 
       24.148145657226706`}, {53.17541634481458, 25.}}, {{53.17541634481458, 
       24.148145657226706`}, {56.82458365518542, 24.148145657226706`}, {
       56.82458365518542, 21.65063509461097}, {53.17541634481458, 
       21.65063509461097}, {53.17541634481458, 24.148145657226706`}}, {{
       53.17541634481458, 21.65063509461097}, {56.82458365518542, 
       21.65063509461097}, {56.82458365518542, 17.67766952966369}, {
       53.17541634481458, 17.67766952966369}, {53.17541634481458, 
       21.65063509461097}}, {{53.17541634481458, 17.67766952966369}, {
       56.82458365518542, 17.67766952966369}, {56.82458365518542, 
       12.500000000000004`}, {53.17541634481458, 12.500000000000004`}, {
       53.17541634481458, 17.67766952966369}}, {{53.17541634481458, 
       12.500000000000004`}, {56.82458365518542, 12.500000000000004`}, {
       56.82458365518542, 6.470476127563024}, {53.17541634481458, 
       6.470476127563024}, {53.17541634481458, 12.500000000000004`}}, {{
       53.17541634481458, 6.470476127563024}, {56.82458365518542, 
       6.470476127563024}, {56.82458365518542, 7.0819236220599744`*^-15}, {
       53.17541634481458, 7.0819236220599744`*^-15}, {53.17541634481458, 
       6.470476127563024}}, {{53.17541634481458, 1.5308084989341915`*^-15}, {
       56.82458365518542, 1.5308084989341915`*^-15}, {
       56.82458365518542, -6.470476127563016}, {
       53.17541634481458, -6.470476127563016}, {53.17541634481458, 
       1.5308084989341915`*^-15}}, {{53.17541634481458, -6.470476127563016}, {
       56.82458365518542, -6.470476127563016}, {
       56.82458365518542, -12.499999999999995`}, {
       53.17541634481458, -12.499999999999995`}, {
       53.17541634481458, -6.470476127563016}}, {{
       53.17541634481458, -12.499999999999995`}, {
       56.82458365518542, -12.499999999999995`}, {
       56.82458365518542, -17.677669529663685`}, {
       53.17541634481458, -17.677669529663685`}, {
       53.17541634481458, -12.499999999999995`}}, {{
       53.17541634481458, -17.677669529663685`}, {
       56.82458365518542, -17.677669529663685`}, {
       56.82458365518542, -21.65063509461097}, {
       53.17541634481458, -21.65063509461097}, {
       53.17541634481458, -17.677669529663685`}}, {{
       53.17541634481458, -21.650635094610962`}, {
       56.82458365518542, -21.650635094610962`}, {
       56.82458365518542, -24.148145657226706`}, {
       53.17541634481458, -24.148145657226706`}, {
       53.17541634481458, -21.650635094610962`}}, {{
       53.17541634481458, -24.148145657226706`}, {
       56.82458365518542, -24.148145657226706`}, {56.82458365518542, -25.}, {
       53.17541634481458, -25.}, {
       53.17541634481458, -24.148145657226706`}}, {{
       53.17541634481458, -25.}, {56.82458365518542, -25.}, {
       56.82458365518542, -24.148145657226706`}, {
       53.17541634481458, -24.148145657226706`}, {
       53.17541634481458, -25.}}, {{53.17541634481458, -24.14814565722671}, {
       56.82458365518542, -24.14814565722671}, {
       56.82458365518542, -21.65063509461097}, {
       53.17541634481458, -21.65063509461097}, {
       53.17541634481458, -24.14814565722671}}, {{
       53.17541634481458, -21.65063509461097}, {
       56.82458365518542, -21.65063509461097}, {
       56.82458365518542, -17.677669529663692`}, {
       53.17541634481458, -17.677669529663692`}, {
       53.17541634481458, -21.65063509461097}}, {{
       53.17541634481458, -17.677669529663696`}, {
       56.82458365518542, -17.677669529663696`}, {
       56.82458365518542, -12.50000000000001}, {
       53.17541634481458, -12.50000000000001}, {
       53.17541634481458, -17.677669529663696`}}, {{
       53.17541634481458, -12.50000000000001}, {
       56.82458365518542, -12.50000000000001}, {
       56.82458365518542, -6.470476127563038}, {
       53.17541634481458, -6.470476127563038}, {
       53.17541634481458, -12.50000000000001}}, {{
       53.17541634481458, -6.470476127563038}, {
       56.82458365518542, -6.470476127563038}, {
       56.82458365518542, -2.6796885989305705`*^-14}, {
       53.17541634481458, -2.6796885989305705`*^-14}, {
       53.17541634481458, -6.470476127563038}}, {{
       53.17541634481458, -4.592425496802574*^-15}, {
       56.82458365518542, -4.592425496802574*^-15}, {56.82458365518542, 
       6.470476127563007}, {53.17541634481458, 6.470476127563007}, {
       53.17541634481458, -4.592425496802574*^-15}}, {{53.17541634481458, 
       6.470476127563007}, {56.82458365518542, 6.470476127563007}, {
       56.82458365518542, 12.499999999999984`}, {53.17541634481458, 
       12.499999999999984`}, {53.17541634481458, 6.470476127563007}}, {{
       53.17541634481458, 12.499999999999984`}, {56.82458365518542, 
       12.499999999999984`}, {56.82458365518542, 17.67766952966367}, {
       53.17541634481458, 17.67766952966367}, {53.17541634481458, 
       12.499999999999984`}}, {{53.17541634481458, 17.677669529663685`}, {
       56.82458365518542, 17.677669529663685`}, {56.82458365518542, 
       21.65063509461096}, {53.17541634481458, 21.65063509461096}, {
       53.17541634481458, 17.677669529663685`}}, {{53.17541634481458, 
       21.65063509461096}, {56.82458365518542, 21.65063509461096}, {
       56.82458365518542, 24.148145657226703`}, {53.17541634481458, 
       24.148145657226703`}, {53.17541634481458, 21.65063509461096}}, {{
       53.17541634481458, 24.148145657226703`}, {56.82458365518542, 
       24.148145657226703`}, {56.82458365518542, 25.}, {53.17541634481458, 
       25.}, {53.17541634481458, 24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}, {{150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150.,
        0.}, {150., 0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHkhwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAJP8g58=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmVmYGBQBGImKPb2ZX66+sP5/dc/FK6a81P5wOYbZr/YUz0dYjQP
HTMR0TywbLrenhklR/b7trB7lfyUP+B9RqQj28HT4U6U/UI/LpUDSqvOPHNi
276/LMZ3g81f8QNbPok8VFTxdJj74Nin1RxyB5Tbldb7VS7ZH8vNsSnmH/+B
Zxysa9gEPB2YjadlTmASOaDrFNpTU9Wyf055hdr0///3H77Sm8XA4unA5GP7
ZDEDywEGrMDTAcZC02+Ppt8BzX4HNPsd0NzvgOZ+BzT/O6D53wEt/BzQwg+d
f0BlXVZk0hxfh/Zp22Qdn2tghOeEJXfWtB7wddgVorh03xNljPA0Cr83IfOO
r0NN/zSWKedkMcLzwamKXIsPvg4fkl5xcd8WPoAenqKX9Vr5//g6HDuXy7Hy
BvMB9PCEAD84Hz080fRjhCea/RjhieZ+jPBE8z9GeKKFHzof4p8DSQ6bpZwX
JGmJYIQnTL6qazPXrDQBjPCEyX/bHiul8oIDIzxh8kLCG0/G7GfAHp5A+a85
Uv2CVz/sRw9PmDyMiR6eaPrt0cMTzX6M8ERzP0Z4ovkfIzzRws8BAFhAm4U=

     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQvfmG2S/2VE+HGM1Dx0xENA94nxHpyHbwdLgTZb/Q
j0vlwJZPIg8VVTwd5j449mk1h9yBZxysa9gEPB2YjadlTmASOXD4Sm8WA4un
A5OP7ZPFDCwHGMDA04EBCtDkHdD0O6CZ74BmvwOa+xxU1mVFJs3xdWiftk3W
8bnGgQlL7qxpPeDrsCtEcem+J8oHjMLvTci84+tQ0z+NZco52QMPTlXkWnzw
dfiQ9IqL+7bwAdHLeq38f3wdjp3L5Vh5gxnqXj+4e9HkHdD0O6CZ74BmP7r7
IOYeSHLYLOW8IElL5ACMX9W1mWtWmgCc/217rJTKCw44X0h448mY/Qxw/tcc
qX7Bqx/2w/gMyAAhb4+m3wHNfDgfaj+6+xwAIdu/Lg==
      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5633675480539627`*^9, 3.566087005497796*^9, 
  3.56610177295899*^9, 3.5661392167354193`*^9, 3.614707816613716*^9},
 CellTags->{"OptimizeSystem", "RG15."},
 CellLabel->
  "During evaluation of \
In[58]:=",ExpressionUUID->"326b1886-ce69-4775-b57f-27ed8186400d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.52201699999999995327470969641581177711`5.738284559741606", 
   ",", "\<\"-traced system-\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.563367548057311*^9, 3.566087005502171*^9, 
  3.566101772964469*^9, 3.566139216743116*^9, 3.6147078166171417`*^9},
 CellTags->{"OptimizeSystem", "RG15."},
 CellLabel->"Out[58]=",ExpressionUUID->"f0700e2c-2c78-41a6-853d-7af972f922f5"]
}, Open  ]],

Cell[TextData[{
 "Finally we call ",
 StyleBox["OptimizeSystem", "Input"],
 " with the untraced ",
 StyleBox["sphericalsystem", "Input"],
 " information."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"07b449bf-c5a9-46e5-b911-cfe47228b2b3"],

Cell[CellGroupData[{

Cell["Timing[soln = OptimizeSystem[sphericalsystem]]", "Input",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."},
 CellLabel->"In[59]:=",ExpressionUUID->"6ece41d5-f3e3-45cf-aa92-7a37515cbd52"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.06025900000000006251354989217361435294`6.0460118809322365", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SymbolicValues", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", "\[Rule]", "53.25271135647038`"}], ",", 
        RowBox[{"r2", "\[Rule]", 
         RowBox[{"-", "107.12910744768101`"}]}]}], "}"}]}], ",", 
     RowBox[{"NumberOfCycles", "\[Rule]", "270"}], ",", 
     RowBox[{"FinalMerit", "\[Rule]", "0.08802792421771187`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367549122863*^9, 3.5660870063839006`*^9, 
  3.5661017748976307`*^9, 3.566139218438486*^9, 3.6147078177881937`*^9},
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."},
 CellLabel->"Out[59]=",ExpressionUUID->"7ab3a572-6034-4db6-82c5-7498be5e4b4a"]
}, Open  ]],

Cell[TextData[{
 "Here we have stored the resulting answer from ",
 StyleBox["OptimizeSystem", "Input"],
 " in the ",
 StyleBox["soln", "Input"],
 " variable. In this case, the system was iteratively traced 216 times before \
the optimal value was determined. (Note that the standard ",
 StyleBox["OptimizeSystem", "Input"],
 " cannot always find the global minimum and may only find a local minimum. \
In many cases, however, this is already a big help! However, other extensions \
do exist for ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " that enable ",
 StyleBox["OptimizeSystem", "Input"],
 " to perform global optimization. See the Optica Software web site: \
www.opticasoftware.com for further details.) We can now rerun ",
 StyleBox["TurboPlot", "Input"],
 " with the information from ",
 StyleBox["soln", "Input"],
 " to see a trace of the optimal result."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"f12843e5-55ae-47eb-ae22-ba9bb72ec067"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["plot = TurboPlot[trace", "Input"],
 ", soln, PlotType->TopView",
 StyleBox["];", "Input"]
}], "Input",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."},
 CellLabel->"In[60]:=",ExpressionUUID->"1a01a7b8-d66d-4978-801d-81d2ebe5808e"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYCYg5umcWXZX0cGMDA8sAOjcuRKa0I/olvGt6c
kb4Oa1aBgMGBgjcSkwrCvBxWQ/no+tHl0fV/SvFwLr4G4ysc2P3uFt+vYE84
H10/ujy6foi9flD7Gfb+BwMPGJ8BXT+6PJp+Bpj5qyDqHWD6V0D5uMyHyaPr
h/kfwjdwgPkPxkfXjy6Prh8WPxB3WDiwQ8P/H5SPrh81fhgYYPpPnz+/fvbk
1zYw87V0dfcy/n5mA9Pf3tV1Kj3pkA26fnR5dP0w/3eA5R/ZwPwHUX8Jw3x0
eXT9sPg5C3bvbRtY+J+G8tH1o8vD9MP4qOZfQtP/iID5jzD0w/zfCfUPzH+a
0PBA148uD9PfBdUPi58bt28f3rJuiiUsfk9B4wtdPwAziMN0
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{56.23302115315715, -25.}, {
       52.67531038491222, -16.666666666666668`}, {
       50.65606866540971, -8.333333333333336}, {
       49.99999999999999, -3.552713678800501*^-15}, {50.65606866540971, 
       8.333333333333329}, {52.675310384912216`, 16.666666666666657`}, {
       56.233021153157146`, 24.999999999999993`}, {57.04212496576787, 25.}, {
       58.695596117975185`, 16.666666666666668`}, {59.675392542218006`, 
       8.333333333333336}, {60., 3.552713678800501*^-15}, {
       59.675392542218006`, -8.333333333333329}, {
       58.695596117975185`, -16.666666666666657`}, {
       57.04212496576787, -24.999999999999993`}, {
       56.23302115315715, -25.}}, {{56.23302115315715, 0.}, {
       52.67531038491222, 0.}, {50.65606866540971, 0.}, {49.99999999999999, 
       0.}, {50.65606866540971, 0.}, {52.675310384912216`, 0.}, {
       56.233021153157146`, 0.}, {57.04212496576787, 0.}, {
       58.695596117975185`, 0.}, {59.675392542218006`, 0.}, {60., 0.}, {
       59.675392542218006`, 0.}, {58.695596117975185`, 0.}, {
       57.04212496576787, 0.}, {56.23302115315715, 0.}}, {{56.23302115315715, 
       25.}, {57.04212496576787, 25.}, {57.04212496576787, 
       24.148145657226706`}, {56.23302115315715, 24.148145657226706`}, {
       56.23302115315715, 25.}}, {{56.23302115315715, 24.148145657226706`}, {
       57.04212496576787, 24.148145657226706`}, {57.04212496576787, 
       21.65063509461097}, {56.23302115315715, 21.65063509461097}, {
       56.23302115315715, 24.148145657226706`}}, {{56.23302115315715, 
       21.65063509461097}, {57.04212496576787, 21.65063509461097}, {
       57.04212496576787, 17.67766952966369}, {56.23302115315715, 
       17.67766952966369}, {56.23302115315715, 21.65063509461097}}, {{
       56.23302115315715, 17.67766952966369}, {57.04212496576787, 
       17.67766952966369}, {57.04212496576787, 12.500000000000004`}, {
       56.23302115315715, 12.500000000000004`}, {56.23302115315715, 
       17.67766952966369}}, {{56.23302115315715, 12.500000000000004`}, {
       57.04212496576787, 12.500000000000004`}, {57.04212496576787, 
       6.470476127563024}, {56.23302115315715, 6.470476127563024}, {
       56.23302115315715, 12.500000000000004`}}, {{56.23302115315715, 
       6.470476127563024}, {57.04212496576787, 6.470476127563024}, {
       57.04212496576787, 7.0819236220599744`*^-15}, {56.23302115315715, 
       7.0819236220599744`*^-15}, {56.23302115315715, 6.470476127563024}}, {{
       56.23302115315715, 1.5308084989341915`*^-15}, {57.04212496576787, 
       1.5308084989341915`*^-15}, {57.04212496576787, -6.470476127563016}, {
       56.23302115315715, -6.470476127563016}, {56.23302115315715, 
       1.5308084989341915`*^-15}}, {{56.23302115315715, -6.470476127563016}, {
       57.04212496576787, -6.470476127563016}, {
       57.04212496576787, -12.499999999999995`}, {
       56.23302115315715, -12.499999999999995`}, {
       56.23302115315715, -6.470476127563016}}, {{
       56.23302115315715, -12.499999999999995`}, {
       57.04212496576787, -12.499999999999995`}, {
       57.04212496576787, -17.677669529663685`}, {
       56.23302115315715, -17.677669529663685`}, {
       56.23302115315715, -12.499999999999995`}}, {{
       56.23302115315715, -17.677669529663685`}, {
       57.04212496576787, -17.677669529663685`}, {
       57.04212496576787, -21.65063509461097}, {
       56.23302115315715, -21.65063509461097}, {
       56.23302115315715, -17.677669529663685`}}, {{
       56.23302115315715, -21.650635094610962`}, {
       57.04212496576787, -21.650635094610962`}, {
       57.04212496576787, -24.148145657226706`}, {
       56.23302115315715, -24.148145657226706`}, {
       56.23302115315715, -21.650635094610962`}}, {{
       56.23302115315715, -24.148145657226706`}, {
       57.04212496576787, -24.148145657226706`}, {57.04212496576787, -25.}, {
       56.23302115315715, -25.}, {
       56.23302115315715, -24.148145657226706`}}, {{
       56.23302115315715, -25.}, {57.04212496576787, -25.}, {
       57.04212496576787, -24.148145657226706`}, {
       56.23302115315715, -24.148145657226706`}, {
       56.23302115315715, -25.}}, {{56.23302115315715, -24.14814565722671}, {
       57.04212496576787, -24.14814565722671}, {
       57.04212496576787, -21.65063509461097}, {
       56.23302115315715, -21.65063509461097}, {
       56.23302115315715, -24.14814565722671}}, {{
       56.23302115315715, -21.65063509461097}, {
       57.04212496576787, -21.65063509461097}, {
       57.04212496576787, -17.677669529663692`}, {
       56.23302115315715, -17.677669529663692`}, {
       56.23302115315715, -21.65063509461097}}, {{
       56.23302115315715, -17.677669529663696`}, {
       57.04212496576787, -17.677669529663696`}, {
       57.04212496576787, -12.50000000000001}, {
       56.23302115315715, -12.50000000000001}, {
       56.23302115315715, -17.677669529663696`}}, {{
       56.23302115315715, -12.50000000000001}, {
       57.04212496576787, -12.50000000000001}, {
       57.04212496576787, -6.470476127563038}, {
       56.23302115315715, -6.470476127563038}, {
       56.23302115315715, -12.50000000000001}}, {{
       56.23302115315715, -6.470476127563038}, {
       57.04212496576787, -6.470476127563038}, {
       57.04212496576787, -2.6796885989305705`*^-14}, {
       56.23302115315715, -2.6796885989305705`*^-14}, {
       56.23302115315715, -6.470476127563038}}, {{
       56.23302115315715, -4.592425496802574*^-15}, {
       57.04212496576787, -4.592425496802574*^-15}, {57.04212496576787, 
       6.470476127563007}, {56.23302115315715, 6.470476127563007}, {
       56.23302115315715, -4.592425496802574*^-15}}, {{56.23302115315715, 
       6.470476127563007}, {57.04212496576787, 6.470476127563007}, {
       57.04212496576787, 12.499999999999984`}, {56.23302115315715, 
       12.499999999999984`}, {56.23302115315715, 6.470476127563007}}, {{
       56.23302115315715, 12.499999999999984`}, {57.04212496576787, 
       12.499999999999984`}, {57.04212496576787, 17.67766952966367}, {
       56.23302115315716, 17.67766952966367}, {56.23302115315715, 
       12.499999999999984`}}, {{56.23302115315715, 17.677669529663685`}, {
       57.04212496576787, 17.677669529663685`}, {57.04212496576787, 
       21.65063509461096}, {56.23302115315715, 21.65063509461096}, {
       56.23302115315715, 17.677669529663685`}}, {{56.23302115315715, 
       21.65063509461096}, {57.04212496576787, 21.65063509461096}, {
       57.04212496576787, 24.148145657226703`}, {56.23302115315715, 
       24.148145657226703`}, {56.23302115315715, 21.65063509461096}}, {{
       56.23302115315715, 24.148145657226703`}, {57.04212496576787, 
       24.148145657226703`}, {57.04212496576787, 25.}, {56.23302115315715, 
       25.}, {56.23302115315715, 24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{150., -25.}, {150., -16.666666666666668`}, {
       150., -8.333333333333336}, {150., -3.552713678800501*^-15}, {150., 
       8.333333333333329}, {150., 16.666666666666657`}, {150., 
       24.999999999999993`}, {150., 25.}, {150., 16.666666666666668`}, {150., 
       8.333333333333336}, {150., 3.552713678800501*^-15}, {
       150., -8.333333333333329}, {150., -16.666666666666657`}, {
       150., -24.999999999999993`}, {150., -25.}}, {{150., 0.}, {150., 0.}, {
       150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 
       0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150., 0.}, {150.,
        0.}, {150., 0.}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHkhwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAJP8g58=
       "]}],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmVmYGBQBGImKPb2ZX66+sP5/dc/FK6a81P5wFoxnsbjBzwdvsfw
efSpaR5YNl1vz4ySI/t9W9i9Sn7KH8i9yxhiVOXp8HKNrUavsMoBpVVnnjmx
bd9fFuO7weav+IGqRQvLrV08Hf7LxGgnCMgdUG5XWu9XuWR/LDfHpph//Af4
d6Vaact5OnQy92++zCJyQNcptKemqmX/nPIKten//+83VXe938Lu6VBT9PKb
MSPLAQaswNMBxkLTb4+m3wHNfgc0+x3Q3O+A5n4HNP87oPnfAS38HNDCD51/
4CrzH3HW5b4OOleOimXHaWCEp/fK1rrVx30dpm3N3jQlTRkjPFfZTZww6YGv
Q4KhccuVfzIY4ZnFWtwn88nXoUpK7yO/h/AB9PA8YLROruuPr4O6UXzEdgfm
A+jhCQF+cD56eKLpxwhPNPsxwhPN/Zjhiep/jPBECz90PsQ/B5IcHI5pTWR9
dskePTxh8gzaktOK7VbZo4cnXP6z+POfhRv2o4cnTL4hxsL/I+f2/VjDE2S/
wYcjJ2TX7UcPT7j5MCZaeKLpt0cPTzT70d0Pl4e6H93/CHmI//ejhyda+O0H
AG6sir0=
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQvVaMp/H4AU+H7zF8Hn1qmgdy7zKGGFV5OrxcY6vR
K6xyoGrRwnJrF0+H/zIx2gkCcgf4d6Vaact5OnQy92++zCJywFTd9X4Lu6dD
TdHLb8aMLAcYwMDTgQEK0OQd0PQ7oJnvgGa/A5r7HK4y/xFnXe7roHPlqFh2
nMYB75WtdauP+zpM25q9aUqa8oFVdhMnTHrg65BgaNxy5Z/MgSzW4j6ZT74O
VVJ6H/k9hA8cMFon1/XH10HdKD5iuwMz1L1+cPeiyTug6XdAM98BzX5090HM
PZDk4HBMayLrs0v2MD6DtuS0YrtVCP5n8ec/Czfsh/EbYiz8P3Juh/MdDD4c
OSG7Ds5nQAYIeXs0/ejmo9uPMB/ivv0A33+4XA==
      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.5633675493430853`*^9, 3.5660870066785603`*^9, 
  3.566101775256778*^9, 3.566139218756781*^9, 3.614707818000318*^9},
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."},
 CellLabel->
  "During evaluation of \
In[60]:=",ExpressionUUID->"1213985f-5e0e-420a-8dab-9c423b2d855e"]
}, Open  ]],

Cell[TextData[{
 "As one final speed-up, we can add the option ",
 StyleBox["SequentialTrace -> True", "Input"],
 " to ",
 StyleBox["OptimizeSystem", "Input"],
 ". Both ",
 StyleBox["OptimizeSystem", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " use ",
 StyleBox["SequentialTrace -> False", "Input"],
 " by default. In this case, however, we can use ",
 StyleBox["SequentialTrace -> True", "Input"],
 " because the rays in this optical system are all passing through the same \
sequence of optical surfaces without back-tracking or having multiple bounces."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"26adf7e2-d329-4e5f-9eb1-652c33ff4999"],

Cell[CellGroupData[{

Cell["\<\
Timing[soln = OptimizeSystem[sphericalsystem, SequentialTrace->True]]\
\>", "Input",
 CellTags->{"OptimizeSystem", "RG15."},
 CellLabel->"In[61]:=",ExpressionUUID->"e7a71eb1-906b-4f00-b5c4-af9e47b73be8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.97547099999999997699262621608795598149`6.009814275962302", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SymbolicValues", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r1", "\[Rule]", "53.25271135647038`"}], ",", 
        RowBox[{"r2", "\[Rule]", 
         RowBox[{"-", "107.12910744768101`"}]}]}], "}"}]}], ",", 
     RowBox[{"NumberOfCycles", "\[Rule]", "270"}], ",", 
     RowBox[{"FinalMerit", "\[Rule]", "0.08802792421771187`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367550479731*^9, 3.5660870075207443`*^9, 
  3.566101776932802*^9, 3.5661392202933702`*^9, 3.614707818984221*^9},
 CellTags->{"OptimizeSystem", "RG15."},
 CellLabel->"Out[61]=",ExpressionUUID->"db4e6ada-8a4c-406b-a33e-82257316feac"]
}, Open  ]],

Cell[TextData[{
 "In this final example, ",
 StyleBox["SequentialTrace->True", "Input"],
 " has given us a further increase in speed. With larger systems that have \
many optical surfaces, there can be even greater gains in performance from \
this setting. Although the example given here has optimized the surface \
curvatures of the lens, many other optical parameters can be also optimized \
by simply assigning a symbolic value to each desired parameter. This could \
include the thickness of a component or the position of a component or light \
source in space. You can include equations with your symbols or even assign a \
symbolic wavelength to a light source and subsequently optimize the system at \
different colors."
}], "Text",
 CellTags->{
  "OptimizeSystem", 
   "RG15."},ExpressionUUID->"2002864d-91c5-4d29-bf56-0440598d610f"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"d6bcaf1c-8738-4475-\
9022-fe1fc2493382"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "16. ",
 StyleBox["ReadRays", "Input"],
 " with ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"]
}], "Section",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "ReadTurboRays", "16.", 
   "RG16."},ExpressionUUID->"e91ead7e-40a8-487a-bf8c-0484bf29162e"],

Cell[TextData[{
 "As shown previously with ",
 StyleBox["ReadRays", "Input"],
 " and ",
 StyleBox["AnalyzeSystem", "Input"],
 " in ",
 ButtonBox["Section 12",
  BaseStyle->"Hyperlink",
  ButtonData:>"12."],
 ", it is often desirable to get specific parameter values for a selected \
group of intersection points at an optical surface. ",
 StyleBox["ReadRays", "Input"],
 " also offers such functionality for ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " calculations by calling ",
 StyleBox["ReadTurboRays", "Input"],
 " internally."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ReadTurboRays", 
   "RG16."},ExpressionUUID->"e6500628-5d71-46fb-a65d-25f64f40cdac"],

Cell[TextData[{
 StyleBox["ReadTurboRays[", "Input"],
 StyleBox["results",
  FontSlant->"Italic"],
 ", ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 ", ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " takes ray-traced ",
 StyleBox["results",
  FontSlant->"Italic"],
 " from ",
 StyleBox["TurboPlot", "Input"],
 "/",
 StyleBox["TurboTrace", "Input"],
 " and returns a list of values for ",
 StyleBox["rayparameters",
  FontSlant->"Italic"],
 " and ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 " given. However, the ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 " parameter is optional and can be omitted."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ReadTurboRays", 
   "RG16."},ExpressionUUID->"fa23eb4b-123d-4b73-8c2a-049c29b39f31"],

Cell[TextData[{
 "Consequently, you either call ",
 StyleBox["ReadRays", "Input"],
 " or ",
 StyleBox["ReadTurboRays", "Input"],
 " without any change in behavior. As a demonstration, we will use the ",
 StyleBox["plot", "Input"],
 " result from the previous section to examine the optical path-length of \
rays at the screen surface. For this we will use the ",
 StyleBox["OpticalLength", "Input",
  FontFamily->"Courier"],
 ", as the ",
 StyleBox["rayparameter",
  FontSlant->"Italic"],
 ", together with ",
 StyleBox["ComponentNumber->2", "Input",
  FontFamily->"Courier"],
 ", as the ",
 StyleBox["selectionproperty",
  FontSlant->"Italic"],
 ", in ",
 StyleBox["ReadRays", "Input"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ReadTurboRays", 
   "RG16."},ExpressionUUID->"27dc19c8-3f1e-4113-8d48-6d8c91574faf"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["ReadRays", "Input",
  FontFamily->"Courier"],
 "[",
 StyleBox["plot", "Input"],
 ", OpticalLength, ComponentNumber->2]"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ReadTurboRays", "RG16."},
 CellLabel->"In[62]:=",ExpressionUUID->"ac39550a-adc9-476a-badc-8f596522a545"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "155.2735118748985`", ",", "155.24345535924897`", ",", 
   "155.23243898394722`", ",", "155.23058018966805`", ",", 
   "155.23171101443387`", ",", "155.23244752966428`", ",", 
   "155.23171101443387`", ",", "155.23058018966805`", ",", 
   "155.23243898394722`", ",", "155.24345535924897`", ",", 
   "155.2735118748985`"}], "}"}]], "Output",
 CellChangeTimes->{3.563367550628936*^9, 3.56608700759039*^9, 
  3.56610177740688*^9, 3.566139220505598*^9, 3.614707819093523*^9},
 CellTags->{"ReadTurboRays", "RG16."},
 CellLabel->"Out[62]=",ExpressionUUID->"c13cb3ca-df62-45ca-b807-f754b94cce80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["ReadTurboRays", "Input",
  FontFamily->"Courier"],
 "[",
 StyleBox["plot", "Input"],
 ", OpticalLength, ComponentNumber->2]"
}], "Input",
 PageBreakWithin->Automatic,
 AspectRatioFixed->True,
 CellTags->{"ReadTurboRays", "RG16."},
 CellLabel->"In[63]:=",ExpressionUUID->"946ef065-9abd-4fb3-be82-da7b516f91d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "155.2735118748985`", ",", "155.24345535924897`", ",", 
   "155.23243898394722`", ",", "155.23058018966805`", ",", 
   "155.23171101443387`", ",", "155.23244752966428`", ",", 
   "155.23171101443387`", ",", "155.23058018966805`", ",", 
   "155.23243898394722`", ",", "155.24345535924897`", ",", 
   "155.2735118748985`"}], "}"}]], "Output",
 CellChangeTimes->{3.563367550695401*^9, 3.566087007626204*^9, 
  3.566101777436975*^9, 3.566139220555951*^9, 3.6147078191275387`*^9},
 CellTags->{"ReadTurboRays", "RG16."},
 CellLabel->"Out[63]=",ExpressionUUID->"3f20e29b-88cd-423d-8ef8-208f94dec97c"]
}, Open  ]],

Cell[TextData[{
 "Since ",
 StyleBox["ReadRays", "Input"],
 " and ",
 StyleBox["ReadTurboRays", "Input"],
 " both work with ",
 StyleBox["TurboTrace", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 ", it can be easiest to simply use ",
 StyleBox["ReadRays", "Input"],
 " all of the time. You can learn more about ",
 StyleBox["TurboTrace", "Input"],
 ", ",
 StyleBox["TurboPlot", "Input"],
 ", ",
 StyleBox["OptimizeSystem", "Input"],
 ", and ",
 StyleBox["ReadTurboRays", "Input",
  FontFamily->"Courier"],
 " in ",
 ButtonBox["Section 3.6",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"3.6"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide."
}], "Text",
 CellTags->{
  "ReadTurboRays", 
   "RG16."},ExpressionUUID->"a97f46df-9b47-4469-9823-01f3549ca975"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"5b1727ec-11f1-466b-\
8ffa-b4a074884a97"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "17. Energy Calculations with ",
 StyleBox["FindIntensity",
  FontFamily->"Courier"]
}], "Section",
 CellTags->{
  "FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", 
   "RG17.0"},ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1"],

Cell[TextData[{
 "In addition to optimization, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " can also help you determine the light intensity profile at specified \
optical surfaces and to measure the transmitted energy through the optical \
system. This is accomplished with the ",
 StyleBox["FindIntensity", "Input"],
 " function."
}], "Text",
 CellTags->{
  "FindIntensity", "17. Introduction", "RG17.", "RG17.1", 
   "RG17.0"},ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8"],

Cell[TextData[{
 StyleBox["FindIntensity[", "Input",
  FontWeight->"Bold"],
 StyleBox["system",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 " calculates the intensity function for each optical surface that gets \
reported from the ray trace of the ",
 StyleBox["system",
  FontSlant->"Italic"],
 "."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "17. Introduction", "RG17.", "RG17.1", 
   "RG17.0"},ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b"],

Cell[TextData[{
 "For its input, ",
 StyleBox["FindIntensity", "Input",
  FontWeight->"Bold"],
 " works best with either an untraced \"raw\" optical system or a previously \
calculated result by ",
 StyleBox["FindIntensity", "Input",
  FontWeight->"Bold"],
 ". However, when required, ",
 StyleBox["FindIntensity", "Input"],
 " can also work with externally generated trace results. ",
 StyleBox["FindIntensity", "Input",
  FontWeight->"Bold"],
 " works equally well for surfaces that either are close to a focal plane or \
far from any focus. If a light sheet source is used ",
 StyleBox["(",
  FontWeight->"Bold"],
 "ie. ",
 StyleBox["WedgeOfRays", "Input",
  FontWeight->"Bold"],
 " or ",
 StyleBox["LineOfRays", "Input",
  FontWeight->"Bold"],
 StyleBox[")",
  FontWeight->"Bold"],
 ", then a one",
 StyleBox["-",
  FontWeight->"Bold"],
 "dimensional intensity function is automatically calculated by ",
 StyleBox["FindIntensity", "Input",
  FontWeight->"Bold"],
 ". If a volume-filling source is used ",
 StyleBox["(",
  FontWeight->"Bold"],
 "ie. ",
 StyleBox["PointOfRays", "Input",
  FontWeight->"Bold"],
 " or ",
 StyleBox["GridOfRays", "Input",
  FontWeight->"Bold"],
 StyleBox[")",
  FontWeight->"Bold"],
 ", then the intensity calculations are automatically carried out for each \
reported surface in two-dimensions. Because ",
 StyleBox["FindIntensity", "Input"],
 " does not calculate interference or keep track of the coherent phase \
information, it can only measure incoherent light flux properties."
}], "Text",
 CellTags->{
  "FindIntensity", "17. Introduction", "RG17.", "RG17.1", 
   "RG17.0"},ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"20a964d3-7fe5-429c-a9f8-92f8d718eb4d"],

Cell[CellGroupData[{

Cell["2-D Calculations with FindIntensity", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", 
   "17.1"},ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377"],

Cell[TextData[{
 "As an example, we will plot the intensity present for a planar \
cross-section of a Gaussian beam. We will use ",
 StyleBox["FullForm -> True", "Input"],
 " with the ",
 StyleBox["GaussianBeam", "Input"],
 " function to generate a three-dimensional pattern of rays. ",
 StyleBox["FindIntensity", "Input"],
 " uses the ",
 StyleBox["Plot2D", "Input"],
 " option to specify how the intensity information is rendered. With ",
 StyleBox["Plot2D -> False", "Input"],
 ", the intensity is rendered as a three-dimensional plot. (",
 StyleBox["Plot2D -> True", "Input"],
 " constructs a two-dimensional plot.) In addition, the plot is colored \
according to the intensity levels present."
}], "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"3309fe78-8bea-41d2-9e89-be26e8481dcc"],

Cell[CellGroupData[{

Cell["\<\
intensityresult = 
\tFindIntensity[{
\tGaussianBeam[10, .1, NumberOfRays->64, FullForm->True],
\tMove[Screen[50],50]}, Plot2D -> False]\
\>", "Input",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->"In[64]:=",ExpressionUUID->"047766fb-8eda-427a-9c3e-35823ea5836e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "4096"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.561663950801882`"}]}], "}"}]}],
  
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 1., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 4096, Optica`Optica`SmoothKernelSize -> 
    0.561663950801882}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5633675717284307`*^9, 3.5660870267323236`*^9, 
  3.566101799018676*^9, 3.56613924387715*^9, 3.61470783753615*^9},
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->
  "During evaluation of \
In[64]:=",ExpressionUUID->"0de2e702-472d-4a7d-a33a-128938072ae6"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxdnXW8VOUWhunu7j5wCFEJac5GOg1SUkAQaemQBgVUSqS7u1PibFJaGgRE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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtnHcAldMfxt977/u+573nRkmFCiXJlhSiMkrJzt4rmS0je2dkJkXKiKzs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         "]], 
        Polygon3DBox[CompressedData["
1:eJwtnHf8V9Mfx+/nc/f9kpCkoalJv1SolKzIbihSiWQlEiJllIzsvXf2yCgj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         "]], 
        Polygon3DBox[CompressedData["
1:eJwt13mYjuUCB+BvhqlwTlT2JcvkkKNJ1sYwdsaSbGNPIi0K2TKNrUIHLXLq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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0slL1GEAx+HXpsVyKzWz3PCaRXRNpWsZUWqZOtqhg5prqzraXlhWlods
soWIFJGIKB3EY4p0Nf0HjOja8g+Uj3T4zPM9zMD7e39TfKarqjMphPBZo5EQ
1vYIB1RkZ20KoZxR7bdjjOuYneCyOuw/zPDjB/ZeTvIIz+qLfZfj+mHP85si
ySH8Y8G6EIrtUh5kHXvUaI9wSv32V/7SqJ3mfCWasQ/zvl6oWXE9VouOb3AG
tqrSbmO7quwOdqra7uI5nbDP8yQv8KJq7Eu8rFN2N3tUa/cypjq7j/Xs5xVF
7au8pgb7Om+o0b7JWzpt3+ZDvdQdPdOwmrTs+Q5xtxJ2Kn+6g7i9yE+K2U/Y
rahdy3IeYL6K7L/ueUVJ9hzH9N27GGCLFuwKTnAP0zVo//Zel9RmT/Opjtq9
rNc+u4z3nOu5Cte+w0cqsGeZzzzN2Lu4Uwk7lzs0Zedwuz7a2fzALGbqvb2N
W/XOzmC6Ju00pmrCTuE4t3Cz3toeNzhieGNvpOsOr+31RHjlwxWFocj///8q
vl5WFw==
       "],
       VertexColors->None]}, {
      Line3DBox[{1811, 2260, 1810, 1390, 1812, 2261, 1813, 2680, 2262, 1814, 
       2263, 1815, 2681, 2264, 1816, 2265, 1817, 2682, 2266, 1818, 2267, 1819,
        2683, 2268, 1820, 2575, 2785, 1821, 2269, 1822, 2684, 2270, 1823, 
       2271, 1824, 2685, 2272, 1825, 2273, 1826, 2686, 2274, 1827, 2275, 1828,
        2687, 2276, 1829, 2576, 2786, 1830, 2277, 1831, 2688, 2278, 1832, 
       2279, 1833, 2689, 2280, 1834, 2281, 1835, 2690, 2282, 1836, 2283, 1837,
        2691, 2284, 1838, 2285, 1839},
       VertexColors->None], 
      Line3DBox[{1841, 2286, 1840, 2577, 2787, 1842, 2287, 1843, 1421, 1844, 
       2288, 1845, 2692, 2289, 1846, 2290, 1847, 2693, 2291, 1848, 2292, 1849,
        2694, 2293, 1850, 2578, 2788, 1851, 2294, 1852, 2579, 2789, 1853, 
       2295, 1854, 2695, 2296, 1855, 2297, 1856, 2696, 2298, 1857, 2299, 1858,
        2697, 2300, 1859, 2580, 2790, 1860, 2301, 1861, 2581, 2791, 1862, 
       2302, 1863, 2698, 2303, 1864, 2304, 1865, 2699, 2305, 1866, 2306, 1867,
        2700, 2307, 1868, 2308, 1869},
       VertexColors->None], 
      Line3DBox[{1871, 2309, 1870, 2582, 2792, 1872, 2310, 1873, 2583, 2793, 
       1874, 2311, 1875, 1452, 1876, 2312, 1877, 2701, 2313, 1878, 2314, 1879,
        2702, 2315, 1880, 2584, 2794, 1881, 2316, 1882, 2585, 2795, 1883, 
       2317, 1884, 2586, 2796, 1885, 2318, 1886, 2703, 2319, 1887, 2320, 1888,
        2704, 2321, 1889, 2587, 2797, 1890, 2322, 1891, 2588, 2798, 1892, 
       2323, 1893, 2589, 2799, 1894, 2324, 1895, 2705, 2325, 1896, 2326, 1897,
        2706, 2327, 1898, 2328, 1899},
       VertexColors->None], 
      Line3DBox[{1901, 2329, 1900, 2590, 2800, 1902, 2330, 1903, 2591, 2801, 
       1904, 2331, 1905, 2592, 2802, 1906, 2332, 1907, 1483, 1908, 2333, 1909,
        2707, 2334, 1910, 2593, 2803, 1911, 2335, 1912, 2594, 2804, 1913, 
       2336, 1914, 2595, 2805, 1915, 2337, 1916, 2596, 2806, 1917, 2338, 1918,
        2708, 2339, 1919, 2597, 2807, 1920, 2340, 1921, 2598, 2808, 1922, 
       2341, 1923, 2599, 2809, 1924, 2342, 1925, 2600, 2810, 1926, 2343, 1927,
        2709, 2344, 1928, 2345, 1929},
       VertexColors->None], 
      Line3DBox[{1931, 2346, 1930, 2601, 2811, 1932, 2347, 1933, 2602, 2812, 
       1934, 2348, 1935, 2603, 2813, 1936, 2349, 1937, 2604, 2814, 1938, 2350,
        1939, 1514, 1940, 2605, 2815, 1941, 2351, 1942, 2606, 2816, 1943, 
       2352, 1944, 2607, 2817, 1945, 2353, 1946, 2608, 2818, 1947, 2354, 1948,
        2609, 2819, 1949, 2610, 2820, 1950, 2355, 1951, 2611, 2821, 1952, 
       2356, 1953, 2612, 2822, 1954, 2357, 1955, 2613, 2823, 1956, 2358, 1957,
        2614, 2824, 1958, 2359, 1959},
       VertexColors->None], 
      Line3DBox[{1961, 2360, 1960, 2710, 2361, 1962, 2362, 1963, 2711, 2363, 
       1964, 2364, 1965, 2712, 2365, 1966, 2366, 1967, 2713, 2367, 1968, 2368,
        1969, 2714, 2369, 1970, 1530, 1971, 2370, 1972, 2715, 2371, 1973, 
       2372, 1974, 2716, 2373, 1975, 2374, 1976, 2717, 2375, 1977, 2376, 1978,
        2718, 2377, 1979, 2615, 2825, 1980, 2378, 1981, 2719, 2379, 1982, 
       2380, 1983, 2720, 2381, 1984, 2382, 1985, 2721, 2383, 1986, 2384, 1987,
        2722, 2385, 1988, 2386, 1989},
       VertexColors->None], 
      Line3DBox[{1991, 2387, 1990, 2616, 2826, 1992, 2388, 1993, 2723, 2389, 
       1994, 2390, 1995, 2724, 2391, 1996, 2392, 1997, 2725, 2393, 1998, 2394,
        1999, 2726, 2395, 2000, 2617, 2827, 2001, 2396, 2002, 1561, 2003, 
       2397, 2004, 2727, 2398, 2005, 2399, 2006, 2728, 2400, 2007, 2401, 2008,
        2729, 2402, 2009, 2618, 2828, 2010, 2403, 2011, 2619, 2829, 2012, 
       2404, 2013, 2730, 2405, 2014, 2406, 2015, 2731, 2407, 2016, 2408, 2017,
        2732, 2409, 2018, 2410, 2019},
       VertexColors->None], 
      Line3DBox[{2021, 2411, 2020, 2620, 2830, 2022, 2412, 2023, 2621, 2831, 
       2024, 2413, 2025, 2733, 2414, 2026, 2415, 2027, 2734, 2416, 2028, 2417,
        2029, 2735, 2418, 2030, 2622, 2832, 2031, 2419, 2032, 2623, 2833, 
       2033, 2420, 2034, 1592, 2035, 2421, 2036, 2736, 2422, 2037, 2423, 2038,
        2737, 2424, 2039, 2624, 2834, 2040, 2425, 2041, 2625, 2835, 2042, 
       2426, 2043, 2626, 2836, 2044, 2427, 2045, 2738, 2428, 2046, 2429, 2047,
        2739, 2430, 2048, 2431, 2049},
       VertexColors->None], 
      Line3DBox[{2051, 2432, 2050, 2627, 2837, 2052, 2433, 2053, 2628, 2838, 
       2054, 2434, 2055, 2629, 2839, 2056, 2435, 2057, 2740, 2436, 2058, 2437,
        2059, 2741, 2438, 2060, 2630, 2840, 2061, 2439, 2062, 2631, 2841, 
       2063, 2440, 2064, 2632, 2842, 2065, 2441, 2066, 1623, 2067, 2442, 2068,
        2742, 2443, 2069, 2633, 2843, 2070, 2444, 2071, 2634, 2844, 2072, 
       2445, 2073, 2635, 2845, 2074, 2446, 2075, 2636, 2846, 2076, 2447, 2077,
        2743, 2448, 2078, 2449, 2079},
       VertexColors->None], 
      Line3DBox[{2081, 2450, 2080, 2637, 2847, 2082, 2451, 2083, 2638, 2848, 
       2084, 2452, 2085, 2639, 2849, 2086, 2453, 2087, 2640, 2850, 2088, 2454,
        2089, 2744, 2455, 2090, 2641, 2851, 2091, 2456, 2092, 2642, 2852, 
       2093, 2457, 2094, 2643, 2853, 2095, 2458, 2096, 2644, 2854, 2097, 2459,
        2098, 1654, 2099, 2645, 2855, 2100, 2460, 2101, 2646, 2856, 2102, 
       2461, 2103, 2647, 2857, 2104, 2462, 2105, 2648, 2858, 2106, 2463, 2107,
        2649, 2859, 2108, 2464, 2109},
       VertexColors->None], 
      Line3DBox[{2111, 2465, 2110, 2745, 2466, 2112, 2467, 2113, 2746, 2468, 
       2114, 2469, 2115, 2747, 2470, 2116, 2471, 2117, 2748, 2472, 2118, 2473,
        2119, 2749, 2474, 2120, 2750, 2475, 2121, 2476, 2122, 2751, 2477, 
       2123, 2478, 2124, 2752, 2479, 2125, 2480, 2126, 2753, 2481, 2127, 2482,
        2128, 2754, 2483, 2129, 1670, 2130, 2484, 2131, 2755, 2485, 2132, 
       2486, 2133, 2756, 2487, 2134, 2488, 2135, 2757, 2489, 2136, 2490, 2137,
        2758, 2491, 2138, 2492, 2139},
       VertexColors->None], 
      Line3DBox[{2141, 2493, 2140, 2650, 2860, 2142, 2494, 2143, 2759, 2495, 
       2144, 2496, 2145, 2760, 2497, 2146, 2498, 2147, 2761, 2499, 2148, 2500,
        2149, 2762, 2501, 2150, 2651, 2861, 2151, 2502, 2152, 2763, 2503, 
       2153, 2504, 2154, 2764, 2505, 2155, 2506, 2156, 2765, 2507, 2157, 2508,
        2158, 2766, 2509, 2159, 2652, 2862, 2160, 2510, 2161, 1701, 2162, 
       2511, 2163, 2767, 2512, 2164, 2513, 2165, 2768, 2514, 2166, 2515, 2167,
        2769, 2516, 2168, 2517, 2169},
       VertexColors->None], 
      Line3DBox[{2171, 2518, 2170, 2653, 2863, 2172, 2519, 2173, 2654, 2864, 
       2174, 2520, 2175, 2770, 2521, 2176, 2522, 2177, 2771, 2523, 2178, 2524,
        2179, 2772, 2525, 2180, 2655, 2865, 2181, 2526, 2182, 2656, 2866, 
       2183, 2527, 2184, 2773, 2528, 2185, 2529, 2186, 2774, 2530, 2187, 2531,
        2188, 2775, 2532, 2189, 2657, 2867, 2190, 2533, 2191, 2658, 2868, 
       2192, 2534, 2193, 1732, 2194, 2535, 2195, 2776, 2536, 2196, 2537, 2197,
        2777, 2538, 2198, 2539, 2199},
       VertexColors->None], 
      Line3DBox[{2201, 2540, 2200, 2659, 2869, 2202, 2541, 2203, 2660, 2870, 
       2204, 2542, 2205, 2661, 2871, 2206, 2543, 2207, 2778, 2544, 2208, 2545,
        2209, 2779, 2546, 2210, 2662, 2872, 2211, 2547, 2212, 2663, 2873, 
       2213, 2548, 2214, 2664, 2874, 2215, 2549, 2216, 2780, 2550, 2217, 2551,
        2218, 2781, 2552, 2219, 2665, 2875, 2220, 2553, 2221, 2666, 2876, 
       2222, 2554, 2223, 2667, 2877, 2224, 2555, 2225, 1763, 2226, 2556, 2227,
        2782, 2557, 2228, 2558, 2229},
       VertexColors->None], 
      Line3DBox[{2231, 2559, 2230, 2668, 2878, 2232, 2560, 2233, 2669, 2879, 
       2234, 2561, 2235, 2670, 2880, 2236, 2562, 2237, 2671, 2881, 2238, 2563,
        2239, 2783, 2564, 2240, 2672, 2882, 2241, 2565, 2242, 2673, 2883, 
       2243, 2566, 2244, 2674, 2884, 2245, 2567, 2246, 2675, 2885, 2247, 2568,
        2248, 2784, 2569, 2249, 2676, 2886, 2250, 2570, 2251, 2677, 2887, 
       2252, 2571, 2253, 2678, 2888, 2254, 2572, 2255, 2679, 2889, 2256, 2573,
        2257, 1794, 2258, 2574, 2259},
       VertexColors->None]}, {
      Line3DBox[{925, 1375, 926, 1390, 955, 1405, 970, 2787, 1420, 985, 1435, 
       1000, 2792, 1450, 1015, 1465, 1030, 2800, 1480, 1045, 1495, 1060, 2811,
        1510, 1075, 1525, 2710, 1090, 1540, 1105, 2826, 1555, 1120, 1570, 
       1135, 2830, 1585, 1150, 1600, 1165, 2837, 1615, 1180, 1630, 1195, 2847,
        1645, 1210, 1660, 2745, 1225, 1675, 1240, 2860, 1690, 1255, 1705, 
       1270, 2863, 1720, 1285, 1735, 1300, 2869, 1750, 1315, 1765, 1330, 2878,
        1780, 1345, 1795, 1360},
       VertexColors->None], 
      Line3DBox[{927, 1376, 928, 1391, 2680, 956, 1406, 971, 1421, 986, 1436, 
       1001, 2793, 1451, 1016, 1466, 1031, 2801, 1481, 1046, 1496, 1061, 2812,
        1511, 1076, 1526, 2711, 1091, 1541, 1106, 1556, 2723, 1121, 1571, 
       1136, 2831, 1586, 1151, 1601, 1166, 2838, 1616, 1181, 1631, 1196, 2848,
        1646, 1211, 1661, 2746, 1226, 1676, 1241, 1691, 2759, 1256, 1706, 
       1271, 2864, 1721, 1286, 1736, 1301, 2870, 1751, 1316, 1766, 1331, 2879,
        1781, 1346, 1796, 1361},
       VertexColors->None], 
      Line3DBox[{929, 1377, 930, 1392, 2681, 957, 1407, 972, 1422, 2692, 987, 
       1437, 1002, 1452, 1017, 1467, 1032, 2802, 1482, 1047, 1497, 1062, 2813,
        1512, 1077, 1527, 2712, 1092, 1542, 1107, 1557, 2724, 1122, 1572, 
       1137, 1587, 2733, 1152, 1602, 1167, 2839, 1617, 1182, 1632, 1197, 2849,
        1647, 1212, 1662, 2747, 1227, 1677, 1242, 1692, 2760, 1257, 1707, 
       1272, 1722, 2770, 1287, 1737, 1302, 2871, 1752, 1317, 1767, 1332, 2880,
        1782, 1347, 1797, 1362},
       VertexColors->None], 
      Line3DBox[{931, 1378, 932, 1393, 2682, 958, 1408, 973, 1423, 2693, 988, 
       1438, 1003, 1453, 2701, 1018, 1468, 1033, 1483, 1048, 1498, 1063, 2814,
        1513, 1078, 1528, 2713, 1093, 1543, 1108, 1558, 2725, 1123, 1573, 
       1138, 1588, 2734, 1153, 1603, 1168, 1618, 2740, 1183, 1633, 1198, 2850,
        1648, 1213, 1663, 2748, 1228, 1678, 1243, 1693, 2761, 1258, 1708, 
       1273, 1723, 2771, 1288, 1738, 1303, 1753, 2778, 1318, 1768, 1333, 2881,
        1783, 1348, 1798, 1363},
       VertexColors->None], 
      Line3DBox[{933, 1379, 934, 1394, 2683, 959, 1409, 974, 1424, 2694, 989, 
       1439, 1004, 1454, 2702, 1019, 1469, 1034, 1484, 2707, 1049, 1499, 1064,
        1514, 1079, 1529, 2714, 1094, 1544, 1109, 1559, 2726, 1124, 1574, 
       1139, 1589, 2735, 1154, 1604, 1169, 1619, 2741, 1184, 1634, 1199, 1649,
        2744, 1214, 1664, 2749, 1229, 1679, 1244, 1694, 2762, 1259, 1709, 
       1274, 1724, 2772, 1289, 1739, 1304, 1754, 2779, 1319, 1769, 1334, 1784,
        2783, 1349, 1799, 1364},
       VertexColors->None], 
      Line3DBox[{935, 1380, 936, 2785, 1395, 960, 1410, 975, 2788, 1425, 990, 
       1440, 1005, 2794, 1455, 1020, 1470, 1035, 2803, 1485, 1050, 1500, 1065,
        2815, 1515, 1080, 1530, 1095, 1545, 1110, 2827, 1560, 1125, 1575, 
       1140, 2832, 1590, 1155, 1605, 1170, 2840, 1620, 1185, 1635, 1200, 2851,
        1650, 1215, 1665, 2750, 1230, 1680, 1245, 2861, 1695, 1260, 1710, 
       1275, 2865, 1725, 1290, 1740, 1305, 2872, 1755, 1320, 1770, 1335, 2882,
        1785, 1350, 1800, 1365},
       VertexColors->None], 
      Line3DBox[{937, 1381, 938, 1396, 2684, 961, 1411, 976, 2789, 1426, 991, 
       1441, 1006, 2795, 1456, 1021, 1471, 1036, 2804, 1486, 1051, 1501, 1066,
        2816, 1516, 1081, 1531, 2715, 1096, 1546, 1111, 1561, 1126, 1576, 
       1141, 2833, 1591, 1156, 1606, 1171, 2841, 1621, 1186, 1636, 1201, 2852,
        1651, 1216, 1666, 2751, 1231, 1681, 1246, 1696, 2763, 1261, 1711, 
       1276, 2866, 1726, 1291, 1741, 1306, 2873, 1756, 1321, 1771, 1336, 2883,
        1786, 1351, 1801, 1366},
       VertexColors->None], 
      Line3DBox[{939, 1382, 940, 1397, 2685, 962, 1412, 977, 1427, 2695, 992, 
       1442, 1007, 2796, 1457, 1022, 1472, 1037, 2805, 1487, 1052, 1502, 1067,
        2817, 1517, 1082, 1532, 2716, 1097, 1547, 1112, 1562, 2727, 1127, 
       1577, 1142, 1592, 1157, 1607, 1172, 2842, 1622, 1187, 1637, 1202, 2853,
        1652, 1217, 1667, 2752, 1232, 1682, 1247, 1697, 2764, 1262, 1712, 
       1277, 1727, 2773, 1292, 1742, 1307, 2874, 1757, 1322, 1772, 1337, 2884,
        1787, 1352, 1802, 1367},
       VertexColors->None], 
      Line3DBox[{941, 1383, 942, 1398, 2686, 963, 1413, 978, 1428, 2696, 993, 
       1443, 1008, 1458, 2703, 1023, 1473, 1038, 2806, 1488, 1053, 1503, 1068,
        2818, 1518, 1083, 1533, 2717, 1098, 1548, 1113, 1563, 2728, 1128, 
       1578, 1143, 1593, 2736, 1158, 1608, 1173, 1623, 1188, 1638, 1203, 2854,
        1653, 1218, 1668, 2753, 1233, 1683, 1248, 1698, 2765, 1263, 1713, 
       1278, 1728, 2774, 1293, 1743, 1308, 1758, 2780, 1323, 1773, 1338, 2885,
        1788, 1353, 1803, 1368},
       VertexColors->None], 
      Line3DBox[{943, 1384, 944, 1399, 2687, 964, 1414, 979, 1429, 2697, 994, 
       1444, 1009, 1459, 2704, 1024, 1474, 1039, 1489, 2708, 1054, 1504, 1069,
        2819, 1519, 1084, 1534, 2718, 1099, 1549, 1114, 1564, 2729, 1129, 
       1579, 1144, 1594, 2737, 1159, 1609, 1174, 1624, 2742, 1189, 1639, 1204,
        1654, 1219, 1669, 2754, 1234, 1684, 1249, 1699, 2766, 1264, 1714, 
       1279, 1729, 2775, 1294, 1744, 1309, 1759, 2781, 1324, 1774, 1339, 1789,
        2784, 1354, 1804, 1369},
       VertexColors->None], 
      Line3DBox[{945, 1385, 946, 2786, 1400, 965, 1415, 980, 2790, 1430, 995, 
       1445, 1010, 2797, 1460, 1025, 1475, 1040, 2807, 1490, 1055, 1505, 1070,
        2820, 1520, 1085, 2825, 1535, 1100, 1550, 1115, 2828, 1565, 1130, 
       1580, 1145, 2834, 1595, 1160, 1610, 1175, 2843, 1625, 1190, 1640, 1205,
        2855, 1655, 1220, 1670, 1235, 1685, 1250, 2862, 1700, 1265, 1715, 
       1280, 2867, 1730, 1295, 1745, 1310, 2875, 1760, 1325, 1775, 1340, 2886,
        1790, 1355, 1805, 1370},
       VertexColors->None], 
      Line3DBox[{947, 1386, 948, 1401, 2688, 966, 1416, 981, 2791, 1431, 996, 
       1446, 1011, 2798, 1461, 1026, 1476, 1041, 2808, 1491, 1056, 1506, 1071,
        2821, 1521, 1086, 1536, 2719, 1101, 1551, 1116, 2829, 1566, 1131, 
       1581, 1146, 2835, 1596, 1161, 1611, 1176, 2844, 1626, 1191, 1641, 1206,
        2856, 1656, 1221, 1671, 2755, 1236, 1686, 1251, 1701, 1266, 1716, 
       1281, 2868, 1731, 1296, 1746, 1311, 2876, 1761, 1326, 1776, 1341, 2887,
        1791, 1356, 1806, 1371},
       VertexColors->None], 
      Line3DBox[{949, 1387, 950, 1402, 2689, 967, 1417, 982, 1432, 2698, 997, 
       1447, 1012, 2799, 1462, 1027, 1477, 1042, 2809, 1492, 1057, 1507, 1072,
        2822, 1522, 1087, 1537, 2720, 1102, 1552, 1117, 1567, 2730, 1132, 
       1582, 1147, 2836, 1597, 1162, 1612, 1177, 2845, 1627, 1192, 1642, 1207,
        2857, 1657, 1222, 1672, 2756, 1237, 1687, 1252, 1702, 2767, 1267, 
       1717, 1282, 1732, 1297, 1747, 1312, 2877, 1762, 1327, 1777, 1342, 2888,
        1792, 1357, 1807, 1372},
       VertexColors->None], 
      Line3DBox[{951, 1388, 952, 1403, 2690, 968, 1418, 983, 1433, 2699, 998, 
       1448, 1013, 1463, 2705, 1028, 1478, 1043, 2810, 1493, 1058, 1508, 1073,
        2823, 1523, 1088, 1538, 2721, 1103, 1553, 1118, 1568, 2731, 1133, 
       1583, 1148, 1598, 2738, 1163, 1613, 1178, 2846, 1628, 1193, 1643, 1208,
        2858, 1658, 1223, 1673, 2757, 1238, 1688, 1253, 1703, 2768, 1268, 
       1718, 1283, 1733, 2776, 1298, 1748, 1313, 1763, 1328, 1778, 1343, 2889,
        1793, 1358, 1808, 1373},
       VertexColors->None], 
      Line3DBox[{953, 1389, 954, 1404, 2691, 969, 1419, 984, 1434, 2700, 999, 
       1449, 1014, 1464, 2706, 1029, 1479, 1044, 1494, 2709, 1059, 1509, 1074,
        2824, 1524, 1089, 1539, 2722, 1104, 1554, 1119, 1569, 2732, 1134, 
       1584, 1149, 1599, 2739, 1164, 1614, 1179, 1629, 2743, 1194, 1644, 1209,
        2859, 1659, 1224, 1674, 2758, 1239, 1689, 1254, 1704, 2769, 1269, 
       1719, 1284, 1734, 2777, 1299, 1749, 1314, 1764, 2782, 1329, 1779, 1344,
        1794, 1359, 1809, 1374},
       VertexColors->None]}, {}, {}}},
   VertexColors->{
     Hue[0.6499999708035517, 1, 0.10000004042585155`], 
     Hue[0.6499501349069793, 1, 0.10006904397495173`], 
     Hue[0.6498830409238536, 1, 0.10016194333620275`], 
     Hue[0.6498461977051377, 1, 0.1002129570236554], 
     Hue[0.6498030896255687, 1, 0.10027264513382812`], 
     Hue[0.6497535139635646, 1, 0.10034128835814127`], 
     Hue[0.6496983097028106, 1, 0.1004177250268776], 
     Hue[0.6496389419655233, 1, 0.10049992650927547`], 
     Hue[0.649577478494239, 1, 0.10058502977720765`], 
     Hue[0.6495165254872346, 1, 0.1006694262484444], 
     Hue[0.6494590585595534, 1, 0.10074899584061832`], 
     Hue[0.649408198526006, 1, 0.10081941742553022`], 
     Hue[0.6493669337431704, 1, 0.10087655327868715`], 
     Hue[0.6493378392973852, 1, 0.1009168378959282], 
     Hue[0.6493227485192283, 1, 0.10093773281953008`], 
     Hue[0.6493225234655081, 1, 0.10093804443237338`], 
     Hue[0.6493375546952845, 1, 0.10091723196037532`], 
     Hue[0.6493666872241856, 1, 0.10087689461266622`], 
     Hue[0.6494080042211439, 1, 0.1008196864630316], 
     Hue[0.6494589248602171, 1, 0.10074918096277648`], 
     Hue[0.6495164551284213, 1, 0.1006695236683399], 
     Hue[0.6495774685201788, 1, 0.10058504358744468`], 
     Hue[0.6496389846755347, 1, 0.10049986737233654`], 
     Hue[0.649698394426526, 1, 0.10041760771711797`], 
     Hue[0.6497536281731384, 1, 0.10034113022180839`], 
     Hue[0.6498032208248107, 1, 0.10027246347333903`], 
     Hue[0.6498463345952484, 1, 0.10021276748350222`], 
     Hue[0.6498831956240974, 1, 0.10016172913586517`], 
     Hue[0.649950728657251, 1, 0.10006822185919101`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499501349069793, 1, 0.10006904397495173`], 
     Hue[0.6464573223024352, 1, 0.10490524604278194`], 
     Hue[0.641724777803142, 1, 0.11145799996488044`], 
     Hue[0.6391313531926319, 1, 0.11504889557943282`], 
     Hue[0.6360971833227743, 1, 0.11925005386077399`], 
     Hue[0.6326073703548722, 1, 0.12408210258556153`], 
     Hue[0.628721200901634, 1, 0.1294629525977376], 
     Hue[0.6245414168247752, 1, 0.13525034593492677`], 
     Hue[0.6202138963403885, 1, 0.14124229737484675`], 
     Hue[0.615921994799832, 1, 0.14718493027715576`], 
     Hue[0.6118753120591388, 1, 0.15278802945657702`], 
     Hue[0.6082937016181819, 1, 0.1577471823748251], 
     Hue[0.6053877795136546, 1, 0.16177076682724745`], 
     Hue[0.6033385675660863, 1, 0.1646081372161882], 
     Hue[0.6022780343317817, 1, 0.16607656784830227`], 
     Hue[0.602273455287948, 1, 0.16608290806284134`], 
     Hue[0.6033327766268467, 1, 0.16461615543975083`], 
     Hue[0.6053827643478744, 1, 0.16177771090294313`], 
     Hue[0.6082897478234982, 1, 0.1577526568597717], 
     Hue[0.6118725930131017, 1, 0.15279179428955145`], 
     Hue[0.6159205640488971, 1, 0.14718691131691175`], 
     Hue[0.6202136935615623, 1, 0.14124257814552912`], 
     Hue[0.624542287547754, 1, 0.13524914031849444`], 
     Hue[0.6287229249078186, 1, 0.12946056551225132`], 
     Hue[0.6326096948107707, 1, 0.12407888410816373`], 
     Hue[0.6360998533911139, 1, 0.11924635684307319`], 
     Hue[0.6391341378578641, 1, 0.1150450398891113], 
     Hue[0.6417279253205035, 1, 0.11145364186391826`], 
     Hue[0.6464693972464388, 1, 0.10488852688954636`], 
     Hue[0.649950728657251, 1, 0.10006822185919101`], 
     Hue[0.6498830409238536, 1, 0.10016194333620275`], 
     Hue[0.641724777803142, 1, 0.11145799996488044`], 
     Hue[0.6306434748977874, 1, 0.12680134244921756`], 
     Hue[0.6245727303868367, 1, 0.13520698869514916`], 
     Hue[0.6174696271668445, 1, 0.14504205469206152`], 
     Hue[0.6092986732582469, 1, 0.15635568318088897`], 
     Hue[0.6001985108332903, 1, 0.16895590807698263`], 
     Hue[0.5904096633353364, 1, 0.18250969692030347`], 
     Hue[0.5802737763923936, 1, 0.1965440019182242], 
     Hue[0.5702204021385245, 1, 0.2104640585774276], 
     Hue[0.5607407492766581, 1, 0.22358973177078117`], 
     Hue[0.5523500286717988, 1, 0.23520765260827858`], 
     Hue[0.5455419279510902, 1, 0.2446342536061827], 
     Hue[0.5407408069589723, 1, 0.2512819595952691], 
     Hue[0.5382576968540977, 1, 0.25472011204817235`], 
     Hue[0.5382564959967934, 1, 0.25472177477367075`], 
     Hue[0.5407392886284856, 1, 0.2512840618990199], 
     Hue[0.5455406136566957, 1, 0.24463607339842136`], 
     Hue[0.5523489934508787, 1, 0.23520908599109094`], 
     Hue[0.5607400386245786, 1, 0.2235907157505836], 
     Hue[0.5702200298684389, 1, 0.21046457402831537`], 
     Hue[0.5802737264094405, 1, 0.1965440711253901], 
     Hue[0.5904098947812237, 1, 0.1825093764567671], 
     Hue[0.6001989655967652, 1, 0.16895527840447902`], 
     Hue[0.6092992847532812, 1, 0.15635483649545684`], 
     Hue[0.6174703284313343, 1, 0.1450410837104602], 
     Hue[0.6245734607680122, 1, 0.135205977398137], 
     Hue[0.6306442987596863, 1, 0.1268002017173574], 
     Hue[0.6417279253205034, 1, 0.11145364186391847`], 
     Hue[0.6498831956240974, 1, 0.10016172913586517`], 
     Hue[0.6498461977051377, 1, 0.1002129570236554], 
     Hue[0.6391313531926319, 1, 0.11504889557943282`], 
     Hue[0.6245727303868367, 1, 0.13520698869514916`], 
     Hue[0.6165921083515689, 1, 0.14625708074398155`], 
     Hue[0.6072526403378198, 1, 0.15918865183994185`], 
     Hue[0.5965074304344584, 1, 0.17406663478305767`], 
     Hue[0.5845385676182782, 1, 0.19063890637469175`], 
     Hue[0.5716622801396413, 1, 0.20846761211434295`], 
     Hue[0.5583280015998117, 1, 0.2269304593233377], 
     Hue[0.5451009821631014, 1, 0.24524479392801346`], 
     Hue[0.532627770676394, 1, 0.2625153944480699], 
     Hue[0.5215866154536093, 1, 0.27780314783346405`], 
     Hue[0.5126275239482238, 1, 0.2902080437639979], 
     Hue[0.5063092649943484, 1, 0.2989564023155178], 
     Hue[0.5030415295754531, 1, 0.30348095904937267`], 
     Hue[0.5030404640559991, 1, 0.30348243438400135`], 
     Hue[0.5063079178181413, 1, 0.2989582676364198], 
     Hue[0.5126263581144319, 1, 0.290209657995402], 
     Hue[0.521585697641151, 1, 0.277804418650714], 
     Hue[0.5326271410244354, 1, 0.2625162662738587], 
     Hue[0.545100653122046, 1, 0.24524524952332097`], 
     Hue[0.5583279587081368, 1, 0.22693051871181064`], 
     Hue[0.5716624867457912, 1, 0.20846732604428905`], 
     Hue[0.5845389723395107, 1, 0.1906383459914468], 
     Hue[0.5965079738472142, 1, 0.17406588236539575`], 
     Hue[0.607253262945072, 1, 0.15918778976836193`], 
     Hue[0.6165927565645893, 1, 0.14625618321826095`], 
     Hue[0.6245734607680122, 1, 0.1352059773981369], 
     Hue[0.6391341378578639, 1, 0.11504503988911155`], 
     Hue[0.6498463345952484, 1, 0.10021276748350222`], 
     Hue[0.6498030896255687, 1, 0.10027264513382812`], 
     Hue[0.6360971833227743, 1, 0.11925005386077399`], 
     Hue[0.6174696271668445, 1, 0.14504205469206152`], 
     Hue[0.6072526403378198, 1, 0.15918865183994185`], 
     Hue[0.5952940078074799, 1, 0.1757467584204125], 
     Hue[0.5815334198863941, 1, 0.1947998801573005], 
     Hue[0.5662037895546834, 1, 0.21602552215505372`], 
     Hue[0.5497100013722023, 1, 0.2388630750231046], 
     Hue[0.5326277913778148, 1, 0.26251536578456425`], 
     Hue[0.5156814663990663, 1, 0.28597950806283134`], 
     Hue[0.4996997067575764, 1, 0.30810809833566344`], 
     Hue[0.4855519334973518, 1, 0.3276973228498206], 
     Hue[0.4740715013952571, 1, 0.34359330576041325`], 
     Hue[0.46597482804496104`, 1, 0.3548040842454385], 
     Hue[0.46178728216934245`, 1, 0.3606022246886028], 
     Hue[0.46178625847117905`, 1, 0.36060364211682905`], 
     Hue[0.46597353397213837`, 1, 0.3548058760385777], 
     Hue[0.47407038168998694`, 1, 0.3435948561215566], 
     Hue[0.4855510522150247, 1, 0.32769854308688884`], 
     Hue[0.4996991026302832, 1, 0.3081089348196079], 
     Hue[0.5156811510231455, 1, 0.2859799447371832], 
     Hue[0.5326277508879955, 1, 0.26251542184739085`], 
     Hue[0.5497102008098526, 1, 0.23886279887866568`], 
     Hue[0.566204178904602, 1, 0.2160249830551666], 
     Hue[0.5815339424268632, 1, 0.19479915663972797`], 
     Hue[0.5952946063665869, 1, 0.17574592964626434`], 
     Hue[0.607253262945072, 1, 0.15918778976836187`], 
     Hue[0.6174703284313344, 1, 0.14504108371046004`], 
     Hue[0.6360998533911136, 1, 0.1192463568430735], 
     Hue[0.6498032208248107, 1, 0.10027246347333903`], 
     Hue[0.6497535139635646, 1, 0.10034128835814127`], 
     Hue[0.6326073703548722, 1, 0.12408210258556153`], 
     Hue[0.6092986732582468, 1, 0.15635568318088897`], 
     Hue[0.5965074304344584, 1, 0.17406663478305762`], 
     Hue[0.5815334198863941, 1, 0.19479988015730054`], 
     Hue[0.5643008298468729, 1, 0.21866038944279143`], 
     Hue[0.545101007506637, 1, 0.24524475883696412`], 
     Hue[0.5244409336357099, 1, 0.2738510149659401], 
     Hue[0.5030417915253734, 1, 0.303480596349483], 
     Hue[0.4818111283712805, 1, 0.33287689917822705`], 
     Hue[0.461787524939957, 1, 0.360601888544675], 
     Hue[0.44406072296108073`, 1, 0.3851466912846575], 
     Hue[0.42967539275756805`, 1, 0.4050648407972135], 
     Hue[0.4195297118980599, 1, 0.4191127066026864], 
     Hue[0.4142823966531054, 1, 0.42637822001877723`], 
     Hue[0.41428150329811164`, 1, 0.4263794569718454], 
     Hue[0.41952858263311266`, 1, 0.41911427020030556`], 
     Hue[0.4296744158266314, 1, 0.40506619347081807`], 
     Hue[0.44405995434766954`, 1, 0.38514775551861136`], 
     Hue[0.46178699841355336`, 1, 0.3606026175812338], 
     Hue[0.48181085405609525`, 1, 0.3328772789992527], 
     Hue[0.5030417571916423, 1, 0.30348064388849516`], 
     Hue[0.5244411085622436, 1, 0.2738507727599705], 
     Hue[0.5451013481926239, 1, 0.24524428711790539`], 
     Hue[0.5643012865415892, 1, 0.21865975709626115`], 
     Hue[0.5815339424268628, 1, 0.1947991566397283], 
     Hue[0.596507973847214, 1, 0.17406588236539608`], 
     Hue[0.6092992847532812, 1, 0.15635483649545684`], 
     Hue[0.6326096948107703, 1, 0.12407888410816416`], 
     Hue[0.6497536281731384, 1, 0.10034113022180839`], 
     Hue[0.6496983097028106, 1, 0.1004177250268776], 
     Hue[0.628721200901634, 1, 0.1294629525977376], 
     Hue[0.6001985108332903, 1, 0.16895590807698269`], 
     Hue[0.5845385676182782, 1, 0.1906389063746918], 
     Hue[0.5662037895546834, 1, 0.21602552215505372`], 
     Hue[0.545101007506637, 1, 0.24524475883696412`], 
     Hue[0.521586688030249, 1, 0.27780304734273226`], 
     Hue[0.4962815230897488, 1, 0.3128409680295786], 
     Hue[0.4700689058025471, 1, 0.34913536119647326`], 
     Hue[0.4440607762893021, 1, 0.3851466174455819], 
     Hue[0.4195297739541015, 1, 0.4191126206789364], 
     Hue[0.3978115050201396, 1, 0.44918406997211446`], 
     Hue[0.3801863883092052, 1, 0.4735880777257159], 
     Hue[0.36775539250878636`, 1, 0.49080022575706506`], 
     Hue[0.3613260963423509, 1, 0.4997023281413603], 
     Hue[0.36132543116871485`, 1, 0.49970324915101016`], 
     Hue[0.3677545517203828, 1, 0.49080138992562383`], 
     Hue[0.3801856611748639, 1, 0.47358908452711157`], 
     Hue[0.3978109332902876, 1, 0.44918486159806337`], 
     Hue[0.41952938271066786`, 1, 0.4191131624006138], 
     Hue[0.4440605731298055, 1, 0.3851468987433463], 
     Hue[0.47006888141789416`, 1, 0.3491353949598389], 
     Hue[0.49628165443031574`, 1, 0.31284078617340905`], 
     Hue[0.5215869427511122, 1, 0.2778026946523062], 
     Hue[0.5451013481926242, 1, 0.2452442871179049], 
     Hue[0.566204178904602, 1, 0.2160249830551666], 
     Hue[0.5845389723395107, 1, 0.19063834599144672`], 
     Hue[0.6001989655967653, 1, 0.16895527840447883`], 
     Hue[0.6287229249078181, 1, 0.12946056551225182`], 
     Hue[0.649698394426526, 1, 0.10041760771711797`], 
     Hue[0.6496389419655233, 1, 0.10049992650927547`], 
     Hue[0.6245414168247752, 1, 0.13525034593492677`], 
     Hue[0.5904096633353364, 1, 0.18250969692030347`], 
     Hue[0.5716622801396413, 1, 0.2084676121143429], 
     Hue[0.5497100013722022, 1, 0.2388630750231047], 
     Hue[0.5244409336357099, 1, 0.2738510149659401], 
     Hue[0.4962815230897489, 1, 0.3128409680295785], 
     Hue[0.46597494182679966`, 1, 0.3548039267013544], 
     Hue[0.43457916548143993`, 1, 0.3982750016410832], 
     Hue[0.40342627820475824`, 1, 0.4414097686395655], 
     Hue[0.37404109317128503`, 1, 0.48209694791668234`], 
     Hue[0.34802405143856435`, 1, 0.5181205441619878], 
     Hue[0.3269095796788625, 1, 0.5473559665984981], 
     Hue[0.31201716690331643`, 1, 0.5679762304415619], 
     Hue[0.30431479674022255`, 1, 0.5786410506673841], 
     Hue[0.3043144570367268, 1, 0.5786415210260706], 
     Hue[0.3120167377448938, 1, 0.5679768246609164], 
     Hue[0.32690920887930364`, 1, 0.5473564800132719], 
     Hue[0.3480237603580029, 1, 0.5181209471966114], 
     Hue[0.37404089470482704`, 1, 0.4820972227163933], 
     Hue[0.40342617588556917`, 1, 0.44140991031228893`], 
     Hue[0.43457915454354423`, 1, 0.39827501678586186`], 
     Hue[0.46597501058471447`, 1, 0.3548038314980877], 
     Hue[0.4962816544303153, 1, 0.3128407861734096], 
     Hue[0.5244411085622438, 1, 0.2738507727599702], 
     Hue[0.5497102008098522, 1, 0.23886279887866618`], 
     Hue[0.5716624867457911, 1, 0.2084673260442893], 
     Hue[0.5904098947812237, 1, 0.18250937645676713`], 
     Hue[0.6245422875477535, 1, 0.1352491403184951], 
     Hue[0.6496389846755347, 1, 0.10049986737233654`], 
     Hue[0.649577478494239, 1, 0.10058502977720765`], 
     Hue[0.6202138963403885, 1, 0.14124229737484675`], 
     Hue[0.5802737763923936, 1, 0.1965440019182242], 
     Hue[0.5583280015998117, 1, 0.2269304593233377], 
     Hue[0.5326277913778147, 1, 0.2625153657845643], 
     Hue[0.5030417915253735, 1, 0.3034805963494829], 
     Hue[0.470068905802547, 1, 0.34913536119647337`], 
     Hue[0.43457916548144004`, 1, 0.3982750016410831], 
     Hue[0.39781155321321565`, 1, 0.4491840032432399], 
     Hue[0.36132626453773387`, 1, 0.4997020952554455], 
     Hue[0.3269096126332475, 1, 0.5473559209693496], 
     Hue[0.29643658146057444`, 1, 0.589549348746897], 
     Hue[0.27170505303049686`, 1, 0.6237930034962351], 
     Hue[0.25426109147054615`, 1, 0.6479461810407823], 
     Hue[0.24523898831927277`, 1, 0.6604383238656223], 
     Hue[0.24523905911222033`, 1, 0.660438225844618], 
     Hue[0.2542611812693693, 1, 0.6479460567039502], 
     Hue[0.27170513131153495`, 1, 0.6237928951071054], 
     Hue[0.29643664409514314`, 1, 0.5895492620221096], 
     Hue[0.3269096566629648, 1, 0.5473558600051257], 
     Hue[0.36132628914320536`, 1, 0.4997020611863311], 
     Hue[0.39781155912194954`, 1, 0.4491839950619161], 
     Hue[0.4345791545435442, 1, 0.39827501678586197`], 
     Hue[0.4700688814178937, 1, 0.3491353949598395], 
     Hue[0.5030417571916427, 1, 0.3034806438884948], 
     Hue[0.5326277508879953, 1, 0.2625154218473912], 
     Hue[0.5583279587081367, 1, 0.22693051871181089`], 
     Hue[0.5802737264094405, 1, 0.19654407112539013`], 
     Hue[0.6202136935615618, 1, 0.1412425781455299], 
     Hue[0.6495774685201788, 1, 0.10058504358744468`], 
     Hue[0.6495165254872346, 1, 0.1006694262484444], 
     Hue[0.615921994799832, 1, 0.14718493027715576`], 
     Hue[0.5702204021385245, 1, 0.2104640585774276], 
     Hue[0.5451009821631014, 1, 0.2452447939280135], 
     Hue[0.5156814663990663, 1, 0.28597950806283134`], 
     Hue[0.4818111283712805, 1, 0.33287689917822705`], 
     Hue[0.44406077628930185`, 1, 0.3851466174455821], 
     Hue[0.4034262782047582, 1, 0.4414097686395656], 
     Hue[0.36132626453773375`, 1, 0.4997020952554456], 
     Hue[0.3195475603193792, 1, 0.557549531865475], 
     Hue[0.2801358546894734, 1, 0.6121195858145754], 
     Hue[0.24523900321299108`, 1, 0.6604383032435508], 
     Hue[0.2169164278757577, 1, 0.6996541767874124], 
     Hue[0.19693913314547817`, 1, 0.7273150464139533], 
     Hue[0.18660681005456498`, 1, 0.7416213399244486], 
     Hue[0.18660735119910316`, 1, 0.7416205906473956], 
     Hue[0.19693981755676215`, 1, 0.72731409876756], 
     Hue[0.21691702070062718`, 1, 0.6996533559529777], 
     Hue[0.24523947080001152`, 1, 0.6604376558153687], 
     Hue[0.28013617649380107`, 1, 0.6121191402393524], 
     Hue[0.3195477299800872, 1, 0.5575492969506486], 
     Hue[0.3613262891432053, 1, 0.4997020611863311], 
     Hue[0.4034261758855694, 1, 0.4414099103122885], 
     Hue[0.44406057312980485`, 1, 0.3851468987433472], 
     Hue[0.48181085405609547`, 1, 0.33287727899925246`], 
     Hue[0.5156811510231452, 1, 0.2859799447371837], 
     Hue[0.5451006531220457, 1, 0.2452452495233214], 
     Hue[0.5702200298684389, 1, 0.21046457402831542`], 
     Hue[0.6159205640488965, 1, 0.1471869113169126], 
     Hue[0.6495164551284213, 1, 0.1006695236683399], 
     Hue[0.6494590585595534, 1, 0.10074899584061832`], 
     Hue[0.6118753120591388, 1, 0.15278802945657705`], 
     Hue[0.5607407492766581, 1, 0.2235897317707812], 
     Hue[0.532627770676394, 1, 0.2625153944480699], 
     Hue[0.49969970675757647`, 1, 0.30810809833566344`], 
     Hue[0.4617875249399567, 1, 0.36060188854467534`], 
     Hue[0.4195297739541016, 1, 0.4191126206789362], 
     Hue[0.374041093171285, 1, 0.48209694791668245`], 
     Hue[0.3269096126332475, 1, 0.5473559209693496], 
     Hue[0.28013585468947355`, 1, 0.6121195858145752], 
     Hue[0.23601068976558537`, 1, 0.6732159680168818], 
     Hue[0.19693916442808201`, 1, 0.7273150030995787], 
     Hue[0.16522767428299484`, 1, 0.7712232202235456], 
     Hue[0.14285972467856245`, 1, 0.8021942273681443], 
     Hue[0.13129084465845597`, 1, 0.8182126766267533], 
     Hue[0.13129187980583068`, 1, 0.8182112433457729], 
     Hue[0.14286103359112767`, 1, 0.8021924150276694], 
     Hue[0.1652288075468782, 1, 0.7712216510889379], 
     Hue[0.19694005720194346`, 1, 0.7273137669511552], 
     Hue[0.23601130327494635`, 1, 0.6732151185423819], 
     Hue[0.28013617649380124`, 1, 0.6121191402393521], 
     Hue[0.32690965666296495`, 1, 0.5473558600051255], 
     Hue[0.3740408947048273, 1, 0.482097222716393], 
     Hue[0.41952938271066764`, 1, 0.41911316240061414`], 
     Hue[0.4617869984135538, 1, 0.36060261758123324`], 
     Hue[0.499699102630283, 1, 0.3081089348196082], 
     Hue[0.5326271410244352, 1, 0.26251626627385893`], 
     Hue[0.5607400386245787, 1, 0.2235907157505834], 
     Hue[0.611872593013101, 1, 0.15279179428955236`], 
     Hue[0.6494589248602171, 1, 0.10074918096277646`], 
     Hue[0.649408198526006, 1, 0.10081941742553022`], 
     Hue[0.6082937016181819, 1, 0.1577471823748251], 
     Hue[0.5523500286717988, 1, 0.23520765260827858`], 
     Hue[0.5215866154536093, 1, 0.27780314783346405`], 
     Hue[0.4855519334973518, 1, 0.3276973228498206], 
     Hue[0.44406072296108057`, 1, 0.3851466912846577], 
     Hue[0.3978115050201397, 1, 0.44918406997211435`], 
     Hue[0.3480240514385644, 1, 0.5181205441619877], 
     Hue[0.29643658146057444`, 1, 0.589549348746897], 
     Hue[0.24523900321299136`, 1, 0.6604383032435505], 
     Hue[0.19693916442808196`, 1, 0.7273150030995789], 
     Hue[0.15417015857172311`, 1, 0.7865336265929987], 
     Hue[0.11945703130391183`, 1, 0.834597956656122], 
     Hue[0.09497156039235655, 1, 0.8685009163798141], 
     Hue[0.0823074735768965, 1, 0.8860358058166048], 
     Hue[0.08230898266914821, 1, 0.8860337163042563], 
     Hue[0.09497346843216548, 1, 0.8684982744785401], 
     Hue[0.11945868288163919`, 1, 0.8345956698561919], 
     Hue[0.1541714593378561, 1, 0.7865318255321992], 
     Hue[0.1969400572019428, 1, 0.7273137669511561], 
     Hue[0.24523947080001152`, 1, 0.6604376558153687], 
     Hue[0.296436644095143, 1, 0.5895492620221098], 
     Hue[0.3480237603580031, 1, 0.5181209471966112], 
     Hue[0.3978109332902869, 1, 0.44918486159806437`], 
     Hue[0.44405995434766987`, 1, 0.385147755518611], 
     Hue[0.48555105221502437`, 1, 0.3276985430868894], 
     Hue[0.5215856976411508, 1, 0.27780441865071437`], 
     Hue[0.5523489934508787, 1, 0.23520908599109105`], 
     Hue[0.6082897478234974, 1, 0.15775265685977274`], 
     Hue[0.6494080042211439, 1, 0.1008196864630316], 
     Hue[0.6493669337431704, 1, 0.10087655327868715`], 
     Hue[0.6053877795136546, 1, 0.16177076682724748`], 
     Hue[0.5455419279510902, 1, 0.2446342536061827], 
     Hue[0.5126275239482238, 1, 0.2902080437639979], 
     Hue[0.47407150139525717`, 1, 0.3435933057604132], 
     Hue[0.42967539275756805`, 1, 0.4050648407972135], 
     Hue[0.3801863883092051, 1, 0.4735880777257161], 
     Hue[0.32690957967886247`, 1, 0.5473559665984982], 
     Hue[0.2717050530304971, 1, 0.6237930034962348], 
     Hue[0.21691642787575777`, 1, 0.6996541767874123], 
     Hue[0.16522767428299484`, 1, 0.7712232202235456], 
     Hue[0.11945703130391194`, 1, 0.8345979566561219], 
     Hue[0.08230720366207966, 1, 0.8860361795448127], 
     Hue[0.05610269050278349, 1, 0.9223193516115306], 
     Hue[0.04254948112586965, 1, 0.941085333825719], 
     Hue[0.04255139790497975, 1, 0.9410826798238742], 
     Hue[0.0561051139248433, 1, 0.9223159961040631], 
     Hue[0.08230930110914958, 1, 0.8860332753873313], 
     Hue[0.11945868288163874`, 1, 0.8345956698561925], 
     Hue[0.16522880754687713`, 1, 0.7712216510889394], 
     Hue[0.21691702070062646`, 1, 0.6996533559529787], 
     Hue[0.2717051313115346, 1, 0.6237928951071059], 
     Hue[0.32690920887930336`, 1, 0.5473564800132723], 
     Hue[0.3801856611748629, 1, 0.4735890845271129], 
     Hue[0.4296744158266316, 1, 0.40506619347081785`], 
     Hue[0.4740703816899864, 1, 0.3435948561215574], 
     Hue[0.5126263581144317, 1, 0.2902096579954024], 
     Hue[0.5455406136566956, 1, 0.24463607339842153`], 
     Hue[0.6053827643478735, 1, 0.16177771090294435`], 
     Hue[0.6493666872241856, 1, 0.10087689461266622`], 
     Hue[0.6493378392973852, 1, 0.1009168378959282], 
     Hue[0.6033385675660863, 1, 0.16460813721618822`], 
     Hue[0.5407408069589723, 1, 0.2512819595952691], 
     Hue[0.5063092649943483, 1, 0.2989564023155178], 
     Hue[0.46597482804496104`, 1, 0.3548040842454385], 
     Hue[0.4195297118980599, 1, 0.4191127066026864], 
     Hue[0.3677553925087863, 1, 0.49080022575706517`], 
     Hue[0.31201716690331643`, 1, 0.5679762304415619], 
     Hue[0.2542610914705461, 1, 0.6479461810407824], 
     Hue[0.19693913314547795`, 1, 0.7273150464139536], 
     Hue[0.14285972467856234`, 1, 0.8021942273681445], 
     Hue[0.09497156039235666, 1, 0.8685009163798139], 
     Hue[0.05610269050278349, 1, 0.9223193516115304], 
     Hue[0.02868546910747416, 1, 0.9602816581588819], 
     Hue[0.0145049859476436, 1, 0.9799161733032626], 
     Hue[0.014507200776745277`, 1, 0.9799131066168142], 
     Hue[0.028688269301960334`, 1, 0.9602777809665164], 
     Hue[0.05610511392484363, 1, 0.9223159961040626], 
     Hue[0.09497346843216581, 1, 0.8684982744785397], 
     Hue[0.14286103359112723`, 1, 0.80219241502767], 
     Hue[0.19693981755676226`, 1, 0.7273140987675599], 
     Hue[0.25426118126936936`, 1, 0.6479460567039501], 
     Hue[0.3120167377448941, 1, 0.5679768246609159], 
     Hue[0.3677545517203818, 1, 0.49080138992562516`], 
     Hue[0.41952858263311305`, 1, 0.419114270200305], 
     Hue[0.46597353397213803`, 1, 0.35480587603857816`], 
     Hue[0.5063079178181411, 1, 0.2989582676364201], 
     Hue[0.5407392886284856, 1, 0.2512840618990199], 
     Hue[0.6033327766268458, 1, 0.164616155439752], 
     Hue[0.6493375546952845, 1, 0.10091723196037532`], 
     Hue[0.6493227485192283, 1, 0.10093773281953008`], 
     Hue[0.6022780343317817, 1, 0.16607656784830227`], 
     Hue[0.5382576968540977, 1, 0.25472011204817235`], 
     Hue[0.5030415295754531, 1, 0.30348095904937267`], 
     Hue[0.4617872821693424, 1, 0.3606022246886028], 
     Hue[0.41428239665310546`, 1, 0.4263782200187771], 
     Hue[0.3613260963423509, 1, 0.4997023281413603], 
     Hue[0.30431479674022255`, 1, 0.5786410506673841], 
     Hue[0.24523898831927277`, 1, 0.6604383238656223], 
     Hue[0.1866068100545651, 1, 0.7416213399244483], 
     Hue[0.13129084465845575`, 1, 0.8182126766267536], 
     Hue[0.0823074735768965, 1, 0.8860358058166048], 
     Hue[0.04254948112586965, 1, 0.941085333825719], 
     Hue[0.014504985947643378`, 1, 0.9799161733032631], 
     Hue[9.992007221626409*^-16, 1, 0.9999999999999986], 
     Hue[1.7519034480883988`*^-6, 1, 0.9999975742875334], 
     Hue[0.014507200776744833`, 1, 0.9799131066168147], 
     Hue[0.04255139790497986, 1, 0.941082679823874], 
     Hue[0.08230898266914832, 1, 0.8860337163042562], 
     Hue[0.13129187980583035`, 1, 0.8182112433457733], 
     Hue[0.18660735119910332`, 1, 0.7416205906473954], 
     Hue[0.24523905911221994`, 1, 0.6604382258446185], 
     Hue[0.30431445703672644`, 1, 0.5786415210260711], 
     Hue[0.36132543116871385`, 1, 0.4997032491510116], 
     Hue[0.4142815032981123, 1, 0.42637945697184454`], 
     Hue[0.4617862584711786, 1, 0.3606036421168296], 
     Hue[0.5030404640559988, 1, 0.3034824343840017], 
     Hue[0.5382564959967934, 1, 0.25472177477367075`], 
     Hue[0.6022734552879471, 1, 0.1660829080628426], 
     Hue[0.6493225234655081, 1, 0.10093804443237338`], 
     Hue[0.6493225234655081, 1, 0.10093804443237338`], 
     Hue[0.602273455287948, 1, 0.16608290806284137`], 
     Hue[0.5382564959967934, 1, 0.2547217747736707], 
     Hue[0.5030404640559991, 1, 0.30348243438400135`], 
     Hue[0.46178625847117916`, 1, 0.36060364211682894`], 
     Hue[0.41428150329811186`, 1, 0.4263794569718452], 
     Hue[0.36132543116871485`, 1, 0.4997032491510103], 
     Hue[0.30431445703672694`, 1, 0.5786415210260704], 
     Hue[0.24523905911222044`, 1, 0.6604382258446179], 
     Hue[0.18660735119910365`, 1, 0.7416205906473949], 
     Hue[0.1312918798058309, 1, 0.8182112433457727], 
     Hue[0.08230898266914821, 1, 0.8860337163042564], 
     Hue[0.04255139790497964, 1, 0.9410826798238744], 
     Hue[0.014507200776745277`, 1, 0.9799131066168143], 
     Hue[1.7519034479773765`*^-6, 1, 0.9999975742875336], 
     Hue[0., 1, 1.], 
     Hue[0.014504985947642601`, 1, 0.9799161733032642], 
     Hue[0.04254948112586965, 1, 0.941085333825719], 
     Hue[0.08230747357689572, 1, 0.8860358058166059], 
     Hue[0.13129084465845464`, 1, 0.8182126766267551], 
     Hue[0.1866068100545641, 1, 0.7416213399244498], 
     Hue[0.24523898831927204`, 1, 0.6604383238656233], 
     Hue[0.30431479674022205`, 1, 0.5786410506673849], 
     Hue[0.3613260963423495, 1, 0.4997023281413622], 
     Hue[0.4142823966531056, 1, 0.4263782200187769], 
     Hue[0.4617872821693415, 1, 0.36060222468860403`], 
     Hue[0.5030415295754525, 1, 0.3034809590493736], 
     Hue[0.5382576968540976, 1, 0.2547201120481726], 
     Hue[0.6022780343317808, 1, 0.16607656784830355`], 
     Hue[0.6493227485192283, 1, 0.10093773281953008`], 
     Hue[0.6493375546952845, 1, 0.10091723196037532`], 
     Hue[0.6033327766268467, 1, 0.16461615543975078`], 
     Hue[0.5407392886284856, 1, 0.2512840618990199], 
     Hue[0.5063079178181413, 1, 0.29895826763641975`], 
     Hue[0.4659735339721385, 1, 0.3548058760385776], 
     Hue[0.41952858263311266`, 1, 0.41911427020030556`], 
     Hue[0.3677545517203828, 1, 0.49080138992562383`], 
     Hue[0.3120167377448938, 1, 0.5679768246609164], 
     Hue[0.25426118126936953`, 1, 0.6479460567039499], 
     Hue[0.19693981755676204`, 1, 0.7273140987675603], 
     Hue[0.14286103359112778`, 1, 0.8021924150276692], 
     Hue[0.09497346843216536, 1, 0.8684982744785403], 
     Hue[0.056105113924843186`, 1, 0.9223159961040633], 
     Hue[0.028688269301960556`, 1, 0.9602777809665161], 
     Hue[0.014507200776744722`, 1, 0.979913106616815], 
     Hue[0.014504985947642268`, 1, 0.9799161733032645], 
     Hue[0.02868546910747294, 1, 0.9602816581588836], 
     Hue[0.056102690502782715`, 1, 0.9223193516115316], 
     Hue[0.09497156039235577, 1, 0.8685009163798152], 
     Hue[0.142859724678561, 1, 0.8021942273681463], 
     Hue[0.196939133145477, 1, 0.727315046413955], 
     Hue[0.2542610914705451, 1, 0.6479461810407837], 
     Hue[0.31201716690331577`, 1, 0.5679762304415628], 
     Hue[0.36775539250878486`, 1, 0.49080022575706717`], 
     Hue[0.41952971189805954`, 1, 0.41911270660268685`], 
     Hue[0.46597482804496027`, 1, 0.35480408424543974`], 
     Hue[0.5063092649943477, 1, 0.29895640231551857`], 
     Hue[0.5407408069589721, 1, 0.25128195959526944`], 
     Hue[0.6033385675660854, 1, 0.1646081372161895], 
     Hue[0.6493378392973852, 1, 0.1009168378959282], 
     Hue[0.6493666872241856, 1, 0.10087689461266622`], 
     Hue[0.6053827643478744, 1, 0.16177771090294316`], 
     Hue[0.5455406136566957, 1, 0.24463607339842136`], 
     Hue[0.5126263581144319, 1, 0.290209657995402], 
     Hue[0.47407038168998694`, 1, 0.3435948561215566], 
     Hue[0.42967441582663135`, 1, 0.4050661934708182], 
     Hue[0.38018566117486396`, 1, 0.47358908452711146`], 
     Hue[0.3269092088793037, 1, 0.5473564800132719], 
     Hue[0.27170513131153523`, 1, 0.623792895107105], 
     Hue[0.21691702070062696`, 1, 0.6996533559529781], 
     Hue[0.1652288075468783, 1, 0.7712216510889378], 
     Hue[0.11945868288163919`, 1, 0.8345956698561919], 
     Hue[0.08230930110914947, 1, 0.8860332753873316], 
     Hue[0.05610511392484363, 1, 0.9223159961040626], 
     Hue[0.04255139790497986, 1, 0.941082679823874], 
     Hue[0.042549481125869426`, 1, 0.9410853338257192], 
     Hue[0.056102690502782715`, 1, 0.9223193516115316], 
     Hue[0.08230720366208022, 1, 0.8860361795448121], 
     Hue[0.11945703130391139`, 1, 0.8345979566561228], 
     Hue[0.16522767428299417`, 1, 0.7712232202235465], 
     Hue[0.2169164278757577, 1, 0.6996541767874124], 
     Hue[0.27170505303049614`, 1, 0.6237930034962361], 
     Hue[0.32690957967886214`, 1, 0.5473559665984986], 
     Hue[0.38018638830920415`, 1, 0.4735880777257174], 
     Hue[0.4296753927575682, 1, 0.4050648407972133], 
     Hue[0.47407150139525644`, 1, 0.34359330576041414`], 
     Hue[0.5126275239482234, 1, 0.29020804376399834`], 
     Hue[0.5455419279510902, 1, 0.24463425360618277`], 
     Hue[0.6053877795136537, 1, 0.16177076682724867`], 
     Hue[0.6493669337431704, 1, 0.10087655327868715`], 
     Hue[0.6494080042211439, 1, 0.1008196864630316], 
     Hue[0.6082897478234983, 1, 0.15775265685977166`], 
     Hue[0.5523489934508788, 1, 0.2352090859910909], 
     Hue[0.521585697641151, 1, 0.277804418650714], 
     Hue[0.4855510522150247, 1, 0.32769854308688884`], 
     Hue[0.4440599543476695, 1, 0.3851477555186116], 
     Hue[0.39781093329028766`, 1, 0.44918486159806326`], 
     Hue[0.34802376035800314`, 1, 0.5181209471966111], 
     Hue[0.29643664409514314`, 1, 0.5895492620221096], 
     Hue[0.24523947080001135`, 1, 0.6604376558153688], 
     Hue[0.19694005720194352`, 1, 0.7273137669511551], 
     Hue[0.15417145933785564`, 1, 0.7865318255321999], 
     Hue[0.11945868288163886`, 1, 0.8345956698561924], 
     Hue[0.09497346843216592, 1, 0.8684982744785396], 
     Hue[0.08230898266914821, 1, 0.8860337163042563], 
     Hue[0.08230747357689572, 1, 0.8860358058166059], 
     Hue[0.09497156039235577, 1, 0.8685009163798151], 
     Hue[0.11945703130391139`, 1, 0.8345979566561227], 
     Hue[0.1541701585717224, 1, 0.7865336265929997], 
     Hue[0.19693916442808063`, 1, 0.7273150030995806], 
     Hue[0.24523900321299064`, 1, 0.6604383032435515], 
     Hue[0.2964365814605738, 1, 0.5895493487468979], 
     Hue[0.3480240514385639, 1, 0.5181205441619885], 
     Hue[0.3978115050201386, 1, 0.4491840699721158], 
     Hue[0.4440607229610806, 1, 0.3851466912846576], 
     Hue[0.48555193349735115`, 1, 0.32769732284982156`], 
     Hue[0.521586615453609, 1, 0.27780314783346455`], 
     Hue[0.5523500286717986, 1, 0.23520765260827892`], 
     Hue[0.6082937016181811, 1, 0.15774718237482627`], 
     Hue[0.649408198526006, 1, 0.10081941742553022`], 
     Hue[0.6494589248602171, 1, 0.10074918096277648`], 
     Hue[0.6118725930131017, 1, 0.15279179428955145`], 
     Hue[0.5607400386245786, 1, 0.22359071575058354`], 
     Hue[0.5326271410244353, 1, 0.2625162662738588], 
     Hue[0.49969910263028317`, 1, 0.308108934819608], 
     Hue[0.46178699841355325`, 1, 0.360602617581234], 
     Hue[0.419529382710668, 1, 0.4191131624006136], 
     Hue[0.37404089470482704`, 1, 0.4820972227163933], 
     Hue[0.3269096566629647, 1, 0.5473558600051259], 
     Hue[0.2801361764938012, 1, 0.6121191402393522], 
     Hue[0.23601130327494585`, 1, 0.6732151185423827], 
     Hue[0.19694005720194296`, 1, 0.7273137669511559], 
     Hue[0.1652288075468772, 1, 0.7712216510889393], 
     Hue[0.14286103359112723`, 1, 0.80219241502767], 
     Hue[0.13129187980583035`, 1, 0.8182112433457733], 
     Hue[0.13129084465845486`, 1, 0.8182126766267548], 
     Hue[0.1428597246785609, 1, 0.8021942273681465], 
     Hue[0.16522767428299384`, 1, 0.7712232202235471], 
     Hue[0.19693916442808057`, 1, 0.7273150030995807], 
     Hue[0.23601068976558415`, 1, 0.6732159680168835], 
     Hue[0.2801358546894727, 1, 0.6121195858145763], 
     Hue[0.3269096126332466, 1, 0.5473559209693509], 
     Hue[0.37404109317128437`, 1, 0.4820969479166832], 
     Hue[0.4195297739541004, 1, 0.41911262067893795`], 
     Hue[0.46178752493995634`, 1, 0.3606018885446758], 
     Hue[0.4996997067575757, 1, 0.30810809833566444`], 
     Hue[0.5326277706763933, 1, 0.2625153944480707], 
     Hue[0.5607407492766578, 1, 0.22358973177078156`], 
     Hue[0.611875312059138, 1, 0.15278802945657816`], 
     Hue[0.6494590585595534, 1, 0.10074899584061832`], 
     Hue[0.6495164551284213, 1, 0.1006695236683399], 
     Hue[0.6159205640488971, 1, 0.14718691131691178`], 
     Hue[0.5702200298684389, 1, 0.21046457402831537`], 
     Hue[0.545100653122046, 1, 0.24524524952332097`], 
     Hue[0.5156811510231455, 1, 0.2859799447371832], 
     Hue[0.48181085405609536`, 1, 0.3328772789992527], 
     Hue[0.4440605731298055, 1, 0.3851468987433462], 
     Hue[0.4034261758855694, 1, 0.4414099103122886], 
     Hue[0.3613262891432053, 1, 0.4997020611863311], 
     Hue[0.3195477299800872, 1, 0.5575492969506486], 
     Hue[0.2801361764938014, 1, 0.6121191402393519], 
     Hue[0.24523947080001135`, 1, 0.6604376558153688], 
     Hue[0.21691702070062646`, 1, 0.6996533559529787], 
     Hue[0.19693981755676215`, 1, 0.72731409876756], 
     Hue[0.18660735119910338`, 1, 0.7416205906473954], 
     Hue[0.18660681005456414`, 1, 0.7416213399244497], 
     Hue[0.196939133145477, 1, 0.727315046413955], 
     Hue[0.2169164278757577, 1, 0.6996541767874124], 
     Hue[0.2452390032129909, 1, 0.660438303243551], 
     Hue[0.28013585468947266`, 1, 0.6121195858145764], 
     Hue[0.31954756031937853`, 1, 0.5575495318654758], 
     Hue[0.36132626453773325`, 1, 0.4997020952554463], 
     Hue[0.4034262782047576, 1, 0.4414097686395664], 
     Hue[0.4440607762893011, 1, 0.3851466174455832], 
     Hue[0.48181112837128043`, 1, 0.33287689917822716`], 
     Hue[0.5156814663990656, 1, 0.28597950806283223`], 
     Hue[0.5451009821631011, 1, 0.24524479392801388`], 
     Hue[0.5702204021385244, 1, 0.21046405857742778`], 
     Hue[0.6159219947998313, 1, 0.1471849302771567], 
     Hue[0.6495165254872346, 1, 0.1006694262484444], 
     Hue[0.6495774685201788, 1, 0.10058504358744468`], 
     Hue[0.6202136935615623, 1, 0.14124257814552912`], 
     Hue[0.5802737264094404, 1, 0.19654407112539013`], 
     Hue[0.5583279587081368, 1, 0.22693051871181064`], 
     Hue[0.5326277508879955, 1, 0.26251542184739085`], 
     Hue[0.5030417571916423, 1, 0.30348064388849516`], 
     Hue[0.47006888141789427`, 1, 0.3491353949598388], 
     Hue[0.4345791545435442, 1, 0.39827501678586197`], 
     Hue[0.39781155912194954`, 1, 0.449183995061916], 
     Hue[0.36132628914320525`, 1, 0.4997020611863312], 
     Hue[0.3269096566629648, 1, 0.5473558600051257], 
     Hue[0.29643664409514314`, 1, 0.5895492620221096], 
     Hue[0.27170513131153445`, 1, 0.6237928951071061], 
     Hue[0.2542611812693693, 1, 0.6479460567039502], 
     Hue[0.24523905911221994`, 1, 0.6604382258446185], 
     Hue[0.2452389883192717, 1, 0.6604383238656238], 
     Hue[0.25426109147054493`, 1, 0.6479461810407839], 
     Hue[0.2717050530304966, 1, 0.6237930034962356], 
     Hue[0.2964365814605738, 1, 0.5895493487468979], 
     Hue[0.32690961263324664`, 1, 0.5473559209693508], 
     Hue[0.36132626453773325`, 1, 0.4997020952554463], 
     Hue[0.3978115532132151, 1, 0.4491840032432406], 
     Hue[0.4345791654814396, 1, 0.39827500164108376`], 
     Hue[0.4700689058025461, 1, 0.3491353611964746], 
     Hue[0.5030417915253734, 1, 0.303480596349483], 
     Hue[0.5326277913778141, 1, 0.262515365784565], 
     Hue[0.5583280015998114, 1, 0.22693045932333808`], 
     Hue[0.5802737763923935, 1, 0.1965440019182244], 
     Hue[0.6202138963403879, 1, 0.14124229737484756`], 
     Hue[0.649577478494239, 1, 0.10058502977720765`], 
     Hue[0.6496389846755347, 1, 0.10049986737233654`], 
     Hue[0.6245422875477541, 1, 0.13524914031849444`], 
     Hue[0.5904098947812237, 1, 0.18250937645676713`], 
     Hue[0.5716624867457912, 1, 0.20846732604428908`], 
     Hue[0.5497102008098527, 1, 0.23886279887866566`], 
     Hue[0.5244411085622436, 1, 0.2738507727599705], 
     Hue[0.4962816544303158, 1, 0.312840786173409], 
     Hue[0.46597501058471447`, 1, 0.3548038314980877], 
     Hue[0.4345791545435441, 1, 0.39827501678586197`], 
     Hue[0.4034261758855695, 1, 0.4414099103122885], 
     Hue[0.3740408947048274, 1, 0.4820972227163929], 
     Hue[0.3480237603580032, 1, 0.518120947196611], 
     Hue[0.3269092088793032, 1, 0.5473564800132725], 
     Hue[0.312016737744894, 1, 0.567976824660916], 
     Hue[0.30431445703672655`, 1, 0.578641521026071], 
     Hue[0.30431479674022205`, 1, 0.5786410506673849], 
     Hue[0.31201716690331593`, 1, 0.5679762304415626], 
     Hue[0.326909579678862, 1, 0.5473559665984988], 
     Hue[0.3480240514385638, 1, 0.5181205441619886], 
     Hue[0.37404109317128426`, 1, 0.48209694791668334`], 
     Hue[0.4034262782047576, 1, 0.4414097686395664], 
     Hue[0.4345791654814396, 1, 0.39827500164108376`], 
     Hue[0.4659749418267992, 1, 0.35480392670135497`], 
     Hue[0.49628152308974804`, 1, 0.3128409680295796], 
     Hue[0.5244409336357099, 1, 0.2738510149659402], 
     Hue[0.5497100013722017, 1, 0.2388630750231053], 
     Hue[0.5716622801396409, 1, 0.2084676121143433], 
     Hue[0.5904096633353363, 1, 0.1825096969203036], 
     Hue[0.6245414168247746, 1, 0.13525034593492746`], 
     Hue[0.6496389419655233, 1, 0.10049992650927547`], 
     Hue[0.649698394426526, 1, 0.10041760771711797`], 
     Hue[0.6287229249078186, 1, 0.12946056551225132`], 
     Hue[0.6001989655967652, 1, 0.16895527840447902`], 
     Hue[0.5845389723395107, 1, 0.1906383459914468], 
     Hue[0.566204178904602, 1, 0.2160249830551666], 
     Hue[0.5451013481926239, 1, 0.24524428711790536`], 
     Hue[0.5215869427511122, 1, 0.2778026946523062], 
     Hue[0.49628165443031536`, 1, 0.3128407861734095], 
     Hue[0.4700688814178937, 1, 0.3491353949598395], 
     Hue[0.44406057312980485`, 1, 0.3851468987433472], 
     Hue[0.41952938271066764`, 1, 0.419113162400614], 
     Hue[0.3978109332902869, 1, 0.44918486159806437`], 
     Hue[0.38018566117486297`, 1, 0.4735890845271128], 
     Hue[0.3677545517203818, 1, 0.49080138992562516`], 
     Hue[0.3613254311687139, 1, 0.4997032491510115], 
     Hue[0.3613260963423495, 1, 0.4997023281413622], 
     Hue[0.3677553925087849, 1, 0.49080022575706705`], 
     Hue[0.38018638830920404`, 1, 0.47358807772571754`], 
     Hue[0.3978115050201385, 1, 0.449184069972116], 
     Hue[0.4195297739541004, 1, 0.41911262067893795`], 
     Hue[0.4440607762893011, 1, 0.3851466174455832], 
     Hue[0.470068905802546, 1, 0.3491353611964748], 
     Hue[0.49628152308974804`, 1, 0.3128409680295796], 
     Hue[0.5215866880302481, 1, 0.2778030473427335], 
     Hue[0.5451010075066368, 1, 0.2452447588369645], 
     Hue[0.5662037895546829, 1, 0.21602552215505455`], 
     Hue[0.5845385676182777, 1, 0.19063890637469244`], 
     Hue[0.6001985108332901, 1, 0.16895590807698294`], 
     Hue[0.6287212009016335, 1, 0.12946295259773827`], 
     Hue[0.6496983097028106, 1, 0.1004177250268776], 
     Hue[0.6497536281731384, 1, 0.10034113022180839`], 
     Hue[0.6326096948107707, 1, 0.12407888410816371`], 
     Hue[0.6092992847532812, 1, 0.1563548364954568], 
     Hue[0.5965079738472142, 1, 0.17406588236539575`], 
     Hue[0.5815339424268632, 1, 0.19479915663972794`], 
     Hue[0.5643012865415892, 1, 0.21865975709626123`], 
     Hue[0.5451013481926243, 1, 0.24524428711790486`], 
     Hue[0.5244411085622438, 1, 0.27385077275997016`], 
     Hue[0.5030417571916427, 1, 0.30348064388849477`], 
     Hue[0.48181085405609547`, 1, 0.3328772789992524], 
     Hue[0.4617869984135538, 1, 0.36060261758123324`], 
     Hue[0.44405995434766965`, 1, 0.38514775551861136`], 
     Hue[0.42967441582663163`, 1, 0.40506619347081774`], 
     Hue[0.4195285826331131, 1, 0.4191142702003049], 
     Hue[0.4142815032981122, 1, 0.42637945697184465`], 
     Hue[0.4142823966531057, 1, 0.4263782200187768], 
     Hue[0.41952971189805965`, 1, 0.4191127066026866], 
     Hue[0.42967539275756816`, 1, 0.4050648407972133], 
     Hue[0.44406072296108057`, 1, 0.3851466912846577], 
     Hue[0.46178752493995645`, 1, 0.3606018885446757], 
     Hue[0.4818111283712803, 1, 0.33287689917822727`], 
     Hue[0.5030417915253734, 1, 0.30348059634948304`], 
     Hue[0.5244409336357099, 1, 0.2738510149659401], 
     Hue[0.5451010075066367, 1, 0.24524475883696456`], 
     Hue[0.5643008298468729, 1, 0.21866038944279137`], 
     Hue[0.5815334198863938, 1, 0.19479988015730082`], 
     Hue[0.5965074304344583, 1, 0.1740666347830578], 
     Hue[0.6092986732582468, 1, 0.15635568318088902`], 
     Hue[0.6326073703548719, 1, 0.124082102585562], 
     Hue[0.6497535139635646, 1, 0.10034128835814127`], 
     Hue[0.6498032208248107, 1, 0.10027246347333903`], 
     Hue[0.6360998533911139, 1, 0.1192463568430732], 
     Hue[0.6174703284313343, 1, 0.1450410837104602], 
     Hue[0.607253262945072, 1, 0.15918778976836193`], 
     Hue[0.5952946063665869, 1, 0.17574592964626434`], 
     Hue[0.5815339424268628, 1, 0.1947991566397283], 
     Hue[0.566204178904602, 1, 0.21602498305516665`], 
     Hue[0.5497102008098523, 1, 0.2388627988786661], 
     Hue[0.5326277508879953, 1, 0.2625154218473912], 
     Hue[0.5156811510231452, 1, 0.2859799447371837], 
     Hue[0.4996991026302829, 1, 0.3081089348196083], 
     Hue[0.4855510522150243, 1, 0.32769854308688945`], 
     Hue[0.4740703816899863, 1, 0.3435948561215575], 
     Hue[0.465973533972138, 1, 0.35480587603857816`], 
     Hue[0.46178625847117855`, 1, 0.3606036421168297], 
     Hue[0.4617872821693415, 1, 0.36060222468860414`], 
     Hue[0.46597482804496027`, 1, 0.35480408424543974`], 
     Hue[0.47407150139525644`, 1, 0.34359330576041414`], 
     Hue[0.48555193349735104`, 1, 0.3276973228498216], 
     Hue[0.4996997067575757, 1, 0.30810809833566444`], 
     Hue[0.5156814663990656, 1, 0.28597950806283223`], 
     Hue[0.5326277913778141, 1, 0.262515365784565], 
     Hue[0.5497100013722017, 1, 0.2388630750231053], 
     Hue[0.5662037895546829, 1, 0.2160255221550545], 
     Hue[0.5815334198863938, 1, 0.19479988015730082`], 
     Hue[0.5952940078074795, 1, 0.17574675842041304`], 
     Hue[0.6072526403378196, 1, 0.15918865183994224`], 
     Hue[0.6174696271668444, 1, 0.14504205469206172`], 
     Hue[0.6360971833227741, 1, 0.11925005386077443`], 
     Hue[0.6498030896255687, 1, 0.10027264513382812`], 
     Hue[0.6498463345952484, 1, 0.10021276748350222`], 
     Hue[0.6391341378578641, 1, 0.1150450398891113], 
     Hue[0.6245734607680122, 1, 0.135205977398137], 
     Hue[0.6165927565645893, 1, 0.14625618321826095`], 
     Hue[0.607253262945072, 1, 0.15918778976836184`], 
     Hue[0.596507973847214, 1, 0.17406588236539605`], 
     Hue[0.5845389723395107, 1, 0.1906383459914467], 
     Hue[0.5716624867457911, 1, 0.2084673260442893], 
     Hue[0.5583279587081367, 1, 0.22693051871181086`], 
     Hue[0.5451006531220457, 1, 0.2452452495233213], 
     Hue[0.5326271410244352, 1, 0.26251626627385904`], 
     Hue[0.5215856976411507, 1, 0.2778044186507145], 
     Hue[0.5126263581144317, 1, 0.2902096579954024], 
     Hue[0.5063079178181411, 1, 0.2989582676364201], 
     Hue[0.5030404640559988, 1, 0.3034824343840017], 
     Hue[0.5030415295754525, 1, 0.30348095904937356`], 
     Hue[0.5063092649943477, 1, 0.29895640231551857`], 
     Hue[0.5126275239482234, 1, 0.29020804376399834`], 
     Hue[0.5215866154536088, 1, 0.2778031478334647], 
     Hue[0.5326277706763933, 1, 0.26251539444807076`], 
     Hue[0.545100982163101, 1, 0.245244793928014], 
     Hue[0.5583280015998114, 1, 0.22693045932333808`], 
     Hue[0.5716622801396409, 1, 0.2084676121143433], 
     Hue[0.5845385676182777, 1, 0.1906389063746924], 
     Hue[0.5965074304344582, 1, 0.1740666347830579], 
     Hue[0.6072526403378196, 1, 0.15918865183994224`], 
     Hue[0.6165921083515686, 1, 0.14625708074398186`], 
     Hue[0.6245727303868367, 1, 0.13520698869514927`], 
     Hue[0.6391313531926316, 1, 0.11504889557943314`], 
     Hue[0.6498461977051377, 1, 0.1002129570236554], 
     Hue[0.6498831956240974, 1, 0.10016172913586517`], 
     Hue[0.6417279253205035, 1, 0.11145364186391826`], 
     Hue[0.6306442987596863, 1, 0.1268002017173574], 
     Hue[0.6245734607680122, 1, 0.1352059773981369], 
     Hue[0.6174703284313344, 1, 0.14504108371046004`], 
     Hue[0.6092992847532812, 1, 0.15635483649545684`], 
     Hue[0.6001989655967653, 1, 0.16895527840447888`], 
     Hue[0.5904098947812237, 1, 0.18250937645676713`], 
     Hue[0.5802737264094405, 1, 0.19654407112539013`], 
     Hue[0.5702200298684389, 1, 0.21046457402831542`], 
     Hue[0.5607400386245787, 1, 0.22359071575058342`], 
     Hue[0.5523489934508787, 1, 0.23520908599109108`], 
     Hue[0.5455406136566956, 1, 0.2446360733984215], 
     Hue[0.5407392886284856, 1, 0.2512840618990199], 
     Hue[0.5382564959967935, 1, 0.25472177477367064`], 
     Hue[0.5382576968540976, 1, 0.2547201120481726], 
     Hue[0.5407408069589721, 1, 0.25128195959526944`], 
     Hue[0.5455419279510902, 1, 0.24463425360618274`], 
     Hue[0.5523500286717986, 1, 0.23520765260827886`], 
     Hue[0.5607407492766578, 1, 0.22358973177078156`], 
     Hue[0.5702204021385244, 1, 0.21046405857742778`], 
     Hue[0.5802737763923935, 1, 0.19654400191822435`], 
     Hue[0.5904096633353363, 1, 0.1825096969203036], 
     Hue[0.6001985108332901, 1, 0.16895590807698296`], 
     Hue[0.6092986732582468, 1, 0.15635568318088902`], 
     Hue[0.6174696271668444, 1, 0.1450420546920617], 
     Hue[0.6245727303868367, 1, 0.13520698869514927`], 
     Hue[0.6306434748977873, 1, 0.12680134244921762`], 
     Hue[0.6417247778031417, 1, 0.11145799996488066`], 
     Hue[0.6498830409238536, 1, 0.10016194333620275`], 
     Hue[0.649950728657251, 1, 0.10006822185919101`], 
     Hue[0.6464693972464388, 1, 0.10488852688954636`], 
     Hue[0.6417279253205034, 1, 0.11145364186391847`], 
     Hue[0.6391341378578639, 1, 0.11504503988911155`], 
     Hue[0.6360998533911136, 1, 0.1192463568430735], 
     Hue[0.6326096948107703, 1, 0.12407888410816416`], 
     Hue[0.6287229249078181, 1, 0.12946056551225182`], 
     Hue[0.6245422875477535, 1, 0.1352491403184951], 
     Hue[0.6202136935615618, 1, 0.1412425781455299], 
     Hue[0.6159205640488965, 1, 0.14718691131691264`], 
     Hue[0.611872593013101, 1, 0.15279179428955236`], 
     Hue[0.6082897478234974, 1, 0.15775265685977274`], 
     Hue[0.6053827643478735, 1, 0.16177771090294435`], 
     Hue[0.6033327766268458, 1, 0.164616155439752], 
     Hue[0.6022734552879471, 1, 0.1660829080628426], 
     Hue[0.6022780343317807, 1, 0.1660765678483036], 
     Hue[0.6033385675660854, 1, 0.1646081372161895], 
     Hue[0.6053877795136537, 1, 0.1617707668272487], 
     Hue[0.6082937016181811, 1, 0.15774718237482627`], 
     Hue[0.611875312059138, 1, 0.15278802945657816`], 
     Hue[0.6159219947998312, 1, 0.14718493027715673`], 
     Hue[0.6202138963403879, 1, 0.14124229737484756`], 
     Hue[0.6245414168247746, 1, 0.1352503459349275], 
     Hue[0.6287212009016335, 1, 0.12946295259773824`], 
     Hue[0.6326073703548719, 1, 0.124082102585562], 
     Hue[0.6360971833227741, 1, 0.11925005386077443`], 
     Hue[0.6391313531926316, 1, 0.11504889557943314`], 
     Hue[0.6417247778031417, 1, 0.11145799996488066`], 
     Hue[0.6464573223024351, 1, 0.10490524604278213`], 
     Hue[0.6499501349069793, 1, 0.10006904397495173`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649950728657251, 1, 0.10006822185919101`], 
     Hue[0.6498831956240974, 1, 0.10016172913586517`], 
     Hue[0.6498463345952484, 1, 0.10021276748350222`], 
     Hue[0.6498032208248107, 1, 0.10027246347333903`], 
     Hue[0.6497536281731384, 1, 0.10034113022180839`], 
     Hue[0.649698394426526, 1, 0.10041760771711797`], 
     Hue[0.6496389846755347, 1, 0.10049986737233654`], 
     Hue[0.6495774685201788, 1, 0.10058504358744468`], 
     Hue[0.6495164551284213, 1, 0.1006695236683399], 
     Hue[0.6494589248602171, 1, 0.10074918096277646`], 
     Hue[0.6494080042211439, 1, 0.1008196864630316], 
     Hue[0.6493666872241856, 1, 0.10087689461266622`], 
     Hue[0.6493375546952845, 1, 0.10091723196037532`], 
     Hue[0.6493225234655081, 1, 0.10093804443237338`], 
     Hue[0.6493227485192283, 1, 0.10093773281953008`], 
     Hue[0.6493378392973852, 1, 0.1009168378959282], 
     Hue[0.6493669337431704, 1, 0.10087655327868715`], 
     Hue[0.649408198526006, 1, 0.10081941742553022`], 
     Hue[0.6494590585595534, 1, 0.10074899584061832`], 
     Hue[0.6495165254872346, 1, 0.1006694262484444], 
     Hue[0.649577478494239, 1, 0.10058502977720765`], 
     Hue[0.6496389419655233, 1, 0.10049992650927547`], 
     Hue[0.6496983097028106, 1, 0.1004177250268776], 
     Hue[0.6497535139635646, 1, 0.10034128835814127`], 
     Hue[0.6498030896255687, 1, 0.10027264513382812`], 
     Hue[0.6498461977051377, 1, 0.1002129570236554], 
     Hue[0.6498830409238536, 1, 0.10016194333620275`], 
     Hue[0.6499501349069793, 1, 0.10006904397495173`], 
     Hue[0.6499999708035517, 1, 0.10000004042585155`], 
     Hue[0.6498310718059017, 1, 0.10023390057644375`], 
     Hue[0.6499895959854948, 1, 0.1000144055585458], 
     Hue[0.6498336765377891, 1, 0.10023029402459974`], 
     Hue[0.6499898717593472, 1, 0.10001402371782703`], 
     Hue[0.6498336765377891, 1, 0.10023029402459974`], 
     Hue[0.6499898717593472, 1, 0.10001402371782703`], 
     Hue[0.6498310718059017, 1, 0.10023390057644377`], 
     Hue[0.6499895959854948, 1, 0.1000144055585458], 
     Hue[0.6499895959854948, 1, 0.1000144055585458], 
     Hue[0.6499898717593472, 1, 0.10001402371782703`], 
     Hue[0.6499898717593472, 1, 0.10001402371782703`], 
     Hue[0.6499895959854948, 1, 0.1000144055585458], 
     Hue[0.6499853374217525, 1, 0.10002030203141973`], 
     Hue[0.6499857375801574, 1, 0.10001974796593582`], 
     Hue[0.6499857375801574, 1, 0.10001974796593582`], 
     Hue[0.6499853374217525, 1, 0.10002030203141973`], 
     Hue[0.649997354862171, 1, 0.10000366249853244`], 
     Hue[0.6499974629289912, 1, 0.1000035128675507], 
     Hue[0.6499974629289912, 1, 0.1000035128675507], 
     Hue[0.649997354862171, 1, 0.10000366249853244`], 
     Hue[0.649997354862171, 1, 0.10000366249853244`], 
     Hue[0.6499974629289912, 1, 0.1000035128675507], 
     Hue[0.6499974629289912, 1, 0.1000035128675507], 
     Hue[0.649997354862171, 1, 0.10000366249853244`], 
     Hue[0.6498956210456897, 1, 0.10014452470596819`], 
     Hue[0.6426121298967594, 1, 0.11022935860448697`], 
     Hue[0.6498192551554071, 1, 0.10025026209251335`], 
     Hue[0.6372349970239709, 1, 0.11767461950527106`], 
     Hue[0.6497293620994847, 1, 0.10037472940071342`], 
     Hue[0.6309071712190805, 1, 0.12643622446588856`], 
     Hue[0.6496235760977022, 1, 0.10052120232625851`], 
     Hue[0.6234595367036785, 1, 0.13674833379490678`], 
     Hue[0.6495129338042546, 1, 0.10067439934795527`], 
     Hue[0.6156690771285387, 1, 0.1475351239758696], 
     Hue[0.6494145560301994, 1, 0.10081061472741623`], 
     Hue[0.6087414029233015, 1, 0.1571272882600441], 
     Hue[0.6493469313116931, 1, 0.10090424895304037`], 
     Hue[0.6039789462997014, 1, 0.1637214589696442], 
     Hue[0.6493226359923682, 1, 0.10093788862595174`], 
     Hue[0.6022757448098648, 1, 0.1660797379555718], 
     Hue[0.6493466586105661, 1, 0.10090462653921622`], 
     Hue[0.6039733977896679, 1, 0.1637291415219984], 
     Hue[0.649414369301028, 1, 0.10081087327549972`], 
     Hue[0.6087376034721987, 1, 0.15713254903849413`], 
     Hue[0.6495128594866585, 1, 0.10067450224924218`], 
     Hue[0.6156675658591599, 1, 0.14753721650270174`], 
     Hue[0.6496236056366957, 1, 0.10052116142611357`], 
     Hue[0.6234601390512061, 1, 0.1367474997752531], 
     Hue[0.6497294634089954, 1, 0.10037458912600633`], 
     Hue[0.6309092329782291, 1, 0.12643336972245203`], 
     Hue[0.6498193884887249, 1, 0.10025007747715022`], 
     Hue[0.6372377100661452, 1, 0.11767086298533747`], 
     Hue[0.6498958580678137, 1, 0.10014419652148876`], 
     Hue[0.6426169513066163, 1, 0.1102226828062235], 
     Hue[0.6327212191925413, 1, 0.12392446573340435`], 
     Hue[0.6201332908743415, 1, 0.1413539049432194], 
     Hue[0.6053173521973284, 1, 0.16186828157292996`], 
     Hue[0.5878756915996007, 1, 0.18601827316978367`], 
     Hue[0.5696279238346579, 1, 0.21128441315201224`], 
     Hue[0.5533988687474062, 1, 0.23375541250359141`], 
     Hue[0.5422411572690091, 1, 0.24920455147367962`], 
     Hue[0.5382570964254456, 1, 0.25472094341092155`], 
     Hue[0.5422397026998013, 1, 0.24920656549258285`], 
     Hue[0.5533978740975913, 1, 0.2337567897110275], 
     Hue[0.5696275304156977, 1, 0.21128495788595708`], 
     Hue[0.587875852688278, 1, 0.18601805012392278`], 
     Hue[0.6053178951223055, 1, 0.161867529830654], 
     Hue[0.6201340030575886, 1, 0.14135291884333895`], 
     Hue[0.6327224787398396, 1, 0.12392272174483751`], 
     Hue[0.6273024721629233, 1, 0.13142734623595234`], 
     Hue[0.6107549408429757, 1, 0.15433931267895676`], 
     Hue[0.5912710529523796, 1, 0.1813170036043976], 
     Hue[0.5683287105046838, 1, 0.21308332391659163`], 
     Hue[0.5443214064451822, 1, 0.246324206460517], 
     Hue[0.5229667598564574, 1, 0.2758921786602898], 
     Hue[0.5082837209174343, 1, 0.2962225402681678], 
     Hue[0.5030409968157261, 1, 0.303481696716687], 
     Hue[0.5082824304107321, 1, 0.2962243271236017], 
     Hue[0.5229658780640616, 1, 0.27589339960360704`], 
     Hue[0.5443210586159454, 1, 0.24632468807022953`], 
     Hue[0.5683288547363777, 1, 0.21308312421116937`], 
     Hue[0.5912715356875939, 1, 0.181316335201793], 
     Hue[0.610755573052391, 1, 0.154338437312074], 
     Hue[0.6273035877223595, 1, 0.13142580161519454`], 
     Hue[0.6209622939460814, 1, 0.1402060545361951], 
     Hue[0.5997784950063574, 1, 0.16953746845273604`], 
     Hue[0.5748267066162707, 1, 0.20408609853131754`], 
     Hue[0.5454394488736053, 1, 0.2447761477134696], 
     Hue[0.5146826064214731, 1, 0.28736254495488345`], 
     Hue[0.48732040515487984`, 1, 0.32524866978555106`], 
     Hue[0.4685050384669286, 1, 0.35130071596886814`], 
     Hue[0.4617867703202607, 1, 0.360602933402716], 
     Hue[0.46850379888396604`, 1, 0.35130243231450864`], 
     Hue[0.48731955851693204`, 1, 0.32524984205347873`], 
     Hue[0.5146822729985917, 1, 0.28736300661733466`], 
     Hue[0.5454395883293883, 1, 0.2447759546208469], 
     Hue[0.574827170885874, 1, 0.20408545569648226`], 
     Hue[0.5997791025835189, 1, 0.16953662719205081`], 
     Hue[0.6209633643612932, 1, 0.14020457242282494`], 
     Hue[0.6136690539638641, 1, 0.1503043868192651], 
     Hue[0.5871486738419182, 1, 0.18702491314195946`], 
     Hue[0.5559009075730197, 1, 0.230291051052742], 
     Hue[0.5190911481081257, 1, 0.28125841031182586`], 
     Hue[0.48055965315682275`, 1, 0.3346097110136301], 
     Hue[0.4462765732084403, 1, 0.3820785909421597], 
     Hue[0.42270023716665617`, 1, 0.4147227485384761], 
     Hue[0.41428194997560847`, 1, 0.42637883849531133`], 
     Hue[0.4226991555060873, 1, 0.4147242462223407], 
     Hue[0.4462758348559051, 1, 0.38207961327643913`], 
     Hue[0.4805593630784365, 1, 0.33461011266062646`], 
     Hue[0.5190912707195934, 1, 0.2812582405421015], 
     Hue[0.555901313513917, 1, 0.23029048898073037`], 
     Hue[0.5871492042094946, 1, 0.18702417878685362`], 
     Hue[0.6136699866390606, 1, 0.1503030954228393], 
     Hue[0.6055465152211047, 1, 0.16155097892462425`], 
     Hue[0.5730793313285315, 1, 0.20650554123741802`], 
     Hue[0.5348134927357172, 1, 0.25948901005823777`], 
     Hue[0.48972836876794834`, 1, 0.32191456632130233`], 
     Hue[0.44252758864335195`, 1, 0.38726949264766664`], 
     Hue[0.4005262886368848, 1, 0.4454251388104672], 
     Hue[0.3716400786964172, 1, 0.4854214294972685], 
     Hue[0.3613257637555329, 1, 0.49970278864618534`], 
     Hue[0.37163927342490816`, 1, 0.4854225444885887], 
     Hue[0.4005257394678352, 1, 0.44542589919838205`], 
     Hue[0.4425273737286095, 1, 0.3872697902219254], 
     Hue[0.4897284611772105, 1, 0.3219144383700163], 
     Hue[0.5348137958119629, 1, 0.25948859041420536`], 
     Hue[0.5730797264426928, 1, 0.20650499415627152`], 
     Hue[0.6055472079675879, 1, 0.16155001973718605`], 
     Hue[0.5968093671146062, 1, 0.17364856861054537`], 
     Hue[0.5579421059099918, 1, 0.22746477643231902`], 
     Hue[0.512121191521852, 1, 0.29090911943128195`], 
     Hue[0.4581259977404597, 1, 0.36567169543628664`], 
     Hue[0.40158970414016615`, 1, 0.44395271734438546`], 
     Hue[0.3512761816551544, 1, 0.5136175946313247], 
     Hue[0.3166710458956746, 1, 0.5615323979906045], 
     Hue[0.30431462688847466`, 1, 0.5786412858467274], 
     Hue[0.3166706349743969, 1, 0.5615329669585274], 
     Hue[0.351275902151356, 1, 0.513617981636584], 
     Hue[0.4015895958117729, 1, 0.44395286733754535`], 
     Hue[0.458126046574422, 1, 0.36567162782003104`], 
     Hue[0.5121213473795252, 1, 0.29090890362834976`], 
     Hue[0.5579423080358294, 1, 0.2274644965657747], 
     Hue[0.5968097184249482, 1, 0.17364808218084088`], 
     Hue[0.5877625488826427, 1, 0.1861749323163409], 
     Hue[0.5422653702110636, 1, 0.24917102586160433`], 
     Hue[0.4886161540216369, 1, 0.32345455597004125`], 
     Hue[0.42538726241438385`, 1, 0.41100225204162244`], 
     Hue[0.3591752237937034, 1, 0.5026804593625646], 
     Hue[0.30024571035715847`, 1, 0.5842751702747037], 
     Hue[0.25971232945803074`, 1, 0.6403983130581113], 
     Hue[0.24523902371574657`, 1, 0.6604382748551202], 
     Hue[0.2597124156575461, 1, 0.6403981937049362], 
     Hue[0.3002457706661209, 1, 0.5842750867699864], 
     Hue[0.3591752496131905, 1, 0.5026804236125055], 
     Hue[0.4253872556881457, 1, 0.4110022613548753], 
     Hue[0.4886161240406277, 1, 0.32345459748220784`], 
     Hue[0.5422653288205483, 1, 0.2491710831715484], 
     Hue[0.5877624702504635, 1, 0.18617504119166606`], 
     Hue[0.5787894507625196, 1, 0.19859922202112662`], 
     Hue[0.5267137848105794, 1, 0.2707039902622747], 
     Hue[0.46529534933541483`, 1, 0.35574490092019495`], 
     Hue[0.392901274788002, 1, 0.4559828502935357], 
     Hue[0.31708432871750997`, 1, 0.5609601602372939], 
     Hue[0.24960110964755128`, 1, 0.654398463564929], 
     Hue[0.20318203774869042`, 1, 0.7186710246556594], 
     Hue[0.186607080626834, 1, 0.7416209652859221], 
     Hue[0.20318269353921997`, 1, 0.7186701166380032], 
     Hue[0.24960155901173525`, 1, 0.6543978413683665], 
     Hue[0.31708450788719444`, 1, 0.5609599121561923], 
     Hue[0.39290120419997854`, 1, 0.455982948030799], 
     Hue[0.4652951061508435, 1, 0.3557452376372936], 
     Hue[0.5267134643102329, 1, 0.2707044340319852], 
     Hue[0.5787888800272749, 1, 0.19860001226992707`], 
     Hue[0.5703284797983732, 1, 0.21031441258686795`], 
     Hue[0.5120477307271329, 1, 0.29101083437781583`], 
     Hue[0.4432997588836451, 1, 0.38620033385341457`], 
     Hue[0.3622582230367755, 1, 0.4984116911798493], 
     Hue[0.27737803188173044`, 1, 0.6159381097022194], 
     Hue[0.2018231050952699, 1, 0.7205526237142417], 
     Hue[0.14984970892994753`, 1, 0.7925157876354572], 
     Hue[0.13129136223214322`, 1, 0.8182119599862632], 
     Hue[0.14985096295229972`, 1, 0.7925140512968157], 
     Hue[0.20182396296106897`, 1, 0.7205514359000583], 
     Hue[0.277378371917623, 1, 0.6159376388832912], 
     Hue[0.362258085194362, 1, 0.4984118820385758], 
     Hue[0.4432992915435413, 1, 0.3862009809397121], 
     Hue[0.5120471170280902, 1, 0.29101168411495204`], 
     Hue[0.5703273925724269, 1, 0.21031591797663968`], 
     Hue[0.5628394673492456, 1, 0.22068381443950608`], 
     Hue[0.4990649392309484, 1, 0.3089870072186869], 
     Hue[0.42382669011191887`, 1, 0.41316304446042007`], 
     Hue[0.3351271839440668, 1, 0.5359777453082152], 
     Hue[0.24222026328893442`, 1, 0.6646180969845523], 
     Hue[0.15951628430376785`, 1, 0.7791312986563215], 
     Hue[0.1026232700522175, 1, 0.8579062414661603], 
     Hue[0.08230822812302241, 1, 0.8860347610604306], 
     Hue[0.10262509794762609`, 1, 0.8579037105340562], 
     Hue[0.159517534070867, 1, 0.7791295682095688], 
     Hue[0.24222075745013238`, 1, 0.6646174127613552], 
     Hue[0.3351269812922883, 1, 0.5359780259029855], 
     Hue[0.42382600763506506`, 1, 0.4131639894283715], 
     Hue[0.4990640442498219, 1, 0.30898824642332356`], 
     Hue[0.562837884895745, 1, 0.22068600552896844`], 
     Hue[0.556763025119071, 1, 0.22909734983513236`], 
     Hue[0.48853000985261963`, 1, 0.3235738325117574], 
     Hue[0.4080239533114093, 1, 0.43504375695343334`], 
     Hue[0.31310844801677107`, 1, 0.5664652258229325], 
     Hue[0.21368588077621004`, 1, 0.7041272420021707], 
     Hue[0.12517836167629715`, 1, 0.82667611460205], 
     Hue[0.06429160086506347, 1, 0.9109808603406814], 
     Hue[0.0425504395154247, 1, 0.9410840068247965], 
     Hue[0.06429392241993914, 1, 0.9109776458800843], 
     Hue[0.12517994846479374`, 1, 0.8266739175102856], 
     Hue[0.2136865073785173, 1, 0.7041263743989761], 
     Hue[0.31310818948736147`, 1, 0.5664655837867303], 
     Hue[0.408023085666483, 1, 0.43504495830794665`], 
     Hue[0.4885288728491536, 1, 0.32357540682424896`], 
     Hue[0.5567610169112918, 1, 0.22910013043051913`], 
     Hue[0.5524778870728062, 1, 0.2350306178991915], 
     Hue[0.4811002419009813, 1, 0.3338612035217183], 
     Hue[0.3968784471652526, 1, 0.45047599623272716`], 
     Hue[0.2975781480451238, 1, 0.5879687180913671], 
     Hue[0.1935591701162956, 1, 0.7319949952235908], 
     Hue[0.10095758092813223`, 1, 0.8602125802533553], 
     Hue[0.03725335079350833, 1, 0.9484184373628346], 
     Hue[0.014506093362194439`, 1, 0.9799146399600385], 
     Hue[0.03725603324661142, 1, 0.9484147231969996], 
     Hue[0.10095941407703601`, 1, 0.8602100420471809], 
     Hue[0.19355989355891023`, 1, 0.7319939935338167], 
     Hue[0.29757784862601316`, 1, 0.587969132671674], 
     Hue[0.3968774441087934, 1, 0.45047738508013224`], 
     Hue[0.48109892791438935`, 1, 0.3338630228877686], 
     Hue[0.5524755676281785, 1, 0.2350338294379067], 
     Hue[0.5502615101311635, 1, 0.23809944751069675`], 
     Hue[0.47725762494663393`, 1, 0.3391817500738915], 
     Hue[0.3911140152671503, 1, 0.45845751732240736`], 
     Hue[0.289545844634985, 1, 0.5990903689669439], 
     Hue[0.18314956221730821`, 1, 0.7464082984683424], 
     Hue[0.08843039496209137, 1, 0.8775579146678736], 
     Hue[0.023268890690838928`, 1, 0.9677815359665307], 
     Hue[8.759517245993109*^-7, 1, 0.999998787143766], 
     Hue[0.02327101237931839, 1, 0.9677785982440208], 
     Hue[0.08843184481123367, 1, 0.8775559071844456], 
     Hue[0.18315013423702392`, 1, 0.7464075064410438], 
     Hue[0.28954560755560005`, 1, 0.5990906972307076], 
     Hue[0.39111322174150076`, 1, 0.45845861605022975`], 
     Hue[0.47725658556548634`, 1, 0.3391831892170189], 
     Hue[0.550259675863885, 1, 0.23810198726539], 
     Hue[0.5502596758638848, 1, 0.23810198726539025`], 
     Hue[0.47725658556548656`, 1, 0.3391831892170186], 
     Hue[0.3911132217415006, 1, 0.45845861605023], 
     Hue[0.28954560755560027`, 1, 0.5990906972307073], 
     Hue[0.18315013423702398`, 1, 0.7464075064410437], 
     Hue[0.08843184481123334, 1, 0.8775559071844462], 
     Hue[0.02327101237931839, 1, 0.9677785982440207], 
     Hue[8.759517239331771*^-7, 1, 0.9999987871437669], 
     Hue[0.023268890690838595`, 1, 0.9677815359665312], 
     Hue[0.08843039496209071, 1, 0.8775579146678745], 
     Hue[0.18314956221730733`, 1, 0.7464082984683437], 
     Hue[0.2895458446349848, 1, 0.5990903689669441], 
     Hue[0.39111401526715, 1, 0.4584575173224077], 
     Hue[0.47725762494663326`, 1, 0.3391817500738924], 
     Hue[0.5502615101311635, 1, 0.23809944751069664`], 
     Hue[0.5524755676281783, 1, 0.23503382943790696`], 
     Hue[0.48109892791438946`, 1, 0.3338630228877685], 
     Hue[0.39687744410879333`, 1, 0.45047738508013235`], 
     Hue[0.2975778486260126, 1, 0.5879691326716749], 
     Hue[0.19355989355890985`, 1, 0.7319939935338171], 
     Hue[0.10095941407703546`, 1, 0.8602100420471817], 
     Hue[0.03725603324661131, 1, 0.9484147231969997], 
     Hue[0.01450609336219355, 1, 0.9799146399600398], 
     Hue[0.037253350793507334`, 1, 0.948418437362836], 
     Hue[0.10095758092813145`, 1, 0.8602125802533565], 
     Hue[0.19355917011629492`, 1, 0.7319949952235917], 
     Hue[0.29757814804512334`, 1, 0.5879687180913677], 
     Hue[0.3968784471652521, 1, 0.4504759962327278], 
     Hue[0.4811002419009807, 1, 0.333861203521719], 
     Hue[0.5524778870728062, 1, 0.23503061789919152`], 
     Hue[0.5567610169112918, 1, 0.22910013043051922`], 
     Hue[0.4885288728491538, 1, 0.32357540682424857`], 
     Hue[0.4080230856664831, 1, 0.43504495830794654`], 
     Hue[0.3131081894873615, 1, 0.5664655837867302], 
     Hue[0.21368650737851752`, 1, 0.7041263743989757], 
     Hue[0.12517994846479386`, 1, 0.8266739175102854], 
     Hue[0.06429392241993914, 1, 0.9109776458800842], 
     Hue[0.0425504395154247, 1, 0.9410840068247966], 
     Hue[0.06429160086506325, 1, 0.9109808603406816], 
     Hue[0.1251783616762967, 1, 0.8266761146020507], 
     Hue[0.2136858807762101, 1, 0.7041272420021706], 
     Hue[0.3131084480167709, 1, 0.5664652258229326], 
     Hue[0.40802395331140917`, 1, 0.43504375695343345`], 
     Hue[0.4885300098526193, 1, 0.323573832511758], 
     Hue[0.5567630251190712, 1, 0.2290973498351322], 
     Hue[0.5628378848957449, 1, 0.22068600552896855`], 
     Hue[0.4990640442498221, 1, 0.3089882464233233], 
     Hue[0.42382600763506484`, 1, 0.41316398942837174`], 
     Hue[0.335126981292288, 1, 0.5359780259029858], 
     Hue[0.242220757450132, 1, 0.6646174127613557], 
     Hue[0.15951753407086655`, 1, 0.7791295682095694], 
     Hue[0.10262509794762609`, 1, 0.8579037105340561], 
     Hue[0.08230822812302196, 1, 0.8860347610604311], 
     Hue[0.10262327005221694`, 1, 0.8579062414661611], 
     Hue[0.15951628430376724`, 1, 0.7791312986563222], 
     Hue[0.24222026328893392`, 1, 0.6646180969845531], 
     Hue[0.3351271839440666, 1, 0.5359777453082155], 
     Hue[0.42382669011191876`, 1, 0.4131630444604203], 
     Hue[0.49906493923094797`, 1, 0.30898700721868744`], 
     Hue[0.5628394673492456, 1, 0.22068381443950613`], 
     Hue[0.5703273925724266, 1, 0.21031591797664007`], 
     Hue[0.5120471170280902, 1, 0.29101168411495204`], 
     Hue[0.44329929154354086`, 1, 0.38620098093971267`], 
     Hue[0.3622580851943614, 1, 0.49841188203857656`], 
     Hue[0.2773783719176226, 1, 0.6159376388832918], 
     Hue[0.20182396296106825`, 1, 0.7205514359000593], 
     Hue[0.14985096295229905`, 1, 0.7925140512968167], 
     Hue[0.13129136223214255`, 1, 0.8182119599862641], 
     Hue[0.1498497089299461, 1, 0.7925157876354592], 
     Hue[0.20182310509526863`, 1, 0.7205526237142434], 
     Hue[0.27737803188172977`, 1, 0.6159381097022203], 
     Hue[0.36225822303677513`, 1, 0.49841169117984985`], 
     Hue[0.4432997588836446, 1, 0.38620033385341523`], 
     Hue[0.5120477307271325, 1, 0.2910108343778166], 
     Hue[0.5703284797983731, 1, 0.21031441258686806`], 
     Hue[0.5787888800272748, 1, 0.1986000122699272], 
     Hue[0.5267134643102331, 1, 0.27070443403198485`], 
     Hue[0.4652951061508435, 1, 0.3557452376372936], 
     Hue[0.3929012041999783, 1, 0.4559829480307993], 
     Hue[0.3170845078871942, 1, 0.5609599121561927], 
     Hue[0.24960155901173509`, 1, 0.6543978413683669], 
     Hue[0.20318269353921975`, 1, 0.7186701166380034], 
     Hue[0.18660708062683373`, 1, 0.7416209652859226], 
     Hue[0.20318203774868981`, 1, 0.7186710246556602], 
     Hue[0.24960110964755122`, 1, 0.6543984635649291], 
     Hue[0.31708432871750963`, 1, 0.5609601602372944], 
     Hue[0.3929012747880017, 1, 0.45598285029353613`], 
     Hue[0.4652953493354146, 1, 0.3557449009201952], 
     Hue[0.5267137848105791, 1, 0.27070399026227515`], 
     Hue[0.5787894507625198, 1, 0.19859922202112662`], 
     Hue[0.5877624702504634, 1, 0.18617504119166622`], 
     Hue[0.5422653288205485, 1, 0.24917108317154826`], 
     Hue[0.4886161240406276, 1, 0.32345459748220806`], 
     Hue[0.4253872556881455, 1, 0.4110022613548755], 
     Hue[0.3591752496131902, 1, 0.502680423612506], 
     Hue[0.3002457706661208, 1, 0.5842750867699866], 
     Hue[0.2597124156575459, 1, 0.6403981937049364], 
     Hue[0.2452390237157458, 1, 0.6604382748551212], 
     Hue[0.25971232945802986`, 1, 0.6403983130581126], 
     Hue[0.30024571035715797`, 1, 0.5842751702747043], 
     Hue[0.3591752237937029, 1, 0.5026804593625652], 
     Hue[0.4253872624143836, 1, 0.41100225204162266`], 
     Hue[0.48861615402163666`, 1, 0.3234545559700416], 
     Hue[0.5422653702110632, 1, 0.24917102586160478`], 
     Hue[0.5877625488826427, 1, 0.18617493231634097`], 
     Hue[0.5968097184249482, 1, 0.173648082180841], 
     Hue[0.5579423080358296, 1, 0.22746449656577447`], 
     Hue[0.5121213473795251, 1, 0.29090890362834987`], 
     Hue[0.45812604657442185`, 1, 0.3656716278200314], 
     Hue[0.401589595811773, 1, 0.443952867337545], 
     Hue[0.3512759021513562, 1, 0.5136179816365838], 
     Hue[0.31667063497439685`, 1, 0.5615329669585275], 
     Hue[0.3043146268884743, 1, 0.5786412858467279], 
     Hue[0.31667104589567413`, 1, 0.5615323979906051], 
     Hue[0.3512761816551539, 1, 0.5136175946313254], 
     Hue[0.4015897041401657, 1, 0.443952717344386], 
     Hue[0.4581259977404595, 1, 0.36567169543628697`], 
     Hue[0.5121211915218518, 1, 0.2909091194312823], 
     Hue[0.5579421059099916, 1, 0.22746477643231938`], 
     Hue[0.5968093671146062, 1, 0.17364856861054534`], 
     Hue[0.6055472079675877, 1, 0.16155001973718633`], 
     Hue[0.5730797264426927, 1, 0.2065049941562717], 
     Hue[0.5348137958119625, 1, 0.2594885904142058], 
     Hue[0.4897284611772099, 1, 0.3219144383700171], 
     Hue[0.4425273737286087, 1, 0.3872697902219264], 
     Hue[0.40052573946783443`, 1, 0.44542589919838316`], 
     Hue[0.3716392734249071, 1, 0.4854225444885901], 
     Hue[0.3613257637555317, 1, 0.4997027886461869], 
     Hue[0.37164007869641597`, 1, 0.4854214294972703], 
     Hue[0.4005262886368838, 1, 0.44542513881046863`], 
     Hue[0.44252758864335107`, 1, 0.38726949264766775`], 
     Hue[0.4897283687679477, 1, 0.3219145663213033], 
     Hue[0.5348134927357169, 1, 0.2594890100582383], 
     Hue[0.5730793313285311, 1, 0.2065055412374186], 
     Hue[0.6055465152211047, 1, 0.16155097892462433`], 
     Hue[0.6136699866390605, 1, 0.15030309542283937`], 
     Hue[0.5871492042094948, 1, 0.18702417878685337`], 
     Hue[0.555901313513917, 1, 0.23029048898073035`], 
     Hue[0.5190912707195935, 1, 0.28125824054210136`], 
     Hue[0.4805593630784366, 1, 0.33461011266062624`], 
     Hue[0.4462758348559051, 1, 0.38207961327643913`], 
     Hue[0.4226991555060876, 1, 0.4147242462223403], 
     Hue[0.41428194997560897`, 1, 0.4263788384953108], 
     Hue[0.4227002371666561, 1, 0.4147227485384761], 
     Hue[0.4462765732084401, 1, 0.3820785909421599], 
     Hue[0.4805596531568227, 1, 0.3346097110136302], 
     Hue[0.5190911481081258, 1, 0.28125841031182575`], 
     Hue[0.5559009075730197, 1, 0.23029105105274203`], 
     Hue[0.587148673841918, 1, 0.1870249131419596], 
     Hue[0.6136690539638642, 1, 0.15030438681926506`], 
     Hue[0.620963364361293, 1, 0.14020457242282514`], 
     Hue[0.5997791025835187, 1, 0.16953662719205098`], 
     Hue[0.5748271708858737, 1, 0.2040854556964826], 
     Hue[0.545439588329388, 1, 0.2447759546208474], 
     Hue[0.5146822729985913, 1, 0.28736300661733527`], 
     Hue[0.48731955851693154`, 1, 0.3252498420534794], 
     Hue[0.46850379888396554`, 1, 0.3513024323145093], 
     Hue[0.46178677032026, 1, 0.360602933402717], 
     Hue[0.4685050384669278, 1, 0.35130071596886914`], 
     Hue[0.4873204051548792, 1, 0.3252486697855519], 
     Hue[0.5146826064214726, 1, 0.28736254495488417`], 
     Hue[0.545439448873605, 1, 0.24477614771347014`], 
     Hue[0.5748267066162704, 1, 0.20408609853131793`], 
     Hue[0.599778495006357, 1, 0.16953746845273643`], 
     Hue[0.6209622939460813, 1, 0.14020605453619522`], 
     Hue[0.6273035877223594, 1, 0.13142580161519468`], 
     Hue[0.610755573052391, 1, 0.15433843731207403`], 
     Hue[0.5912715356875938, 1, 0.18131633520179324`], 
     Hue[0.5683288547363774, 1, 0.21308312421116973`], 
     Hue[0.544321058615945, 1, 0.24632468807022995`], 
     Hue[0.5229658780640613, 1, 0.27589339960360754`], 
     Hue[0.5082824304107318, 1, 0.29622432712360214`], 
     Hue[0.5030409968157257, 1, 0.3034816967166876], 
     Hue[0.5082837209174339, 1, 0.2962225402681685], 
     Hue[0.5229667598564569, 1, 0.2758921786602904], 
     Hue[0.5443214064451818, 1, 0.24632420646051748`], 
     Hue[0.5683287105046836, 1, 0.21308332391659193`], 
     Hue[0.5912710529523794, 1, 0.1813170036043979], 
     Hue[0.6107549408429755, 1, 0.15433931267895704`], 
     Hue[0.6273024721629233, 1, 0.1314273462359524], 
     Hue[0.6327224787398396, 1, 0.12392272174483755`], 
     Hue[0.6201340030575886, 1, 0.14135291884333887`], 
     Hue[0.6053178951223055, 1, 0.161867529830654], 
     Hue[0.5878758526882779, 1, 0.18601805012392292`], 
     Hue[0.5696275304156976, 1, 0.2112849578859572], 
     Hue[0.5533978740975912, 1, 0.23375678971102762`], 
     Hue[0.5422397026998013, 1, 0.2492065654925829], 
     Hue[0.5382570964254455, 1, 0.25472094341092166`], 
     Hue[0.542241157269009, 1, 0.24920455147367984`], 
     Hue[0.5533988687474061, 1, 0.23375541250359166`], 
     Hue[0.5696279238346578, 1, 0.21128441315201235`], 
     Hue[0.5878756915996006, 1, 0.18601827316978375`], 
     Hue[0.6053173521973283, 1, 0.16186828157293007`], 
     Hue[0.6201332908743415, 1, 0.14135390494321948`], 
     Hue[0.6327212191925413, 1, 0.12392446573340436`], 
     Hue[0.6426169513066162, 1, 0.1102226828062237], 
     Hue[0.6372377100661449, 1, 0.11767086298533777`], 
     Hue[0.6309092329782288, 1, 0.1264333697224525], 
     Hue[0.6234601390512056, 1, 0.1367474997752538], 
     Hue[0.6156675658591593, 1, 0.14753721650270263`], 
     Hue[0.608737603472198, 1, 0.15713254903849522`], 
     Hue[0.603973397789667, 1, 0.16372914152199963`], 
     Hue[0.6022757448098639, 1, 0.16607973795557307`], 
     Hue[0.6039789462997005, 1, 0.16372145896964552`], 
     Hue[0.6087414029233007, 1, 0.15712728826004524`], 
     Hue[0.615669077128538, 1, 0.14753512397587054`], 
     Hue[0.6234595367036779, 1, 0.13674833379490747`], 
     Hue[0.6309071712190801, 1, 0.1264362244658891], 
     Hue[0.6372349970239707, 1, 0.11767461950527143`], 
     Hue[0.6426121298967593, 1, 0.11022935860448715`], 
     Hue[0.6498958580678137, 1, 0.10014419652148876`], 
     Hue[0.6498193884887249, 1, 0.10025007747715022`], 
     Hue[0.6497294634089954, 1, 0.10037458912600633`], 
     Hue[0.6496236056366957, 1, 0.10052116142611357`], 
     Hue[0.6495128594866585, 1, 0.10067450224924218`], 
     Hue[0.649414369301028, 1, 0.10081087327549972`], 
     Hue[0.6493466586105661, 1, 0.10090462653921622`], 
     Hue[0.6493226359923682, 1, 0.10093788862595174`], 
     Hue[0.6493469313116931, 1, 0.10090424895304038`], 
     Hue[0.6494145560301994, 1, 0.10081061472741623`], 
     Hue[0.6495129338042546, 1, 0.10067439934795527`], 
     Hue[0.6496235760977022, 1, 0.10052120232625851`], 
     Hue[0.6497293620994847, 1, 0.10037472940071342`], 
     Hue[0.6498192551554071, 1, 0.10025026209251335`], 
     Hue[0.6498956210456897, 1, 0.10014452470596819`], 
     Hue[0.6432670322601114, 1, 0.1093225707167688], 
     Hue[0.6412530637161606, 1, 0.11211114254685453`], 
     Hue[0.64055187699897, 1, 0.11308201646296469`], 
     Hue[0.6422826805592395, 1, 0.11068551922566836`], 
     Hue[0.6471639496479785, 1, 0.10392683894895278`], 
     Hue[0.6134393712358532, 1, 0.15062240905804938`], 
     Hue[0.617722431996425, 1, 0.14469201723571926`], 
     Hue[0.625798101903588, 1, 0.13351032044118585`], 
     Hue[0.6356016827117188, 1, 0.1199361316299279], 
     Hue[0.6447160778201385, 1, 0.1073161999413467], 
     Hue[0.6180167115996045, 1, 0.14428455316977845`], 
     Hue[0.6308010827908601, 1, 0.12658311613573214`], 
     Hue[0.6400860008926635, 1, 0.1137270756870813], 
     Hue[0.6458023147122057, 1, 0.1058121796292537], 
     Hue[0.6492431084282864, 1, 0.10104800371468042`], 
     Hue[0.6336085712861589, 1, 0.12269582437301088`], 
     Hue[0.6255927744265147, 1, 0.13379462002482578`], 
     Hue[0.6184284943141801, 1, 0.1437143924880583], 
     Hue[0.6134745067166797, 1, 0.15057375993075123`], 
     Hue[0.6124731669546335, 1, 0.1519602303705075], 
     Hue[0.5597906890952162, 1, 0.22490519971431608`], 
     Hue[0.5609429858823104, 1, 0.22330971185526255`], 
     Hue[0.5702672651642874, 1, 0.21039917131098668`], 
     Hue[0.5852727256986744, 1, 0.18962237980183555`], 
     Hue[0.6023460341736332, 1, 0.1659824142211233], 
     Hue[0.5728233150649802, 1, 0.20686002529464279`], 
     Hue[0.5978608444763083, 1, 0.17219267687895778`], 
     Hue[0.6177971273208912, 1, 0.14458859294030454`], 
     Hue[0.6317774561574506, 1, 0.12523121455122221`], 
     Hue[0.6417279253205035, 1, 0.1114536418639183], 
     Hue[0.627788739277394, 1, 0.1307540533082238], 
     Hue[0.6137476741062011, 1, 0.15019552816064463`], 
     Hue[0.5984661270407605, 1, 0.1713545933281777], 
     Hue[0.5823892479014552, 1, 0.1936148875210621], 
     Hue[0.5678708626721414, 1, 0.21371726706934283`], 
     Hue[0.5264808821814904, 1, 0.2710264708256288], 
     Hue[0.51856947216833, 1, 0.28198073084385067`], 
     Hue[0.5206490804550483, 1, 0.27910127321608696`], 
     Hue[0.5319539978428438, 1, 0.2634483106791394], 
     Hue[0.5498837618975733, 1, 0.238622483526437], 
     Hue[0.5460781147159542, 1, 0.24389184116252494`], 
     Hue[0.5738152966617035, 1, 0.20548651231456438`], 
     Hue[0.5981227827376427, 1, 0.1718299931324947], 
     Hue[0.6171412389813049, 1, 0.14549674602588547`], 
     Hue[0.6322361435905947, 1, 0.12459610887456123`], 
     Hue[0.6215312007966796, 1, 0.13941833735844364`], 
     Hue[0.6032807955115133, 1, 0.16468812929175092`], 
     Hue[0.5832495875495568, 1, 0.19242364800830597`], 
     Hue[0.5619036579491845, 1, 0.22197955053189833`], 
     Hue[0.5422634024502561, 1, 0.2491737504534917], 
     Hue[0.49143641314473197`, 1, 0.3195495817996019], 
     Hue[0.48055379551473054`, 1, 0.33461782159498854`], 
     Hue[0.48241389402331597`, 1, 0.332042300583101], 
     Hue[0.49623368777809296`, 1, 0.31290720153802515`], 
     Hue[0.5188498732647925, 1, 0.2815924831718258], 
     Hue[0.5167402753982261, 1, 0.2845134648332255], 
     Hue[0.5518646402844236, 1, 0.235879728836952], 
     Hue[0.5828486430136465, 1, 0.19297880198110498`], 
     Hue[0.607253262945072, 1, 0.1591877897683619], 
     Hue[0.6267346593848439, 1, 0.13221354854406242`], 
     Hue[0.6143233938953457, 1, 0.14939837768336744`], 
     Hue[0.5911781275556787, 1, 0.18144566953829105`], 
     Hue[0.5655942394702503, 1, 0.2168695145796534], 
     Hue[0.538042948910495, 1, 0.25501745535469933`], 
     Hue[0.5123130950578718, 1, 0.29064340684294676`], 
     Hue[0.45101559593564255`, 1, 0.3755168671660334], 
     Hue[0.4365740211159339, 1, 0.3955128938394762], 
     Hue[0.4380343927337269, 1, 0.39349084083022434`], 
     Hue[0.45463005955166735`, 1, 0.3705122252361529], 
     Hue[0.48258054548984075`, 1, 0.3318115523986821], 
     Hue[0.482928869591982, 1, 0.331329257488025], 
     Hue[0.5264877691436816, 1, 0.27101693503182567`], 
     Hue[0.5651338019504073, 1, 0.21750704345328228`], 
     Hue[0.595749619171822, 1, 0.17511591191593873`], 
     Hue[0.6203089596274788, 1, 0.14111067128502947`], 
     Hue[0.6062751719935869, 1, 0.16054206954734124`], 
     Hue[0.577567654884599, 1, 0.2002909393905552], 
     Hue[0.5456133928020999, 1, 0.24453530227401563`], 
     Hue[0.5108479266774192, 1, 0.2926721015235735], 
     Hue[0.4779185437202067, 1, 0.33826663177202154`], 
     Hue[0.40580850751011666`, 1, 0.4381112972936847], 
     Hue[0.38710539258653054`, 1, 0.4640079179571116], 
     Hue[0.38780391391091, 1, 0.4630407345848938], 
     Hue[0.40723391967740985`, 1, 0.4361376496774326], 
     Hue[0.4409936328930443, 1, 0.38939343137886173`], 
     Hue[0.4451684747100397, 1, 0.38361288117071435`], 
     Hue[0.4979716801206474, 1, 0.31050075060218063`], 
     Hue[0.5451013481926241, 1, 0.2452442871179051], 
     Hue[0.5826608286441058, 1, 0.19323885264662272`], 
     Hue[0.612941217282257, 1, 0.15131216068610576`], 
     Hue[0.5975930766290172, 1, 0.1725634323598224], 
     Hue[0.5627707137144806, 1, 0.22077901177994988`], 
     Hue[0.5237424830742484, 1, 0.274818100358733], 
     Hue[0.4808559336876715, 1, 0.3341994764324549], 
     Hue[0.43968454609442587`, 1, 0.3912060131000258], 
     Hue[0.3569622667530063, 1, 0.5057445537266066], 
     Hue[0.3333200485926565, 1, 0.5384799327178603], 
     Hue[0.33282027668953873`, 1, 0.5391719245837157], 
     Hue[0.35499038208254546`, 1, 0.508474855578014], 
     Hue[0.394839678467105, 1, 0.45329890673785467`], 
     Hue[0.4044326263121378, 1, 0.44001636356780927`], 
     Hue[0.46699847829300933`, 1, 0.35338672236352553`], 
     Hue[0.5231924110198737, 1, 0.2755797385878672], 
     Hue[0.5682510443450479, 1, 0.21319086167608758`], 
     Hue[0.6047633384625758, 1, 0.16263537751335672`], 
     Hue[0.5885739589734652, 1, 0.18505144142135593`], 
     Hue[0.5472657246634997, 1, 0.2422474581582313], 
     Hue[0.5006531714587011, 1, 0.3067879164417985], 
     Hue[0.44893409467340356`, 1, 0.3783989458368259], 
     Hue[0.39864398660653866`, 1, 0.4480314031601772], 
     Hue[0.30613714542441306`, 1, 0.5761177986431204], 
     Hue[0.27696374403564483`, 1, 0.6165117390275687], 
     Hue[0.2747769279262213, 1, 0.6195396382560012], 
     Hue[0.29941936073446906`, 1, 0.5854193466753506], 
     Hue[0.34538449739612315`, 1, 0.5217753112976757], 
     Hue[0.3621209519908067, 1, 0.49860175878196], 
     Hue[0.4345791545435442, 1, 0.39827501678586197`], 
     Hue[0.500084212233562, 1, 0.307575706138145], 
     Hue[0.552941860021709, 1, 0.23438819381609535`], 
     Hue[0.5959981070525373, 1, 0.17477185177340993`], 
     Hue[0.579594182301374, 1, 0.19748497835194373`], 
     Hue[0.5316739170993457, 1, 0.26383611478552127`], 
     Hue[0.47723759735959204`, 1, 0.3392094805790264], 
     Hue[0.41626594024551333`, 1, 0.42363177504467386`], 
     Hue[0.3562518639222174, 1, 0.5067281884153912], 
     Hue[0.25544782939052296`, 1, 0.6463030054592759], 
     Hue[0.22030348310954634`, 1, 0.6949644080021666], 
     Hue[0.21592316975918785`, 1, 0.7010294572565091], 
     Hue[0.24259113109163727`, 1, 0.6641045877192715], 
     Hue[0.29439908564497536`, 1, 0.5923704967992649], 
     Hue[0.32000785039776697`, 1, 0.5569122071415534], 
     Hue[0.40202252169466446`, 1, 0.4433534314996954], 
     Hue[0.4766737410268823, 1, 0.3399902047320092], 
     Hue[0.5373050892257643, 1, 0.2560391072258649], 
     Hue[0.5869575084668387, 1, 0.18728960366130032`], 
     Hue[0.5710872328122532, 1, 0.20926383149072644`], 
     Hue[0.5167251850346483, 1, 0.28453435918279474`], 
     Hue[0.45456303581376467`, 1, 0.3706050273347874], 
     Hue[0.3842971118118804, 1, 0.46789630672201177`], 
     Hue[0.31432650590976696`, 1, 0.5647786841249381], 
     Hue[0.20733875071075575`, 1, 0.7129155759389536], 
     Hue[0.1660024444276858, 1, 0.7701504615616658], 
     Hue[0.1589493449301977, 1, 0.7799162916351109], 
     Hue[0.18703012692867338`, 1, 0.7410352088679907], 
     Hue[0.24408594985937843`, 1, 0.6620348386562452], 
     Hue[0.28013617649380124`, 1, 0.6121191402393521], 
     Hue[0.3708622433144219, 1, 0.48649843233387746`], 
     Hue[0.4540316873519137, 1, 0.37134074058965794`], 
     Hue[0.522035897273629, 1, 0.2771810653134368], 
     Hue[0.5780298854580632, 1, 0.19965092782729704`], 
     Hue[0.563511019306925, 1, 0.21975397326733456`], 
     Hue[0.5032053724394926, 1, 0.30325409969916417`], 
     Hue[0.4337980162250367, 1, 0.39935659291918], 
     Hue[0.35463996524360725`, 1, 0.5089600481242362], 
     Hue[0.2749360615481364, 1, 0.6193192993948881], 
     Hue[0.16440022497095574`, 1, 0.7723689192709844], 
     Hue[0.11692659598318078`, 1, 0.8381016363309804], 
     Hue[0.10679991366380204`, 1, 0.8521231964655049], 
     Hue[0.13554779899441238`, 1, 0.8123184321615828], 
     Hue[0.1969400572019434, 1, 0.7273137669511553], 
     Hue[0.244662710329695, 1, 0.661236247235807], 
     Hue[0.3427452344342436, 1, 0.5254296753987396], 
     Hue[0.4333278292564815, 1, 0.4000076210294873], 
     Hue[0.5079065757593585, 1, 0.29674474125627287`], 
     Hue[0.5696556090993762, 1, 0.21124607970855602`], 
     Hue[0.5573078855136699, 1, 0.22834292775030318`], 
     Hue[0.49188966916713917`, 1, 0.3189219965378073], 
     Hue[0.41611570155088495`, 1, 0.4238397978526208], 
     Hue[0.3289443018365475, 1, 0.5445386589955497], 
     Hue[0.2402382951548664, 1, 0.6673623605548004], 
     Hue[0.129142297944433, 1, 0.8211875874615543], 
     Hue[0.07590092200313592, 1, 0.8949064156879656], 
     Hue[0.062429435740938066`, 1, 0.9135592428202396], 
     Hue[0.09101591614372295, 1, 0.8739779622625374], 
     Hue[0.15555362786398375`, 1, 0.7846180537267917], 
     Hue[0.2156684604819588, 1, 0.7013821316403648], 
     Hue[0.3192910676832634, 1, 0.5579046755154815], 
     Hue[0.41573414221698096`, 1, 0.42436811077648795`], 
     Hue[0.49570429192730225`, 1, 0.31364021117758156`], 
     Hue[0.5622928254940656, 1, 0.22144070316206316`], 
     Hue[0.5528621143129753, 1, 0.23449861095126512`], 
     Hue[0.48346958900868453`, 1, 0.33058056906489836`], 
     Hue[0.402585392648726, 1, 0.4425740717171487], 
     Hue[0.3087474576267833, 1, 0.5725035202090692], 
     Hue[0.21228788392593295`, 1, 0.7060629299487082], 
     Hue[0.10375357462868628`, 1, 0.8563412043602805], 
     Hue[0.04544226115578831, 1, 0.9370799460919854], 
     Hue[0.028528340951307407`, 1, 0.9604992202212667], 
     Hue[0.05610511392484341, 1, 0.922315996104063], 
     Hue[0.12238397672032486`, 1, 0.8305452630026271], 
     Hue[0.19495787943114457`, 1, 0.730058320787646], 
     Hue[0.30193883613655437`, 1, 0.5819308422724633], 
     Hue[0.4023160544951288, 1, 0.44294700146828325`], 
     Hue[0.48615945773804453`, 1, 0.32685613543963066`], 
     Hue[0.5563766442135991, 1, 0.22963233878117056`], 
     Hue[0.5504603601125956, 1, 0.23782411676717538`], 
     Hue[0.4784830257287196, 1, 0.33748504129869594`], 
     Hue[0.3940656300924371, 1, 0.4543706660258563], 
     Hue[0.2953226222573054, 1, 0.5910917537975772], 
     Hue[0.19283611511503895`, 1, 0.7329961483022538], 
     Hue[0.08987650496460464, 1, 0.8755556085105475], 
     Hue[0.02750426862112454, 1, 0.9619171665245967], 
     Hue[0.0072533689255459555`, 1, 0.989956873795398], 
     Hue[0.03302049699040399, 1, 0.9542793118594407], 
     Hue[0.09951326985387388, 1, 0.8622123955869438], 
     Hue[0.18387320634860493`, 1, 0.7454063296711624], 
     Hue[0.2918011380948874, 1, 0.5959676549455406], 
     Hue[0.3939259619828554, 1, 0.45456405263912325`], 
     Hue[0.47987363275358597`, 1, 0.3355595854181117], 
     Hue[0.552276944877135, 1, 0.2353088455547362], 
     Hue[0.5502605344346037, 1, 0.23810079847516416`], 
     Hue[0.4772569851352818, 1, 0.33918263596653286`], 
     Hue[0.3911137242536845, 1, 0.4584579202641291], 
     Hue[0.28954586233322194`, 1, 0.5990903444616927], 
     Hue[0.18314962691401915`, 1, 0.7464082088882812], 
     Hue[0.08843171541781147, 1, 0.8775560863445687], 
     Hue[0.023270413385846567`, 1, 0.9677794276195971], 
     Hue[5.551115123125783*^-16, 1, 0.9999999999999992], 
     Hue[0.023270413385846456`, 1, 0.9677794276195972], 
     Hue[0.0884317154178117, 1, 0.8775560863445684], 
     Hue[0.18314962691401832`, 1, 0.7464082088882823], 
     Hue[0.28954586233322177`, 1, 0.599090344461693], 
     Hue[0.39111372425368446`, 1, 0.45845792026412924`], 
     Hue[0.4772569851352815, 1, 0.3391826359665334], 
     Hue[0.5502605344346039, 1, 0.23810079847516394`], 
     Hue[0.5522769448771349, 1, 0.23530884555473644`], 
     Hue[0.47987363275358613`, 1, 0.33555958541811154`], 
     Hue[0.39392596198285534`, 1, 0.45456405263912336`], 
     Hue[0.29180113809488756`, 1, 0.5959676549455403], 
     Hue[0.18387320634860504`, 1, 0.7454063296711623], 
     Hue[0.09951326985387332, 1, 0.8622123955869446], 
     Hue[0.03302049699040399, 1, 0.9542793118594406], 
     Hue[0.007253368925545067, 1, 0.9899568737953991], 
     Hue[0.027504268621123984`, 1, 0.9619171665245976], 
     Hue[0.08987650496460409, 1, 0.8755556085105483], 
     Hue[0.1928361151150383, 1, 0.7329961483022547], 
     Hue[0.2953226222573051, 1, 0.5910917537975776], 
     Hue[0.39406563009243667`, 1, 0.45437066602585696`], 
     Hue[0.47848302572871904`, 1, 0.3374850412986967], 
     Hue[0.5504603601125957, 1, 0.23782411676717527`], 
     Hue[0.556376644213599, 1, 0.22963233878117065`], 
     Hue[0.4861594577380448, 1, 0.3268561354396303], 
     Hue[0.4023160544951288, 1, 0.44294700146828325`], 
     Hue[0.30193883613655415`, 1, 0.5819308422724635], 
     Hue[0.19495787943114423`, 1, 0.7300583207876464], 
     Hue[0.1223839767203252, 1, 0.8305452630026267], 
     Hue[0.05610511392484352, 1, 0.9223159961040629], 
     Hue[0.028528340951307074`, 1, 0.9604992202212671], 
     Hue[0.045442261155787755`, 1, 0.9370799460919861], 
     Hue[0.10375357462868562`, 1, 0.8563412043602814], 
     Hue[0.21228788392593306`, 1, 0.706062929948708], 
     Hue[0.3087474576267832, 1, 0.5725035202090695], 
     Hue[0.40258539264872584`, 1, 0.4425740717171489], 
     Hue[0.4834695890086842, 1, 0.33058056906489885`], 
     Hue[0.5528621143129753, 1, 0.2344986109512651], 
     Hue[0.5622928254940655, 1, 0.2214407031620632], 
     Hue[0.4957042919273025, 1, 0.3136402111775813], 
     Hue[0.41573414221698096`, 1, 0.42436811077648795`], 
     Hue[0.31929106768326354`, 1, 0.5579046755154813], 
     Hue[0.21566846048195915`, 1, 0.7013821316403642], 
     Hue[0.1555536278639834, 1, 0.7846180537267922], 
     Hue[0.09101591614372329, 1, 0.873977962262537], 
     Hue[0.062429435740937955`, 1, 0.9135592428202398], 
     Hue[0.07590092200313547, 1, 0.8949064156879663], 
     Hue[0.12914229794443266`, 1, 0.8211875874615547], 
     Hue[0.24023829515486617`, 1, 0.6673623605548007], 
     Hue[0.32894430183654727`, 1, 0.54453865899555], 
     Hue[0.41611570155088495`, 1, 0.4238397978526208], 
     Hue[0.4918896691671389, 1, 0.31892199653780773`], 
     Hue[0.55730788551367, 1, 0.228342927750303], 
     Hue[0.569655609099376, 1, 0.21124607970855636`], 
     Hue[0.5079065757593586, 1, 0.2967447412562727], 
     Hue[0.4333278292564813, 1, 0.4000076210294875], 
     Hue[0.3427452344342435, 1, 0.5254296753987399], 
     Hue[0.24466271032969478`, 1, 0.6612362472358072], 
     Hue[0.19694005720194308`, 1, 0.7273137669511557], 
     Hue[0.13554779899441216`, 1, 0.8123184321615831], 
     Hue[0.1067999136638016, 1, 0.8521231964655054], 
     Hue[0.11692659598318034`, 1, 0.8381016363309811], 
     Hue[0.1644002249709553, 1, 0.7723689192709849], 
     Hue[0.274936061548136, 1, 0.6193192993948886], 
     Hue[0.354639965243607, 1, 0.5089600481242365], 
     Hue[0.43379801622503644`, 1, 0.39935659291918035`], 
     Hue[0.5032053724394923, 1, 0.30325409969916467`], 
     Hue[0.563511019306925, 1, 0.2197539732673346], 
     Hue[0.5780298854580632, 1, 0.19965092782729715`], 
     Hue[0.5220358972736292, 1, 0.27718106531343656`], 
     Hue[0.4540316873519136, 1, 0.37134074058965805`], 
     Hue[0.3708622433144216, 1, 0.4864984323338778], 
     Hue[0.2801361764938012, 1, 0.6121191402393522], 
     Hue[0.2440859498593782, 1, 0.6620348386562456], 
     Hue[0.1870301269286732, 1, 0.7410352088679909], 
     Hue[0.1589493449301974, 1, 0.7799162916351113], 
     Hue[0.16600244442768497`, 1, 0.770150461561667], 
     Hue[0.2073387507107548, 1, 0.7129155759389548], 
     Hue[0.31432650590976674`, 1, 0.5647786841249384], 
     Hue[0.3842971118118802, 1, 0.467896306722012], 
     Hue[0.45456303581376445`, 1, 0.37060502733478773`], 
     Hue[0.5167251850346479, 1, 0.2845343591827952], 
     Hue[0.5710872328122532, 1, 0.20926383149072653`], 
     Hue[0.5869575084668386, 1, 0.18728960366130046`], 
     Hue[0.5373050892257645, 1, 0.25603910722586465`], 
     Hue[0.4766737410268823, 1, 0.33999020473200914`], 
     Hue[0.4020225216946644, 1, 0.4433534314996954], 
     Hue[0.320007850397767, 1, 0.5569122071415533], 
     Hue[0.2943990856449754, 1, 0.5923704967992648], 
     Hue[0.24259113109163727`, 1, 0.6641045877192715], 
     Hue[0.21592316975918763`, 1, 0.7010294572565094], 
     Hue[0.22030348310954578`, 1, 0.6949644080021674], 
     Hue[0.2554478293905231, 1, 0.6463030054592758], 
     Hue[0.35625186392221725`, 1, 0.5067281884153916], 
     Hue[0.41626594024551333`, 1, 0.423631775044674], 
     Hue[0.47723759735959204`, 1, 0.33920948057902645`], 
     Hue[0.5316739170993455, 1, 0.26383611478552166`], 
     Hue[0.579594182301374, 1, 0.19748497835194362`], 
     Hue[0.5959981070525372, 1, 0.17477185177341], 
     Hue[0.5529418600217092, 1, 0.23438819381609502`], 
     Hue[0.500084212233562, 1, 0.30757570613814494`], 
     Hue[0.4345791545435442, 1, 0.39827501678586197`], 
     Hue[0.3621209519908067, 1, 0.49860175878196], 
     Hue[0.3453844973961235, 1, 0.5217753112976753], 
     Hue[0.2994193607344692, 1, 0.5854193466753503], 
     Hue[0.27477692792622116`, 1, 0.6195396382560014], 
     Hue[0.27696374403564417`, 1, 0.6165117390275696], 
     Hue[0.3061371454244128, 1, 0.5761177986431207], 
     Hue[0.39864398660653844`, 1, 0.44803140316017753`], 
     Hue[0.4489340946734035, 1, 0.3783989458368259], 
     Hue[0.500653171458701, 1, 0.3067879164417987], 
     Hue[0.5472657246634994, 1, 0.24224745815823162`], 
     Hue[0.5885739589734652, 1, 0.18505144142135593`], 
     Hue[0.6047633384625756, 1, 0.1626353775133569], 
     Hue[0.5682510443450479, 1, 0.21319086167608753`], 
     Hue[0.5231924110198736, 1, 0.2755797385878674], 
     Hue[0.4669984782930092, 1, 0.35338672236352564`], 
     Hue[0.40443262631213817`, 1, 0.4400163635678087], 
     Hue[0.39483967846710455`, 1, 0.45329890673785533`], 
     Hue[0.35499038208254485`, 1, 0.5084748555780149], 
     Hue[0.3328202766895381, 1, 0.5391719245837164], 
     Hue[0.33332004859265607`, 1, 0.5384799327178609], 
     Hue[0.356962266753006, 1, 0.5057445537266071], 
     Hue[0.4396845460944252, 1, 0.3912060131000267], 
     Hue[0.4808559336876712, 1, 0.3341994764324553], 
     Hue[0.5237424830742482, 1, 0.27481810035873333`], 
     Hue[0.5627707137144804, 1, 0.22077901177995024`], 
     Hue[0.5975930766290172, 1, 0.17256343235982236`], 
     Hue[0.6129412172822569, 1, 0.1513121606861058], 
     Hue[0.582660828644106, 1, 0.1932388526466225], 
     Hue[0.5451013481926241, 1, 0.24524428711790514`], 
     Hue[0.4979716801206472, 1, 0.31050075060218085`], 
     Hue[0.4451684747100392, 1, 0.383612881170715], 
     Hue[0.44099363289304444`, 1, 0.3893934313788616], 
     Hue[0.40723391967741, 1, 0.4361376496774323], 
     Hue[0.3878039139109099, 1, 0.46304073458489403`], 
     Hue[0.3871053925865298, 1, 0.4640079179571126], 
     Hue[0.4058085075101159, 1, 0.4381112972936857], 
     Hue[0.47791854372020676`, 1, 0.33826663177202143`], 
     Hue[0.5108479266774192, 1, 0.2926721015235735], 
     Hue[0.5456133928020998, 1, 0.2445353022740158], 
     Hue[0.5775676548845988, 1, 0.20029093939055556`], 
     Hue[0.6062751719935868, 1, 0.1605420695473413], 
     Hue[0.6203089596274787, 1, 0.1411106712850296], 
     Hue[0.5957496191718221, 1, 0.17511591191593862`], 
     Hue[0.5651338019504072, 1, 0.21750704345328234`], 
     Hue[0.5264877691436817, 1, 0.27101693503182545`], 
     Hue[0.4829288695919822, 1, 0.3313292574880246], 
     Hue[0.48258054548984053`, 1, 0.3318115523986824], 
     Hue[0.45463005955166735`, 1, 0.3705122252361529], 
     Hue[0.4380343927337269, 1, 0.39349084083022434`], 
     Hue[0.4365740211159338, 1, 0.3955128938394764], 
     Hue[0.45101559593564255`, 1, 0.3755168671660334], 
     Hue[0.5123130950578715, 1, 0.2906434068429472], 
     Hue[0.5380429489104949, 1, 0.25501745535469944`], 
     Hue[0.5655942394702502, 1, 0.21686951457965348`], 
     Hue[0.5911781275556787, 1, 0.18144566953829117`], 
     Hue[0.6143233938953458, 1, 0.14939837768336733`], 
     Hue[0.6267346593848437, 1, 0.13221354854406253`], 
     Hue[0.607253262945072, 1, 0.1591877897683619], 
     Hue[0.5828486430136464, 1, 0.19297880198110512`], 
     Hue[0.5518646402844234, 1, 0.23587972883695227`], 
     Hue[0.5167402753982258, 1, 0.2845134648332258], 
     Hue[0.5188498732647923, 1, 0.2815924831718261], 
     Hue[0.4962336877780928, 1, 0.3129072015380254], 
     Hue[0.4824138940233156, 1, 0.3320423005831016], 
     Hue[0.4805537955147301, 1, 0.33461782159498915`], 
     Hue[0.4914364131447315, 1, 0.3195495817996026], 
     Hue[0.5422634024502558, 1, 0.24917375045349197`], 
     Hue[0.5619036579491844, 1, 0.2219795505318985], 
     Hue[0.5832495875495567, 1, 0.19242364800830622`], 
     Hue[0.603280795511513, 1, 0.1646881292917512], 
     Hue[0.6215312007966796, 1, 0.1394183373584437], 
     Hue[0.6322361435905947, 1, 0.12459610887456124`], 
     Hue[0.617141238981305, 1, 0.1454967460258854], 
     Hue[0.5981227827376426, 1, 0.1718299931324948], 
     Hue[0.5738152966617034, 1, 0.2054865123145645], 
     Hue[0.5460781147159541, 1, 0.24389184116252516`], 
     Hue[0.5498837618975733, 1, 0.238622483526437], 
     Hue[0.5319539978428438, 1, 0.2634483106791393], 
     Hue[0.5206490804550483, 1, 0.279101273216087], 
     Hue[0.5185694721683298, 1, 0.281980730843851], 
     Hue[0.52648088218149, 1, 0.2710264708256292], 
     Hue[0.5678708626721414, 1, 0.2137172670693428], 
     Hue[0.5823892479014552, 1, 0.19361488752106204`], 
     Hue[0.5984661270407605, 1, 0.17135459332817785`], 
     Hue[0.613747674106201, 1, 0.15019552816064477`], 
     Hue[0.627788739277394, 1, 0.1307540533082238], 
     Hue[0.6417279253205034, 1, 0.11145364186391843`], 
     Hue[0.6317774561574506, 1, 0.12523121455122227`], 
     Hue[0.6177971273208911, 1, 0.14458859294030463`], 
     Hue[0.5978608444763083, 1, 0.17219267687895778`], 
     Hue[0.5728233150649804, 1, 0.20686002529464262`], 
     Hue[0.6023460341736327, 1, 0.16598241422112395`], 
     Hue[0.585272725698674, 1, 0.18962237980183605`], 
     Hue[0.5702672651642873, 1, 0.21039917131098695`], 
     Hue[0.5609429858823103, 1, 0.22330971185526277`], 
     Hue[0.5597906890952162, 1, 0.2249051997143161], 
     Hue[0.612473166954633, 1, 0.15196023037050804`], 
     Hue[0.6134745067166796, 1, 0.15057375993075145`], 
     Hue[0.61842849431418, 1, 0.14371439248805848`], 
     Hue[0.6255927744265147, 1, 0.13379462002482584`], 
     Hue[0.6336085712861589, 1, 0.12269582437301085`], 
     Hue[0.6492431084282864, 1, 0.1010480037146804], 
     Hue[0.6458023147122057, 1, 0.10581217962925371`], 
     Hue[0.6400860008926634, 1, 0.11372707568708143`], 
     Hue[0.6308010827908599, 1, 0.12658311613573245`], 
     Hue[0.618016711599604, 1, 0.14428455316977903`], 
     Hue[0.6447160778201386, 1, 0.10731619994134659`], 
     Hue[0.6356016827117187, 1, 0.11993613162992803`], 
     Hue[0.6257981019035878, 1, 0.13351032044118621`], 
     Hue[0.6177224319964245, 1, 0.1446920172357199], 
     Hue[0.6134393712358527, 1, 0.15062240905805013`], 
     Hue[0.6471639496479787, 1, 0.1039268389489526], 
     Hue[0.6422826805592395, 1, 0.11068551922566831`], 
     Hue[0.6405518769989699, 1, 0.11308201646296481`], 
     Hue[0.6412530637161605, 1, 0.11211114254685471`], 
     Hue[0.6432670322601114, 1, 0.10932257071676893`], 
     Hue[0.6426121298967594, 1, 0.11022935860448697`], 
     Hue[0.6498956210456897, 1, 0.10014452470596819`], 
     Hue[0.6327212191925413, 1, 0.12392446573340435`], 
     Hue[0.6273024721629233, 1, 0.13142734623595234`], 
     Hue[0.6209622939460814, 1, 0.1402060545361951], 
     Hue[0.6136690539638642, 1, 0.15030438681926508`], 
     Hue[0.6055465152211048, 1, 0.16155097892462422`], 
     Hue[0.5968093671146062, 1, 0.17364856861054534`], 
     Hue[0.5877625488826427, 1, 0.1861749323163409], 
     Hue[0.5787894507625196, 1, 0.19859922202112662`], 
     Hue[0.5703284797983732, 1, 0.21031441258686792`], 
     Hue[0.5628394673492456, 1, 0.22068381443950608`], 
     Hue[0.556763025119071, 1, 0.22909734983513239`], 
     Hue[0.5524778870728062, 1, 0.23503061789919147`], 
     Hue[0.5502615101311635, 1, 0.23809944751069675`], 
     Hue[0.5502596758638848, 1, 0.23810198726539028`], 
     Hue[0.5524755676281783, 1, 0.23503382943790702`], 
     Hue[0.5567610169112917, 1, 0.22910013043051924`], 
     Hue[0.5628378848957449, 1, 0.2206860055289686], 
     Hue[0.5703273925724266, 1, 0.21031591797664007`], 
     Hue[0.5787888800272748, 1, 0.1986000122699272], 
     Hue[0.5877624702504634, 1, 0.18617504119166617`], 
     Hue[0.5968097184249482, 1, 0.173648082180841], 
     Hue[0.6055472079675877, 1, 0.16155001973718633`], 
     Hue[0.6136699866390605, 1, 0.15030309542283937`], 
     Hue[0.620963364361293, 1, 0.14020457242282514`], 
     Hue[0.6273035877223594, 1, 0.13142580161519468`], 
     Hue[0.6327224787398396, 1, 0.12392272174483755`], 
     Hue[0.6426169513066162, 1, 0.11022268280622372`], 
     Hue[0.6498958580678137, 1, 0.10014419652148876`], 
     Hue[0.6372349970239709, 1, 0.11767461950527106`], 
     Hue[0.6498192551554071, 1, 0.10025026209251335`], 
     Hue[0.6201332908743415, 1, 0.14135390494321937`], 
     Hue[0.6107549408429757, 1, 0.15433931267895676`], 
     Hue[0.5997784950063574, 1, 0.16953746845273604`], 
     Hue[0.5871486738419182, 1, 0.18702491314195946`], 
     Hue[0.5730793313285315, 1, 0.206505541237418], 
     Hue[0.5579421059099918, 1, 0.22746477643231902`], 
     Hue[0.5422653702110636, 1, 0.24917102586160433`], 
     Hue[0.5267137848105794, 1, 0.27070399026227465`], 
     Hue[0.5120477307271329, 1, 0.29101083437781583`], 
     Hue[0.49906493923094836`, 1, 0.3089870072186869], 
     Hue[0.48853000985261963`, 1, 0.3235738325117575], 
     Hue[0.4811002419009813, 1, 0.3338612035217183], 
     Hue[0.47725762494663393`, 1, 0.3391817500738915], 
     Hue[0.47725658556548656`, 1, 0.3391831892170186], 
     Hue[0.4810989279143894, 1, 0.3338630228877686], 
     Hue[0.4885288728491538, 1, 0.3235754068242486], 
     Hue[0.4990640442498221, 1, 0.3089882464233233], 
     Hue[0.5120471170280902, 1, 0.29101168411495204`], 
     Hue[0.5267134643102331, 1, 0.27070443403198485`], 
     Hue[0.5422653288205485, 1, 0.2491710831715483], 
     Hue[0.5579423080358296, 1, 0.2274644965657745], 
     Hue[0.5730797264426927, 1, 0.20650499415627166`], 
     Hue[0.5871492042094948, 1, 0.1870241787868534], 
     Hue[0.5997791025835187, 1, 0.16953662719205095`], 
     Hue[0.610755573052391, 1, 0.15433843731207403`], 
     Hue[0.6201340030575886, 1, 0.14135291884333887`], 
     Hue[0.6372377100661449, 1, 0.11767086298533777`], 
     Hue[0.6498193884887249, 1, 0.10025007747715022`], 
     Hue[0.6309071712190805, 1, 0.12643622446588856`], 
     Hue[0.6497293620994847, 1, 0.10037472940071342`], 
     Hue[0.6053173521973284, 1, 0.16186828157292998`], 
     Hue[0.5912710529523796, 1, 0.18131700360439762`], 
     Hue[0.5748267066162707, 1, 0.20408609853131757`], 
     Hue[0.5559009075730197, 1, 0.230291051052742], 
     Hue[0.5348134927357172, 1, 0.25948901005823777`], 
     Hue[0.5121211915218519, 1, 0.290909119431282], 
     Hue[0.4886161540216369, 1, 0.32345455597004125`], 
     Hue[0.46529534933541483`, 1, 0.35574490092019484`], 
     Hue[0.4432997588836452, 1, 0.38620033385341435`], 
     Hue[0.4238266901119189, 1, 0.41316304446041996`], 
     Hue[0.4080239533114093, 1, 0.43504375695343334`], 
     Hue[0.39687844716525267`, 1, 0.45047599623272705`], 
     Hue[0.39111401526715023`, 1, 0.45845751732240736`], 
     Hue[0.3911132217415005, 1, 0.4584586160502301], 
     Hue[0.39687744410879333`, 1, 0.45047738508013235`], 
     Hue[0.4080230856664831, 1, 0.43504495830794654`], 
     Hue[0.42382600763506495`, 1, 0.41316398942837174`], 
     Hue[0.4432992915435409, 1, 0.38620098093971267`], 
     Hue[0.46529510615084346`, 1, 0.3557452376372937], 
     Hue[0.4886161240406275, 1, 0.32345459748220806`], 
     Hue[0.5121213473795251, 1, 0.29090890362834987`], 
     Hue[0.5348137958119625, 1, 0.2594885904142058], 
     Hue[0.555901313513917, 1, 0.23029048898073032`], 
     Hue[0.5748271708858737, 1, 0.2040854556964826], 
     Hue[0.5912715356875938, 1, 0.18131633520179324`], 
     Hue[0.6053178951223055, 1, 0.16186752983065394`], 
     Hue[0.6309092329782288, 1, 0.1264333697224525], 
     Hue[0.6497294634089954, 1, 0.10037458912600633`], 
     Hue[0.6234595367036785, 1, 0.13674833379490678`], 
     Hue[0.6496235760977022, 1, 0.10052120232625851`], 
     Hue[0.5878756915996007, 1, 0.18601827316978367`], 
     Hue[0.5683287105046838, 1, 0.21308332391659163`], 
     Hue[0.5454394488736053, 1, 0.24477614771346962`], 
     Hue[0.5190911481081257, 1, 0.28125841031182586`], 
     Hue[0.48972836876794834`, 1, 0.32191456632130233`], 
     Hue[0.4581259977404597, 1, 0.36567169543628664`], 
     Hue[0.42538726241438385`, 1, 0.41100225204162244`], 
     Hue[0.39290127478800213`, 1, 0.4559828502935356], 
     Hue[0.36225822303677563`, 1, 0.4984116911798492], 
     Hue[0.33512718394406676`, 1, 0.5359777453082153], 
     Hue[0.31310844801677107`, 1, 0.5664652258229325], 
     Hue[0.2975781480451238, 1, 0.5879687180913671], 
     Hue[0.289545844634985, 1, 0.5990903689669439], 
     Hue[0.2895456075556001, 1, 0.5990906972307075], 
     Hue[0.2975778486260126, 1, 0.5879691326716749], 
     Hue[0.31310818948736147`, 1, 0.5664655837867303], 
     Hue[0.3351269812922879, 1, 0.5359780259029859], 
     Hue[0.3622580851943614, 1, 0.49841188203857645`], 
     Hue[0.39290120419997815`, 1, 0.45598294803079953`], 
     Hue[0.4253872556881455, 1, 0.4110022613548755], 
     Hue[0.45812604657442185`, 1, 0.3656716278200314], 
     Hue[0.48972846117720986`, 1, 0.3219144383700171], 
     Hue[0.5190912707195935, 1, 0.28125824054210136`], 
     Hue[0.545439588329388, 1, 0.24477595462084745`], 
     Hue[0.5683288547363774, 1, 0.21308312421116973`], 
     Hue[0.5878758526882779, 1, 0.18601805012392292`], 
     Hue[0.6234601390512056, 1, 0.1367474997752538], 
     Hue[0.6496236056366957, 1, 0.10052116142611357`], 
     Hue[0.6156690771285387, 1, 0.1475351239758696], 
     Hue[0.6495129338042546, 1, 0.10067439934795527`], 
     Hue[0.5696279238346579, 1, 0.21128441315201224`], 
     Hue[0.5443214064451821, 1, 0.24632420646051703`], 
     Hue[0.5146826064214731, 1, 0.28736254495488345`], 
     Hue[0.4805596531568227, 1, 0.33460971101363013`], 
     Hue[0.44252758864335184`, 1, 0.38726949264766675`], 
     Hue[0.4015897041401661, 1, 0.44395271734438546`], 
     Hue[0.3591752237937033, 1, 0.5026804593625647], 
     Hue[0.31708432871750997`, 1, 0.5609601602372939], 
     Hue[0.27737803188173027`, 1, 0.6159381097022196], 
     Hue[0.2422202632889342, 1, 0.6646180969845527], 
     Hue[0.21368588077620998`, 1, 0.7041272420021708], 
     Hue[0.19355917011629586`, 1, 0.7319949952235904], 
     Hue[0.183149562217308, 1, 0.7464082984683428], 
     Hue[0.18315013423702348`, 1, 0.7464075064410445], 
     Hue[0.19355989355891, 1, 0.7319939935338169], 
     Hue[0.21368650737851774`, 1, 0.7041263743989754], 
     Hue[0.24222075745013216`, 1, 0.6646174127613554], 
     Hue[0.27737837191762255`, 1, 0.6159376388832919], 
     Hue[0.3170845078871942, 1, 0.5609599121561927], 
     Hue[0.3591752496131902, 1, 0.5026804236125059], 
     Hue[0.401589595811773, 1, 0.44395286733754513`], 
     Hue[0.44252737372860873`, 1, 0.3872697902219264], 
     Hue[0.4805593630784366, 1, 0.3346101126606263], 
     Hue[0.5146822729985912, 1, 0.28736300661733527`], 
     Hue[0.544321058615945, 1, 0.24632468807023003`], 
     Hue[0.5696275304156976, 1, 0.2112849578859572], 
     Hue[0.6156675658591593, 1, 0.1475372165027026], 
     Hue[0.6495128594866585, 1, 0.10067450224924218`], 
     Hue[0.6087414029233015, 1, 0.1571272882600441], 
     Hue[0.6494145560301994, 1, 0.10081061472741623`], 
     Hue[0.5533988687474062, 1, 0.23375541250359141`], 
     Hue[0.5229667598564574, 1, 0.2758921786602898], 
     Hue[0.48732040515487984`, 1, 0.325248669785551], 
     Hue[0.44627657320844005`, 1, 0.3820785909421599], 
     Hue[0.4005262886368849, 1, 0.4454251388104672], 
     Hue[0.35127618165515445`, 1, 0.5136175946313246], 
     Hue[0.30024571035715847`, 1, 0.5842751702747037], 
     Hue[0.24960110964755156`, 1, 0.6543984635649286], 
     Hue[0.20182310509526985`, 1, 0.7205526237142418], 
     Hue[0.15951628430376785`, 1, 0.7791312986563215], 
     Hue[0.12517836167629715`, 1, 0.8266761146020501], 
     Hue[0.10095758092813223`, 1, 0.8602125802533555], 
     Hue[0.08843039496209137, 1, 0.8775579146678736], 
     Hue[0.08843184481123345, 1, 0.877555907184446], 
     Hue[0.10095941407703568`, 1, 0.8602100420471814], 
     Hue[0.12517994846479386`, 1, 0.8266739175102854], 
     Hue[0.15951753407086688`, 1, 0.7791295682095689], 
     Hue[0.2018239629610682, 1, 0.7205514359000594], 
     Hue[0.24960155901173514`, 1, 0.6543978413683668], 
     Hue[0.30024577066612074`, 1, 0.5842750867699867], 
     Hue[0.35127590215135607`, 1, 0.5136179816365839], 
     Hue[0.40052573946783443`, 1, 0.44542589919838316`], 
     Hue[0.4462758348559053, 1, 0.3820796132764389], 
     Hue[0.48731955851693165`, 1, 0.32524984205347934`], 
     Hue[0.5229658780640613, 1, 0.2758933996036075], 
     Hue[0.5533978740975912, 1, 0.2337567897110276], 
     Hue[0.608737603472198, 1, 0.15713254903849522`], 
     Hue[0.649414369301028, 1, 0.10081087327549972`], 
     Hue[0.6039789462997014, 1, 0.16372145896964424`], 
     Hue[0.6493469313116931, 1, 0.10090424895304037`], 
     Hue[0.5422411572690091, 1, 0.24920455147367965`], 
     Hue[0.5082837209174343, 1, 0.29622254026816786`], 
     Hue[0.4685050384669286, 1, 0.35130071596886814`], 
     Hue[0.42270023716665617`, 1, 0.4147227485384761], 
     Hue[0.37164007869641713`, 1, 0.48542142949726863`], 
     Hue[0.3166710458956746, 1, 0.5615323979906045], 
     Hue[0.25971232945803074`, 1, 0.6403983130581113], 
     Hue[0.20318203774869037`, 1, 0.7186710246556595], 
     Hue[0.14984970892994742`, 1, 0.7925157876354575], 
     Hue[0.10262327005221772`, 1, 0.8579062414661601], 
     Hue[0.06429160086506358, 1, 0.9109808603406813], 
     Hue[0.03725335079350833, 1, 0.9484184373628346], 
     Hue[0.02326889069083926, 1, 0.9677815359665303], 
     Hue[0.0232710123793185, 1, 0.9677785982440206], 
     Hue[0.0372560332466112, 1, 0.9484147231969998], 
     Hue[0.06429392241993914, 1, 0.9109776458800842], 
     Hue[0.10262509794762609`, 1, 0.8579037105340562], 
     Hue[0.14985096295229905`, 1, 0.7925140512968167], 
     Hue[0.2031826935392198, 1, 0.7186701166380033], 
     Hue[0.25971241565754605`, 1, 0.6403981937049362], 
     Hue[0.316670634974397, 1, 0.5615329669585273], 
     Hue[0.3716392734249071, 1, 0.4854225444885901], 
     Hue[0.42269915550608755`, 1, 0.4147242462223404], 
     Hue[0.4685037988839656, 1, 0.3513024323145092], 
     Hue[0.5082824304107318, 1, 0.2962243271236021], 
     Hue[0.5422397026998013, 1, 0.2492065654925829], 
     Hue[0.603973397789667, 1, 0.1637291415219996], 
     Hue[0.6493466586105661, 1, 0.10090462653921622`], 
     Hue[0.6022757448098648, 1, 0.1660797379555718], 
     Hue[0.6493226359923682, 1, 0.10093788862595174`], 
     Hue[0.5382570964254456, 1, 0.25472094341092155`], 
     Hue[0.5030409968157261, 1, 0.30348169671668696`], 
     Hue[0.4617867703202607, 1, 0.360602933402716], 
     Hue[0.41428194997560863`, 1, 0.4263788384953111], 
     Hue[0.3613257637555329, 1, 0.49970278864618534`], 
     Hue[0.30431462688847477`, 1, 0.5786412858467272], 
     Hue[0.24523902371574663`, 1, 0.6604382748551201], 
     Hue[0.1866070806268344, 1, 0.7416209652859216], 
     Hue[0.13129136223214333`, 1, 0.8182119599862631], 
     Hue[0.08230822812302241, 1, 0.8860347610604306], 
     Hue[0.0425504395154247, 1, 0.9410840068247966], 
     Hue[0.014506093362194328`, 1, 0.9799146399600387], 
     Hue[8.759517244882886*^-7, 1, 0.999998787143766], 
     Hue[8.759517240441994*^-7, 1, 0.9999987871437668], 
     Hue[0.014506093362193773`, 1, 0.9799146399600395], 
     Hue[0.0425504395154247, 1, 0.9410840068247965], 
     Hue[0.08230822812302196, 1, 0.8860347610604311], 
     Hue[0.13129136223214244`, 1, 0.8182119599862643], 
     Hue[0.18660708062683368`, 1, 0.7416209652859226], 
     Hue[0.24523902371574602`, 1, 0.660438274855121], 
     Hue[0.30431462688847427`, 1, 0.578641285846728], 
     Hue[0.3613257637555317, 1, 0.4997027886461869], 
     Hue[0.41428194997560897`, 1, 0.42637883849531066`], 
     Hue[0.46178677032026005`, 1, 0.3606029334027169], 
     Hue[0.5030409968157256, 1, 0.3034816967166877], 
     Hue[0.5382570964254455, 1, 0.25472094341092166`], 
     Hue[0.6022757448098639, 1, 0.16607973795557307`], 
     Hue[0.6493226359923682, 1, 0.10093788862595174`], 
     Hue[0.6039733977896679, 1, 0.1637291415219984], 
     Hue[0.6493466586105661, 1, 0.10090462653921622`], 
     Hue[0.5422397026998014, 1, 0.24920656549258283`], 
     Hue[0.5082824304107322, 1, 0.2962243271236017], 
     Hue[0.4685037988839661, 1, 0.35130243231450853`], 
     Hue[0.4226991555060873, 1, 0.4147242462223407], 
     Hue[0.37163927342490816`, 1, 0.4854225444885887], 
     Hue[0.3166706349743969, 1, 0.5615329669585274], 
     Hue[0.2597124156575464, 1, 0.6403981937049358], 
     Hue[0.2031826935392198, 1, 0.7186701166380033], 
     Hue[0.14985096295229983`, 1, 0.7925140512968156], 
     Hue[0.10262509794762598`, 1, 0.8579037105340563], 
     Hue[0.06429392241993892, 1, 0.9109776458800846], 
     Hue[0.03725603324661164, 1, 0.9484147231969993], 
     Hue[0.02327101237931828, 1, 0.9677785982440209], 
     Hue[0.023268890690838262`, 1, 0.9677815359665316], 
     Hue[0.037253350793507334`, 1, 0.948418437362836], 
     Hue[0.06429160086506325, 1, 0.9109808603406816], 
     Hue[0.10262327005221683`, 1, 0.8579062414661613], 
     Hue[0.14984970892994642`, 1, 0.7925157876354588], 
     Hue[0.20318203774868981`, 1, 0.7186710246556602], 
     Hue[0.25971232945802986`, 1, 0.6403983130581126], 
     Hue[0.316671045895674, 1, 0.5615323979906052], 
     Hue[0.37164007869641597`, 1, 0.4854214294972703], 
     Hue[0.42270023716665606`, 1, 0.41472274853847624`], 
     Hue[0.4685050384669278, 1, 0.35130071596886914`], 
     Hue[0.5082837209174339, 1, 0.2962225402681685], 
     Hue[0.542241157269009, 1, 0.24920455147367987`], 
     Hue[0.6039789462997005, 1, 0.16372145896964552`], 
     Hue[0.6493469313116931, 1, 0.10090424895304037`], 
     Hue[0.6087376034721987, 1, 0.15713254903849413`], 
     Hue[0.649414369301028, 1, 0.10081087327549972`], 
     Hue[0.5533978740975913, 1, 0.23375678971102748`], 
     Hue[0.5229658780640616, 1, 0.27589339960360704`], 
     Hue[0.48731955851693204`, 1, 0.32524984205347873`], 
     Hue[0.44627583485590494`, 1, 0.38207961327643936`], 
     Hue[0.4005257394678352, 1, 0.44542589919838205`], 
     Hue[0.3512759021513562, 1, 0.5136179816365838], 
     Hue[0.3002457706661209, 1, 0.5842750867699864], 
     Hue[0.24960155901173514`, 1, 0.6543978413683668], 
     Hue[0.20182396296106897`, 1, 0.7205514359000583], 
     Hue[0.15951753407086666`, 1, 0.7791295682095692], 
     Hue[0.12517994846479374`, 1, 0.8266739175102855], 
     Hue[0.10095941407703612`, 1, 0.8602100420471807], 
     Hue[0.08843184481123367, 1, 0.8775559071844458], 
     Hue[0.08843039496209071, 1, 0.8775579146678745], 
     Hue[0.10095758092813156`, 1, 0.8602125802533563], 
     Hue[0.1251783616762967, 1, 0.8266761146020507], 
     Hue[0.1595162843037672, 1, 0.7791312986563224], 
     Hue[0.20182310509526868`, 1, 0.7205526237142433], 
     Hue[0.249601109647551, 1, 0.6543984635649294], 
     Hue[0.30024571035715797`, 1, 0.5842751702747043], 
     Hue[0.35127618165515406`, 1, 0.5136175946313252], 
     Hue[0.4005262886368839, 1, 0.4454251388104685], 
     Hue[0.44627657320844016`, 1, 0.3820785909421599], 
     Hue[0.4873204051548792, 1, 0.3252486697855519], 
     Hue[0.522966759856457, 1, 0.2758921786602903], 
     Hue[0.553398868747406, 1, 0.23375541250359172`], 
     Hue[0.6087414029233007, 1, 0.15712728826004524`], 
     Hue[0.6494145560301994, 1, 0.10081061472741623`], 
     Hue[0.6156675658591598, 1, 0.14753721650270174`], 
     Hue[0.6495128594866585, 1, 0.10067450224924218`], 
     Hue[0.5696275304156977, 1, 0.21128495788595708`], 
     Hue[0.5443210586159454, 1, 0.24632468807022953`], 
     Hue[0.5146822729985917, 1, 0.28736300661733466`], 
     Hue[0.4805593630784365, 1, 0.33461011266062646`], 
     Hue[0.44252737372860956`, 1, 0.3872697902219253], 
     Hue[0.401589595811773, 1, 0.443952867337545], 
     Hue[0.3591752496131904, 1, 0.5026804236125056], 
     Hue[0.31708450788719444`, 1, 0.5609599121561923], 
     Hue[0.2773783719176231, 1, 0.6159376388832911], 
     Hue[0.24222075745013222`, 1, 0.6646174127613553], 
     Hue[0.2136865073785173, 1, 0.7041263743989761], 
     Hue[0.19355989355891012`, 1, 0.7319939935338168], 
     Hue[0.18315013423702398`, 1, 0.7464075064410437], 
     Hue[0.18314956221730744`, 1, 0.7464082984683436], 
     Hue[0.19355917011629492`, 1, 0.7319949952235917], 
     Hue[0.2136858807762101, 1, 0.7041272420021706], 
     Hue[0.2422202632889342, 1, 0.6646180969845527], 
     Hue[0.2773780318817297, 1, 0.6159381097022204], 
     Hue[0.31708432871750963`, 1, 0.5609601602372944], 
     Hue[0.3591752237937029, 1, 0.5026804593625652], 
     Hue[0.4015897041401657, 1, 0.443952717344386], 
     Hue[0.44252758864335107`, 1, 0.38726949264766775`], 
     Hue[0.4805596531568227, 1, 0.33460971101363013`], 
     Hue[0.5146826064214726, 1, 0.28736254495488417`], 
     Hue[0.5443214064451819, 1, 0.2463242064605174], 
     Hue[0.5696279238346578, 1, 0.21128441315201235`], 
     Hue[0.615669077128538, 1, 0.14753512397587054`], 
     Hue[0.6495129338042546, 1, 0.10067439934795527`], 
     Hue[0.6234601390512061, 1, 0.13674749977525308`], 
     Hue[0.6496236056366957, 1, 0.10052116142611357`], 
     Hue[0.587875852688278, 1, 0.1860180501239228], 
     Hue[0.5683288547363776, 1, 0.2130831242111694], 
     Hue[0.5454395883293884, 1, 0.24477595462084686`], 
     Hue[0.5190912707195934, 1, 0.2812582405421015], 
     Hue[0.4897284611772105, 1, 0.3219144383700163], 
     Hue[0.458126046574422, 1, 0.36567162782003104`], 
     Hue[0.4253872556881456, 1, 0.4110022613548753], 
     Hue[0.39290120419997865`, 1, 0.45598294803079886`], 
     Hue[0.362258085194362, 1, 0.4984118820385758], 
     Hue[0.3351269812922884, 1, 0.5359780259029854], 
     Hue[0.3131081894873613, 1, 0.5664655837867305], 
     Hue[0.297577848626013, 1, 0.5879691326716743], 
     Hue[0.2895456075556001, 1, 0.5990906972307075], 
     Hue[0.28954584463498473`, 1, 0.5990903689669442], 
     Hue[0.2975781480451234, 1, 0.5879687180913676], 
     Hue[0.3131084480167709, 1, 0.5664652258229326], 
     Hue[0.33512718394406654`, 1, 0.5359777453082156], 
     Hue[0.3622582230367751, 1, 0.49841169117984996`], 
     Hue[0.3929012747880017, 1, 0.45598285029353613`], 
     Hue[0.4253872624143836, 1, 0.41100225204162266`], 
     Hue[0.4581259977404595, 1, 0.36567169543628697`], 
     Hue[0.4897283687679477, 1, 0.3219145663213032], 
     Hue[0.5190911481081258, 1, 0.28125841031182575`], 
     Hue[0.545439448873605, 1, 0.24477614771347014`], 
     Hue[0.5683287105046836, 1, 0.21308332391659193`], 
     Hue[0.5878756915996006, 1, 0.18601827316978375`], 
     Hue[0.6234595367036779, 1, 0.13674833379490747`], 
     Hue[0.6496235760977022, 1, 0.10052120232625851`], 
     Hue[0.6309092329782291, 1, 0.126433369722452], 
     Hue[0.6497294634089954, 1, 0.10037458912600633`], 
     Hue[0.6053178951223055, 1, 0.16186752983065394`], 
     Hue[0.5912715356875939, 1, 0.181316335201793], 
     Hue[0.574827170885874, 1, 0.20408545569648226`], 
     Hue[0.5559013135139169, 1, 0.2302904889807304], 
     Hue[0.5348137958119629, 1, 0.2594885904142053], 
     Hue[0.5121213473795252, 1, 0.2909089036283497], 
     Hue[0.4886161240406277, 1, 0.32345459748220784`], 
     Hue[0.4652951061508435, 1, 0.3557452376372936], 
     Hue[0.4432992915435413, 1, 0.3862009809397121], 
     Hue[0.4238260076350649, 1, 0.41316398942837174`], 
     Hue[0.40802308566648304`, 1, 0.43504495830794654`], 
     Hue[0.3968774441087934, 1, 0.45047738508013224`], 
     Hue[0.3911132217415007, 1, 0.45845861605022986`], 
     Hue[0.39111401526715006`, 1, 0.4584575173224076], 
     Hue[0.3968784471652522, 1, 0.4504759962327277], 
     Hue[0.40802395331140906`, 1, 0.43504375695343356`], 
     Hue[0.4238266901119186, 1, 0.4131630444604204], 
     Hue[0.4432997588836446, 1, 0.38620033385341523`], 
     Hue[0.4652953493354146, 1, 0.3557449009201953], 
     Hue[0.4886161540216366, 1, 0.3234545559700417], 
     Hue[0.5121211915218518, 1, 0.2909091194312822], 
     Hue[0.5348134927357168, 1, 0.2594890100582383], 
     Hue[0.5559009075730197, 1, 0.230291051052742], 
     Hue[0.5748267066162703, 1, 0.20408609853131798`], 
     Hue[0.5912710529523794, 1, 0.1813170036043979], 
     Hue[0.6053173521973283, 1, 0.16186828157293004`], 
     Hue[0.6309071712190801, 1, 0.1264362244658891], 
     Hue[0.6497293620994847, 1, 0.10037472940071342`], 
     Hue[0.6372377100661452, 1, 0.11767086298533747`], 
     Hue[0.6498193884887249, 1, 0.10025007747715022`], 
     Hue[0.6201340030575886, 1, 0.14135291884333895`], 
     Hue[0.610755573052391, 1, 0.154338437312074], 
     Hue[0.5997791025835189, 1, 0.16953662719205084`], 
     Hue[0.5871492042094947, 1, 0.18702417878685362`], 
     Hue[0.5730797264426928, 1, 0.20650499415627152`], 
     Hue[0.5579423080358294, 1, 0.22746449656577464`], 
     Hue[0.5422653288205485, 1, 0.2491710831715484], 
     Hue[0.526713464310233, 1, 0.2707044340319851], 
     Hue[0.5120471170280901, 1, 0.29101168411495215`], 
     Hue[0.49906404424982187`, 1, 0.30898824642332356`], 
     Hue[0.4885288728491535, 1, 0.323575406824249], 
     Hue[0.48109892791438935`, 1, 0.33386302288776865`], 
     Hue[0.47725658556548634`, 1, 0.33918318921701895`], 
     Hue[0.47725762494663326`, 1, 0.3391817500738924], 
     Hue[0.4811002419009807, 1, 0.333861203521719], 
     Hue[0.4885300098526193, 1, 0.323573832511758], 
     Hue[0.49906493923094797`, 1, 0.30898700721868755`], 
     Hue[0.5120477307271325, 1, 0.2910108343778166], 
     Hue[0.5267137848105791, 1, 0.2707039902622752], 
     Hue[0.5422653702110632, 1, 0.24917102586160478`], 
     Hue[0.5579421059099916, 1, 0.22746477643231938`], 
     Hue[0.5730793313285311, 1, 0.20650554123741857`], 
     Hue[0.587148673841918, 1, 0.18702491314195963`], 
     Hue[0.599778495006357, 1, 0.1695374684527364], 
     Hue[0.6107549408429755, 1, 0.15433931267895704`], 
     Hue[0.6201332908743415, 1, 0.1413539049432195], 
     Hue[0.6372349970239707, 1, 0.11767461950527143`], 
     Hue[0.6498192551554071, 1, 0.10025026209251335`], 
     Hue[0.6426169513066163, 1, 0.1102226828062235], 
     Hue[0.6498958580678137, 1, 0.10014419652148876`], 
     Hue[0.6327224787398396, 1, 0.12392272174483751`], 
     Hue[0.6273035877223595, 1, 0.13142580161519454`], 
     Hue[0.6209633643612932, 1, 0.1402045724228249], 
     Hue[0.6136699866390606, 1, 0.1503030954228393], 
     Hue[0.6055472079675879, 1, 0.16155001973718608`], 
     Hue[0.5968097184249482, 1, 0.17364808218084088`], 
     Hue[0.5877624702504635, 1, 0.18617504119166603`], 
     Hue[0.5787888800272749, 1, 0.19860001226992707`], 
     Hue[0.5703273925724269, 1, 0.2103159179766397], 
     Hue[0.562837884895745, 1, 0.22068600552896844`], 
     Hue[0.5567610169112918, 1, 0.22910013043051908`], 
     Hue[0.5524755676281785, 1, 0.2350338294379067], 
     Hue[0.5502596758638851, 1, 0.23810198726538992`], 
     Hue[0.5502615101311635, 1, 0.23809944751069667`], 
     Hue[0.5524778870728062, 1, 0.2350306178991915], 
     Hue[0.5567630251190712, 1, 0.2290973498351322], 
     Hue[0.5628394673492456, 1, 0.22068381443950608`], 
     Hue[0.5703284797983731, 1, 0.21031441258686806`], 
     Hue[0.5787894507625196, 1, 0.19859922202112662`], 
     Hue[0.5877625488826427, 1, 0.1861749323163409], 
     Hue[0.5968093671146062, 1, 0.17364856861054534`], 
     Hue[0.6055465152211046, 1, 0.1615509789246244], 
     Hue[0.6136690539638642, 1, 0.15030438681926506`], 
     Hue[0.6209622939460813, 1, 0.1402060545361952], 
     Hue[0.6273024721629233, 1, 0.1314273462359524], 
     Hue[0.6327212191925413, 1, 0.12392446573340436`], 
     Hue[0.6426121298967593, 1, 0.11022935860448715`], 
     Hue[0.6498956210456897, 1, 0.10014452470596819`], 
     Hue[0.6432670322601114, 1, 0.10932257071676882`], 
     Hue[0.627788739277394, 1, 0.1307540533082238], 
     Hue[0.6215312007966796, 1, 0.13941833735844364`], 
     Hue[0.6143233938953457, 1, 0.14939837768336742`], 
     Hue[0.6062751719935869, 1, 0.16054206954734118`], 
     Hue[0.5975930766290172, 1, 0.17256343235982238`], 
     Hue[0.5885739589734652, 1, 0.18505144142135593`], 
     Hue[0.579594182301374, 1, 0.19748497835194373`], 
     Hue[0.5710872328122532, 1, 0.20926383149072644`], 
     Hue[0.5573078855136699, 1, 0.2283429277503032], 
     Hue[0.5528621143129753, 1, 0.23449861095126506`], 
     Hue[0.5504603601125956, 1, 0.23782411676717535`], 
     Hue[0.5502605344346037, 1, 0.23810079847516413`], 
     Hue[0.5522769448771349, 1, 0.23530884555473644`], 
     Hue[0.556376644213599, 1, 0.22963233878117068`], 
     Hue[0.5622928254940655, 1, 0.22144070316206327`], 
     Hue[0.569655609099376, 1, 0.21124607970855636`], 
     Hue[0.5869575084668386, 1, 0.18728960366130043`], 
     Hue[0.5959981070525373, 1, 0.17477185177340998`], 
     Hue[0.6047633384625756, 1, 0.16263537751335694`], 
     Hue[0.6129412172822569, 1, 0.1513121606861058], 
     Hue[0.6203089596274787, 1, 0.1411106712850296], 
     Hue[0.6267346593848437, 1, 0.13221354854406253`], 
     Hue[0.6322361435905947, 1, 0.12459610887456124`], 
     Hue[0.6417279253205034, 1, 0.11145364186391843`], 
     Hue[0.6492431084282864, 1, 0.1010480037146804], 
     Hue[0.6412530637161606, 1, 0.11211114254685453`], 
     Hue[0.6137476741062011, 1, 0.15019552816064463`], 
     Hue[0.5911781275556787, 1, 0.18144566953829103`], 
     Hue[0.577567654884599, 1, 0.20029093939055523`], 
     Hue[0.5627707137144807, 1, 0.22077901177994982`], 
     Hue[0.5472657246634997, 1, 0.2422474581582313], 
     Hue[0.5316739170993457, 1, 0.26383611478552127`], 
     Hue[0.5167251850346483, 1, 0.28453435918279474`], 
     Hue[0.49188966916713917`, 1, 0.31892199653780734`], 
     Hue[0.4784830257287196, 1, 0.33748504129869594`], 
     Hue[0.4772569851352818, 1, 0.33918263596653286`], 
     Hue[0.4798736327535861, 1, 0.3355595854181116], 
     Hue[0.4861594577380448, 1, 0.3268561354396303], 
     Hue[0.4957042919273025, 1, 0.3136402111775813], 
     Hue[0.5079065757593586, 1, 0.2967447412562727], 
     Hue[0.5373050892257645, 1, 0.25603910722586465`], 
     Hue[0.5682510443450479, 1, 0.21319086167608753`], 
     Hue[0.582660828644106, 1, 0.19323885264662252`], 
     Hue[0.5957496191718221, 1, 0.17511591191593862`], 
     Hue[0.607253262945072, 1, 0.1591877897683619], 
     Hue[0.617141238981305, 1, 0.1454967460258854], 
     Hue[0.6317774561574506, 1, 0.12523121455122227`], 
     Hue[0.6458023147122057, 1, 0.10581217962925371`], 
     Hue[0.64055187699897, 1, 0.11308201646296469`], 
     Hue[0.5984661270407605, 1, 0.17135459332817773`], 
     Hue[0.5655942394702503, 1, 0.21686951457965342`], 
     Hue[0.5237424830742484, 1, 0.274818100358733], 
     Hue[0.5006531714587011, 1, 0.3067879164417985], 
     Hue[0.47723759735959215`, 1, 0.33920948057902633`], 
     Hue[0.4545630358137646, 1, 0.3706050273347875], 
     Hue[0.4161157015508852, 1, 0.4238397978526206], 
     Hue[0.3940656300924371, 1, 0.4543706660258563], 
     Hue[0.3939259619828552, 1, 0.4545640526391236], 
     Hue[0.40231605449512875`, 1, 0.44294700146828325`], 
     Hue[0.415734142216981, 1, 0.42436811077648795`], 
     Hue[0.4333278292564813, 1, 0.4000076210294875], 
     Hue[0.4766737410268823, 1, 0.33999020473200914`], 
     Hue[0.5231924110198736, 1, 0.2755797385878674], 
     Hue[0.5651338019504073, 1, 0.21750704345328228`], 
     Hue[0.5828486430136464, 1, 0.19297880198110512`], 
     Hue[0.5981227827376427, 1, 0.17182999313249475`], 
     Hue[0.6177971273208911, 1, 0.1445885929403046], 
     Hue[0.6400860008926634, 1, 0.11372707568708142`], 
     Hue[0.6422826805592395, 1, 0.11068551922566836`], 
     Hue[0.5823892479014552, 1, 0.1936148875210621], 
     Hue[0.538042948910495, 1, 0.25501745535469933`], 
     Hue[0.48085593368767154`, 1, 0.33419947643245485`], 
     Hue[0.41626594024551333`, 1, 0.42363177504467386`], 
     Hue[0.3842971118118805, 1, 0.46789630672201166`], 
     Hue[0.3289443018365473, 1, 0.5445386589955499], 
     Hue[0.2953226222573054, 1, 0.5910917537975772], 
     Hue[0.2918011380948874, 1, 0.5959676549455406], 
     Hue[0.3192910676832635, 1, 0.5579046755154814], 
     Hue[0.3427452344342434, 1, 0.52542967539874], 
     Hue[0.40202252169466424`, 1, 0.44335343149969575`], 
     Hue[0.4669984782930092, 1, 0.35338672236352564`], 
     Hue[0.5264877691436817, 1, 0.27101693503182545`], 
     Hue[0.5738152966617034, 1, 0.2054865123145645], 
     Hue[0.5978608444763083, 1, 0.17219267687895778`], 
     Hue[0.6308010827908599, 1, 0.12658311613573245`], 
     Hue[0.6471639496479785, 1, 0.10392683894895278`], 
     Hue[0.5678708626721414, 1, 0.21371726706934283`], 
     Hue[0.5123130950578718, 1, 0.29064340684294676`], 
     Hue[0.4396845460944257, 1, 0.391206013100026], 
     Hue[0.35625186392221736`, 1, 0.5067281884153914], 
     Hue[0.24023829515486617`, 1, 0.6673623605548007], 
     Hue[0.19283611511503923`, 1, 0.7329961483022533], 
     Hue[0.18387320634860455`, 1, 0.7454063296711629], 
     Hue[0.21566846048195937`, 1, 0.7013821316403639], 
     Hue[0.320007850397767, 1, 0.5569122071415533], 
     Hue[0.40443262631213805`, 1, 0.4400163635678088], 
     Hue[0.4829288695919822, 1, 0.33132925748802466`], 
     Hue[0.546078114715954, 1, 0.24389184116252524`], 
     Hue[0.618016711599604, 1, 0.144284553169779], 
     Hue[0.6134393712358532, 1, 0.15062240905804938`], 
     Hue[0.5597906890952162, 1, 0.22490519971431608`], 
     Hue[0.5264808821814904, 1, 0.2710264708256288], 
     Hue[0.49143641314473197`, 1, 0.3195495817996019], 
     Hue[0.45101559593564244`, 1, 0.3755168671660335], 
     Hue[0.40580850751011666`, 1, 0.4381112972936846], 
     Hue[0.3569622667530064, 1, 0.5057445537266065], 
     Hue[0.30613714542441306`, 1, 0.5761177986431204], 
     Hue[0.2554478293905232, 1, 0.6463030054592757], 
     Hue[0.2073387507107557, 1, 0.7129155759389537], 
     Hue[0.12914229794443288`, 1, 0.8211875874615544], 
     Hue[0.10375357462868617`, 1, 0.8563412043602807], 
     Hue[0.08987650496460475, 1, 0.8755556085105474], 
     Hue[0.08843171541781158, 1, 0.8775560863445686], 
     Hue[0.09951326985387354, 1, 0.8622123955869443], 
     Hue[0.12238397672032508`, 1, 0.8305452630026268], 
     Hue[0.1555536278639838, 1, 0.7846180537267917], 
     Hue[0.19694005720194285`, 1, 0.727313766951156], 
     Hue[0.29439908564497536`, 1, 0.5923704967992649], 
     Hue[0.34538449739612337`, 1, 0.5217753112976754], 
     Hue[0.39483967846710455`, 1, 0.45329890673785533`], 
     Hue[0.4409936328930446, 1, 0.3893934313788614], 
     Hue[0.48258054548984053`, 1, 0.3318115523986824], 
     Hue[0.5188498732647924, 1, 0.28159248317182606`], 
     Hue[0.5498837618975734, 1, 0.23862248352643697`], 
     Hue[0.6023460341736327, 1, 0.16598241422112395`], 
     Hue[0.6447160778201386, 1, 0.10731619994134659`], 
     Hue[0.617722431996425, 1, 0.14469201723571928`], 
     Hue[0.51856947216833, 1, 0.28198073084385067`], 
     Hue[0.48055379551473054`, 1, 0.33461782159498854`], 
     Hue[0.4365740211159339, 1, 0.3955128938394761], 
     Hue[0.3871053925865305, 1, 0.4640079179571117], 
     Hue[0.3333200485926564, 1, 0.5384799327178603], 
     Hue[0.2769637440356448, 1, 0.6165117390275688], 
     Hue[0.22030348310954628`, 1, 0.6949644080021667], 
     Hue[0.16600244442768575`, 1, 0.7701504615616659], 
     Hue[0.07590092200313603, 1, 0.8949064156879655], 
     Hue[0.02750426862112476, 1, 0.9619171665245965], 
     Hue[0.023270413385846567`, 1, 0.9677794276195971], 
     Hue[0.03302049699040388, 1, 0.9542793118594408], 
     Hue[0.05610511392484363, 1, 0.9223159961040627], 
     Hue[0.09101591614372317, 1, 0.8739779622625371], 
     Hue[0.13554779899441216`, 1, 0.8123184321615832], 
     Hue[0.24259113109163727`, 1, 0.6641045877192715], 
     Hue[0.3549903820825449, 1, 0.5084748555780148], 
     Hue[0.40723391967740996`, 1, 0.4361376496774324], 
     Hue[0.45463005955166735`, 1, 0.3705122252361529], 
     Hue[0.4962336877780928, 1, 0.3129072015380254], 
     Hue[0.5319539978428438, 1, 0.2634483106791393], 
     Hue[0.5852727256986741, 1, 0.18962237980183602`], 
     Hue[0.6356016827117187, 1, 0.11993613162992803`], 
     Hue[0.625798101903588, 1, 0.13351032044118585`], 
     Hue[0.5206490804550483, 1, 0.27910127321608696`], 
     Hue[0.438034392733727, 1, 0.39349084083022423`], 
     Hue[0.38780391391091007`, 1, 0.4630407345848938], 
     Hue[0.33282027668953884`, 1, 0.5391719245837155], 
     Hue[0.2747769279262213, 1, 0.6195396382560012], 
     Hue[0.21592316975918813`, 1, 0.7010294572565088], 
     Hue[0.1589493449301979, 1, 0.7799162916351106], 
     Hue[0.062429435740938066`, 1, 0.9135592428202397], 
     Hue[0.007253368925545622, 1, 0.9899568737953984], 
     Hue[0.0072533689255454, 1, 0.9899568737953987], 
     Hue[0.028528340951307296`, 1, 0.9604992202212669], 
     Hue[0.062429435740937955`, 1, 0.9135592428202398], 
     Hue[0.1067999136638016, 1, 0.8521231964655055], 
     Hue[0.21592316975918785`, 1, 0.7010294572565091], 
     Hue[0.3328202766895381, 1, 0.5391719245837165], 
     Hue[0.438034392733727, 1, 0.3934908408302241], 
     Hue[0.4824138940233156, 1, 0.33204230058310147`], 
     Hue[0.5206490804550483, 1, 0.279101273216087], 
     Hue[0.5702672651642872, 1, 0.21039917131098698`], 
     Hue[0.6257981019035878, 1, 0.13351032044118621`], 
     Hue[0.6356016827117188, 1, 0.1199361316299279], 
     Hue[0.5319539978428438, 1, 0.2634483106791394], 
     Hue[0.4546300595516674, 1, 0.3705122252361528], 
     Hue[0.3549903820825455, 1, 0.508474855578014], 
     Hue[0.2994193607344692, 1, 0.5854193466753503], 
     Hue[0.24259113109163738`, 1, 0.6641045877192714], 
     Hue[0.18703012692867332`, 1, 0.7410352088679908], 
     Hue[0.09101591614372273, 1, 0.8739779622625377], 
     Hue[0.0330204969904041, 1, 0.9542793118594404], 
     Hue[0.027504268621123762`, 1, 0.9619171665245978], 
     Hue[0.07590092200313547, 1, 0.8949064156879663], 
     Hue[0.11692659598318034`, 1, 0.838101636330981], 
     Hue[0.22030348310954573`, 1, 0.6949644080021675], 
     Hue[0.333320048592656, 1, 0.5384799327178609], 
     Hue[0.4365740211159337, 1, 0.3955128938394764], 
     Hue[0.5185694721683298, 1, 0.281980730843851], 
     Hue[0.5609429858823103, 1, 0.22330971185526277`], 
     Hue[0.6177224319964245, 1, 0.1446920172357199], 
     Hue[0.6447160778201385, 1, 0.1073161999413467], 
     Hue[0.5498837618975734, 1, 0.23862248352643695`], 
     Hue[0.48258054548984075`, 1, 0.3318115523986821], 
     Hue[0.39483967846710505`, 1, 0.45329890673785456`], 
     Hue[0.29439908564497536`, 1, 0.5923704967992649], 
     Hue[0.2440859498593781, 1, 0.6620348386562457], 
     Hue[0.15555362786398336`, 1, 0.7846180537267923], 
     Hue[0.0995132698538741, 1, 0.8622123955869436], 
     Hue[0.08987650496460409, 1, 0.8755556085105483], 
     Hue[0.12914229794443277`, 1, 0.8211875874615546], 
     Hue[0.2554478293905228, 1, 0.6463030054592761], 
     Hue[0.35696226675300613`, 1, 0.5057445537266069], 
     Hue[0.4510155959356426, 1, 0.3755168671660334], 
     Hue[0.5264808821814901, 1, 0.27102647082562903`], 
     Hue[0.6134393712358527, 1, 0.15062240905805013`], 
     Hue[0.6180167115996045, 1, 0.14428455316977848`], 
     Hue[0.5728233150649802, 1, 0.20686002529464279`], 
     Hue[0.5460781147159542, 1, 0.24389184116252494`], 
     Hue[0.5167402753982261, 1, 0.2845134648332255], 
     Hue[0.482928869591982, 1, 0.331329257488025], 
     Hue[0.4451684747100398, 1, 0.38361288117071424`], 
     Hue[0.40443262631213794`, 1, 0.44001636356780904`], 
     Hue[0.3621209519908066, 1, 0.4986017587819601], 
     Hue[0.32000785039776697`, 1, 0.5569122071415534], 
     Hue[0.2801361764938014, 1, 0.6121191402393519], 
     Hue[0.24466271032969483`, 1, 0.6612362472358071], 
     Hue[0.2156684604819588, 1, 0.7013821316403648], 
     Hue[0.1949578794311445, 1, 0.7300583207876461], 
     Hue[0.183873206348605, 1, 0.7454063296711624], 
     Hue[0.18314962691401843`, 1, 0.7464082088882822], 
     Hue[0.1928361151150383, 1, 0.7329961483022547], 
     Hue[0.21228788392593306`, 1, 0.706062929948708], 
     Hue[0.24023829515486633`, 1, 0.6673623605548005], 
     Hue[0.2749360615481359, 1, 0.6193192993948887], 
     Hue[0.35625186392221725`, 1, 0.5067281884153916], 
     Hue[0.39864398660653844`, 1, 0.44803140316017753`], 
     Hue[0.4396845460944252, 1, 0.3912060131000267], 
     Hue[0.47791854372020687`, 1, 0.3382666317720213], 
     Hue[0.5123130950578715, 1, 0.2906434068429472], 
     Hue[0.542263402450256, 1, 0.24917375045349185`], 
     Hue[0.5678708626721414, 1, 0.2137172670693428], 
     Hue[0.612473166954633, 1, 0.15196023037050804`], 
     Hue[0.6471639496479787, 1, 0.1039268389489526], 
     Hue[0.6308010827908601, 1, 0.12658311613573214`], 
     Hue[0.5738152966617035, 1, 0.20548651231456438`], 
     Hue[0.5518646402844236, 1, 0.23587972883695194`], 
     Hue[0.5264877691436816, 1, 0.27101693503182567`], 
     Hue[0.4979716801206474, 1, 0.3105007506021805], 
     Hue[0.46699847829300933`, 1, 0.35338672236352553`], 
     Hue[0.4345791545435441, 1, 0.39827501678586197`], 
     Hue[0.4020225216946645, 1, 0.4433534314996953], 
     Hue[0.3708622433144219, 1, 0.48649843233387735`], 
     Hue[0.3192910676832634, 1, 0.5579046755154815], 
     Hue[0.30193883613655426`, 1, 0.5819308422724634], 
     Hue[0.29180113809488745`, 1, 0.5959676549455405], 
     Hue[0.28954586233322177`, 1, 0.599090344461693], 
     Hue[0.2953226222573051, 1, 0.5910917537975776], 
     Hue[0.308747457626783, 1, 0.5725035202090697], 
     Hue[0.32894430183654727`, 1, 0.54453865899555], 
     Hue[0.35463996524360697`, 1, 0.5089600481242366], 
     Hue[0.41626594024551333`, 1, 0.423631775044674], 
     Hue[0.4808559336876712, 1, 0.3341994764324553], 
     Hue[0.5108479266774192, 1, 0.2926721015235735], 
     Hue[0.5380429489104949, 1, 0.25501745535469944`], 
     Hue[0.5619036579491844, 1, 0.2219795505318985], 
     Hue[0.5823892479014552, 1, 0.19361488752106204`], 
     Hue[0.6134745067166796, 1, 0.15057375993075145`], 
     Hue[0.6422826805592395, 1, 0.11068551922566833`], 
     Hue[0.6400860008926635, 1, 0.1137270756870813], 
     Hue[0.5981227827376427, 1, 0.1718299931324947], 
     Hue[0.5651338019504072, 1, 0.21750704345328234`], 
     Hue[0.5451013481926241, 1, 0.2452442871179051], 
     Hue[0.5231924110198738, 1, 0.27557973858786716`], 
     Hue[0.500084212233562, 1, 0.3075757061381449], 
     Hue[0.4766737410268823, 1, 0.3399902047320092], 
     Hue[0.4540316873519137, 1, 0.37134074058965794`], 
     Hue[0.41573414221698096`, 1, 0.42436811077648795`], 
     Hue[0.3939259619828554, 1, 0.45456405263912336`], 
     Hue[0.39111372425368446`, 1, 0.45845792026412924`], 
     Hue[0.3940656300924367, 1, 0.45437066602585685`], 
     Hue[0.40258539264872584`, 1, 0.4425740717171489], 
     Hue[0.41611570155088484`, 1, 0.42383979785262094`], 
     Hue[0.43379801622503644`, 1, 0.39935659291918035`], 
     Hue[0.47723759735959204`, 1, 0.3392094805790265], 
     Hue[0.5237424830742481, 1, 0.27481810035873333`], 
     Hue[0.5655942394702503, 1, 0.21686951457965342`], 
     Hue[0.5832495875495567, 1, 0.1924236480083062], 
     Hue[0.5984661270407605, 1, 0.17135459332817785`], 
     Hue[0.61842849431418, 1, 0.14371439248805845`], 
     Hue[0.6405518769989699, 1, 0.11308201646296481`], 
     Hue[0.6458023147122057, 1, 0.1058121796292537], 
     Hue[0.6171412389813049, 1, 0.14549674602588547`], 
     Hue[0.595749619171822, 1, 0.17511591191593873`], 
     Hue[0.5682510443450479, 1, 0.2131908616760876], 
     Hue[0.552941860021709, 1, 0.23438819381609532`], 
     Hue[0.5373050892257643, 1, 0.25603910722586487`], 
     Hue[0.522035897273629, 1, 0.2771810653134368], 
     Hue[0.49570429192730214`, 1, 0.3136402111775816], 
     Hue[0.47987363275358597`, 1, 0.3355595854181118], 
     Hue[0.47848302572871904`, 1, 0.3374850412986968], 
     Hue[0.4834695890086842, 1, 0.33058056906489885`], 
     Hue[0.49188966916713883`, 1, 0.3189219965378078], 
     Hue[0.5032053724394923, 1, 0.30325409969916467`], 
     Hue[0.5316739170993455, 1, 0.26383611478552166`], 
     Hue[0.5627707137144804, 1, 0.22077901177995024`], 
     Hue[0.5911781275556787, 1, 0.18144566953829117`], 
     Hue[0.613747674106201, 1, 0.15019552816064477`], 
     Hue[0.6255927744265147, 1, 0.13379462002482587`], 
     Hue[0.6412530637161605, 1, 0.11211114254685471`], 
     Hue[0.6492431084282864, 1, 0.10104800371468042`], 
     Hue[0.6322361435905947, 1, 0.12459610887456123`], 
     Hue[0.6203089596274788, 1, 0.14111067128502947`], 
     Hue[0.6047633384625757, 1, 0.16263537751335672`], 
     Hue[0.5869575084668387, 1, 0.18728960366130032`], 
     Hue[0.5780298854580632, 1, 0.19965092782729704`], 
     Hue[0.5622928254940656, 1, 0.22144070316206316`], 
     Hue[0.552276944877135, 1, 0.2353088455547362], 
     Hue[0.5504603601125957, 1, 0.2378241167671753], 
     Hue[0.5573078855136702, 1, 0.22834292775030293`], 
     Hue[0.5635110193069252, 1, 0.21975397326733448`], 
     Hue[0.579594182301374, 1, 0.19748497835194362`], 
     Hue[0.5975930766290172, 1, 0.17256343235982233`], 
     Hue[0.6143233938953458, 1, 0.14939837768336736`], 
     Hue[0.627788739277394, 1, 0.1307540533082238], 
     Hue[0.6432670322601114, 1, 0.10932257071676893`], 
     Hue[0.563511019306925, 1, 0.21975397326733456`], 
     Hue[0.5780298854580632, 1, 0.1996509278272972], 
     Hue[0.6255927744265147, 1, 0.13379462002482578`], 
     Hue[0.5032053724394926, 1, 0.30325409969916417`], 
     Hue[0.48346958900868453`, 1, 0.33058056906489836`], 
     Hue[0.5220358972736292, 1, 0.27718106531343656`], 
     Hue[0.5529418600217092, 1, 0.23438819381609505`], 
     Hue[0.6184284943141801, 1, 0.14371439248805834`], 
     Hue[0.5832495875495568, 1, 0.19242364800830597`], 
     Hue[0.4337980162250368, 1, 0.3993565929191799], 
     Hue[0.40258539264872606`, 1, 0.4425740717171486], 
     Hue[0.3911137242536845, 1, 0.4584579202641291], 
     Hue[0.4540316873519137, 1, 0.37134074058965805`], 
     Hue[0.500084212233562, 1, 0.307575706138145], 
     Hue[0.545101348192624, 1, 0.2452442871179052], 
     Hue[0.6134745067166797, 1, 0.15057375993075123`], 
     Hue[0.5619036579491845, 1, 0.22197955053189833`], 
     Hue[0.5108479266774191, 1, 0.2926721015235736], 
     Hue[0.35463996524360725`, 1, 0.5089600481242361], 
     Hue[0.3087474576267834, 1, 0.5725035202090691], 
     Hue[0.28954586233322194`, 1, 0.5990903444616927], 
     Hue[0.30193883613655403`, 1, 0.5819308422724636], 
     Hue[0.37086224331442164`, 1, 0.4864984323338778], 
     Hue[0.43457915454354423`, 1, 0.39827501678586186`], 
     Hue[0.4979716801206472, 1, 0.3105007506021809], 
     Hue[0.5518646402844234, 1, 0.2358797288369523], 
     Hue[0.6124731669546335, 1, 0.1519602303705075], 
     Hue[0.5422634024502561, 1, 0.2491737504534917], 
     Hue[0.4779185437202067, 1, 0.33826663177202154`], 
     Hue[0.39864398660653866`, 1, 0.4480314031601773], 
     Hue[0.2749360615481363, 1, 0.6193192993948882], 
     Hue[0.21228788392593284`, 1, 0.7060629299487083], 
     Hue[0.18314962691401898`, 1, 0.7464082088882814], 
     Hue[0.19495787943114445`, 1, 0.7300583207876462], 
     Hue[0.24466271032969494`, 1, 0.661236247235807], 
     Hue[0.28013617649380107`, 1, 0.6121191402393524], 
     Hue[0.3621209519908067, 1, 0.49860175878196], 
     Hue[0.4451684747100392, 1, 0.383612881170715], 
     Hue[0.5167402753982258, 1, 0.28451346483322587`], 
     Hue[0.5728233150649804, 1, 0.20686002529464262`], 
     Hue[0.24408594985937848`, 1, 0.6620348386562452], 
     Hue[0.5609429858823104, 1, 0.22330971185526255`], 
     Hue[0.116926595983181, 1, 0.8381016363309802], 
     Hue[0.1870301269286732, 1, 0.7410352088679909], 
     Hue[0.2994193607344693, 1, 0.5854193466753502], 
     Hue[0.5702672651642874, 1, 0.21039917131098668`], 
     Hue[0.482413894023316, 1, 0.3320423005831009], 
     Hue[0.10679991366380182`, 1, 0.8521231964655052], 
     Hue[0.028528340951307407`, 1, 0.9604992202212667], 
     Hue[0.15894934493019736`, 1, 0.7799162916351113], 
     Hue[0.27477692792622116`, 1, 0.6195396382560014], 
     Hue[0.38780391391090985`, 1, 0.46304073458489403`], 
     Hue[0.5852727256986744, 1, 0.1896223798018355], 
     Hue[0.49623368777809296`, 1, 0.3129072015380251], 
     Hue[0.40723391967740985`, 1, 0.4361376496774325], 
     Hue[0.1355477989944125, 1, 0.8123184321615827], 
     Hue[0.0561051139248433, 1, 0.9223159961040631], 
     Hue[0.023270413385846234`, 1, 0.9677794276195976], 
     Hue[0.1660024444276852, 1, 0.7701504615616667], 
     Hue[0.27696374403564433`, 1, 0.6165117390275694], 
     Hue[0.3871053925865298, 1, 0.4640079179571126], 
     Hue[0.4805537955147301, 1, 0.33461782159498915`], 
     Hue[0.6023460341736332, 1, 0.1659824142211233], 
     Hue[0.5188498732647925, 1, 0.28159248317182584`], 
     Hue[0.4409936328930442, 1, 0.38939343137886184`], 
     Hue[0.34538449739612326`, 1, 0.5217753112976755], 
     Hue[0.19694005720194346`, 1, 0.7273137669511552], 
     Hue[0.12238397672032497`, 1, 0.830545263002627], 
     Hue[0.0884317154178117, 1, 0.8775560863445685], 
     Hue[0.10375357462868562`, 1, 0.8563412043602814], 
     Hue[0.20733875071075492`, 1, 0.7129155759389547], 
     Hue[0.3061371454244128, 1, 0.5761177986431207], 
     Hue[0.405808507510116, 1, 0.4381112972936856], 
     Hue[0.4914364131447315, 1, 0.3195495817996026], 
     Hue[0.5597906890952161, 1, 0.22490519971431616`], 
     Hue[0.5978608444763083, 1, 0.17219267687895778`], 
     Hue[0.3427452344342437, 1, 0.5254296753987395], 
     Hue[0.3842971118118802, 1, 0.467896306722012], 
     Hue[0.6177971273208912, 1, 0.14458859294030454`], 
     Hue[0.5828486430136465, 1, 0.19297880198110495`], 
     Hue[0.4333278292564814, 1, 0.4000076210294874], 
     Hue[0.40231605449512886`, 1, 0.44294700146828314`], 
     Hue[0.45456303581376445`, 1, 0.37060502733478773`], 
     Hue[0.500653171458701, 1, 0.3067879164417987], 
     Hue[0.6317774561574506, 1, 0.12523121455122221`], 
     Hue[0.607253262945072, 1, 0.1591877897683619], 
     Hue[0.5826608286441058, 1, 0.19323885264662272`], 
     Hue[0.5079065757593584, 1, 0.2967447412562729], 
     Hue[0.4861594577380445, 1, 0.32685613543963077`], 
     Hue[0.4772569851352815, 1, 0.3391826359665334], 
     Hue[0.5167251850346479, 1, 0.28453435918279524`], 
     Hue[0.5472657246634994, 1, 0.24224745815823162`], 
     Hue[0.5775676548845988, 1, 0.20029093939055556`], 
     Hue[0.6417279253205035, 1, 0.1114536418639183], 
     Hue[0.6267346593848439, 1, 0.13221354854406242`], 
     Hue[0.612941217282257, 1, 0.15131216068610576`], 
     Hue[0.5959981070525373, 1, 0.17477185177340993`], 
     Hue[0.5696556090993762, 1, 0.21124607970855605`], 
     Hue[0.5563766442135991, 1, 0.22963233878117056`], 
     Hue[0.5502605344346039, 1, 0.2381007984751639], 
     Hue[0.5528621143129753, 1, 0.234498610951265], 
     Hue[0.5710872328122532, 1, 0.20926383149072647`], 
     Hue[0.5885739589734652, 1, 0.18505144142135588`], 
     Hue[0.6062751719935868, 1, 0.1605420695473413], 
     Hue[0.6215312007966796, 1, 0.13941833735844367`], 
     Hue[0.6228630326504282, 1, 0.13757426248402257`], 
     Hue[0.6096877329029456, 1, 0.15581698521130607`], 
     Hue[0.5942753953788704, 1, 0.17715714486002554`], 
     Hue[0.578196972458653, 1, 0.1994195765957113], 
     Hue[0.5534622544369899, 1, 0.2336676477026293], 
     Hue[0.5502609097025113, 1, 0.23810027887344595`], 
     Hue[0.5539759816994939, 1, 0.23295633303146995`], 
     Hue[0.5638867655424574, 1, 0.21923370924890517`], 
     Hue[0.5953645965293008, 1, 0.1756490201901989], 
     Hue[0.6106661374931279, 1, 0.1544622711633613], 
     Hue[0.6236270389875472, 1, 0.13651640755570388`], 
     Hue[0.6348006587199928, 1, 0.12104524177231768`], 
     Hue[0.5804419605717948, 1, 0.1963111315159765], 
     Hue[0.553671553411395, 1, 0.23337784912268394`], 
     Hue[0.5257149248329863, 1, 0.27208702715432675`], 
     Hue[0.47725711309755225`, 1, 0.3391824587880046], 
     Hue[0.4836291928262171, 1, 0.33035957916369946`], 
     Hue[0.5008325505517295, 1, 0.3065395453899131], 
     Hue[0.5817027184239647, 1, 0.19456546679758735`], 
     Hue[0.6042635988004508, 1, 0.16332732473783743`], 
     Hue[0.6236270389875473, 1, 0.13651640755570377`], 
     Hue[0.5055680372000515, 1, 0.2999827177230057], 
     Hue[0.4637621616894648, 1, 0.3578677761222796], 
     Hue[0.4007621658133186, 1, 0.4450985396430973], 
     Hue[0.42654081381261244`, 1, 0.4094050270286905], 
     Hue[0.5817027184239646, 1, 0.19456546679758752`], 
     Hue[0.610666137493128, 1, 0.1544622711633612], 
     Hue[0.3907502340439717, 1, 0.4589612144006546], 
     Hue[0.3389361078632657, 1, 0.5307038506508629], 
     Hue[0.5953645965293008, 1, 0.17564902019019882`], 
     Hue[0.5632871686543652, 1, 0.22006392032472508`], 
     Hue[0.5004450836337965, 1, 0.30707603804551264`], 
     Hue[0.42604254035927835`, 1, 0.41009494411792236`], 
     Hue[0.33837931416065686`, 1, 0.5314747957775521], 
     Hue[0.24658236972349462`, 1, 0.6585782573059306], 
     Hue[0.10834460042460281`, 1, 0.8499843994120885], 
     Hue[0.08843114950821718, 1, 0.8775568699116992], 
     Hue[0.10861104359249618`, 1, 0.8496154781026976], 
     Hue[0.1648636088038778, 1, 0.7717273108869385], 
     Hue[0.33893610786326595`, 1, 0.5307038506508626], 
     Hue[0.42654081381261255`, 1, 0.4094050270286903], 
     Hue[0.5008325505517293, 1, 0.30653954538991346`], 
     Hue[0.5638867655424575, 1, 0.219233709248905], 
     Hue[0.4830746978240673, 1, 0.3311273414743684], 
     Hue[0.40004897243384896`, 1, 0.4460860381685169], 
     Hue[0.3022320270374818, 1, 0.5815248856404098], 
     Hue[0.19980207471950806`, 1, 0.7233509734652965], 
     Hue[0.02326999810538999, 1, 0.9677800026233061], 
     Hue[0.04582379719126228, 1, 0.936551665427483], 
     Hue[0.10861104359249629`, 1, 0.8496154781026974], 
     Hue[0.4007621658133187, 1, 0.4450985396430972], 
     Hue[0.48362919282621697`, 1, 0.3303595791636996], 
     Hue[0.5539759816994941, 1, 0.23295633303146973`], 
     Hue[0.3911136684189974, 1, 0.4584579975736959], 
     Hue[0.289545777407348, 1, 0.5990904620513643], 
     Hue[0.18314986366475478`, 1, 0.7464078810795703], 
     Hue[0.023269998105389655`, 1, 0.9677800026233067], 
     Hue[0.08843114950821707, 1, 0.8775568699116995], 
     Hue[0.4772571130975518, 1, 0.3391824587880052], 
     Hue[0.5502609097025114, 1, 0.23810027887344576`], 
     Hue[0.30286961558245473`, 1, 0.5806420707319858], 
     Hue[0.19995218021711048`, 1, 0.7231431350840009], 
     Hue[0.10834460042460226`, 1, 0.8499843994120891], 
     Hue[0.5534622544369899, 1, 0.2336676477026293], 
     Hue[0.24684375443555662`, 1, 0.6582163400123062], 
     Hue[0.5785358818375376, 1, 0.19895031745571717`], 
     Hue[0.5259338698041325, 1, 0.27178387257889347`], 
     Hue[0.4640436151731847, 1, 0.3574780712986674], 
     Hue[0.391064624126182, 1, 0.4585259050560557], 
     Hue[0.3146212857943015, 1, 0.5643705273617364], 
     Hue[0.24684375443555678`, 1, 0.658216340012306], 
     Hue[0.19995218021711053`, 1, 0.7231431350840007], 
     Hue[0.18314986366475433`, 1, 0.7464078810795709], 
     Hue[0.19980207471950773`, 1, 0.723350973465297], 
     Hue[0.24658236972349445`, 1, 0.6585782573059308], 
     Hue[0.3907502340439714, 1, 0.45896121440065496`], 
     Hue[0.46376216168946466`, 1, 0.3578677761222797], 
     Hue[0.525714924832986, 1, 0.2720870271543271], 
     Hue[0.5781969724586531, 1, 0.1994195765957112], 
     Hue[0.5546086760264161, 1, 0.23208029473265476`], 
     Hue[0.5067715095368749, 1, 0.2983163714104809], 
     Hue[0.4502770825641294, 1, 0.3765394241419747], 
     Hue[0.3910646241261822, 1, 0.4585259050560555], 
     Hue[0.3028696155824549, 1, 0.5806420707319856], 
     Hue[0.28954577740734794`, 1, 0.5990904620513644], 
     Hue[0.3022320270374816, 1, 0.5815248856404102], 
     Hue[0.33837931416065664`, 1, 0.5314747957775524], 
     Hue[0.5055680372000513, 1, 0.2999827177230059], 
     Hue[0.5536715534113947, 1, 0.23337784912268422`], 
     Hue[0.5942753953788705, 1, 0.17715714486002548`], 
     Hue[0.5475013404862448, 1, 0.24192122086519957`], 
     Hue[0.5067715095368749, 1, 0.2983163714104809], 
     Hue[0.4640436151731846, 1, 0.3574780712986675], 
     Hue[0.3911136684189974, 1, 0.4584579975736959], 
     Hue[0.4000489724338487, 1, 0.4460860381685172], 
     Hue[0.42604254035927813`, 1, 0.4100949441179226], 
     Hue[0.5804419605717945, 1, 0.19631113151597673`], 
     Hue[0.6096877329029456, 1, 0.15581698521130607`], 
     Hue[0.5546086760264158, 1, 0.23208029473265504`], 
     Hue[0.5259338698041324, 1, 0.2717838725788937], 
     Hue[0.483074697824067, 1, 0.33112734147436884`], 
     Hue[0.500445083633796, 1, 0.3070760380455132], 
     Hue[0.6228630326504281, 1, 0.1375742624840226], 
     Hue[0.5785358818375377, 1, 0.19895031745571706`], 
     Hue[0.5632871686543652, 1, 0.22006392032472502`], 
     Hue[0.5632871686543652, 1, 0.2200639203247251], 
     Hue[0.5785358818375376, 1, 0.19895031745571723`], 
     Hue[0.6228630326504282, 1, 0.13757426248402257`], 
     Hue[0.5004450836337964, 1, 0.30707603804551264`], 
     Hue[0.4830746978240673, 1, 0.3311273414743684], 
     Hue[0.5259338698041325, 1, 0.27178387257889347`], 
     Hue[0.554608676026416, 1, 0.2320802947326548], 
     Hue[0.6096877329029456, 1, 0.1558169852113061], 
     Hue[0.5804419605717948, 1, 0.19631113151597648`], 
     Hue[0.4260425403592784, 1, 0.41009494411792224`], 
     Hue[0.40004897243384896`, 1, 0.4460860381685169], 
     Hue[0.3911136684189974, 1, 0.4584579975736959], 
     Hue[0.46404361517318465`, 1, 0.3574780712986674], 
     Hue[0.5067715095368749, 1, 0.29831637141048095`], 
     Hue[0.5475013404862448, 1, 0.24192122086519957`], 
     Hue[0.5942753953788704, 1, 0.17715714486002554`], 
     Hue[0.553671553411395, 1, 0.23337784912268397`], 
     Hue[0.5055680372000515, 1, 0.2999827177230057], 
     Hue[0.3383793141606568, 1, 0.5314747957775522], 
     Hue[0.3022320270374819, 1, 0.5815248856404097], 
     Hue[0.28954577740734794`, 1, 0.5990904620513644], 
     Hue[0.3028696155824547, 1, 0.5806420707319859], 
     Hue[0.39106462412618187`, 1, 0.45852590505605595`], 
     Hue[0.4502770825641294, 1, 0.3765394241419747], 
     Hue[0.5067715095368749, 1, 0.29831637141048095`], 
     Hue[0.5546086760264158, 1, 0.2320802947326551], 
     Hue[0.578196972458653, 1, 0.19941957659571127`], 
     Hue[0.5257149248329863, 1, 0.27208702715432675`], 
     Hue[0.4637621616894647, 1, 0.3578677761222796], 
     Hue[0.3907502340439716, 1, 0.45896121440065485`], 
     Hue[0.2465823697234944, 1, 0.6585782573059309], 
     Hue[0.19980207471950812`, 1, 0.7233509734652964], 
     Hue[0.1831498636647544, 1, 0.7464078810795708], 
     Hue[0.19995218021711053`, 1, 0.7231431350840007], 
     Hue[0.24684375443555684`, 1, 0.6582163400123059], 
     Hue[0.31462128579430143`, 1, 0.5643705273617365], 
     Hue[0.3910646241261821, 1, 0.4585259050560556], 
     Hue[0.4640436151731846, 1, 0.3574780712986675], 
     Hue[0.5259338698041323, 1, 0.2717838725788938], 
     Hue[0.5785358818375377, 1, 0.19895031745571706`], 
     Hue[0.2468437544355569, 1, 0.6582163400123058], 
     Hue[0.5534622544369899, 1, 0.23366764770262935`], 
     Hue[0.10834460042460292`, 1, 0.8499843994120884], 
     Hue[0.1999521802171107, 1, 0.7231431350840006], 
     Hue[0.30286961558245495`, 1, 0.5806420707319855], 
     Hue[0.5502609097025113, 1, 0.23810027887344595`], 
     Hue[0.47725711309755225`, 1, 0.3391824587880046], 
     Hue[0.08843114950821707, 1, 0.8775568699116993], 
     Hue[0.02326999810538999, 1, 0.9677800026233062], 
     Hue[0.18314986366475428`, 1, 0.746407881079571], 
     Hue[0.2895457774073478, 1, 0.5990904620513645], 
     Hue[0.3911136684189974, 1, 0.4584579975736959], 
     Hue[0.553975981699494, 1, 0.23295633303146987`], 
     Hue[0.4836291928262172, 1, 0.33035957916369935`], 
     Hue[0.40076216581331864`, 1, 0.4450985396430973], 
     Hue[0.10861104359249618`, 1, 0.8496154781026977], 
     Hue[0.045823797191262394`, 1, 0.9365516654274828], 
     Hue[0.023269998105389544`, 1, 0.9677800026233068], 
     Hue[0.19980207471950773`, 1, 0.723350973465297], 
     Hue[0.3022320270374816, 1, 0.5815248856404102], 
     Hue[0.4000489724338486, 1, 0.44608603816851733`], 
     Hue[0.4830746978240669, 1, 0.33112734147436895`], 
     Hue[0.5638867655424574, 1, 0.21923370924890512`], 
     Hue[0.5008325505517295, 1, 0.3065395453899131], 
     Hue[0.42654081381261244`, 1, 0.4094050270286905], 
     Hue[0.33893610786326583`, 1, 0.5307038506508628], 
     Hue[0.16486360880387757`, 1, 0.7717273108869387], 
     Hue[0.1086110435924964, 1, 0.8496154781026973], 
     Hue[0.08843114950821707, 1, 0.8775568699116995], 
     Hue[0.10834460042460226`, 1, 0.8499843994120891], 
     Hue[0.24658236972349423`, 1, 0.658578257305931], 
     Hue[0.3383793141606567, 1, 0.5314747957775523], 
     Hue[0.42604254035927824`, 1, 0.41009494411792247`], 
     Hue[0.500445083633796, 1, 0.3070760380455132], 
     Hue[0.5632871686543652, 1, 0.2200639203247251], 
     Hue[0.5953645965293008, 1, 0.1756490201901989], 
     Hue[0.33893610786326606`, 1, 0.5307038506508625], 
     Hue[0.39075023404397147`, 1, 0.45896121440065496`], 
     Hue[0.6106661374931279, 1, 0.1544622711633613], 
     Hue[0.5817027184239647, 1, 0.19456546679758735`], 
     Hue[0.42654081381261244`, 1, 0.4094050270286905], 
     Hue[0.4007621658133187, 1, 0.4450985396430972], 
     Hue[0.4637621616894646, 1, 0.3578677761222798], 
     Hue[0.5055680372000513, 1, 0.2999827177230059], 
     Hue[0.6236270389875472, 1, 0.13651640755570388`], 
     Hue[0.6042635988004508, 1, 0.16332732473783745`], 
     Hue[0.5817027184239646, 1, 0.19456546679758752`], 
     Hue[0.5008325505517291, 1, 0.30653954538991346`], 
     Hue[0.4836291928262169, 1, 0.33035957916369973`], 
     Hue[0.4772571130975518, 1, 0.33918245878800524`], 
     Hue[0.525714924832986, 1, 0.2720870271543271], 
     Hue[0.5536715534113947, 1, 0.23337784912268422`], 
     Hue[0.5804419605717945, 1, 0.19631113151597676`], 
     Hue[0.6348006587199928, 1, 0.12104524177231768`], 
     Hue[0.6236270389875473, 1, 0.13651640755570377`], 
     Hue[0.610666137493128, 1, 0.1544622711633612], 
     Hue[0.5953645965293008, 1, 0.17564902019019882`], 
     Hue[0.5638867655424575, 1, 0.21923370924890503`], 
     Hue[0.5539759816994941, 1, 0.23295633303146976`], 
     Hue[0.5502609097025114, 1, 0.23810027887344573`], 
     Hue[0.55346225443699, 1, 0.23366764770262918`], 
     Hue[0.5781969724586531, 1, 0.1994195765957112], 
     Hue[0.5942753953788705, 1, 0.17715714486002548`], 
     Hue[0.6096877329029456, 1, 0.1558169852113061], 
     Hue[0.6228630326504282, 1, 0.1375742624840226]},
   VertexNormals->CompressedData["
1:eJw8XHlcT90TLqFIC5FSthKVSNm3jkJCe7K1klakfU/7Xlq176FIaRHqVSdl
CREppCKFElpUKJXfmXP7/v66n3fe3HvunPnOfeaZZ87yk+e0TaexsbHt52Zj
4yBXiWzroh3lz6pYVyXlyX///vWjuX/5flxnF8CWh4feHhJbhwfqtfrAviVe
4oHGub9VixJVz+nXKeGH3um5YF+pknhzze+JKv7236fWX1PBb2SKzcH+7aMl
10YfdlxhFxzLE66Bfcw/zwT7/GB3d91GDpzd8tl36X86uENF3W2S2EtbbVY+
L5uBeW6cHN4nfhTb/td9Z4LYB9VUjrz/NhMfjjn2wq9DH4tUJ1eOE7vVk4tB
bYqceIVz8j3VT8a4vEQ89C+xp9vrjaX6z8Q/Y3KKl+mYYEetcqkxYl8coDj+
JHU6jlBwadJNN8Vs3StK/hD7Xdd1Uksi2HFmaX8t1xVzvO3edaXfxH7kzgWx
NQ1jVcnfXYWKD1ri9Zd02X4RuwSXvnRC80BVmPAdrz8OVri5Yg7/CLH7Tz5N
l7d5U6VzdrhDnO80Nh2Wixwmdu078j8Col8rtBySVF899zQ+99ItAuw15h1a
a1sHFLYZlx4JcbbCwX4/eOA+JnEFVUJvxxSq1v8R6FWzxJfzYyfB/s9SxvdW
DDta0PdH5nGuOTZcfkIR1ulWIKX4OXs6erT3hl1ohileL36oGN6rKc6TvTR0
Jjq3RmN+LfHDs7HD1A9nzG77n97HieSsAipMiN/ytRZSv41sL+AJHpiJ7iqW
Vld90Mcr/j2kfg4v/BirVj4DVXanNFQvP4pbdeXKYV/KdxgJXGniQDOud2rz
l+vgQNsMuo/dTufG1H3Z0QnX2ae0gzTw7z+ynLDvhxWVDh77PaEwqLrUZfdl
FWw0q4/GyYJ9xrOdg/4qtOSu1KyrUcJ/QxppXEnmDZsWTc5D6jn/NU/rl8W2
0nk0DnuvXOMrzq9XiDaa5lWaX1/FZsrE7a+fX2m8aozGf4f4ZcWtncLcuW2f
HPD/r9w/zz4m9qx9Lud/bTDESlc0ONC5YKyzbf5qc2LP7XWc1HA1xhdLg952
cUdhA/HtimOT/WjGIultortMcMZfi1V+gXG46qbxh0PEfkjs2qaT9aZYRTfm
yoyCJHyldcUW0wny953Gw1nvzfFio93nai0y8J0oBW3R8X4UtkJx/+kNlvhq
uFKS5uNsjHpbO2zH+tHkmf3C4ZGW2GbbB5+00ctYrlNzn+WfftQZbZA+VGWB
nyWaqcaKXcWK7gkNC371o5jXiqbnr5jhM+1d2YWi13Hw+E6b1KF+JFJvXLh9
rwl+qXFsUWpVId79rK5VbrAfPWi71vnP1gDL/ROb7WZThJcXtwrN7+9HryJC
74q5aeMtTuJXx9cVY/2V83O8f/Sj9ogdf6p1t+Lr/EGi3nHF2FZ1P8/V7/0o
usSiagHfVmTvUvEtgNg1A/XZwf58epNXp7s2UvtlwDZdrhinfOKIhft8cj69
9KWDAeodfHvCmzz3T5cENzxXdlx+6aSyCdozvlL0Cllnm8LCl7BO/75daWfy
zNDb9BTPMvJevHfeWMB7zTir4dlRbYEutZm0xxM/dDUefAp+KPf4bKEWbYlC
VW1+gd/s3ZP2gt/cFwsEd260RKpJJerqxM/6ZXM+gp8Tx3y6/vtgjmZpV8VU
kH3ZMTdJB/Zl+ovmxULPTJGA48tbo9eTcCoP7zbYxwe7BRfY7zJBAaNRTo5k
33liDT/Cvq915uLSdTVG4sfmXG4mcXLwONtuiJP3nYWt6TsM0fbqoYklJK5q
o+ulIa6+nbE629PlgPa26bqRK9nHXjuIQ/OdeBlbvyw690bBjsQ7Fl/DxPn9
s+tonj0nyH8P8i4r3yb9m5wG8fr2w0k3iF9xxMSt09CoS02hLe4smu4O16fj
u3vfQp4UF/ILV7HHb3nUP//c6Yw5jGX+PSR2i47pnI9CnLD++rBqnmpP/CH/
RV8esWullT2YCHTFo3dPRNem++LEp1sSvCFPCq8dej7ijnf3rz4/9iQQX3cu
2aVG7D5cefb7gj3xTiPf4TMqYfi4EY8JH/x+S+fMtB3xxBk+FQGjfZE4P6pu
sI74xzP6/SxbDk/8K9r+LbdyDO5JiT7rSewdbFGC1VFu+FRz3jUO+zj8VX9V
vhyxWz1zvViV4oTLY5c68xvH43t3Lup+I/viV5nyZ0LZFhuVyiVLDiTgiUuD
W4uI/camD3l8Rab41cu1n7VmJ+GuU/EhAcR+XIzduD5BDZMfjfOW1CT8tttQ
8hyxe2wVWhV2QQ3dvrtAfDax74tdIw/2O3cfbztYZIquO6rqLCT3GeT9FAf3
4ag8N2ftPlvEkxr/daQ/AYfumbEbnut0syV1NMUJ1a8Pdu8xisdxId/1YJ2C
Z7fsZ492Q2a+FUt67OLw7atlhfBeu6zUGoo5PBGb/x+tib0xOD+13Br8cEJz
9kj+iCeaZjzr4AjxW7qhLPXb9esfG12CPdEz6xzr88TP269YnAA/Nz27Xz40
4o7iXrRvW/w0EJ9hv6IA+9Kbz3NxQZArco775fOT7OOG+5svwj4Kr5Pd1xji
hHbnrcpxJft+r2rpD9j3/96mTpI4QRJR1VEmCs44oLVrAuIkS2nxHKUbtuhV
0t1RxRu2eLskfw/E1QMjtX4S36j5WEsJiXdspv6MxrlDu0H5wxol9F5X6ZNT
0N+qrkQmn2e49lF8UN8VcRvwAgsnPJzKs6MhdyYg7+KpfJsSNdgF8fq+L8Yf
4td8Km5fHcp2lzzuilnXAL6VeTeIvfi3skpztifOmqt1+/Y2byy9WUkxiNhf
KvqsFnvsjU22/PrZpOWPry2qOKQN9g1yH/aa+OLzj2cfv9MRjLPeOf/HT+wD
/9DsgDN++CPbJofougj84/pAVy1Zz9OTmhWNN/1wedp562rraJzi+GvMmtg3
/7yoziXoh/mWaxtLDsfi8l58R5DYy1Tndi1w88Gvn3t+/HooHovMlW6tJvHQ
ukS0sA574jVvP+z+cC4RI1++0/bELtaQK7H6rhO2PMqvs1MiGT9eVzG+nthv
V3JvFw49g21W3FSpOJaCY1/0LuAk9vWX7e9XO+tg2+36z5RGU7DBnhtv+0ke
Uzo0WzrTXgft2VJ1EewjS/RbwM7XIPZcI/QM4uDbLwj3iftyn97HZlJU+PBd
J+Tk+Wk5PHdy+QH63KGI6bUT2BO9s7MUgnXqHde2gnVWcJyvlHfzQfcELj6D
95I4LPcO3qvvwZaJFYJ+yLfVZT/4Iamk+Db4IdtkuOf7TT/Ud23sGPjNYevv
UfCb2mHlZ8ln/FBYipkT+FlKejH1cxu/neRhE18k4DHTEPblQc/HCtiXSZvO
EpnH3qhP4B1vM9lHqwxjuo8HK3PXfsj2RMu3ZnXBvhuIidJ9vxPxu4HEB/qR
p9IOcfL0uTiNk8CotGskvtHCQAueCBJXZWeYODdUKkgheRx5bZXhJ3kdf/Jl
p/l8o3LbCcXLKijHhPc4wS9VC8UZ3JKyNYXBtWxPZwLO9ZrCt4ZjDD7wKjLf
CXjhSQmDE9yjM+9Dnj0RojQb8m5ULJNv//GaFcO6k11m7YX4XWfPxG3Ek3IB
51FfvPnnonlw3dUuPHaQ2DXz8sRkvAKwVkqTi11NEF4i1qDzj9yf+6aQ07yI
IDxH/E5k2cII/GjM8lYWsZ984ZB55mMwlvjmaZhgFY290sdbNxK7hdDGLREK
Idj41fziapM4PP5mcTvs4+2sbqtY+2C80u9MwdwjCVjiUFPufmJPjPh7TOJU
IE4JmLXCY2kyXhZ+feFbElem71UXvOb1w0mmH3iU41Mxb+ZInT2xv214Gnds
uSfW2XXAaEN8Ol7hW71WnNi5FgqeLlexwwI1kpsU/mXgzpMdXN/+krzUU1HS
M3AUJyy7cXJSPxMrce7e+5zYZbbN2Tr0/Siapzzr+DixR/bO2wf2gODnfY0q
doj79A3+reQ+tmH9s+A+0U8DfX2Xe6KxprWtsuS5t54iWXiuutKFzf28fkgN
F4QqkXXW/HhO19ngtmyb4qlAlP3SsdKVvNfNF4OC8F52+gFfC+2DkdzdNAt+
4of7WvgK+EFRWcDiikIIWin9LAj89sDqC/1dLy8eDfb5GIzCjPUEEomf97z5
8A78vETkhrRYRBAymlx8/Q7ZF3fsVwb7EtO7U2GTVwAKVeeKcyL7WFQkR/dx
xtXdL91HfdH+L6r3yRUnH6oehX0vKczvIHGC5np9liPxjo3WMnHeFXXuJcnj
SIZjcDfJ67hWhMnntSUqVgSvIFuFW4IEv2DDUGOKW7zaBe5oBGmgx7cfzdDw
ZccLxNdRfM6qx1j1Gasu2zLDiuLaxvuvdgLObXvP4Ns1nPwxgA9u8927C3jh
1UcGJ7gbuQ9Cnl1Q2bEO8m7KeDn9nWrxbnKGeH3z/bwIxO9xXyZuH93OLX7w
LRSzrl5xukkXif3n2bJPYl4R+NqW+1n33KNwe7NQBeSTQ2MfKnmlI/Fck9k5
1Xdj8Quv9aFBZD3KoV/3KGdE4ltHpJMfiSRgnU6+Nsh7s3lWbPHPuoBnN7gI
bHRIxjWr+q2OEfv6MJ02SZ5w3OJ1dIFAaho+n1NN4+30hiOzTnYEYa5sycfF
6zPxb52+ZUeI3XrMpiMG+WJN3Uc5f3Sz8IsdltvHCJ48qSNr59zjhMtGb0aU
iWXjDWLBq/8j9ry/WlwIGeFatUOzk8Oz8S3De+dSiN2nvTOjYbsR+pE1o+Ii
sf8sErIHu45xw7ILPU7o2zs+kSJyH0tuw7VwH5v/0qQuI18k9eDN4BB57v0m
tZ3w3KF/Rd3OHUFoQ9FpvkKyzoN76pfDOmUfv1+nyBOO9NRNe3jIe61vT6Pv
ddh00cbUrAvox3Xl4/LEDyvv8VE/hOUrHdXPiERsVoe2gd9Ozrj/DvwWfCWS
fbl0JDqtXa9SQ/wcUtMcDH7mSJMNXecVgZawN/beJ/uiJ9dFv3cjSuZGz7+F
ItWBTw7kimc9sEqEfSwdLAom8Y3+NNrvIPGOrx2QZ/LVKprHkYmr2g2S17Fb
JZPPn/WfTiR4BSVHsKcT/IIDXm+iuEVLsPYKweWIc8dqGYLTccqOuRSfcy3k
yeUt10FePFiI1KPYrpSpQ384OlIeQaHVVhp4hbNTfEJ9byytx/YfOvEH6rMR
V6YuS5O0dwdcq+cm8w1wbkEJg2/jh5J14TuUf0i2GfDC67MuFCe4lxyOhjzL
cUjYDfLugptMvmXFKyt+WXHr2clt2soXg1nX+jeHreF7emJ/n/XlBbHYOUVu
GnfWRdzvs60ek/VIxBjtqjaIxe5uO2o26CThs7tKjnIS+/XbEn0JNTFYf95y
njWTqfjJlit0312c66MN1kbjKsG0CrZtmdjhjzyNw/XnQ1SaUQS+9KDur1xN
Ft6XUrx8B7GXiD4rnzweiGMHmur92HLwbr2D0u9H+9HrlQc1I/g9sLnC0b18
H3Pwb+4tp7OI/amHg76LuAm2FtWxW6d7Cdd+Hu/zI/bZcatypMVM0Jevm7AU
sW/azTkM9kWB3nvT+D1Q5L5Z72aS+wSMb7eB+4xGJ5Ry6wWieO8r5z3Ic2fE
zl0Lzx2bz+30GUUg34jcdTJknVvPj4vDOq/GRGabrY1GGW43Ksa3ZmL159Nk
4L0+rvXuzayJQXaFeh2SxA+yi/ZRPzgZzTpbZxCL1MeURcBv3kHxR8Bv9RHz
Nl5fEIu45yTF8hA/W9+uewJ+NnktEtDBF4P23Ft4llyxblP3GdgXnyN5XSS+
ERKRjyfxjk+eYeLcSIU3geRxFDOzeB3J61gi35/mczvh7RokTlBzh8MGgl/w
CflOilsWrfmkT3A5ajv1pIXgdFzCc4ni8za1cC9SfyKRaUH9pB7FeVVptA49
8rW+tmr5UdTe152vVj4DJ99h+BYW/8Xiw1g8WOEzK8ojfJnL8AoJjQyfsOTB
+xGoxwx/59L67IkqU5cl5xc5At6K+sng3M/xDL6tSfmgD/jAeHdLDOCF9d4T
FCfs+eKYAXl2mn8HzbsreDbQfDuyVI4L4lWrs8IR4rfSbQuN20Gr9tef3sVj
r8d8L+DabadPv+8u3dIxyXIJWMvJbnRBbTK+EnPGWZjY9Zf43hJ0ice67k15
dTnpuN06960eWf8bDpH1m+PisH+1l77MyixcENYZiEmczAxTLA31jyb4nP18
x/1sXDx9jdZBYpdTyfTWexSKPxQWCAYtuIR1t4e4Tv4hOHzOx4ItDd7477Ys
iWkcl/HdusK4RmI/vfFr7b3vZnilqZfWa8/L+NlTvdOY2FdFiPYv/G6GTOtd
Dj0j9lztDluwrxxrdN3Z4I0MT/K++TXtMt5/ZzgF7uM0W1j05KNQtKL6oIon
ee5Q2jEveG7I0umzIv2j0ZrXGx68Jev8ZrVYF9Yp4faUe0dcHEryuyS0irxX
4LMfwfBek6vMA0Rc4tGmZTsna4gf5G9It4Af/jp/r0+XS0AjlhsFwW8r6984
gd90jBx1et7Fo9kL6w3JFR85uIgT/IyLksJIfKP2e+wyJN5xyemnNM5zE94i
ksdRuJgMH8nr+L3Ga5rPLe6PzSd4BdkI1Jwl+AVbDHZQ3MKRImhJ4gTlPKc4
HZ8eYPD5CYW4cFJ/otsVh5+TehT7LzGndeiHZr7d6o+zEeesEcfOjZb4YpIA
5VseSqSq3/2gjyR/i88KHpiJjcMf0bi9LRBNedtei2O+wOPiKf6Wo0jWF3ic
6qW884EPE7jB8GDFiQ0hwCMsdmJ4BTcNhk/Y92H7Oagrjur03YX6jEuJqcsO
xt0sAXy2ckOMAOBctVNLKb79liqaA9+5O3ONNAAvKGXwUJzwxUrhFuSLRR9U
10PerUq+RfMtK15Z8cuK25OhQ1ETkin4etvlTLjqLB0Ug3xleAutldJMxnOv
Cup9FcrAfA9MvkE+rE7g73glnIgf9FWu+22ehQ9NLPOEOHHNv/JA0z8Oq7V/
uynJk4OLP7eaFhK7yDmZw+YGkbhdwSJH2OQSHt9bmRtK7NH3H7MbFvlhm6jv
XUcPXcaxjhvO+BL7hgTbx09arLCMX/6ulS8v4zMprv1+xB4jNq2ut8UKFW7d
HSZC7OpuBb/AvrZ7jpJ+kR/iyRdVP0juw/5D1xHuc+N5tJqZQSRSvS3SxUOe
G/ji4A14burBwM1knajkn6rtUrLOo73Op2Gde/7WNjYKJyKHkKZPA+S9Uvfe
84b3shZWlJfUTEadcW15ncQP8yy3/AA/OLfmNIxLpqB1qh+ayBUb2+yleZ6N
bTPEN2orcKoh8Y51iltonHv+2L+a7Ativ6CoSfI6trqdQPO5UMC9TWQfEX9f
+xaCX7BMykOKW/hcUpzJviOLG2kGBKdjM7+vFJ9b1mjrkDhBlkPr+kg9iod/
MHXofI/i0yN9kWhE4+uS6ySuDtyRoXG1aMi3m8QhOuOsGawWbYmHLuVQXtHt
zG7Vk5+MkX+0u9fpfZx4moAQjVtWv8EnJIwtzX/m//sOf/QVKG/bKd5TBDxu
SDjD3+5429AC/JemKC8/8GGVOgwPNjDB8Ag89i5SwCu0qd6j35051teKoB7b
1yilDfXZkW9MXfaU8zMf4NraihE5wLkNuwcorlOIkWAHfOBZeKYZ8MKyqOv0
+9hecDUC8qxr1bM0yLt4XwnNt1zT5ZUhXvcEVIhA/P7KO0Pj9r9jh7X5l6dj
7celhnDlmrAp7CZ+6KtPDJudROJ/mlR8YHsmFrv+sjKW2MvfHemqPZ+AD2+V
jO9xzMaxCz//gHiTLjjE/2gkGjdvs3TwvUfifOFeixxin/lgU2dyOMFdKzob
g/Iv4bOvnAVeEfu1pNLjH7E1/nXxfFbsChLPpoEGw8T+kJNXYqjaGq1waIwJ
Ivb8zS6nwO6y4vRkVHgg4l6j3uFC7tOoGb0Y7mPl03b13kg00ph2DTuS586T
/2gDz6058+f73fMJKOr178z3ZJ2LfL4Pwzrlj5vrcySlIDnfpGte5L2kRGbU
wnst3fLlN9fydMRtVr5xFvGD6cG2YvBDPxPf6CQT7/+P8xf/3nPX5qQjSe/4
fSSv45n75Gk+N+zRbyN4BUXyan8i+AWz9arQfZF6sUSH4HJkUPd9LcHpOC55
Lt3HSKEAY1J/oqOegVCP4odPq2kdOh4ltYPECWJLtOSQIHFSF1pK+ZaPKZXm
E3tjkDnXtdZiEle8h25RXrHjtevzeLGryNz3KPDo2D7iCOXP72qttr2nY4JE
952HfhEe+n2EidssH9on8854yfE0dTr+84Xpl5W/ZfoNR9kbzkD/Yd1vpu/w
+8f068DbVmQqrAEed7hlJeVvWfwXiw9j8WCB8+uXAY8wtm+RJfAKLD5hn1zG
bKjHlNZNFEJ9JpjygNYvZYXJNYBr/X98yQScu65LhuLbwozfRwAf4LPXtgFe
cK/pojhBM+P3Rsizwva8NO+6Syyh+bZujLMM4vXOlUvJEL/fxKto3PIcj5gu
9CUds665oSfyQoj9fGeY5GX1ZOy33D3D5msmDl8aOR/iyjXkvc4x0Ti8+2zv
uK9wNjY8dsZZlTy3SHCl2ZZdIfjWnHPcEgPZeG2J0KkHxJ7/1SEwaLMtns+m
273WKAevzH36jo+s31fm0LGQLbZoAId+ESN2o+bPH8B+bc9wuNSuEJT/zvrv
AnIfzF99Fu5za4uuqrpoHHoyV3CGE3nuf0le3vDcw+7TVRLVk9He8ZTDZmSd
XT2XRWGdK2THzGd/SUeDSpoXyRXb2vUWwnspF2vWkvhG+zUkFUi843OJkzXg
h7/DPHUkj6OvejZrwG+XWzDN51ILeLkJXkFI+gXgF6wuOEJxi7RdYTXB5aTu
iwCcjgtq/9F9mSnU10jqT3RyRRfUo/hJUzbdx+sKMpddlyajGcdeaiqSff/z
aITyLV25r/8jcYKaV/A9kCdxUi6zgfKK5v82b+6xi0MLo9+IsEe74azDJZQ/
L0mUP1Mmeh3N/PX20pk8Myw6vZv2iQyd8tOCM0zRvz2z5T9nT8fLjHVpP/Tp
9zba370/1e9Vmerzykxw0T7ZI/4NzdA3W8XxmPbL9FqjPKDfYPkq3hr6D3PX
M32Hh9Y2CPhQjx6Gx+XX46f8bay9Jx/wX28uTV8KfNjnL8OUXzrGO70GeITQ
cBx3oiMIzzD5TfmEOvR4FOqxcZ9QWp8dvF1C6zIct8cbcG3hi10U58YUrab4
Vrct4T7gg96CTIoXhiIbKU74yMVRBnlWKWr57Psk76qvrKf51nMkoRDidbvL
DXaI3+CpuI34IedeXJ+KHWX5suHaN/jJ15/c/xXnKxO76fH4dJHkTrZX6dg6
MDT1FFnPjZeC7Scvh+HD8hZWdssy8cljWsrryPojW8zWXGixwz0lS/nFvTKx
nLXvYB6xd3j8/cvRaofMZ8YLCRE7n2T5ENijK4V/al8OQwo/+SZPkfvMVfup
BvfZ9Dhy9anp8cisdiivpzEd99zMvwTPZSvXeZ1en4rypl1JzCDr7DRZFQbr
vJtw05TENzrRO7GPxDvm7kujcX5p1Rd3ksdR6+EDqyqJHzLlftN8vl/U6DzB
K2jxEqNF4LdHzxwobpmY9bOG4HI0X1f93wXiZ2mBZRSfD1rmriX1J7KTcAsh
9ej/69CAFNeZheszkZ53DK8L2Ue28ec0bw9eaXdRik9FWTEdtv1k37PuvqD7
PuKxkovECQq9EX9jgsTJ5Updyp9v6luT2mMUj9IblYtGSVwdSftC+0QOz9fN
ulJViN44NHFPKpvgmlAp2g/9cUBM5lGuOVqxbQ30/7Fr6kna92fpElg6BZY+
gaercRb0d7/GvjwO/V4zxzba5/XdGpECfbIvW9xNJ5VtcZ3LAO2XsfoNrP4D
q+/wMyrfAHhbi4BpRcDjsvhb2YfHcoH/Gtz4TjAW+WJ9fVPKg9Uee/sEeIR5
KydVgVfIPqBF+QRL9xweqMd481sEoD67kxxH6zK55pcFgGttuW7JWhCcG3vw
KsW3yM4xCfBB3XbBkYcEL2TOlKc4ocj92AjkWU2bPaGQd/nnW9B8u0FahMZr
BrdlGcRv6nkPGrfrNm7bvTg6Aed1c0jCdc+2nK8Qh4d8km0qEyLwmoNO/6Su
JuJNGa34Pnkv45eBvqvWOGANG7mz3NuS8FFed34r4odudnk9DlkHtDMtP2Ns
axKuNF7EB3YVJb2EnIQINCqZumU+uU/e7fAHcJ/6H1aKs6MTkETmhpXkilu+
5gzAc4P3/oH4Ri8eGfCTeMfSJ4tonG89ZSFP8jjadv38BzXyXjJ8zjSfX77v
X07wCkru2H+U4BfcbzdAcYt7REc7weVIXWTUj+B07D+Fz/srzyuS+hMJSpSd
JfUoHpyqQ82eX7X2YMtBM0Rm9nLrBeLtJUKUb7l4dEn3kG4WWn1r09Also83
LupSXlE7M61eNj4dFWhXp/mSfRf4pET582sV4QtJnCBnz1nRuiROOu6p0Tj5
GOXL+as/AeXrqrqu3WeLnasnlSCuBgxfHfG2KUIKz2XCXzoY4M6z22jfn/dL
Vn+3miVa2qXPL/x2rGqXwUWqbxnyuEf1NG+t/47HNw9UPZvS1cw3+5sHuoRa
zOgUrngw+oTSbKdO6O+G2UmoQ783UzqB9nnDX23bB/2tPYlSLxaGnsHjp77T
PpfxH47t0G+Iv1exE/oP+bEfKC9hPFs5GnjbGJfhNpceJzw4x5d+vyRKD1P+
a5Z77owL/B54Q9RGyoOFdkWLAo8QFBvJtbXBG8vUFFM+wWCLZwvUY1zLV+Qa
kPpstEeB1mUz/myvAFybY5HknERwbm9VAsW3RmqnxleQ77pO0IvMTQQv/De2
meKEqO5GT8izh/V4ad49FLmP5lvtIQEtaRJncrlvF0D8Jou/pHErap/mfuP3
BVzl/DKsiFw17/vZLyPfxw3f4zjNFztig38ma18XROK/aZ1bvxJ7gOqOn4FL
HVHj2gufq4n93X8JG8FuE+PfkPj7AuL070m/SO4T+tnPCe5zX/HRU4GriejO
7mbVS+S5O9Yn0DiXeZDdS/I46rn0UlWHrJNf/jfN5xMqqt8JXkFejfm/pcl7
XVx2m+KWissPfhJcjra7ltXGED+YmtpSfG6wNlSK1J8o5NG536Qexd1HzGkd
+mLZo6Zf0y6jggvSsgrEz0uUBijfwvmQ68XMjzmo+On32RlkX7ymeEU3WV3+
IrFs9O9EgPsFso/LFptQ/nzoYyLX1n8ZiNNyUVwj2fcS45+0T3RB5ic3iRO0
I1hIR43EyaD2YxonBklrvRfOTkIKdbXQ/8dxyq2075+YUD7CIVeM1B4ERXa5
a+PpVxdRfUvB1XThIGcrlD9umLqmdaDKwLCf6rhYOrDZx+vT5WzeVLH0YCvm
M3oarml2o1W6W3GlNqOrCX620Q50CfIrplGdQuykEdUnFKW+fg593Hd2TL83
Z7CQ9nmzTzUZQJ/s85u7tG/G47eX4iuFWd080G/4bp3NuRsZ4ZXaVbTv8Dzk
kDXwttOmOVEed4bNP8rfpvmUHQD+a677d8qHcegbUx6sYZPTduAR3vJ3PLnf
YoUXyPtSPuGFUXMB1GOn12w93kXqszRND1qXDVegt4BrSyRbAwMIzpUWaqH4
tlXi1rgYwQGybVFrIgheuFh/geKE9R8mtCDPblkfSvPuytPeNN+q3f7n0kzi
8k3iC86TJH7LZ/2lcTtxcjyzNskRs64OhuPXHxB/Ns99lGCT4ogil91NcEpx
xFzKH3LA3hpxohkXRCLDXzt+Bi11xHb9l2mcJ5Yuek3yOCo/6q/3b60Dnlkp
TPO55Gs1MYJXUHz1rnH2Vjuc3XqH4hZl2XcC4kY56JOh5XG/Lba4XfUNxeeX
Nve1kfoT1fJ9kfxYbY2LfI/SOjQzVxl4FtSQevbxJ+K3Bu8SyreM3VDSe+Z5
GaXsEwZ+ETvUtFJe8dPwjgIp3UtIXnYse7WYCfYVmkf5868zb+dfDM9GWtJb
01u2G+G74Uton+hDy6DWuH4maphdv2Xk+1Gcfk2Q9kMfDv0KJHGCCgutpVPt
dXDRiBHt+6cpFGnPTk1Cnze0r/K5oIYFM1dQfcv3zocdAXHFKGh3a4UI31Y8
O9aB6rg+z1rNITX3NLr8bMMPv+jXVf33PKhe8arIdka/eG492BWMpnSMNw8o
UR1YSeLkf8J8W5GvrwG9D+dDhdWgp5G/LUj1NesGV9Pn3h8rSYR4zu2fRXUK
vq56dJ1WUXsNoL97NfARvBda+IGfvleLiU4d9MlKVYIzn243Qm8N51I/2Jts
vQ39BuuTv8BvqLOKm/ot5KnWKeBtU2f96xf4bob4Q95SP9+omxMI/Ndqu991
X1qs0KpTN+m+DCaYPwEeQb1kjuTnamtU2WtM99HOvGo62Xd8WqPtWCCpzx5M
ttB9z06Mpbj2zN7SvzMIzk2wu0njZMfVHIoP6r68Pc5J8EL7AX4aV1dUXoRC
nj0htPpnMMm7dnMTaRwG336SYEviNfdTXYIdid9Nxt00bv97x55Vk+T4/+vL
++wFYGd7fRryOBJRucl5arEjcg7upb+LPO3VI+R3hPSfi/quXuOA9KQO099R
sf5t+N2hmt8314S32KHlq6Lp7+6CrhL8TtFZ9x1Bfpttke2pdvo7VRTSTSG/
axSZn6rXjq1RuOYF+rt2qy8APhHFfjV58pD4bcGIB80Dqc5miOQN1BWYdb+K
+HmXqBXNG7GnjpiRPIPOznGFPIMC/Kf3w77cfHdvJslLyODg0VlbkRES7rlP
89J/fKNHSR5DwWHDxX0DR1H7K2Wax4IibpVBPNtcrL5f6ayDcj/dpHnPLO3B
BZInkaSMhnFdghrS9z1O8+Th8Ni5JK+i/uSKsbu6W5GtywmaV+2cZOOX851G
XSX16Rts3ihEf1pP83BO7V2qu53BrugFOlzvKf1t9opCql9cMFr+5KO7Nlqq
zegY8zecOAI6MN+5fB0HikzRTO8u+l3YUbZqKeCNAl8Le9DXrNaupd8RucXS
C0GXED3HZCvoFOyn9AmvRN+JQn93CdvihxE9Tuj0VJ93Hc9s2icb0WvsTeX3
QBbbdtLvGsdL4Q7oN/yH3Jug/zDx9Bv9Dnq46usAb/v69xx5vSI/lPFJn343
N3niZ8B/CW4QtSTfWWSgE0G/s9quC+YJErwRdmGnPPAKWVPf5dEdl+E7jjvW
i9H6THjhOP2Oa5fJTQNcK7Rb6CfgXNuRaPrd943QxAkEH4wGi96IJ3ghfAon
pJmsgvjGX4aDAVegQw4xNM71fydwmpF4dRt+0wXxu57zHY3b/Ps7tUrIv19e
6/OrmFx3/FCkuMXFryCG4HL0KnEMcA5a1zRCcc7W2LhLBBehkt8uJaZknT2N
cyguOnip4DXBUcj7R8i3jeS99u4+QnHUg96aeoK7kNCLL6IEdyGe+5EUd7We
evGY4DR053wT8OgoomMvg9NmHBUnuA45c36qJLgOrTyWS3Fd7Q9NNYIDUfwj
PZtIsi8rs1ZTHGh4d0kowY3o6syrm13JPsYuDKC4cUbKJimCM9HYwELQuaCq
jC6KMy9veKwEeCO6O5dNhMRJqRej48o96jRdm+CN8zG1AnNJXH3RiKQ4dnL/
0gyCe5HK2iM+K9y0UaCzFMW9Iw+uK/5ysEL9L+58v9g8oGB/kZfi5MMv+qhe
3GpKP14wpRsP+/Wd6m4vuNTogg53ayGjv13KpfEd9It5ToyecW/NdKpjTMkz
Eod68Eis0yOC89Hlu4we7Ms13y+gp3G+UQF1ATpauoPWBfoX3b+DLsGXZyPU
EehYgTatI/QKr7pAf/e+lLwn9HtP+S6kdYf3xteq0Cc7p3LwxolHoeiZoz6t
Uz5I7ZyAfoO3RXmHqUEkMnilSOuaf8KHS4G3XZTqaQ887repOujknPgJR1IP
yr43uk/qJuS+NYnWTQvnO18EHuHhTL1E4BWWFKTROsv9dnTTLFKPOb3miYX6
jFWX5XrbQx2Hp4mlFgHODf9+hcb5+4ogig9cxLorAC80Ci+l+Zw9stxHluTZ
gnlVynNI3h2b2E7zLSteWfHLilvvDb6vRcnzbJIWZMI17eALWoeeENF2JnUr
2m5a+43UrSR/mtK69ZeG2htS56Jlc81/HiHv9WBLOa1zFy4WiiB1MbpW4rn6
EfFD6lRd7Khy4A6po9FtM79wc+K38YzrtI7OmXlmPqm70fe67QdI3Y0WeUXQ
utslqBnqdLRjkPb/kXiYKq3TLULGs0hdj6ret0Jdj0r2WNC6fu5jD7UNpB7c
VtQAei50ufY+5QHE2Gr2Qj24K0xIfzWJkznqd2mcaMYpV0sOJCBz7e6USWVb
5LPiK+UZCtZ5/nMl9aD5+s/ASyDdykHKS1z/8nGo8KAl+jBTwWFNw5jCO90j
lMfovcm9BuYceIo+h8Hcg+bUvMOzrkkR0ItPqJ1fAPpxrdOMbrwta9QbdLcu
sQEnQYfbtI3R31r8eyMKfN3kk4f8k9gTWRtrUh4me4ZNEOjAzl29dQh0YTLR
jB5McCCTB/Q0H59GAs+DjPWfUp7nV10e1SXY/12rAToFpVuTlBcSrdd5A/1d
/6p33y74R6MjDwUpj/ROtsQa+mRhq0VWQN9s40UPyjt1C30CngqnVpZtqzyf
gOyzhihPtVQCA6+Ffx7o/pKgnowkPhZTXstSpZQf+C//3D0TwIc92r6T8mAP
bcwpjyCpeccaeIUByyoa54aH39N6bHeZ7zOoz0Q+zlCHPMn1J3j83zs7/GO3
JsW5ItGVFLfcbIgFXI7GatmGAC94PY+lOGE8R4bHjOTZ2uq2ZMi7X6by7S2G
Z0EHGN4FsfgWSQHrsmKyPtbVyOUV5RX3XNpsZ/M1E6k3GPZdIu9lx1VKecj6
jJDsHsdsZMVx+WIt8cO3zd8pbznZ3wt9UHT8P/0G8Jv5kXeU57wn7uPbcT8b
ydy7NjuM+PmE+RLKi95WeTYiV5OFGvebdTeRfTnlXkF51Die+tri9ZlowWL3
zhNkH71af1LedY5Z2DTl+FR03PQ9+2uy7+jjH7rvtw7mrgO+btYc9uY6EidK
afMor2v/1DOZ3zgeXb74Ja+KxNVN7UjKA8vKlXKmVhUiE8W8nu17TdD2tHeU
N97CL1w784o5sq6+6b0kgh1t2VFIeWbWfM41l1nASyPWnM68h7V0zsGlmZl7
+C+OmXeo3G+4GPTiyuxXFUE/7jLG6MYL+2UfQj/Fm2tNE+hw0TtGf5vr+vcW
6Bdz8tF+0DN+df1JefXVGxo/gQ5sE1vNctCFzQvIoPgqtL+A6mmMg7eVg74m
f4q3fzm4ZjHoEsL0l41sj4tDh6b3U55fNkm8Gfq7b7Uj/kC/17e4hvYFVto9
LII+WVPoKdo3q29hp/2yU44XVkO/YUFxVCn0H/zuDtK+w1uNyovA22odOrkF
eNzuqT5FqZQa9DXwHtMKEeDDPjy2o/n8Vc6fVOARhr+aQR8EBeWVUNwy73TW
cV9Sj80u2DwhRvCsrHQ3xeeCmm+DvAmunX5esAJwrtayXxTfunxpKtpM8EGm
vj7wLuR7K01xwmTXzaKjJM9e7fsDfRy0ejSA5luz6UnQ9yE4Yr8PxO/+BRk0
bjcNdu0SIu/Duh4+uYf2iaRCi/MC2zPRehcnj9nED+ZST2lfabO+7vrf5lno
t/yP+U3Eb4NpC2gf6uO+Yl2ZlVloU1rn0c3Ez/OXdNC+laJoIvS5kGBQ4UMD
si/OL1fRfVmYmAx9MeSgWDhLiuyjx5RekUsparHH0mSUuun9AQmy7/eDCmkf
bWV4bCv0UzaoZfUuIHGy+w3Td9shijGHfRy6ZXFdojrKDS2qF6d9utrR7OhC
0etoos/M4fwVM9S7VI329QrHk/7ppJuirc3zxJ6mTkdYfCXtA7Lmyu5cK+CE
OTPWfBlf2nY6nxO4iise5nXMPjBzOqw5B9bcA2veQUzClerFw1NaBkA/flmy
hPYxjw8xulv3GYe7QIdrkMbobznicoxAv/jYvlkN9IzHpXlon5TLyAj6qvjy
gocvQRdWnnWQ5u22uX8W1+ak4+QPeWdAXyNmvYr2YRuMpZJAl9Bj+vcA6BR+
im+mfdv5+Mt26O/qt3yi/V6ZN+9on5ezN9IN+mSNjftp32wsZpD2y9pv+J+A
fsPQXdML0H+IffGR5vMi3oILwNuu4/WmPK5XYw/FLZla3IDL8YJtdZQPaz7p
SPF54BF3ya5qayzxKe4F8ApL7xnSOlSrwdqgmdRjtaLTIqE+e7IyndZlp/Yr
1SQSXLtj19lqwLl6d1MovpXTupDzkOCDhlw76LOj+KOHKE54eNZUD/Ls8k0m
qZB3s13GaL6N+/vwKsSrnr1XNsTv1Sv3adyaR4V58pP3X69S4QfX5YKGtO9/
VaN6+1ehDBTKeYJPivjNpdKW6gSOj30orstJR9WhWxsEiZ//+55JdQUXRcRB
h4A8cv90J5B9sXx7le7LrmVDMzc6JKMYl7rV/mQfv7v/pPvYMp/qzlGxhrJz
LNn3wbuvqM4hrCRWHfrdm1u4dnCROBEwrqW6iHMPMwa5lWOQ+znRQRsSVxEG
F5h5IjmZnbFiV1H8GzOYn0PTHXOo7sJT6jjvUh0TNHzA/W6q/0xUoF5B45Y1
D8maj2TNRbJf/D1C5/F2N3rCnFlRJTNfFuSUsBfmcyo17OdfH/FE3xEzp7Pi
gKMe6JE+7GbmHrpmMDqTFyWzw0CP9HdnCuhS0KMp3bgXV+gW0CN5Rpw3AB0u
S39r5aa8HPRI/CpXzoGeUfVnHNW9LB7bs5TqwCYkGkEXdmK4iepkuNVHMNXT
ZOZSfY11x36KT+L7Q4RBl1AT8JHqFOI9d9I4j3PZyAf93Rbl5ZDXUeXZKprP
H+x8ugb6ZOmKBrRvJl9sS3HLrDLTawSX4/EFYqALQhXPdCk+T7Sw7Cb1Jz7j
6aAAPK5UmwmtQ62vJD0caLHCwXM5gXdBoxzXKd9io2pf97zFCk2IhesCr8DD
bkH5hCzP86oGpB7T6eBpgPrMQH8/rcsavlh9BT2So+VYIuDcpIQnFN8mffX5
DvjAWXJeAeAFFk6w8Xk1A/KsLH8F6KzQrY/CNN8u/hq1AOI168sBOYjf5Gn2
NG4571WGTRB/7db0DYSr5aPfVMfVJav0HvRIAmLD4cnEzw832FPd15pUxWug
R8q4WitSTfZlV+hdqhMr0B5KAT3SiVkCRspkH8cHGV1Z0O5S0KGh4zdtdkaQ
fe/SYeYsnqQJm4Me6RHbgrJGEiec+b+pbi33zfGy0b5IxO+xaZktiatlmx7Q
uHrQOu4AeqTLPpowJ4oOVR6jurjbOQ46Bz8ZI9s7jeFtipyI3WEFjVv3hrd0
jre7O2k6zPWKTs3zJmQw85Dufi5uMB85r5qZi2w71GwOc2XSw8OtMGcW/ZGZ
L0twdLcBvajfzc53MK+zaFKU6gD991PdIJ6Y1e0Fcw/FfIxuMOP02d2gF2f3
EZ4J+vH/6wxjki6C7nYkPGQd6HB/8zymusSusCB90C+69pbrgp6RpWOsa1LP
Ax2YtPZBiHckFNJG45ylp2Hpa1i6Gm3fRqpL6G9Xmg46hZsVfyhuCT/RIRvp
H43//jWrgn5vvaAoxecxFee1oU/269d+0G2iRQ8P0zr0TOqrEOg3FG+KbIX+
Q0hjD+Vbzmhc7hP+boY5rSePAo+LWxj+VvLx2/uV383QxtfrlIEPW7zbjPJg
H69HRQGPMDx8AfpFiEO1gPIJ+jLPUqAeu8I+uRzqsyel3rQuC9c3nA+4Nir/
Qhjg3Ec1Cym+9TPaoAT4wOTafhPACzdc2yhOiG1qr4E827bteAHk3adrLtF8
+43TyxfiVT3xvxbwW8gcJxq37eFtoMv9/1Vghx7lJbKi5MZmZ11EGsXXzlwm
+5Igv4PqePffTL9SfTcWXfawqOEl+/gyX56ZszApUE2wikZlHLe8z5B9Xx3P
1gb7fmfc2wj0osYja9gDSJzYbP1J48QoM23RWZUw9G1TrNU+Elf/XLipDnlx
oHOE5uNs5MF2ffvpDZYorLOT6pb7jv828OnQR6InEne9/zYTnVVLoXGr5h9D
589FCjsTYB69fWoOPUaTmeMV3e77GeZ6q/iYed4BqW07YB6y1u3hPZiP7Gu+
THXXsz7/NQY9f9lfWzpn9qeWmS/bKux1DeZzHrTfWAvzOl9zmTmd4/rMnIP1
nzXnYe7BupPRgR94KewOenFN5ooe72Z04z2RAqAzx8fLEkNAhyto8YTGOUu/
yNIzsnSMmUt0qA4s/7ZBE+jCGsoP0O8jS0/D0tewdDXHpqeeBF3CkuJcedAp
bJ/SJxSPNz6H/m6LcP4Z6PeOzxWhfMuFO6gond8Dn9g8+zn0zfa4KFBe8dO5
yOw1YibYnXdbKfQfPBbyUP6cLXavvqu4CeKpOHIKeNxH62ZQ/tans2gB8F+R
t3T2AR9WkLiO8mDp714o/jseiEosX8IcAeo8vZfyCebxY3rNpB4ziH9M6zPN
V6W0LuNXXY4B1+7VTKoCnCvcJk3f62pRMVsiwQelKUtgrgHN88mhflhXfmMd
5Nkf7xRKwG+Xntym+Xb/Jzo3gRzN5cYhfgMDttO47Q/gPtFK9mPphjkwZ4GO
WByhcxYLPo9m3HOPQuaX6FwG+sQvTOcy+EXYAssWRqCg8oXW88i+236xonMc
h+R194Kef8ZjOveBlLa40rmPIW+Ni2NPApHp/pWvnpO4+vqhmM6J3JnFYVBr
kYGW7TAdz3pvjupn7KZzJSG/xnr2ih9FTxbbr31eNgOJL+mhcyhinxvouQmz
n0gtgHMUgqfOTzg3W+w2zJ//N7ZBHObRH43y0DmX9lMqdI73zerCSJjrLWhl
5nkr+fq5YB5ySbDzLZiPZM3RlAUxc2XSYvM3w5xZwQQzXyZlNXAa5nPkmCtq
imPmdEJvr0+GOYcFCTffwdyD29FPTJx7KQiBXpx3Gq8C6MflZzH5nKW7Zelw
WfrbffIHt4N+sVbykBboGT9tZ3SMr1NCOUAHlnNqgOrCkjQv0/qlSW6rqnNH
EP4ZeBl4F+R0uonuu+IE21vQJXCk9/SATqF4Sp/A6u+y+r2sPm/Lj26Yq8Kb
TBYUQ99sS8di2idyFyqZtRkZoevrTNmh/3DAp472HbzLEla59Dihk3PW+QCP
27c+gsZhs8SVvzHIFzU/fwhzXv/nwQQlekaARwheKAVzYahjez/lEzJG7L9J
knpskRIXJ9Rn+5fW0veKsHhEce3FXVpzAOd+MBqkfrgtFWoJ+ECy9SfFC6Gq
DE5oK53+AvLsp8103gK5/WTy7T3vO+MQr6+aI3Igfsu2LKRxu+d+SsUDsn9x
P9puwFVoAzM3J/Yp3tGuJgj5CnFJypB9/8DLzNkNmHD/aNLyR5M/lq8UI3HS
6cfMQTfsjLpWm+6LTj3Juj4R6Iqk5Jg5vhCjhwkzCpKQiuR1ON8Clb9aRef+
VuQJv1n8nw4qctdy0G3kQI2hzJwg67wP1vkfrHM/Vn2d5QznJrSecRaAcxQy
vZnzEwwTkvJg/tynonQXzKPX3mXmFv/JMnO8OQr+62GuV4+fmXOcnxn6COYh
l0iZ18N85KgJMxd5v+/9FpgrO8BbTOfMpG2Z+bLAxiI6n7PDuTcF5nVsTzFz
OskRFK/gb8pL+GHu4c8dBrcc/qZ5FvTik7FbXQGvybn3UHzuNvhpBHS3BnLi
J0GH+7uHqUOXnnlB9YvOc67kg54xwnGY8i3OeowOLI/Tww10YdzGjB7MpLxr
HehppAZlYS4VvRveRfnzyZYb71+q2OEL3slUpyD2b4j2iXLrD20d/H4UN/kt
VIN+b9oPYdoPZVMcon2yWREb9aFvxibD9P3XcdsnQr8h+eqoBPQfjnN+ot/3
Ffd2PAXe9k9F+0HgcZOMGf62JOfWp2ZePxQ+8YMN+LBInTG6zjC3cZjzRW9v
R1JeIeJ9AeUT1q2lc8HoXPRV0KH/vy4L9xiVB1yrZOJ0A/wmqL+E4luX7Hcw
R4TcUa8G4IW03f/oPJGShaAZ5Nnzt074Q97dp3+a5tueDjlZiNfha0z8dtx7
Tvfxi347rzPZ7zgeEZiDRobci+gctPvtymswD/s3V3N7M4mTnc+YuekggVd9
PNWeaIM5Pd8C1f5roHPWPcIvFvkFxqFXEXbrREkcvsQn6Vw2F79X9+xwDTQc
rcG20Ycd5UYzc9ysc2qk+CpV4dwa1nk1Mb7L6HkfgTcjZsL5H0FHmXM/0hbn
h8O5CT/zFrJFqNijl13MXPnXXQodMH8+fX3QU5hHd3/FzKFXfaVz6/jsulvt
8B6ntJk4/5HIzEP2b6R5HSWPMvlcWMppG8yVRQXsVYXv0thSZr4sUnraU5jP
eTw91Rzwl5voEoq72H99moA5B1FrZu5BQYepQ9nT/ywAvfidifVboZ6u1WB0
4yv2GBeC7va58r17wBsV9K6nvOK2FRKpoF+MXBw/B/hRoTWMjlFrvwkCHZii
SwTVhb25qk75/yghYaqnCT4xwQX9rrJhRleTXhQonWKvg/23moVBX9d0BaNP
kPs9+0GFsw5617CvGOxhWrdon5fVJ2P1zVj9Mla/gdV/YPUdXpfdE3uMPdG8
/OGdsM6SQV7K325p8W0F/uvb0RVv4L38l8vQ37WhdgKc24D6LYK1wA/DW2ro
9251f+o1qMeSJN7Q+szkD1OXbbhpxwG41mPnTEPwMwvfzjsq+wrwweKRBmXY
FxZOqCo7uAby7IpvNsOQd1lz0Gf7nipCvEY/H7kO+74ph4lbyfnyzhAfnV47
HOA6ayNzroVIRRDb0E5ntLrzoSOczzFDjjkHo9JlfkMXdxS61mYwpEHi0PTo
DnpuxqzCfjW5ayro/pKPGWtI3KYpM+dsHOReR89XYp23xDpniXVODevcGtZ5
NTeO89LzPh74PKXnf7DO/Tjyy242nJvAK6J4Fc5ReOrMxPnrW2vhXBFsGszM
o2fNY/J5Xgwzx7vtVmUCzPW2tjHzvKG/HzyAeUi/rWlGMB+ZuYGZi/xet/sB
zJUNHmfmzKbvYubL8lyY+ZxZNX8sYF6nuouZ03HXdGuGOYfiPGbuwcOKmXeQ
MgqUB734ngZGP67FzejGIz0Y3W3q6S/poMONFmf0t7Iqd2+AfrF72sqZoGec
G87oGMc5ZkO/H2+zcvIEXZjWnDba9y+/HLYq4IIavhaaog76Gt5NElTf0lYj
YfwkQQ0NFC+PAp3CoqWMPkEz4iIHf5EpqgmpYod+b1xUFO3zztm29Db0yY5Y
MH2zqq89tF/G6jew+g+svkP9Z9ElwNv+4JxLeVwu9hWUv73pnc9hy+GJwh6r
/QQ+zISd4cEW71XmBh6hmVe5GHiF2w8YPmF7l+g5qMecjIMFoT4bymDqMqUc
qS7AtVfXcyUCzu0NZvBttMKba4AP9t/8ng94Yb00gxN2Vj3kgDxrVVbZC3l3
vhBzrsW7PEVniFdp+U/sEL/eUkzcplsIXKgptEXuUqYRcA29zJxTlBt9dFjh
XDDSNjid+muDIVrUy5xrxDv2683xOiX0MOtKu8a5vwq3IplzkCzb8ui5YPMn
Rc3gnDDW+WCzgq7Q85VOTp23dM6NOWcp9fXGm3BOjfid8T44t6ZPizmvpvGt
NR+c9xE1df6Hsh9z7ofmuYVw7hPm5bCl5yh89GfOT6iT2Qy4HPuWCuTCPHqI
PDOHLuAT+A3meJ9oMnO9l+4x87yseUjWfCRrLlJoIzNXtirjL50z49Bm5stO
K0o7w3yOHHc2nddJt2PmdEbbmDmHb/g4nXt40vGF9okc1yrAOVqYK6iDC/Tj
GvWMbjx0+9Fc0N0+NOumOtwTCoz+Vk/87wbQL7pfiKZ6Rr05IlTfonuH/64w
31as94XRhSknMXqwpBINOAcMnQpg9DVNpxldjaLkk5WgS5A8sY/qFPatZfQJ
O+59ov3dV1rltN/rr8j0eaVjh95Dn+yWUBjtmxU8Zvplm+63wBwRcpxk+g+7
JJi+A+8Aw9uqs0+nPG56HMPfxoaHLQH+a9c8CUfwm08aw4MNrGlQAx7hlY/Q
BeAVChwZPsFwtukY1GOxHiX6UJ/NFWHqsoOcitsA14q5qlGcG/KVwbcfutQ3
Aj6YxblfBPCC91UGJ+i3Mnn2cZYkzbvtuky+vdT0KI3G62dvGr/vupm4vXup
f3rbJ4f/XxsPMOfOXVhyxF1HbB0yOc/VeZ1dAN1sYM6pY51nxzrfjnWu3fE1
5vRcMNY5YazzwQaaP3fC+UrHLtnQ85ZY5yyxzqnR9HpMz61hnVdTN3Xex8lL
K+n5HwJT537IeA8LwrkJve1L6TkK1lPnJ6j1f8mF+fPNRR/oPHr81Bw6a46X
NdfLmud1eD7NEeYhj6w/TOcj/8xj5iK77d7zwFyZRt9yOmc2OjVf9sZVGs4t
xAE3Eum8jszUnM7yqTmHo4Wr6dyD/dS8g9CUXtxlfz7Vj2+Z0o3nTuluF/Lk
UR2u7pT+VlZq4w/f6NdVt17spHrGj1M6xnHLZ3BOo0L2DVGqC8ua0oM5cbjt
i28eUFg7UEf1NXpTuprUoeJroEtg6RRY+gT1DUpnob87+nm8Bvq96lN93p1T
fTKlpCjaN3sw1S/buFSkCPoNl07uo/2H8qm+g8MUb6uy6zTlcWdM8bci3GJ7
gf8q6BE1BD7MdIoHm5luJwM8Qp5sD+UVVk3xCZrxX5yhHrvILU7rsxdTdZme
fR874Nre19EU515m4VtNs3TAB+5zRyleYOEEVp5l5V1WvmXFKyt+WXFbEfB3
zbbyZwqsK+sc0XFD76iJ0l2YdT3/wdsB7GcXNW/S1Z6Dd4xaSGu5sONPq79N
gl1FIqz7lf8uFH36RnyT/y4stjfKGewHlh7VlS/lRiK5/YXWkux4S9wv+vfv
VpTTv2tJSKf/jvX3/RtDCjeUcuPOltg/ZyXZ0ZKpv9/p6tExXrrr/9exXmY9
WY5f7TRd2JHKIpWX2tpz0BwZZj2s9bHWy1on676s57Du3/jjM11fpe8Jul7W
Oln3ZT2Hdf9tYT3NW3z5MOvKlsxH7b9i2Piqm3jRcvNjk/eaePHYnRXU3n1Q
mf436/+z7Bzbvd9v8uX7/1Vh6j7jRVf4eHgHqxbLx9TcPfOtKnNuJ92XFQPB
DSbFvQrl8e5px6MHqgRvdVG76dZgD9Pi3qr5f3M2HoseUBCasj+58Tmdm3dQ
ga1wYs5/Z74pXJq6D+u+rOew7h9kWED/vcwSR3o/1n1Yz+ttcqTPZz2XdV/W
c1j3P38yZHfL3mk4K09kLsfDXThG/HA52DV7RCz1RU7h966n+N83BGDl8wsr
fYndMebCHeFINsxWdPG+3m9VvCH/zxr4e30OXt2YjSfx13cb1oe+jcHCndIZ
CSRvf3XQ3//u8nQcWl63uThPF/9Y5ioNv5ewEalWk5tmeNlar1eysqnYuCng
XDv5XnjaJX8xYOfEMf4aiiGLDHFGzC5H+D0+VmoP3HrQEgftFPS2uJiDJ71P
6/+GOc3Xh1uXms3E8cNR05ucTbBsnbsA/N65pt/5fDbNArek++dt0r6Kr+vI
agyM9CPucxfvC/Sz4/WW2ubzTM3xrBRLO8gnGTcjuk2LTXBs19FDJ6wKcbl4
8Q5f8t2suH6ZK35oqEq6wHzdPCErvDlATR/yVZ74rl1J3bq4NuL3j6bhIrzM
6uh9tj7yHYmUXh/f7F61YEVUwir+03ity9ELkPfOLfoQ+vzavapSxx/CfnHF
WG3x17XwfV/2Lzlu89iQQnWoR2zQIivcuVz1ONx/9Zw818Kvuijey3Ckldw/
Pp23DO7vWMund3eYHR1YPe3IPTNzvFljrS2s/9h3x5drSk3Qm5Wqg1Zk/WkP
bORh/fnTDq/cdGYmWnd9JNTLxQRPkxSg/hk+YfjueIYFqj6z3Hob8c/NxFsH
wD+Hzhf17ZrJiWRezfrJRvw/YmFM/R+w98CBWlVLZK9x+LMZ8X9ahCz1f/3c
G4Y38qajIrei8PYruvihWB3dXx/fuYF7y8zQqrdrd0iQ/RX9sM0W9tdh/jzR
xkg2xOa24Hn4T1Wcu1thLcRPu7Wvz5ONJ5H9SiMtDxI/bTsFsyB+3gZzBoSq
T0O7D3t/dqrchW1s02h8fuWRsVu85BS665y6sYDE56E1tjQ+Rb8XSVcGOeO+
jrYdE1Hn8AwHvVfPIA83NSdpaTniVI5nR/ZouOPzGwP+3iR2r7HOXW4Jblgx
X+SIqJ0/lj/y/cBpYj9ZL/84JscTd9rxss21C8fnpN48mQQ8X1+HlNs88A3d
Qp9WixhcZso96ULsn+LMVxgtcsbzbU5uOScWj8XqwnKGCc6JVHFfZVVmibn6
l2dIlCRiK7fq4lhi532nqmnnm10lWWU4vjw1Cbt9/MBpA/OJhvKSxWWWyPRP
jt+P4kScba13F/7+2a81g8mLnBG77N0nKuT+ppn+V+H+zW+55gS1eSCr6e+k
68l6djgf/gfr+Wp6OPxhjifq4hias5isv3zo9GNYv9Jik7sJCW6o4cjfgb3k
fTs4PqrA+wocVHpxVMsRbfG6O6OE+Gci/O8o+IdH2vaJULAzUol/J+sfcw7/
RvUvwJ8CGhcfaX47j9/GpH88vskWP6qy+6+Y2A2ulRtc5PTA6ov7azc+9cQd
33itEuB7dI4/NsbDBwcqutkc0wzEj1sN5m6GPCxUtD7pvB8+4yTh8ZwnEh88
FNdxg6yzWuW30f5xXyx/7GnphkVxeIbuufK5wJOfXHBT1+w8PnVltbCPTCK+
xRFz35P4QWa+b5Nyrw1O3d+nfmg0GV80kzwlSOx8oVkWVr6ZVc3z4sd3j6bg
7reROoMkDi88keIw77VBKsNfReHvr3zoM4G/Tzs8oR9mdh59lskd8Cb3ryx5
Vgv3L+c9Mtds3BftEFmeButxsD95B9bzuTJ9btF5P/R2NMge1p/6vewDrL8g
d09GhocPUlD76gPv+579Gz+875tjRwpSOD1Q3rOfSzcR/yi4/LYE/6Ts5vov
69t5JD5r1xM94s+k7s0V4M9BidxPQXV+OKaE9+GMJQ544yqPVn9i51uVsHRg
0AdvP/FG3t7KB/9z+JtnArhi/j4NJdNA7D1h4XRvYSj+ee3sibdkPbx/Ps27
9ScY9xsPXOqUjMEOiYrKi6Bv+Fm5L1U7GE9E/ihL9EvAaVXd83aT95U6ejvO
29UPb/txNf/svlT88HDwAR/it+6o5U1nrjtisz9li89eyMDjXirxk3/Jd+q/
sraG/Iyq9wW7UmFeKuFEQOkLYn/u8U8y7LojMrxTIG1B/r7h2doE+PufnWW8
ya5+yKyJW9WK3P/6LA16/9AtE3Z3tINRm/Q0owSynu3jb+bCei5d38VT/ycY
tS7eI9ZF1u+su3gvrP+61PN2ddNA5OAhLvaAvK/eimJjeN85WnWrhgZ90Jf6
zEln4p9H7reof9hUcrML6/zQy+R+roXEnw89X7aAP4VtnWWm1QRjzrdbOkfq
nHAJX4i6MrFP2AQ93eISiH9WKqd/rfDD+qkpdsuI/ea0k/W75oTj77krBb9F
ReDkwRFsTJ4raxx723BfJObstrvnFxeHf5o8qTGB9Wc4SSKXC5in8rV/6ZVk
HPGuz0yLvK/bB8/uv6bBWHvGv9MTMzNxXinvcXPin6+H3nlErXLHSyt5Nt3t
zMIxRj7dL0mdJS0siJXdU6pyLboXwvyZyLOqXRnEfkrrmm/+KncUtTjn3y3y
9/u6+Xrh7w3F0+fPMwtG/35cfT1K7l9+5ym9f/bnz9JHXC6gPaXml4rIeoQ1
FtH1bNKX6bfdF4nuWjz77E/Wf7TC+h6sf5jP/8rBOeFoFH/u+knet+pwbxW8
b8gPlxPbXQLRmMCBziHiHyNlYeqfBdLHPorXBKOuN9uOLHrshNO+e6mCP2+O
WfbaqF7AFwYPvKwbdsHN/KoXhsh9nDon3wj5heEdhm7nzdMC8M0K/PMZsb9X
/1Z4QSYae/w65lYqH4Wzf7xLaiTreRd+oLBgVSzWH1TenRARj58sGVKKI+u/
c2X04aGrMTjM7olw2MY03Nq+cbs6eV+1s46X7LsisM93xzqZ6CzceCukWg30
qyJ1DmLZ3rgz/6/hl+QcbG785dEd8l3b8nxPSGJrXFWMoct/MM/3b+miqyHE
vs9txb/V2d5or+sj1ffk7/NehPyPp+uO5/J731Y0pGgYoZAI0UAo7lTaIWRE
ZERZGSEre++3vXdlJCVKxgkNKiqphGiIlIqmlPzOOe/v59c/79fr9LzOc5/7
eZ5z7nFdlwfk+u/Ic3Ho2zi40VOvLIXnVzArbiXzb/uTeetoGQM0JbsvhWN7
8kXeqxF7Pq3n6boqlQw7IIUzE9s/G8HQJPY/3szWypBLgmfL7kXU4/We74rO
IOvd1CFfLxQSAwe0D5/2wv5RPvJ7kvhnnQjPaNSBeBgNWr+d9ccZ9MtKLJb4
U3DD57MiYgyUuKpV67OpDzJfu3swBo83jn+P3nImEQV+c1iU8TQcdX+TMiN1
V903ypeKE1PQiiHxfG2RJJT8K2+hIr6v85xtRikTaehucsK2bz3pyMjodHg9
tt8+lN3lhUkasg3Yk683mIfc87t49fF6d9/09gkaSUKfFxZvXZBUhLYf7mE3
w/4Bv0jju+Mh6KJeUMHD6yXo4PM285Ep/L0c8uDKVwtr3r78kuFz/1Kkyldf
dBePW+85XPtgPASqTvzpuIWvz0tPOU6ud8/OeBU2kgQqF9262fH8e7+FcpH5
nb6HwKBJGjjMDJw7gO15sfsEH7FHbIU5e8ZEGvyebr/yA9s/IGwURuzfr/zh
SmliCiQeaq41xOs1E9/MTdYrrVz2B/sHXGysNC9i/2w9KWVK/MMZHt4mIcaA
1ytnY1TNfNDJdocB4s/AHU4erJtT0Q1th6W7m3zQuoOCCuRc+Br688Ob3clo
w+D+v2MyEUizeQMrJx5neb8yZ/7SDFRcp6PUfTQJyS2rPR2Pn/v3ZzzHGANZ
iL3kUpqHQgYq3CAm8g7b/6q6o/mWXBYS2SzQfMQgH1WrtVb64fWeDoR+tl8p
6Gr9/fmhvUWIR4lv9gbRp5q48djTMAJVnLJ2mZ5biqyFu/ji8PjU+LyH2f8s
NKZ0ZVKkCT/vgLliAh7nf6W838MwAn5N7Hb6hK/PyDy1glzPdVZZHc8PrUtW
rfHF818XtOdowOO8y662tMllgURf0EV9bI8D9+UqYo/k3D1hSQNZsD9kMuIM
tv/rtZvCxP7r94+K4/VC0p+Sj/14vWWhPu5kvV6f4xuwf8AlkSeXXTYC8U4u
YiH+cSxd/mVWORXSD9/aWoj9mZ0mJ0/8eU3jho7Jrgxk4bJ+46Z33mjZhvAb
kYTv0H5o8wxvGtrHnqsY7BKOUswOfc7C47tnFjmmJmYj+RLn6aTuRBSZ/Gt8
HD/3IZ7CU0ta8tCSD6YHRJzT0U/J+kppbCfXewXOpKlc1BKoDZeP4P8v6Et6
S/jjGfe/8LBlIIUvN+cMbi9Cf/sC+yPxuKdNdKjOjWi0gcv5uqNVCfqSf8u/
C48PHq+KuyicpPFljdPR9NWl6NUj59Xs2D820/1GWjeioWdotbc5vj5d1CqC
XD/x5eBXLrYMaFZvce3B8x823PuGzG/d7FIVNZULV546V5Rhe44xLFKJPU92
fjy3sCUPyq20k1Zh+436Qy4S+6scW3kZidkQ57q8Ogev12B2N13v2V8XjP7y
pkGc4bededg/Ur+3fiL+Ob1bbFh7VwaMrVBYmIb9+XTNtgbiz+AnbxYPSGej
s8+eHbxX64VmtV8v+UP66RXsfyJrMhCjoqXMKjYUPX3JJUO+l2m0pyyhLw99
d2hfPvMwHg282mV6BN93cKrDsEC5EC0qWfI33yMVrdb1KkkiOCvuvLyhOwUo
z/2B3UBnNrJdMrw5Ba9rj/pG9bTXWWhpVXVT6Y0CpI2UVncSHodMrdOHT3FI
cPPDu4IXi9DakpVbK/E8anfm7t0sUqDhfKNBVNGiGHHXdlmKEz3Digz9F5/i
oD5A22IBvl5TIlqLXK+TKaEV9ToL7J7/GMnG8+sHLZMj84sKCl/qvVMAUZVi
5T3Ynvd5yurEHtue7JYs5UK4cXaHYzG2fznHu3PE/vw3W1Wi+vLg2e5dLXyP
4lF4bjhd74xSrkVETQZc9jH4chb7p6BOcS3xz0ZRHe126WyIVPU7sa7OC/1S
+rSc+DO4f9cmq7pcZBS7PzFn3Wn07+xoOOkLF38Ybn/LlY2W+bSraPgHoRN/
FtSRvvAGQYGF3G8KkHJWcK6UWjTiiBf1HSLvrXVdxrdnRYjPSHmz/04GerBh
/1NJbKfG0133xY4WoRsPH/a3VqSjcu/wEYKf9xBIKPRxykXbBXeIfvPLQf65
+rdd8fV7tg4YaVklooCtZ+VyuvKR/JvvfrN4/mPP1gT/NjuvETPJNXdtQAGy
EjqzBuH13jp4ymmLVSJwuy02CcbXd70uDSXXH1dYiOyccmEy5l7zazw/S1Z0
J5l/12q5JP6jRXDtUFR2A7bnyaumT8QeJLfG++OzIph72VErENu/4GHJC2L/
Xu1ae643BXBQ1NF8C17vYEWcH1nv9rF/Hq+5sqFtovevEfYP9/YLtcQ/omPb
I7XqcuHfwXlffmJ/etyuiCX+FP/0MiO8PR+t8RcKWfTcGS0arK8l8afC5lG3
gY85KEmnK9OxwQfxnzCrJftS9nK/C+mLi5Cu6g/TlAWhSKCttT4I33cyedhi
XLoE+Z5O2zU0HoM+n52f/Abb73Tguzz7+WK0+9StovUCDORyiO0t5dHENrhz
BOQjPzu1v653U1H2Dv81Wniei0I/PGOiklCAglzzlUMZKMKnpMcP33feiXtH
ipouanxQWMrPr5aJpEdSgkLw+5MZUVjsF5UEu3nae3Lx9f1bzvWR62vyjhSO
n82HyafuddZ4/kr2Dnkyv9PWbt2f54pB8gR/qQy2R13m1kdiz6BhB98b6RLw
eshlMYztl+bfnknsL4ydbUtaXAQl79PNSvB6t9l7NpL1VmwbDnrxMQd6Ey8s
T8P+8f3kS/2z+GiculV7PnQZbztWiP0pZ6vUTPx53fxmt1R+ARJfKO6z3tQa
7VDZdYPwmxZXprdu0MxD1x9LzDG964IYznJ9R/A8SjwcT/69K0Ifsz0ecMh4
o2mrRu0d+L62XpuEjPlLUfOXo67BEUHo43MnVoLzNLnatKQ7oQR5Z0W+fHIt
HOfjHHPJftg4L6vc3qcAmUXzOt00jkER76sjOPF9m4R4/y44wkB9AVVPb0fF
I6uYqpnb5O9E2ObOs5mt1hjfXyM+ejEBLRUQ459D6sxlolIzJgzo+NKWXEGu
FzrGeofoUCl1jJr5FMDuuCsml/H8QjppCWT+DQ8ad7cllECZvm7fA2xPyL/n
vMSe6nIzlQP8pbCy1Fo8HNvvILR6HrG/U1+Ca+pdEcRPfbYTwOsV/xCsR9ab
F9flKK+ZB1/Hy9+exv7xXnCT+mfhfKUXfPkF4PVp9c4Y7M/ZRz9uEX9eckuQ
6JgtQNWZE5xmjvvQKp/3wr5E3+nk6bWNk3nIh+1apP9bQ2SuHaqwjegb95nd
OmpQjFRSzm8+tNYSzZjfO7wa3/clh5NZOaMUsTwNzWV7b4car+lWVmM7T3z1
GFTHcUCzOkvCs2ln1PTySQ8n0R9mHbVa01+ANLNSjLRL3ZDUZJ+rN77veyG3
eRO3Gaj20W8+s+7TqMDu6qlQgveQL1oR9rBcQ9pucVd1lge6NTW/5w32swzn
Sbe3txkws0I482TPaeT5TtGRXN8xpe6wor8AZtfP2331nBv6OGBxmszPX2fE
s3FuKZTO2bpl+I8zmtuf3E/skY/s/FvAKIVM+Vj1mFE7tFRs5gqx/+O5YmNj
g2J49+Eyyz0pS7Rq9VsTsl52udyA+sk8qE5cWOQ1ZIi22b1eT/xzNq816fps
Adifs+BXMN+HONXd1hB/dlZVhuFxJMG1lmuz+T7o2HaGjs8aOqbgedCw8jsx
7yFDWC80QOcxYBdywvdFMUsNee9IWcKyN730vtvO7GMrxH5eM3dFc+SoHWzc
/4fa+byN6+8GEp/Vmh95/8cZtN9n03UVhT4/hv2AvBX81lw/5wbWOmbUD/0x
N/Ox39CWyL52x57TYPNVkvrtSum5FWFfyptz1Pm1q7I84Md1XurnjmNdPvi5
QIjTnSvm3aehdTKHPpdjdu/Jc4RDcHPzwVI3KE54SZ9j0yORTvzcITvApPrR
tDOE/Bymz52rEQ7j9wQOVH16yfLeDiQGDel7wrn9RSN+r2B1r8QJ7bWW8MHh
EX2vjjj/FMTvITCMjaQD3xqCS2oEfQ+v3uKWxe8tmLDJpBs77gOvymH63irK
ogf4PUeOJjMPo02tYVHSX/qeX1EW8cffBfqpzsXrcdcFRB430O8iMTieD39H
yNK4dwm/jDfwmwTS7+jbfJ39+LtDtVpcTmERQVD3WIR+d8Pm1lL4O0Ub/ead
xN8prO+ZpN+pX2foOP6uUWx5xeNq4xh4K5FNv+sbFxP6/powkPNMwsbKqHho
zbak+0DZ6jfm1vyXm2d2OfrjfQOu+Kyg+wZL/5967iMMsPs0/+EdfP0h51C6
z2yIfnAX70sQMm/N41Y8//SaILovhY/cFMf7GNzuk/PH+xjodPzjIva43TJb
gfc9WHVw3uIQbP+rYju6760q8e3G+yT4OcvkzcHrDVx5g+6TS1we1OJ9FVLr
Um/gfRVMptZR/0gKDwzgfRhK+DYu24j9WfgP6D4c6D9PAe/byOvy1vKC587Q
Wa1K92351OA0vM8jS04eWbzPgyyLF93nlfqt7+NzAV0Wm5bD5wL0CZ2m58J+
SXEJfI4g+6gT59+Ox0BClyY9R6Jt6nfjcwcFzB1pxOcOnLS+Q88d6RdLQ/A5
hY5FLZSxuZsKKzoa6TllcK8kCJ9riG/rvkx8roHipjp6rhXmPJ2smals7srz
S8LnIMy57UfPQQuOHiV8boLqrZE9+NyETVfa6Lkp1SWdj89ZGPzUOYXPWbCQ
cqfnrOM9XzF8LoOLxe5GfC6D2AwnPZcjhzLs8DkOKnzJ5ByHwOI59Byfn+RZ
is99UNuZFIPPfUjKYp77J0IeWOM4ATKQSi6OE+DaHQvqH/M1k1U4rgAe2Zh+
HFfAAPdVGldwsqh44zgEvdpzqxrHIfDq1SUah9zpHAjHcQt6euE5iVtg5HIJ
jVuOf8w+heMcxAgf24njHNCyiaVxjrR2aCiOi9BDbi1VHBfBrd58GhdBhwyJ
o9ASv8rzOI4C76IGGkfFi0h8xXEX4pS4IoPjLoh+mk/jLtlWyVAcpyERJyEO
HKcBn+B1GqcdWL7y5Kzc+Wb2KL1/0gEF4C3sT+O67plXUbtwXHdt7fJTOA6E
ErEmGgfqcDncxnEjeLncl8NxI+St2kPjxkerFOpwnAltsrZOOM4EUa7zNM5c
ZXomDceloJGj6IvjUnjcuZ3GpeuXH+HGcSygpw15UmS9b5hxbKPY9gYc94LG
gf51OO4F962LmHFv/9WdOE6GzTfOtuA4GYp+vqFxcnvSCOC4Gu1/HByO42oY
+viFxtWbVAqccRyOWEt2TuA4HETubqBxeOttbnUct6Mll7Ie4Lgdbt8OpXH7
xYXe3TjOR2/bOLVxnA+NbK9pnB8m8Twb5wVo/ibzdpwXQLy0Gs0LeramB+E8
Av1itevCeQRMlzLziGGlVJ4+nKdcNDC1xXkH3FrqS/OOpbf8R5RECprlH5xc
gvMUKEx8SvMUw/l8MWM4T4k56NmE8xoIndxI85oLge07cR4EBX/nn8d5EJSz
bKN50NsbX1Jw3gRn03bp4LwJHvl9pnmTQJ2jAc6zYFv8j5UF2P6GRDeaZ2kP
7iB5GRyq7LPHeRks7dak6zW1vPMT53EQs+RKJs7j4ITBPJrH7edyEcJ5Hxxz
tNmD8z5YaTxE874arj/PcZ6IPBo85uA8EV7Gbad5Yp9xnSXOK5HMgpVqOK+E
F3VbaF6ZNdEpgPNQZH+2nOShsNduF81DvRSSqnHeipZd2leD81a4reNL89aa
f0smcJ6LJB7HncZ5LnBtPkrz3I/mC83m4rw7WCzdBufFsJhVnebFBe9ltu3C
efey/R9CcB4NB0R0aB5dqn8t6fpAYnPuPi53nHfDRMQxmnc/U06/dxDn3d7V
LRU4T4cH99/SPL0uN9cP5/WgU4G4cV4PZb4Mmte7VqWsT8J5963jCdaXsT0j
y9ppHWB8Vi5yCc67q1YaOotg+xvmXKR1g+JZTrtUnHfHbnvIwsDrTelm1hks
ZYvlZ3Debb/0tl4w9o9PFLMuEbLI4agJzrsT0EH+Tdif27+E0DpG/LW572aV
U9Gix3s3FTb5AKulPK172Lu33CN1JL3Dy7PZZSOgtmkhrZNYCc2IkjpSyPYq
9oGjSbBu2IvWVU62rYlMGshCvtO2jDMKGeAq0UzrMC1GOlVtclkodSKhQt8g
H1zO1tK6TcU2za2kjlQlmqHg21sEfBdtaJ0nAN6/OG0YgaZnw6w+4bjgTa8v
rQs5jhVLC84ea17jMJst/bgUXn8zpnWkJ61CmzwNI2DV+nbzaXw94/MrWnfa
fOkXK/uvFPh8bZw9FM//6/0iWqf6N8tafksuC3Jq36cdwfaUL31E61rHlx/d
xxjIgsdp6rEe2H7HeilaB9v87gWD1JFsZJ0VuvF69xdco3Wz1m/vR0kdqSQp
bMkHmQh4v4ZZZxv6sDaYdXMq5FTJyOzG/hwfXU7rcmuTf16XEGOg+yv901XN
fCBVzInW8W48XjBD6qJWP54cuvg0HLoD1tC63+Tng/WliSkoIFKO1AlhSl6Z
1gmdrThYMybS0OU326p+9KTDwDFjWlccr0icM2iShn7aClw+MJgHHBOnaB2y
RTGLLXwkCQkd/trBnlQEqavCaN2SV/BwUOd4CJLo4+u8db0EEkuiaZ2zm9e7
+r5PqEaVxD795/6lYH6kgdZFS+8O/r07HgJntnbmPsTXb9mAaB21eJHh46CR
JFgqZbx3AZ6f58FNWnct54/xe2GSBgESFiV62J4sxfu0Tlu31UA/ZSIN/mxv
UP+G7ddkeNC67r9PIheLE1NA46trjjZe75zyfFoHXpZU6Ufqoh3il1gysH/K
3WRo3bjmk0WUiBgDHDYJqX829QHx+1rMOrPZtSdRB+LR0qNN61h/nIH2u+K0
Lp2YP3NfKCQGCYQkO3vlhkFV6hStY49wlbUw5JIQer2W1L1h9DOz7n2Y9+Wd
q1LJaGH3UvbMuDTwVk2hdfK6cw+bj5YxkON3/dJwpVzYYPqR1tU/S3nMhryN
Q2xPVFWlkgrh83QRrcNvSTEOlSsKRKA+pjGYVQw3/sbRun3+MVX+/IYUjZZZ
vyrCwzpiKU7r/Is3rt4iURQIl3caHRvB1+sLDNG+wK78zpvub+OgeF1dmxye
/1F5NO0j/JHb2G9QxoBPF3YLxWB7xLs20r6DAqtF+UWpZOg2vKuWju2PUPxB
+xSrDddWxsslQYH0EdLXANMD/bSvsSKt655ASAycCPvtaYf9s73lJu2DNHJ7
TrkciAerMMnm9u9noMlrP+2b7Fev7pFojUQs+jf3CXV4wtvKQNpnGQ02st1y
JhyxLsh7/e1GCOxbzuzLJH9nXN3PHYtU7VoffU2Mg/BKZh8nx9BwynV3Apr5
+WIgNCUFQrNP0b7PLqvBdUZn4tE3rotZ1eeyoFhamPaJvg9+COe1jUSaB28/
+c1ZAIGfntC+0g/ZOfEVUr5I/6nXj7o3hVDpsoz2od7zDSUc2pKt8UH6Fw/h
B7n9baN9q/myyfOTpHwhfYHbukZ8fY12KO1zud0/1vvneCQkuQiRvhhcGlxE
5ze/+1gEzsRDWP5W/xpsjyzfJLVHTNioy3x3AmyWU0IhROfBrIP23d6Xj/dv
446FLq5a0qcDy0XMPt0n1r52lTPhcPL70qIx7J93Kcy+ns3712psrZEQtNO9
50e7J5wOjaR9wLkzvWlV7SHonzgLJ7/oafj6m9k3dG14JP5tMggxpv+xn7EP
gixvZp+R2+8k6UsisYGKpbf5o8Gvl9mXPOvayvVgKhKNHt0g/FaaAZc9RWkf
c9sj1sDrepFoxd5uo/SQdPh5qZf2PfVrk3dmeYeg/MPnttjvzoHKHF3aJ2UP
tTOIrvRAwa9XSp6Iz4c2x420r7pk8q7F3Y/5GpuVYhiEtyJmEk37sEfvGXA4
VXqA2eUQbid8vfyWA7Rva8+haB/oHQI9fhH5Tnj+kOJYOr93GO0Lg4p8wvUM
bE/vdmZfON7biqtuKhLGFmRlvsH289zaQfvIlWr6pO8Mqw4UnGrB6/3C5kz7
zvw7eIQmJnE+9oBjgzv2T2Qds0/9SZpvMqI9BHL+KbbOwf7krvOlfW3VwY6y
wo9nkXp8RLOpsit47lChfXD9KdeabC4/dMJjmFf5vj8opTP75teuiZfm+wUh
m9ZHnia64WC+j9lnL2iVWlZ9NgSJf1xxvGthAoiU19G+/MlFmVK2f4PRHl2J
OEWhFNggYUP7+H9ObtwcY3sWDbU/GQ6UywC9s49o3/+Xfc/w8Q8uqPFB9GKD
31nwq/cbxQl8b93bY3+2QKNezGJsx+9sOMSdQnEFKZNuQbs/uMAc2au7yPV3
rjJxCNUl2wUMbc9CcPkVviA8/w+URHELhZUBBOcAc8/tKSX2/C1wpTgHI60y
mcyzITDyYd0JYv/RN6kUF8F55nE8wy8I7p19d4KsN/CwOcVReJWxGady+cGO
Z8pXlbB/3NQWMXEX9def6348C3qrC3qOYH8ezWHiNFpC3W8KRHqhQzPn9EIZ
p4BzCxPXEXXgSo/xIQ80WfRC9oqOL8yfnaY4EK3eyjvp6T7oiajOwl1uocBz
c4jiRqpvpxOcCZqKfysj4hYL7/bYU5zJl0d2iyMG/FB05b1tD04Qpp8+xaVw
jhjOZgl5oaz9zeN7xInez1mKYwmPGtS5XHsSnWqNK/t0OQPKZvQp7sXy3/gV
1+giDf/FFqLiOZlgueQFxcnIjX4YsK89Cdd3VTRLXsmAoO56iqtZcdxY2ULI
CzI/vjY5hefn6AijOJx99a5quwb8YKvjhux+bI9XJxfF7bT3CtxlFPsD64DH
al5sv43sU4rz+TzRJuOT7gOhSkdchfF6HVI+UlzQ9WTz5EOHPGD3yLDfTuwf
/vZQiiOyFDNSborwAk+LD0dnEk+B5AYm7sjquKCdiKgNunlBXfriwzAQucPE
KTXH7A29p2SFnp3dvcuvlwGnBvkp3mnf1qxYrVpb9GTdZxlJhRwwPq9BcVP7
jeN3th04iY5zzvbaphbDHLHNFH/1lmPZ0yP5J9Clc5st1PTKwM2pleK4bGrc
utfVWCMV812D9vZVMPw6mOLBTH9Urro0dhhpej/70P+9Gt69Wk1xZcpNpZIP
y1o0Tnz4zROSchnQVlYFgk/b/O8lT9boYRBV+vK2B19vm+ZEcW5y4qxLbC9b
w5NDjZqWeP7cllaKl5PfqzbilHsCbq3kyFTG9phlb6G4u/EDGTGq+0/CX4nI
0yew/WOJbtT+5KJHQ9ZXbaGJraNVAa/XPSCK4gB9f/UfZChZgYWyiHQ09o9p
pBzFEzpl7nY1W2EDL/eosg9if96aK0D9qdF4wTtamw2J5iX6eDRtA21/Jk5M
KeSLZHcCC5Ib3XUk+usBkLRj4s0S9T1OXrrAgcrjJur6zx2GLW5M3JqCjdno
Nk4uVP/62PF/gubgymZJ8W8+QxMblB050annZcP+Z6zhu/RSiqObYCwmeDxk
f7PCFNnawZZWBYrHG+k03rB5+luzxHW/o2FC9pD55SDF9R2bmLfp51NfDVn2
SwckFztA2IkjFB84sV8pPfXbN42iZuvpRQL2cEdPh+IMZYWHOJZ+YQVgee2w
+LgdcPA4ULyiSw5/xkpbTrjFLWze7WUNSh1+1B7dPwf6jrJyQceJ6KvhQuYg
KadJ7bdz/U1wmLAwTtLq0oXDcNyFicNEPMbVggkskMHqp2vy6wA0dTHxnDIs
pntfaLGBgZtFKeudbeCvwMSF8nDvZojeMkadP0qySr6GoBVKdiuz8HjSinFj
M3VjVG1mvcVpazRa98Mr9xAej/e8bJO29TDacknrRP5QLLor39K1jtgp+M/3
cvE+xKkwYlF5KRJ1zJ34ajtL/n6TdYfUZ1l0vSS0sEPEC0VNvYkbJM8rWfh5
+egxdHXi64TWkgpkyzWxPuz7FxCeLmR7eXEvSny7+Wri6gvos6xN3JufOC9Y
fEfh2lVpeP8n1ynsVBE6rrlxbjWOK/ZG+rOU3t0O/JOFrupP09DtYS74SfRj
G0wG7VJV4PaTkV8dW0JQyuvN5sX4vhZxja9N1ewga/+Q86lz55Ha9B1u1V94
v3pfeFqDxRoiqvWefarNQQksvsMt+L3NyWnOUHxiDHVCz/umFeNRy5e5XoJ4
nuF3bOmax/fCwpebOwIifdD4EW/zJ3hc7GvUbnsOXejVrBJets8IqWsufE2e
l0WpitXoHje0z+K1NfntF9ii9IzgzGtu6I3IuaKIDv/WvwZhqOFu9n1f8p74
+kVJHnVDDLnPMv1OyUj98ycbV8KbO3XhhuKkCzLTF3ohuLwA/Tkucu0NPvcf
Jr+EPWH2qPjKVxUZxQvopm7b8QfYb/rhX4+xbfJAXYPdq4uzs9C6JQUPVhIc
o4BO0NUQa3T77eTaijdF6M8RvXFb7M9b7V+NaobXwyLvap/pv+fRzGHHzyzY
PyC9ue2PlCWosodxGVtVoKrkooua+HmNVFRVjwbbgXVL27IS+UrkEzL9L+Yb
Ppflo+5xjPlC/ZcaZ4fSFMTd1f9vNckX4IXLIhNvePRu7hs3lVQkOHTLexke
P2D/PU4l1R32Rao/6ZpmIIth41sBBD+wJPHJwFl7uDtkb/WTPR4dSl3WsQT7
Z96iTd3Lc5zBW6P/bkdCKBJfqlpG+IDJn8Kzl3D7IQPY0ua6zBVF3WlMbyR4
+LWq2//e9EZrj8rtKWbxR1Effk8Vkrp6VhzXI7eziH+uS1KhaRji2SPEZoDH
e7JDjx9iCUTOB9lP1a6LQ8Ovf6z8SPSI/H7W+Vv5o7QtO0ynwxkoWjmj0Y3w
cEt4do6Z+KPTxttltSbS0RVJWbY4gj/prGboOTij0zWLPjTvyULHYvoTNcj7
KfLdaixPHLoT68+je1no00Tugo14vPFxW8BHUScw7h7pS7HKRAeifDSciU7m
zNRrLqkzcG7Z7mNR5mlIfqXD8lE8PlzewL6/Phi/t1PpS/8mo2OaS8YECC97
wR+Q0cXjHXWBsnrxqHFi+f47ePywefvNTyIB4Czko/TONgzVeG78pYvXe7/0
7Zxv6V6QY3bnygohP5S1NPJFBcEVJx5OMLLzAeGRBt+CJ6fQs+SkzFt4/GOF
f3iwUDD6JrzllEm/OxqNMXBIJXiw6JNOPTmByGSHrSP5TX4ZxupJcLwtW38M
NYegHzXw0VE6Epl8vpfDjccl98p0L3gdihZz2p+Q2ZmI2JpX2ERjO0842SV+
3BeCNkpdEhsyTEHFl1s2zsHjd44E528bCEZ65mt1Rbuy0Vhawa1C/J3eCFpw
7nGlO1L+tGmVpGweOj795zTRDbiz+uJMV48ksHkemygxyUPub6qLbElf3mzz
Qa4PbqBtfyek2CwH3fKYt+w2Hl+CxuQXFwaAq69g/5PSDLSEdbbPEvvZzF+6
gZ8jEjJYbsZ/3pWOfu/JGzpE4hbHhwePpkUA7P38pMghCbVOv7XWwnYGtAwX
cEiEQr/KpcEaiEQ66z1zuPB6d8T+znt6+SyMPnnV4W0bgB7I9PuR9/b1K6fy
ZxJBcPV+0PAib1fUcrn1DNmvit7/PRPwJBzpqu9huxnjiWoWS/86isenGA46
iV9C0aKVSku5/gUjPs/crSp4XD44TkNhNhLBs2+3LnfEILa5kteL/hG9Zf++
scRo1HWtZ/v7Zwz0lKGdNI7tl3wTVSV/MRItis/JtW5IR8sNFV1IfaCz8sjl
l9UR6NDshin7vHwkqyZfEIP3GUmjL2M7+s4g14DnnCZQiCx5TkhsIjx6xqnh
Qtm1cHddm3HX6UK0d0fC9a1Ej0Krv2Hgtxe8DfMfz7IvQPW6GXdLSV1d3+bz
DflQEHz/mvtfXQ6yeN/uYEnqk/sKPO+KxMN3R4WSUecs9LqM+7AV+XtAYru/
77gUB1duPPgQPJKMeF55paVjO686FTy2douC9Z9CO+YMxaANCWpvsvF6307l
heb6hEChT5qBuVQwikypb9Ym/JTa7mMbr4XBoU3xsoamp5F2H4eiC8Etf75r
91EyFuWZLw7703oGrepbmkb2mee2IB7RGYWWm4/z57KHoe9f2SXIPuCnWaYZ
9TUe/ffLG8y5RIzoJ5RosqpFJKIFKVd0rMVTUcHdW3PXYzsv+Aa+UX0Zj97x
+N/b1JOF/taZPdfE63KsvaYeIhiH2r5c5rxkXYj4bzzUdMP78O+hKkWJmrPo
nLP68pxlxQjJCVQvweMrZmJGLZbKAQe/8JURl2I0HPApnR+Pd1qGxz+87g/y
p07P4ThRhPRmP6z2x+MWLiaTHOujwHfoir23YgFa8TmoZBf2f0vG5fLXngyo
rVthN3duLurnMBizwOOvv51YKr+TAYxvQuebZlORadxX1S5sZ8klkw3DbgnA
LZXO+4I9AYU+F1Yk+0xV/UDVw3WRoD/sW9hqEIrWcj7w58R+06v6t6LifTSY
6LUNT057ogi+dT/Xkvd8WcY/2d+JqGPfqGDbFh/0nVVh8CrBNzasOBYtmICe
LXHtk3ALR4Ibfykn4nHVoJtaAo0M9HxnCcu20kTkE134PAb70/jNrsfnhVOQ
mvjhhOSxNLTur6G+ObbT+CH/7ytDDJTqeO8Mr34u6pgRDQS8rrzgqpw73klo
zNZqbbh7EdK3/CBB6pOzXSLRY9HBaCZr9JO6VQnasOGBniweV54xsuHQkgee
soA9oWMlKM1r/sRaPD73093z8zhwfrelQc91shgpPb2xy4v0ed8+q/jTGA8P
MtQ6LlYVouHU7VnrSZ1QIdY3SCINzJcpSrffzENy8LDImuikdR29WvQnFZZF
bn88cyYdFVX1RfzAdm6039K5ijUZ4qIHCx+UJ6J22/KJQLxevc7mZ/OPxEHt
tzmrJljC0b989TiSP/7TKSjerJ0IH8vW/1Ve5o1ElvB0dJH3vzt5rIUjBQ0c
FKlMvuqD2Oorirbj8cdbRd9P6TNQX9b8rEeLIpBuzQdeWTzeovVYIVs+DemJ
p+0a3JqEVqp1l3/A/tT9m6Lq8jkdxRjZqZDffRVWO8KxncLo7tFNjDS0PilC
KnYkD2nWqq/fjde1Z6QyXTs8Bf3jDhbY96gIvdsYuZLod12K2vo3YTQMXb/n
+6t+ogRtDOJQuUjqxhbBDYdOKkCDsEVcwPlSpGue4lVB8FoT+QuvmIaB+L1L
ZXMelyCJae1npF5qseB3tZoRAw6aHWGHzCK0ePjDrt0EX1QS6efwPRN2+PH1
rTiQj5p7DNZFk+clO+9Yw2AmnMw7/mV2WQaqYT2xVZTgHNhClQU80+DhI73f
2hpJ6NVjN5ZBvF4nkblc0o5JcGB/38t7E+EotZ6/9wDx83rxbhv9ZOBfUCj5
y8YH/ZlT8Nmc8FmcF89/uBz7JbQlL2XKG+mZlF0gOgmqzYpnf69MRXbeY095
K8ORpLeqVAvhd7x7GDtQlYlmG4tHvwkmIc3PK2p3/yW6ZPUeCb3ZyOxh4+bt
v9PRZaM853qiB27uVXXNJguJscgt596Rj1SDHU564HVdrz64aw0jHU1K3ayT
MShCLstT7xD9yYgyB7HBg1Eobkmt6PuUErRNasWlm1NEj+v0dx1VBTDdZ/dx
yKcUTZR2J3Xg8XVegovftUbCNks5WfdnJYiv5yhXLh6P+jr34kfbVEhgNfug
cLcISW67d/4K0VVWUmvNuJkLm6NHZ3475KFvo0six8l9nwm78N/OBeXJUhvj
knQ0J29W5wjRl1MLLrvzIxNY0Ja3/suT0M6VjH5VvF4tAclH71VTAJa1+Hp9
CUcOb2P03mL/fLCZ/hJjmwZP/8S+2VPug/RK1lx9SXA+wUkyffOzEF+oz82x
US+02kf1uxIe9wq+/mzHw3SU9/xr26s1YWj4x7rVJnh8tFnDRGppLoq5YrCg
QSwRhc3Ojlwk+mANETefVuUjxhapgshXaWgT/NCai+3UyNoxeGxdHnqzsX+M
/J4+82LoNcF9bbnxZ9IrC+mKCXp9Gy1AvZapxvfx+PEFC2Q7UmNRY9k0pG0o
Riue+HuQ/unRx+y/c6LWwdMLeW2jmiWozJ3nRSoelwgZ1T3BFwtJ4rvH370s
Rv+uevouIjhG81jlKocMiG6y4Y9aVoTY0gQK4vH8Kqfer3OrLICeH0p9a/5k
ozXLD8hk4PG+10O9TagAynbblm5lT0Ouon51pI7NbTt5/59hLvhaSsa+FUhE
szzbWvLxelMNtIR2/kwDtCnaS/xZGGozvuTiTepgDxIK9Gwy4WlefKx/jTcS
/TKvn8QzDsqMN471OehBzxmd9LOnkfADNf9K8vc0N0VL3FfPQrMPH59c4hWM
2jxusE4TnWTjZ2lDAgUoraH3m2lyLGKp1eaQIngbWfOv4/mFyCIgzgwSU1Bz
4sgPf1KHX/HKUmuwAB3UumxoE5qN2qJ3PUjH6+pPfSk3tCgXxa0f0ia/ioPJ
orb4+m3lvGe9khNQelD6/YPNBTi/Cf9UQur/EcIdg5tlQON6deSmL4VIs73t
3xT5+4nnQv79Ek0A/hqWv0ueFaI4HZUHS/H4Aj0d87WQDWvb351c61qAOAvr
PIbwfe//C/lWo1UEt1dyzCj9SEeh4dGlpN+9wS4NSpyKwNpRsfnd2mTE8nCs
SBPbI86Z9M5duQD+2e80fesZizgcT5cRncBjvuFPi/wzYSevYXc5IwQFzGzT
JXXCz1N6J5FkDtguXJ2nfNwLHbc/akLizFHeUkfHP3nI6/eLffKXT6FxgT8K
6/G45wv3fQO7cxA3z5bT9838UZ/hhdXleJzvyfDnQ06FKFPSu2+BcgRadFqM
7wbR4zWaNnGRK0afAu87L1+UhGQ/cyARcq5tyLsp7lKEdkd+Hc7dk458+thk
kkg/NHCt9uzGfHT8hKNwQ1waSjRQdVDC8/DdVduYvjAJVfB6LDyYloXmuYYt
FcL3XVXA3+VoJAn+k6xtO4RzkeXeBKtqPM477x37lsFE4LkU1DMblYs+smSk
+xDekMX9No/6XNj16Oe1wrpsFCIyeTsG28PGnuk4lVwMnibSW/R8GWjs4xWb
StLnSjBVdnxSDLfTH5U1GMWjU+3G94lO71wPlhrdsEK4NeJdcwefU19FzlVX
EXzs/O1lwxXZIGr/ROqCXCCSnf11/Sa252vm4b2WIXlwLeGYzehNd1R38YHh
TvL3L5okdF8ZFiAd7eKyo1Y2aEXfkcOd5O89bVtcEtaZi65s4pKc990deXyo
rnUmfyfl07m+Z25FKP+8SNFxu0D0ePjBM3vCO1D80ax+vAQ9kn11Jo81Ch0t
zp0mOJOnOrZDTleLkam64langiQ0Z/fzI9dIf/nBvOJ0iwKkdlzFtntzHOLK
//3kN+FTvLPZHcfGQPqCnjnkt9XIW96L6Etb7FssfEAULLiM5FMjU9CzXMtD
R/D54nBsbvvC10mQFZx8a0FKKrq1aWXSZ2zn374brAVX8+FFQhzv8PMUpGMd
/NgCzx+56VSNWXAJaE2I9xmdj0AOyn2PX2F7iuIfbWPvL4GNds8edLmFoiae
puf3CF53+JR4c0gRmHiamWuqBqIHDwOirfA82m7sg5EWudDhwKY/HO+FhCpN
Dc+SevjUg53ecgXwedcikROPnFBh2X6/fvJ3Oowun3LoK0AaHonGytPa6Ns5
lqJ4olP3/rXqx9o8dPXfb+HlAVaIV2j9gf0EH/v4572HAsXIaoOwbjSfK1ra
s/usGtE5XP2sMF65FAWevvCCj4HzUC9R+Vukv8/Q3X4rrQT1xj3QiL8Yhvp2
ZIt8IHj7ggTFPZ0F6DJ34OdTXZ4o03z8uwf5O1n7nxTXZDBQmYmER3pQIKoS
W8RhRXTMzNd/zwpeBGFjrjc/qYehT02a6xNwXConNrPLIIIBAt/kVKtdI5Gn
8fttS/D1IRu6FXZGFgCn256ErTuj0DHJE61CeH6b9srTO1lL4Y5R+Bw3hiva
c1lWmIvgQ2bCJ93cS4FDo6ih0cUN6XR1GNVjOy2NQv/GiBXDy0wry6sVLshq
aZmoMl5v8/O+ejb/PNATaXpaH2iPuo7U7NLH/pkUsVFxuVUAvcdmTu5TtkKu
C/ZNpOL76vfme9TNFqCKkDt3U0u0IOK+zjGCu1MryjjWMJmHkp08C47Hb4Mn
v3b9IvkFu4lcNsGLhrwQVfpVOx8tWrp8guAczq9ni61klOJ48e8ixZ8GKI4h
/pa8t1q2Ly7C3FK07kyPYm+lPfJbpVo7H69LNPVopFh/AZKZeaVz+rIjhC1c
qh9MdGVRldbP2wykqPdYQPXUMTgVLKVL8q/e3eP6MbMrm//7ZaH/JmBolb4a
vh6+fpdTVTp1DOnLyNLrf2oNJeL5wW7qxiOny47o3fFldP5Vfa652B74xsvz
s7vSHsdle6g96id7QrH98ORJV+L6nwagPyNF7e+XamcQHOOylYf0d9TOh78K
K+h6lzWy78X+gZKs7a/s4rehA5kHqH+SCyODsD9hmcj087gSLcTWuZf6c3nX
TVnsfzRcqLsU+x8sB3Sp/7myszvw80ILC3auvhFoD83Gl+jzKtGaWRwrVox2
3S3zvVzhAoVDRfT5tivfYXN3L0VjdVomN1zcYFVjG30f9i0sP47fH7Scx63S
neEKS8Y30PdH9v6Xdfh9QzInhk/h9w0SKuzp+/bb3qpXP4KBygsUFa+4RsI1
yVf0/eQb2/pDKGQRCj+3cQV+n0ElaQ99n4/3VZ7D7z80PBCTzAgKhNfz59H3
vy39hQL+XsDD4OBr5y5P4O6dpN+L5elL+vj7ggyD9hdxF8NAwCyFfl8f21Qu
4O8RLFky1i5l+IF69DL6PUpwubXh7xdiosRD8PcLGcP76ff7Q1ByI/7eYd7Z
j/KCAVYwX4H5vS8vT/fC+wPkHAlq3TStDealfwvJ/vDP9qU63k/Q+JFqTbtH
TjD7S4fuJ28P2P7A+w9SOr+wHu8/MF/sMN1/YuP71uH9Cs2q3vizTTUQ9hj4
0f3qsJvkIby/IeMktmN4fwOZljq6v80zcYzD+yF66fIwCO+HwFb1k+6Ht2NW
TudfzUdHrig74v0TuAM96P6pfYP3Bd5vkSPrO2O834LmH3m63x7w01xjtl8U
3QmXysb7M1Qd1qX7s87mp6LxbAxg9Sv6jPdz8D6tQ/fzh3YKLXj/h8awaZ+e
zXHwpu0+3f8Ditwf4/MCvmnGnMTnBYzmv6DnxTn1VTfx+QJ/Kw9fx+cLeN/L
pOeLzruV/fg8gm8LPCfxeQQPltyj55GM59dkfH5BVtP9w/j8gscbrtLzS/c7
7xF83kH6dQ0hCysbcB8woOedOs9jNXw+IjA9J47PR3C/84iej/u8HtTh8xQp
JXeuxOcp2Oj9oOfpb4N3dfj8Rbk9vzLx+QtC4qX0/LW69lUNn9dos8arlfi8
BhA1p+e1bnanLT7f0VepdG18voNxWQ09323yLozheADVPsyWw/EAvAzmvEPi
gasPeVlx/IBmhJtrcPwA0xP5NH6ICrZ5tNVIEtlOedfgeANYvjJovJElkCKH
4xMQ7L3QeiAtC/iaUml8YvyAxQ3HM7DlTeJeHM/AQIE0jWeWvXK4iOMfGNu2
zRzHP3DbbQ2Nf3o37DLH8RJYfvqejeMlOGvwt5nES7o8w19wfAWDWZ1K3MoR
YHpLmMZX/tL31XA8Bi+7H7nieAzuPK2g8djEZEYIjt+APe/zORy/Qbv8Dxq/
xVZbmuJ4Dw25dTTheA/YVh6j8d5ee/v3OD5EouNPhnB8COx1W2l8KDf/1wiO
J9EecaFTOJ4Enhw3Gk/asEjq4fgTebbbFOH4E1p3v6XxZ+yjvEkcr6LDrCK8
yj/S4dfzCBqvyiTqF+H4FvE0Wu7F8S3wDVyn8e0NldgLU6IJyGPw1VccD0MD
zyYaDxsGvWzgUZFBt96MeOL4Ga5mddL4Ofraqr3eyQmge+P9OI63IWPcmMbb
TiJH7XBc/v+/mWxBND6fmB+lh+N5aBhfr4rjebj9x4DG81GCzeM4/oc1iec8
cPwPQYXvaPw/WLc8FecL4HvI7C/OFyBNWIfmCzFTaoI4vwC5nlNHcH4BwmJN
NL/Y6X/iO85HIGFXQgDOR6BZR5nmI/efeqXi/AWlDHUF4fwFVLW4af7ycr+y
BM530CNeI2+c78CR8os03+GuZ3uG8yMkeudOAM6PwFQbaH7UWh80jPMp9Mw5
KQvnU/DirRfNpzQ4zojg/AsNHC35jfMvsGw/SPOvKwVTKThfQw7L5s7D+Rq0
XOSh+Vpov/y+k3yxqLSRm2XkZTHwNpvR/G69w+iv2Kh1yFSq6jbOB0FTcSHN
B+057ezbU2Ph5NUCJZw/wtHOeJo/joXGzOJ8E769UTHH+Sb8bi6k+abPh+j5
luvyoLPOcDH5XTF5m+anb/kt+nA+C3W5p7pxPgtqfe9oPrukVNEA57/Qe2ql
EM5/YeduZv671nVBF86XofEs+3WcL4ML73qaL5+smVDE+TXcFU+7jvNrMPTY
TPPriKJ5IzgfR9K8FgM4HwcrT2maj88J2PMa5++oPrPjNM7f4aV/FM3fnaNl
K3G+j4xNy37jfB9k0+Jpvn9ypM2b/3Yuut0oGWBckg6LvadofcB5tGVO5s1c
lDr+u+W3Qx6EufPResJV130XPtqmot8Wr6YU7hZBYWgrrT8sP3r/5nBrJMq4
5ivq/qwE5CZO0nrFRHkkf7WKAtq7snbpK59SWBV8jdY3bqw5EzVwMAoCT7Tx
vE8pgYcZqrQe8oaVr0eSkQ4vTDY1yhgUQR7HeVo/2XlGOfOaTRaceRsxsWBH
PlgIeNN6iwrUmyf0ZsPzE03rt/9Oh/1lJbQ+87bmbuRAVSaIX5L9/k0wCcoX
M+s5PXPEvH+vTAXxD2s/8FaGwxJ7Zv1nlZmHwMPl6TD/nmB4ypQ3BC4+T+tF
vVDYbqOfjOwtrin8svEBQYNCWl9yvL90vrRjEtpZpTZ6byIc6t8up/WovZXD
WwQ801CccfYcHY0kcFFxofWrWrvKow2Dmeh4k/PM7LIM8H5+nNa7HmkePe7w
PRNNdUQ/X3EgH0bXHKH1scElkX1qRgz08eOpPxqZRbAyaozW02o4C1OvmIYh
neL2yjmPS2Drnt20/la7tP9C4UkF9HW3UFjA+VIILcuk9Tre2eWRCaNhMMxR
OV4/UQLKCYtpfY+rL6FBOzwFpJv8+PY9KoLTf8JoPfD9h3qHTYw0yPa9JRs7
kgeyqmq0fvjv6i5SZ4TQ3l/K5Jchb03rjYPGmfLZ8mlwdGWi+uDWJLA7/4TW
J3Nzvr+d0mfAilUPqx/hc8pIi1nPfMdo/9nCkQIytQI3k6/6gNvxMlr/PNdx
PWuzdiI6HiQ0przMG2xcF9F6qY9Qxbv5R+LQlfIhiQmWcEjN2krrqyv1B++t
Yk1GnLvcSh+UJ4LFXmY9tv/i75qiP6kosteja+ZMOhjs6Kf123VHMjSDJNIQ
I6lBqf1mHmzmfEbrvUmxz7P+NMaj5kTn9otVhSDOvZPWh8sVvZXmcwSjxe98
9rlOFoPJDLOeHBgkYMWtJY90Im/vCB0rgeCIhbT+/Picl+6H6GDQqy8bVbcq
AYs/7bRerWev9+uOdxJwf2tSCncvAo2Xz2h9W6jEcUHNEAMqLQu9efVzQVJA
mNbD9yqYdZ4XTgG0YDQ4eSwNzj8xofXz6LY8DYFGBqyWuPgXShPhqWAxrbe7
lLZqRQsmQLfIiocSbuGwcv9vWp+ft2L+fLnfifBQcISvbYsPHE5ZR+v5j0SP
L654H42CUhV6J6c9AXUz6/8hd7IbH66LRD2s+ZmtBqHw7tJ92i9QabLfNuyW
gPR5//zoZU+AzjQR2l8IkPFfLL+Tgezm1uU1zabCqvjvtB9xvtGv+LUnA40a
hR+ZOzcX5D4Y0f7FmKPuSY71Ucg/4t1Jb8UCMJobRfsdmzPfv3x43R+NuXtM
sZ8oAkn9Sdof4f5q9DJ9qRwyHC09P+JSDKwV32g/5SmLrf/qmrPQ/TOTP2dZ
MVg789H+i3RTnm6IYBwkFsexXLIuhKGZx7Rfc103ZUD1ZTw4M3bf2tSTBY0W
5rS/w3JYgkMtIhGixdj3WounAnvIbdoPMpXauCPqazyssz2/jfyOejP7Rwaa
AYIRnVEwfteaO5c9DBa/5KD9pi7Vg14fJWOhTnrI5U/rGZDVYPanyuosDDde
C0Mt5cukDU1PQ5bBHNrP+iWj75frE4KCyw3NzKWC4U8es/81bKDdb+0WhSaf
2TTNGYqBOU3Mftm2ukzOnZfi0GURwaHgkWQYKTxD+2uVnC/874rEIwfeS1mj
zlmQt4mH9uNuhLWsaJAPRTJZXH9n6nKgfOQe7d8prL3V2f/bC8Vc/DiSZV8A
ET9zab8vjCN3NEp2LWrM4DnUdboQeqOTaX/wt0O5186+M/Cad9MfYygEmVxH
2k9cXmBS8LI6Ag5lWf+yz8Pnm7IC7T8+cfe9JH8xEozQzXzrhnS4NbyJ9itv
uLq9GEuMBq+txirvnzFgTFaX9jeXiQrrKsxGwrczl0k/FMTXr6b90BG2sf2J
X0KBE1SEuP4FwzVLZv80IVY2MuBJOPAzfn1DMZ7QEiNF+62L/i0ofiYRhLhN
rF4s8nYFvXlttD/r2L6h8Onls2hz4vI2b9sA+LKV2c81E2gp5ZAIReKXox7V
QCS8L2f2f/d+VD9wNC0C1Zs/e1jkkARj2cO0X8yx/dFtfo5IxD7yJeLzrnTQ
5Myn/WWRAwy+xYUBaHFxeNeT0gxQeMnaT/rRMzInTTg/uKGNosU+xWY58KNx
Ie1f83t7/B3skUTSPdZPS0zy4KjGNdrv5q/UePa40h0OcX1cLCmbB+6is7Q/
PsSz8PS2gWDIG4/eIdqVDZ8+l9B++q+OE6T/Dq4u9kuGDFNgzc822n/f5NFy
f8HrUBCOqraQ2ZkIj4VFaL9+Trz6l6HmEDDpFh11lI4EF9P7tL//oj76ZE9O
IFRvZXcgvzAvnOIBfr5ZnhIsFAxis/kOJv3u0CLIxA88XTARbmTng1ZUj2QU
PDkF0Qwm3sBweGbBt3QvpHx7fscKIT+wvBpB8Qljnqytn0QC0IFW1e3vbMMg
eGwDxTPsfRiyQ0Y3GG2pFvKX1YsHIS5+in/Qm1YV2l8fjM5OQ/TSv8mgk7yU
4iWsr63/wiV1BmnNRf5R5mkQ8+g4xVesz95f/0HUCQluufA9xSoTJsU8KR7j
Wk2WzYs8cbS/5l4VupcFzgE5FL8xo5anaeDgDCYuw5PNe7LgweFeive4IcRb
MWbiD0FRhdJaE/h8WytD8SGKzYrV/lb+8EG+z206nAEC71IonuSA31uLQyyB
EDWxKax2XRxI3/9O8Sfrbn7+9NDtLGgd+55eaBoGv62ZeBX9+w2qf296w4rY
r1rFLP4wsXCa4luWO22/uITbD/zvdF53XeYKRXlMPMy8kjWdy3Oc0TH/840d
CaGwOpaJn6lb6DowcNYetQX1Gf1kj4dwueUUb+M23pSikuqOKod+PuqaZoCM
jAnF56ScjrdfZOKNBCq4RtxUUsFlLxPPY7Ul4RHHmC/qUPoe6FCaAlvu9lL8
z0f5+RWjwXboUJ4DZ4l8JRxbPHeW4IWiTBh2f6Us0T0dkRkjqwpQWFNB8UVX
I6aNLg6vR2vjMggeCfJPM/FIycdOl18NsQatJI11FW+KYK6OLsUvFUjYu7Ft
8oADPe5QnJ0FB02zKN7Jwfb5tj1h9pD3XlpWRvECtN3spPioIauKJsVJF3hz
0+2J4PICuLB5FcVTaXj6hUgedYMG4VmpfqdkmO/8meKvOtfla4/IucK7Jefa
/xqEwVA8E6+VP4ffdXSPG+i5RbmQ38kXahTf1dX6U9eeQxdpFbY5Ld1nBG8s
mHiwT5rxRZrH96Lf2xvCAiJ9QEHNh+LHDk7y5Ss+MUam2/0rpxXjobx8AcWb
8X/5Y6vBYo3u73Sq/1SbA6mhQRSfJsA33W+qZoe+1SlanDp3HqpSuyme7Svf
t3d2qSpoVe2ygI4tIXDCYSvFv/GHpR4qvbsdpQj3b1J/mgbpo3wULye+cGZd
w1VpFPDmkG7YqSKYI76D4utchvb8HLy4Fxazfc1OXH0BlE54UjxemtsV1orR
YwBlPQNaSyrg3F+WDQS/p5iXgqQ+y4LmgoM97SJekLj3HcX7dejYBV4u3gee
vKcFKi9Fgq/PN4oP3Ov67mTa1sPwweyrav5QLNy+10bxhM591/XM1I3h+47L
K522RsNlS2+KP+QoTasQvWUMLwITY0u+huA4gIlXPPxVnOpaFim52xGdS+Fg
pr7l2DA71cH8pFWjSXQxk/+nhxns+EmV6AlyDXvJEX3Balcmvlclzu8V0b97
7V7dTvTwJhuZ+Oqv3aJtRK+Nw/vfG6LfxgpM3bbJ6ifvib5Yx88pWaI3xsLO
1Bn7oOH4nOhhLXsXNE70sWZeMvkdpzYy9ZtWJhyiek4JwNRxui80RvWGLoaf
cyf6Q+NpTN0hw2ZHWaKPw2JTpU30ch54M3VyXPfWqBE9Fxe29kVE3+VOG1PX
RWqdZiXRH9kj9lue6JHsU3lP+ZVzTEcGeZ47I5OS2XSin5FTc4PyW8Ni+tuI
vsMT5Q9PiN5Dn4sW5Rd36fQoEz0CxTW3JYk+we99o5TfXb7U8ryy+T6w2BYV
TPj0LRPelEf/rf2KTIypNWRdmrpH+N8mu2Yo73vt5OpSwk/eVX1LjvCVZ7XU
KE85VGbJa8KnrVvQf5rwa4/YV1Ne7VaP87GE/zl+8us2wgftLGDyQFfZrGYn
fEUJyfm9hL8YyGDyFvOedPITfl2ruuMo4duFGDF5dnr3rJMIH0xq+40Gwg9z
euxIeWGPPy+QIvyl4wY53YTPZP+JyWM6y56rTfg2TTErnxL+TVAOk3fja+6w
gPBD5ph6pBC+yHf2bsoTOb/Tq4nwGdbLcF8k/AZpVSavoedpzCGCv+/lZ20h
eHx/NSYOX3dDAMWLVzGcbAl+vLmNiRsPNQui+OZZBSkfgnfW+R/OGf6nu+rh
32lIdFiFXjP1V9lHc6lOa5ueINVt/U+vNar6uQnRwbzqYJ9DdDFLpZh6mMJG
UY1Et9FMpcaU6DiG8zB5BJwKnopEZzBi9v4qoju4yIzJ4zCe11RAdPHc8wU6
iU6ehxuTR1N27kYA0XFTvVTaS3TdVEqYem61qp/4ie6YwXB1DOHbhfgw9cee
hyvzfZCJQNBaMUb4jmu+rqc8vpRL/w4RXafn9fuUiM6TqaMu5VHecdcuIDpE
9ovnzxBdojd9TD0iDefajUQ3J7Y/poPo6OxeyE15xEOCDyKJzoud9Qd3ovti
YcvUe/HVjjhOdEleLhC+SXRKCtWY+iR6k7VUR6N+7pQ80dX4OhVMdQy0eRa/
8RoyhBsSWglEB8KZ8ZLqP/j6OCUTnYKBFU0eRLdgyr+RzrPmVYUK4dXzvRiK
Jzz7oNgz9L7BbPMHCA/80YxqBOGFyzeVUj54W7DOIOEtP8938yA85lh5Jn/5
hU7BdsKzXSrA5N26GDH5tkb2hYWEF5rLsa6d+M32KZMfysN6XI/wGMezV1Ne
41pPJp+Rh3eJI+Hd7Rodpjy8hVeY/LtfmjeHCU/MIiThBOGNuQ4K0OdY776S
k/CaFsndW0V4Ttv/x29y9dTkJzyckqNmVwkvhzOQycdJ1TeTI7yRxMd3nxAe
SdP/+CNWB+Qpz+HM4+Qwwns4+ZrJd3BT2k5x+f/h9P/D5xuhGKoLrJM6+Yro
BAd1MvWBYyceUR3ha8PC+4mu8Pj/9IRnBg4YEv1WxxpjFaLn2uvL1HGNVL7q
RPQ3+XRrk4j+aBonky/za70S1ccsHJ49QPQyBe8ydTL/03P8T9/xP13H//QH
/9Mj/E+HcLHMWsKTRBuTsqqIfl6KJ5MvufDHchWi76Y+aUj13naVX6V81c/1
fzkZ3YlIUOeQO9EnazT7TvnCP/14JYh+luUNvQtET+uxOVNHy3wT/xDRe3Lb
9ZeX6D855QhQvvzbnu+ORJ9oyNX4PNErMmti6hXsN+C5zC7jjR6osj8m+jpi
PC1ULyJ1ey+/7lpLpNEhSPVg/ondp3odfjvVW4heiaN+3AmiX9K0o5/qljh8
iXQm+hpx9rG8RG9jTU8A1dnoOWFpTfQgRvU5HxN9CLN7zlQXgrOEexvRL+gM
y3UhegbLhZk6BiHLtIhOFhytXAyEf887xeTdy3pEXCX8cM9DkfyEL24ry+SJ
q99czEr4zAxxCxHitx+xZyivWbjuNeXfWgi6NxA+rk+zEuXh9qt8jCd80cwP
EQ2EP6pwh8kbrcuKfkz4jXID/dcI3/GtG5PnyHs6ho/w8Vx0nYYIP6/8JZOX
N2Hs4kv4VNVLg4sIn6x1HZNHlr42kJvwncxuOz8k/CelCibv6UHPTcrPyUXW
yYSvE1rJ5Ol03HlJ+SSDVzY7En6Jxv94JRti91Dd6tuW8WFEx1rFmqlf3d+9
j+pci/xfTfcdzlX/xgGcBqWJSiQqkexRRslRImmgYYUSUhHZK2TvTWQlIyOS
1bCORAkNUlSIyiopDZuec9/H89fvuly/q4fzPd/POuf9eusf6gP3Om3euxZl
4lwA7rBREe0Qn1tO+8MGHGnu4MxuCdHZAW7uLxnayxWP34yu6+VrAf/KJgLJ
jOx9mMsT42dAh/SivGQ5uKTOR2iPtHf2yX5wM6v28d4FR3M49hfmUkOe5KqA
83iqnv8YuI97jtLeo/S/2mhwCZX1p03AKczkpn3CGWdfE3D0PqrvCgJX70TN
HczFh9w8PwbuW2dOry44cHJ8tP82aSSHTtm9u+tjwC3LunoUXYh87wZjcLXW
ObGagrPVf4aJdjnCF+0HB6r9RyIfuFDRkhfQRbnVJbBx0aA5Ofiu5Sw4RhfV
DqFLk/BJuip0wJxYblA2nkb9XM72H3o7M8pL0YWZrJdRBiemQJAPfRj3H3Jr
vgyHEBu+SnKCa8K3hXax2rrmjoO7Ufw0xgkcDr3sDPQ3LsfGngQnwnD1HLoR
eY4f0YvgzMojwTVoCixKBuegotUdfQO1EddwyOFPpsX5Qy7fayeJefz9Z9Ty
IDfeXrl3KeTIZzNol9I6LG4R5Jy3l62qgdzzqSk678zWL9kNudza8MBRyOlm
vqDzudskrXkhR2p+VX6sifrcRz7QedL3i+TOQW5wt8IIG+Qgo+7Q+cdVuVHC
kNNb/8ssBnJ7jAJ0Xm/yXQ/mytab0zkzT2k6X3bYQwdzUH9ip4YgF2U/n4fK
6zdCV/1XTfQ4OOsvTGhf/XlwFDrsvcPJveCyi8177KMJLD7gZQupMRwAPzuK
k3azRbY1o+/MmSa8B7znAzcuY/6x69FjyJ2Sj94zdYBP3HFgEPOnfimvroKf
O9r8hhc83YwdPzH/23wmfBV4r7vaq+6C/2pquxvz1476hB/4pN1njuuBV9rW
3YH5dzeu7bfB05S6b1kAvmapRSP6Ay8+R8uC/7jv1AM28CCZ/d+h/yCjXqQH
XqHcdL4X+IV2J8bQ3wjz63kIvl7MsHkBeHszQynon4ReGXwAHlxBXdFy8OHi
FdegP7M4vOXIm/v+JPeORmHwzLh0vqD/E8l/7kfblBW5qvfNa/C3qi51or+0
bZNn+99pKyLpxpIn4EWN6RejE1XCWsjVdN+feNZvJAu+0YZzY+gaxZgaTYC/
82NjzXHweAZi76HD08LRZQpezDnN6WLwY1hjS9GNKZHMfgy+yeLv+tfBO2m7
ooDOycrFkehxHF7t0w8+x0V72p+cbh/MBT8ioMToKXgSAvV30ZHweT2K3oF7
MO0fRFbQ7oGm+Ot8yOc/ynqBef1NWUOY0//9QT8Z8uQhZzfwQ748+wSdKyfs
+k9C/lle84I95KEvxr/DHPTtruAIyMcy96VwQH53jz6d232TQedLZ9OerYG8
aak4nTOVtluFech6kx5w7sk3gXQukr2lBPN7PCWm/JDn+zGf40u5zobuf7mc
M8u5IhOSV4v2/7O3KWNPwBnbgHroDVg73xdwbq3WHnDe97fILAb3ve0A7b2H
CKqvBZf8yep16JSbkLRPHhKenw+OdvK/DTfA1TZ6EIA56z8O7GbgPruav3AD
B7rzCAfm3JOZ7z0Fp7hoSCEH3OIHA7RX/FZ6hSK4ujVsFm7g7EoYv0bn4Y/z
dk5wYD8y70IXdn31UnQ2XHclbwW3lPRLYV+1IIEM9DqPzslF5q+N4Gz2hUlu
AHczdZL2Ni+kcTOCCxnL/owEJ1J1G+1DzpxluQOO4eas2w7gGgZzBqOztLHm
cRa4e2ErPZLA4XubW4bOlcA2EyeNLFvSe67eAdy4d6dfoDOWMZb75N4tW2LH
BJshOGdWV43RNzN/MNUJDtdFnoIpcLkq98SgxyW04v0Hk6dxhEco4zVwpF5f
rqf9KNbaNeAcOb89Ynae+j2/ytHO5EkJ7VFweU4NN6iD05P2eSX6PIcPnj8B
joyFcthmcGV6dmmhJ5PnMC4K7sk2ARZxuG4Hnpujf5LkUv8CnA59Ea4OP+o6
C6gGotdxM+ThTnAl4pycNvtSn0vpV9qXaMj0eA4OguV0hgzbuUCyqugFfo4+
QZbykNtvWhSLOf7rXFr4uR9q3NEDOfMRj94jkDuPY27BvLnsJ4OvkIt+edJr
BnLSe5g9MR/Nfj0Ac7zq0o6PINe79w6d5z3wKQtzp7qhInqQQyXm86fjE7XY
S6Fzqnkt9FRw9tL9FD6brbDH4qSy3VDc79/V0vN9FgnThSnQT9B+bJso9BXs
q6J7CtYs+nYEfPwK8zod8PXXZm3HPHuLeMgm8N/tR+yqwIOPYaEdeNMlN+TB
K++0Vk6I2uZGSqS6oefgsfcU+tpibTxR4G1/eduHnsZFFrt48KClBnvtwYfe
ltSAnslcg7Ml+MVmbGbt4Bl/u/QKPRkf+9Ul4O1+n5B1PVoeTH79+wY9n0uh
3BXgwzp0L9cd+h5Grjkii56S+6zoAfBMJz/q2oBv2jH9FT2rm3+ezYG/uTl1
rwZ4nPYZKeiJjUV8lgEvUvc1r9Jy/Why6T7ajXwo1eJ9utWeDNY5rAneocfq
m+jp/ZVl2H6xzZ4Ymf1dDT6fzg5BdPk4T3uHFgSFE2r91hLgyXUZmqEjZ7/A
IRq8Mxs/r3fgn922v017non6iuBzaZ/hQa9rd2ouOl0KfCtNwJO6fez7EvCl
Num4oysVf2AI/aNeBi8D8JC+px9BB0lP9Oox8Hre53/tcKCum9IjV3R7KjnV
n4Avo87vfQi8me4tUejMsL8YUAIP5dDSRfngo3i7hKCLsiJ/8A/4HextTDfA
85jypx2PZ3ORm8Cb6LnP/xv8icPdkuhOrB2JZgPv4OBO3TnwEvR20k6Cw753
tyHPv19BzhLy/Z4OdK4/tvIb5s/11l7Whjy6dx6dQ394wg7z0l/n89Np87np
g2eLsDfl5uMaW43cR9WFN+n+FPeA69izkszNK33vjVu1wHzfysWv5bPQqyHO
c/Ik9Gw0JdH9Gi8zn89BDwRn9MUL0AvRYkD3QXiE2yRBb8HBouurW5NuVEc3
0f0FF3PaN4Gzf0fpL49CRVJ1XcpDdEsivVzLwIWP0XxblNQUW232YyO6MVyF
O0+BY85zxGKvT7lftSnzPXR7umNHw8HdZnwdkM/674ziqU5jdJN+GZ32BCda
cPFMzhfuSMUTRrroVuXfOSAArnGSK6OR/Io0xaItjeiGtQai10aONL32/BWa
rSg177adNnBdCm6sZfmn+uTZAkW92Hh08wZbUxL7CyLIL7GnXhvLFima+GxH
t7CN9iLJO1dnT/r9yFP8M+9Gxk5yHi1IdCAOpm538yVuVy+wXIM/13uN/w5h
PjsgbsJbVB0//+8Mjqs5gtMnWZtUXrCnoDpzszf+d1X2iC7c7plGxGU4/Jkw
yK42SHLF3/NP+mtRcNCkPjJtdp66Ua0dWY9/1xx9HYhrfDlrOxUiqzXnrwOj
FnrlhGKLxr41/wyr/3fLiXYmLXCRpCufGN9776tY+7ESrzP7Pfd8cHwswu9l
UZ+LosstPvxcfs27M7sm/4gbTCcqXp33Z1JP6MeAk5I9XVXQ1HRDUepHEH7u
9+ddDzmV7csu+qcpHpn3PSoVKnjBofjkVHnWJjxdsfB5B95X1vNugtX2ihWa
OY8Um+f9hP9z/iYec1Lr3rop/p/3b/+chL0+clqbV0LPT5oY3e/DvPoq9gB5
nX9eAr1AH+f7gDZ+ORQAfTBzvS1Dd8suEPzD+vT36KoLH4zPCuUOjee+Xib8
/37H790uz3wp6Nu4M1JfSn1PCYbVdO/GXUNJ7IfYpnB0C/RFiFux4vf68b9B
degz4OmbeAH9Br/9Q3EckF2c2gL+vp1ETgt4/GeDw3Hc+F220gW8eN1IaSt7
7QDC+IcNjjNmr/3Pg29+9ZKcODUuEcqOxjguhXkGWoLH/TpGqabjexghuyQE
x7FGPjU58KNDA2wjwJM+VECPewWqnXHgHe/vONkJ/nGjRR6Ok/Kpxi351Phs
ZOppQo2rxOGdF3BcPbJ2xUFqHCY/bnN4Cr6sz00BHIdrT8cdM261J0Q8clvB
Q82UD8Jx237ppRVPqfF5QXxTIvidkWJ+OM6rrxzUA18yKrRlK3iTKU21OC94
XcwKBw8xnuOuG/iIrFz3cR4Jqm2IB78vItW9c4D6u+r4zuK8wzn0swK8uW1D
3YbUPEXIN7TgPBWUP2YKPtqqK1WfwEtb/r4N5zXxa/Kp4HkFmQcvaADfq7ga
50Entbcm4E8defBcHDyq71pdOG/ub2KSBi+p3TvtLfhJ0a4eOM8eUCdWge8z
tHIr9LQQiqy08/O/R/O/T/O/SzOeElQDfkpeIHOABXVfuX5/gPP+tvc16H0I
cfIeAf9DcoR2P5KNNdGnkCGaD4BX0T7vVFSuFcPeqesvxxugh8p1gO6fUrnO
hj1Vgu8LjKG3Sni+r0p8+PhL6DEqsJaqgl4jaQu6z+iFStJv6N2pYS25BT08
95Y147qIx/+cGvTEpPFtFILeGMbnR2kH6ejHNug1uWlftQN6TpzW0f0m6nXl
2MNxdXrTH5/PYcTFhVm4TmNg/PgJeiO2riTqoEfigbEnruuYsz5thp6D7LW/
JKD3QC/ZCteBCWprj4HLf673mAy1biQu5xzFdaMg8/Xv4MibFqdMBvYmEmsH
N+M605ovTAvc8xSfxjfgoMeXpOC61IlpXR043eqL7p8Ht7soow3Xsbk55kfB
lfa8L/EKnOlx1gxc9w4wa5gX37IlxbItzoOLnPvADNfJ2aX37oPbq7IuQxsc
3zedn3BdzfhVRO8xtX7WzWesA3eW/60brsM/Vi7pBRc1py0D1u3EQ0svXLcL
PmTbAY5ndqL4M3A9szNUcJ3PyfbhOriT0wVvWMGhTEnWwn0Bj/YAGziJ6SNf
c8FNdHD0x32Ey9DGZeD6FTvqf4XrdjeY9v0Sjj8kwKGrrr7TBC5duchT3Kd4
nJCvAzdtbF+hAThqDAqRuK/REUs/B86XTqFgE7hfjlVs+DnKK4+mgUtVxvja
C5wqu0sh+Ll3dyYzg6N06DZjB7XPIo40x+I+S/7OOLo/MSfVZcEB8qul/Z+Z
cx/RqWHrvcwNbo1ZIu3VZLZMoavyVPvzWnBWfq6gfZUFO+YuQS+aYFTIKPSk
PUqn+9HE53vUvrBLCkOvGuN8n9ojpTrs3+rvjVgGfVzsV+gerrxlt5PhfGO8
TpAZ+qPy+uneqOh7iUbQb3Tu6RYr6Ds6qE57X5sSd+ZCH0+zI99e6Of5Os2B
++LGs2thH01Ki729A30yPVuHcR/dZSpaD30n7W/7BaD/ZMN+M9x3l919nQz9
HLXqxAfo6+AfLMR9evfkXBH0SSw9ZI39Ej8XGtG9EqYCndB/8E7Utgj6EDb6
CeE5gMPWmbfg9TeX37kBfv++4Dw8Nwgz6u0GX/7mIhMN8OYbuivxnCExMssT
PHSXd3fVwEfXPf8BzyX8mT5O9U1bkQ6v9BjB815RlojnGAe7N7c2TFkR0scL
SPCnz1z6i+ceBw4H7Acf2cYnhBO8ZFN5ZvTeF/VWqIHn6+9aAecqRDnHVjxX
2brPahf4s6IaBkXg0QbsLsFzmBMMtS7gpY4/3BQBfuqNw4N4brPqV5AR+J6H
A0OkwfsUiqOdz0NCLDfBo2QvEsgCn/JN/As8F7KzGLoFfmLyt5Ag8BQZjjXg
OdJURQicOxH3At3rwP9zj5LDcyedgEvO4NMJWN6Dcyri8V/aqVsQ6wc9W0RP
6/cJ8NX4NGlXzVusMR3ON0wWLNcAD8zjpi2eg/kIXU8Er2pllO928KtsNi3B
c7PW5u3oK9UsKkFvScCddpbM94ihB2RfX5QBPpDQvAv0basc9vY9uKqlAj1+
TJl0f5/bLD/2/B381wvuEfFjvu8vbsyNCXrj4rn/JUKPnBGnJZ4TXv/ZZg3n
zwb/Xm+A3rPgWrrvrLNQfSv0cnHeaVsIPV2hXnQ/15es473QI6VV9ek39Er1
CdLnlmRg7FLsPSo42gQ9SH0X6P4jfR+9Eujp2T16mgl6e/qdtPFc1IOP0xp6
ZZj3rA+FnhnZmcd4jhrlvikEelDqjIaxF6VjxhfPXWtt7plCb8df0QYSejxE
9w/gOe2IVJkV9EzI6FU5QO/Es29peK575YM8nAOTv3/gOTDBPn8OXJN1Bh3/
r2wF+8D1Lz1Mu+LK565WRgyYkwPxjZPg0D9spl33fIGkjQsGzYk5pYjT4Kaz
TR3Fc+lGmbIa7wAv4tm+OA5wvpnfW+I5dnPEpD441N/X/LoALvWxZQvx3Nsv
qy4I3OQFuoeTwFFe1rsHz8nD7EWWgfNbKD5hCO7vhq+X8Vw9wTjlHLi0ilbC
3uDU+vUW4jn8qbulfuCoJpzKVQFX1fXXdjy3/zrSqQju546g0ZPggKp9oc/5
XXnUZMGp1H11OQPcytEPY/hcYOHZ2DpwFVds9n0EzmLAAdpXNMuYjgcHcP9b
05ky6nPnDdyPzx0u7PyGbh1jeYwwOHZ/ntN+nddcsCA4a3FZ3xvAXQv62obP
Nbr0F6MLdkqg8Ao4Yc+HaR9M8qctOlavKvregmslPO9ZVQsZYK/kmm3jQdAz
adBK90tqvLyJPZTrbWyMoZeyYb6P0q5echT6Dq9v6cb+Q04GuvewyK3HE54P
fnBXuwl9fb+Z6Oc+jzitNkOfnNQ//w/QL7fxAP2cqN+7sxv6z8TdNXOgD20q
gH6utNJtWQT0ddnvS3gA/V3TAiH4HCpPXbkS+qXedDAXQd9UdiTtx/7fh/R/
P9L/vUgql6JKoL+n84HSCujzIb3V8LnYuet12dA3c0dDEftnjAQC8Tma/4/1
Pbt2BZOVxz3guRtxkyMKn7sZqJnshT6Pu12b66Df44G5Ez6nI4SVlaB/omZQ
mQn6KJZ988HnesxqM6sbthmT4nEHjKA/YU99Dz4HPHhDQA18/y/afx9ATm59
eys+N7w75tC1SMiF2Fr4thF8+hsL6OeMWSF198FPVyrXhueSBNMrEp9Lju/K
6wTvW3/AYBX433d5uPA55jpNxePgUy9Lq80Ar/p71H78u2YWpi0DT/mogLo1
+MrPUunnpLFLAnaD/ysQpHsNrlvscbo/a/lD5Zvg1a7zH8sFv/axP/0c9kOK
vif4qprNw4XgrY4L0s9tJ7pSOcEDXcB4pgl80MvN9HPe45UnL4Nf2a/ZfBQ8
y2v/6OfCvXfXmcLzwSrhvBDwFx/cop8ja5qYWYMPeOpc3VbwAg0qaSewd6/E
Y/DsDKbyu8G3871Au3a8VwTRXzve+EYNPDbTeYft0OFi7D19xjvqCT2o3lJ0
/+n/PanLN+hhb+r/fal5eUnM0NN5UOJxM/R2fo2g+zqffVi5GXolJZbevwM9
k4et6efyy94uY3C+6EWG26bzQS/irVj6Ob4664oe6O3j61M6DT1+Jg60E7sz
N84ReuZMNbgroHdOfxvdN7edq+cQ9KJZW+tOgAecZ0T3o53hqs2HHq+nN6Mq
wWMWXEP3edUuzjwOvVPriiOwhypDl+6f2qTf2g89SXOGvWbQm2TeIY3vOUj7
SE9Cr0/to9vO0POzvyUb34twPstQGlfhSiaxMYRAL420IN1Hs/iEmi30pujf
K7GAHhVVhUf43sVae4ta+4/a5K/XO92g9+PS9Cd8TyPtpO0Sz8/axI4MXW7o
qdDfSfdT1OaNvIUeBXmdJyXQq2AsK4b/jtVfBRLc/8RNz85CD0B6BO3/G1yW
EQKnfn2kAgluvajfSnzP5HiGSwq46qstuP+Cs97kSfvqrv/wPRZiXLNeElzw
V8y0Bz60YOVScKtnx7b3w3UL+Ez71RfefVwOzvKdVAsPuM4jBdvxPZkjvnI2
4AK/StJDJ7h68SN8r0a0QjEXHNvJkRvQV0mwitPv4XzT2ykB7uqDjiFucFh/
ZdDv7Wx4GVoMTuiIz7tj4IaWH6Pf8zGP++EBruU79vZYcC53VNG+pRhb4zZw
GGX3tqqDy3jiGu0xMtRYohvo2JBUCI5g9bwfmMGcib28SfM9vYzz/bxVawOw
x3d17jrs9f2/z5eLq0cM+mW/uvdg32z2fM+sQu2Tp9CHKrf1+0PoR5UapXtR
QzovwntW5AOTe9jn+duR9nizZ0y0oW9y+7uhHuifNPlD907uLAqVhH7EQuv9
Q9CXaOhA9ySqZN7whT6/iQi636+0h+7167pK98+1fxYcgT66RdV0D92+/hhm
6EszNJfA/rSNMnRvWv39r67Q75Wx0gj7vvhnhvE9tM1f3v+EPiqVZP1g6Kdy
3E/3UplYqlRAf9KP/V4K0KfEqEX3KAn++D4afMqEHNu5rAP6f4JSxvC9ONOX
OtukjNTJ7gNckdBXIzxG99So6fVe07ekFvn8idiv0q9K96oI6gSIS56i1oGe
rz5AH0jJmr34nl6y21Pm1e1WxJwoTyH0VyxuL8H3+q4/iquBfgW5l1nYt2A1
Q/csnL8cvBf6AHwTP3FCP4BDMN0LEHPgrAD49Yanh9Czd7pFO/ZKbzM5wVtv
i4i8Cv46kwkHvpfo5O6+D3zwH8W/A8ALnxymnXAljYlG8KzPD4ZNgW+9UIJ+
79Hr5onX4C+r3Xm5Gzxm/iu0w3wmnLkGvGDBN9d+gB8s1ki7wQz9r9+Ab9s/
+akDvFvVOPo9zENSAqfBYy0u6NgJPuvZeZd13Hc9+qFVS8ovgyfqzUI7ov97
l//7l/+7l3dPm6B32S7/Jxz8y6Ny9Huk213lasEN1NKqSQZH0LyOfl/6ztMd
0bof7EgRv84QHy5vMtT2CL6vvkRq71Jw2cI0rNFpM1hI+2wzC+X6x2udycvd
QT6j/KGk2prGOHiPOkojAN2rCtvpWXCw/nLQ/tXZUOWHoaWu5LfjyyMaF8WS
2/LP34S8Usw5uURwhT4daF8CzlBoGu0LGRimbusfcCJPmZyM6GVJJJ8wPP4F
eb37JunRokXWZPnbHAvwRYKWz2Au9XPXQ1Hds6akulSJ4ah2GrmUO+cw5ILT
j0eg13By/ZgN+A3D9v8wl/1B8D6rWqYKwXi2yu/jvzRSp9RTHe7D+m/rVTEP
n6AiBPn4t/5amIvPMH1kLffqEsEXW92cLpJGFl5zMocct7/VVQ3IG5uv0JaB
/PGOCy2YO7bwPqUoaOZElERopnziTybrhxq0IL8gcz+gBnKGayeODkLu0PYS
nTfMcLvU/svUlejxy0ywPB5DOmZ4fYd8HBn98TPkuEr3CmOuqzWGznMJzkzu
G55yJOwExg5UDQaTRKXaX8gfLd7wTgRyMitll52A3EyDMZ2XqU7qfrrCxYZa
Z2z+0cnnRRbGRWG+QzOUDXMIdp5WAZBLqIii8wjOjp73nkT4Ert3+fZvSbYi
r60+gu/PNzBU4nveewqr8b3vb/Pve4vw0Y6qXOysAbiqFn9oT1W3X1kJPMrr
tTVK4FP+XEa/t3+sSp0TXD/m57eOgfP3h4/Op/gwafQkL/QjPT0CPvo/DyKV
EpZiPmgLtW8EN605sskEHDVh6zHMZ8UbRdmA86UlOp4H7tcutb+Yj1v0zfQL
uFQpHANu4FSpytD5RAVfiXJwlDi2SlSDq1T9XQrzoXv85EzAo0lo2HQEfJqv
s9mYg9ZzWpkFrkfqai8lcD7cdohh3t+yREnQOFyJqJCdVQKX4t2jo+gtrLRZ
xlxx9SKhf9quDhwF23baTwjq0dKAnH+W1fhryP3bLjbCvP+eC5+5IZfunbv/
AeTUU9bT+XQ/yZ5CyFG7zlr3Qa5aj4/APPWmoxOekEeNGt77EfKpERp0LrUv
cj835PqSkvsHIefXWk3n+1g5dqRADk2EsbUCcmmMcXQerSNmiRHkplLLfTFH
VRZG56dKjETqIOfzOn9BJuR+ukXpvA/rcGkj5FKSdn1YAjmVp/fpfErODssV
PxeGE5UKjxl6PS6SXEI2mKeQa3qI7/33n8jLgByAwPz7/6oSoejqfh6TPA/O
rpwQ7eu+5+mNAJ+02rB28qWtBykdRuc+zt1hQefRb6X/LnAfmQ/Q3qN1Ud4s
kRVJjmZuUgY/b0gjHXN8rweGt4HvFnLjFCN4b1cudGOOcneXzw/wyLKmFoeB
Tzb0hgtzrLtTCufKN0eSXC7Ku8HTUj2/ZAByxKJLcg8tlwkgb7x/+htcoo/Z
nJiXTw1a7hvEZkO6HytF3yWm8CC6EE9rFaWLb18mJpaMLgEn47TkLfQxZiWO
j4DjoBXgJgSuQ02pB3oOUVPRz8AdiE8YfAgOAaF9E/0BRc6HbJCTD9n1YQBy
88OHnDAvP7slchTyxsURAbcgf7z6VSTmjvnsQnMgt8ndU/sUcpysunR+c4Ox
bCnk395P6/RAHq5ths7Bfbjr3QJ5rc2GS29Bfmt/Mp3bcvtpsB/yRXF7HjdC
3ij6Lp0z8n3+uqx+KprgfHFQXDHOjnQTyqqHXMyQ/2bMb6gVS+dCnmPjHTrH
MXZH5gz4yIPJtY7gJQsvpp3k8d3ml8GZ3c8mcg7c2dMNtDfLnvleGbzOx8H9
reB38rTQbuefe20x4B66q515Cw4ieeYk5jcFVY0UwI+TEv/tCp7cOe1kzCl7
mJ65C96Z4YRpM/hny87/wJz4zT+Jx8GN+mFScBIcqdYty9CP2qNhx8oefYU8
9fx7Lng86Vrr0f3QPD16pvKyLRERGvPX1i6LZB98ip4J+3txN/AgsrQk5cCH
2HZBH12I3WFuEeAXJLX/PQqeweyvAXQM0qRKoiAHHlcnaQ658ELDScyDl9rV
NkOe9hNnQRnka83U6FxteeDSHsglPuH7OK1cGEY2b3DBfGLyqy8ekO9iVJVV
gbyXaSft3KpLN6y3kIsjongtatj1XMg3lYxukEvKuWOJ+RnZ80zmkKcpms/R
XEunfeqXsqat4FV7zTvV05VBBuD8aq18XAnu7/hoPOazTsxMQf6QNPLwjgU/
9aPATswhFmTPWoI7KaZl8gkcyuZl/Ji3ZU23YQK/b0h7WSp4fqNVtpgrD1op
XgU+V8lGoUzwurKvcqFTwSFYlR5R4Ef2thrqg3vkUHQFPZayh8aqrtE2hEr6
FgnwYxJiVNGN6d+eHgDuhs/+izbgcJz+lon+xtdM3RrI1XsMv2eEnL04SXt9
/+eT/88r/59T1rb+mwQ5T60IJVvIffak0nnPKhmmMMjLbbvEswTyc3+f07m5
0XWrMHc0XPUIXG1Sq4DOHwmU5KPrrfOUaxKc7xEJ2vc+Nm0xnJeUSObeep37
T8qBzOZd2gT5rGj90G3gJv/g61MFR5nhOe0n85cUC4Hzy/lUPBXc38SnOZhP
NJBW/wYureZd+SPg1F5eIYP5ULv8Yz/vmNwkTdPGxNFVze/EfG6YtKEIuJ9D
AlGp4IBKmQ9iPvpMku5mcCpXkVUJ4FY+fO2N+fS73edawVWUntxzHpzF3ikP
9AGkFUUDwQG8zXj/A7iAG6ai0Wdo+/7lXXnYNdLazUodfLXYCRV0SAyi2YrB
/8oxZboJHhjXsTF0YLjbigibF45k3+ClA+BX7SjpRoenodBu/8UiSyL86cRT
8JZSgqePgYPkONR6AzygpAz+3eADXXYxRhfo7f1Jsc/tscTizUF300pvkM+n
3NCxUX3ntwG8lc4jbmcdH6aQQltG0GEbqjiiAT7IhcUCeeCFvOYvRSekvewT
OguGxdUR4C58SH2C3gLP3kPj4AKcceZ/DU6ALON39AE6s5/WQ479t/y7Ssi1
+zsrY57dIKLKBHLXzteXqy6WCCLPHqS9WclXyVOQE37yxnIz5Ibfz9F54fEL
0i8h1zrbcek45FzNKhgw3/r3UJor5DDf13T+gVzm0kPnMI/JzR5nES2WT+jx
vc9d5GNOjnxxWRn6+wfxJPKfB+TcFLfTuTcFSzrv9uQhAzryCRLp6MonnKQ9
+dC/zkPgcU8t3NulZWFFdmt3Yk5TqUNpFfjRKzIOXQNP+uAmBgfIyeoasiwF
77iKq+Pb/vfOJF+VCeaUHz0gFoDPe2xYh3NriQc5nb8Jc+JnH6+AfD7J98r+
FviyOoEvMad/0IpjAPxTpX6tGvBQPV+wopNwV3AxK3idw0zcll1HgsjeERF0
KrRNy5TBl5wte7WgIS6U3MMXik7I359hKuD0+Z8JABeHlA1xRQ+naeDCwevg
naXlNIB/NlUwtRDcJ3NBasNgfYYQSR3mnKiPJgebv2nAfEfejWMpsQkkZNnV
NoIvtY5hFF2puK0LhZfGxhEfn3/WX90bRUYaS6ODZO2sXgteD6tSNBf4PbJy
19Ht2XFhQzL4Mnc0Tt2Z4okgP/1VRmfm4R6u1eB0tPa+1OurDSQdByzQ6yg5
Xn4QvIO8Qn5D8A+aVtHuQbkg6xzk8wOlTli+euBOHmYexpy+4tNTmCdfPOhx
qnPSiTwXn4y5ct2ZrRGQfw73EumDPPSdfmbMQYfm+I9BXrdSuUToG88lsvmU
A+Z2p5TXO4mdvU18/1h6TFjQmJRM3NYCOdP7ux5hHlInJUEJ8pFtw3QuUiyJ
H/sGjmkNSlaUChLFPnTvwIebbrfAbT8S9hMdd0/pVMz/Xky/Ygj+tYrbZH+U
8HbiXkUo5tx3KVTmgtfMWnrTTHONCDGY+QudATk+y6PgC/OYaVt82S9GMNxj
QufBg0/cFzxc8kzkMfYL4kRaWyI6G6IMUYt6XLPIgJkWhtXy4kT8zCN0Tuyk
xAfBG+WauvJaPkiU+Js53gHOjO/G+EJwGy8zHXxSqcNPTHjEoKfkxvqIf3iP
H1m08emgvu8qwif/GLph+1+6K1E/J0r2xH5/77uKzAzUwp/nZz3zigmMJfib
/axjjvCQH5lvoX8VrfisEZwmcwuxF4d1+Mn862H472+qP6wGrlCiso3XaTkh
8qXrAPpC8i7Wq8Fn4Vh9YVmPnDi5Qqocf//77/tVwLloduEEd5k0F1qO1+Fb
9aPD4AUwOQz0FAlvJ5Xr4vB6Bqg5j0O+3SAjp+trGz95d1Mh5tx7F/Tdhjz2
L5dBk97ULSTbOtrV131kf6llJpuojLW+pNonQR4rl1/BSM1TGxyPYd7V1Hs5
f1WpICmyic69dr+swD6JaA4bPuiX6OmmeyVEg4S7weV/ZHZqJTj9Ieq0z39q
mOU7+ObGvbwbwTvn/XId78/mVoET4EQvvZp0DtzoyT2VeJ/bnZorB9fYLKm8
r+iUH9F1WgV9lfruESFweH895pH+UhtIeN45j9+XI+WKf8CN/bMnVBsc2bO2
NugLqaQdSQN/c/qfxUbwOJcUpeH30bDMvbDIJpAMP2joQ32vCfemX/i9jljP
8QY8uCPHl/SBD1dwlB4fZrg+tIGrxbksag84WwZFETiexNQ1vAMH6nv5uV3O
MREEU5YdelCrLZk3g6ejsf3RFPg6axQEcbz6sLzsG7gkel28KuCUxLx6guNe
/Fw8IzV+EgX6pZtV3jsTrznNcfw8cIXOyT9UTZKA3PyYGZ2XPxN3ckvip3Qi
lu2jXIWPCaE0aDAG+e77r8oxh8ydpmn7seAgcTuEziN/X/wPez50fl/4CL0f
OT1038fnqo2m0JcwKZpUCv0J5jMXcR7xs7q+FNx59iWLmKj5iPC6R/vzDO3N
6Hf7uQr7gue9NZt2Wngk3w+Cg3y+lyUZXOSqqec4P+Y0vx0PXJtORhyLtQHH
12k7L3pQLIsTj4J/2hUm0QMeapouI7pnwR46nuBINq/xZgdXsibKCedxK19f
qcsvHIldNqtFwOc7zv4T1wOKwQc3g2um0/9mHzhnqgq7cV3hZzT4CNyi9e+H
l1DrE4KTMRHXJ2GftcTAf7na8eQHeDCpop24zhl7xjACjsbrs45h4GpYn5fC
9RJLKPtG8Ah4TafMwSfgPCiK666/b8cx1836S4IFct567+l892D4Q+xN2Xyi
fwJ6VI4tforrvVeDS20cs2LJCbuPef8G3YicGYFZyPsvl/yMvRQlY33j6g+9
ifASup8iOmk2FHoUqh40F0CvguFu2rsI/vQiB9z/gtRH4dAD0HWQBdefm9sL
TcGpN+BVCAC3/n6hHnovvot/q4CrvtC4zgyc9YtdTbiOnVN6Bs4R2dCy3B1c
8E0HT6J3tO5xBeOURSqpqR1XB461ky3tTT1W37Vp23QSGegVsw3c5RxWJfS+
3jFZEzJ/48ntSQ/+gRNsuMEJvTV/P0Y7cGz5bpEXwLXVS8jH9XbzqKOkbnYA
mZT4OxEcVvHePvQGU5/MDoET+vYky0VwQ2PvS+C6/bBGuumz/IvEm0lRL3Au
y7vPom9puO+1JTiMdx4qqILLuC7jJq7/o78uHbRMiyKKVsmUgyOo1TyJfuBt
6SBpcO4q9RbkgXvnLCmB+wi/EWlzcNmKFfKPgNPGfOsI+mz10tzT4FuxBcZG
gndlpe6M+xFD1t0y4DH1zUW4gs/Uxb4TXSausGLY1xBXVub9pfY1xN/9W3Bf
s6qL7ADvhl9pzXfwb3jW6aF782r/z2TwWXSPTlSC1zL8mHZaeBh2CIMnEj5x
KBR8kT8na9AVaWP0QP9C5nJxGngYF4TjcJ/1LWqHi8COHOLDePZhDb+LhIR0
7HlwG668PYm+AFPIkkbwBi7NOwOSD+j+npU5ly5Cn08qE93jQ44OuUIPyqTN
xqPQi7LnKb1P9HYOfAO9HTMT8Xuhx2PJcdpjWTMWOwA9Ex9CV/+F3gn3E7SH
Y77ZuAB6EWJbuJmgJ+Ghz2/0iBgXr0LHP8HxwT1w/QM0ac//k/TjP+DO+y++
rAUOffuvC+hxXT5pcRqcdJ+sjeimE3EMmrD/vZzsWgqut2XOu+fgfBsc9kSP
7q8kzw3wkZNq7XaDl7xlnzbur7W/ZvC8tPUln/5W2w++L6//fXQvb1y2/Q3+
7IvZ5bBPJ/R/PsF9ut/2K/v5x04QHiXPQ8BPrd/Cj27q4kOn+sD3PKCqi96n
yFs23O/b+zVkgEfpenBBK/iUyiYR6FIyeXSEg59Yoq5gCJ7irZI5dBTtlj2z
AO8vdNvBSfD/4o/0oPs3GmMjBG7a26l7uuCoKQhk47mE20Ag+lOrTFVfgEdV
TNIOVVnBBm/wkiyOivOAn+R9/wG6SZ4VX3eC7yMuJ/8MvJ8xIy08D8mp+poM
Hs1gxbLly3t9iSNlbOjS5PL0BYCfItT7/Ax4KmHJtKPywmLac+26NOKnekjh
7tHLhMtVxYfgfiRoqKFPIRvz1xW8io9XaKdCXUXyA/Q/eb1sT4U+KKUhugfK
VbNaCnp05N5qNkCvzq35Pp31n+ofQx9J7PdL76GfRNmaPl+6vLGDA/ozjCaZ
eKBP49It2rlqygrNg74HvdQOOKcieNnoc6ozoe1LNBSjyCh1CwnoK3ButkHn
jV/1Xj94+jKSV3PA17/TGYXnXev3SoeA/346dOgJePAtJ/aicxhgJRQDjjZx
orYMXG2m1bSnHfXgd0vx7cvkmRd5c+ATMyy/jedyf+2e6T4rZSFu9IcloKf7
kAMdXTbhFVvAe92eEFIF/usfeU083+t5oH0bfNJp25QR8Eqfr3mETumV7QpX
wNN86/UEzgkJb3sOPCe8dtVewCAmlFALX5IDHmSpvDI6kEHqI4x/OKMI9oLF
4eDqXRJZj+eQclUWi5SyIgmrD157wSd7cJvuAeFZHfkIXCdPlZi94DydYKXP
P312jPBfEgwkVJe+2txT7UMcs3mCHlFeTvA1cHMK2Ip+gqMTeZ4+Rx1cO8fV
cSmG6P9DbNpuaEuwlBmYgffyY6fcLnBJhMPiLMApCXtC+yT3N2hj75d9dWMs
9IBlzvd/Bd4+eB/6k6L1RRigTylpLd2jNM2Vog09ND0rDT2hl0a/jD5PZlon
wgt9Hl9sd72Dfo9BX7rXYybL4w/0T4y9mVwIfRRam+geCu0q/1DoS2hoWYb9
CUzb6N6Ec2zVnuD733Vv5gHvX1j8DrqXbOK+68FJF7BWyQM3/fu+CTw/t2Oa
qX1w9SJpYuxXAf50SwftTotvot1ehacSMuD42siI43m+7/Oys+DMju+SuQXu
rPWrQvRm/bfN3gUX9WNqnSI4qcPL8/C5QJ3s6cPgeG48cnkPuJ7/dt5Dz1PN
2qsbPETRECt47kD8CqWfOxwYLHoHrtzVdgN1cOYKQyfw+YW02xAv+Fwlg1WH
wev6vYV+DvKSzN0HzpF78aad4B7lC9LPTdbItNdOn/Aj4oe4hQdEbIg1qZno
85zq4kRHJi8q+zC4Mtcv0p6MQ/QI9rQ9G6V72yTn+9r6dru7Qt/Vrq2fsf+K
mO+9mnHWE4XeINUfP7FHyKGN7g96+nz4G/SvyDhXZEIfC8sWuodlonWiF3os
Ju1GRqDXYtsbus/i1Ia4bO8SF5LxmXfqAdPrhF6lYBesf0IP3jIDv37GJfEQ
ePZLN9GOfZi7OjjUZPHxg7Lggnu+oj3wjSzOSjunjhJ5XDucwVd+uZt2lZtL
dVvApc2tD0Kn1moJ7dPuW+29JtHDngiVyJU0e5hM9Nz/7gGeamfd7TjwKAPf
snKCT1n66BY+Z/z6z2wduH4vjI8tAedP9DHt+7neGv8FPprEYvsg8NK+e9JO
Wn4Xazk4U5MFlnfAneqIp5+fkpXW6PUs8XHLA79nazX9vLViYNEi6vchjVrO
baB+H/Ji7y/8ffSPd96krg/hZ384hro+5LElwnh9ohdVV1KfLyn6c4049fmS
yW/pz/dQUvQl6KUobjx/EHoqPoYX4/02YjYqCb5/yVqtMvD+Tevz8b51tChw
Bx9202W1beDFTpH5+H3JadX4Bc7msIDnEnA3XyTR3uY/o+iN1PhAKlo8EaHG
B3LpDnp8mOI2EaXGGTKKk1uUGmfI4ux6HGeaqy+vpcY3Uq/2zh3oxxBtU8Lx
7ULyeznoFaj+SX6HnoHdSvU4TpoxXxcvKGMhI+Vfp4Pn0OrEiuOtYdytRPBq
RY7u6gC/1v/ibhzPO87cZgX3k3v2OfTYkH+vWOO8UL0iagk1vxAqfbm7wFNk
bKF7mq53yPtT8x0548h5h5rvyOTTu3G+c3+nkAW9a7N2xkuoeZNsa2bFefO6
W6Un9FclPTPaAn1WplH0/GusSWpDn0erguAY9HtMn6dd3x7nh5XQiyDrV/UC
ehJGlCJxnWBWeHaf2NgJckg5Pg68+baVG3G9sem1tRs43d67B6GXgFRXqsF1
C8vFjHJweA95bukCl/f8bkdc/7A3/l3BsC6BcEwoUQXfdOMZc1xHPeW3zgIX
8szPLXOi+6PJn4vGcD1mJXIV+tiIEyaHdoK390uoD9d1mZoP/Kn1JJm1+48R
tZ4kdw0G4XqSg3WZAvTMjZxsuAK9c7aK1bgu9f22pRf6ugry+Eegv+ucsg6u
by/4Jq+B3qPIVd/VoAfp8F8VXCe7PB9Qh16TkP1zytBzItShi+vtFXZ3jkM/
xJbzPBXQFzF17iuu250UFGtf518ktwAeuySLjCE1cP2/Wda7Szs7gOA3kg0E
v/xHCmMr7COmmn+92fk3nviwUGJ1qUo6ye/ghfuRS9kqTNT+hbh19soqcIub
NI7h/sWIfc8X8F57Z9XMwX99lK2N+yB19QgTcDPZzNZfB0dT2ZD2M9mranzB
H+Q+mlMMHmHW1TTcl5X1Ez7U/o44pld8j9rfkUqf+XB/18dzY5ra/xJs088N
wEU+MbsJ97/RWRs3Uvt30tXsN0O5jwkZXnEG9+/+a0MboMflyY8bqtDrkn0v
BM8THjnt4AE3mfNmQ9Z5tlDyMdNxPN84/Pk89D8ReYEcOuDRLuM4jOckRqWR
Vi0z2SQL51IrjT4JYkerHJ7nFKgarMrSSyVj5Z51d7fxE6weuXguNCdqqww9
MfmPJjw85YQIC86veB41cDbIMCYwltyzYM0Z6aM8xKKS23iuJVTr3A9ecySn
Yot8kChZWT6B52kNynxe4N4e/ZiuueGCODnTmYznct4xQjfBD11T+tvIeY0I
eeX+OJ7vFXUNe4mdvU3eL5+2FRI0Jo408uB5YzCzTSb0Dq5hVU2DHsI0O0Y8
t5xwaF4K/W1WpfG3oc9Ngn0Qzz/X664ogT6bn4cymyZ5Iog3v/fj+eqvT9aa
S2PjSE5GKdbVvVHEQiNZPKe9FFhpxG99huw2/Gk4UR9NWE59wvNeZvdv/OBN
c3BI5TyNCyWE1mbgefKNddbd4PbWpeeuihzwI4zXrMFz6ajIlUzgn7ZMlrLx
l3gQEblceL69kvfD3FbhVCL/t8cTcCWvBizEc3KL5kuu0WL5ZMej+opFPubE
edISz+cfRwV+hj7FTquYW9CvOBIwjb2Kx8cIcFrJv85lhxZLBBGWsh74vGDa
4jEL9Hsdb/epgL6vMNY+fO5w/ZzUCejvybLNOAJ9PjI69fj8YrewjODn9ljS
bVW0O/Si/LgXhM9BLtasWmxWZEkq5rxqhH4J2Zo5fJ5Sdlz3+BvZMELAzrIJ
nP4NwuX0cxmBF1rgbtdnsDwFhzuOsRSf7xyw12UHv/iM8tIs8IwzOYLwOZFP
95vhOyY3ieWTh/u9OcOIx7Wf8HlTY/RNHvA0H6ik+YGvmXY0H59bKZQfXHA7
KZHou3qs65+UA7Fh2SJ8/tWwQoHNQi6OPDZ+/Bm7ngsRfG8BPq8sOFFVAf1D
Ao0jKtBHpO3Xj89Ps36sfQzet5Xx05fgfzfIfcPnud0nH9yvn4omx4NY+BXj
7Ih705n4PFpEK+cj9FDaH6hNgV5K9v30c+2s7v0VnxxDyewytyHoNZLSdsPn
6ed1a9ihD8bGJpYb+mHiovzwubxCN8sq8MST9pTvAl/c2YkJ3wfYzCckAC5z
eKDuRKLYNUJUpgffK/Aur+H4uTCc5L1P/unxuEgwXL+M7z+YaX58Cv2XZilx
adCH6SFCv0fxRyExDXoEd65lx17BrPV0n2C7Tt096FVaONWNPUv1k3vxfY9k
jV1Zn8OdyOciMy+gr0aL1xjfG9GLFhI0CVcin1WqCkDvx75tJ/H9E958SXi/
hWC6lFAKDnrGvR34fkuZBGkBfvQtxaYs8KSn1MbwPZk31pNvkxf6Ed7m/zr8
nwcRqUdZ8H0b9bcuj55E+JILC3q/bUm2Iq4lHsb3f95EXmlZ4WJDXggI+tPJ
50XoHqPfIzrPx3BoeMqRNNG1P1Y1GEwwrqffRzr2/MjLX6aupPUt4xuWx2OI
modX8b0m1QNDwoJmTmTF5ETuJ/5kolv7Cb4ftdWBN1j+1SXSuvVgW7pIGtFR
bYvvWb1N/S6pnKlCitkfifn4L41ILnHG97W8yosv6p41JVbwmJqNaqcRR5kz
8b0vbu8a0X5w3jP4EntZEgnrihp8f2zw7UhVaKkr8dspNLlxUSzxzfMcvofW
vT343XitMxHi2Ro9yh9KnDd9hu+zLRkOCNf9YEe4q7hf9+HyJjQY6PfiVFY/
1eYh7MjcBuU0LQ8vMu+1nE4y9XOXhRqPLN85kc5GUlxn4oLJEqPROmHq54/1
nVrFnFzJjyop1eNl0eSBkEAOR+q/K2E1smlBtQs5arX4iMSFBHIy4WSCN/V7
CqT1X+GcMyOPbOWY0lBJIy+wNMm9AYequD1ZVYmTEEhK+t7/L42M6pF/CNeB
e3Eo90Jjc6Jr8OvPbXZppLPyu2eV8L6lxIJ1Mfn2hOOmxwufOaeQaeItXlep
67z6pPtUnYUrMcag6XPDOYb8ZeYurUf9PnPic0M3r1H7utOulfW/Q8i/hHQv
vtdx5dehpD5b4uoc80fNSG/yi1CKfwy8f+uUxrQh3YEYf1DLx5vuQMpWdXrW
Uz9/1521ifGmLynfphMZ9DyQrGZ/0TwN71dLMul8GvYneZ7rRAfIRJGh+++q
nqB+7lC8cyREw5+U//nqoq/iNXIs0yg3lroOufqFGrdObSJaDTezgGt3b7OH
7D54XhkcmS4qbE+8HdZyNHiVQh5cs9j7EvVz9/Zx7QWDXsTxlyHpSx4mkkm3
dOL6qJ+nNmQU3nTwJaYFfxNbfQJJloP3eBnhvaZewnbk7FWCJSfHivpfUuN6
b6UL9fOTE7dUDkV6E7sGyIGUPlvSZaoR/97CtAutOuJRpMQrVktJ9zhy7zal
xyzwXtlcbN/Rh5Fkxkjb7d9Pk8j7gUP7vlDXv2R/ysJWQw/Cenq5+Msb6eRX
9i8X4RxMuLviwruuYMLzdKrYgqI0ckFAe/lPcM+uMuykfj/izlfDYur3JU+W
0L9njOJaobLfIUS3uLNOzjUnknOE+RN8Ljxrws88UI8nN1pZa/rOpJIDkiua
NlH/zh5zRT7p+9FEVHs7t1p6Opkp9Jl7B+TpREvUE5xjiBuHuAyfWbiSh0QD
d8Dn/nJ25H31ihRSxMhU+rqJPVlw6MyD69R1U9ewMfOvSyQj9lw09XvlRXIt
UGH4AuvDJzPvdMrSyF9LZJhqyWDSVWWCBX5/T2ueVTwZ6WSiUflLu1vRZB+7
O5sM9I/cvs7MIZROrtuVnLtCPIFcsDjYA9ZRd/uzP+/ljyTT37udOronjWR9
WsnUOQXvK0oxjLuzEDue+LmKfEgjZQ6nCEdQ1/OxUM7eb7sjiVmeG3y79qaR
5GyQUDv1/5diMcnN25hCsDK/uHx7Ywp51mRxx2noLX3kzU79/UTydyl56nqQ
7qZ9eB1ku5iFqOtO2LtwJlKfAzloTF9/Yc6JBOq+Icw4mhyp+4i8HqSL90/I
CwPLbOcU4mxuaUBqvj2pcOlyEHyPDGdFuJ73pJDK7407r1nakYt41vpaUD9n
6b9SuvhWOvlE+l0lzwV3cmq62Qg+d+3AF+Nbn2eSyRyjKauzfMnRfe8+tFDX
4cHmgdR7qpnkogvFqYF9wWR2b3NHF/XzXbv0StiXshMrFlYnTddHkyVaXv43
qM+LMeeaNgtfNLFcyVp+GV80adL5iwGe0x1KzhmQ35tG8Fz4sHJ4dyTpcikc
r4//i3Q+6v4jtHfVv6buR1IgYwDvw4H8RZ7U94doZQ0Vo75PJJPUIvwenU8V
dv5nm0ZIfhu9v8HYnGQej++G8eTXoJ8W7N+8vh3bsCJSkHi92n8A9nHaK/46
3ab2P0zbpdRCTHiJ6aymeDiPFeDe8Wwvte7nOt/a8rFmVvH3kHrbWur6P7mx
oGmKWrfFVul2sbCwk/ZNN/Dv+sl48Tz1eRMKFxn+SHqykHxPb+HnviJq/VLI
P4jLBnUWn9pEap+ix4EB+dzxKmo+OPdg7aw0wUn2xv97AeOh9k75BSLNmeTC
sO5fmmx+RJ+gxVLIs0eltXH3HMgkH11bmcf5L5ho26n3+APsL1SFQqj7j1iW
OnZnH38k4TIQjPfh3eqdvooq1Lrhs1KN8JwZYWacthfGYa/K2CIxkXRyA5lo
+EEmgbjpzN0WQv07172PZmRR60C/b6fPf25zIRJ33r3vCP0XkmKXlshdI5l+
HV/8UdufYGifdooDX2Xgpsrqx0lksOSzNVNVkcTNdwr3YNzouzocFT+dSr7p
cA//rBFPCI7qssP3elFXYbiQVCr5MVNRnfpfgnX6SAqsD/8sfe1P/R7kAuuw
R9TvRQRdW4a/D/khTZnrXzCZdLxEiPq7iSdH1fDvzTizoSWqbrY65rPAA+rz
IYrYtfFzMTyl/TOgL5g44paURN2PRBRfB96Hqm2ZvNT3lmjcKfhjnVA6Yfyv
CL+/vy2WHafGHYLvkORlahwiOO8vxfFnafPDQmocJNqU8wapcZFgOziI4+GP
9kIHanwnrp6KmqLGe+KwrAGO807axcaCFxII7mjdvUzVLsSa1U3XYR705a13
fMcVRTps+yD+aMCfMLp+TVYX/M+Fldbm5+PIiNK/1nPCUUTgFcfildT/X9/r
5q6sr/FkjlqZHPW/hNRY2J0AeH+bTdWJuo7k/QlXD+q6EnyfjPF6XuoxTdNi
8yNV69j+CjdnEsORlnifVKUZM/iY8pJzu8/YUfc1EXz1Bd7Pa2X0H1LfW4KB
v3OO+h4TDFGv8fv75QIHm/2taCJtYQMbNf4Rv5RtcNyrn3MIpuYJYlLH9DM1
bxBv6uRwvvgmLF5MzX/E13sGLtR8SLjY5uE8uLGVd+NIWTSx5/bIlZ1OroTH
n/frYZ2Qr/097lJROLnfucqD+l9i8c/NXwWpn9sZvLCh/n7yvlyHBXU9iLLP
9HV4lr+dm7qfSNmSi7up+4uY41TE+yqrYK2tVqQgOSu27xCce9dkBeH39/kW
rpfUOEVEL4qpoMYt4tO1BhyvtCo/HaTGd8L2x89+arwnFMe/4zg/9MvmITWv
E/rBTnupeZ44/7gR5/eerq/senHBREGrQJz1Oydit5ZqPax/RNSTpKnPjxQi
VtlTnych0ER/jgzkADf1fSA/12qZU98PgrON/l6wRYYqxVvaETom/hzU+EqI
PFuD42q+kZwBNQ8RJ8NdHKl5ifhTvhfnow+NmraaHl7E95C//dS6jBh/thfX
Y0pl+jKDbS5kyFrNLclZCcSAlsND+D6W8PtdTDaxJzrqA+vKVqQQlYbny2G+
m5Gr0aV+ThrJON+hfk7eDbuEP3/h7C5J/TtEbbHLOurfIY/mOuG/47Jrzoz6
75JiKhXDsB7s2rYP/7v8Xr8tYb68e03bC+ZPth5F/D3ldRcspv4usnGVsADM
G6YjrPh3ifcYr4RxYWCNpA2ME4HkFF6HRSzHd8B9HyaW7wzfg3X89HW7tWFw
EXWdSQVr41vUdSbN++jr/KXodA2st8Q4z6nB+muMn/5cQqpmD8A8rWXo8BXm
bcFdw/g5pkqcbdxIzU/nXN5WwXy1cVETfu7SBYVu3NT4zpMWcBL91QQfvE/C
3lXwwDh16ZKrKoxbZw134321RkzcFr6H8uHO9vC9VDRzwPvwX/baALhfOVKd
EuD+HVWj79vBwDZW6j4nNzY9gfucLE/qxPvcUdaiEtaF6ePr4XtBcq3Nxe+F
icHKUFhvRSaWDMH6SyNbFr9Hb1ObnsE6Y9dny2Ww7vBbfxW/dzzRC9xgfs2T
8lnET823Keat+D1tmJHiWWjKSzhu2OkC81XS3Ub8Xhs7NrJQ4wDBKTc1So0D
JEu1PY4Dtl2/smH8fZd0ywnG47g8fRw3xBRmFGB88RlfLgvjzds2epxxs2q6
AN9DclPLRfhe3hR2xuug5aSK931mKe9W+B7wOsTj5+jTu+8ENe6R3/fU61Pj
Hml89DmOe0sPG3nAOnjx69QeWBd7vj2F42Ts79pSWF+GDa/thfXmEzF6XC1K
F9kF6z/lUD51WA/a3F6H43Dh3WPBsN6S5738lRq3yX1eaThuJ5y7ERNErTMs
qllzYN1RK1GO43yqXP5tr/pZxcNL5zJh3r6TdxbnhZ0rvuvAfHl/zWYemD+D
HhjgPOIuVbUF5r/DrZovYT7ccX8dzjslEqnHYX769snIDeYrthOaOE8tWr41
AMbfkYQ9l2E8VmKlx+HT55QUYZyqsspaC+PWG216vGKW0zSBcaHGeAV8P0he
kVn8XnTlchVS8ywhY7HBhppnyfzXBTjPhpqll8L8t6WuTQ3mw/23efD30f+z
wZWax0nvWtJViNpXZZrewnl8UXibFaw7dWXMu2Ed2pxSgvO+6vHNu2G+dPbd
3E393SSzojL+vTrLvsD9QTCsGTGDecN8mQ3eJ/dq7L5T6xBy+8JnVzQJTkLv
36KXsA45v3UVL+xbHn+I6yyk9jHTy11w3XLsRIQJrGsnllzr7vVkISYP5+I6
h1FLv5RaF5ERmoUt0SzsxFqWDFwXGR6ebYB5Omd8rkjj0Wy18fJD+LlU39ax
gfnp+hMP+SYTXrJ/+Su8n0fPNR6A8X37jAu7AjXev3oRgt9fscI3l6h1HTnm
xMFNreuIJw9TcF0X7dQVDfuo2o+EM+yrJDvmvGAduOzOCty3OF8t7muh9jFb
/ej9y9wr3SFqnUn26fsupNaZhOyCCFxn7tKL2kGtS8k38Y3S1LqUSHCbwHXp
nyNMNeQSdlJQ9/FPah1LmPXZ498106ScCeuMh7J3r1DrXuLz/ia8D920JyZg
ft3m93MNKzXf1pfQ8+yUjQ+sq4k5SxlbXmq++mXQiOMV349kFpgnKvYr88G8
IbtmPY6rwnvcDal1O/nJ7ZMOtW4nvp60x3V7UeKePNgfirZfcYH94pK3J3Cd
v0p7RBT2Y/uvhYTB/syP8S3uC2I5XLbAPorcK8sP+6qXCR9xH2Hv+KWb2neQ
Yikxg7D/OC23HvcdLA+LTah9Crn5+Y5/sB4XEkvA63PpZcaieHcW0kKpyQrW
uTc9M/Bz79q9ZhzWnfHjz67AOlSCKwjvwxt2qr9hvVXuM6MC6y+J8zn4/eVd
qLkc1hmrzkUvh3WHarsDjntcfothX0bYL165FObt62n0vuyL0VddmC/ZGxl0
Yf68vkoN5yMZ7/Rhat9H+D58Z0Lt+wjeplO47xMw3baX2ieS7CcKzah9IvHY
Nwj3iU/dy1VhH7V8ywUO2Fc18/XidejnDzeH9d/bTzOHYD1o8m85jj+r2bm4
qX0rqavprEbtW4lHXUtw32q0Za8y7MPPj97Lg335t2P0Ple1bOdy2I+dWPsP
9sVE1p5OvP730xgcYN/y0qpvM+xjvFd+xftwR8eXb7C+rHY+kgPrzQIXet+9
ai7+Nay3BI6OmML6K0JyL84Xf4993k3t68nqlUt7qX09MWHahPt6yfvfL8P+
X+BdHZwDELsz6HOAnkmyBPbhYc79krAvl26if89rqwusYX+o8+JZDOwX9br1
8P6Rl/lVKULto1LvvLSCfdUpjqW4nzI+80Yjj9q3VEkvHYXzOitJXxwH1NbJ
wLkHYctx9xysi3MNTuM4f8J39VFYFz7p0QiEdWL+omKcBxvs87hhvfVe90QI
rL8Y3ehzlbp3p+a40h3IPrNJYd50B8Jg/hzGPeCsZlKfLbnpmvSQZqQ3wVCb
jH+vb+bTXzevOZEzqfca63+HEOynpfCcZ8uVN3/rLFzJHRwrgm84xxDvra7g
uRDHuN+mGGrfyz/Zx/GM2gez2DTjOdK2SblzC6n9oV1m5/Q2uzQi1fI1njuJ
yRqnSCtxkvJbpSb6qf1ZnPIOPKeyKt/ezUntowwNzizQpPZVVpFP8FyrjrWG
ewG17t++eeiUBLUPOPDyGJ6DlU5mtIhR6+BtX6yfjVPr4h8T/nhuNmcecdeS
Wl+KX63cfoZab7LW/sRzts5Mdy1Y/13uTcnXotaDOvb0udx//hc0Ig==
    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Lighting->"Neutral",
  Method->{"RotationControl" -> "Globe"},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.5633675717284307`*^9, 3.5660870267323236`*^9, 
  3.566101799018676*^9, 3.56613924387715*^9, 3.614707843259116*^9},
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->
  "During evaluation of \
In[64]:=",ExpressionUUID->"eeabf9da-4b78-4217-9378-83252c32fedd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "IntensityFunction", 
    "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
   RowBox[{"OutputGraphics", "\[Rule]", 
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxdnXW8VOUWhunu7j5wCFEJac5GOg1SUkAQaemQBgVUSqS7u1PibFJaGgRE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      "], {{
        {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtnHcAldMfxt977/u+573nRkmFCiXJlhSiMkrJzt4rmS0je2dkJkXKiKzs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            "]], 
           Polygon3DBox[CompressedData["
1:eJwtnHf8V9Mfx+/nc/f9kpCkoalJv1SolKzIbihSiWQlEiJllIzsvXf2yCgj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            "]], 
           Polygon3DBox[CompressedData["
1:eJwt13mYjuUCB+BvhqlwTlT2JcvkkKNJ1sYwdsaSbGNPIi0K2TKNrUIHLXLq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            "]]}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0slL1GEAx+HXpsVyKzWz3PCaRXRNpWsZUWqZOtqhg5prqzraXlhWlods
soWIFJGIKB3EY4p0Nf0HjOja8g+Uj3T4zPM9zMD7e39TfKarqjMphPBZo5EQ
1vYIB1RkZ20KoZxR7bdjjOuYneCyOuw/zPDjB/ZeTvIIz+qLfZfj+mHP85si
ySH8Y8G6EIrtUh5kHXvUaI9wSv32V/7SqJ3mfCWasQ/zvl6oWXE9VouOb3AG
tqrSbmO7quwOdqra7uI5nbDP8yQv8KJq7Eu8rFN2N3tUa/cypjq7j/Xs5xVF
7au8pgb7Om+o0b7JWzpt3+ZDvdQdPdOwmrTs+Q5xtxJ2Kn+6g7i9yE+K2U/Y
rahdy3IeYL6K7L/ueUVJ9hzH9N27GGCLFuwKTnAP0zVo//Zel9RmT/Opjtq9
rNc+u4z3nOu5Cte+w0cqsGeZzzzN2Lu4Uwk7lzs0Zedwuz7a2fzALGbqvb2N
W/XOzmC6Ju00pmrCTuE4t3Cz3toeNzhieGNvpOsOr+31RHjlwxWFocj///8q
vl5WFw==
          "],
          VertexColors->None]}, {
         Line3DBox[{1811, 2260, 1810, 1390, 1812, 2261, 1813, 2680, 2262, 
          1814, 2263, 1815, 2681, 2264, 1816, 2265, 1817, 2682, 2266, 1818, 
          2267, 1819, 2683, 2268, 1820, 2575, 2785, 1821, 2269, 1822, 2684, 
          2270, 1823, 2271, 1824, 2685, 2272, 1825, 2273, 1826, 2686, 2274, 
          1827, 2275, 1828, 2687, 2276, 1829, 2576, 2786, 1830, 2277, 1831, 
          2688, 2278, 1832, 2279, 1833, 2689, 2280, 1834, 2281, 1835, 2690, 
          2282, 1836, 2283, 1837, 2691, 2284, 1838, 2285, 1839},
          VertexColors->None], 
         Line3DBox[{1841, 2286, 1840, 2577, 2787, 1842, 2287, 1843, 1421, 
          1844, 2288, 1845, 2692, 2289, 1846, 2290, 1847, 2693, 2291, 1848, 
          2292, 1849, 2694, 2293, 1850, 2578, 2788, 1851, 2294, 1852, 2579, 
          2789, 1853, 2295, 1854, 2695, 2296, 1855, 2297, 1856, 2696, 2298, 
          1857, 2299, 1858, 2697, 2300, 1859, 2580, 2790, 1860, 2301, 1861, 
          2581, 2791, 1862, 2302, 1863, 2698, 2303, 1864, 2304, 1865, 2699, 
          2305, 1866, 2306, 1867, 2700, 2307, 1868, 2308, 1869},
          VertexColors->None], 
         Line3DBox[{1871, 2309, 1870, 2582, 2792, 1872, 2310, 1873, 2583, 
          2793, 1874, 2311, 1875, 1452, 1876, 2312, 1877, 2701, 2313, 1878, 
          2314, 1879, 2702, 2315, 1880, 2584, 2794, 1881, 2316, 1882, 2585, 
          2795, 1883, 2317, 1884, 2586, 2796, 1885, 2318, 1886, 2703, 2319, 
          1887, 2320, 1888, 2704, 2321, 1889, 2587, 2797, 1890, 2322, 1891, 
          2588, 2798, 1892, 2323, 1893, 2589, 2799, 1894, 2324, 1895, 2705, 
          2325, 1896, 2326, 1897, 2706, 2327, 1898, 2328, 1899},
          VertexColors->None], 
         Line3DBox[{1901, 2329, 1900, 2590, 2800, 1902, 2330, 1903, 2591, 
          2801, 1904, 2331, 1905, 2592, 2802, 1906, 2332, 1907, 1483, 1908, 
          2333, 1909, 2707, 2334, 1910, 2593, 2803, 1911, 2335, 1912, 2594, 
          2804, 1913, 2336, 1914, 2595, 2805, 1915, 2337, 1916, 2596, 2806, 
          1917, 2338, 1918, 2708, 2339, 1919, 2597, 2807, 1920, 2340, 1921, 
          2598, 2808, 1922, 2341, 1923, 2599, 2809, 1924, 2342, 1925, 2600, 
          2810, 1926, 2343, 1927, 2709, 2344, 1928, 2345, 1929},
          VertexColors->None], 
         Line3DBox[{1931, 2346, 1930, 2601, 2811, 1932, 2347, 1933, 2602, 
          2812, 1934, 2348, 1935, 2603, 2813, 1936, 2349, 1937, 2604, 2814, 
          1938, 2350, 1939, 1514, 1940, 2605, 2815, 1941, 2351, 1942, 2606, 
          2816, 1943, 2352, 1944, 2607, 2817, 1945, 2353, 1946, 2608, 2818, 
          1947, 2354, 1948, 2609, 2819, 1949, 2610, 2820, 1950, 2355, 1951, 
          2611, 2821, 1952, 2356, 1953, 2612, 2822, 1954, 2357, 1955, 2613, 
          2823, 1956, 2358, 1957, 2614, 2824, 1958, 2359, 1959},
          VertexColors->None], 
         Line3DBox[{1961, 2360, 1960, 2710, 2361, 1962, 2362, 1963, 2711, 
          2363, 1964, 2364, 1965, 2712, 2365, 1966, 2366, 1967, 2713, 2367, 
          1968, 2368, 1969, 2714, 2369, 1970, 1530, 1971, 2370, 1972, 2715, 
          2371, 1973, 2372, 1974, 2716, 2373, 1975, 2374, 1976, 2717, 2375, 
          1977, 2376, 1978, 2718, 2377, 1979, 2615, 2825, 1980, 2378, 1981, 
          2719, 2379, 1982, 2380, 1983, 2720, 2381, 1984, 2382, 1985, 2721, 
          2383, 1986, 2384, 1987, 2722, 2385, 1988, 2386, 1989},
          VertexColors->None], 
         Line3DBox[{1991, 2387, 1990, 2616, 2826, 1992, 2388, 1993, 2723, 
          2389, 1994, 2390, 1995, 2724, 2391, 1996, 2392, 1997, 2725, 2393, 
          1998, 2394, 1999, 2726, 2395, 2000, 2617, 2827, 2001, 2396, 2002, 
          1561, 2003, 2397, 2004, 2727, 2398, 2005, 2399, 2006, 2728, 2400, 
          2007, 2401, 2008, 2729, 2402, 2009, 2618, 2828, 2010, 2403, 2011, 
          2619, 2829, 2012, 2404, 2013, 2730, 2405, 2014, 2406, 2015, 2731, 
          2407, 2016, 2408, 2017, 2732, 2409, 2018, 2410, 2019},
          VertexColors->None], 
         Line3DBox[{2021, 2411, 2020, 2620, 2830, 2022, 2412, 2023, 2621, 
          2831, 2024, 2413, 2025, 2733, 2414, 2026, 2415, 2027, 2734, 2416, 
          2028, 2417, 2029, 2735, 2418, 2030, 2622, 2832, 2031, 2419, 2032, 
          2623, 2833, 2033, 2420, 2034, 1592, 2035, 2421, 2036, 2736, 2422, 
          2037, 2423, 2038, 2737, 2424, 2039, 2624, 2834, 2040, 2425, 2041, 
          2625, 2835, 2042, 2426, 2043, 2626, 2836, 2044, 2427, 2045, 2738, 
          2428, 2046, 2429, 2047, 2739, 2430, 2048, 2431, 2049},
          VertexColors->None], 
         Line3DBox[{2051, 2432, 2050, 2627, 2837, 2052, 2433, 2053, 2628, 
          2838, 2054, 2434, 2055, 2629, 2839, 2056, 2435, 2057, 2740, 2436, 
          2058, 2437, 2059, 2741, 2438, 2060, 2630, 2840, 2061, 2439, 2062, 
          2631, 2841, 2063, 2440, 2064, 2632, 2842, 2065, 2441, 2066, 1623, 
          2067, 2442, 2068, 2742, 2443, 2069, 2633, 2843, 2070, 2444, 2071, 
          2634, 2844, 2072, 2445, 2073, 2635, 2845, 2074, 2446, 2075, 2636, 
          2846, 2076, 2447, 2077, 2743, 2448, 2078, 2449, 2079},
          VertexColors->None], 
         Line3DBox[{2081, 2450, 2080, 2637, 2847, 2082, 2451, 2083, 2638, 
          2848, 2084, 2452, 2085, 2639, 2849, 2086, 2453, 2087, 2640, 2850, 
          2088, 2454, 2089, 2744, 2455, 2090, 2641, 2851, 2091, 2456, 2092, 
          2642, 2852, 2093, 2457, 2094, 2643, 2853, 2095, 2458, 2096, 2644, 
          2854, 2097, 2459, 2098, 1654, 2099, 2645, 2855, 2100, 2460, 2101, 
          2646, 2856, 2102, 2461, 2103, 2647, 2857, 2104, 2462, 2105, 2648, 
          2858, 2106, 2463, 2107, 2649, 2859, 2108, 2464, 2109},
          VertexColors->None], 
         Line3DBox[{2111, 2465, 2110, 2745, 2466, 2112, 2467, 2113, 2746, 
          2468, 2114, 2469, 2115, 2747, 2470, 2116, 2471, 2117, 2748, 2472, 
          2118, 2473, 2119, 2749, 2474, 2120, 2750, 2475, 2121, 2476, 2122, 
          2751, 2477, 2123, 2478, 2124, 2752, 2479, 2125, 2480, 2126, 2753, 
          2481, 2127, 2482, 2128, 2754, 2483, 2129, 1670, 2130, 2484, 2131, 
          2755, 2485, 2132, 2486, 2133, 2756, 2487, 2134, 2488, 2135, 2757, 
          2489, 2136, 2490, 2137, 2758, 2491, 2138, 2492, 2139},
          VertexColors->None], 
         Line3DBox[{2141, 2493, 2140, 2650, 2860, 2142, 2494, 2143, 2759, 
          2495, 2144, 2496, 2145, 2760, 2497, 2146, 2498, 2147, 2761, 2499, 
          2148, 2500, 2149, 2762, 2501, 2150, 2651, 2861, 2151, 2502, 2152, 
          2763, 2503, 2153, 2504, 2154, 2764, 2505, 2155, 2506, 2156, 2765, 
          2507, 2157, 2508, 2158, 2766, 2509, 2159, 2652, 2862, 2160, 2510, 
          2161, 1701, 2162, 2511, 2163, 2767, 2512, 2164, 2513, 2165, 2768, 
          2514, 2166, 2515, 2167, 2769, 2516, 2168, 2517, 2169},
          VertexColors->None], 
         Line3DBox[{2171, 2518, 2170, 2653, 2863, 2172, 2519, 2173, 2654, 
          2864, 2174, 2520, 2175, 2770, 2521, 2176, 2522, 2177, 2771, 2523, 
          2178, 2524, 2179, 2772, 2525, 2180, 2655, 2865, 2181, 2526, 2182, 
          2656, 2866, 2183, 2527, 2184, 2773, 2528, 2185, 2529, 2186, 2774, 
          2530, 2187, 2531, 2188, 2775, 2532, 2189, 2657, 2867, 2190, 2533, 
          2191, 2658, 2868, 2192, 2534, 2193, 1732, 2194, 2535, 2195, 2776, 
          2536, 2196, 2537, 2197, 2777, 2538, 2198, 2539, 2199},
          VertexColors->None], 
         Line3DBox[{2201, 2540, 2200, 2659, 2869, 2202, 2541, 2203, 2660, 
          2870, 2204, 2542, 2205, 2661, 2871, 2206, 2543, 2207, 2778, 2544, 
          2208, 2545, 2209, 2779, 2546, 2210, 2662, 2872, 2211, 2547, 2212, 
          2663, 2873, 2213, 2548, 2214, 2664, 2874, 2215, 2549, 2216, 2780, 
          2550, 2217, 2551, 2218, 2781, 2552, 2219, 2665, 2875, 2220, 2553, 
          2221, 2666, 2876, 2222, 2554, 2223, 2667, 2877, 2224, 2555, 2225, 
          1763, 2226, 2556, 2227, 2782, 2557, 2228, 2558, 2229},
          VertexColors->None], 
         Line3DBox[{2231, 2559, 2230, 2668, 2878, 2232, 2560, 2233, 2669, 
          2879, 2234, 2561, 2235, 2670, 2880, 2236, 2562, 2237, 2671, 2881, 
          2238, 2563, 2239, 2783, 2564, 2240, 2672, 2882, 2241, 2565, 2242, 
          2673, 2883, 2243, 2566, 2244, 2674, 2884, 2245, 2567, 2246, 2675, 
          2885, 2247, 2568, 2248, 2784, 2569, 2249, 2676, 2886, 2250, 2570, 
          2251, 2677, 2887, 2252, 2571, 2253, 2678, 2888, 2254, 2572, 2255, 
          2679, 2889, 2256, 2573, 2257, 1794, 2258, 2574, 2259},
          VertexColors->None]}, {
         Line3DBox[{925, 1375, 926, 1390, 955, 1405, 970, 2787, 1420, 985, 
          1435, 1000, 2792, 1450, 1015, 1465, 1030, 2800, 1480, 1045, 1495, 
          1060, 2811, 1510, 1075, 1525, 2710, 1090, 1540, 1105, 2826, 1555, 
          1120, 1570, 1135, 2830, 1585, 1150, 1600, 1165, 2837, 1615, 1180, 
          1630, 1195, 2847, 1645, 1210, 1660, 2745, 1225, 1675, 1240, 2860, 
          1690, 1255, 1705, 1270, 2863, 1720, 1285, 1735, 1300, 2869, 1750, 
          1315, 1765, 1330, 2878, 1780, 1345, 1795, 1360},
          VertexColors->None], 
         Line3DBox[{927, 1376, 928, 1391, 2680, 956, 1406, 971, 1421, 986, 
          1436, 1001, 2793, 1451, 1016, 1466, 1031, 2801, 1481, 1046, 1496, 
          1061, 2812, 1511, 1076, 1526, 2711, 1091, 1541, 1106, 1556, 2723, 
          1121, 1571, 1136, 2831, 1586, 1151, 1601, 1166, 2838, 1616, 1181, 
          1631, 1196, 2848, 1646, 1211, 1661, 2746, 1226, 1676, 1241, 1691, 
          2759, 1256, 1706, 1271, 2864, 1721, 1286, 1736, 1301, 2870, 1751, 
          1316, 1766, 1331, 2879, 1781, 1346, 1796, 1361},
          VertexColors->None], 
         Line3DBox[{929, 1377, 930, 1392, 2681, 957, 1407, 972, 1422, 2692, 
          987, 1437, 1002, 1452, 1017, 1467, 1032, 2802, 1482, 1047, 1497, 
          1062, 2813, 1512, 1077, 1527, 2712, 1092, 1542, 1107, 1557, 2724, 
          1122, 1572, 1137, 1587, 2733, 1152, 1602, 1167, 2839, 1617, 1182, 
          1632, 1197, 2849, 1647, 1212, 1662, 2747, 1227, 1677, 1242, 1692, 
          2760, 1257, 1707, 1272, 1722, 2770, 1287, 1737, 1302, 2871, 1752, 
          1317, 1767, 1332, 2880, 1782, 1347, 1797, 1362},
          VertexColors->None], 
         Line3DBox[{931, 1378, 932, 1393, 2682, 958, 1408, 973, 1423, 2693, 
          988, 1438, 1003, 1453, 2701, 1018, 1468, 1033, 1483, 1048, 1498, 
          1063, 2814, 1513, 1078, 1528, 2713, 1093, 1543, 1108, 1558, 2725, 
          1123, 1573, 1138, 1588, 2734, 1153, 1603, 1168, 1618, 2740, 1183, 
          1633, 1198, 2850, 1648, 1213, 1663, 2748, 1228, 1678, 1243, 1693, 
          2761, 1258, 1708, 1273, 1723, 2771, 1288, 1738, 1303, 1753, 2778, 
          1318, 1768, 1333, 2881, 1783, 1348, 1798, 1363},
          VertexColors->None], 
         Line3DBox[{933, 1379, 934, 1394, 2683, 959, 1409, 974, 1424, 2694, 
          989, 1439, 1004, 1454, 2702, 1019, 1469, 1034, 1484, 2707, 1049, 
          1499, 1064, 1514, 1079, 1529, 2714, 1094, 1544, 1109, 1559, 2726, 
          1124, 1574, 1139, 1589, 2735, 1154, 1604, 1169, 1619, 2741, 1184, 
          1634, 1199, 1649, 2744, 1214, 1664, 2749, 1229, 1679, 1244, 1694, 
          2762, 1259, 1709, 1274, 1724, 2772, 1289, 1739, 1304, 1754, 2779, 
          1319, 1769, 1334, 1784, 2783, 1349, 1799, 1364},
          VertexColors->None], 
         Line3DBox[{935, 1380, 936, 2785, 1395, 960, 1410, 975, 2788, 1425, 
          990, 1440, 1005, 2794, 1455, 1020, 1470, 1035, 2803, 1485, 1050, 
          1500, 1065, 2815, 1515, 1080, 1530, 1095, 1545, 1110, 2827, 1560, 
          1125, 1575, 1140, 2832, 1590, 1155, 1605, 1170, 2840, 1620, 1185, 
          1635, 1200, 2851, 1650, 1215, 1665, 2750, 1230, 1680, 1245, 2861, 
          1695, 1260, 1710, 1275, 2865, 1725, 1290, 1740, 1305, 2872, 1755, 
          1320, 1770, 1335, 2882, 1785, 1350, 1800, 1365},
          VertexColors->None], 
         Line3DBox[{937, 1381, 938, 1396, 2684, 961, 1411, 976, 2789, 1426, 
          991, 1441, 1006, 2795, 1456, 1021, 1471, 1036, 2804, 1486, 1051, 
          1501, 1066, 2816, 1516, 1081, 1531, 2715, 1096, 1546, 1111, 1561, 
          1126, 1576, 1141, 2833, 1591, 1156, 1606, 1171, 2841, 1621, 1186, 
          1636, 1201, 2852, 1651, 1216, 1666, 2751, 1231, 1681, 1246, 1696, 
          2763, 1261, 1711, 1276, 2866, 1726, 1291, 1741, 1306, 2873, 1756, 
          1321, 1771, 1336, 2883, 1786, 1351, 1801, 1366},
          VertexColors->None], 
         Line3DBox[{939, 1382, 940, 1397, 2685, 962, 1412, 977, 1427, 2695, 
          992, 1442, 1007, 2796, 1457, 1022, 1472, 1037, 2805, 1487, 1052, 
          1502, 1067, 2817, 1517, 1082, 1532, 2716, 1097, 1547, 1112, 1562, 
          2727, 1127, 1577, 1142, 1592, 1157, 1607, 1172, 2842, 1622, 1187, 
          1637, 1202, 2853, 1652, 1217, 1667, 2752, 1232, 1682, 1247, 1697, 
          2764, 1262, 1712, 1277, 1727, 2773, 1292, 1742, 1307, 2874, 1757, 
          1322, 1772, 1337, 2884, 1787, 1352, 1802, 1367},
          VertexColors->None], 
         Line3DBox[{941, 1383, 942, 1398, 2686, 963, 1413, 978, 1428, 2696, 
          993, 1443, 1008, 1458, 2703, 1023, 1473, 1038, 2806, 1488, 1053, 
          1503, 1068, 2818, 1518, 1083, 1533, 2717, 1098, 1548, 1113, 1563, 
          2728, 1128, 1578, 1143, 1593, 2736, 1158, 1608, 1173, 1623, 1188, 
          1638, 1203, 2854, 1653, 1218, 1668, 2753, 1233, 1683, 1248, 1698, 
          2765, 1263, 1713, 1278, 1728, 2774, 1293, 1743, 1308, 1758, 2780, 
          1323, 1773, 1338, 2885, 1788, 1353, 1803, 1368},
          VertexColors->None], 
         Line3DBox[{943, 1384, 944, 1399, 2687, 964, 1414, 979, 1429, 2697, 
          994, 1444, 1009, 1459, 2704, 1024, 1474, 1039, 1489, 2708, 1054, 
          1504, 1069, 2819, 1519, 1084, 1534, 2718, 1099, 1549, 1114, 1564, 
          2729, 1129, 1579, 1144, 1594, 2737, 1159, 1609, 1174, 1624, 2742, 
          1189, 1639, 1204, 1654, 1219, 1669, 2754, 1234, 1684, 1249, 1699, 
          2766, 1264, 1714, 1279, 1729, 2775, 1294, 1744, 1309, 1759, 2781, 
          1324, 1774, 1339, 1789, 2784, 1354, 1804, 1369},
          VertexColors->None], 
         Line3DBox[{945, 1385, 946, 2786, 1400, 965, 1415, 980, 2790, 1430, 
          995, 1445, 1010, 2797, 1460, 1025, 1475, 1040, 2807, 1490, 1055, 
          1505, 1070, 2820, 1520, 1085, 2825, 1535, 1100, 1550, 1115, 2828, 
          1565, 1130, 1580, 1145, 2834, 1595, 1160, 1610, 1175, 2843, 1625, 
          1190, 1640, 1205, 2855, 1655, 1220, 1670, 1235, 1685, 1250, 2862, 
          1700, 1265, 1715, 1280, 2867, 1730, 1295, 1745, 1310, 2875, 1760, 
          1325, 1775, 1340, 2886, 1790, 1355, 1805, 1370},
          VertexColors->None], 
         Line3DBox[{947, 1386, 948, 1401, 2688, 966, 1416, 981, 2791, 1431, 
          996, 1446, 1011, 2798, 1461, 1026, 1476, 1041, 2808, 1491, 1056, 
          1506, 1071, 2821, 1521, 1086, 1536, 2719, 1101, 1551, 1116, 2829, 
          1566, 1131, 1581, 1146, 2835, 1596, 1161, 1611, 1176, 2844, 1626, 
          1191, 1641, 1206, 2856, 1656, 1221, 1671, 2755, 1236, 1686, 1251, 
          1701, 1266, 1716, 1281, 2868, 1731, 1296, 1746, 1311, 2876, 1761, 
          1326, 1776, 1341, 2887, 1791, 1356, 1806, 1371},
          VertexColors->None], 
         Line3DBox[{949, 1387, 950, 1402, 2689, 967, 1417, 982, 1432, 2698, 
          997, 1447, 1012, 2799, 1462, 1027, 1477, 1042, 2809, 1492, 1057, 
          1507, 1072, 2822, 1522, 1087, 1537, 2720, 1102, 1552, 1117, 1567, 
          2730, 1132, 1582, 1147, 2836, 1597, 1162, 1612, 1177, 2845, 1627, 
          1192, 1642, 1207, 2857, 1657, 1222, 1672, 2756, 1237, 1687, 1252, 
          1702, 2767, 1267, 1717, 1282, 1732, 1297, 1747, 1312, 2877, 1762, 
          1327, 1777, 1342, 2888, 1792, 1357, 1807, 1372},
          VertexColors->None], 
         Line3DBox[{951, 1388, 952, 1403, 2690, 968, 1418, 983, 1433, 2699, 
          998, 1448, 1013, 1463, 2705, 1028, 1478, 1043, 2810, 1493, 1058, 
          1508, 1073, 2823, 1523, 1088, 1538, 2721, 1103, 1553, 1118, 1568, 
          2731, 1133, 1583, 1148, 1598, 2738, 1163, 1613, 1178, 2846, 1628, 
          1193, 1643, 1208, 2858, 1658, 1223, 1673, 2757, 1238, 1688, 1253, 
          1703, 2768, 1268, 1718, 1283, 1733, 2776, 1298, 1748, 1313, 1763, 
          1328, 1778, 1343, 2889, 1793, 1358, 1808, 1373},
          VertexColors->None], 
         Line3DBox[{953, 1389, 954, 1404, 2691, 969, 1419, 984, 1434, 2700, 
          999, 1449, 1014, 1464, 2706, 1029, 1479, 1044, 1494, 2709, 1059, 
          1509, 1074, 2824, 1524, 1089, 1539, 2722, 1104, 1554, 1119, 1569, 
          2732, 1134, 1584, 1149, 1599, 2739, 1164, 1614, 1179, 1629, 2743, 
          1194, 1644, 1209, 2859, 1659, 1224, 1674, 2758, 1239, 1689, 1254, 
          1704, 2769, 1269, 1719, 1284, 1734, 2777, 1299, 1749, 1314, 1764, 
          2782, 1329, 1779, 1344, 1794, 1359, 1809, 1374},
          VertexColors->None]}, {}, {}}},
      VertexColors->{
        Hue[0.6499999708035517, 1, 0.10000004042585155`], 
        Hue[0.6499501349069793, 1, 0.10006904397495173`], 
        Hue[0.6498830409238536, 1, 0.10016194333620275`], 
        Hue[0.6498461977051377, 1, 0.1002129570236554], 
        Hue[0.6498030896255687, 1, 0.10027264513382812`], 
        Hue[0.6497535139635646, 1, 0.10034128835814127`], 
        Hue[0.6496983097028106, 1, 0.1004177250268776], 
        Hue[0.6496389419655233, 1, 0.10049992650927547`], 
        Hue[0.649577478494239, 1, 0.10058502977720765`], 
        Hue[0.6495165254872346, 1, 0.1006694262484444], 
        Hue[0.6494590585595534, 1, 0.10074899584061832`], 
        Hue[0.649408198526006, 1, 0.10081941742553022`], 
        Hue[0.6493669337431704, 1, 0.10087655327868715`], 
        Hue[0.6493378392973852, 1, 0.1009168378959282], 
        Hue[0.6493227485192283, 1, 0.10093773281953008`], 
        Hue[0.6493225234655081, 1, 0.10093804443237338`], 
        Hue[0.6493375546952845, 1, 0.10091723196037532`], 
        Hue[0.6493666872241856, 1, 0.10087689461266622`], 
        Hue[0.6494080042211439, 1, 0.1008196864630316], 
        Hue[0.6494589248602171, 1, 0.10074918096277648`], 
        Hue[0.6495164551284213, 1, 0.1006695236683399], 
        Hue[0.6495774685201788, 1, 0.10058504358744468`], 
        Hue[0.6496389846755347, 1, 0.10049986737233654`], 
        Hue[0.649698394426526, 1, 0.10041760771711797`], 
        Hue[0.6497536281731384, 1, 0.10034113022180839`], 
        Hue[0.6498032208248107, 1, 0.10027246347333903`], 
        Hue[0.6498463345952484, 1, 0.10021276748350222`], 
        Hue[0.6498831956240974, 1, 0.10016172913586517`], 
        Hue[0.649950728657251, 1, 0.10006822185919101`], 
        Hue[0.65, 1, 0.1], 
        Hue[0.6499501349069793, 1, 0.10006904397495173`], 
        Hue[0.6464573223024352, 1, 0.10490524604278194`], 
        Hue[0.641724777803142, 1, 0.11145799996488044`], 
        Hue[0.6391313531926319, 1, 0.11504889557943282`], 
        Hue[0.6360971833227743, 1, 0.11925005386077399`], 
        Hue[0.6326073703548722, 1, 0.12408210258556153`], 
        Hue[0.628721200901634, 1, 0.1294629525977376], 
        Hue[0.6245414168247752, 1, 0.13525034593492677`], 
        Hue[0.6202138963403885, 1, 0.14124229737484675`], 
        Hue[0.615921994799832, 1, 0.14718493027715576`], 
        Hue[0.6118753120591388, 1, 0.15278802945657702`], 
        Hue[0.6082937016181819, 1, 0.1577471823748251], 
        Hue[0.6053877795136546, 1, 0.16177076682724745`], 
        Hue[0.6033385675660863, 1, 0.1646081372161882], 
        Hue[0.6022780343317817, 1, 0.16607656784830227`], 
        Hue[0.602273455287948, 1, 0.16608290806284134`], 
        Hue[0.6033327766268467, 1, 0.16461615543975083`], 
        Hue[0.6053827643478744, 1, 0.16177771090294313`], 
        Hue[0.6082897478234982, 1, 0.1577526568597717], 
        Hue[0.6118725930131017, 1, 0.15279179428955145`], 
        Hue[0.6159205640488971, 1, 0.14718691131691175`], 
        Hue[0.6202136935615623, 1, 0.14124257814552912`], 
        Hue[0.624542287547754, 1, 0.13524914031849444`], 
        Hue[0.6287229249078186, 1, 0.12946056551225132`], 
        Hue[0.6326096948107707, 1, 0.12407888410816373`], 
        Hue[0.6360998533911139, 1, 0.11924635684307319`], 
        Hue[0.6391341378578641, 1, 0.1150450398891113], 
        Hue[0.6417279253205035, 1, 0.11145364186391826`], 
        Hue[0.6464693972464388, 1, 0.10488852688954636`], 
        Hue[0.649950728657251, 1, 0.10006822185919101`], 
        Hue[0.6498830409238536, 1, 0.10016194333620275`], 
        Hue[0.641724777803142, 1, 0.11145799996488044`], 
        Hue[0.6306434748977874, 1, 0.12680134244921756`], 
        Hue[0.6245727303868367, 1, 0.13520698869514916`], 
        Hue[0.6174696271668445, 1, 0.14504205469206152`], 
        Hue[0.6092986732582469, 1, 0.15635568318088897`], 
        Hue[0.6001985108332903, 1, 0.16895590807698263`], 
        Hue[0.5904096633353364, 1, 0.18250969692030347`], 
        Hue[0.5802737763923936, 1, 0.1965440019182242], 
        Hue[0.5702204021385245, 1, 0.2104640585774276], 
        Hue[0.5607407492766581, 1, 0.22358973177078117`], 
        Hue[0.5523500286717988, 1, 0.23520765260827858`], 
        Hue[0.5455419279510902, 1, 0.2446342536061827], 
        Hue[0.5407408069589723, 1, 0.2512819595952691], 
        Hue[0.5382576968540977, 1, 0.25472011204817235`], 
        Hue[0.5382564959967934, 1, 0.25472177477367075`], 
        Hue[0.5407392886284856, 1, 0.2512840618990199], 
        Hue[0.5455406136566957, 1, 0.24463607339842136`], 
        Hue[0.5523489934508787, 1, 0.23520908599109094`], 
        Hue[0.5607400386245786, 1, 0.2235907157505836], 
        Hue[0.5702200298684389, 1, 0.21046457402831537`], 
        Hue[0.5802737264094405, 1, 0.1965440711253901], 
        Hue[0.5904098947812237, 1, 0.1825093764567671], 
        Hue[0.6001989655967652, 1, 0.16895527840447902`], 
        Hue[0.6092992847532812, 1, 0.15635483649545684`], 
        Hue[0.6174703284313343, 1, 0.1450410837104602], 
        Hue[0.6245734607680122, 1, 0.135205977398137], 
        Hue[0.6306442987596863, 1, 0.1268002017173574], 
        Hue[0.6417279253205034, 1, 0.11145364186391847`], 
        Hue[0.6498831956240974, 1, 0.10016172913586517`], 
        Hue[0.6498461977051377, 1, 0.1002129570236554], 
        Hue[0.6391313531926319, 1, 0.11504889557943282`], 
        Hue[0.6245727303868367, 1, 0.13520698869514916`], 
        Hue[0.6165921083515689, 1, 0.14625708074398155`], 
        Hue[0.6072526403378198, 1, 0.15918865183994185`], 
        Hue[0.5965074304344584, 1, 0.17406663478305767`], 
        Hue[0.5845385676182782, 1, 0.19063890637469175`], 
        Hue[0.5716622801396413, 1, 0.20846761211434295`], 
        Hue[0.5583280015998117, 1, 0.2269304593233377], 
        Hue[0.5451009821631014, 1, 0.24524479392801346`], 
        Hue[0.532627770676394, 1, 0.2625153944480699], 
        Hue[0.5215866154536093, 1, 0.27780314783346405`], 
        Hue[0.5126275239482238, 1, 0.2902080437639979], 
        Hue[0.5063092649943484, 1, 0.2989564023155178], 
        Hue[0.5030415295754531, 1, 0.30348095904937267`], 
        Hue[0.5030404640559991, 1, 0.30348243438400135`], 
        Hue[0.5063079178181413, 1, 0.2989582676364198], 
        Hue[0.5126263581144319, 1, 0.290209657995402], 
        Hue[0.521585697641151, 1, 0.277804418650714], 
        Hue[0.5326271410244354, 1, 0.2625162662738587], 
        Hue[0.545100653122046, 1, 0.24524524952332097`], 
        Hue[0.5583279587081368, 1, 0.22693051871181064`], 
        Hue[0.5716624867457912, 1, 0.20846732604428905`], 
        Hue[0.5845389723395107, 1, 0.1906383459914468], 
        Hue[0.5965079738472142, 1, 0.17406588236539575`], 
        Hue[0.607253262945072, 1, 0.15918778976836193`], 
        Hue[0.6165927565645893, 1, 0.14625618321826095`], 
        Hue[0.6245734607680122, 1, 0.1352059773981369], 
        Hue[0.6391341378578639, 1, 0.11504503988911155`], 
        Hue[0.6498463345952484, 1, 0.10021276748350222`], 
        Hue[0.6498030896255687, 1, 0.10027264513382812`], 
        Hue[0.6360971833227743, 1, 0.11925005386077399`], 
        Hue[0.6174696271668445, 1, 0.14504205469206152`], 
        Hue[0.6072526403378198, 1, 0.15918865183994185`], 
        Hue[0.5952940078074799, 1, 0.1757467584204125], 
        Hue[0.5815334198863941, 1, 0.1947998801573005], 
        Hue[0.5662037895546834, 1, 0.21602552215505372`], 
        Hue[0.5497100013722023, 1, 0.2388630750231046], 
        Hue[0.5326277913778148, 1, 0.26251536578456425`], 
        Hue[0.5156814663990663, 1, 0.28597950806283134`], 
        Hue[0.4996997067575764, 1, 0.30810809833566344`], 
        Hue[0.4855519334973518, 1, 0.3276973228498206], 
        Hue[0.4740715013952571, 1, 0.34359330576041325`], 
        Hue[0.46597482804496104`, 1, 0.3548040842454385], 
        Hue[0.46178728216934245`, 1, 0.3606022246886028], 
        Hue[0.46178625847117905`, 1, 0.36060364211682905`], 
        Hue[0.46597353397213837`, 1, 0.3548058760385777], 
        Hue[0.47407038168998694`, 1, 0.3435948561215566], 
        Hue[0.4855510522150247, 1, 0.32769854308688884`], 
        Hue[0.4996991026302832, 1, 0.3081089348196079], 
        Hue[0.5156811510231455, 1, 0.2859799447371832], 
        Hue[0.5326277508879955, 1, 0.26251542184739085`], 
        Hue[0.5497102008098526, 1, 0.23886279887866568`], 
        Hue[0.566204178904602, 1, 0.2160249830551666], 
        Hue[0.5815339424268632, 1, 0.19479915663972797`], 
        Hue[0.5952946063665869, 1, 0.17574592964626434`], 
        Hue[0.607253262945072, 1, 0.15918778976836187`], 
        Hue[0.6174703284313344, 1, 0.14504108371046004`], 
        Hue[0.6360998533911136, 1, 0.1192463568430735], 
        Hue[0.6498032208248107, 1, 0.10027246347333903`], 
        Hue[0.6497535139635646, 1, 0.10034128835814127`], 
        Hue[0.6326073703548722, 1, 0.12408210258556153`], 
        Hue[0.6092986732582468, 1, 0.15635568318088897`], 
        Hue[0.5965074304344584, 1, 0.17406663478305762`], 
        Hue[0.5815334198863941, 1, 0.19479988015730054`], 
        Hue[0.5643008298468729, 1, 0.21866038944279143`], 
        Hue[0.545101007506637, 1, 0.24524475883696412`], 
        Hue[0.5244409336357099, 1, 0.2738510149659401], 
        Hue[0.5030417915253734, 1, 0.303480596349483], 
        Hue[0.4818111283712805, 1, 0.33287689917822705`], 
        Hue[0.461787524939957, 1, 0.360601888544675], 
        Hue[0.44406072296108073`, 1, 0.3851466912846575], 
        Hue[0.42967539275756805`, 1, 0.4050648407972135], 
        Hue[0.4195297118980599, 1, 0.4191127066026864], 
        Hue[0.4142823966531054, 1, 0.42637822001877723`], 
        Hue[0.41428150329811164`, 1, 0.4263794569718454], 
        Hue[0.41952858263311266`, 1, 0.41911427020030556`], 
        Hue[0.4296744158266314, 1, 0.40506619347081807`], 
        Hue[0.44405995434766954`, 1, 0.38514775551861136`], 
        Hue[0.46178699841355336`, 1, 0.3606026175812338], 
        Hue[0.48181085405609525`, 1, 0.3328772789992527], 
        Hue[0.5030417571916423, 1, 0.30348064388849516`], 
        Hue[0.5244411085622436, 1, 0.2738507727599705], 
        Hue[0.5451013481926239, 1, 0.24524428711790539`], 
        Hue[0.5643012865415892, 1, 0.21865975709626115`], 
        Hue[0.5815339424268628, 1, 0.1947991566397283], 
        Hue[0.596507973847214, 1, 0.17406588236539608`], 
        Hue[0.6092992847532812, 1, 0.15635483649545684`], 
        Hue[0.6326096948107703, 1, 0.12407888410816416`], 
        Hue[0.6497536281731384, 1, 0.10034113022180839`], 
        Hue[0.6496983097028106, 1, 0.1004177250268776], 
        Hue[0.628721200901634, 1, 0.1294629525977376], 
        Hue[0.6001985108332903, 1, 0.16895590807698269`], 
        Hue[0.5845385676182782, 1, 0.1906389063746918], 
        Hue[0.5662037895546834, 1, 0.21602552215505372`], 
        Hue[0.545101007506637, 1, 0.24524475883696412`], 
        Hue[0.521586688030249, 1, 0.27780304734273226`], 
        Hue[0.4962815230897488, 1, 0.3128409680295786], 
        Hue[0.4700689058025471, 1, 0.34913536119647326`], 
        Hue[0.4440607762893021, 1, 0.3851466174455819], 
        Hue[0.4195297739541015, 1, 0.4191126206789364], 
        Hue[0.3978115050201396, 1, 0.44918406997211446`], 
        Hue[0.3801863883092052, 1, 0.4735880777257159], 
        Hue[0.36775539250878636`, 1, 0.49080022575706506`], 
        Hue[0.3613260963423509, 1, 0.4997023281413603], 
        Hue[0.36132543116871485`, 1, 0.49970324915101016`], 
        Hue[0.3677545517203828, 1, 0.49080138992562383`], 
        Hue[0.3801856611748639, 1, 0.47358908452711157`], 
        Hue[0.3978109332902876, 1, 0.44918486159806337`], 
        Hue[0.41952938271066786`, 1, 0.4191131624006138], 
        Hue[0.4440605731298055, 1, 0.3851468987433463], 
        Hue[0.47006888141789416`, 1, 0.3491353949598389], 
        Hue[0.49628165443031574`, 1, 0.31284078617340905`], 
        Hue[0.5215869427511122, 1, 0.2778026946523062], 
        Hue[0.5451013481926242, 1, 0.2452442871179049], 
        Hue[0.566204178904602, 1, 0.2160249830551666], 
        Hue[0.5845389723395107, 1, 0.19063834599144672`], 
        Hue[0.6001989655967653, 1, 0.16895527840447883`], 
        Hue[0.6287229249078181, 1, 0.12946056551225182`], 
        Hue[0.649698394426526, 1, 0.10041760771711797`], 
        Hue[0.6496389419655233, 1, 0.10049992650927547`], 
        Hue[0.6245414168247752, 1, 0.13525034593492677`], 
        Hue[0.5904096633353364, 1, 0.18250969692030347`], 
        Hue[0.5716622801396413, 1, 0.2084676121143429], 
        Hue[0.5497100013722022, 1, 0.2388630750231047], 
        Hue[0.5244409336357099, 1, 0.2738510149659401], 
        Hue[0.4962815230897489, 1, 0.3128409680295785], 
        Hue[0.46597494182679966`, 1, 0.3548039267013544], 
        Hue[0.43457916548143993`, 1, 0.3982750016410832], 
        Hue[0.40342627820475824`, 1, 0.4414097686395655], 
        Hue[0.37404109317128503`, 1, 0.48209694791668234`], 
        Hue[0.34802405143856435`, 1, 0.5181205441619878], 
        Hue[0.3269095796788625, 1, 0.5473559665984981], 
        Hue[0.31201716690331643`, 1, 0.5679762304415619], 
        Hue[0.30431479674022255`, 1, 0.5786410506673841], 
        Hue[0.3043144570367268, 1, 0.5786415210260706], 
        Hue[0.3120167377448938, 1, 0.5679768246609164], 
        Hue[0.32690920887930364`, 1, 0.5473564800132719], 
        Hue[0.3480237603580029, 1, 0.5181209471966114], 
        Hue[0.37404089470482704`, 1, 0.4820972227163933], 
        Hue[0.40342617588556917`, 1, 0.44140991031228893`], 
        Hue[0.43457915454354423`, 1, 0.39827501678586186`], 
        Hue[0.46597501058471447`, 1, 0.3548038314980877], 
        Hue[0.4962816544303153, 1, 0.3128407861734096], 
        Hue[0.5244411085622438, 1, 0.2738507727599702], 
        Hue[0.5497102008098522, 1, 0.23886279887866618`], 
        Hue[0.5716624867457911, 1, 0.2084673260442893], 
        Hue[0.5904098947812237, 1, 0.18250937645676713`], 
        Hue[0.6245422875477535, 1, 0.1352491403184951], 
        Hue[0.6496389846755347, 1, 0.10049986737233654`], 
        Hue[0.649577478494239, 1, 0.10058502977720765`], 
        Hue[0.6202138963403885, 1, 0.14124229737484675`], 
        Hue[0.5802737763923936, 1, 0.1965440019182242], 
        Hue[0.5583280015998117, 1, 0.2269304593233377], 
        Hue[0.5326277913778147, 1, 0.2625153657845643], 
        Hue[0.5030417915253735, 1, 0.3034805963494829], 
        Hue[0.470068905802547, 1, 0.34913536119647337`], 
        Hue[0.43457916548144004`, 1, 0.3982750016410831], 
        Hue[0.39781155321321565`, 1, 0.4491840032432399], 
        Hue[0.36132626453773387`, 1, 0.4997020952554455], 
        Hue[0.3269096126332475, 1, 0.5473559209693496], 
        Hue[0.29643658146057444`, 1, 0.589549348746897], 
        Hue[0.27170505303049686`, 1, 0.6237930034962351], 
        Hue[0.25426109147054615`, 1, 0.6479461810407823], 
        Hue[0.24523898831927277`, 1, 0.6604383238656223], 
        Hue[0.24523905911222033`, 1, 0.660438225844618], 
        Hue[0.2542611812693693, 1, 0.6479460567039502], 
        Hue[0.27170513131153495`, 1, 0.6237928951071054], 
        Hue[0.29643664409514314`, 1, 0.5895492620221096], 
        Hue[0.3269096566629648, 1, 0.5473558600051257], 
        Hue[0.36132628914320536`, 1, 0.4997020611863311], 
        Hue[0.39781155912194954`, 1, 0.4491839950619161], 
        Hue[0.4345791545435442, 1, 0.39827501678586197`], 
        Hue[0.4700688814178937, 1, 0.3491353949598395], 
        Hue[0.5030417571916427, 1, 0.3034806438884948], 
        Hue[0.5326277508879953, 1, 0.2625154218473912], 
        Hue[0.5583279587081367, 1, 0.22693051871181089`], 
        Hue[0.5802737264094405, 1, 0.19654407112539013`], 
        Hue[0.6202136935615618, 1, 0.1412425781455299], 
        Hue[0.6495774685201788, 1, 0.10058504358744468`], 
        Hue[0.6495165254872346, 1, 0.1006694262484444], 
        Hue[0.615921994799832, 1, 0.14718493027715576`], 
        Hue[0.5702204021385245, 1, 0.2104640585774276], 
        Hue[0.5451009821631014, 1, 0.2452447939280135], 
        Hue[0.5156814663990663, 1, 0.28597950806283134`], 
        Hue[0.4818111283712805, 1, 0.33287689917822705`], 
        Hue[0.44406077628930185`, 1, 0.3851466174455821], 
        Hue[0.4034262782047582, 1, 0.4414097686395656], 
        Hue[0.36132626453773375`, 1, 0.4997020952554456], 
        Hue[0.3195475603193792, 1, 0.557549531865475], 
        Hue[0.2801358546894734, 1, 0.6121195858145754], 
        Hue[0.24523900321299108`, 1, 0.6604383032435508], 
        Hue[0.2169164278757577, 1, 0.6996541767874124], 
        Hue[0.19693913314547817`, 1, 0.7273150464139533], 
        Hue[0.18660681005456498`, 1, 0.7416213399244486], 
        Hue[0.18660735119910316`, 1, 0.7416205906473956], 
        Hue[0.19693981755676215`, 1, 0.72731409876756], 
        Hue[0.21691702070062718`, 1, 0.6996533559529777], 
        Hue[0.24523947080001152`, 1, 0.6604376558153687], 
        Hue[0.28013617649380107`, 1, 0.6121191402393524], 
        Hue[0.3195477299800872, 1, 0.5575492969506486], 
        Hue[0.3613262891432053, 1, 0.4997020611863311], 
        Hue[0.4034261758855694, 1, 0.4414099103122885], 
        Hue[0.44406057312980485`, 1, 0.3851468987433472], 
        Hue[0.48181085405609547`, 1, 0.33287727899925246`], 
        Hue[0.5156811510231452, 1, 0.2859799447371837], 
        Hue[0.5451006531220457, 1, 0.2452452495233214], 
        Hue[0.5702200298684389, 1, 0.21046457402831542`], 
        Hue[0.6159205640488965, 1, 0.1471869113169126], 
        Hue[0.6495164551284213, 1, 0.1006695236683399], 
        Hue[0.6494590585595534, 1, 0.10074899584061832`], 
        Hue[0.6118753120591388, 1, 0.15278802945657705`], 
        Hue[0.5607407492766581, 1, 0.2235897317707812], 
        Hue[0.532627770676394, 1, 0.2625153944480699], 
        Hue[0.49969970675757647`, 1, 0.30810809833566344`], 
        Hue[0.4617875249399567, 1, 0.36060188854467534`], 
        Hue[0.4195297739541016, 1, 0.4191126206789362], 
        Hue[0.374041093171285, 1, 0.48209694791668245`], 
        Hue[0.3269096126332475, 1, 0.5473559209693496], 
        Hue[0.28013585468947355`, 1, 0.6121195858145752], 
        Hue[0.23601068976558537`, 1, 0.6732159680168818], 
        Hue[0.19693916442808201`, 1, 0.7273150030995787], 
        Hue[0.16522767428299484`, 1, 0.7712232202235456], 
        Hue[0.14285972467856245`, 1, 0.8021942273681443], 
        Hue[0.13129084465845597`, 1, 0.8182126766267533], 
        Hue[0.13129187980583068`, 1, 0.8182112433457729], 
        Hue[0.14286103359112767`, 1, 0.8021924150276694], 
        Hue[0.1652288075468782, 1, 0.7712216510889379], 
        Hue[0.19694005720194346`, 1, 0.7273137669511552], 
        Hue[0.23601130327494635`, 1, 0.6732151185423819], 
        Hue[0.28013617649380124`, 1, 0.6121191402393521], 
        Hue[0.32690965666296495`, 1, 0.5473558600051255], 
        Hue[0.3740408947048273, 1, 0.482097222716393], 
        Hue[0.41952938271066764`, 1, 0.41911316240061414`], 
        Hue[0.4617869984135538, 1, 0.36060261758123324`], 
        Hue[0.499699102630283, 1, 0.3081089348196082], 
        Hue[0.5326271410244352, 1, 0.26251626627385893`], 
        Hue[0.5607400386245787, 1, 0.2235907157505834], 
        Hue[0.611872593013101, 1, 0.15279179428955236`], 
        Hue[0.6494589248602171, 1, 0.10074918096277646`], 
        Hue[0.649408198526006, 1, 0.10081941742553022`], 
        Hue[0.6082937016181819, 1, 0.1577471823748251], 
        Hue[0.5523500286717988, 1, 0.23520765260827858`], 
        Hue[0.5215866154536093, 1, 0.27780314783346405`], 
        Hue[0.4855519334973518, 1, 0.3276973228498206], 
        Hue[0.44406072296108057`, 1, 0.3851466912846577], 
        Hue[0.3978115050201397, 1, 0.44918406997211435`], 
        Hue[0.3480240514385644, 1, 0.5181205441619877], 
        Hue[0.29643658146057444`, 1, 0.589549348746897], 
        Hue[0.24523900321299136`, 1, 0.6604383032435505], 
        Hue[0.19693916442808196`, 1, 0.7273150030995789], 
        Hue[0.15417015857172311`, 1, 0.7865336265929987], 
        Hue[0.11945703130391183`, 1, 0.834597956656122], 
        Hue[0.09497156039235655, 1, 0.8685009163798141], 
        Hue[0.0823074735768965, 1, 0.8860358058166048], 
        Hue[0.08230898266914821, 1, 0.8860337163042563], 
        Hue[0.09497346843216548, 1, 0.8684982744785401], 
        Hue[0.11945868288163919`, 1, 0.8345956698561919], 
        Hue[0.1541714593378561, 1, 0.7865318255321992], 
        Hue[0.1969400572019428, 1, 0.7273137669511561], 
        Hue[0.24523947080001152`, 1, 0.6604376558153687], 
        Hue[0.296436644095143, 1, 0.5895492620221098], 
        Hue[0.3480237603580031, 1, 0.5181209471966112], 
        Hue[0.3978109332902869, 1, 0.44918486159806437`], 
        Hue[0.44405995434766987`, 1, 0.385147755518611], 
        Hue[0.48555105221502437`, 1, 0.3276985430868894], 
        Hue[0.5215856976411508, 1, 0.27780441865071437`], 
        Hue[0.5523489934508787, 1, 0.23520908599109105`], 
        Hue[0.6082897478234974, 1, 0.15775265685977274`], 
        Hue[0.6494080042211439, 1, 0.1008196864630316], 
        Hue[0.6493669337431704, 1, 0.10087655327868715`], 
        Hue[0.6053877795136546, 1, 0.16177076682724748`], 
        Hue[0.5455419279510902, 1, 0.2446342536061827], 
        Hue[0.5126275239482238, 1, 0.2902080437639979], 
        Hue[0.47407150139525717`, 1, 0.3435933057604132], 
        Hue[0.42967539275756805`, 1, 0.4050648407972135], 
        Hue[0.3801863883092051, 1, 0.4735880777257161], 
        Hue[0.32690957967886247`, 1, 0.5473559665984982], 
        Hue[0.2717050530304971, 1, 0.6237930034962348], 
        Hue[0.21691642787575777`, 1, 0.6996541767874123], 
        Hue[0.16522767428299484`, 1, 0.7712232202235456], 
        Hue[0.11945703130391194`, 1, 0.8345979566561219], 
        Hue[0.08230720366207966, 1, 0.8860361795448127], 
        Hue[0.05610269050278349, 1, 0.9223193516115306], 
        Hue[0.04254948112586965, 1, 0.941085333825719], 
        Hue[0.04255139790497975, 1, 0.9410826798238742], 
        Hue[0.0561051139248433, 1, 0.9223159961040631], 
        Hue[0.08230930110914958, 1, 0.8860332753873313], 
        Hue[0.11945868288163874`, 1, 0.8345956698561925], 
        Hue[0.16522880754687713`, 1, 0.7712216510889394], 
        Hue[0.21691702070062646`, 1, 0.6996533559529787], 
        Hue[0.2717051313115346, 1, 0.6237928951071059], 
        Hue[0.32690920887930336`, 1, 0.5473564800132723], 
        Hue[0.3801856611748629, 1, 0.4735890845271129], 
        Hue[0.4296744158266316, 1, 0.40506619347081785`], 
        Hue[0.4740703816899864, 1, 0.3435948561215574], 
        Hue[0.5126263581144317, 1, 0.2902096579954024], 
        Hue[0.5455406136566956, 1, 0.24463607339842153`], 
        Hue[0.6053827643478735, 1, 0.16177771090294435`], 
        Hue[0.6493666872241856, 1, 0.10087689461266622`], 
        Hue[0.6493378392973852, 1, 0.1009168378959282], 
        Hue[0.6033385675660863, 1, 0.16460813721618822`], 
        Hue[0.5407408069589723, 1, 0.2512819595952691], 
        Hue[0.5063092649943483, 1, 0.2989564023155178], 
        Hue[0.46597482804496104`, 1, 0.3548040842454385], 
        Hue[0.4195297118980599, 1, 0.4191127066026864], 
        Hue[0.3677553925087863, 1, 0.49080022575706517`], 
        Hue[0.31201716690331643`, 1, 0.5679762304415619], 
        Hue[0.2542610914705461, 1, 0.6479461810407824], 
        Hue[0.19693913314547795`, 1, 0.7273150464139536], 
        Hue[0.14285972467856234`, 1, 0.8021942273681445], 
        Hue[0.09497156039235666, 1, 0.8685009163798139], 
        Hue[0.05610269050278349, 1, 0.9223193516115304], 
        Hue[0.02868546910747416, 1, 0.9602816581588819], 
        Hue[0.0145049859476436, 1, 0.9799161733032626], 
        Hue[0.014507200776745277`, 1, 0.9799131066168142], 
        Hue[0.028688269301960334`, 1, 0.9602777809665164], 
        Hue[0.05610511392484363, 1, 0.9223159961040626], 
        Hue[0.09497346843216581, 1, 0.8684982744785397], 
        Hue[0.14286103359112723`, 1, 0.80219241502767], 
        Hue[0.19693981755676226`, 1, 0.7273140987675599], 
        Hue[0.25426118126936936`, 1, 0.6479460567039501], 
        Hue[0.3120167377448941, 1, 0.5679768246609159], 
        Hue[0.3677545517203818, 1, 0.49080138992562516`], 
        Hue[0.41952858263311305`, 1, 0.419114270200305], 
        Hue[0.46597353397213803`, 1, 0.35480587603857816`], 
        Hue[0.5063079178181411, 1, 0.2989582676364201], 
        Hue[0.5407392886284856, 1, 0.2512840618990199], 
        Hue[0.6033327766268458, 1, 0.164616155439752], 
        Hue[0.6493375546952845, 1, 0.10091723196037532`], 
        Hue[0.6493227485192283, 1, 0.10093773281953008`], 
        Hue[0.6022780343317817, 1, 0.16607656784830227`], 
        Hue[0.5382576968540977, 1, 0.25472011204817235`], 
        Hue[0.5030415295754531, 1, 0.30348095904937267`], 
        Hue[0.4617872821693424, 1, 0.3606022246886028], 
        Hue[0.41428239665310546`, 1, 0.4263782200187771], 
        Hue[0.3613260963423509, 1, 0.4997023281413603], 
        Hue[0.30431479674022255`, 1, 0.5786410506673841], 
        Hue[0.24523898831927277`, 1, 0.6604383238656223], 
        Hue[0.1866068100545651, 1, 0.7416213399244483], 
        Hue[0.13129084465845575`, 1, 0.8182126766267536], 
        Hue[0.0823074735768965, 1, 0.8860358058166048], 
        Hue[0.04254948112586965, 1, 0.941085333825719], 
        Hue[0.014504985947643378`, 1, 0.9799161733032631], 
        Hue[9.992007221626409*^-16, 1, 0.9999999999999986], 
        Hue[1.7519034480883988`*^-6, 1, 0.9999975742875334], 
        Hue[0.014507200776744833`, 1, 0.9799131066168147], 
        Hue[0.04255139790497986, 1, 0.941082679823874], 
        Hue[0.08230898266914832, 1, 0.8860337163042562], 
        Hue[0.13129187980583035`, 1, 0.8182112433457733], 
        Hue[0.18660735119910332`, 1, 0.7416205906473954], 
        Hue[0.24523905911221994`, 1, 0.6604382258446185], 
        Hue[0.30431445703672644`, 1, 0.5786415210260711], 
        Hue[0.36132543116871385`, 1, 0.4997032491510116], 
        Hue[0.4142815032981123, 1, 0.42637945697184454`], 
        Hue[0.4617862584711786, 1, 0.3606036421168296], 
        Hue[0.5030404640559988, 1, 0.3034824343840017], 
        Hue[0.5382564959967934, 1, 0.25472177477367075`], 
        Hue[0.6022734552879471, 1, 0.1660829080628426], 
        Hue[0.6493225234655081, 1, 0.10093804443237338`], 
        Hue[0.6493225234655081, 1, 0.10093804443237338`], 
        Hue[0.602273455287948, 1, 0.16608290806284137`], 
        Hue[0.5382564959967934, 1, 0.2547217747736707], 
        Hue[0.5030404640559991, 1, 0.30348243438400135`], 
        Hue[0.46178625847117916`, 1, 0.36060364211682894`], 
        Hue[0.41428150329811186`, 1, 0.4263794569718452], 
        Hue[0.36132543116871485`, 1, 0.4997032491510103], 
        Hue[0.30431445703672694`, 1, 0.5786415210260704], 
        Hue[0.24523905911222044`, 1, 0.6604382258446179], 
        Hue[0.18660735119910365`, 1, 0.7416205906473949], 
        Hue[0.1312918798058309, 1, 0.8182112433457727], 
        Hue[0.08230898266914821, 1, 0.8860337163042564], 
        Hue[0.04255139790497964, 1, 0.9410826798238744], 
        Hue[0.014507200776745277`, 1, 0.9799131066168143], 
        Hue[1.7519034479773765`*^-6, 1, 0.9999975742875336], 
        Hue[0., 1, 1.], 
        Hue[0.014504985947642601`, 1, 0.9799161733032642], 
        Hue[0.04254948112586965, 1, 0.941085333825719], 
        Hue[0.08230747357689572, 1, 0.8860358058166059], 
        Hue[0.13129084465845464`, 1, 0.8182126766267551], 
        Hue[0.1866068100545641, 1, 0.7416213399244498], 
        Hue[0.24523898831927204`, 1, 0.6604383238656233], 
        Hue[0.30431479674022205`, 1, 0.5786410506673849], 
        Hue[0.3613260963423495, 1, 0.4997023281413622], 
        Hue[0.4142823966531056, 1, 0.4263782200187769], 
        Hue[0.4617872821693415, 1, 0.36060222468860403`], 
        Hue[0.5030415295754525, 1, 0.3034809590493736], 
        Hue[0.5382576968540976, 1, 0.2547201120481726], 
        Hue[0.6022780343317808, 1, 0.16607656784830355`], 
        Hue[0.6493227485192283, 1, 0.10093773281953008`], 
        Hue[0.6493375546952845, 1, 0.10091723196037532`], 
        Hue[0.6033327766268467, 1, 0.16461615543975078`], 
        Hue[0.5407392886284856, 1, 0.2512840618990199], 
        Hue[0.5063079178181413, 1, 0.29895826763641975`], 
        Hue[0.4659735339721385, 1, 0.3548058760385776], 
        Hue[0.41952858263311266`, 1, 0.41911427020030556`], 
        Hue[0.3677545517203828, 1, 0.49080138992562383`], 
        Hue[0.3120167377448938, 1, 0.5679768246609164], 
        Hue[0.25426118126936953`, 1, 0.6479460567039499], 
        Hue[0.19693981755676204`, 1, 0.7273140987675603], 
        Hue[0.14286103359112778`, 1, 0.8021924150276692], 
        Hue[0.09497346843216536, 1, 0.8684982744785403], 
        Hue[0.056105113924843186`, 1, 0.9223159961040633], 
        Hue[0.028688269301960556`, 1, 0.9602777809665161], 
        Hue[0.014507200776744722`, 1, 0.979913106616815], 
        Hue[0.014504985947642268`, 1, 0.9799161733032645], 
        Hue[0.02868546910747294, 1, 0.9602816581588836], 
        Hue[0.056102690502782715`, 1, 0.9223193516115316], 
        Hue[0.09497156039235577, 1, 0.8685009163798152], 
        Hue[0.142859724678561, 1, 0.8021942273681463], 
        Hue[0.196939133145477, 1, 0.727315046413955], 
        Hue[0.2542610914705451, 1, 0.6479461810407837], 
        Hue[0.31201716690331577`, 1, 0.5679762304415628], 
        Hue[0.36775539250878486`, 1, 0.49080022575706717`], 
        Hue[0.41952971189805954`, 1, 0.41911270660268685`], 
        Hue[0.46597482804496027`, 1, 0.35480408424543974`], 
        Hue[0.5063092649943477, 1, 0.29895640231551857`], 
        Hue[0.5407408069589721, 1, 0.25128195959526944`], 
        Hue[0.6033385675660854, 1, 0.1646081372161895], 
        Hue[0.6493378392973852, 1, 0.1009168378959282], 
        Hue[0.6493666872241856, 1, 0.10087689461266622`], 
        Hue[0.6053827643478744, 1, 0.16177771090294316`], 
        Hue[0.5455406136566957, 1, 0.24463607339842136`], 
        Hue[0.5126263581144319, 1, 0.290209657995402], 
        Hue[0.47407038168998694`, 1, 0.3435948561215566], 
        Hue[0.42967441582663135`, 1, 0.4050661934708182], 
        Hue[0.38018566117486396`, 1, 0.47358908452711146`], 
        Hue[0.3269092088793037, 1, 0.5473564800132719], 
        Hue[0.27170513131153523`, 1, 0.623792895107105], 
        Hue[0.21691702070062696`, 1, 0.6996533559529781], 
        Hue[0.1652288075468783, 1, 0.7712216510889378], 
        Hue[0.11945868288163919`, 1, 0.8345956698561919], 
        Hue[0.08230930110914947, 1, 0.8860332753873316], 
        Hue[0.05610511392484363, 1, 0.9223159961040626], 
        Hue[0.04255139790497986, 1, 0.941082679823874], 
        Hue[0.042549481125869426`, 1, 0.9410853338257192], 
        Hue[0.056102690502782715`, 1, 0.9223193516115316], 
        Hue[0.08230720366208022, 1, 0.8860361795448121], 
        Hue[0.11945703130391139`, 1, 0.8345979566561228], 
        Hue[0.16522767428299417`, 1, 0.7712232202235465], 
        Hue[0.2169164278757577, 1, 0.6996541767874124], 
        Hue[0.27170505303049614`, 1, 0.6237930034962361], 
        Hue[0.32690957967886214`, 1, 0.5473559665984986], 
        Hue[0.38018638830920415`, 1, 0.4735880777257174], 
        Hue[0.4296753927575682, 1, 0.4050648407972133], 
        Hue[0.47407150139525644`, 1, 0.34359330576041414`], 
        Hue[0.5126275239482234, 1, 0.29020804376399834`], 
        Hue[0.5455419279510902, 1, 0.24463425360618277`], 
        Hue[0.6053877795136537, 1, 0.16177076682724867`], 
        Hue[0.6493669337431704, 1, 0.10087655327868715`], 
        Hue[0.6494080042211439, 1, 0.1008196864630316], 
        Hue[0.6082897478234983, 1, 0.15775265685977166`], 
        Hue[0.5523489934508788, 1, 0.2352090859910909], 
        Hue[0.521585697641151, 1, 0.277804418650714], 
        Hue[0.4855510522150247, 1, 0.32769854308688884`], 
        Hue[0.4440599543476695, 1, 0.3851477555186116], 
        Hue[0.39781093329028766`, 1, 0.44918486159806326`], 
        Hue[0.34802376035800314`, 1, 0.5181209471966111], 
        Hue[0.29643664409514314`, 1, 0.5895492620221096], 
        Hue[0.24523947080001135`, 1, 0.6604376558153688], 
        Hue[0.19694005720194352`, 1, 0.7273137669511551], 
        Hue[0.15417145933785564`, 1, 0.7865318255321999], 
        Hue[0.11945868288163886`, 1, 0.8345956698561924], 
        Hue[0.09497346843216592, 1, 0.8684982744785396], 
        Hue[0.08230898266914821, 1, 0.8860337163042563], 
        Hue[0.08230747357689572, 1, 0.8860358058166059], 
        Hue[0.09497156039235577, 1, 0.8685009163798151], 
        Hue[0.11945703130391139`, 1, 0.8345979566561227], 
        Hue[0.1541701585717224, 1, 0.7865336265929997], 
        Hue[0.19693916442808063`, 1, 0.7273150030995806], 
        Hue[0.24523900321299064`, 1, 0.6604383032435515], 
        Hue[0.2964365814605738, 1, 0.5895493487468979], 
        Hue[0.3480240514385639, 1, 0.5181205441619885], 
        Hue[0.3978115050201386, 1, 0.4491840699721158], 
        Hue[0.4440607229610806, 1, 0.3851466912846576], 
        Hue[0.48555193349735115`, 1, 0.32769732284982156`], 
        Hue[0.521586615453609, 1, 0.27780314783346455`], 
        Hue[0.5523500286717986, 1, 0.23520765260827892`], 
        Hue[0.6082937016181811, 1, 0.15774718237482627`], 
        Hue[0.649408198526006, 1, 0.10081941742553022`], 
        Hue[0.6494589248602171, 1, 0.10074918096277648`], 
        Hue[0.6118725930131017, 1, 0.15279179428955145`], 
        Hue[0.5607400386245786, 1, 0.22359071575058354`], 
        Hue[0.5326271410244353, 1, 0.2625162662738588], 
        Hue[0.49969910263028317`, 1, 0.308108934819608], 
        Hue[0.46178699841355325`, 1, 0.360602617581234], 
        Hue[0.419529382710668, 1, 0.4191131624006136], 
        Hue[0.37404089470482704`, 1, 0.4820972227163933], 
        Hue[0.3269096566629647, 1, 0.5473558600051259], 
        Hue[0.2801361764938012, 1, 0.6121191402393522], 
        Hue[0.23601130327494585`, 1, 0.6732151185423827], 
        Hue[0.19694005720194296`, 1, 0.7273137669511559], 
        Hue[0.1652288075468772, 1, 0.7712216510889393], 
        Hue[0.14286103359112723`, 1, 0.80219241502767], 
        Hue[0.13129187980583035`, 1, 0.8182112433457733], 
        Hue[0.13129084465845486`, 1, 0.8182126766267548], 
        Hue[0.1428597246785609, 1, 0.8021942273681465], 
        Hue[0.16522767428299384`, 1, 0.7712232202235471], 
        Hue[0.19693916442808057`, 1, 0.7273150030995807], 
        Hue[0.23601068976558415`, 1, 0.6732159680168835], 
        Hue[0.2801358546894727, 1, 0.6121195858145763], 
        Hue[0.3269096126332466, 1, 0.5473559209693509], 
        Hue[0.37404109317128437`, 1, 0.4820969479166832], 
        Hue[0.4195297739541004, 1, 0.41911262067893795`], 
        Hue[0.46178752493995634`, 1, 0.3606018885446758], 
        Hue[0.4996997067575757, 1, 0.30810809833566444`], 
        Hue[0.5326277706763933, 1, 0.2625153944480707], 
        Hue[0.5607407492766578, 1, 0.22358973177078156`], 
        Hue[0.611875312059138, 1, 0.15278802945657816`], 
        Hue[0.6494590585595534, 1, 0.10074899584061832`], 
        Hue[0.6495164551284213, 1, 0.1006695236683399], 
        Hue[0.6159205640488971, 1, 0.14718691131691178`], 
        Hue[0.5702200298684389, 1, 0.21046457402831537`], 
        Hue[0.545100653122046, 1, 0.24524524952332097`], 
        Hue[0.5156811510231455, 1, 0.2859799447371832], 
        Hue[0.48181085405609536`, 1, 0.3328772789992527], 
        Hue[0.4440605731298055, 1, 0.3851468987433462], 
        Hue[0.4034261758855694, 1, 0.4414099103122886], 
        Hue[0.3613262891432053, 1, 0.4997020611863311], 
        Hue[0.3195477299800872, 1, 0.5575492969506486], 
        Hue[0.2801361764938014, 1, 0.6121191402393519], 
        Hue[0.24523947080001135`, 1, 0.6604376558153688], 
        Hue[0.21691702070062646`, 1, 0.6996533559529787], 
        Hue[0.19693981755676215`, 1, 0.72731409876756], 
        Hue[0.18660735119910338`, 1, 0.7416205906473954], 
        Hue[0.18660681005456414`, 1, 0.7416213399244497], 
        Hue[0.196939133145477, 1, 0.727315046413955], 
        Hue[0.2169164278757577, 1, 0.6996541767874124], 
        Hue[0.2452390032129909, 1, 0.660438303243551], 
        Hue[0.28013585468947266`, 1, 0.6121195858145764], 
        Hue[0.31954756031937853`, 1, 0.5575495318654758], 
        Hue[0.36132626453773325`, 1, 0.4997020952554463], 
        Hue[0.4034262782047576, 1, 0.4414097686395664], 
        Hue[0.4440607762893011, 1, 0.3851466174455832], 
        Hue[0.48181112837128043`, 1, 0.33287689917822716`], 
        Hue[0.5156814663990656, 1, 0.28597950806283223`], 
        Hue[0.5451009821631011, 1, 0.24524479392801388`], 
        Hue[0.5702204021385244, 1, 0.21046405857742778`], 
        Hue[0.6159219947998313, 1, 0.1471849302771567], 
        Hue[0.6495165254872346, 1, 0.1006694262484444], 
        Hue[0.6495774685201788, 1, 0.10058504358744468`], 
        Hue[0.6202136935615623, 1, 0.14124257814552912`], 
        Hue[0.5802737264094404, 1, 0.19654407112539013`], 
        Hue[0.5583279587081368, 1, 0.22693051871181064`], 
        Hue[0.5326277508879955, 1, 0.26251542184739085`], 
        Hue[0.5030417571916423, 1, 0.30348064388849516`], 
        Hue[0.47006888141789427`, 1, 0.3491353949598388], 
        Hue[0.4345791545435442, 1, 0.39827501678586197`], 
        Hue[0.39781155912194954`, 1, 0.449183995061916], 
        Hue[0.36132628914320525`, 1, 0.4997020611863312], 
        Hue[0.3269096566629648, 1, 0.5473558600051257], 
        Hue[0.29643664409514314`, 1, 0.5895492620221096], 
        Hue[0.27170513131153445`, 1, 0.6237928951071061], 
        Hue[0.2542611812693693, 1, 0.6479460567039502], 
        Hue[0.24523905911221994`, 1, 0.6604382258446185], 
        Hue[0.2452389883192717, 1, 0.6604383238656238], 
        Hue[0.25426109147054493`, 1, 0.6479461810407839], 
        Hue[0.2717050530304966, 1, 0.6237930034962356], 
        Hue[0.2964365814605738, 1, 0.5895493487468979], 
        Hue[0.32690961263324664`, 1, 0.5473559209693508], 
        Hue[0.36132626453773325`, 1, 0.4997020952554463], 
        Hue[0.3978115532132151, 1, 0.4491840032432406], 
        Hue[0.4345791654814396, 1, 0.39827500164108376`], 
        Hue[0.4700689058025461, 1, 0.3491353611964746], 
        Hue[0.5030417915253734, 1, 0.303480596349483], 
        Hue[0.5326277913778141, 1, 0.262515365784565], 
        Hue[0.5583280015998114, 1, 0.22693045932333808`], 
        Hue[0.5802737763923935, 1, 0.1965440019182244], 
        Hue[0.6202138963403879, 1, 0.14124229737484756`], 
        Hue[0.649577478494239, 1, 0.10058502977720765`], 
        Hue[0.6496389846755347, 1, 0.10049986737233654`], 
        Hue[0.6245422875477541, 1, 0.13524914031849444`], 
        Hue[0.5904098947812237, 1, 0.18250937645676713`], 
        Hue[0.5716624867457912, 1, 0.20846732604428908`], 
        Hue[0.5497102008098527, 1, 0.23886279887866566`], 
        Hue[0.5244411085622436, 1, 0.2738507727599705], 
        Hue[0.4962816544303158, 1, 0.312840786173409], 
        Hue[0.46597501058471447`, 1, 0.3548038314980877], 
        Hue[0.4345791545435441, 1, 0.39827501678586197`], 
        Hue[0.4034261758855695, 1, 0.4414099103122885], 
        Hue[0.3740408947048274, 1, 0.4820972227163929], 
        Hue[0.3480237603580032, 1, 0.518120947196611], 
        Hue[0.3269092088793032, 1, 0.5473564800132725], 
        Hue[0.312016737744894, 1, 0.567976824660916], 
        Hue[0.30431445703672655`, 1, 0.578641521026071], 
        Hue[0.30431479674022205`, 1, 0.5786410506673849], 
        Hue[0.31201716690331593`, 1, 0.5679762304415626], 
        Hue[0.326909579678862, 1, 0.5473559665984988], 
        Hue[0.3480240514385638, 1, 0.5181205441619886], 
        Hue[0.37404109317128426`, 1, 0.48209694791668334`], 
        Hue[0.4034262782047576, 1, 0.4414097686395664], 
        Hue[0.4345791654814396, 1, 0.39827500164108376`], 
        Hue[0.4659749418267992, 1, 0.35480392670135497`], 
        Hue[0.49628152308974804`, 1, 0.3128409680295796], 
        Hue[0.5244409336357099, 1, 0.2738510149659402], 
        Hue[0.5497100013722017, 1, 0.2388630750231053], 
        Hue[0.5716622801396409, 1, 0.2084676121143433], 
        Hue[0.5904096633353363, 1, 0.1825096969203036], 
        Hue[0.6245414168247746, 1, 0.13525034593492746`], 
        Hue[0.6496389419655233, 1, 0.10049992650927547`], 
        Hue[0.649698394426526, 1, 0.10041760771711797`], 
        Hue[0.6287229249078186, 1, 0.12946056551225132`], 
        Hue[0.6001989655967652, 1, 0.16895527840447902`], 
        Hue[0.5845389723395107, 1, 0.1906383459914468], 
        Hue[0.566204178904602, 1, 0.2160249830551666], 
        Hue[0.5451013481926239, 1, 0.24524428711790536`], 
        Hue[0.5215869427511122, 1, 0.2778026946523062], 
        Hue[0.49628165443031536`, 1, 0.3128407861734095], 
        Hue[0.4700688814178937, 1, 0.3491353949598395], 
        Hue[0.44406057312980485`, 1, 0.3851468987433472], 
        Hue[0.41952938271066764`, 1, 0.419113162400614], 
        Hue[0.3978109332902869, 1, 0.44918486159806437`], 
        Hue[0.38018566117486297`, 1, 0.4735890845271128], 
        Hue[0.3677545517203818, 1, 0.49080138992562516`], 
        Hue[0.3613254311687139, 1, 0.4997032491510115], 
        Hue[0.3613260963423495, 1, 0.4997023281413622], 
        Hue[0.3677553925087849, 1, 0.49080022575706705`], 
        Hue[0.38018638830920404`, 1, 0.47358807772571754`], 
        Hue[0.3978115050201385, 1, 0.449184069972116], 
        Hue[0.4195297739541004, 1, 0.41911262067893795`], 
        Hue[0.4440607762893011, 1, 0.3851466174455832], 
        Hue[0.470068905802546, 1, 0.3491353611964748], 
        Hue[0.49628152308974804`, 1, 0.3128409680295796], 
        Hue[0.5215866880302481, 1, 0.2778030473427335], 
        Hue[0.5451010075066368, 1, 0.2452447588369645], 
        Hue[0.5662037895546829, 1, 0.21602552215505455`], 
        Hue[0.5845385676182777, 1, 0.19063890637469244`], 
        Hue[0.6001985108332901, 1, 0.16895590807698294`], 
        Hue[0.6287212009016335, 1, 0.12946295259773827`], 
        Hue[0.6496983097028106, 1, 0.1004177250268776], 
        Hue[0.6497536281731384, 1, 0.10034113022180839`], 
        Hue[0.6326096948107707, 1, 0.12407888410816371`], 
        Hue[0.6092992847532812, 1, 0.1563548364954568], 
        Hue[0.5965079738472142, 1, 0.17406588236539575`], 
        Hue[0.5815339424268632, 1, 0.19479915663972794`], 
        Hue[0.5643012865415892, 1, 0.21865975709626123`], 
        Hue[0.5451013481926243, 1, 0.24524428711790486`], 
        Hue[0.5244411085622438, 1, 0.27385077275997016`], 
        Hue[0.5030417571916427, 1, 0.30348064388849477`], 
        Hue[0.48181085405609547`, 1, 0.3328772789992524], 
        Hue[0.4617869984135538, 1, 0.36060261758123324`], 
        Hue[0.44405995434766965`, 1, 0.38514775551861136`], 
        Hue[0.42967441582663163`, 1, 0.40506619347081774`], 
        Hue[0.4195285826331131, 1, 0.4191142702003049], 
        Hue[0.4142815032981122, 1, 0.42637945697184465`], 
        Hue[0.4142823966531057, 1, 0.4263782200187768], 
        Hue[0.41952971189805965`, 1, 0.4191127066026866], 
        Hue[0.42967539275756816`, 1, 0.4050648407972133], 
        Hue[0.44406072296108057`, 1, 0.3851466912846577], 
        Hue[0.46178752493995645`, 1, 0.3606018885446757], 
        Hue[0.4818111283712803, 1, 0.33287689917822727`], 
        Hue[0.5030417915253734, 1, 0.30348059634948304`], 
        Hue[0.5244409336357099, 1, 0.2738510149659401], 
        Hue[0.5451010075066367, 1, 0.24524475883696456`], 
        Hue[0.5643008298468729, 1, 0.21866038944279137`], 
        Hue[0.5815334198863938, 1, 0.19479988015730082`], 
        Hue[0.5965074304344583, 1, 0.1740666347830578], 
        Hue[0.6092986732582468, 1, 0.15635568318088902`], 
        Hue[0.6326073703548719, 1, 0.124082102585562], 
        Hue[0.6497535139635646, 1, 0.10034128835814127`], 
        Hue[0.6498032208248107, 1, 0.10027246347333903`], 
        Hue[0.6360998533911139, 1, 0.1192463568430732], 
        Hue[0.6174703284313343, 1, 0.1450410837104602], 
        Hue[0.607253262945072, 1, 0.15918778976836193`], 
        Hue[0.5952946063665869, 1, 0.17574592964626434`], 
        Hue[0.5815339424268628, 1, 0.1947991566397283], 
        Hue[0.566204178904602, 1, 0.21602498305516665`], 
        Hue[0.5497102008098523, 1, 0.2388627988786661], 
        Hue[0.5326277508879953, 1, 0.2625154218473912], 
        Hue[0.5156811510231452, 1, 0.2859799447371837], 
        Hue[0.4996991026302829, 1, 0.3081089348196083], 
        Hue[0.4855510522150243, 1, 0.32769854308688945`], 
        Hue[0.4740703816899863, 1, 0.3435948561215575], 
        Hue[0.465973533972138, 1, 0.35480587603857816`], 
        Hue[0.46178625847117855`, 1, 0.3606036421168297], 
        Hue[0.4617872821693415, 1, 0.36060222468860414`], 
        Hue[0.46597482804496027`, 1, 0.35480408424543974`], 
        Hue[0.47407150139525644`, 1, 0.34359330576041414`], 
        Hue[0.48555193349735104`, 1, 0.3276973228498216], 
        Hue[0.4996997067575757, 1, 0.30810809833566444`], 
        Hue[0.5156814663990656, 1, 0.28597950806283223`], 
        Hue[0.5326277913778141, 1, 0.262515365784565], 
        Hue[0.5497100013722017, 1, 0.2388630750231053], 
        Hue[0.5662037895546829, 1, 0.2160255221550545], 
        Hue[0.5815334198863938, 1, 0.19479988015730082`], 
        Hue[0.5952940078074795, 1, 0.17574675842041304`], 
        Hue[0.6072526403378196, 1, 0.15918865183994224`], 
        Hue[0.6174696271668444, 1, 0.14504205469206172`], 
        Hue[0.6360971833227741, 1, 0.11925005386077443`], 
        Hue[0.6498030896255687, 1, 0.10027264513382812`], 
        Hue[0.6498463345952484, 1, 0.10021276748350222`], 
        Hue[0.6391341378578641, 1, 0.1150450398891113], 
        Hue[0.6245734607680122, 1, 0.135205977398137], 
        Hue[0.6165927565645893, 1, 0.14625618321826095`], 
        Hue[0.607253262945072, 1, 0.15918778976836184`], 
        Hue[0.596507973847214, 1, 0.17406588236539605`], 
        Hue[0.5845389723395107, 1, 0.1906383459914467], 
        Hue[0.5716624867457911, 1, 0.2084673260442893], 
        Hue[0.5583279587081367, 1, 0.22693051871181086`], 
        Hue[0.5451006531220457, 1, 0.2452452495233213], 
        Hue[0.5326271410244352, 1, 0.26251626627385904`], 
        Hue[0.5215856976411507, 1, 0.2778044186507145], 
        Hue[0.5126263581144317, 1, 0.2902096579954024], 
        Hue[0.5063079178181411, 1, 0.2989582676364201], 
        Hue[0.5030404640559988, 1, 0.3034824343840017], 
        Hue[0.5030415295754525, 1, 0.30348095904937356`], 
        Hue[0.5063092649943477, 1, 0.29895640231551857`], 
        Hue[0.5126275239482234, 1, 0.29020804376399834`], 
        Hue[0.5215866154536088, 1, 0.2778031478334647], 
        Hue[0.5326277706763933, 1, 0.26251539444807076`], 
        Hue[0.545100982163101, 1, 0.245244793928014], 
        Hue[0.5583280015998114, 1, 0.22693045932333808`], 
        Hue[0.5716622801396409, 1, 0.2084676121143433], 
        Hue[0.5845385676182777, 1, 0.1906389063746924], 
        Hue[0.5965074304344582, 1, 0.1740666347830579], 
        Hue[0.6072526403378196, 1, 0.15918865183994224`], 
        Hue[0.6165921083515686, 1, 0.14625708074398186`], 
        Hue[0.6245727303868367, 1, 0.13520698869514927`], 
        Hue[0.6391313531926316, 1, 0.11504889557943314`], 
        Hue[0.6498461977051377, 1, 0.1002129570236554], 
        Hue[0.6498831956240974, 1, 0.10016172913586517`], 
        Hue[0.6417279253205035, 1, 0.11145364186391826`], 
        Hue[0.6306442987596863, 1, 0.1268002017173574], 
        Hue[0.6245734607680122, 1, 0.1352059773981369], 
        Hue[0.6174703284313344, 1, 0.14504108371046004`], 
        Hue[0.6092992847532812, 1, 0.15635483649545684`], 
        Hue[0.6001989655967653, 1, 0.16895527840447888`], 
        Hue[0.5904098947812237, 1, 0.18250937645676713`], 
        Hue[0.5802737264094405, 1, 0.19654407112539013`], 
        Hue[0.5702200298684389, 1, 0.21046457402831542`], 
        Hue[0.5607400386245787, 1, 0.22359071575058342`], 
        Hue[0.5523489934508787, 1, 0.23520908599109108`], 
        Hue[0.5455406136566956, 1, 0.2446360733984215], 
        Hue[0.5407392886284856, 1, 0.2512840618990199], 
        Hue[0.5382564959967935, 1, 0.25472177477367064`], 
        Hue[0.5382576968540976, 1, 0.2547201120481726], 
        Hue[0.5407408069589721, 1, 0.25128195959526944`], 
        Hue[0.5455419279510902, 1, 0.24463425360618274`], 
        Hue[0.5523500286717986, 1, 0.23520765260827886`], 
        Hue[0.5607407492766578, 1, 0.22358973177078156`], 
        Hue[0.5702204021385244, 1, 0.21046405857742778`], 
        Hue[0.5802737763923935, 1, 0.19654400191822435`], 
        Hue[0.5904096633353363, 1, 0.1825096969203036], 
        Hue[0.6001985108332901, 1, 0.16895590807698296`], 
        Hue[0.6092986732582468, 1, 0.15635568318088902`], 
        Hue[0.6174696271668444, 1, 0.1450420546920617], 
        Hue[0.6245727303868367, 1, 0.13520698869514927`], 
        Hue[0.6306434748977873, 1, 0.12680134244921762`], 
        Hue[0.6417247778031417, 1, 0.11145799996488066`], 
        Hue[0.6498830409238536, 1, 0.10016194333620275`], 
        Hue[0.649950728657251, 1, 0.10006822185919101`], 
        Hue[0.6464693972464388, 1, 0.10488852688954636`], 
        Hue[0.6417279253205034, 1, 0.11145364186391847`], 
        Hue[0.6391341378578639, 1, 0.11504503988911155`], 
        Hue[0.6360998533911136, 1, 0.1192463568430735], 
        Hue[0.6326096948107703, 1, 0.12407888410816416`], 
        Hue[0.6287229249078181, 1, 0.12946056551225182`], 
        Hue[0.6245422875477535, 1, 0.1352491403184951], 
        Hue[0.6202136935615618, 1, 0.1412425781455299], 
        Hue[0.6159205640488965, 1, 0.14718691131691264`], 
        Hue[0.611872593013101, 1, 0.15279179428955236`], 
        Hue[0.6082897478234974, 1, 0.15775265685977274`], 
        Hue[0.6053827643478735, 1, 0.16177771090294435`], 
        Hue[0.6033327766268458, 1, 0.164616155439752], 
        Hue[0.6022734552879471, 1, 0.1660829080628426], 
        Hue[0.6022780343317807, 1, 0.1660765678483036], 
        Hue[0.6033385675660854, 1, 0.1646081372161895], 
        Hue[0.6053877795136537, 1, 0.1617707668272487], 
        Hue[0.6082937016181811, 1, 0.15774718237482627`], 
        Hue[0.611875312059138, 1, 0.15278802945657816`], 
        Hue[0.6159219947998312, 1, 0.14718493027715673`], 
        Hue[0.6202138963403879, 1, 0.14124229737484756`], 
        Hue[0.6245414168247746, 1, 0.1352503459349275], 
        Hue[0.6287212009016335, 1, 0.12946295259773824`], 
        Hue[0.6326073703548719, 1, 0.124082102585562], 
        Hue[0.6360971833227741, 1, 0.11925005386077443`], 
        Hue[0.6391313531926316, 1, 0.11504889557943314`], 
        Hue[0.6417247778031417, 1, 0.11145799996488066`], 
        Hue[0.6464573223024351, 1, 0.10490524604278213`], 
        Hue[0.6499501349069793, 1, 0.10006904397495173`], 
        Hue[0.65, 1, 0.1], 
        Hue[0.649950728657251, 1, 0.10006822185919101`], 
        Hue[0.6498831956240974, 1, 0.10016172913586517`], 
        Hue[0.6498463345952484, 1, 0.10021276748350222`], 
        Hue[0.6498032208248107, 1, 0.10027246347333903`], 
        Hue[0.6497536281731384, 1, 0.10034113022180839`], 
        Hue[0.649698394426526, 1, 0.10041760771711797`], 
        Hue[0.6496389846755347, 1, 0.10049986737233654`], 
        Hue[0.6495774685201788, 1, 0.10058504358744468`], 
        Hue[0.6495164551284213, 1, 0.1006695236683399], 
        Hue[0.6494589248602171, 1, 0.10074918096277646`], 
        Hue[0.6494080042211439, 1, 0.1008196864630316], 
        Hue[0.6493666872241856, 1, 0.10087689461266622`], 
        Hue[0.6493375546952845, 1, 0.10091723196037532`], 
        Hue[0.6493225234655081, 1, 0.10093804443237338`], 
        Hue[0.6493227485192283, 1, 0.10093773281953008`], 
        Hue[0.6493378392973852, 1, 0.1009168378959282], 
        Hue[0.6493669337431704, 1, 0.10087655327868715`], 
        Hue[0.649408198526006, 1, 0.10081941742553022`], 
        Hue[0.6494590585595534, 1, 0.10074899584061832`], 
        Hue[0.6495165254872346, 1, 0.1006694262484444], 
        Hue[0.649577478494239, 1, 0.10058502977720765`], 
        Hue[0.6496389419655233, 1, 0.10049992650927547`], 
        Hue[0.6496983097028106, 1, 0.1004177250268776], 
        Hue[0.6497535139635646, 1, 0.10034128835814127`], 
        Hue[0.6498030896255687, 1, 0.10027264513382812`], 
        Hue[0.6498461977051377, 1, 0.1002129570236554], 
        Hue[0.6498830409238536, 1, 0.10016194333620275`], 
        Hue[0.6499501349069793, 1, 0.10006904397495173`], 
        Hue[0.6499999708035517, 1, 0.10000004042585155`], 
        Hue[0.6498310718059017, 1, 0.10023390057644375`], 
        Hue[0.6499895959854948, 1, 0.1000144055585458], 
        Hue[0.6498336765377891, 1, 0.10023029402459974`], 
        Hue[0.6499898717593472, 1, 0.10001402371782703`], 
        Hue[0.6498336765377891, 1, 0.10023029402459974`], 
        Hue[0.6499898717593472, 1, 0.10001402371782703`], 
        Hue[0.6498310718059017, 1, 0.10023390057644377`], 
        Hue[0.6499895959854948, 1, 0.1000144055585458], 
        Hue[0.6499895959854948, 1, 0.1000144055585458], 
        Hue[0.6499898717593472, 1, 0.10001402371782703`], 
        Hue[0.6499898717593472, 1, 0.10001402371782703`], 
        Hue[0.6499895959854948, 1, 0.1000144055585458], 
        Hue[0.6499853374217525, 1, 0.10002030203141973`], 
        Hue[0.6499857375801574, 1, 0.10001974796593582`], 
        Hue[0.6499857375801574, 1, 0.10001974796593582`], 
        Hue[0.6499853374217525, 1, 0.10002030203141973`], 
        Hue[0.649997354862171, 1, 0.10000366249853244`], 
        Hue[0.6499974629289912, 1, 0.1000035128675507], 
        Hue[0.6499974629289912, 1, 0.1000035128675507], 
        Hue[0.649997354862171, 1, 0.10000366249853244`], 
        Hue[0.649997354862171, 1, 0.10000366249853244`], 
        Hue[0.6499974629289912, 1, 0.1000035128675507], 
        Hue[0.6499974629289912, 1, 0.1000035128675507], 
        Hue[0.649997354862171, 1, 0.10000366249853244`], 
        Hue[0.6498956210456897, 1, 0.10014452470596819`], 
        Hue[0.6426121298967594, 1, 0.11022935860448697`], 
        Hue[0.6498192551554071, 1, 0.10025026209251335`], 
        Hue[0.6372349970239709, 1, 0.11767461950527106`], 
        Hue[0.6497293620994847, 1, 0.10037472940071342`], 
        Hue[0.6309071712190805, 1, 0.12643622446588856`], 
        Hue[0.6496235760977022, 1, 0.10052120232625851`], 
        Hue[0.6234595367036785, 1, 0.13674833379490678`], 
        Hue[0.6495129338042546, 1, 0.10067439934795527`], 
        Hue[0.6156690771285387, 1, 0.1475351239758696], 
        Hue[0.6494145560301994, 1, 0.10081061472741623`], 
        Hue[0.6087414029233015, 1, 0.1571272882600441], 
        Hue[0.6493469313116931, 1, 0.10090424895304037`], 
        Hue[0.6039789462997014, 1, 0.1637214589696442], 
        Hue[0.6493226359923682, 1, 0.10093788862595174`], 
        Hue[0.6022757448098648, 1, 0.1660797379555718], 
        Hue[0.6493466586105661, 1, 0.10090462653921622`], 
        Hue[0.6039733977896679, 1, 0.1637291415219984], 
        Hue[0.649414369301028, 1, 0.10081087327549972`], 
        Hue[0.6087376034721987, 1, 0.15713254903849413`], 
        Hue[0.6495128594866585, 1, 0.10067450224924218`], 
        Hue[0.6156675658591599, 1, 0.14753721650270174`], 
        Hue[0.6496236056366957, 1, 0.10052116142611357`], 
        Hue[0.6234601390512061, 1, 0.1367474997752531], 
        Hue[0.6497294634089954, 1, 0.10037458912600633`], 
        Hue[0.6309092329782291, 1, 0.12643336972245203`], 
        Hue[0.6498193884887249, 1, 0.10025007747715022`], 
        Hue[0.6372377100661452, 1, 0.11767086298533747`], 
        Hue[0.6498958580678137, 1, 0.10014419652148876`], 
        Hue[0.6426169513066163, 1, 0.1102226828062235], 
        Hue[0.6327212191925413, 1, 0.12392446573340435`], 
        Hue[0.6201332908743415, 1, 0.1413539049432194], 
        Hue[0.6053173521973284, 1, 0.16186828157292996`], 
        Hue[0.5878756915996007, 1, 0.18601827316978367`], 
        Hue[0.5696279238346579, 1, 0.21128441315201224`], 
        Hue[0.5533988687474062, 1, 0.23375541250359141`], 
        Hue[0.5422411572690091, 1, 0.24920455147367962`], 
        Hue[0.5382570964254456, 1, 0.25472094341092155`], 
        Hue[0.5422397026998013, 1, 0.24920656549258285`], 
        Hue[0.5533978740975913, 1, 0.2337567897110275], 
        Hue[0.5696275304156977, 1, 0.21128495788595708`], 
        Hue[0.587875852688278, 1, 0.18601805012392278`], 
        Hue[0.6053178951223055, 1, 0.161867529830654], 
        Hue[0.6201340030575886, 1, 0.14135291884333895`], 
        Hue[0.6327224787398396, 1, 0.12392272174483751`], 
        Hue[0.6273024721629233, 1, 0.13142734623595234`], 
        Hue[0.6107549408429757, 1, 0.15433931267895676`], 
        Hue[0.5912710529523796, 1, 0.1813170036043976], 
        Hue[0.5683287105046838, 1, 0.21308332391659163`], 
        Hue[0.5443214064451822, 1, 0.246324206460517], 
        Hue[0.5229667598564574, 1, 0.2758921786602898], 
        Hue[0.5082837209174343, 1, 0.2962225402681678], 
        Hue[0.5030409968157261, 1, 0.303481696716687], 
        Hue[0.5082824304107321, 1, 0.2962243271236017], 
        Hue[0.5229658780640616, 1, 0.27589339960360704`], 
        Hue[0.5443210586159454, 1, 0.24632468807022953`], 
        Hue[0.5683288547363777, 1, 0.21308312421116937`], 
        Hue[0.5912715356875939, 1, 0.181316335201793], 
        Hue[0.610755573052391, 1, 0.154338437312074], 
        Hue[0.6273035877223595, 1, 0.13142580161519454`], 
        Hue[0.6209622939460814, 1, 0.1402060545361951], 
        Hue[0.5997784950063574, 1, 0.16953746845273604`], 
        Hue[0.5748267066162707, 1, 0.20408609853131754`], 
        Hue[0.5454394488736053, 1, 0.2447761477134696], 
        Hue[0.5146826064214731, 1, 0.28736254495488345`], 
        Hue[0.48732040515487984`, 1, 0.32524866978555106`], 
        Hue[0.4685050384669286, 1, 0.35130071596886814`], 
        Hue[0.4617867703202607, 1, 0.360602933402716], 
        Hue[0.46850379888396604`, 1, 0.35130243231450864`], 
        Hue[0.48731955851693204`, 1, 0.32524984205347873`], 
        Hue[0.5146822729985917, 1, 0.28736300661733466`], 
        Hue[0.5454395883293883, 1, 0.2447759546208469], 
        Hue[0.574827170885874, 1, 0.20408545569648226`], 
        Hue[0.5997791025835189, 1, 0.16953662719205081`], 
        Hue[0.6209633643612932, 1, 0.14020457242282494`], 
        Hue[0.6136690539638641, 1, 0.1503043868192651], 
        Hue[0.5871486738419182, 1, 0.18702491314195946`], 
        Hue[0.5559009075730197, 1, 0.230291051052742], 
        Hue[0.5190911481081257, 1, 0.28125841031182586`], 
        Hue[0.48055965315682275`, 1, 0.3346097110136301], 
        Hue[0.4462765732084403, 1, 0.3820785909421597], 
        Hue[0.42270023716665617`, 1, 0.4147227485384761], 
        Hue[0.41428194997560847`, 1, 0.42637883849531133`], 
        Hue[0.4226991555060873, 1, 0.4147242462223407], 
        Hue[0.4462758348559051, 1, 0.38207961327643913`], 
        Hue[0.4805593630784365, 1, 0.33461011266062646`], 
        Hue[0.5190912707195934, 1, 0.2812582405421015], 
        Hue[0.555901313513917, 1, 0.23029048898073037`], 
        Hue[0.5871492042094946, 1, 0.18702417878685362`], 
        Hue[0.6136699866390606, 1, 0.1503030954228393], 
        Hue[0.6055465152211047, 1, 0.16155097892462425`], 
        Hue[0.5730793313285315, 1, 0.20650554123741802`], 
        Hue[0.5348134927357172, 1, 0.25948901005823777`], 
        Hue[0.48972836876794834`, 1, 0.32191456632130233`], 
        Hue[0.44252758864335195`, 1, 0.38726949264766664`], 
        Hue[0.4005262886368848, 1, 0.4454251388104672], 
        Hue[0.3716400786964172, 1, 0.4854214294972685], 
        Hue[0.3613257637555329, 1, 0.49970278864618534`], 
        Hue[0.37163927342490816`, 1, 0.4854225444885887], 
        Hue[0.4005257394678352, 1, 0.44542589919838205`], 
        Hue[0.4425273737286095, 1, 0.3872697902219254], 
        Hue[0.4897284611772105, 1, 0.3219144383700163], 
        Hue[0.5348137958119629, 1, 0.25948859041420536`], 
        Hue[0.5730797264426928, 1, 0.20650499415627152`], 
        Hue[0.6055472079675879, 1, 0.16155001973718605`], 
        Hue[0.5968093671146062, 1, 0.17364856861054537`], 
        Hue[0.5579421059099918, 1, 0.22746477643231902`], 
        Hue[0.512121191521852, 1, 0.29090911943128195`], 
        Hue[0.4581259977404597, 1, 0.36567169543628664`], 
        Hue[0.40158970414016615`, 1, 0.44395271734438546`], 
        Hue[0.3512761816551544, 1, 0.5136175946313247], 
        Hue[0.3166710458956746, 1, 0.5615323979906045], 
        Hue[0.30431462688847466`, 1, 0.5786412858467274], 
        Hue[0.3166706349743969, 1, 0.5615329669585274], 
        Hue[0.351275902151356, 1, 0.513617981636584], 
        Hue[0.4015895958117729, 1, 0.44395286733754535`], 
        Hue[0.458126046574422, 1, 0.36567162782003104`], 
        Hue[0.5121213473795252, 1, 0.29090890362834976`], 
        Hue[0.5579423080358294, 1, 0.2274644965657747], 
        Hue[0.5968097184249482, 1, 0.17364808218084088`], 
        Hue[0.5877625488826427, 1, 0.1861749323163409], 
        Hue[0.5422653702110636, 1, 0.24917102586160433`], 
        Hue[0.4886161540216369, 1, 0.32345455597004125`], 
        Hue[0.42538726241438385`, 1, 0.41100225204162244`], 
        Hue[0.3591752237937034, 1, 0.5026804593625646], 
        Hue[0.30024571035715847`, 1, 0.5842751702747037], 
        Hue[0.25971232945803074`, 1, 0.6403983130581113], 
        Hue[0.24523902371574657`, 1, 0.6604382748551202], 
        Hue[0.2597124156575461, 1, 0.6403981937049362], 
        Hue[0.3002457706661209, 1, 0.5842750867699864], 
        Hue[0.3591752496131905, 1, 0.5026804236125055], 
        Hue[0.4253872556881457, 1, 0.4110022613548753], 
        Hue[0.4886161240406277, 1, 0.32345459748220784`], 
        Hue[0.5422653288205483, 1, 0.2491710831715484], 
        Hue[0.5877624702504635, 1, 0.18617504119166606`], 
        Hue[0.5787894507625196, 1, 0.19859922202112662`], 
        Hue[0.5267137848105794, 1, 0.2707039902622747], 
        Hue[0.46529534933541483`, 1, 0.35574490092019495`], 
        Hue[0.392901274788002, 1, 0.4559828502935357], 
        Hue[0.31708432871750997`, 1, 0.5609601602372939], 
        Hue[0.24960110964755128`, 1, 0.654398463564929], 
        Hue[0.20318203774869042`, 1, 0.7186710246556594], 
        Hue[0.186607080626834, 1, 0.7416209652859221], 
        Hue[0.20318269353921997`, 1, 0.7186701166380032], 
        Hue[0.24960155901173525`, 1, 0.6543978413683665], 
        Hue[0.31708450788719444`, 1, 0.5609599121561923], 
        Hue[0.39290120419997854`, 1, 0.455982948030799], 
        Hue[0.4652951061508435, 1, 0.3557452376372936], 
        Hue[0.5267134643102329, 1, 0.2707044340319852], 
        Hue[0.5787888800272749, 1, 0.19860001226992707`], 
        Hue[0.5703284797983732, 1, 0.21031441258686795`], 
        Hue[0.5120477307271329, 1, 0.29101083437781583`], 
        Hue[0.4432997588836451, 1, 0.38620033385341457`], 
        Hue[0.3622582230367755, 1, 0.4984116911798493], 
        Hue[0.27737803188173044`, 1, 0.6159381097022194], 
        Hue[0.2018231050952699, 1, 0.7205526237142417], 
        Hue[0.14984970892994753`, 1, 0.7925157876354572], 
        Hue[0.13129136223214322`, 1, 0.8182119599862632], 
        Hue[0.14985096295229972`, 1, 0.7925140512968157], 
        Hue[0.20182396296106897`, 1, 0.7205514359000583], 
        Hue[0.277378371917623, 1, 0.6159376388832912], 
        Hue[0.362258085194362, 1, 0.4984118820385758], 
        Hue[0.4432992915435413, 1, 0.3862009809397121], 
        Hue[0.5120471170280902, 1, 0.29101168411495204`], 
        Hue[0.5703273925724269, 1, 0.21031591797663968`], 
        Hue[0.5628394673492456, 1, 0.22068381443950608`], 
        Hue[0.4990649392309484, 1, 0.3089870072186869], 
        Hue[0.42382669011191887`, 1, 0.41316304446042007`], 
        Hue[0.3351271839440668, 1, 0.5359777453082152], 
        Hue[0.24222026328893442`, 1, 0.6646180969845523], 
        Hue[0.15951628430376785`, 1, 0.7791312986563215], 
        Hue[0.1026232700522175, 1, 0.8579062414661603], 
        Hue[0.08230822812302241, 1, 0.8860347610604306], 
        Hue[0.10262509794762609`, 1, 0.8579037105340562], 
        Hue[0.159517534070867, 1, 0.7791295682095688], 
        Hue[0.24222075745013238`, 1, 0.6646174127613552], 
        Hue[0.3351269812922883, 1, 0.5359780259029855], 
        Hue[0.42382600763506506`, 1, 0.4131639894283715], 
        Hue[0.4990640442498219, 1, 0.30898824642332356`], 
        Hue[0.562837884895745, 1, 0.22068600552896844`], 
        Hue[0.556763025119071, 1, 0.22909734983513236`], 
        Hue[0.48853000985261963`, 1, 0.3235738325117574], 
        Hue[0.4080239533114093, 1, 0.43504375695343334`], 
        Hue[0.31310844801677107`, 1, 0.5664652258229325], 
        Hue[0.21368588077621004`, 1, 0.7041272420021707], 
        Hue[0.12517836167629715`, 1, 0.82667611460205], 
        Hue[0.06429160086506347, 1, 0.9109808603406814], 
        Hue[0.0425504395154247, 1, 0.9410840068247965], 
        Hue[0.06429392241993914, 1, 0.9109776458800843], 
        Hue[0.12517994846479374`, 1, 0.8266739175102856], 
        Hue[0.2136865073785173, 1, 0.7041263743989761], 
        Hue[0.31310818948736147`, 1, 0.5664655837867303], 
        Hue[0.408023085666483, 1, 0.43504495830794665`], 
        Hue[0.4885288728491536, 1, 0.32357540682424896`], 
        Hue[0.5567610169112918, 1, 0.22910013043051913`], 
        Hue[0.5524778870728062, 1, 0.2350306178991915], 
        Hue[0.4811002419009813, 1, 0.3338612035217183], 
        Hue[0.3968784471652526, 1, 0.45047599623272716`], 
        Hue[0.2975781480451238, 1, 0.5879687180913671], 
        Hue[0.1935591701162956, 1, 0.7319949952235908], 
        Hue[0.10095758092813223`, 1, 0.8602125802533553], 
        Hue[0.03725335079350833, 1, 0.9484184373628346], 
        Hue[0.014506093362194439`, 1, 0.9799146399600385], 
        Hue[0.03725603324661142, 1, 0.9484147231969996], 
        Hue[0.10095941407703601`, 1, 0.8602100420471809], 
        Hue[0.19355989355891023`, 1, 0.7319939935338167], 
        Hue[0.29757784862601316`, 1, 0.587969132671674], 
        Hue[0.3968774441087934, 1, 0.45047738508013224`], 
        Hue[0.48109892791438935`, 1, 0.3338630228877686], 
        Hue[0.5524755676281785, 1, 0.2350338294379067], 
        Hue[0.5502615101311635, 1, 0.23809944751069675`], 
        Hue[0.47725762494663393`, 1, 0.3391817500738915], 
        Hue[0.3911140152671503, 1, 0.45845751732240736`], 
        Hue[0.289545844634985, 1, 0.5990903689669439], 
        Hue[0.18314956221730821`, 1, 0.7464082984683424], 
        Hue[0.08843039496209137, 1, 0.8775579146678736], 
        Hue[0.023268890690838928`, 1, 0.9677815359665307], 
        Hue[8.759517245993109*^-7, 1, 0.999998787143766], 
        Hue[0.02327101237931839, 1, 0.9677785982440208], 
        Hue[0.08843184481123367, 1, 0.8775559071844456], 
        Hue[0.18315013423702392`, 1, 0.7464075064410438], 
        Hue[0.28954560755560005`, 1, 0.5990906972307076], 
        Hue[0.39111322174150076`, 1, 0.45845861605022975`], 
        Hue[0.47725658556548634`, 1, 0.3391831892170189], 
        Hue[0.550259675863885, 1, 0.23810198726539], 
        Hue[0.5502596758638848, 1, 0.23810198726539025`], 
        Hue[0.47725658556548656`, 1, 0.3391831892170186], 
        Hue[0.3911132217415006, 1, 0.45845861605023], 
        Hue[0.28954560755560027`, 1, 0.5990906972307073], 
        Hue[0.18315013423702398`, 1, 0.7464075064410437], 
        Hue[0.08843184481123334, 1, 0.8775559071844462], 
        Hue[0.02327101237931839, 1, 0.9677785982440207], 
        Hue[8.759517239331771*^-7, 1, 0.9999987871437669], 
        Hue[0.023268890690838595`, 1, 0.9677815359665312], 
        Hue[0.08843039496209071, 1, 0.8775579146678745], 
        Hue[0.18314956221730733`, 1, 0.7464082984683437], 
        Hue[0.2895458446349848, 1, 0.5990903689669441], 
        Hue[0.39111401526715, 1, 0.4584575173224077], 
        Hue[0.47725762494663326`, 1, 0.3391817500738924], 
        Hue[0.5502615101311635, 1, 0.23809944751069664`], 
        Hue[0.5524755676281783, 1, 0.23503382943790696`], 
        Hue[0.48109892791438946`, 1, 0.3338630228877685], 
        Hue[0.39687744410879333`, 1, 0.45047738508013235`], 
        Hue[0.2975778486260126, 1, 0.5879691326716749], 
        Hue[0.19355989355890985`, 1, 0.7319939935338171], 
        Hue[0.10095941407703546`, 1, 0.8602100420471817], 
        Hue[0.03725603324661131, 1, 0.9484147231969997], 
        Hue[0.01450609336219355, 1, 0.9799146399600398], 
        Hue[0.037253350793507334`, 1, 0.948418437362836], 
        Hue[0.10095758092813145`, 1, 0.8602125802533565], 
        Hue[0.19355917011629492`, 1, 0.7319949952235917], 
        Hue[0.29757814804512334`, 1, 0.5879687180913677], 
        Hue[0.3968784471652521, 1, 0.4504759962327278], 
        Hue[0.4811002419009807, 1, 0.333861203521719], 
        Hue[0.5524778870728062, 1, 0.23503061789919152`], 
        Hue[0.5567610169112918, 1, 0.22910013043051922`], 
        Hue[0.4885288728491538, 1, 0.32357540682424857`], 
        Hue[0.4080230856664831, 1, 0.43504495830794654`], 
        Hue[0.3131081894873615, 1, 0.5664655837867302], 
        Hue[0.21368650737851752`, 1, 0.7041263743989757], 
        Hue[0.12517994846479386`, 1, 0.8266739175102854], 
        Hue[0.06429392241993914, 1, 0.9109776458800842], 
        Hue[0.0425504395154247, 1, 0.9410840068247966], 
        Hue[0.06429160086506325, 1, 0.9109808603406816], 
        Hue[0.1251783616762967, 1, 0.8266761146020507], 
        Hue[0.2136858807762101, 1, 0.7041272420021706], 
        Hue[0.3131084480167709, 1, 0.5664652258229326], 
        Hue[0.40802395331140917`, 1, 0.43504375695343345`], 
        Hue[0.4885300098526193, 1, 0.323573832511758], 
        Hue[0.5567630251190712, 1, 0.2290973498351322], 
        Hue[0.5628378848957449, 1, 0.22068600552896855`], 
        Hue[0.4990640442498221, 1, 0.3089882464233233], 
        Hue[0.42382600763506484`, 1, 0.41316398942837174`], 
        Hue[0.335126981292288, 1, 0.5359780259029858], 
        Hue[0.242220757450132, 1, 0.6646174127613557], 
        Hue[0.15951753407086655`, 1, 0.7791295682095694], 
        Hue[0.10262509794762609`, 1, 0.8579037105340561], 
        Hue[0.08230822812302196, 1, 0.8860347610604311], 
        Hue[0.10262327005221694`, 1, 0.8579062414661611], 
        Hue[0.15951628430376724`, 1, 0.7791312986563222], 
        Hue[0.24222026328893392`, 1, 0.6646180969845531], 
        Hue[0.3351271839440666, 1, 0.5359777453082155], 
        Hue[0.42382669011191876`, 1, 0.4131630444604203], 
        Hue[0.49906493923094797`, 1, 0.30898700721868744`], 
        Hue[0.5628394673492456, 1, 0.22068381443950613`], 
        Hue[0.5703273925724266, 1, 0.21031591797664007`], 
        Hue[0.5120471170280902, 1, 0.29101168411495204`], 
        Hue[0.44329929154354086`, 1, 0.38620098093971267`], 
        Hue[0.3622580851943614, 1, 0.49841188203857656`], 
        Hue[0.2773783719176226, 1, 0.6159376388832918], 
        Hue[0.20182396296106825`, 1, 0.7205514359000593], 
        Hue[0.14985096295229905`, 1, 0.7925140512968167], 
        Hue[0.13129136223214255`, 1, 0.8182119599862641], 
        Hue[0.1498497089299461, 1, 0.7925157876354592], 
        Hue[0.20182310509526863`, 1, 0.7205526237142434], 
        Hue[0.27737803188172977`, 1, 0.6159381097022203], 
        Hue[0.36225822303677513`, 1, 0.49841169117984985`], 
        Hue[0.4432997588836446, 1, 0.38620033385341523`], 
        Hue[0.5120477307271325, 1, 0.2910108343778166], 
        Hue[0.5703284797983731, 1, 0.21031441258686806`], 
        Hue[0.5787888800272748, 1, 0.1986000122699272], 
        Hue[0.5267134643102331, 1, 0.27070443403198485`], 
        Hue[0.4652951061508435, 1, 0.3557452376372936], 
        Hue[0.3929012041999783, 1, 0.4559829480307993], 
        Hue[0.3170845078871942, 1, 0.5609599121561927], 
        Hue[0.24960155901173509`, 1, 0.6543978413683669], 
        Hue[0.20318269353921975`, 1, 0.7186701166380034], 
        Hue[0.18660708062683373`, 1, 0.7416209652859226], 
        Hue[0.20318203774868981`, 1, 0.7186710246556602], 
        Hue[0.24960110964755122`, 1, 0.6543984635649291], 
        Hue[0.31708432871750963`, 1, 0.5609601602372944], 
        Hue[0.3929012747880017, 1, 0.45598285029353613`], 
        Hue[0.4652953493354146, 1, 0.3557449009201952], 
        Hue[0.5267137848105791, 1, 0.27070399026227515`], 
        Hue[0.5787894507625198, 1, 0.19859922202112662`], 
        Hue[0.5877624702504634, 1, 0.18617504119166622`], 
        Hue[0.5422653288205485, 1, 0.24917108317154826`], 
        Hue[0.4886161240406276, 1, 0.32345459748220806`], 
        Hue[0.4253872556881455, 1, 0.4110022613548755], 
        Hue[0.3591752496131902, 1, 0.502680423612506], 
        Hue[0.3002457706661208, 1, 0.5842750867699866], 
        Hue[0.2597124156575459, 1, 0.6403981937049364], 
        Hue[0.2452390237157458, 1, 0.6604382748551212], 
        Hue[0.25971232945802986`, 1, 0.6403983130581126], 
        Hue[0.30024571035715797`, 1, 0.5842751702747043], 
        Hue[0.3591752237937029, 1, 0.5026804593625652], 
        Hue[0.4253872624143836, 1, 0.41100225204162266`], 
        Hue[0.48861615402163666`, 1, 0.3234545559700416], 
        Hue[0.5422653702110632, 1, 0.24917102586160478`], 
        Hue[0.5877625488826427, 1, 0.18617493231634097`], 
        Hue[0.5968097184249482, 1, 0.173648082180841], 
        Hue[0.5579423080358296, 1, 0.22746449656577447`], 
        Hue[0.5121213473795251, 1, 0.29090890362834987`], 
        Hue[0.45812604657442185`, 1, 0.3656716278200314], 
        Hue[0.401589595811773, 1, 0.443952867337545], 
        Hue[0.3512759021513562, 1, 0.5136179816365838], 
        Hue[0.31667063497439685`, 1, 0.5615329669585275], 
        Hue[0.3043146268884743, 1, 0.5786412858467279], 
        Hue[0.31667104589567413`, 1, 0.5615323979906051], 
        Hue[0.3512761816551539, 1, 0.5136175946313254], 
        Hue[0.4015897041401657, 1, 0.443952717344386], 
        Hue[0.4581259977404595, 1, 0.36567169543628697`], 
        Hue[0.5121211915218518, 1, 0.2909091194312823], 
        Hue[0.5579421059099916, 1, 0.22746477643231938`], 
        Hue[0.5968093671146062, 1, 0.17364856861054534`], 
        Hue[0.6055472079675877, 1, 0.16155001973718633`], 
        Hue[0.5730797264426927, 1, 0.2065049941562717], 
        Hue[0.5348137958119625, 1, 0.2594885904142058], 
        Hue[0.4897284611772099, 1, 0.3219144383700171], 
        Hue[0.4425273737286087, 1, 0.3872697902219264], 
        Hue[0.40052573946783443`, 1, 0.44542589919838316`], 
        Hue[0.3716392734249071, 1, 0.4854225444885901], 
        Hue[0.3613257637555317, 1, 0.4997027886461869], 
        Hue[0.37164007869641597`, 1, 0.4854214294972703], 
        Hue[0.4005262886368838, 1, 0.44542513881046863`], 
        Hue[0.44252758864335107`, 1, 0.38726949264766775`], 
        Hue[0.4897283687679477, 1, 0.3219145663213033], 
        Hue[0.5348134927357169, 1, 0.2594890100582383], 
        Hue[0.5730793313285311, 1, 0.2065055412374186], 
        Hue[0.6055465152211047, 1, 0.16155097892462433`], 
        Hue[0.6136699866390605, 1, 0.15030309542283937`], 
        Hue[0.5871492042094948, 1, 0.18702417878685337`], 
        Hue[0.555901313513917, 1, 0.23029048898073035`], 
        Hue[0.5190912707195935, 1, 0.28125824054210136`], 
        Hue[0.4805593630784366, 1, 0.33461011266062624`], 
        Hue[0.4462758348559051, 1, 0.38207961327643913`], 
        Hue[0.4226991555060876, 1, 0.4147242462223403], 
        Hue[0.41428194997560897`, 1, 0.4263788384953108], 
        Hue[0.4227002371666561, 1, 0.4147227485384761], 
        Hue[0.4462765732084401, 1, 0.3820785909421599], 
        Hue[0.4805596531568227, 1, 0.3346097110136302], 
        Hue[0.5190911481081258, 1, 0.28125841031182575`], 
        Hue[0.5559009075730197, 1, 0.23029105105274203`], 
        Hue[0.587148673841918, 1, 0.1870249131419596], 
        Hue[0.6136690539638642, 1, 0.15030438681926506`], 
        Hue[0.620963364361293, 1, 0.14020457242282514`], 
        Hue[0.5997791025835187, 1, 0.16953662719205098`], 
        Hue[0.5748271708858737, 1, 0.2040854556964826], 
        Hue[0.545439588329388, 1, 0.2447759546208474], 
        Hue[0.5146822729985913, 1, 0.28736300661733527`], 
        Hue[0.48731955851693154`, 1, 0.3252498420534794], 
        Hue[0.46850379888396554`, 1, 0.3513024323145093], 
        Hue[0.46178677032026, 1, 0.360602933402717], 
        Hue[0.4685050384669278, 1, 0.35130071596886914`], 
        Hue[0.4873204051548792, 1, 0.3252486697855519], 
        Hue[0.5146826064214726, 1, 0.28736254495488417`], 
        Hue[0.545439448873605, 1, 0.24477614771347014`], 
        Hue[0.5748267066162704, 1, 0.20408609853131793`], 
        Hue[0.599778495006357, 1, 0.16953746845273643`], 
        Hue[0.6209622939460813, 1, 0.14020605453619522`], 
        Hue[0.6273035877223594, 1, 0.13142580161519468`], 
        Hue[0.610755573052391, 1, 0.15433843731207403`], 
        Hue[0.5912715356875938, 1, 0.18131633520179324`], 
        Hue[0.5683288547363774, 1, 0.21308312421116973`], 
        Hue[0.544321058615945, 1, 0.24632468807022995`], 
        Hue[0.5229658780640613, 1, 0.27589339960360754`], 
        Hue[0.5082824304107318, 1, 0.29622432712360214`], 
        Hue[0.5030409968157257, 1, 0.3034816967166876], 
        Hue[0.5082837209174339, 1, 0.2962225402681685], 
        Hue[0.5229667598564569, 1, 0.2758921786602904], 
        Hue[0.5443214064451818, 1, 0.24632420646051748`], 
        Hue[0.5683287105046836, 1, 0.21308332391659193`], 
        Hue[0.5912710529523794, 1, 0.1813170036043979], 
        Hue[0.6107549408429755, 1, 0.15433931267895704`], 
        Hue[0.6273024721629233, 1, 0.1314273462359524], 
        Hue[0.6327224787398396, 1, 0.12392272174483755`], 
        Hue[0.6201340030575886, 1, 0.14135291884333887`], 
        Hue[0.6053178951223055, 1, 0.161867529830654], 
        Hue[0.5878758526882779, 1, 0.18601805012392292`], 
        Hue[0.5696275304156976, 1, 0.2112849578859572], 
        Hue[0.5533978740975912, 1, 0.23375678971102762`], 
        Hue[0.5422397026998013, 1, 0.2492065654925829], 
        Hue[0.5382570964254455, 1, 0.25472094341092166`], 
        Hue[0.542241157269009, 1, 0.24920455147367984`], 
        Hue[0.5533988687474061, 1, 0.23375541250359166`], 
        Hue[0.5696279238346578, 1, 0.21128441315201235`], 
        Hue[0.5878756915996006, 1, 0.18601827316978375`], 
        Hue[0.6053173521973283, 1, 0.16186828157293007`], 
        Hue[0.6201332908743415, 1, 0.14135390494321948`], 
        Hue[0.6327212191925413, 1, 0.12392446573340436`], 
        Hue[0.6426169513066162, 1, 0.1102226828062237], 
        Hue[0.6372377100661449, 1, 0.11767086298533777`], 
        Hue[0.6309092329782288, 1, 0.1264333697224525], 
        Hue[0.6234601390512056, 1, 0.1367474997752538], 
        Hue[0.6156675658591593, 1, 0.14753721650270263`], 
        Hue[0.608737603472198, 1, 0.15713254903849522`], 
        Hue[0.603973397789667, 1, 0.16372914152199963`], 
        Hue[0.6022757448098639, 1, 0.16607973795557307`], 
        Hue[0.6039789462997005, 1, 0.16372145896964552`], 
        Hue[0.6087414029233007, 1, 0.15712728826004524`], 
        Hue[0.615669077128538, 1, 0.14753512397587054`], 
        Hue[0.6234595367036779, 1, 0.13674833379490747`], 
        Hue[0.6309071712190801, 1, 0.1264362244658891], 
        Hue[0.6372349970239707, 1, 0.11767461950527143`], 
        Hue[0.6426121298967593, 1, 0.11022935860448715`], 
        Hue[0.6498958580678137, 1, 0.10014419652148876`], 
        Hue[0.6498193884887249, 1, 0.10025007747715022`], 
        Hue[0.6497294634089954, 1, 0.10037458912600633`], 
        Hue[0.6496236056366957, 1, 0.10052116142611357`], 
        Hue[0.6495128594866585, 1, 0.10067450224924218`], 
        Hue[0.649414369301028, 1, 0.10081087327549972`], 
        Hue[0.6493466586105661, 1, 0.10090462653921622`], 
        Hue[0.6493226359923682, 1, 0.10093788862595174`], 
        Hue[0.6493469313116931, 1, 0.10090424895304038`], 
        Hue[0.6494145560301994, 1, 0.10081061472741623`], 
        Hue[0.6495129338042546, 1, 0.10067439934795527`], 
        Hue[0.6496235760977022, 1, 0.10052120232625851`], 
        Hue[0.6497293620994847, 1, 0.10037472940071342`], 
        Hue[0.6498192551554071, 1, 0.10025026209251335`], 
        Hue[0.6498956210456897, 1, 0.10014452470596819`], 
        Hue[0.6432670322601114, 1, 0.1093225707167688], 
        Hue[0.6412530637161606, 1, 0.11211114254685453`], 
        Hue[0.64055187699897, 1, 0.11308201646296469`], 
        Hue[0.6422826805592395, 1, 0.11068551922566836`], 
        Hue[0.6471639496479785, 1, 0.10392683894895278`], 
        Hue[0.6134393712358532, 1, 0.15062240905804938`], 
        Hue[0.617722431996425, 1, 0.14469201723571926`], 
        Hue[0.625798101903588, 1, 0.13351032044118585`], 
        Hue[0.6356016827117188, 1, 0.1199361316299279], 
        Hue[0.6447160778201385, 1, 0.1073161999413467], 
        Hue[0.6180167115996045, 1, 0.14428455316977845`], 
        Hue[0.6308010827908601, 1, 0.12658311613573214`], 
        Hue[0.6400860008926635, 1, 0.1137270756870813], 
        Hue[0.6458023147122057, 1, 0.1058121796292537], 
        Hue[0.6492431084282864, 1, 0.10104800371468042`], 
        Hue[0.6336085712861589, 1, 0.12269582437301088`], 
        Hue[0.6255927744265147, 1, 0.13379462002482578`], 
        Hue[0.6184284943141801, 1, 0.1437143924880583], 
        Hue[0.6134745067166797, 1, 0.15057375993075123`], 
        Hue[0.6124731669546335, 1, 0.1519602303705075], 
        Hue[0.5597906890952162, 1, 0.22490519971431608`], 
        Hue[0.5609429858823104, 1, 0.22330971185526255`], 
        Hue[0.5702672651642874, 1, 0.21039917131098668`], 
        Hue[0.5852727256986744, 1, 0.18962237980183555`], 
        Hue[0.6023460341736332, 1, 0.1659824142211233], 
        Hue[0.5728233150649802, 1, 0.20686002529464279`], 
        Hue[0.5978608444763083, 1, 0.17219267687895778`], 
        Hue[0.6177971273208912, 1, 0.14458859294030454`], 
        Hue[0.6317774561574506, 1, 0.12523121455122221`], 
        Hue[0.6417279253205035, 1, 0.1114536418639183], 
        Hue[0.627788739277394, 1, 0.1307540533082238], 
        Hue[0.6137476741062011, 1, 0.15019552816064463`], 
        Hue[0.5984661270407605, 1, 0.1713545933281777], 
        Hue[0.5823892479014552, 1, 0.1936148875210621], 
        Hue[0.5678708626721414, 1, 0.21371726706934283`], 
        Hue[0.5264808821814904, 1, 0.2710264708256288], 
        Hue[0.51856947216833, 1, 0.28198073084385067`], 
        Hue[0.5206490804550483, 1, 0.27910127321608696`], 
        Hue[0.5319539978428438, 1, 0.2634483106791394], 
        Hue[0.5498837618975733, 1, 0.238622483526437], 
        Hue[0.5460781147159542, 1, 0.24389184116252494`], 
        Hue[0.5738152966617035, 1, 0.20548651231456438`], 
        Hue[0.5981227827376427, 1, 0.1718299931324947], 
        Hue[0.6171412389813049, 1, 0.14549674602588547`], 
        Hue[0.6322361435905947, 1, 0.12459610887456123`], 
        Hue[0.6215312007966796, 1, 0.13941833735844364`], 
        Hue[0.6032807955115133, 1, 0.16468812929175092`], 
        Hue[0.5832495875495568, 1, 0.19242364800830597`], 
        Hue[0.5619036579491845, 1, 0.22197955053189833`], 
        Hue[0.5422634024502561, 1, 0.2491737504534917], 
        Hue[0.49143641314473197`, 1, 0.3195495817996019], 
        Hue[0.48055379551473054`, 1, 0.33461782159498854`], 
        Hue[0.48241389402331597`, 1, 0.332042300583101], 
        Hue[0.49623368777809296`, 1, 0.31290720153802515`], 
        Hue[0.5188498732647925, 1, 0.2815924831718258], 
        Hue[0.5167402753982261, 1, 0.2845134648332255], 
        Hue[0.5518646402844236, 1, 0.235879728836952], 
        Hue[0.5828486430136465, 1, 0.19297880198110498`], 
        Hue[0.607253262945072, 1, 0.1591877897683619], 
        Hue[0.6267346593848439, 1, 0.13221354854406242`], 
        Hue[0.6143233938953457, 1, 0.14939837768336744`], 
        Hue[0.5911781275556787, 1, 0.18144566953829105`], 
        Hue[0.5655942394702503, 1, 0.2168695145796534], 
        Hue[0.538042948910495, 1, 0.25501745535469933`], 
        Hue[0.5123130950578718, 1, 0.29064340684294676`], 
        Hue[0.45101559593564255`, 1, 0.3755168671660334], 
        Hue[0.4365740211159339, 1, 0.3955128938394762], 
        Hue[0.4380343927337269, 1, 0.39349084083022434`], 
        Hue[0.45463005955166735`, 1, 0.3705122252361529], 
        Hue[0.48258054548984075`, 1, 0.3318115523986821], 
        Hue[0.482928869591982, 1, 0.331329257488025], 
        Hue[0.5264877691436816, 1, 0.27101693503182567`], 
        Hue[0.5651338019504073, 1, 0.21750704345328228`], 
        Hue[0.595749619171822, 1, 0.17511591191593873`], 
        Hue[0.6203089596274788, 1, 0.14111067128502947`], 
        Hue[0.6062751719935869, 1, 0.16054206954734124`], 
        Hue[0.577567654884599, 1, 0.2002909393905552], 
        Hue[0.5456133928020999, 1, 0.24453530227401563`], 
        Hue[0.5108479266774192, 1, 0.2926721015235735], 
        Hue[0.4779185437202067, 1, 0.33826663177202154`], 
        Hue[0.40580850751011666`, 1, 0.4381112972936847], 
        Hue[0.38710539258653054`, 1, 0.4640079179571116], 
        Hue[0.38780391391091, 1, 0.4630407345848938], 
        Hue[0.40723391967740985`, 1, 0.4361376496774326], 
        Hue[0.4409936328930443, 1, 0.38939343137886173`], 
        Hue[0.4451684747100397, 1, 0.38361288117071435`], 
        Hue[0.4979716801206474, 1, 0.31050075060218063`], 
        Hue[0.5451013481926241, 1, 0.2452442871179051], 
        Hue[0.5826608286441058, 1, 0.19323885264662272`], 
        Hue[0.612941217282257, 1, 0.15131216068610576`], 
        Hue[0.5975930766290172, 1, 0.1725634323598224], 
        Hue[0.5627707137144806, 1, 0.22077901177994988`], 
        Hue[0.5237424830742484, 1, 0.274818100358733], 
        Hue[0.4808559336876715, 1, 0.3341994764324549], 
        Hue[0.43968454609442587`, 1, 0.3912060131000258], 
        Hue[0.3569622667530063, 1, 0.5057445537266066], 
        Hue[0.3333200485926565, 1, 0.5384799327178603], 
        Hue[0.33282027668953873`, 1, 0.5391719245837157], 
        Hue[0.35499038208254546`, 1, 0.508474855578014], 
        Hue[0.394839678467105, 1, 0.45329890673785467`], 
        Hue[0.4044326263121378, 1, 0.44001636356780927`], 
        Hue[0.46699847829300933`, 1, 0.35338672236352553`], 
        Hue[0.5231924110198737, 1, 0.2755797385878672], 
        Hue[0.5682510443450479, 1, 0.21319086167608758`], 
        Hue[0.6047633384625758, 1, 0.16263537751335672`], 
        Hue[0.5885739589734652, 1, 0.18505144142135593`], 
        Hue[0.5472657246634997, 1, 0.2422474581582313], 
        Hue[0.5006531714587011, 1, 0.3067879164417985], 
        Hue[0.44893409467340356`, 1, 0.3783989458368259], 
        Hue[0.39864398660653866`, 1, 0.4480314031601772], 
        Hue[0.30613714542441306`, 1, 0.5761177986431204], 
        Hue[0.27696374403564483`, 1, 0.6165117390275687], 
        Hue[0.2747769279262213, 1, 0.6195396382560012], 
        Hue[0.29941936073446906`, 1, 0.5854193466753506], 
        Hue[0.34538449739612315`, 1, 0.5217753112976757], 
        Hue[0.3621209519908067, 1, 0.49860175878196], 
        Hue[0.4345791545435442, 1, 0.39827501678586197`], 
        Hue[0.500084212233562, 1, 0.307575706138145], 
        Hue[0.552941860021709, 1, 0.23438819381609535`], 
        Hue[0.5959981070525373, 1, 0.17477185177340993`], 
        Hue[0.579594182301374, 1, 0.19748497835194373`], 
        Hue[0.5316739170993457, 1, 0.26383611478552127`], 
        Hue[0.47723759735959204`, 1, 0.3392094805790264], 
        Hue[0.41626594024551333`, 1, 0.42363177504467386`], 
        Hue[0.3562518639222174, 1, 0.5067281884153912], 
        Hue[0.25544782939052296`, 1, 0.6463030054592759], 
        Hue[0.22030348310954634`, 1, 0.6949644080021666], 
        Hue[0.21592316975918785`, 1, 0.7010294572565091], 
        Hue[0.24259113109163727`, 1, 0.6641045877192715], 
        Hue[0.29439908564497536`, 1, 0.5923704967992649], 
        Hue[0.32000785039776697`, 1, 0.5569122071415534], 
        Hue[0.40202252169466446`, 1, 0.4433534314996954], 
        Hue[0.4766737410268823, 1, 0.3399902047320092], 
        Hue[0.5373050892257643, 1, 0.2560391072258649], 
        Hue[0.5869575084668387, 1, 0.18728960366130032`], 
        Hue[0.5710872328122532, 1, 0.20926383149072644`], 
        Hue[0.5167251850346483, 1, 0.28453435918279474`], 
        Hue[0.45456303581376467`, 1, 0.3706050273347874], 
        Hue[0.3842971118118804, 1, 0.46789630672201177`], 
        Hue[0.31432650590976696`, 1, 0.5647786841249381], 
        Hue[0.20733875071075575`, 1, 0.7129155759389536], 
        Hue[0.1660024444276858, 1, 0.7701504615616658], 
        Hue[0.1589493449301977, 1, 0.7799162916351109], 
        Hue[0.18703012692867338`, 1, 0.7410352088679907], 
        Hue[0.24408594985937843`, 1, 0.6620348386562452], 
        Hue[0.28013617649380124`, 1, 0.6121191402393521], 
        Hue[0.3708622433144219, 1, 0.48649843233387746`], 
        Hue[0.4540316873519137, 1, 0.37134074058965794`], 
        Hue[0.522035897273629, 1, 0.2771810653134368], 
        Hue[0.5780298854580632, 1, 0.19965092782729704`], 
        Hue[0.563511019306925, 1, 0.21975397326733456`], 
        Hue[0.5032053724394926, 1, 0.30325409969916417`], 
        Hue[0.4337980162250367, 1, 0.39935659291918], 
        Hue[0.35463996524360725`, 1, 0.5089600481242362], 
        Hue[0.2749360615481364, 1, 0.6193192993948881], 
        Hue[0.16440022497095574`, 1, 0.7723689192709844], 
        Hue[0.11692659598318078`, 1, 0.8381016363309804], 
        Hue[0.10679991366380204`, 1, 0.8521231964655049], 
        Hue[0.13554779899441238`, 1, 0.8123184321615828], 
        Hue[0.1969400572019434, 1, 0.7273137669511553], 
        Hue[0.244662710329695, 1, 0.661236247235807], 
        Hue[0.3427452344342436, 1, 0.5254296753987396], 
        Hue[0.4333278292564815, 1, 0.4000076210294873], 
        Hue[0.5079065757593585, 1, 0.29674474125627287`], 
        Hue[0.5696556090993762, 1, 0.21124607970855602`], 
        Hue[0.5573078855136699, 1, 0.22834292775030318`], 
        Hue[0.49188966916713917`, 1, 0.3189219965378073], 
        Hue[0.41611570155088495`, 1, 0.4238397978526208], 
        Hue[0.3289443018365475, 1, 0.5445386589955497], 
        Hue[0.2402382951548664, 1, 0.6673623605548004], 
        Hue[0.129142297944433, 1, 0.8211875874615543], 
        Hue[0.07590092200313592, 1, 0.8949064156879656], 
        Hue[0.062429435740938066`, 1, 0.9135592428202396], 
        Hue[0.09101591614372295, 1, 0.8739779622625374], 
        Hue[0.15555362786398375`, 1, 0.7846180537267917], 
        Hue[0.2156684604819588, 1, 0.7013821316403648], 
        Hue[0.3192910676832634, 1, 0.5579046755154815], 
        Hue[0.41573414221698096`, 1, 0.42436811077648795`], 
        Hue[0.49570429192730225`, 1, 0.31364021117758156`], 
        Hue[0.5622928254940656, 1, 0.22144070316206316`], 
        Hue[0.5528621143129753, 1, 0.23449861095126512`], 
        Hue[0.48346958900868453`, 1, 0.33058056906489836`], 
        Hue[0.402585392648726, 1, 0.4425740717171487], 
        Hue[0.3087474576267833, 1, 0.5725035202090692], 
        Hue[0.21228788392593295`, 1, 0.7060629299487082], 
        Hue[0.10375357462868628`, 1, 0.8563412043602805], 
        Hue[0.04544226115578831, 1, 0.9370799460919854], 
        Hue[0.028528340951307407`, 1, 0.9604992202212667], 
        Hue[0.05610511392484341, 1, 0.922315996104063], 
        Hue[0.12238397672032486`, 1, 0.8305452630026271], 
        Hue[0.19495787943114457`, 1, 0.730058320787646], 
        Hue[0.30193883613655437`, 1, 0.5819308422724633], 
        Hue[0.4023160544951288, 1, 0.44294700146828325`], 
        Hue[0.48615945773804453`, 1, 0.32685613543963066`], 
        Hue[0.5563766442135991, 1, 0.22963233878117056`], 
        Hue[0.5504603601125956, 1, 0.23782411676717538`], 
        Hue[0.4784830257287196, 1, 0.33748504129869594`], 
        Hue[0.3940656300924371, 1, 0.4543706660258563], 
        Hue[0.2953226222573054, 1, 0.5910917537975772], 
        Hue[0.19283611511503895`, 1, 0.7329961483022538], 
        Hue[0.08987650496460464, 1, 0.8755556085105475], 
        Hue[0.02750426862112454, 1, 0.9619171665245967], 
        Hue[0.0072533689255459555`, 1, 0.989956873795398], 
        Hue[0.03302049699040399, 1, 0.9542793118594407], 
        Hue[0.09951326985387388, 1, 0.8622123955869438], 
        Hue[0.18387320634860493`, 1, 0.7454063296711624], 
        Hue[0.2918011380948874, 1, 0.5959676549455406], 
        Hue[0.3939259619828554, 1, 0.45456405263912325`], 
        Hue[0.47987363275358597`, 1, 0.3355595854181117], 
        Hue[0.552276944877135, 1, 0.2353088455547362], 
        Hue[0.5502605344346037, 1, 0.23810079847516416`], 
        Hue[0.4772569851352818, 1, 0.33918263596653286`], 
        Hue[0.3911137242536845, 1, 0.4584579202641291], 
        Hue[0.28954586233322194`, 1, 0.5990903444616927], 
        Hue[0.18314962691401915`, 1, 0.7464082088882812], 
        Hue[0.08843171541781147, 1, 0.8775560863445687], 
        Hue[0.023270413385846567`, 1, 0.9677794276195971], 
        Hue[5.551115123125783*^-16, 1, 0.9999999999999992], 
        Hue[0.023270413385846456`, 1, 0.9677794276195972], 
        Hue[0.0884317154178117, 1, 0.8775560863445684], 
        Hue[0.18314962691401832`, 1, 0.7464082088882823], 
        Hue[0.28954586233322177`, 1, 0.599090344461693], 
        Hue[0.39111372425368446`, 1, 0.45845792026412924`], 
        Hue[0.4772569851352815, 1, 0.3391826359665334], 
        Hue[0.5502605344346039, 1, 0.23810079847516394`], 
        Hue[0.5522769448771349, 1, 0.23530884555473644`], 
        Hue[0.47987363275358613`, 1, 0.33555958541811154`], 
        Hue[0.39392596198285534`, 1, 0.45456405263912336`], 
        Hue[0.29180113809488756`, 1, 0.5959676549455403], 
        Hue[0.18387320634860504`, 1, 0.7454063296711623], 
        Hue[0.09951326985387332, 1, 0.8622123955869446], 
        Hue[0.03302049699040399, 1, 0.9542793118594406], 
        Hue[0.007253368925545067, 1, 0.9899568737953991], 
        Hue[0.027504268621123984`, 1, 0.9619171665245976], 
        Hue[0.08987650496460409, 1, 0.8755556085105483], 
        Hue[0.1928361151150383, 1, 0.7329961483022547], 
        Hue[0.2953226222573051, 1, 0.5910917537975776], 
        Hue[0.39406563009243667`, 1, 0.45437066602585696`], 
        Hue[0.47848302572871904`, 1, 0.3374850412986967], 
        Hue[0.5504603601125957, 1, 0.23782411676717527`], 
        Hue[0.556376644213599, 1, 0.22963233878117065`], 
        Hue[0.4861594577380448, 1, 0.3268561354396303], 
        Hue[0.4023160544951288, 1, 0.44294700146828325`], 
        Hue[0.30193883613655415`, 1, 0.5819308422724635], 
        Hue[0.19495787943114423`, 1, 0.7300583207876464], 
        Hue[0.1223839767203252, 1, 0.8305452630026267], 
        Hue[0.05610511392484352, 1, 0.9223159961040629], 
        Hue[0.028528340951307074`, 1, 0.9604992202212671], 
        Hue[0.045442261155787755`, 1, 0.9370799460919861], 
        Hue[0.10375357462868562`, 1, 0.8563412043602814], 
        Hue[0.21228788392593306`, 1, 0.706062929948708], 
        Hue[0.3087474576267832, 1, 0.5725035202090695], 
        Hue[0.40258539264872584`, 1, 0.4425740717171489], 
        Hue[0.4834695890086842, 1, 0.33058056906489885`], 
        Hue[0.5528621143129753, 1, 0.2344986109512651], 
        Hue[0.5622928254940655, 1, 0.2214407031620632], 
        Hue[0.4957042919273025, 1, 0.3136402111775813], 
        Hue[0.41573414221698096`, 1, 0.42436811077648795`], 
        Hue[0.31929106768326354`, 1, 0.5579046755154813], 
        Hue[0.21566846048195915`, 1, 0.7013821316403642], 
        Hue[0.1555536278639834, 1, 0.7846180537267922], 
        Hue[0.09101591614372329, 1, 0.873977962262537], 
        Hue[0.062429435740937955`, 1, 0.9135592428202398], 
        Hue[0.07590092200313547, 1, 0.8949064156879663], 
        Hue[0.12914229794443266`, 1, 0.8211875874615547], 
        Hue[0.24023829515486617`, 1, 0.6673623605548007], 
        Hue[0.32894430183654727`, 1, 0.54453865899555], 
        Hue[0.41611570155088495`, 1, 0.4238397978526208], 
        Hue[0.4918896691671389, 1, 0.31892199653780773`], 
        Hue[0.55730788551367, 1, 0.228342927750303], 
        Hue[0.569655609099376, 1, 0.21124607970855636`], 
        Hue[0.5079065757593586, 1, 0.2967447412562727], 
        Hue[0.4333278292564813, 1, 0.4000076210294875], 
        Hue[0.3427452344342435, 1, 0.5254296753987399], 
        Hue[0.24466271032969478`, 1, 0.6612362472358072], 
        Hue[0.19694005720194308`, 1, 0.7273137669511557], 
        Hue[0.13554779899441216`, 1, 0.8123184321615831], 
        Hue[0.1067999136638016, 1, 0.8521231964655054], 
        Hue[0.11692659598318034`, 1, 0.8381016363309811], 
        Hue[0.1644002249709553, 1, 0.7723689192709849], 
        Hue[0.274936061548136, 1, 0.6193192993948886], 
        Hue[0.354639965243607, 1, 0.5089600481242365], 
        Hue[0.43379801622503644`, 1, 0.39935659291918035`], 
        Hue[0.5032053724394923, 1, 0.30325409969916467`], 
        Hue[0.563511019306925, 1, 0.2197539732673346], 
        Hue[0.5780298854580632, 1, 0.19965092782729715`], 
        Hue[0.5220358972736292, 1, 0.27718106531343656`], 
        Hue[0.4540316873519136, 1, 0.37134074058965805`], 
        Hue[0.3708622433144216, 1, 0.4864984323338778], 
        Hue[0.2801361764938012, 1, 0.6121191402393522], 
        Hue[0.2440859498593782, 1, 0.6620348386562456], 
        Hue[0.1870301269286732, 1, 0.7410352088679909], 
        Hue[0.1589493449301974, 1, 0.7799162916351113], 
        Hue[0.16600244442768497`, 1, 0.770150461561667], 
        Hue[0.2073387507107548, 1, 0.7129155759389548], 
        Hue[0.31432650590976674`, 1, 0.5647786841249384], 
        Hue[0.3842971118118802, 1, 0.467896306722012], 
        Hue[0.45456303581376445`, 1, 0.37060502733478773`], 
        Hue[0.5167251850346479, 1, 0.2845343591827952], 
        Hue[0.5710872328122532, 1, 0.20926383149072653`], 
        Hue[0.5869575084668386, 1, 0.18728960366130046`], 
        Hue[0.5373050892257645, 1, 0.25603910722586465`], 
        Hue[0.4766737410268823, 1, 0.33999020473200914`], 
        Hue[0.4020225216946644, 1, 0.4433534314996954], 
        Hue[0.320007850397767, 1, 0.5569122071415533], 
        Hue[0.2943990856449754, 1, 0.5923704967992648], 
        Hue[0.24259113109163727`, 1, 0.6641045877192715], 
        Hue[0.21592316975918763`, 1, 0.7010294572565094], 
        Hue[0.22030348310954578`, 1, 0.6949644080021674], 
        Hue[0.2554478293905231, 1, 0.6463030054592758], 
        Hue[0.35625186392221725`, 1, 0.5067281884153916], 
        Hue[0.41626594024551333`, 1, 0.423631775044674], 
        Hue[0.47723759735959204`, 1, 0.33920948057902645`], 
        Hue[0.5316739170993455, 1, 0.26383611478552166`], 
        Hue[0.579594182301374, 1, 0.19748497835194362`], 
        Hue[0.5959981070525372, 1, 0.17477185177341], 
        Hue[0.5529418600217092, 1, 0.23438819381609502`], 
        Hue[0.500084212233562, 1, 0.30757570613814494`], 
        Hue[0.4345791545435442, 1, 0.39827501678586197`], 
        Hue[0.3621209519908067, 1, 0.49860175878196], 
        Hue[0.3453844973961235, 1, 0.5217753112976753], 
        Hue[0.2994193607344692, 1, 0.5854193466753503], 
        Hue[0.27477692792622116`, 1, 0.6195396382560014], 
        Hue[0.27696374403564417`, 1, 0.6165117390275696], 
        Hue[0.3061371454244128, 1, 0.5761177986431207], 
        Hue[0.39864398660653844`, 1, 0.44803140316017753`], 
        Hue[0.4489340946734035, 1, 0.3783989458368259], 
        Hue[0.500653171458701, 1, 0.3067879164417987], 
        Hue[0.5472657246634994, 1, 0.24224745815823162`], 
        Hue[0.5885739589734652, 1, 0.18505144142135593`], 
        Hue[0.6047633384625756, 1, 0.1626353775133569], 
        Hue[0.5682510443450479, 1, 0.21319086167608753`], 
        Hue[0.5231924110198736, 1, 0.2755797385878674], 
        Hue[0.4669984782930092, 1, 0.35338672236352564`], 
        Hue[0.40443262631213817`, 1, 0.4400163635678087], 
        Hue[0.39483967846710455`, 1, 0.45329890673785533`], 
        Hue[0.35499038208254485`, 1, 0.5084748555780149], 
        Hue[0.3328202766895381, 1, 0.5391719245837164], 
        Hue[0.33332004859265607`, 1, 0.5384799327178609], 
        Hue[0.356962266753006, 1, 0.5057445537266071], 
        Hue[0.4396845460944252, 1, 0.3912060131000267], 
        Hue[0.4808559336876712, 1, 0.3341994764324553], 
        Hue[0.5237424830742482, 1, 0.27481810035873333`], 
        Hue[0.5627707137144804, 1, 0.22077901177995024`], 
        Hue[0.5975930766290172, 1, 0.17256343235982236`], 
        Hue[0.6129412172822569, 1, 0.1513121606861058], 
        Hue[0.582660828644106, 1, 0.1932388526466225], 
        Hue[0.5451013481926241, 1, 0.24524428711790514`], 
        Hue[0.4979716801206472, 1, 0.31050075060218085`], 
        Hue[0.4451684747100392, 1, 0.383612881170715], 
        Hue[0.44099363289304444`, 1, 0.3893934313788616], 
        Hue[0.40723391967741, 1, 0.4361376496774323], 
        Hue[0.3878039139109099, 1, 0.46304073458489403`], 
        Hue[0.3871053925865298, 1, 0.4640079179571126], 
        Hue[0.4058085075101159, 1, 0.4381112972936857], 
        Hue[0.47791854372020676`, 1, 0.33826663177202143`], 
        Hue[0.5108479266774192, 1, 0.2926721015235735], 
        Hue[0.5456133928020998, 1, 0.2445353022740158], 
        Hue[0.5775676548845988, 1, 0.20029093939055556`], 
        Hue[0.6062751719935868, 1, 0.1605420695473413], 
        Hue[0.6203089596274787, 1, 0.1411106712850296], 
        Hue[0.5957496191718221, 1, 0.17511591191593862`], 
        Hue[0.5651338019504072, 1, 0.21750704345328234`], 
        Hue[0.5264877691436817, 1, 0.27101693503182545`], 
        Hue[0.4829288695919822, 1, 0.3313292574880246], 
        Hue[0.48258054548984053`, 1, 0.3318115523986824], 
        Hue[0.45463005955166735`, 1, 0.3705122252361529], 
        Hue[0.4380343927337269, 1, 0.39349084083022434`], 
        Hue[0.4365740211159338, 1, 0.3955128938394764], 
        Hue[0.45101559593564255`, 1, 0.3755168671660334], 
        Hue[0.5123130950578715, 1, 0.2906434068429472], 
        Hue[0.5380429489104949, 1, 0.25501745535469944`], 
        Hue[0.5655942394702502, 1, 0.21686951457965348`], 
        Hue[0.5911781275556787, 1, 0.18144566953829117`], 
        Hue[0.6143233938953458, 1, 0.14939837768336733`], 
        Hue[0.6267346593848437, 1, 0.13221354854406253`], 
        Hue[0.607253262945072, 1, 0.1591877897683619], 
        Hue[0.5828486430136464, 1, 0.19297880198110512`], 
        Hue[0.5518646402844234, 1, 0.23587972883695227`], 
        Hue[0.5167402753982258, 1, 0.2845134648332258], 
        Hue[0.5188498732647923, 1, 0.2815924831718261], 
        Hue[0.4962336877780928, 1, 0.3129072015380254], 
        Hue[0.4824138940233156, 1, 0.3320423005831016], 
        Hue[0.4805537955147301, 1, 0.33461782159498915`], 
        Hue[0.4914364131447315, 1, 0.3195495817996026], 
        Hue[0.5422634024502558, 1, 0.24917375045349197`], 
        Hue[0.5619036579491844, 1, 0.2219795505318985], 
        Hue[0.5832495875495567, 1, 0.19242364800830622`], 
        Hue[0.603280795511513, 1, 0.1646881292917512], 
        Hue[0.6215312007966796, 1, 0.1394183373584437], 
        Hue[0.6322361435905947, 1, 0.12459610887456124`], 
        Hue[0.617141238981305, 1, 0.1454967460258854], 
        Hue[0.5981227827376426, 1, 0.1718299931324948], 
        Hue[0.5738152966617034, 1, 0.2054865123145645], 
        Hue[0.5460781147159541, 1, 0.24389184116252516`], 
        Hue[0.5498837618975733, 1, 0.238622483526437], 
        Hue[0.5319539978428438, 1, 0.2634483106791393], 
        Hue[0.5206490804550483, 1, 0.279101273216087], 
        Hue[0.5185694721683298, 1, 0.281980730843851], 
        Hue[0.52648088218149, 1, 0.2710264708256292], 
        Hue[0.5678708626721414, 1, 0.2137172670693428], 
        Hue[0.5823892479014552, 1, 0.19361488752106204`], 
        Hue[0.5984661270407605, 1, 0.17135459332817785`], 
        Hue[0.613747674106201, 1, 0.15019552816064477`], 
        Hue[0.627788739277394, 1, 0.1307540533082238], 
        Hue[0.6417279253205034, 1, 0.11145364186391843`], 
        Hue[0.6317774561574506, 1, 0.12523121455122227`], 
        Hue[0.6177971273208911, 1, 0.14458859294030463`], 
        Hue[0.5978608444763083, 1, 0.17219267687895778`], 
        Hue[0.5728233150649804, 1, 0.20686002529464262`], 
        Hue[0.6023460341736327, 1, 0.16598241422112395`], 
        Hue[0.585272725698674, 1, 0.18962237980183605`], 
        Hue[0.5702672651642873, 1, 0.21039917131098695`], 
        Hue[0.5609429858823103, 1, 0.22330971185526277`], 
        Hue[0.5597906890952162, 1, 0.2249051997143161], 
        Hue[0.612473166954633, 1, 0.15196023037050804`], 
        Hue[0.6134745067166796, 1, 0.15057375993075145`], 
        Hue[0.61842849431418, 1, 0.14371439248805848`], 
        Hue[0.6255927744265147, 1, 0.13379462002482584`], 
        Hue[0.6336085712861589, 1, 0.12269582437301085`], 
        Hue[0.6492431084282864, 1, 0.1010480037146804], 
        Hue[0.6458023147122057, 1, 0.10581217962925371`], 
        Hue[0.6400860008926634, 1, 0.11372707568708143`], 
        Hue[0.6308010827908599, 1, 0.12658311613573245`], 
        Hue[0.618016711599604, 1, 0.14428455316977903`], 
        Hue[0.6447160778201386, 1, 0.10731619994134659`], 
        Hue[0.6356016827117187, 1, 0.11993613162992803`], 
        Hue[0.6257981019035878, 1, 0.13351032044118621`], 
        Hue[0.6177224319964245, 1, 0.1446920172357199], 
        Hue[0.6134393712358527, 1, 0.15062240905805013`], 
        Hue[0.6471639496479787, 1, 0.1039268389489526], 
        Hue[0.6422826805592395, 1, 0.11068551922566831`], 
        Hue[0.6405518769989699, 1, 0.11308201646296481`], 
        Hue[0.6412530637161605, 1, 0.11211114254685471`], 
        Hue[0.6432670322601114, 1, 0.10932257071676893`], 
        Hue[0.6426121298967594, 1, 0.11022935860448697`], 
        Hue[0.6498956210456897, 1, 0.10014452470596819`], 
        Hue[0.6327212191925413, 1, 0.12392446573340435`], 
        Hue[0.6273024721629233, 1, 0.13142734623595234`], 
        Hue[0.6209622939460814, 1, 0.1402060545361951], 
        Hue[0.6136690539638642, 1, 0.15030438681926508`], 
        Hue[0.6055465152211048, 1, 0.16155097892462422`], 
        Hue[0.5968093671146062, 1, 0.17364856861054534`], 
        Hue[0.5877625488826427, 1, 0.1861749323163409], 
        Hue[0.5787894507625196, 1, 0.19859922202112662`], 
        Hue[0.5703284797983732, 1, 0.21031441258686792`], 
        Hue[0.5628394673492456, 1, 0.22068381443950608`], 
        Hue[0.556763025119071, 1, 0.22909734983513239`], 
        Hue[0.5524778870728062, 1, 0.23503061789919147`], 
        Hue[0.5502615101311635, 1, 0.23809944751069675`], 
        Hue[0.5502596758638848, 1, 0.23810198726539028`], 
        Hue[0.5524755676281783, 1, 0.23503382943790702`], 
        Hue[0.5567610169112917, 1, 0.22910013043051924`], 
        Hue[0.5628378848957449, 1, 0.2206860055289686], 
        Hue[0.5703273925724266, 1, 0.21031591797664007`], 
        Hue[0.5787888800272748, 1, 0.1986000122699272], 
        Hue[0.5877624702504634, 1, 0.18617504119166617`], 
        Hue[0.5968097184249482, 1, 0.173648082180841], 
        Hue[0.6055472079675877, 1, 0.16155001973718633`], 
        Hue[0.6136699866390605, 1, 0.15030309542283937`], 
        Hue[0.620963364361293, 1, 0.14020457242282514`], 
        Hue[0.6273035877223594, 1, 0.13142580161519468`], 
        Hue[0.6327224787398396, 1, 0.12392272174483755`], 
        Hue[0.6426169513066162, 1, 0.11022268280622372`], 
        Hue[0.6498958580678137, 1, 0.10014419652148876`], 
        Hue[0.6372349970239709, 1, 0.11767461950527106`], 
        Hue[0.6498192551554071, 1, 0.10025026209251335`], 
        Hue[0.6201332908743415, 1, 0.14135390494321937`], 
        Hue[0.6107549408429757, 1, 0.15433931267895676`], 
        Hue[0.5997784950063574, 1, 0.16953746845273604`], 
        Hue[0.5871486738419182, 1, 0.18702491314195946`], 
        Hue[0.5730793313285315, 1, 0.206505541237418], 
        Hue[0.5579421059099918, 1, 0.22746477643231902`], 
        Hue[0.5422653702110636, 1, 0.24917102586160433`], 
        Hue[0.5267137848105794, 1, 0.27070399026227465`], 
        Hue[0.5120477307271329, 1, 0.29101083437781583`], 
        Hue[0.49906493923094836`, 1, 0.3089870072186869], 
        Hue[0.48853000985261963`, 1, 0.3235738325117575], 
        Hue[0.4811002419009813, 1, 0.3338612035217183], 
        Hue[0.47725762494663393`, 1, 0.3391817500738915], 
        Hue[0.47725658556548656`, 1, 0.3391831892170186], 
        Hue[0.4810989279143894, 1, 0.3338630228877686], 
        Hue[0.4885288728491538, 1, 0.3235754068242486], 
        Hue[0.4990640442498221, 1, 0.3089882464233233], 
        Hue[0.5120471170280902, 1, 0.29101168411495204`], 
        Hue[0.5267134643102331, 1, 0.27070443403198485`], 
        Hue[0.5422653288205485, 1, 0.2491710831715483], 
        Hue[0.5579423080358296, 1, 0.2274644965657745], 
        Hue[0.5730797264426927, 1, 0.20650499415627166`], 
        Hue[0.5871492042094948, 1, 0.1870241787868534], 
        Hue[0.5997791025835187, 1, 0.16953662719205095`], 
        Hue[0.610755573052391, 1, 0.15433843731207403`], 
        Hue[0.6201340030575886, 1, 0.14135291884333887`], 
        Hue[0.6372377100661449, 1, 0.11767086298533777`], 
        Hue[0.6498193884887249, 1, 0.10025007747715022`], 
        Hue[0.6309071712190805, 1, 0.12643622446588856`], 
        Hue[0.6497293620994847, 1, 0.10037472940071342`], 
        Hue[0.6053173521973284, 1, 0.16186828157292998`], 
        Hue[0.5912710529523796, 1, 0.18131700360439762`], 
        Hue[0.5748267066162707, 1, 0.20408609853131757`], 
        Hue[0.5559009075730197, 1, 0.230291051052742], 
        Hue[0.5348134927357172, 1, 0.25948901005823777`], 
        Hue[0.5121211915218519, 1, 0.290909119431282], 
        Hue[0.4886161540216369, 1, 0.32345455597004125`], 
        Hue[0.46529534933541483`, 1, 0.35574490092019484`], 
        Hue[0.4432997588836452, 1, 0.38620033385341435`], 
        Hue[0.4238266901119189, 1, 0.41316304446041996`], 
        Hue[0.4080239533114093, 1, 0.43504375695343334`], 
        Hue[0.39687844716525267`, 1, 0.45047599623272705`], 
        Hue[0.39111401526715023`, 1, 0.45845751732240736`], 
        Hue[0.3911132217415005, 1, 0.4584586160502301], 
        Hue[0.39687744410879333`, 1, 0.45047738508013235`], 
        Hue[0.4080230856664831, 1, 0.43504495830794654`], 
        Hue[0.42382600763506495`, 1, 0.41316398942837174`], 
        Hue[0.4432992915435409, 1, 0.38620098093971267`], 
        Hue[0.46529510615084346`, 1, 0.3557452376372937], 
        Hue[0.4886161240406275, 1, 0.32345459748220806`], 
        Hue[0.5121213473795251, 1, 0.29090890362834987`], 
        Hue[0.5348137958119625, 1, 0.2594885904142058], 
        Hue[0.555901313513917, 1, 0.23029048898073032`], 
        Hue[0.5748271708858737, 1, 0.2040854556964826], 
        Hue[0.5912715356875938, 1, 0.18131633520179324`], 
        Hue[0.6053178951223055, 1, 0.16186752983065394`], 
        Hue[0.6309092329782288, 1, 0.1264333697224525], 
        Hue[0.6497294634089954, 1, 0.10037458912600633`], 
        Hue[0.6234595367036785, 1, 0.13674833379490678`], 
        Hue[0.6496235760977022, 1, 0.10052120232625851`], 
        Hue[0.5878756915996007, 1, 0.18601827316978367`], 
        Hue[0.5683287105046838, 1, 0.21308332391659163`], 
        Hue[0.5454394488736053, 1, 0.24477614771346962`], 
        Hue[0.5190911481081257, 1, 0.28125841031182586`], 
        Hue[0.48972836876794834`, 1, 0.32191456632130233`], 
        Hue[0.4581259977404597, 1, 0.36567169543628664`], 
        Hue[0.42538726241438385`, 1, 0.41100225204162244`], 
        Hue[0.39290127478800213`, 1, 0.4559828502935356], 
        Hue[0.36225822303677563`, 1, 0.4984116911798492], 
        Hue[0.33512718394406676`, 1, 0.5359777453082153], 
        Hue[0.31310844801677107`, 1, 0.5664652258229325], 
        Hue[0.2975781480451238, 1, 0.5879687180913671], 
        Hue[0.289545844634985, 1, 0.5990903689669439], 
        Hue[0.2895456075556001, 1, 0.5990906972307075], 
        Hue[0.2975778486260126, 1, 0.5879691326716749], 
        Hue[0.31310818948736147`, 1, 0.5664655837867303], 
        Hue[0.3351269812922879, 1, 0.5359780259029859], 
        Hue[0.3622580851943614, 1, 0.49841188203857645`], 
        Hue[0.39290120419997815`, 1, 0.45598294803079953`], 
        Hue[0.4253872556881455, 1, 0.4110022613548755], 
        Hue[0.45812604657442185`, 1, 0.3656716278200314], 
        Hue[0.48972846117720986`, 1, 0.3219144383700171], 
        Hue[0.5190912707195935, 1, 0.28125824054210136`], 
        Hue[0.545439588329388, 1, 0.24477595462084745`], 
        Hue[0.5683288547363774, 1, 0.21308312421116973`], 
        Hue[0.5878758526882779, 1, 0.18601805012392292`], 
        Hue[0.6234601390512056, 1, 0.1367474997752538], 
        Hue[0.6496236056366957, 1, 0.10052116142611357`], 
        Hue[0.6156690771285387, 1, 0.1475351239758696], 
        Hue[0.6495129338042546, 1, 0.10067439934795527`], 
        Hue[0.5696279238346579, 1, 0.21128441315201224`], 
        Hue[0.5443214064451821, 1, 0.24632420646051703`], 
        Hue[0.5146826064214731, 1, 0.28736254495488345`], 
        Hue[0.4805596531568227, 1, 0.33460971101363013`], 
        Hue[0.44252758864335184`, 1, 0.38726949264766675`], 
        Hue[0.4015897041401661, 1, 0.44395271734438546`], 
        Hue[0.3591752237937033, 1, 0.5026804593625647], 
        Hue[0.31708432871750997`, 1, 0.5609601602372939], 
        Hue[0.27737803188173027`, 1, 0.6159381097022196], 
        Hue[0.2422202632889342, 1, 0.6646180969845527], 
        Hue[0.21368588077620998`, 1, 0.7041272420021708], 
        Hue[0.19355917011629586`, 1, 0.7319949952235904], 
        Hue[0.183149562217308, 1, 0.7464082984683428], 
        Hue[0.18315013423702348`, 1, 0.7464075064410445], 
        Hue[0.19355989355891, 1, 0.7319939935338169], 
        Hue[0.21368650737851774`, 1, 0.7041263743989754], 
        Hue[0.24222075745013216`, 1, 0.6646174127613554], 
        Hue[0.27737837191762255`, 1, 0.6159376388832919], 
        Hue[0.3170845078871942, 1, 0.5609599121561927], 
        Hue[0.3591752496131902, 1, 0.5026804236125059], 
        Hue[0.401589595811773, 1, 0.44395286733754513`], 
        Hue[0.44252737372860873`, 1, 0.3872697902219264], 
        Hue[0.4805593630784366, 1, 0.3346101126606263], 
        Hue[0.5146822729985912, 1, 0.28736300661733527`], 
        Hue[0.544321058615945, 1, 0.24632468807023003`], 
        Hue[0.5696275304156976, 1, 0.2112849578859572], 
        Hue[0.6156675658591593, 1, 0.1475372165027026], 
        Hue[0.6495128594866585, 1, 0.10067450224924218`], 
        Hue[0.6087414029233015, 1, 0.1571272882600441], 
        Hue[0.6494145560301994, 1, 0.10081061472741623`], 
        Hue[0.5533988687474062, 1, 0.23375541250359141`], 
        Hue[0.5229667598564574, 1, 0.2758921786602898], 
        Hue[0.48732040515487984`, 1, 0.325248669785551], 
        Hue[0.44627657320844005`, 1, 0.3820785909421599], 
        Hue[0.4005262886368849, 1, 0.4454251388104672], 
        Hue[0.35127618165515445`, 1, 0.5136175946313246], 
        Hue[0.30024571035715847`, 1, 0.5842751702747037], 
        Hue[0.24960110964755156`, 1, 0.6543984635649286], 
        Hue[0.20182310509526985`, 1, 0.7205526237142418], 
        Hue[0.15951628430376785`, 1, 0.7791312986563215], 
        Hue[0.12517836167629715`, 1, 0.8266761146020501], 
        Hue[0.10095758092813223`, 1, 0.8602125802533555], 
        Hue[0.08843039496209137, 1, 0.8775579146678736], 
        Hue[0.08843184481123345, 1, 0.877555907184446], 
        Hue[0.10095941407703568`, 1, 0.8602100420471814], 
        Hue[0.12517994846479386`, 1, 0.8266739175102854], 
        Hue[0.15951753407086688`, 1, 0.7791295682095689], 
        Hue[0.2018239629610682, 1, 0.7205514359000594], 
        Hue[0.24960155901173514`, 1, 0.6543978413683668], 
        Hue[0.30024577066612074`, 1, 0.5842750867699867], 
        Hue[0.35127590215135607`, 1, 0.5136179816365839], 
        Hue[0.40052573946783443`, 1, 0.44542589919838316`], 
        Hue[0.4462758348559053, 1, 0.3820796132764389], 
        Hue[0.48731955851693165`, 1, 0.32524984205347934`], 
        Hue[0.5229658780640613, 1, 0.2758933996036075], 
        Hue[0.5533978740975912, 1, 0.2337567897110276], 
        Hue[0.608737603472198, 1, 0.15713254903849522`], 
        Hue[0.649414369301028, 1, 0.10081087327549972`], 
        Hue[0.6039789462997014, 1, 0.16372145896964424`], 
        Hue[0.6493469313116931, 1, 0.10090424895304037`], 
        Hue[0.5422411572690091, 1, 0.24920455147367965`], 
        Hue[0.5082837209174343, 1, 0.29622254026816786`], 
        Hue[0.4685050384669286, 1, 0.35130071596886814`], 
        Hue[0.42270023716665617`, 1, 0.4147227485384761], 
        Hue[0.37164007869641713`, 1, 0.48542142949726863`], 
        Hue[0.3166710458956746, 1, 0.5615323979906045], 
        Hue[0.25971232945803074`, 1, 0.6403983130581113], 
        Hue[0.20318203774869037`, 1, 0.7186710246556595], 
        Hue[0.14984970892994742`, 1, 0.7925157876354575], 
        Hue[0.10262327005221772`, 1, 0.8579062414661601], 
        Hue[0.06429160086506358, 1, 0.9109808603406813], 
        Hue[0.03725335079350833, 1, 0.9484184373628346], 
        Hue[0.02326889069083926, 1, 0.9677815359665303], 
        Hue[0.0232710123793185, 1, 0.9677785982440206], 
        Hue[0.0372560332466112, 1, 0.9484147231969998], 
        Hue[0.06429392241993914, 1, 0.9109776458800842], 
        Hue[0.10262509794762609`, 1, 0.8579037105340562], 
        Hue[0.14985096295229905`, 1, 0.7925140512968167], 
        Hue[0.2031826935392198, 1, 0.7186701166380033], 
        Hue[0.25971241565754605`, 1, 0.6403981937049362], 
        Hue[0.316670634974397, 1, 0.5615329669585273], 
        Hue[0.3716392734249071, 1, 0.4854225444885901], 
        Hue[0.42269915550608755`, 1, 0.4147242462223404], 
        Hue[0.4685037988839656, 1, 0.3513024323145092], 
        Hue[0.5082824304107318, 1, 0.2962243271236021], 
        Hue[0.5422397026998013, 1, 0.2492065654925829], 
        Hue[0.603973397789667, 1, 0.1637291415219996], 
        Hue[0.6493466586105661, 1, 0.10090462653921622`], 
        Hue[0.6022757448098648, 1, 0.1660797379555718], 
        Hue[0.6493226359923682, 1, 0.10093788862595174`], 
        Hue[0.5382570964254456, 1, 0.25472094341092155`], 
        Hue[0.5030409968157261, 1, 0.30348169671668696`], 
        Hue[0.4617867703202607, 1, 0.360602933402716], 
        Hue[0.41428194997560863`, 1, 0.4263788384953111], 
        Hue[0.3613257637555329, 1, 0.49970278864618534`], 
        Hue[0.30431462688847477`, 1, 0.5786412858467272], 
        Hue[0.24523902371574663`, 1, 0.6604382748551201], 
        Hue[0.1866070806268344, 1, 0.7416209652859216], 
        Hue[0.13129136223214333`, 1, 0.8182119599862631], 
        Hue[0.08230822812302241, 1, 0.8860347610604306], 
        Hue[0.0425504395154247, 1, 0.9410840068247966], 
        Hue[0.014506093362194328`, 1, 0.9799146399600387], 
        Hue[8.759517244882886*^-7, 1, 0.999998787143766], 
        Hue[8.759517240441994*^-7, 1, 0.9999987871437668], 
        Hue[0.014506093362193773`, 1, 0.9799146399600395], 
        Hue[0.0425504395154247, 1, 0.9410840068247965], 
        Hue[0.08230822812302196, 1, 0.8860347610604311], 
        Hue[0.13129136223214244`, 1, 0.8182119599862643], 
        Hue[0.18660708062683368`, 1, 0.7416209652859226], 
        Hue[0.24523902371574602`, 1, 0.660438274855121], 
        Hue[0.30431462688847427`, 1, 0.578641285846728], 
        Hue[0.3613257637555317, 1, 0.4997027886461869], 
        Hue[0.41428194997560897`, 1, 0.42637883849531066`], 
        Hue[0.46178677032026005`, 1, 0.3606029334027169], 
        Hue[0.5030409968157256, 1, 0.3034816967166877], 
        Hue[0.5382570964254455, 1, 0.25472094341092166`], 
        Hue[0.6022757448098639, 1, 0.16607973795557307`], 
        Hue[0.6493226359923682, 1, 0.10093788862595174`], 
        Hue[0.6039733977896679, 1, 0.1637291415219984], 
        Hue[0.6493466586105661, 1, 0.10090462653921622`], 
        Hue[0.5422397026998014, 1, 0.24920656549258283`], 
        Hue[0.5082824304107322, 1, 0.2962243271236017], 
        Hue[0.4685037988839661, 1, 0.35130243231450853`], 
        Hue[0.4226991555060873, 1, 0.4147242462223407], 
        Hue[0.37163927342490816`, 1, 0.4854225444885887], 
        Hue[0.3166706349743969, 1, 0.5615329669585274], 
        Hue[0.2597124156575464, 1, 0.6403981937049358], 
        Hue[0.2031826935392198, 1, 0.7186701166380033], 
        Hue[0.14985096295229983`, 1, 0.7925140512968156], 
        Hue[0.10262509794762598`, 1, 0.8579037105340563], 
        Hue[0.06429392241993892, 1, 0.9109776458800846], 
        Hue[0.03725603324661164, 1, 0.9484147231969993], 
        Hue[0.02327101237931828, 1, 0.9677785982440209], 
        Hue[0.023268890690838262`, 1, 0.9677815359665316], 
        Hue[0.037253350793507334`, 1, 0.948418437362836], 
        Hue[0.06429160086506325, 1, 0.9109808603406816], 
        Hue[0.10262327005221683`, 1, 0.8579062414661613], 
        Hue[0.14984970892994642`, 1, 0.7925157876354588], 
        Hue[0.20318203774868981`, 1, 0.7186710246556602], 
        Hue[0.25971232945802986`, 1, 0.6403983130581126], 
        Hue[0.316671045895674, 1, 0.5615323979906052], 
        Hue[0.37164007869641597`, 1, 0.4854214294972703], 
        Hue[0.42270023716665606`, 1, 0.41472274853847624`], 
        Hue[0.4685050384669278, 1, 0.35130071596886914`], 
        Hue[0.5082837209174339, 1, 0.2962225402681685], 
        Hue[0.542241157269009, 1, 0.24920455147367987`], 
        Hue[0.6039789462997005, 1, 0.16372145896964552`], 
        Hue[0.6493469313116931, 1, 0.10090424895304037`], 
        Hue[0.6087376034721987, 1, 0.15713254903849413`], 
        Hue[0.649414369301028, 1, 0.10081087327549972`], 
        Hue[0.5533978740975913, 1, 0.23375678971102748`], 
        Hue[0.5229658780640616, 1, 0.27589339960360704`], 
        Hue[0.48731955851693204`, 1, 0.32524984205347873`], 
        Hue[0.44627583485590494`, 1, 0.38207961327643936`], 
        Hue[0.4005257394678352, 1, 0.44542589919838205`], 
        Hue[0.3512759021513562, 1, 0.5136179816365838], 
        Hue[0.3002457706661209, 1, 0.5842750867699864], 
        Hue[0.24960155901173514`, 1, 0.6543978413683668], 
        Hue[0.20182396296106897`, 1, 0.7205514359000583], 
        Hue[0.15951753407086666`, 1, 0.7791295682095692], 
        Hue[0.12517994846479374`, 1, 0.8266739175102855], 
        Hue[0.10095941407703612`, 1, 0.8602100420471807], 
        Hue[0.08843184481123367, 1, 0.8775559071844458], 
        Hue[0.08843039496209071, 1, 0.8775579146678745], 
        Hue[0.10095758092813156`, 1, 0.8602125802533563], 
        Hue[0.1251783616762967, 1, 0.8266761146020507], 
        Hue[0.1595162843037672, 1, 0.7791312986563224], 
        Hue[0.20182310509526868`, 1, 0.7205526237142433], 
        Hue[0.249601109647551, 1, 0.6543984635649294], 
        Hue[0.30024571035715797`, 1, 0.5842751702747043], 
        Hue[0.35127618165515406`, 1, 0.5136175946313252], 
        Hue[0.4005262886368839, 1, 0.4454251388104685], 
        Hue[0.44627657320844016`, 1, 0.3820785909421599], 
        Hue[0.4873204051548792, 1, 0.3252486697855519], 
        Hue[0.522966759856457, 1, 0.2758921786602903], 
        Hue[0.553398868747406, 1, 0.23375541250359172`], 
        Hue[0.6087414029233007, 1, 0.15712728826004524`], 
        Hue[0.6494145560301994, 1, 0.10081061472741623`], 
        Hue[0.6156675658591598, 1, 0.14753721650270174`], 
        Hue[0.6495128594866585, 1, 0.10067450224924218`], 
        Hue[0.5696275304156977, 1, 0.21128495788595708`], 
        Hue[0.5443210586159454, 1, 0.24632468807022953`], 
        Hue[0.5146822729985917, 1, 0.28736300661733466`], 
        Hue[0.4805593630784365, 1, 0.33461011266062646`], 
        Hue[0.44252737372860956`, 1, 0.3872697902219253], 
        Hue[0.401589595811773, 1, 0.443952867337545], 
        Hue[0.3591752496131904, 1, 0.5026804236125056], 
        Hue[0.31708450788719444`, 1, 0.5609599121561923], 
        Hue[0.2773783719176231, 1, 0.6159376388832911], 
        Hue[0.24222075745013222`, 1, 0.6646174127613553], 
        Hue[0.2136865073785173, 1, 0.7041263743989761], 
        Hue[0.19355989355891012`, 1, 0.7319939935338168], 
        Hue[0.18315013423702398`, 1, 0.7464075064410437], 
        Hue[0.18314956221730744`, 1, 0.7464082984683436], 
        Hue[0.19355917011629492`, 1, 0.7319949952235917], 
        Hue[0.2136858807762101, 1, 0.7041272420021706], 
        Hue[0.2422202632889342, 1, 0.6646180969845527], 
        Hue[0.2773780318817297, 1, 0.6159381097022204], 
        Hue[0.31708432871750963`, 1, 0.5609601602372944], 
        Hue[0.3591752237937029, 1, 0.5026804593625652], 
        Hue[0.4015897041401657, 1, 0.443952717344386], 
        Hue[0.44252758864335107`, 1, 0.38726949264766775`], 
        Hue[0.4805596531568227, 1, 0.33460971101363013`], 
        Hue[0.5146826064214726, 1, 0.28736254495488417`], 
        Hue[0.5443214064451819, 1, 0.2463242064605174], 
        Hue[0.5696279238346578, 1, 0.21128441315201235`], 
        Hue[0.615669077128538, 1, 0.14753512397587054`], 
        Hue[0.6495129338042546, 1, 0.10067439934795527`], 
        Hue[0.6234601390512061, 1, 0.13674749977525308`], 
        Hue[0.6496236056366957, 1, 0.10052116142611357`], 
        Hue[0.587875852688278, 1, 0.1860180501239228], 
        Hue[0.5683288547363776, 1, 0.2130831242111694], 
        Hue[0.5454395883293884, 1, 0.24477595462084686`], 
        Hue[0.5190912707195934, 1, 0.2812582405421015], 
        Hue[0.4897284611772105, 1, 0.3219144383700163], 
        Hue[0.458126046574422, 1, 0.36567162782003104`], 
        Hue[0.4253872556881456, 1, 0.4110022613548753], 
        Hue[0.39290120419997865`, 1, 0.45598294803079886`], 
        Hue[0.362258085194362, 1, 0.4984118820385758], 
        Hue[0.3351269812922884, 1, 0.5359780259029854], 
        Hue[0.3131081894873613, 1, 0.5664655837867305], 
        Hue[0.297577848626013, 1, 0.5879691326716743], 
        Hue[0.2895456075556001, 1, 0.5990906972307075], 
        Hue[0.28954584463498473`, 1, 0.5990903689669442], 
        Hue[0.2975781480451234, 1, 0.5879687180913676], 
        Hue[0.3131084480167709, 1, 0.5664652258229326], 
        Hue[0.33512718394406654`, 1, 0.5359777453082156], 
        Hue[0.3622582230367751, 1, 0.49841169117984996`], 
        Hue[0.3929012747880017, 1, 0.45598285029353613`], 
        Hue[0.4253872624143836, 1, 0.41100225204162266`], 
        Hue[0.4581259977404595, 1, 0.36567169543628697`], 
        Hue[0.4897283687679477, 1, 0.3219145663213032], 
        Hue[0.5190911481081258, 1, 0.28125841031182575`], 
        Hue[0.545439448873605, 1, 0.24477614771347014`], 
        Hue[0.5683287105046836, 1, 0.21308332391659193`], 
        Hue[0.5878756915996006, 1, 0.18601827316978375`], 
        Hue[0.6234595367036779, 1, 0.13674833379490747`], 
        Hue[0.6496235760977022, 1, 0.10052120232625851`], 
        Hue[0.6309092329782291, 1, 0.126433369722452], 
        Hue[0.6497294634089954, 1, 0.10037458912600633`], 
        Hue[0.6053178951223055, 1, 0.16186752983065394`], 
        Hue[0.5912715356875939, 1, 0.181316335201793], 
        Hue[0.574827170885874, 1, 0.20408545569648226`], 
        Hue[0.5559013135139169, 1, 0.2302904889807304], 
        Hue[0.5348137958119629, 1, 0.2594885904142053], 
        Hue[0.5121213473795252, 1, 0.2909089036283497], 
        Hue[0.4886161240406277, 1, 0.32345459748220784`], 
        Hue[0.4652951061508435, 1, 0.3557452376372936], 
        Hue[0.4432992915435413, 1, 0.3862009809397121], 
        Hue[0.4238260076350649, 1, 0.41316398942837174`], 
        Hue[0.40802308566648304`, 1, 0.43504495830794654`], 
        Hue[0.3968774441087934, 1, 0.45047738508013224`], 
        Hue[0.3911132217415007, 1, 0.45845861605022986`], 
        Hue[0.39111401526715006`, 1, 0.4584575173224076], 
        Hue[0.3968784471652522, 1, 0.4504759962327277], 
        Hue[0.40802395331140906`, 1, 0.43504375695343356`], 
        Hue[0.4238266901119186, 1, 0.4131630444604204], 
        Hue[0.4432997588836446, 1, 0.38620033385341523`], 
        Hue[0.4652953493354146, 1, 0.3557449009201953], 
        Hue[0.4886161540216366, 1, 0.3234545559700417], 
        Hue[0.5121211915218518, 1, 0.2909091194312822], 
        Hue[0.5348134927357168, 1, 0.2594890100582383], 
        Hue[0.5559009075730197, 1, 0.230291051052742], 
        Hue[0.5748267066162703, 1, 0.20408609853131798`], 
        Hue[0.5912710529523794, 1, 0.1813170036043979], 
        Hue[0.6053173521973283, 1, 0.16186828157293004`], 
        Hue[0.6309071712190801, 1, 0.1264362244658891], 
        Hue[0.6497293620994847, 1, 0.10037472940071342`], 
        Hue[0.6372377100661452, 1, 0.11767086298533747`], 
        Hue[0.6498193884887249, 1, 0.10025007747715022`], 
        Hue[0.6201340030575886, 1, 0.14135291884333895`], 
        Hue[0.610755573052391, 1, 0.154338437312074], 
        Hue[0.5997791025835189, 1, 0.16953662719205084`], 
        Hue[0.5871492042094947, 1, 0.18702417878685362`], 
        Hue[0.5730797264426928, 1, 0.20650499415627152`], 
        Hue[0.5579423080358294, 1, 0.22746449656577464`], 
        Hue[0.5422653288205485, 1, 0.2491710831715484], 
        Hue[0.526713464310233, 1, 0.2707044340319851], 
        Hue[0.5120471170280901, 1, 0.29101168411495215`], 
        Hue[0.49906404424982187`, 1, 0.30898824642332356`], 
        Hue[0.4885288728491535, 1, 0.323575406824249], 
        Hue[0.48109892791438935`, 1, 0.33386302288776865`], 
        Hue[0.47725658556548634`, 1, 0.33918318921701895`], 
        Hue[0.47725762494663326`, 1, 0.3391817500738924], 
        Hue[0.4811002419009807, 1, 0.333861203521719], 
        Hue[0.4885300098526193, 1, 0.323573832511758], 
        Hue[0.49906493923094797`, 1, 0.30898700721868755`], 
        Hue[0.5120477307271325, 1, 0.2910108343778166], 
        Hue[0.5267137848105791, 1, 0.2707039902622752], 
        Hue[0.5422653702110632, 1, 0.24917102586160478`], 
        Hue[0.5579421059099916, 1, 0.22746477643231938`], 
        Hue[0.5730793313285311, 1, 0.20650554123741857`], 
        Hue[0.587148673841918, 1, 0.18702491314195963`], 
        Hue[0.599778495006357, 1, 0.1695374684527364], 
        Hue[0.6107549408429755, 1, 0.15433931267895704`], 
        Hue[0.6201332908743415, 1, 0.1413539049432195], 
        Hue[0.6372349970239707, 1, 0.11767461950527143`], 
        Hue[0.6498192551554071, 1, 0.10025026209251335`], 
        Hue[0.6426169513066163, 1, 0.1102226828062235], 
        Hue[0.6498958580678137, 1, 0.10014419652148876`], 
        Hue[0.6327224787398396, 1, 0.12392272174483751`], 
        Hue[0.6273035877223595, 1, 0.13142580161519454`], 
        Hue[0.6209633643612932, 1, 0.1402045724228249], 
        Hue[0.6136699866390606, 1, 0.1503030954228393], 
        Hue[0.6055472079675879, 1, 0.16155001973718608`], 
        Hue[0.5968097184249482, 1, 0.17364808218084088`], 
        Hue[0.5877624702504635, 1, 0.18617504119166603`], 
        Hue[0.5787888800272749, 1, 0.19860001226992707`], 
        Hue[0.5703273925724269, 1, 0.2103159179766397], 
        Hue[0.562837884895745, 1, 0.22068600552896844`], 
        Hue[0.5567610169112918, 1, 0.22910013043051908`], 
        Hue[0.5524755676281785, 1, 0.2350338294379067], 
        Hue[0.5502596758638851, 1, 0.23810198726538992`], 
        Hue[0.5502615101311635, 1, 0.23809944751069667`], 
        Hue[0.5524778870728062, 1, 0.2350306178991915], 
        Hue[0.5567630251190712, 1, 0.2290973498351322], 
        Hue[0.5628394673492456, 1, 0.22068381443950608`], 
        Hue[0.5703284797983731, 1, 0.21031441258686806`], 
        Hue[0.5787894507625196, 1, 0.19859922202112662`], 
        Hue[0.5877625488826427, 1, 0.1861749323163409], 
        Hue[0.5968093671146062, 1, 0.17364856861054534`], 
        Hue[0.6055465152211046, 1, 0.1615509789246244], 
        Hue[0.6136690539638642, 1, 0.15030438681926506`], 
        Hue[0.6209622939460813, 1, 0.1402060545361952], 
        Hue[0.6273024721629233, 1, 0.1314273462359524], 
        Hue[0.6327212191925413, 1, 0.12392446573340436`], 
        Hue[0.6426121298967593, 1, 0.11022935860448715`], 
        Hue[0.6498956210456897, 1, 0.10014452470596819`], 
        Hue[0.6432670322601114, 1, 0.10932257071676882`], 
        Hue[0.627788739277394, 1, 0.1307540533082238], 
        Hue[0.6215312007966796, 1, 0.13941833735844364`], 
        Hue[0.6143233938953457, 1, 0.14939837768336742`], 
        Hue[0.6062751719935869, 1, 0.16054206954734118`], 
        Hue[0.5975930766290172, 1, 0.17256343235982238`], 
        Hue[0.5885739589734652, 1, 0.18505144142135593`], 
        Hue[0.579594182301374, 1, 0.19748497835194373`], 
        Hue[0.5710872328122532, 1, 0.20926383149072644`], 
        Hue[0.5573078855136699, 1, 0.2283429277503032], 
        Hue[0.5528621143129753, 1, 0.23449861095126506`], 
        Hue[0.5504603601125956, 1, 0.23782411676717535`], 
        Hue[0.5502605344346037, 1, 0.23810079847516413`], 
        Hue[0.5522769448771349, 1, 0.23530884555473644`], 
        Hue[0.556376644213599, 1, 0.22963233878117068`], 
        Hue[0.5622928254940655, 1, 0.22144070316206327`], 
        Hue[0.569655609099376, 1, 0.21124607970855636`], 
        Hue[0.5869575084668386, 1, 0.18728960366130043`], 
        Hue[0.5959981070525373, 1, 0.17477185177340998`], 
        Hue[0.6047633384625756, 1, 0.16263537751335694`], 
        Hue[0.6129412172822569, 1, 0.1513121606861058], 
        Hue[0.6203089596274787, 1, 0.1411106712850296], 
        Hue[0.6267346593848437, 1, 0.13221354854406253`], 
        Hue[0.6322361435905947, 1, 0.12459610887456124`], 
        Hue[0.6417279253205034, 1, 0.11145364186391843`], 
        Hue[0.6492431084282864, 1, 0.1010480037146804], 
        Hue[0.6412530637161606, 1, 0.11211114254685453`], 
        Hue[0.6137476741062011, 1, 0.15019552816064463`], 
        Hue[0.5911781275556787, 1, 0.18144566953829103`], 
        Hue[0.577567654884599, 1, 0.20029093939055523`], 
        Hue[0.5627707137144807, 1, 0.22077901177994982`], 
        Hue[0.5472657246634997, 1, 0.2422474581582313], 
        Hue[0.5316739170993457, 1, 0.26383611478552127`], 
        Hue[0.5167251850346483, 1, 0.28453435918279474`], 
        Hue[0.49188966916713917`, 1, 0.31892199653780734`], 
        Hue[0.4784830257287196, 1, 0.33748504129869594`], 
        Hue[0.4772569851352818, 1, 0.33918263596653286`], 
        Hue[0.4798736327535861, 1, 0.3355595854181116], 
        Hue[0.4861594577380448, 1, 0.3268561354396303], 
        Hue[0.4957042919273025, 1, 0.3136402111775813], 
        Hue[0.5079065757593586, 1, 0.2967447412562727], 
        Hue[0.5373050892257645, 1, 0.25603910722586465`], 
        Hue[0.5682510443450479, 1, 0.21319086167608753`], 
        Hue[0.582660828644106, 1, 0.19323885264662252`], 
        Hue[0.5957496191718221, 1, 0.17511591191593862`], 
        Hue[0.607253262945072, 1, 0.1591877897683619], 
        Hue[0.617141238981305, 1, 0.1454967460258854], 
        Hue[0.6317774561574506, 1, 0.12523121455122227`], 
        Hue[0.6458023147122057, 1, 0.10581217962925371`], 
        Hue[0.64055187699897, 1, 0.11308201646296469`], 
        Hue[0.5984661270407605, 1, 0.17135459332817773`], 
        Hue[0.5655942394702503, 1, 0.21686951457965342`], 
        Hue[0.5237424830742484, 1, 0.274818100358733], 
        Hue[0.5006531714587011, 1, 0.3067879164417985], 
        Hue[0.47723759735959215`, 1, 0.33920948057902633`], 
        Hue[0.4545630358137646, 1, 0.3706050273347875], 
        Hue[0.4161157015508852, 1, 0.4238397978526206], 
        Hue[0.3940656300924371, 1, 0.4543706660258563], 
        Hue[0.3939259619828552, 1, 0.4545640526391236], 
        Hue[0.40231605449512875`, 1, 0.44294700146828325`], 
        Hue[0.415734142216981, 1, 0.42436811077648795`], 
        Hue[0.4333278292564813, 1, 0.4000076210294875], 
        Hue[0.4766737410268823, 1, 0.33999020473200914`], 
        Hue[0.5231924110198736, 1, 0.2755797385878674], 
        Hue[0.5651338019504073, 1, 0.21750704345328228`], 
        Hue[0.5828486430136464, 1, 0.19297880198110512`], 
        Hue[0.5981227827376427, 1, 0.17182999313249475`], 
        Hue[0.6177971273208911, 1, 0.1445885929403046], 
        Hue[0.6400860008926634, 1, 0.11372707568708142`], 
        Hue[0.6422826805592395, 1, 0.11068551922566836`], 
        Hue[0.5823892479014552, 1, 0.1936148875210621], 
        Hue[0.538042948910495, 1, 0.25501745535469933`], 
        Hue[0.48085593368767154`, 1, 0.33419947643245485`], 
        Hue[0.41626594024551333`, 1, 0.42363177504467386`], 
        Hue[0.3842971118118805, 1, 0.46789630672201166`], 
        Hue[0.3289443018365473, 1, 0.5445386589955499], 
        Hue[0.2953226222573054, 1, 0.5910917537975772], 
        Hue[0.2918011380948874, 1, 0.5959676549455406], 
        Hue[0.3192910676832635, 1, 0.5579046755154814], 
        Hue[0.3427452344342434, 1, 0.52542967539874], 
        Hue[0.40202252169466424`, 1, 0.44335343149969575`], 
        Hue[0.4669984782930092, 1, 0.35338672236352564`], 
        Hue[0.5264877691436817, 1, 0.27101693503182545`], 
        Hue[0.5738152966617034, 1, 0.2054865123145645], 
        Hue[0.5978608444763083, 1, 0.17219267687895778`], 
        Hue[0.6308010827908599, 1, 0.12658311613573245`], 
        Hue[0.6471639496479785, 1, 0.10392683894895278`], 
        Hue[0.5678708626721414, 1, 0.21371726706934283`], 
        Hue[0.5123130950578718, 1, 0.29064340684294676`], 
        Hue[0.4396845460944257, 1, 0.391206013100026], 
        Hue[0.35625186392221736`, 1, 0.5067281884153914], 
        Hue[0.24023829515486617`, 1, 0.6673623605548007], 
        Hue[0.19283611511503923`, 1, 0.7329961483022533], 
        Hue[0.18387320634860455`, 1, 0.7454063296711629], 
        Hue[0.21566846048195937`, 1, 0.7013821316403639], 
        Hue[0.320007850397767, 1, 0.5569122071415533], 
        Hue[0.40443262631213805`, 1, 0.4400163635678088], 
        Hue[0.4829288695919822, 1, 0.33132925748802466`], 
        Hue[0.546078114715954, 1, 0.24389184116252524`], 
        Hue[0.618016711599604, 1, 0.144284553169779], 
        Hue[0.6134393712358532, 1, 0.15062240905804938`], 
        Hue[0.5597906890952162, 1, 0.22490519971431608`], 
        Hue[0.5264808821814904, 1, 0.2710264708256288], 
        Hue[0.49143641314473197`, 1, 0.3195495817996019], 
        Hue[0.45101559593564244`, 1, 0.3755168671660335], 
        Hue[0.40580850751011666`, 1, 0.4381112972936846], 
        Hue[0.3569622667530064, 1, 0.5057445537266065], 
        Hue[0.30613714542441306`, 1, 0.5761177986431204], 
        Hue[0.2554478293905232, 1, 0.6463030054592757], 
        Hue[0.2073387507107557, 1, 0.7129155759389537], 
        Hue[0.12914229794443288`, 1, 0.8211875874615544], 
        Hue[0.10375357462868617`, 1, 0.8563412043602807], 
        Hue[0.08987650496460475, 1, 0.8755556085105474], 
        Hue[0.08843171541781158, 1, 0.8775560863445686], 
        Hue[0.09951326985387354, 1, 0.8622123955869443], 
        Hue[0.12238397672032508`, 1, 0.8305452630026268], 
        Hue[0.1555536278639838, 1, 0.7846180537267917], 
        Hue[0.19694005720194285`, 1, 0.727313766951156], 
        Hue[0.29439908564497536`, 1, 0.5923704967992649], 
        Hue[0.34538449739612337`, 1, 0.5217753112976754], 
        Hue[0.39483967846710455`, 1, 0.45329890673785533`], 
        Hue[0.4409936328930446, 1, 0.3893934313788614], 
        Hue[0.48258054548984053`, 1, 0.3318115523986824], 
        Hue[0.5188498732647924, 1, 0.28159248317182606`], 
        Hue[0.5498837618975734, 1, 0.23862248352643697`], 
        Hue[0.6023460341736327, 1, 0.16598241422112395`], 
        Hue[0.6447160778201386, 1, 0.10731619994134659`], 
        Hue[0.617722431996425, 1, 0.14469201723571928`], 
        Hue[0.51856947216833, 1, 0.28198073084385067`], 
        Hue[0.48055379551473054`, 1, 0.33461782159498854`], 
        Hue[0.4365740211159339, 1, 0.3955128938394761], 
        Hue[0.3871053925865305, 1, 0.4640079179571117], 
        Hue[0.3333200485926564, 1, 0.5384799327178603], 
        Hue[0.2769637440356448, 1, 0.6165117390275688], 
        Hue[0.22030348310954628`, 1, 0.6949644080021667], 
        Hue[0.16600244442768575`, 1, 0.7701504615616659], 
        Hue[0.07590092200313603, 1, 0.8949064156879655], 
        Hue[0.02750426862112476, 1, 0.9619171665245965], 
        Hue[0.023270413385846567`, 1, 0.9677794276195971], 
        Hue[0.03302049699040388, 1, 0.9542793118594408], 
        Hue[0.05610511392484363, 1, 0.9223159961040627], 
        Hue[0.09101591614372317, 1, 0.8739779622625371], 
        Hue[0.13554779899441216`, 1, 0.8123184321615832], 
        Hue[0.24259113109163727`, 1, 0.6641045877192715], 
        Hue[0.3549903820825449, 1, 0.5084748555780148], 
        Hue[0.40723391967740996`, 1, 0.4361376496774324], 
        Hue[0.45463005955166735`, 1, 0.3705122252361529], 
        Hue[0.4962336877780928, 1, 0.3129072015380254], 
        Hue[0.5319539978428438, 1, 0.2634483106791393], 
        Hue[0.5852727256986741, 1, 0.18962237980183602`], 
        Hue[0.6356016827117187, 1, 0.11993613162992803`], 
        Hue[0.625798101903588, 1, 0.13351032044118585`], 
        Hue[0.5206490804550483, 1, 0.27910127321608696`], 
        Hue[0.438034392733727, 1, 0.39349084083022423`], 
        Hue[0.38780391391091007`, 1, 0.4630407345848938], 
        Hue[0.33282027668953884`, 1, 0.5391719245837155], 
        Hue[0.2747769279262213, 1, 0.6195396382560012], 
        Hue[0.21592316975918813`, 1, 0.7010294572565088], 
        Hue[0.1589493449301979, 1, 0.7799162916351106], 
        Hue[0.062429435740938066`, 1, 0.9135592428202397], 
        Hue[0.007253368925545622, 1, 0.9899568737953984], 
        Hue[0.0072533689255454, 1, 0.9899568737953987], 
        Hue[0.028528340951307296`, 1, 0.9604992202212669], 
        Hue[0.062429435740937955`, 1, 0.9135592428202398], 
        Hue[0.1067999136638016, 1, 0.8521231964655055], 
        Hue[0.21592316975918785`, 1, 0.7010294572565091], 
        Hue[0.3328202766895381, 1, 0.5391719245837165], 
        Hue[0.438034392733727, 1, 0.3934908408302241], 
        Hue[0.4824138940233156, 1, 0.33204230058310147`], 
        Hue[0.5206490804550483, 1, 0.279101273216087], 
        Hue[0.5702672651642872, 1, 0.21039917131098698`], 
        Hue[0.6257981019035878, 1, 0.13351032044118621`], 
        Hue[0.6356016827117188, 1, 0.1199361316299279], 
        Hue[0.5319539978428438, 1, 0.2634483106791394], 
        Hue[0.4546300595516674, 1, 0.3705122252361528], 
        Hue[0.3549903820825455, 1, 0.508474855578014], 
        Hue[0.2994193607344692, 1, 0.5854193466753503], 
        Hue[0.24259113109163738`, 1, 0.6641045877192714], 
        Hue[0.18703012692867332`, 1, 0.7410352088679908], 
        Hue[0.09101591614372273, 1, 0.8739779622625377], 
        Hue[0.0330204969904041, 1, 0.9542793118594404], 
        Hue[0.027504268621123762`, 1, 0.9619171665245978], 
        Hue[0.07590092200313547, 1, 0.8949064156879663], 
        Hue[0.11692659598318034`, 1, 0.838101636330981], 
        Hue[0.22030348310954573`, 1, 0.6949644080021675], 
        Hue[0.333320048592656, 1, 0.5384799327178609], 
        Hue[0.4365740211159337, 1, 0.3955128938394764], 
        Hue[0.5185694721683298, 1, 0.281980730843851], 
        Hue[0.5609429858823103, 1, 0.22330971185526277`], 
        Hue[0.6177224319964245, 1, 0.1446920172357199], 
        Hue[0.6447160778201385, 1, 0.1073161999413467], 
        Hue[0.5498837618975734, 1, 0.23862248352643695`], 
        Hue[0.48258054548984075`, 1, 0.3318115523986821], 
        Hue[0.39483967846710505`, 1, 0.45329890673785456`], 
        Hue[0.29439908564497536`, 1, 0.5923704967992649], 
        Hue[0.2440859498593781, 1, 0.6620348386562457], 
        Hue[0.15555362786398336`, 1, 0.7846180537267923], 
        Hue[0.0995132698538741, 1, 0.8622123955869436], 
        Hue[0.08987650496460409, 1, 0.8755556085105483], 
        Hue[0.12914229794443277`, 1, 0.8211875874615546], 
        Hue[0.2554478293905228, 1, 0.6463030054592761], 
        Hue[0.35696226675300613`, 1, 0.5057445537266069], 
        Hue[0.4510155959356426, 1, 0.3755168671660334], 
        Hue[0.5264808821814901, 1, 0.27102647082562903`], 
        Hue[0.6134393712358527, 1, 0.15062240905805013`], 
        Hue[0.6180167115996045, 1, 0.14428455316977848`], 
        Hue[0.5728233150649802, 1, 0.20686002529464279`], 
        Hue[0.5460781147159542, 1, 0.24389184116252494`], 
        Hue[0.5167402753982261, 1, 0.2845134648332255], 
        Hue[0.482928869591982, 1, 0.331329257488025], 
        Hue[0.4451684747100398, 1, 0.38361288117071424`], 
        Hue[0.40443262631213794`, 1, 0.44001636356780904`], 
        Hue[0.3621209519908066, 1, 0.4986017587819601], 
        Hue[0.32000785039776697`, 1, 0.5569122071415534], 
        Hue[0.2801361764938014, 1, 0.6121191402393519], 
        Hue[0.24466271032969483`, 1, 0.6612362472358071], 
        Hue[0.2156684604819588, 1, 0.7013821316403648], 
        Hue[0.1949578794311445, 1, 0.7300583207876461], 
        Hue[0.183873206348605, 1, 0.7454063296711624], 
        Hue[0.18314962691401843`, 1, 0.7464082088882822], 
        Hue[0.1928361151150383, 1, 0.7329961483022547], 
        Hue[0.21228788392593306`, 1, 0.706062929948708], 
        Hue[0.24023829515486633`, 1, 0.6673623605548005], 
        Hue[0.2749360615481359, 1, 0.6193192993948887], 
        Hue[0.35625186392221725`, 1, 0.5067281884153916], 
        Hue[0.39864398660653844`, 1, 0.44803140316017753`], 
        Hue[0.4396845460944252, 1, 0.3912060131000267], 
        Hue[0.47791854372020687`, 1, 0.3382666317720213], 
        Hue[0.5123130950578715, 1, 0.2906434068429472], 
        Hue[0.542263402450256, 1, 0.24917375045349185`], 
        Hue[0.5678708626721414, 1, 0.2137172670693428], 
        Hue[0.612473166954633, 1, 0.15196023037050804`], 
        Hue[0.6471639496479787, 1, 0.1039268389489526], 
        Hue[0.6308010827908601, 1, 0.12658311613573214`], 
        Hue[0.5738152966617035, 1, 0.20548651231456438`], 
        Hue[0.5518646402844236, 1, 0.23587972883695194`], 
        Hue[0.5264877691436816, 1, 0.27101693503182567`], 
        Hue[0.4979716801206474, 1, 0.3105007506021805], 
        Hue[0.46699847829300933`, 1, 0.35338672236352553`], 
        Hue[0.4345791545435441, 1, 0.39827501678586197`], 
        Hue[0.4020225216946645, 1, 0.4433534314996953], 
        Hue[0.3708622433144219, 1, 0.48649843233387735`], 
        Hue[0.3192910676832634, 1, 0.5579046755154815], 
        Hue[0.30193883613655426`, 1, 0.5819308422724634], 
        Hue[0.29180113809488745`, 1, 0.5959676549455405], 
        Hue[0.28954586233322177`, 1, 0.599090344461693], 
        Hue[0.2953226222573051, 1, 0.5910917537975776], 
        Hue[0.308747457626783, 1, 0.5725035202090697], 
        Hue[0.32894430183654727`, 1, 0.54453865899555], 
        Hue[0.35463996524360697`, 1, 0.5089600481242366], 
        Hue[0.41626594024551333`, 1, 0.423631775044674], 
        Hue[0.4808559336876712, 1, 0.3341994764324553], 
        Hue[0.5108479266774192, 1, 0.2926721015235735], 
        Hue[0.5380429489104949, 1, 0.25501745535469944`], 
        Hue[0.5619036579491844, 1, 0.2219795505318985], 
        Hue[0.5823892479014552, 1, 0.19361488752106204`], 
        Hue[0.6134745067166796, 1, 0.15057375993075145`], 
        Hue[0.6422826805592395, 1, 0.11068551922566833`], 
        Hue[0.6400860008926635, 1, 0.1137270756870813], 
        Hue[0.5981227827376427, 1, 0.1718299931324947], 
        Hue[0.5651338019504072, 1, 0.21750704345328234`], 
        Hue[0.5451013481926241, 1, 0.2452442871179051], 
        Hue[0.5231924110198738, 1, 0.27557973858786716`], 
        Hue[0.500084212233562, 1, 0.3075757061381449], 
        Hue[0.4766737410268823, 1, 0.3399902047320092], 
        Hue[0.4540316873519137, 1, 0.37134074058965794`], 
        Hue[0.41573414221698096`, 1, 0.42436811077648795`], 
        Hue[0.3939259619828554, 1, 0.45456405263912336`], 
        Hue[0.39111372425368446`, 1, 0.45845792026412924`], 
        Hue[0.3940656300924367, 1, 0.45437066602585685`], 
        Hue[0.40258539264872584`, 1, 0.4425740717171489], 
        Hue[0.41611570155088484`, 1, 0.42383979785262094`], 
        Hue[0.43379801622503644`, 1, 0.39935659291918035`], 
        Hue[0.47723759735959204`, 1, 0.3392094805790265], 
        Hue[0.5237424830742481, 1, 0.27481810035873333`], 
        Hue[0.5655942394702503, 1, 0.21686951457965342`], 
        Hue[0.5832495875495567, 1, 0.1924236480083062], 
        Hue[0.5984661270407605, 1, 0.17135459332817785`], 
        Hue[0.61842849431418, 1, 0.14371439248805845`], 
        Hue[0.6405518769989699, 1, 0.11308201646296481`], 
        Hue[0.6458023147122057, 1, 0.1058121796292537], 
        Hue[0.6171412389813049, 1, 0.14549674602588547`], 
        Hue[0.595749619171822, 1, 0.17511591191593873`], 
        Hue[0.5682510443450479, 1, 0.2131908616760876], 
        Hue[0.552941860021709, 1, 0.23438819381609532`], 
        Hue[0.5373050892257643, 1, 0.25603910722586487`], 
        Hue[0.522035897273629, 1, 0.2771810653134368], 
        Hue[0.49570429192730214`, 1, 0.3136402111775816], 
        Hue[0.47987363275358597`, 1, 0.3355595854181118], 
        Hue[0.47848302572871904`, 1, 0.3374850412986968], 
        Hue[0.4834695890086842, 1, 0.33058056906489885`], 
        Hue[0.49188966916713883`, 1, 0.3189219965378078], 
        Hue[0.5032053724394923, 1, 0.30325409969916467`], 
        Hue[0.5316739170993455, 1, 0.26383611478552166`], 
        Hue[0.5627707137144804, 1, 0.22077901177995024`], 
        Hue[0.5911781275556787, 1, 0.18144566953829117`], 
        Hue[0.613747674106201, 1, 0.15019552816064477`], 
        Hue[0.6255927744265147, 1, 0.13379462002482587`], 
        Hue[0.6412530637161605, 1, 0.11211114254685471`], 
        Hue[0.6492431084282864, 1, 0.10104800371468042`], 
        Hue[0.6322361435905947, 1, 0.12459610887456123`], 
        Hue[0.6203089596274788, 1, 0.14111067128502947`], 
        Hue[0.6047633384625757, 1, 0.16263537751335672`], 
        Hue[0.5869575084668387, 1, 0.18728960366130032`], 
        Hue[0.5780298854580632, 1, 0.19965092782729704`], 
        Hue[0.5622928254940656, 1, 0.22144070316206316`], 
        Hue[0.552276944877135, 1, 0.2353088455547362], 
        Hue[0.5504603601125957, 1, 0.2378241167671753], 
        Hue[0.5573078855136702, 1, 0.22834292775030293`], 
        Hue[0.5635110193069252, 1, 0.21975397326733448`], 
        Hue[0.579594182301374, 1, 0.19748497835194362`], 
        Hue[0.5975930766290172, 1, 0.17256343235982233`], 
        Hue[0.6143233938953458, 1, 0.14939837768336736`], 
        Hue[0.627788739277394, 1, 0.1307540533082238], 
        Hue[0.6432670322601114, 1, 0.10932257071676893`], 
        Hue[0.563511019306925, 1, 0.21975397326733456`], 
        Hue[0.5780298854580632, 1, 0.1996509278272972], 
        Hue[0.6255927744265147, 1, 0.13379462002482578`], 
        Hue[0.5032053724394926, 1, 0.30325409969916417`], 
        Hue[0.48346958900868453`, 1, 0.33058056906489836`], 
        Hue[0.5220358972736292, 1, 0.27718106531343656`], 
        Hue[0.5529418600217092, 1, 0.23438819381609505`], 
        Hue[0.6184284943141801, 1, 0.14371439248805834`], 
        Hue[0.5832495875495568, 1, 0.19242364800830597`], 
        Hue[0.4337980162250368, 1, 0.3993565929191799], 
        Hue[0.40258539264872606`, 1, 0.4425740717171486], 
        Hue[0.3911137242536845, 1, 0.4584579202641291], 
        Hue[0.4540316873519137, 1, 0.37134074058965805`], 
        Hue[0.500084212233562, 1, 0.307575706138145], 
        Hue[0.545101348192624, 1, 0.2452442871179052], 
        Hue[0.6134745067166797, 1, 0.15057375993075123`], 
        Hue[0.5619036579491845, 1, 0.22197955053189833`], 
        Hue[0.5108479266774191, 1, 0.2926721015235736], 
        Hue[0.35463996524360725`, 1, 0.5089600481242361], 
        Hue[0.3087474576267834, 1, 0.5725035202090691], 
        Hue[0.28954586233322194`, 1, 0.5990903444616927], 
        Hue[0.30193883613655403`, 1, 0.5819308422724636], 
        Hue[0.37086224331442164`, 1, 0.4864984323338778], 
        Hue[0.43457915454354423`, 1, 0.39827501678586186`], 
        Hue[0.4979716801206472, 1, 0.3105007506021809], 
        Hue[0.5518646402844234, 1, 0.2358797288369523], 
        Hue[0.6124731669546335, 1, 0.1519602303705075], 
        Hue[0.5422634024502561, 1, 0.2491737504534917], 
        Hue[0.4779185437202067, 1, 0.33826663177202154`], 
        Hue[0.39864398660653866`, 1, 0.4480314031601773], 
        Hue[0.2749360615481363, 1, 0.6193192993948882], 
        Hue[0.21228788392593284`, 1, 0.7060629299487083], 
        Hue[0.18314962691401898`, 1, 0.7464082088882814], 
        Hue[0.19495787943114445`, 1, 0.7300583207876462], 
        Hue[0.24466271032969494`, 1, 0.661236247235807], 
        Hue[0.28013617649380107`, 1, 0.6121191402393524], 
        Hue[0.3621209519908067, 1, 0.49860175878196], 
        Hue[0.4451684747100392, 1, 0.383612881170715], 
        Hue[0.5167402753982258, 1, 0.28451346483322587`], 
        Hue[0.5728233150649804, 1, 0.20686002529464262`], 
        Hue[0.24408594985937848`, 1, 0.6620348386562452], 
        Hue[0.5609429858823104, 1, 0.22330971185526255`], 
        Hue[0.116926595983181, 1, 0.8381016363309802], 
        Hue[0.1870301269286732, 1, 0.7410352088679909], 
        Hue[0.2994193607344693, 1, 0.5854193466753502], 
        Hue[0.5702672651642874, 1, 0.21039917131098668`], 
        Hue[0.482413894023316, 1, 0.3320423005831009], 
        Hue[0.10679991366380182`, 1, 0.8521231964655052], 
        Hue[0.028528340951307407`, 1, 0.9604992202212667], 
        Hue[0.15894934493019736`, 1, 0.7799162916351113], 
        Hue[0.27477692792622116`, 1, 0.6195396382560014], 
        Hue[0.38780391391090985`, 1, 0.46304073458489403`], 
        Hue[0.5852727256986744, 1, 0.1896223798018355], 
        Hue[0.49623368777809296`, 1, 0.3129072015380251], 
        Hue[0.40723391967740985`, 1, 0.4361376496774325], 
        Hue[0.1355477989944125, 1, 0.8123184321615827], 
        Hue[0.0561051139248433, 1, 0.9223159961040631], 
        Hue[0.023270413385846234`, 1, 0.9677794276195976], 
        Hue[0.1660024444276852, 1, 0.7701504615616667], 
        Hue[0.27696374403564433`, 1, 0.6165117390275694], 
        Hue[0.3871053925865298, 1, 0.4640079179571126], 
        Hue[0.4805537955147301, 1, 0.33461782159498915`], 
        Hue[0.6023460341736332, 1, 0.1659824142211233], 
        Hue[0.5188498732647925, 1, 0.28159248317182584`], 
        Hue[0.4409936328930442, 1, 0.38939343137886184`], 
        Hue[0.34538449739612326`, 1, 0.5217753112976755], 
        Hue[0.19694005720194346`, 1, 0.7273137669511552], 
        Hue[0.12238397672032497`, 1, 0.830545263002627], 
        Hue[0.0884317154178117, 1, 0.8775560863445685], 
        Hue[0.10375357462868562`, 1, 0.8563412043602814], 
        Hue[0.20733875071075492`, 1, 0.7129155759389547], 
        Hue[0.3061371454244128, 1, 0.5761177986431207], 
        Hue[0.405808507510116, 1, 0.4381112972936856], 
        Hue[0.4914364131447315, 1, 0.3195495817996026], 
        Hue[0.5597906890952161, 1, 0.22490519971431616`], 
        Hue[0.5978608444763083, 1, 0.17219267687895778`], 
        Hue[0.3427452344342437, 1, 0.5254296753987395], 
        Hue[0.3842971118118802, 1, 0.467896306722012], 
        Hue[0.6177971273208912, 1, 0.14458859294030454`], 
        Hue[0.5828486430136465, 1, 0.19297880198110495`], 
        Hue[0.4333278292564814, 1, 0.4000076210294874], 
        Hue[0.40231605449512886`, 1, 0.44294700146828314`], 
        Hue[0.45456303581376445`, 1, 0.37060502733478773`], 
        Hue[0.500653171458701, 1, 0.3067879164417987], 
        Hue[0.6317774561574506, 1, 0.12523121455122221`], 
        Hue[0.607253262945072, 1, 0.1591877897683619], 
        Hue[0.5826608286441058, 1, 0.19323885264662272`], 
        Hue[0.5079065757593584, 1, 0.2967447412562729], 
        Hue[0.4861594577380445, 1, 0.32685613543963077`], 
        Hue[0.4772569851352815, 1, 0.3391826359665334], 
        Hue[0.5167251850346479, 1, 0.28453435918279524`], 
        Hue[0.5472657246634994, 1, 0.24224745815823162`], 
        Hue[0.5775676548845988, 1, 0.20029093939055556`], 
        Hue[0.6417279253205035, 1, 0.1114536418639183], 
        Hue[0.6267346593848439, 1, 0.13221354854406242`], 
        Hue[0.612941217282257, 1, 0.15131216068610576`], 
        Hue[0.5959981070525373, 1, 0.17477185177340993`], 
        Hue[0.5696556090993762, 1, 0.21124607970855605`], 
        Hue[0.5563766442135991, 1, 0.22963233878117056`], 
        Hue[0.5502605344346039, 1, 0.2381007984751639], 
        Hue[0.5528621143129753, 1, 0.234498610951265], 
        Hue[0.5710872328122532, 1, 0.20926383149072647`], 
        Hue[0.5885739589734652, 1, 0.18505144142135588`], 
        Hue[0.6062751719935868, 1, 0.1605420695473413], 
        Hue[0.6215312007966796, 1, 0.13941833735844367`], 
        Hue[0.6228630326504282, 1, 0.13757426248402257`], 
        Hue[0.6096877329029456, 1, 0.15581698521130607`], 
        Hue[0.5942753953788704, 1, 0.17715714486002554`], 
        Hue[0.578196972458653, 1, 0.1994195765957113], 
        Hue[0.5534622544369899, 1, 0.2336676477026293], 
        Hue[0.5502609097025113, 1, 0.23810027887344595`], 
        Hue[0.5539759816994939, 1, 0.23295633303146995`], 
        Hue[0.5638867655424574, 1, 0.21923370924890517`], 
        Hue[0.5953645965293008, 1, 0.1756490201901989], 
        Hue[0.6106661374931279, 1, 0.1544622711633613], 
        Hue[0.6236270389875472, 1, 0.13651640755570388`], 
        Hue[0.6348006587199928, 1, 0.12104524177231768`], 
        Hue[0.5804419605717948, 1, 0.1963111315159765], 
        Hue[0.553671553411395, 1, 0.23337784912268394`], 
        Hue[0.5257149248329863, 1, 0.27208702715432675`], 
        Hue[0.47725711309755225`, 1, 0.3391824587880046], 
        Hue[0.4836291928262171, 1, 0.33035957916369946`], 
        Hue[0.5008325505517295, 1, 0.3065395453899131], 
        Hue[0.5817027184239647, 1, 0.19456546679758735`], 
        Hue[0.6042635988004508, 1, 0.16332732473783743`], 
        Hue[0.6236270389875473, 1, 0.13651640755570377`], 
        Hue[0.5055680372000515, 1, 0.2999827177230057], 
        Hue[0.4637621616894648, 1, 0.3578677761222796], 
        Hue[0.4007621658133186, 1, 0.4450985396430973], 
        Hue[0.42654081381261244`, 1, 0.4094050270286905], 
        Hue[0.5817027184239646, 1, 0.19456546679758752`], 
        Hue[0.610666137493128, 1, 0.1544622711633612], 
        Hue[0.3907502340439717, 1, 0.4589612144006546], 
        Hue[0.3389361078632657, 1, 0.5307038506508629], 
        Hue[0.5953645965293008, 1, 0.17564902019019882`], 
        Hue[0.5632871686543652, 1, 0.22006392032472508`], 
        Hue[0.5004450836337965, 1, 0.30707603804551264`], 
        Hue[0.42604254035927835`, 1, 0.41009494411792236`], 
        Hue[0.33837931416065686`, 1, 0.5314747957775521], 
        Hue[0.24658236972349462`, 1, 0.6585782573059306], 
        Hue[0.10834460042460281`, 1, 0.8499843994120885], 
        Hue[0.08843114950821718, 1, 0.8775568699116992], 
        Hue[0.10861104359249618`, 1, 0.8496154781026976], 
        Hue[0.1648636088038778, 1, 0.7717273108869385], 
        Hue[0.33893610786326595`, 1, 0.5307038506508626], 
        Hue[0.42654081381261255`, 1, 0.4094050270286903], 
        Hue[0.5008325505517293, 1, 0.30653954538991346`], 
        Hue[0.5638867655424575, 1, 0.219233709248905], 
        Hue[0.4830746978240673, 1, 0.3311273414743684], 
        Hue[0.40004897243384896`, 1, 0.4460860381685169], 
        Hue[0.3022320270374818, 1, 0.5815248856404098], 
        Hue[0.19980207471950806`, 1, 0.7233509734652965], 
        Hue[0.02326999810538999, 1, 0.9677800026233061], 
        Hue[0.04582379719126228, 1, 0.936551665427483], 
        Hue[0.10861104359249629`, 1, 0.8496154781026974], 
        Hue[0.4007621658133187, 1, 0.4450985396430972], 
        Hue[0.48362919282621697`, 1, 0.3303595791636996], 
        Hue[0.5539759816994941, 1, 0.23295633303146973`], 
        Hue[0.3911136684189974, 1, 0.4584579975736959], 
        Hue[0.289545777407348, 1, 0.5990904620513643], 
        Hue[0.18314986366475478`, 1, 0.7464078810795703], 
        Hue[0.023269998105389655`, 1, 0.9677800026233067], 
        Hue[0.08843114950821707, 1, 0.8775568699116995], 
        Hue[0.4772571130975518, 1, 0.3391824587880052], 
        Hue[0.5502609097025114, 1, 0.23810027887344576`], 
        Hue[0.30286961558245473`, 1, 0.5806420707319858], 
        Hue[0.19995218021711048`, 1, 0.7231431350840009], 
        Hue[0.10834460042460226`, 1, 0.8499843994120891], 
        Hue[0.5534622544369899, 1, 0.2336676477026293], 
        Hue[0.24684375443555662`, 1, 0.6582163400123062], 
        Hue[0.5785358818375376, 1, 0.19895031745571717`], 
        Hue[0.5259338698041325, 1, 0.27178387257889347`], 
        Hue[0.4640436151731847, 1, 0.3574780712986674], 
        Hue[0.391064624126182, 1, 0.4585259050560557], 
        Hue[0.3146212857943015, 1, 0.5643705273617364], 
        Hue[0.24684375443555678`, 1, 0.658216340012306], 
        Hue[0.19995218021711053`, 1, 0.7231431350840007], 
        Hue[0.18314986366475433`, 1, 0.7464078810795709], 
        Hue[0.19980207471950773`, 1, 0.723350973465297], 
        Hue[0.24658236972349445`, 1, 0.6585782573059308], 
        Hue[0.3907502340439714, 1, 0.45896121440065496`], 
        Hue[0.46376216168946466`, 1, 0.3578677761222797], 
        Hue[0.525714924832986, 1, 0.2720870271543271], 
        Hue[0.5781969724586531, 1, 0.1994195765957112], 
        Hue[0.5546086760264161, 1, 0.23208029473265476`], 
        Hue[0.5067715095368749, 1, 0.2983163714104809], 
        Hue[0.4502770825641294, 1, 0.3765394241419747], 
        Hue[0.3910646241261822, 1, 0.4585259050560555], 
        Hue[0.3028696155824549, 1, 0.5806420707319856], 
        Hue[0.28954577740734794`, 1, 0.5990904620513644], 
        Hue[0.3022320270374816, 1, 0.5815248856404102], 
        Hue[0.33837931416065664`, 1, 0.5314747957775524], 
        Hue[0.5055680372000513, 1, 0.2999827177230059], 
        Hue[0.5536715534113947, 1, 0.23337784912268422`], 
        Hue[0.5942753953788705, 1, 0.17715714486002548`], 
        Hue[0.5475013404862448, 1, 0.24192122086519957`], 
        Hue[0.5067715095368749, 1, 0.2983163714104809], 
        Hue[0.4640436151731846, 1, 0.3574780712986675], 
        Hue[0.3911136684189974, 1, 0.4584579975736959], 
        Hue[0.4000489724338487, 1, 0.4460860381685172], 
        Hue[0.42604254035927813`, 1, 0.4100949441179226], 
        Hue[0.5804419605717945, 1, 0.19631113151597673`], 
        Hue[0.6096877329029456, 1, 0.15581698521130607`], 
        Hue[0.5546086760264158, 1, 0.23208029473265504`], 
        Hue[0.5259338698041324, 1, 0.2717838725788937], 
        Hue[0.483074697824067, 1, 0.33112734147436884`], 
        Hue[0.500445083633796, 1, 0.3070760380455132], 
        Hue[0.6228630326504281, 1, 0.1375742624840226], 
        Hue[0.5785358818375377, 1, 0.19895031745571706`], 
        Hue[0.5632871686543652, 1, 0.22006392032472502`], 
        Hue[0.5632871686543652, 1, 0.2200639203247251], 
        Hue[0.5785358818375376, 1, 0.19895031745571723`], 
        Hue[0.6228630326504282, 1, 0.13757426248402257`], 
        Hue[0.5004450836337964, 1, 0.30707603804551264`], 
        Hue[0.4830746978240673, 1, 0.3311273414743684], 
        Hue[0.5259338698041325, 1, 0.27178387257889347`], 
        Hue[0.554608676026416, 1, 0.2320802947326548], 
        Hue[0.6096877329029456, 1, 0.1558169852113061], 
        Hue[0.5804419605717948, 1, 0.19631113151597648`], 
        Hue[0.4260425403592784, 1, 0.41009494411792224`], 
        Hue[0.40004897243384896`, 1, 0.4460860381685169], 
        Hue[0.3911136684189974, 1, 0.4584579975736959], 
        Hue[0.46404361517318465`, 1, 0.3574780712986674], 
        Hue[0.5067715095368749, 1, 0.29831637141048095`], 
        Hue[0.5475013404862448, 1, 0.24192122086519957`], 
        Hue[0.5942753953788704, 1, 0.17715714486002554`], 
        Hue[0.553671553411395, 1, 0.23337784912268397`], 
        Hue[0.5055680372000515, 1, 0.2999827177230057], 
        Hue[0.3383793141606568, 1, 0.5314747957775522], 
        Hue[0.3022320270374819, 1, 0.5815248856404097], 
        Hue[0.28954577740734794`, 1, 0.5990904620513644], 
        Hue[0.3028696155824547, 1, 0.5806420707319859], 
        Hue[0.39106462412618187`, 1, 0.45852590505605595`], 
        Hue[0.4502770825641294, 1, 0.3765394241419747], 
        Hue[0.5067715095368749, 1, 0.29831637141048095`], 
        Hue[0.5546086760264158, 1, 0.2320802947326551], 
        Hue[0.578196972458653, 1, 0.19941957659571127`], 
        Hue[0.5257149248329863, 1, 0.27208702715432675`], 
        Hue[0.4637621616894647, 1, 0.3578677761222796], 
        Hue[0.3907502340439716, 1, 0.45896121440065485`], 
        Hue[0.2465823697234944, 1, 0.6585782573059309], 
        Hue[0.19980207471950812`, 1, 0.7233509734652964], 
        Hue[0.1831498636647544, 1, 0.7464078810795708], 
        Hue[0.19995218021711053`, 1, 0.7231431350840007], 
        Hue[0.24684375443555684`, 1, 0.6582163400123059], 
        Hue[0.31462128579430143`, 1, 0.5643705273617365], 
        Hue[0.3910646241261821, 1, 0.4585259050560556], 
        Hue[0.4640436151731846, 1, 0.3574780712986675], 
        Hue[0.5259338698041323, 1, 0.2717838725788938], 
        Hue[0.5785358818375377, 1, 0.19895031745571706`], 
        Hue[0.2468437544355569, 1, 0.6582163400123058], 
        Hue[0.5534622544369899, 1, 0.23366764770262935`], 
        Hue[0.10834460042460292`, 1, 0.8499843994120884], 
        Hue[0.1999521802171107, 1, 0.7231431350840006], 
        Hue[0.30286961558245495`, 1, 0.5806420707319855], 
        Hue[0.5502609097025113, 1, 0.23810027887344595`], 
        Hue[0.47725711309755225`, 1, 0.3391824587880046], 
        Hue[0.08843114950821707, 1, 0.8775568699116993], 
        Hue[0.02326999810538999, 1, 0.9677800026233062], 
        Hue[0.18314986366475428`, 1, 0.746407881079571], 
        Hue[0.2895457774073478, 1, 0.5990904620513645], 
        Hue[0.3911136684189974, 1, 0.4584579975736959], 
        Hue[0.553975981699494, 1, 0.23295633303146987`], 
        Hue[0.4836291928262172, 1, 0.33035957916369935`], 
        Hue[0.40076216581331864`, 1, 0.4450985396430973], 
        Hue[0.10861104359249618`, 1, 0.8496154781026977], 
        Hue[0.045823797191262394`, 1, 0.9365516654274828], 
        Hue[0.023269998105389544`, 1, 0.9677800026233068], 
        Hue[0.19980207471950773`, 1, 0.723350973465297], 
        Hue[0.3022320270374816, 1, 0.5815248856404102], 
        Hue[0.4000489724338486, 1, 0.44608603816851733`], 
        Hue[0.4830746978240669, 1, 0.33112734147436895`], 
        Hue[0.5638867655424574, 1, 0.21923370924890512`], 
        Hue[0.5008325505517295, 1, 0.3065395453899131], 
        Hue[0.42654081381261244`, 1, 0.4094050270286905], 
        Hue[0.33893610786326583`, 1, 0.5307038506508628], 
        Hue[0.16486360880387757`, 1, 0.7717273108869387], 
        Hue[0.1086110435924964, 1, 0.8496154781026973], 
        Hue[0.08843114950821707, 1, 0.8775568699116995], 
        Hue[0.10834460042460226`, 1, 0.8499843994120891], 
        Hue[0.24658236972349423`, 1, 0.658578257305931], 
        Hue[0.3383793141606567, 1, 0.5314747957775523], 
        Hue[0.42604254035927824`, 1, 0.41009494411792247`], 
        Hue[0.500445083633796, 1, 0.3070760380455132], 
        Hue[0.5632871686543652, 1, 0.2200639203247251], 
        Hue[0.5953645965293008, 1, 0.1756490201901989], 
        Hue[0.33893610786326606`, 1, 0.5307038506508625], 
        Hue[0.39075023404397147`, 1, 0.45896121440065496`], 
        Hue[0.6106661374931279, 1, 0.1544622711633613], 
        Hue[0.5817027184239647, 1, 0.19456546679758735`], 
        Hue[0.42654081381261244`, 1, 0.4094050270286905], 
        Hue[0.4007621658133187, 1, 0.4450985396430972], 
        Hue[0.4637621616894646, 1, 0.3578677761222798], 
        Hue[0.5055680372000513, 1, 0.2999827177230059], 
        Hue[0.6236270389875472, 1, 0.13651640755570388`], 
        Hue[0.6042635988004508, 1, 0.16332732473783745`], 
        Hue[0.5817027184239646, 1, 0.19456546679758752`], 
        Hue[0.5008325505517291, 1, 0.30653954538991346`], 
        Hue[0.4836291928262169, 1, 0.33035957916369973`], 
        Hue[0.4772571130975518, 1, 0.33918245878800524`], 
        Hue[0.525714924832986, 1, 0.2720870271543271], 
        Hue[0.5536715534113947, 1, 0.23337784912268422`], 
        Hue[0.5804419605717945, 1, 0.19631113151597676`], 
        Hue[0.6348006587199928, 1, 0.12104524177231768`], 
        Hue[0.6236270389875473, 1, 0.13651640755570377`], 
        Hue[0.610666137493128, 1, 0.1544622711633612], 
        Hue[0.5953645965293008, 1, 0.17564902019019882`], 
        Hue[0.5638867655424575, 1, 0.21923370924890503`], 
        Hue[0.5539759816994941, 1, 0.23295633303146976`], 
        Hue[0.5502609097025114, 1, 0.23810027887344573`], 
        Hue[0.55346225443699, 1, 0.23366764770262918`], 
        Hue[0.5781969724586531, 1, 0.1994195765957112], 
        Hue[0.5942753953788705, 1, 0.17715714486002548`], 
        Hue[0.6096877329029456, 1, 0.1558169852113061], 
        Hue[0.6228630326504282, 1, 0.1375742624840226]},
      VertexNormals->CompressedData["
1:eJw8XHlcT90TLqFIC5FSthKVSNm3jkJCe7K1klakfU/7Xlq176FIaRHqVSdl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       "]],
     Axes->True,
     BoxRatios->{1, 1, 0.4},
     DisplayFunction->((Print[#]; #)& ),
     FormatType->OutputForm,
     Lighting->"Neutral",
     Method->{"RotationControl" -> "Globe"},
     PlotLabel->"Surface Intensity",
     PlotRange->All,
     PlotRangePadding->{Automatic, Automatic, Automatic}]}], ",", 
   RowBox[{"ComponentNumber", "\[Rule]", "1.`"}], ",", 
   RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
   RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
   RowBox[{"SmoothKernelSize", "\[Rule]", "0.561663950801882`"}], ",", 
   RowBox[{"RayBoundary", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "12.510426233341068`"}], ",", "12.510426233341068`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "12.510426233341068`"}], ",", "12.510426233341068`"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"NumberOfRays", "\[Rule]", "4096"}], ",", 
   RowBox[{"Full3D", "\[Rule]", "True"}], ",", 
   RowBox[{"Energy", "\[Rule]", "100.`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5633675754182577`*^9, 3.56608703111974*^9, 
  3.5661018055620947`*^9, 3.5661392496808023`*^9, 3.614707843424522*^9},
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->"Out[64]=",ExpressionUUID->"1c035b97-c43f-4851-8b25-054d8a319820"]
}, Open  ]],

Cell[TextData[{
 "Note that since we specified ",
 StyleBox["NumberOfRays -> 64", "Input"],
 " with ",
 StyleBox["FullForm -> True", "Input"],
 " in the ",
 StyleBox["GaussianBeam", "Input"],
 ", there have been, in fact, ",
 Cell[BoxData[
  SuperscriptBox["64", "2"]],ExpressionUUID->
  "a21a0b35-1312-4840-b6aa-b9513e90132c"],
 " = 4096 rays created. This was the result of ",
 StyleBox["FullForm -> True", "Input"],
 ". If  ",
 StyleBox["FullForm -> False", "Input"],
 " has been used instead, then only 64 rays would have been generated in \
total. In general, you are free to choose the number of rays to be traced \
with ",
 StyleBox["FindIntensity", "Input"],
 ". Bear in mind, however, that there needs to be a sufficient number of ray \
samples to make the ",
 StyleBox["FindIntensity", "Input"],
 " result meaningful. As a rule of thumb, ",
 StyleBox["NumberOfRays -> 64", "Input"],
 " is the minimum value required for reasonable full-surface calculations (to \
produce 4096 rays) and ",
 StyleBox["NumberOfRays -> 256", "Input"],
 " is the minimum required for light-sheet ray-traces (to produce 256 rays)."
}], "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"61fe767f-feb3-477a-a22f-08ad310cb74c"],

Cell[TextData[{
 "You can use ",
 StyleBox["Options[FindIntensity]", "Input"],
 " to observe its default option settings."
}], "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"9f08fe51-ea3c-4aaa-9cef-8c9e59b7d550"],

Cell[CellGroupData[{

Cell[TextData[{
 "Options[",
 StyleBox["FindIntensity", "Input"],
 "]"
}], "Input",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->"In[65]:=",ExpressionUUID->"6c99f091-180f-479e-a164-578479e304a5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"KernelScale", "\[Rule]", "Relative"}], ",", 
   RowBox[{"SmoothKernelSize", "\[Rule]", "1"}], ",", 
   RowBox[{"SmoothKernelRange", "\[Rule]", "4"}], ",", 
   RowBox[{"IntensitySetting", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Energy", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"IntensityScale", "\[Rule]", "1"}], ",", 
   RowBox[{"Print", "\[Rule]", "True"}], ",", 
   RowBox[{"Show", "\[Rule]", "True"}], ",", 
   RowBox[{"ReportedSurfaces", "\[Rule]", "Last"}], ",", 
   RowBox[{"SequentialTrace", "\[Rule]", "False"}], ",", 
   RowBox[{"GenerationLimit", "\[Rule]", "200"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"PlotDomain", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "30"}], ",", 
   RowBox[{"Plot2D", "\[Rule]", "ContourPlot"}], ",", 
   RowBox[{"ContourLines", "\[Rule]", "False"}], ",", 
   RowBox[{"Contours", "\[Rule]", "50"}], ",", 
   RowBox[{"Full3D", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Hue", "[", 
       RowBox[{
        RowBox[{"0.65`", "\[VeryThinSpace]", "-", 
         RowBox[{"Intensity", " ", "0.65`"}]}], ",", "1", ",", 
        RowBox[{
         RowBox[{"Intensity", " ", "0.9`"}], "+", "0.1`"}]}], "]"}], "&"}], 
     ")"}]}], ",", 
   RowBox[{"FilterTrace", "\[Rule]", "True"}], ",", 
   RowBox[{"ScoutTrace", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ScoutRays", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ThresholdIntensity", "\[Rule]", "0.001`"}], ",", 
   RowBox[{"CosineCompensation", "\[Rule]", "True"}], ",", 
   RowBox[{"SequentialRead", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"InterpolatingFunction", "\[Rule]", "False"}], ",", 
   RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
   RowBox[{"SampleFactor", "\[Rule]", "2"}], ",", 
   RowBox[{"RecenterData", "\[Rule]", "False"}], ",", 
   RowBox[{"InterceptHole", "\[Rule]", "False"}], ",", 
   RowBox[{"RunningCommentary", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5633675756055*^9, 3.566087031369728*^9, 
  3.566101805755084*^9, 3.566139250208363*^9, 3.614707843794819*^9},
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->"Out[65]=",ExpressionUUID->"af9e7bec-c4e9-4c06-977f-2f278dbbb732"]
}, Open  ]],

Cell[TextData[{
 "Here we can see that ",
 StyleBox["FindIntensity", "Input"],
 " uses a number of options that we have not encountered before. The most \
significant of these are listed below."
}], "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"cc3b45c7-e4f3-4e3c-b46f-6d6e177fe337"],

Cell[BoxData[
 TagBox[GridBox[{
    {"IntensitySetting", "Print"},
    {"SequentialRead", "ReportedSurfaces"},
    {"IntensityScale", "Show"},
    {"KernelScale", "SmoothKernelRange"},
    {"Plot2D", "SmoothKernelSize"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "FramedBox",
 TextAlignment->Center,
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->
  "Out[12]//TableForm=",ExpressionUUID->"46cb697f-b80f-4d01-bd6c-\
4876a42ca360"],

Cell[TextData[{
 "Options that help characterize ",
 StyleBox["FindIntensity", "Input",
  FontSlant->"Plain"],
 "."
}], "Commentary",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"c67f89f6-560d-495a-8599-39f4b27400df"],

Cell["\<\
While some of these options will be considered further in this section, \
others will be left to discussion elsewhere.\
\>", "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"e5a6054d-dd48-4061-bcbb-f0b7a1201f9a"],

Cell[TextData[{
 "In addition to showing information as a three-dimensional plot, the ",
 StyleBox["Plot2D", "Input"],
 " option in ",
 StyleBox["FindIntensity", "Input"],
 " has several other settings. Its settings are shown below. "
}], "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"acbccdd9-b6e4-4445-8c63-5d21e8a43520"],

Cell[TextData[{
 StyleBox["False", "Input"],
 " or ",
 StyleBox["Full3D", "Input"],
 " gives the full three-dimensional rendering of the intensity profile.\n",
 StyleBox["True", "Input"],
 " or ",
 StyleBox["SideView", "Input"],
 " gives a two-dimensional cross-section rendering at the x-z plane of the \
intensity profile.\n",
 StyleBox["FrontView", "Input"],
 " gives a two-dimensional cross-section rendering at the y-z plane of the \
intensity profile.\n",
 StyleBox["ContourPlot", "Input"],
 " gives a contour plot of the intensity profile."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f"],

Cell[TextData[{
 "Settings of ",
 StyleBox["Plot2D", "Input",
  FontSlant->"Plain"],
 "."
}], "Commentary",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"7831497e-8aba-4284-b96e-49915e0b2651"],

Cell[TextData[{
 "Next we shall plot the same ",
 StyleBox["FindIntensity", "Input"],
 " calculation with its default plot setting (",
 StyleBox["Plot2D -> ContourPlot", "Input"],
 "). This time we call ",
 StyleBox["FindIntensity", "Input"],
 " with the previous results stored in ",
 StyleBox["intensityresult", "Input"],
 ". This saves us from having to rerun the ray trace and intensity \
calibration. We will use ",
 StyleBox["Print -> False", "Input"],
 " to switch off the printed messages. (",
 StyleBox["Show -> False", "Input"],
 " can be used to switch off the graphical rendering.)"
}], "Text",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", 
   "RG17.1"},ExpressionUUID->"b637b49d-dc30-4a08-809d-bb46795dbf59"],

Cell[CellGroupData[{

Cell["FindIntensity[intensityresult, Print -> False];", "Input",
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->"In[66]:=",ExpressionUUID->"1b065470-deed-4044-8680-13146f928883"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJyE3Xvwr1lW1/fh2BmYY0vO9JzpGdsenDndc7qng4qooBPCdOFg0AISGYxI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   "], {
    {Hue[0.65, 1, 0.1], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgl0VUW2hg9cjExOODEJiiBJEy5DLvhAwhOkhU7giah5KhASAslhFoEL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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHl01dURxwceexBqAElYgmxiBEIgL/RogQJC4RhoAS0tAoGXl+UBsgTI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        "]]}]}, 
    {Hue[0.6310297726243713, 1, 0.12626646867394736`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXl8VOXVx69ggwoqBoGwqCgEkjoZMAzYlgQJgiIJLqhRqkRmgszEqpAA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        "]], PolygonBox[CompressedData["
1:eJwtmneA1MUVx4ciXWNQmhwcUg9cLhHvsMAdHGIE7hBFODVywO7C7qIiHgcL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        "]], 
       PolygonBox[CompressedData["
1:eJwtlFlsjGEUho8WCRFLJSRiiZC4kVHtf+Witia2EJQgMaWG6ah2uqChaqkl
SKqCkhqk9kHv7C5aVAWJNhXVvegSWzfpUKa0PCfff/Hm+//3O+c977ecb+KG
5OXeEBFZDQaAx+tFisDkSJG68SIpbpEhHpGtE0Q+WCLb4kS2g5JYEddYkWeM
haAIDCevGG4Y4yAwGOwiNgN81Fw0hqMVg2Y52g0RIn5iboAPLpFQOMd0kQq0
3oEyp0gp2EZOHrnpjBfRygdd6O2Dmwd3idg11L3IeA6cB5noNY0T8YSLnOb/
DGggbwHcbwdANwjq4etAOHUHUP8LeVeJuwJ+UGM/NRZTYxKenzJ/Fs+H8XsE
bFXf1E1jTARJoAmtRLhGW1f1n1LnCXCjcwI9D+MF6rTi5Tr+bhFTYK9Z1z4N
L/2p1UzMR3wsJC6I5140+oAP7izowN8e9KLQCwWpfNfBJTOXAgL4CSG3i7ED
dIIA+V0gj/irxPsYe+PJ4buG3ATytoB44AaVcInMBYh5Tl4JSCDnFFwi4232
pR2vPu7LV/S/2dDvc3AdzN11m/uh96Sd9Xbj6SFre4XWS+BF5zR6KR7jUb2e
J7eT3AfkHiNvBXuazXgEHAVDN4qMYH4He9XFf0D3jry3IJbcFuZOkPsL30lo
V1lmPbquEmK69e7ad13vfDi1dxHXStwxYnLijKZq76RGGHph1CyEn4P/Doe5
m3pHi+HmwnXCveW/wmk8qleL9VYxF+My91LvZwJcC1yWy9wZvTsx3Kv71Ojb
JHIHvZnMf3OYe6P3R89Ez6Yaf158BllXCFr9gB/vBXA3Gb38J4G+aSKv0Yik
xgvyovn+jl4NWrVOcz/0ntSil0LuP/SWEPuOuAj8HUDjIKhlD3vwVc6e/sVn
r92v2rfv8fyGuVXEHOc/R88c7hncVLga9Oej1+0wdy5g95z2Xj5e/dS9xFhB
3DzifhLXxly707wx+ta8x18acQM9xo/6isRfJfFLXaavtb83wzXD7YHr4T8I
Mji3kXgZzbml8b+YM0+198dr95z2np/cNnLzXaa/tM+uUO8mda8xZrOWJnTW
sgelrLEMjILfznyjZd43fefc8JvAcvbgHvFBzvIGvB90E3eQ+BjyPqP/CWTr
ewaXwxgN9vLdaZne1h7XfdD9OMncZeZyPaa2enDipZkaOXjLJfYUaCM3kzhL
+4mYL6w31z4XPZ9V8IeY/2UZT+qtGv4PcVV272gPLSIuS3veMm+tvrl67nr+
b6j7h7r11H0EP5t9a3OYPtZ+boZbBNfjMHdT7+h9uFlwrQ7zfug7ou+nvqM+
9qoYvSnoZRG3DzRRN536Yzyml7SnMvj2wWUyLgMH+P5pmXda3+s8zjgKnSLO
fMU6kZVgBnG7iWu3zP7oPv0H2weWwg==
        "]]}]}, 
    {Hue[0.6183824904462961, 1, 0.1437780901512823], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgl01dW1xg+gaAUcUhUcMFGmBmJSIFGQoAQBhYAySBAkITeR5EaRcBNC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        "]], PolygonBox[CompressedData["
1:eJwtmgucjtX2xzej6V8m12ISUW5nNEyYyW1GxqGEyhCiRt4Z3nn9j9vcjGsX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        "]], PolygonBox[CompressedData["
1:eJwtkc8rw3EYx9/fyQG5cHHwa04sfcvaUaEQzcWWSdls2pADCdnmNCk2haNM
E3+DsqOcHZy5UH4sRySN8Pr0dXj1efp8nud5P+/P455eDCy4JDVAJbiikgU1
XinXLK0mpNY5aa1FevBJmZi0Aach6QQKnRKpCnXAlDQGF11SD7X5uHQblm4g
Q48jemxyLnmkYUv67KfvhJSECHVhuKS2l9pjassBqZvh3Lb0RfwNFjkrjQhy
liPcQ5Z5tuGJ+ZJotKFxj+YdbBEXuMtx1qNTB1F0bfT9zLGOhzQ8+qVgBfXE
83iaJH7j7pweRfghxqJifdIvsUakPTR34QXdNBoeNBLMtc988X8/xtc1OYNN
0js+nulVgnxQOoTikDSOxwPiD/76DO+jfOgMO5g1e4BqqOVuh7cUOcuQJa7y
OrsyO7tCYwCNV9vxbfy3M0+KuUo+53/MP/0B4wZfeg==
        "]]}]}, 
    {Hue[0.6057352082682209, 1, 0.16128971162861722`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgl4FcTVhkcQkMVK1F8pSQhYQAIkgSZhDWqCKCViZQtgvcF7A8kNoGQh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        "]], PolygonBox[CompressedData["
1:eJwtmgucz1X6x49kSqNlsJEZBg0ZxgyZcR2VS5JRuY5LZpjfjLlgmZ9hdP1v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        "]], PolygonBox[CompressedData["
1:eJwtk8tPk1EQxQ+vP0BjjCYqEnxES1qNqBhXJizUVqMFakgsQluLtUnpQwGX
PmAhJmo0UGN8Et2xdWPcaCIuRDdK1JXFZyILmqDR8qi/yWVxMvebO3fmzJn5
6iI9wVSlpG2gBnTtkL6vk/Jx6X2nNAlOdkkxcKVbOlArjTZKQx3SZXAsKn1Y
K+0kwXbwjrMf33nuLoC35PtHvknylcg1By5xfxHUJqWjddJ6bBH/DHhK3Azx
d3jX4pWC4LaHN5ul8FkpAY9T4CpcDsLlcaPLabnLoIb6i52uoTecm6jTA480
iOMr4OvHd4Pvm+AudYrUexZ39Y3HrRbp/ko0wDZRfw84lJW6N0oB7BTfX0CF
D47kK8LneVh6EXY5LXfetFkjjWCvw/UaEG8Pk6MCG4tIUZDeIu3dJN3LSX37
pF6w6KfWcuIC9EfuR+Ar76P0O0G/50LUXUUf2HFiX4EquLTB5Q+xL+ExDn7S
yw8wbXpw9wvrIS7NOUHtMjGC31SKOdSjDbYPHfqBl7gscWniqoipBg/J/QAU
4BKBy2vbA3h74X+cPua5WwDzGfSiz3LGzcpmtmG/VA9KQTRA2wVsAQ0/g9MN
0jK0erLE2/jP8SZE/Wp4BM4wH2p4tkrDzG4ErGiXxlaza/hizexos5uxzXoX
9xO8LfN2NzP/yLk96vZ1aGkvbT8HQZC6Ax1uz23fh+n9G/twgr1oZU5J+mjL
uhnYLEbRPIn2IfodYFaD4C99+okrZdx/Yv+L7YLtxCznVupX+pyGpmUOTXP4
fD6nv80hhS+DrwHfEeolyBfMOr1N9zx8puE1Fncztdn+pudZkEGDT2jRiyb/
AXVNyjs=
        "]]}]}, 
    {Hue[0.5930879260901457, 1, 0.17880133310595214`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmnl4ltW1xY8MAUUQgreigSYMYZBAgCRYNKnEoIAJKggEJV8kQQlBKvkS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        "]], PolygonBox[CompressedData["
1:eJwtmndc13Uexz+p4EDLUW4FByouSEAT4RQ1F+5TQQVEUBAc8AON6tS7XKlp
7plaV5p7dZp73iPNOsudqytXniv1EtGyvOfr3t8/XvX58f3M9/v9eY/Xx1qp
2b1HFXHOdeU/xfj//LbOvfuic/cqO3c6xLlrGc7tDXAu2d+54xHO7Yl1rhLf
y/BtV75zJcGqBs4NLO7crUznFvL7Ib9/LOXcJzn8pv/zMs61r+fcXxjzQ1Pn
UoOdSwNtc51LaMTv+s7dr+5cEN9OsN63oBXfokHXxs4VVHOudnn2FcffU52L
AtEgBnwb6lwTNp7I+gvY+4pIxgQ5FwfGs5+pjJkYYHMsSnJuLd8T+BYPZvD9
AX+7D7ozVw9wjj2cBTvecG4nqJboXFXGji3nXK0uzuWx3rOiNsdMxh/kvGfZ
2wPWCItx7tUYa/tXcG46+++Y7dyEOs7t9mP9cOe+Yj9d6d8H+f4ajXxZ+ypo
wdqvgb7MXx353g5EH8x/Ktm5k+A8uACahzmXxHm/4LxD2iFT1viY+W6zZv0Y
O7PO3g18yFlrgPnoo2Vpzs73IvTvgex7oc9V6HMaa9dgfB7jp9I+mObcAXAI
HAb3hiET9nKEMzdhbxXYY3nwMngFBIFAUAvUBn4xplvpuDVrvTnYuXywGp2u
AZNoTwQ7ae8CNVlzJfJdBQJpX0ffuaXNpkog213YzyvIIw955cl+kMG/wc/s
7T5oyppNQCgIAwP+5NwSxpeo5dzi5siqh3MpLzvX5SXOH2Y2p/314swn0cVF
dH0B7EfXB8DeFtY/jv6Z7dERe30KpuWhT9C+q3NzndnYX5H1oizntrK//ehj
HusdGGay/gj51kT27zF2OjjMWf8JvuOM50BV9loN/MaafehfSP+R9G/BHDOZ
axJ/68Dct+l7C7Sjb3uwk/l3BJpOpdvv+XYZNOBbCDjE9/18342+iqGv/vxt
RA32xP1byv5/Zb2ljB3HGb5A1tfHOPcT968o928l80Qhn5ZgNnueA2ZwpyZy
vnbYc3g359ahE4ceJmMvm3zImTUecL8zkWdRZFOYjg2w/n3svSzj+6C/a2XM
3sf2c+4FZHaCvd2kTxHa87lTm7lbXdD/DXzB18joKxDJHprnmk+Rb1mKvO9k
mk+Qb/genf0bTGcvCfXMRmQrjULNVmWzPyOL+ezxcV3nRrPf2bQ7MEdQkMkg
C/kVYkuPwfIm+A5wgjtVwHp53LGh2MtV+jegPY8x12i3YMwl5s7hPOs5T50h
2D2oC4LBqaZ23t7YWCn2+Zp05PXfQP8kZH4Tef9An2P0zY81+YVxhuQQO7PO
folvl0FGe7Nd2aRsM4H+1+nfj/nGM9/4RJPdNvztjTboEn1NZf+x7PkpsljJ
+oH8ns1+xjNvFfpXof9X+KRBrZyL4EyYhXuJ80XSfof5H5UxexnJfmagnyvM
vbMS96evc2fY02nwD+xoGwjFx3dkvtvouyntdxlfwPgoxi9j4kvMuZX5ZzL/
Zdp/4ftDvjfj+2y+X2lq5xnK/jqyv7v0+SDIYpBi0Qvc0QvYxwrFAGT3iDv/
CygAj0EQNjcJ2/uS+7OIuSsmWd/y6PsV2sGMOUNs+4i/7cPWb2eaLQ1k/uXI
5yZrbKI9k/2c4LzF0GFR4Af8QXqY2YJs4i3Wm5vCvQDNsPNw8KnWCzCd/sT8
M7kft7CtLaw5gbNN9eQxnD2WRRfx9D+mvWCTK/D/4zx5/P/+KHbx/Q/O2445
42i/z13YGGD++tMIswnZxiFkfxicpM8JUJZ7Xg40jDFdzwLjkOdSbHsJ6DKa
+UDKIPQOPuVsq8GXzBVb1HzADfbfE59zLshiag/a9dD/X9lPCfYbhX4vYD/7
sIVA/NN52ku4U7/yLZT9vc5ZdiOTjtjLPuxhOfEunzudy9wpsinWWtPXbEk6
lW57ssckf8sxetFehM9YCE5x7tMgaoyNv1ITH8zcdTnrb4yvz/p1aPfmLL1A
AugPgsZYPnG7LHbXiXicgEyrAOLBA3zreOYeB7Yw91YQh32U5/z/RSeXGDsX
nbQPsJj4qs9irmLvJHzD5CZ2x3TXznG+67RPcQdncBdrI7MR6G8fNv3E33z6
ftpnkFF+NbNBf9b6nP5v0v8WPqEt/ffQJ6mezaG5KieZrU5FpgnsxbGHg5y3
Onvqz+8IZBSeazFFsWUv9jYp2O7wHtpJbUzWf69InyjzkfKVX2ArR8Ak+nzD
3V/EfibSPs+378AexT4QHGr3X/bqx906hUx6B5jMT9M+E2exU/6nRIzFCMWK
48jyG3Clkdm+fMIc+ndnr8OCTcf/wn6DkizW/0Kf4pz3e+7jrCDzUfJV7bqT
O75o9+0h+mqHDX7D9yn8bk37bLbZlnzYOdqbO5mupXPlkvM5y4YyloMu4HxF
M03W/0HHfTjbDNa/x9gS/J4UZzZ2yss5T3hnOO7FIMWiFfiEpcj2Y+kHITdT
Tkn7CuNfzbSYrti+HxwAc9BXAbqLRUY7mH+XF6/3gVqRZoOyRZ0xjVhTBhlH
YSt/Rz6BfH/M9wIwAF8zEFTB5iuDqqAamIHveQ/4cU5/cGco5wd3wT2wkLF+
tSwnuYtvy6JvJriL7d4Dr3KHn6H/U8gwjPY29lsO/TTjPDPZbxLyOV7N7kQU
9hr4Gr6e2DORGPSYWDQWebyOvbZjz5/xvT3j/6hkNvIh9lmip/W/wveXWjs3
mPlOMl9fvqfQnsb4PzuT4c48i8mKzZLZXNqHmKOQ9l3GTKd/OeynLPBhY7lg
MmeZ5MlAsliFzFeC8vSp4EFtxSjFqkq0K+ZaDqpctDtzHmbuO9hfS/Zfkm+9
gi0n/5Lzb2QPJfndHH1soP0k2mK5YnrfWMvZlcvodzy/C6NtfE/gx1yl0FFJ
EABKp1uMV6xvyferzLcZX5JIrnUMGQ4ebT5TvlNnXsD3RSAY2T/h92LaEd0s
91JMV2zfxZ15m/VRhRuHLOfEmC+Uj8hBns1zrFbZio86RHwv19p08R3rvcF6
YZ4/lI3IVqKwuV2s/xt7fIytzmQ/T8pYzqLcZUm41S75zLe9s+U0kkd3vi/N
MJuSbVXn7tVoZDWear3x5JzvEI8+bMgdamgxVbG1tCebbHSXk2I2LduWTqVb
zaG5ZPOy/ZqMqQGqgmqgS0OTnWTYt4nlAMoFVBOoNvBjTDHwAiiSbjJWf9lv
IUK7P4K8cITlEMollBMr15HPm8jZT8azDvI5i3wfIu8PkEHV4lZjjeW+H/Pq
N+lculeOo1xnFOdN5byLPXmp5uuUbTm7cvc6+Na64PkbVnvKp/xBu9Zw5FnL
arrx1C4L2duCEVaDqRbz93KR+5ztATg7ErseaTYmWwv2cs9nfPsdHEXnU7CF
HtjPWmxhXY61b6K/U8SiW2EmC91R3dXzrFGkptlHLrJdo5yeswVzxumcdZ3P
fIPuxHraXVkzDnQD3UE77lQk9lOc76v5/jb6R43/j3FrkM3BpvZNc2ruTdiv
r7L5gB3Iezb2W6We1YCqBR8Ns1z5KGv+QrsiMr5dyvpkM9+WflYLymY30y4b
bVzDemx+JWf9ht/lWasM9rGV+fzR2cmidmeK0y5ob+eXTciWVPOo9nmNMdej
LSYpNp0mnpwcYzWmas074G6a1ZSqLX9WPYqtfAuqYC8/c56bnP1zZLYcf9aB
/S2PsBxMuVhZvoXEWI6vXD8BeymCXWSHmP0oR5yCPC5mWq6smHgT26vC+Mq5
xkmIm9ikfDDD/qZv2oP2Ips9QfsfMVb/bGP9bbQXcKZN6H8jiED+9f9kteVs
1vw9z3IC5Qaq+VT7zcu03LgRNr+B9Qdjzyv9LKdbgr47KB+paz5/ULTVAKoF
5KPlq2vQri5b52zB4EiMxcob7Oco7ZGptjftsTHxeAA1zWLk+RPymIF8Nw+3
36p5hqKrCanmS1QzlsK+M7x8fD591tK3aajZiub0pVrMUOxQjH8vyWKOYo/2
3NFnHJK4JMWkVvj/NbKR6uZzk/m9it/FqpsOpctCn9lST+Z/THsnPmcH+Anb
uQkmoIu2+MKOfE/kLrQmni8rbxyZuLIh6DctxDgScSXKObd4OpQulYMoF5GO
Ipn/ITY8nvZe7KE6438np30G/LhU/inGmYg72Qa2Z1iNo1pHY/7L2E6ZlouK
oxJXpTusu6yafS35UFV0UwVUYi+VPc5G3I04BHEJ0pF0pTO04SxB4ZZfKZ9c
xqUNxzedQ/aF6GQP+jqpmhk4fPYLoIXHT8mn1UY/q3yWW8tHrPQZB7Tai9mK
3eLYxLUpRitWp7PPoSHG6YjbCeJbIAinHQF+GWy50i7OVyTUaiDVQsqJlRvf
9e6qfKh8qTgdcTshfGuYaxyRuCJxbuLelPMq963Bt5qq15F5NcV+5BnOfudH
W1s5Qzf6F+ZY7jCBvz3JsZiu2C4beIfzNPbyK9WAe/DFz3xWu4lzK8r8O/Av
x/wth1rL/fvRZ76iOd+v0D4Vb9yeOKzTtCeR000Ek8EUsDfNZC8d7GthNiHb
kA6kiyz6ZILhYARYzx1uyHyR2ONcbKNblsU21Xjds8znyff1Q9+X4ywmKzYr
hiqWNmbPjXKNIxNX1t+rtXQHdBe2e7YYSJ8g0CLTuISr6Ke5fG9Ty40UL5Vr
zSZWzQJzwFywDqwF68GGIeaj5Ks2g4XRNqfmVo2iWkU6kq5Uw6mWk06lW3GK
4ha3D2StcuavttGeFmO1qmJiSp7VLKpdxDkMQNclxRnWMD4iBbtLYs1A7lMd
8dV5ximLWz7CmMbxJnPJXvxgFv5pUoTliuKYxTXPyrRaoQJ34P1M40jFlYrz
E/e3KMbmVo6dyO9Rkcb9ifPtQv9U9jA4xDhWca0Vsc1XQBnaL4ISEca1iJMR
NzMn2riCr8UhyTdHG5d7lt+zfFYjqFZoxd2MBrfEgdQ3n/ZZknFyymeV06xn
7vaxNlac2TzGfx5iZxcnK262gPkfgd+V94M22NDxIOMIxRVeG8Xdr2MxY1C4
1Wyq3dQnNss4K8lfNeRR1pvZxWL3c8bsa2UcprhMxRDFkhNjLBaLMxF3si3J
+JCOjN9OOwIb/YL85UFt7u0oy0mUm6xUbQAuxhm3oPrz6wiTgWShHEa5zB6+
v17eZCLZiNMRtxMKwkAac6R6NZRqqWY+k7U4gnnIIcWLjzrzddZfM9xik2LU
omTbk/b2GT40kFr1eLxxxR9hAxXJTS+I41c+yd9uYAtXmxFP6dsTf/u8NzbS
ynLvt5DRzj7EnRAbK85K3NWhlja/ZNA83TgKcRXKuZV7iwOQ75YP38L6i7OM
G1TOskS6STduRRyLuJq6nWz9GpxnNHuv6vGFegPRW4g4a3HXiiGKJSu4I8tB
Fn8bDv6cbLa/nTv1NNVyUuWmyuGVy38CPgYtyWGjRlqOoFxBPl++f6HPah9x
SoeRb9FQ47Ll8wu538PokxFib0B6CxqH/D4sbzn6skirEVQrKMdXrq+cW7l3
G/rGphpHKK5QOWFL5g5kzmL8Lov/fhk/ViHD2luRh2tsOZJyJeVYo9FdSJTJ
RjKqh6zyYm1v2qNfqMlM3y8j0zxkO6y9+Qr5DMVOcXTi6nSndbeVcyv3Vo02
oonVaPqtnPwivn5QqtUWyhGVK4qjFld9hHFHG1pMln7F+SS2QXapJntxqOJS
Y7y3Mr0h6C3hP5H2NiVOpS36d8Tr1733pJas1weZVwgwDvIRsWz/GOOexPkd
oJ2cZ9y+OK1Bek/IsVgoGT6lXQv/NjnYOCmfYgLr7Q00DkRcSLZ8dbDpLJFv
g8BtfxuTy7fFsVbbaszBYcYxiGsQxxtIPlLWq2dVv4ibKJ5v3Lw4Zv9845DF
JQ9m/EV0uYczv4yvi2f899x1v0x7W1MMViyOy7TYKM4um718FWG+QpxVD+Yq
fMPeKlTTPKbdEVl2AJ1AZ1A8xtZTPOnP3t9NNu5qADKdTLtfmslWOVEksm7n
M+5XMUaxprnPYp1yDuUeo1jzaoDJKEc5TaTltqrJq3L+/flWS+gNSm9RelNQ
vaSaaiPt3fn2Nqs5NNc+ZLg70N5g9Ra7d5i9Telv+2nfSzH/opr1TopxWOKy
FPMV+6d4uUdpvpUBfXTH9U4J+oFEbGIg2IStbwbD2W+tIHtj0VtLfK69HavG
SqC9e5jlbrKHPbTXx9jd0ZvVYX4/zzHuUzWfar8GMfa2KR85VuOTLFeRT99F
e32Y3S+9j+itTxybuDZxauti7I1Lb13iWPdir5vzLVdXzr9F/GCq1WKqyd7P
M45QXKHO0JH9z4s1bkRvPnr76ezpXm/GejtO995nVLOoltEbgt4SOjH/b6z9
iVdfygZli5vyLdcT576RdlAniw3y4fLlX0fb25pi0mZsYzk+ctlIywGVC4bn
GLdTVPUC7RD8xaZ6xumI61ZNotpEOaBywYgc6ysOX1y+OHxx+Xqje4y+sthv
ZojZtGy7K4iTL+dvI0Ay8edYHYsBejtammW2rfU+yDKfKt+qOTSXOE9xn6qh
EhvbG5L4Fb1BJtDvdJ7VlkPQz5k84yzFXSrGKtbqDV5v8fW5aw3AygjLnxXz
D4lP7WzctfZ0Ohudsr/f61jOrdx7dLr5Xvlg+eoGURZL5a+DkfXBOMsdxBGI
K1BNodpCMUWxRW804r7FB01A9/PaWC6pGD+X9t8y7W1dPku+a4SXa6tGU612
KcN8j3yCfMMpjy/Xm7PexpXjPPf22yTH3kz19qM3oJLY3gL2Px/MZt9zwI/M
9wMIYGxp8A5r/Q2MBeOGWs2l2kscsLhgvSFpPr0pvsn+a3v2JRlIFoq5ir16
s9TbpTh+nVf8Qz3WT/beD5QP6O1FOYjGao4fyU0uZNvbh94QLmbbG6LeEpVz
70A334Ybtyyf8l261ZiqNVUDqxbWm59ybeXcAanmU+RbdCadTRyVuKrtrL+a
9dOS7S7pDXZwsuVkys3EgYkL65xlsVkxrFOWvWl96uUYyjVcvtmaaqB1kSYz
yW4EY0eOtJxaubVybuXe8gHyBZLfW7Hm4+TrCri7j8EHGcZ9igMVN6x/s6F/
u6EaVbVqbrz92xm94fvi7Q7pLslnynde81ks0pvhjWizcdl6nHf3xPHd996k
9TZdkGNcgGJyX/r7NTbZ6M1cb+fiuJTLi8M/zvfrkZZL6t+knM+0Gku1lt7I
9Fb2xGdchu7TU9rVu1huqTuku6ScQrmFajTVapKRZLXWq9U2eLWa3hD1lrgx
xf7tjt5f9PY2Lc24HPlDcTkp7Ywbk49qONpqLOlf9v428l3PmefWsDd8veUX
8bhb+Tz5vsPev0U5iCwOgTrJVltqzIZUy9GUq+nNR28//wMVwOgS
        "]], 
       PolygonBox[CompressedData["
1:eJwtkstLlGEUxh/vkPUfeMkRyWiheQXRhbtJzWI2hpdwZnAUR2dwUhe1E8Jq
NjWYouC4MZhC7D+QJmgRCjougkDRily40I0zoebl9/J+ix/vxznnfZ/nnPOV
+cKeULakSsiD5FPpC6z5pX/F0lG1FBuU2kulrIh00iyloYd8N7iCkqeM2gbp
ZotUCA+pC1RIDzg/9EvLsALHRdInTreTb+dc9Epx+IhmAlahl7oVzlu8NURd
J3V7eNiHJeJxmEb7L/6C+Av6pGE4GpJ+4LOmXvoc4C1wh6Wpcul/k7SB9jqk
4BSNzX6rbTzs8raXu9/r8DUutUEHHKKxgFaImlGYcWaRoG4E7QPyUb/1ZLzF
0PGg9ydELfrv4R2xt/Cb2G6J9ILYS8f/beaXZnYZqKxCh5iXXs778Axvnkmv
IQpd5EQuQzwNPXyPEHNxL5cZPWZWBRHr0/gdIB8mv8TdRYgbaqRveKg3vug/
ZvZTbfuc99sdmF18JZ6ESep2qK+oRQ9+8f0qYOdo5nnvvpRN7Cd3U9zbBhfz
X2NGSfZxio8ziMCYmTXz6yS3yvw26GEd8vD5BP0C+mjBv48+WjlnqZ+D/Crb
+5XX1pt7l2PSBeRQ94j6DP/ktrPXvgm8Qi90NbIH/s8Ec57H2wIU8l43791A
d4u3UnCn1u7mecD2bfo38zd7GHTmeJd711wKr9E=
        "]]}]}, 
    {Hue[0.5804406439120705, 1, 0.19631295458328707`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mgl4ldW1hjcig0yRoBAJCsisSMYDVpJCCIohAbwSgsI5gYYhJCiQhEAt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        "]], PolygonBox[CompressedData["
1:eJw1mnlA11W6xo8rpiKlXUMhwwUCQ1EBlxQVMU1BaVIwFVAxMcCFRXPK9M6U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        "]], PolygonBox[CompressedData["
1:eJwtk0tI1FEUxj8yhyIfWZrgY8zARW3GyakkihBt0cbIRCudcRx1MpPRJogi
KoI0KJGcFrZo24va5KKQolKHXosiXViEJRQWRaSLso3S73BdfNzzP/c7r++e
f3Gkqya2TFI5SAVZm6V+r9TbJqWHpQxwDHSD1Kj0kLtaONviUrhE2s450Cwl
wMt26XGKtNInvcJ+DTK4r4WXxRmHcxx0x6QusL6MOhSNYedxfwCel/MsnHPg
hF/KpJ6nVZoNSXOGUulfoTTaIo3wPQqyiakjNpfzJHGnQDp2mtWukPZ7pFXG
oe9h8qVF3Tw2VzW+IXy/mLeF71awtVPaAu5Sa2C5FMD+CO8tvGpib8C5Ccro
bwW+v/TymT6mwSJYAF56zubuNBw/tUP0F+C8TG99oICZY8w+Td5CbG/M+e1+
7LB0qEh6EnA5LfdvanjI5/e7+WzO2/D2wRsKOL1Mt/v4avE9wFfMOxxFq7oI
PQaledAD5wIYhlcPbxjeI3LuIHeCnmua0AvkEdtG7E5ifxD3E+Tgi+ArxfeF
76/gKjokTAt0SZLjOvOkgovYnWi6QK7FJrcftidvqBuk7gh1e4nrAX1gpkC6
tKS/vUMHmMLXznmNuEEwQWyI2CSxa+iliV420MsUfXwCXnzt+Pbgm+V7Luhm
sZkOgn7y1XN+Zy+/gRL4SfZ1xmzepoE32hR3+phOtm+2d/MgTuwfzudoVcls
99AqTK5mUGmx7NgL+qrC3g3OwFsHr6TV7YPthelgeniY6Rn5Upb+L/vPzqNV
H/wMtBun73cgizkamCfd57Q2zcvxteDLxXeFvbzDfmbuQlvsBHgPZxLkwwvC
W+1zPVqvt+ilghpjfvee9q5V8KLw8n1OQ9NyI74wvrX4BunnKTH5UfdW9mYT
zDIOPoAO5pgMOa1N873EHiG2iNhM0IidE3E9WW//AQLY334=
        "]]}]}, 
    {Hue[0.5677933617339952, 1, 0.21382457606062202`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgl41sW1xgdFQMKWgCQYBCKECAQCIQkqX6jIIiEBFEkCkg9SwpIQWb7E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        "]], 
       PolygonBox[CompressedData["
1:eJwtmnmAz9Xex4+97MQYd2wTYx3GMDMVM7ZBGMYSE8YWgxn7zBhaPKn7lIpU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        "]], PolygonBox[CompressedData["
1:eJwtkTsvg2EUx/9xiyAWi9Tl9YbExFu8mzCyYDC4NdqqRCvSVrr7GqRGmy5e
yqIJIakPQJsoFrG4xCBhM/g9eQy/nJNz/uc5l8dNZOczdZI6oRGGctJSk3Th
S8P4HkTWpBUoE4s5UjUptUWlViinpGtiN9hpNFNwiG6G2C66PMziF3ybM5rJ
tDQBOyPSS4M0jp+BLgZoH5Wy+NtQjEtf3dIJ9ggCOKVnlFgRG8AxlOAc3sPS
T490ti5tbUi1XskZI0ddCe6ZJW5m9e0+Zi8TN3kX3QP6NHV37HJZL3V4UgW/
Cknm+WXWxZiUwt+EPno68Ea+wrsf2OaEtMwMLZ69j7nTKrE0sUHP6k1d8L/T
M/ve0jdC3yfqHyGE7or+Nfx9+uRhDp3PffbMXdjvm/dew3Zvs/8A/9QPIVjg
/9ycvY25UQHdJ/oD6v4AqeVj4w==
        "]]}]}, 
    {Hue[0.55514607955592, 1, 0.23133619753795692`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgl0VtW5hreogBBBwlzUJJKQBDIAIlMSIAyKhCBq+AOERAhD8hOEhBBS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        "]], 
       PolygonBox[CompressedData["
1:eJw1mnd4lcW2xoeOhCIdBAwthBJIwISWgIYiLQFESCgJJbTsIJAQIcdyL4iA
WBHFQi+iohQpCoooIIgCCtI9Vo4PYEcU9dgez/295933jw/Wt2e+mTVrvatO
muRNHzKtdAhhDP+U5f+Pc0L4tlIIu+JDeHFmCCtmhTCiZQgdy4Tw9OQQ+o9i
7LoQBjcLYVHXENZNCaFitRDiK4YwtFMIE7NCSK8XwrSYELYPCGEQ70m838R7
Ju8PlYTwM99uYb8Hoe9oE0K30l4zjf1eHh/CpFIhjG0YwivQ77JnTmwIP8HP
T4y3yA2hMWu9w/s+3jPHhJDBs6d9CG/wjGJ+e+bXiQvhRFoIc3hv2Yg94H82
9N3st5u98qqwXzv2vz2Ef7YIocL1rM9+NTJCmFUDmvGqiSF8GP1+LDJYjywu
JYRwe+UQnuc9Bv6vYe+KPGV5yvHMbO31vmDO9LacPxJCq8YhrGR+cUoIp/km
vVUIbeDvGPTjveEb+bVvitxvQw7JIWSXRw6SH3uv5JsT8LOQNc6w1kze/2K8
U9UQhvCeBo+z4S8eeVUZjayzQziMvMdUCCERehFrlm1qmUq2FceG0PuaEOqV
43fo2Rle/wn4mTsjhNq838H7Vc7fnLXbtjd/5WuHsGow8k+w7PfXRYfDQvhP
N8vjGfj7N/zM7g5ueM9qwlywkZIOP1WMgYFg4X0wMJD1v2eN79HfGuY8wtzK
7HG8Zwh/3MT3zO/dHOwVhjAe/RxFngsYL4Ws2nKevpxlU/0Q2kEPR8aZpTxn
AnMvJcF7I+PnNeQxYDqyqc43YDqkhlCLM9fkqdYhhGt58ieF0Bn8XWV+BLoN
e/4JPj9APl/Ay238lhUdnwp9mjPex1kzkW9j5HtMGK9hfOYjm7eS/Z7JeYuy
rHPpPguZHEFWI1kjlvWusN4o6Iv8Nomxiay5hrU3scYx8Huc53x+CEvBQNNG
tkHZ4o6x/lY20xT8xvDNZeZ+C76z0dc38H8HsvuLMw+Et38jk5vh7Y5rQ3ig
D2eCn9I14ZP9EgtCWMb8Xsw/x/z/9A/hJex753U+8zJsJZ75b7N+N3h8CV7n
5xlrsfDTGX4+xsaeiPGZp3PexcisB7Jeg/wehT6U4f0OII8d4P5a7Lca8/fB
0y70/wB7bmDvP5D5a+inMut9Usm/LYW3xTyfVjKPy6HnF4Vwsor9y+vM7Rf1
R7F83wZ/tAn5Z8JLf/kg+GlRaF3K58RDd58KprCH0thA/IQQ9jJndj3LsBdn
fXa88ZTLGZ+DXsuTGH1fB70F/WAGIY7z3zTLMpAs+vLbPGTTA7wnYJ/fwe8C
eI3nt428H2H9M+jzOM870OPQaWvGVjL/OOMsHVZA38s33/BtKmfYiv7a9gih
Plg7zvvdyPKuDNPDsf+l6HsP+BjBej8izx+RZx1+21fGe3Zg/e1DsT1sNRN5
PnkDuMiy72jHmn9C7+gHRit5zg7mNuL7hjz1sJ36PN8zZwXy6QVenkA+e9J8
tjcbgKtc8yBeZBOnwOK5fO+/if0/hO6dZ/p9ePyI97uKrDudcR70btb7Gvor
njm8v4O/+Q+BKAH9bEE/vw+B9zpgD/x+hL0uAs9fYuu18ddNGD8bsW+UPcZi
j107ghnoBeD1FvC9nfMtLu0z6qyZrJHBMxo7GsOzA4zeB56WIL8S5Ncpqk9h
/BD8zkm2PsXjXPi7lG7/Owd9XYTeiA8vBa7H8M2nnOU+5jQt4/MshP4O+S1H
fj3gcTHyq4FMq/N8wNoneDbh/57E/63gySV+tkoxPg7xvM/4kpvsu+7kDMOw
92uZ3wff9wZnrAb9ZhS/i3jOQR/ARr+Av6fBSGqGbVq2vRR9NQa7V8Y71ilG
KVaNSLVsJINj+MpZEfN6gTVGwEsFzvBIc8dcxd6OrPkEa9dA5zs5/w9RfCxC
HsuQwxV4nl/PNvID9LPEiJ117dPl239GxlfjHY9Pg90JSfb9tWqx/0C+n4hO
4O8gNnoCWy2JGHviZ3iKY5Bi0R6+aQ1WlqXYPlbB053Mvb+//Yf2fI69u2ZY
FuJ3UKJjlmLXbORxDfI4x54l4K06630IfUF6iXX8m835csDvIM5ykt8uMtYu
xXR38LUNWZ/p6W8Ho5OqyPMC+OzI+V7lDBXx79vxTzXhZxj+59I0chrw9LJ8
1Dj8M8/FaR5rjo7ysM+2Kd7/A54v2O9KkmPfTuQTw9lvYPzDWMv4MLLP5Eyf
lfFvPzJ/XWvbxzTwu5DYWAWd3Yju1qHDluiyDDF0WUX7uNLQc0cip2scH+6F
rgem+jcxvhZjS32j8SATHu/Hv1Ya7NxGazTvHMLDfRzPtMYj0L/eiA0huyxk
UAldf8Se7ckteqK/TOTZnBxjZJzzm4bQZdtYXgfh9zT8PocNvQ2vZ9FPPrwv
j+afioGvsVbnZOP5Zuaswp+fn+Zc9AF8fCvkV445D0fxGs/3k1gvLsZrDmDs
/j4+q2JiY/ZuhI72oavL4K0ea6VnGEs9wdwSZL2e7w9E+ZnMep9OsywU30aw
38oOXu9XMDlkiDEtbCtnPAN9njO3B3tT0MmxYmx8kuO3ZJYDXX6SsSIZSBYJ
PWxLwrR8f72+9n3i780uIRTMsD/h6CECvbrQslCMPJZjHyRfpBzzFL4pFXyc
hp9jyH9VunMs2Vtd8HQKvNfmmzqc7W3ONBJfsLLQuZfWU+zdnGAsCpOyDeUk
yk0KON9g5QLZju2X5R+gWyC/+5Ffec68mv2a4Ovact7FzB8ALxU6OPdUDjp9
omOoYqnmfMvaZxKcD63lt1Lwn5Di/ZQTfcb4nVF+5dPPI6981mj1//lsB+cA
ygVOI9PRyDaB98bNnCMoV5gyybmccr4C6LHY67stnDNuxTfWAf8x2EZ/7Lku
9Cf5jl2KYTdy3kbs34D932fNccirSzS+K+bV53w1Ga/dwD51M/utAwOD+f4y
+r2MPSQORw71XTMdRheVsNfvgn16S3hpkuDcaDc2tA5/PzPR8foFZNoP2Wan
2L8LU0n4u/3tXJvJRmQrdxHT/tXQ+Fbut5oYWAl7rsmzCnuuw5nfjPrXiV2M
WWFXNvsLtlshwbXfQnzkQHzlEnxcK/QR0PGMYv/23zHOeAn5H0n1+61gZgt4
ebHAe/XBp+ZQC2zAR03j2/3IIA7eH2O8B/ngbvD9MPy8Ab8/w28Re3ZBPkNY
/0HWqwl+96P/D8iBBtdwzLjK+A7k+UqMa6RX8QUvgbGt5e2jt0B347dPqjtm
lVf+1db1yMvyIax3LNXrD2V8K/y+19O1q3R+FPpovvPd0eChYZ5zWNn6HPTd
i/h4M889zZzjbkO/LWaYF/HUEvpqlvMh2e9PWa5BVYv+hbxW4j+yuvvs0nk1
eNsz2rWK6rMpbZ1TKbf6imderjEgLPwi/cJ/RXKea9HfWPTXkfj4BPJIKWP/
+CT0demefyfn+47znc137imMnoS+hA7KKR/Hv7VHFy1vsO+UjczEtx3Jcmwp
x/hQ1avY9I/KLeD3G3TyGuf5u6Vz8HT2ejbLvuUH9qgCHneM93lUo22DPpLh
/Q6zXhf2uzXiWkg51CzWrxzxtzfz2y6wllTifEg5dyL0KvCfizwn8f065tYf
61ghf6lYm43ie2FLD4O3LOjkHp6vGngX/G4sdD9jCPLYDL32Vtf+OvMa6FoZ
jvXCUCL8nOJ89aL6WoX8/+xq3SsG9kHfxwc6VxFmhJ3xnL9rDce3POhNhd5L
GBOWYyc4V1VMVmxWjqBcQZgUNttk2FfKR7eGfgD8dilvHl4Fv89EfPZEMPM3
638G/q6HtwGc6VPotRHXjhpfGXGOoFxBMbrmjc6plYtKZ9LdoXaOT6rZMtDf
lYh7BWtZ45eIazDVYqqXmnOWv7H5xS2MgTvAwgn08QD8rmf+78y/kZrhah3X
F9vIr1t3d+6tb/TtGfxhQ94r8j6C94eRR2oUv+fIH/JV87P/KTBys/I/dDC2
gvf4lfVHjbF/n8v8CHifPdG1wXzeC6c6B1VuVxl+2jG/0hjXdqrx0hgfXuy9
5aPkq4qK7R/k0x7vZplKdjOYc6bYMVGxUZga3gv5z3QsVP66HjqLORWYO5c1
zmE786Ln02/ZjFWFh9iqrul6c5ZY9pgd55j9LXu9NtbxRz5vD/Tj+LcE8PMb
Oh2E730+6i/7sd5m1iuFvKpe7/7QnM7OgZULa80pM+wDJEvJ9KEJ7iFprr4J
vOfmObbKPyqX1RoaV09nCflf74GWvfCo3s0y1numqePzD8j6rRL74iaMj4ef
VSXu5yinfBA8Hcy3bxd+lWvIh8uXy16UO+6ipjnVxP2a6iOwlQL7gvnI/F3w
tLC/e4HK2ZW7v8N6B2JdT78geRQ4lgh/Gwq8htZSzFbs7ouN7m1gfpTrpjLn
SGP7HPm6vGT3Qu7CBi4rX8xx7q/zfA69IZrfS0Yv5LlnovlaszP7T8s2r1oz
rcDf6Nvq7D+x2GfQ+FHGuzO+Hp93GV+8nDPndLLMNL8G8ycX24Z0lo+Yn9rR
GBKW5oHP/viLYcV+F6YWgJ11SfZtrfE3I3tZJpKNalTVqt0KvPdGMPebavFo
v/G//SDoCPvNhb/9sg/mPtrbseYw6y2GfoGYMSSan0xi7RfznKsNhd+Xi+1T
ZB8T+H419OGZ7uUKA0egn4nyJx0ngb378TeXm7tmVi/kLHPOsvZJ5Dke/fRl
fH9z5+TKzZsXOd5pfjPo5eyR19g5j3KfFSWOfVWZfxH9rYqYF/l4+fqlvI9r
7JxRvbQzWe5t6LdlEdd88g8VeW/J+/wc5y6Sr2xXPSL1itST3AxWnor4e/Gw
Avqb0a6l5L/Ve6gY7X9RRoTy0J+Qc2691j0K9SoGDLMuXwHPLcHz9tHuHQkT
m5BVrRvtm1V/q/fcDZ43xzkn6pBJbI/i+yTy3Al+ujO+Jc75YTy54x8R+175
yA7otnKJe9Hy4fLlHxMTlpZ2jPgEulOG68MM9uwMPYP1rsS5J9qvnzEqrCrm
qhcxgvenou8beX+O5/Fof1a1evlo/i6fPA3/EDPTtZ7qGfU2Vw83VvXN83z7
dA/3Y/pyvlTONzXJ9bb22Mz48emuPdSjew9bWFJiXyt/EAM+lg13rFWPeC3z
f4u416zzX4Z+qodzE+2hvdQDFfZbM+cWxodF3KuRTWRFjGlhWzmOcp1mYCAW
WXVEZ7uJZauwh0Gx7k9PVC482bWqcrzd4ONAG/diVAPczdlbKmbXsL9XL69Z
iXNNxbRm8PtYb/cq1INviu9dnevcQjnbLbpLSDGv4k93BcKMsCMdxvd3Da5a
XBjYhL9/O9ofU4zbMMF3KrLHctIx9DzmPBnnnr7uDvKyXZs9xW/3MfZyFI+q
/9U7v9DBtZJq0m3Eo+bkO9c1M6br42j+p7N9heLFisGu4ZXrPMWaA9Pdo1Et
oZqitmrZbo4FPyLDauoHTnetpHylbKpjvuKVcthK8J+d5XxHMXA49OfF7uUp
hz5f7Jpcta9q4Lrws63QubtyOt1VqSbWuGr4WPZ/qdC1iMaV+z2JTBbGeA/l
VqrhVcsfZM6zafZJ8k3ySevSXMNKXpLhfORVusS1qHyCfEPHaD9T9V49sLaQ
NVvDey3mv4L/6ppprCt/Ua706ACPf8QeN6HvBTOsC/XE1YvfPsW9P9nE1u7u
YSg3Vc9ob1/3DNQ7UP6gXmKDNPev1OMoy37FyPvHOOOxYY5rOulDPbSfsM+v
JzqWK6Y/ja62o7PPy9snqHe0upVzH/lP1d6j09w7UY5UhvX3cp4HovWaapel
ye5N645vAvzcNsb5mDA5ZYx71hoP4GkE631f6FpEPf9/QU8oduxUfqxarN1w
19qqiVUbrwTvNZq4ZlXt+lgU/wN4r4+sWiknjt5vKLYPZb8yNdyjUa/mh46e
qzW19lnmJ8aZJ/F+EHseFe2XT4a/+CL3xhTPdFclHytfK58s39y/yFhRvJqY
5jsr+Qb5iDWTHTMVO1Xjr+U9Qj57oarPoLOo5te4YuxGxmvdblkqXteGjsly
ba0YqVjZNioP9eAud3QOrlxcd1K7kdfRHMfCEnj6krGnk22PbeH3VJHvoHQX
pTvTdyb7Dkp3UaqhDyT7jkBnlwwOTXbOqdxTGBVWJRON607hdca7DHX92xh5
dx3qGk21mnxePL7vEb6pDZZGwdMi6GHj0AnP6+y1J9l3tuJH90PHBxgTwoZq
pi28r8Sf3hfv/mdv4tGuUe5367dxfHu6yL5GOjwH/b/pvptVjtgC+yma6lpA
GJwL1o92s/9vq/oVe713hu82ZdPyhSUpHlPPXL3zNnm+i1HPXb13xVTFltlg
9FKxY4D0rfzgPfid3cp3Nfp+I+NxRc49hcnW0C8m+K5MPQT1Em4vtn/5VXcQ
0PFTfDf6J3tcD72zyL5DPmopvmhMK+cWqgEWMX9vgmO3eu7qvatHLFn9Sr7R
Y6hlpnfdaetue1+Ce4PqEekuYGOC7xJ0Pt09vQqGfm/mHlqtHN9xKvbqt9aF
7omqd6Qe0hXiw5ZuPo/uxHU3XhC9L1WMmIpvbhVxbiWf8p7q0zRjUXciuhup
W2Jb/hme6kBHov5XmOkOb6+2sqx1h6y7deV4wvc/kOfXqt3BwHfxvtM7ivwv
FRr76nGo19Eo3bVcPvJayf4fIs/urJ0AD/8s8p297u7121nwvCLLc+Xf1Ctq
w5wGNRxDH4L3/hnutak/obse9YDVC9Ydh+7Cvio0b+pBqxd9osh3+er3jhhn
HydfpzvYb6GPc76HWtjf6y50GTYdE/Vvq/BvW7v5LkF37rp7L53kekdz1jDe
vZ9tTzW2au2Cqa6FlX8tmeA7H939qObcC79z2K9vC9voK8iz9zj3hvQ3EQ8l
+2841C+UTL9Dtr91dK4inxUHHk8WWXbq2Z9HHoXZ9lWqcaZDl0l1LFfMSQaf
PxS6ttKZdbf7VpZzIfGwifENafYN8tGD5Itvc26rmkG1zaxi+1bZSAn01FzH
Sn1zG3TTHOeyytGUq+1ijbpxjuf3K573NLZ0BvUSGkb7s8pxlesmYf+5ce7P
7ebsp3va9hRvlYv+BH7XNDb+9LcMqqF0XsW8N4l9HQrcK1MNlS//ke3Yrnxz
VrZ7Hup9qOe7r43vWPWuHmFvcp+2Ba69VI+qF/Z2qvM71XiphfaZOmsndJiF
7IZlmZY/Vm6xMpov6swnkWW1XN/lyUYUCyYVu7ZUTqDcYAXrPRJjHS+HTirw
Xb/4Vy34XDv7ItmMbEd/w6B8awFzTipXTnc/TP1+3UWpB6FehP7G5F585YmI
5yq/1N+OqEepXqVs6B72W5trXyke1uT6b1BUm0jGV/m2U4JzVdV874K//dF+
rnSUiK6GFLg2lg3IFnQnq7tZ+SvdVfwcca9K9Z96g2mFzt0l00PItlGee7fy
v/rbhYsjnTuewV4uQMffZFo+LBZZ9BxqX6qYo7vWuIh7n8qPBrL+pmj+rzur
pvB3c4pzW/ln9Wpe0FPePvJF6JIZ7s/IX/wDejaY+ivOGBaWZZOyTd2R6K5E
fyOl+3DdGW+DfnaCc3vlUwfJ9Z9Jj/ZCWHM99D3Rfp5q7DfQ9y15vovRHYnu
SspG7VN79io2ZqV7+aA/eE+MuFem+PAl/P4fto6ufA==
        "]], 
       PolygonBox[CompressedData["
1:eJwtks0rhFEUxp9kwobxFWpmGGVHmGbHP0DGaDL5nvFNyohiIguUrSWzs5id
FQ0lDLNAERMpRUkSUSz8B363dxa/znnPvfd5zrn3dQ/PBCJZkqrABoFhacrJ
d73kCElO+IUfiDZKdpeUNyplQT75fKO1ZvZEB6UFCHqkQ9ZyxqXqOam3RnIT
973SAbQOSS2wS+6vlLYnpPtJ6Q4e4JraI3EVrRWIoZdCz4VeOd/nDqmMWAwl
8I13hNoX8QM+M5jcQ385nP0bkSr4LocXtNN4vBLL0DxlfdNjeRnPDWZronbE
2baw5AM76wUQmZbWq6VZYpi9IfBTTxiPMSnOLB1o73mtGc2sMfbGObNFbGOv
D1zcc4h7LuSe8+mpIIPJb+jrEo30pHX/5h3ezP1Qeyd2o9kFZ3j0UbvAsxnt
ETyaiLn0mwc2yIZl5iilvyrmqsV3CN8SfAvRLYJ2tHyQQC+A3g56SeghT1Lr
ZC0IV9T6qaW8lr/p44T8GOp43wHeuYGYxO8EJuhljZ6miM/0fcvZJ6IDbycs
cXdvvNti5r8x/88/k9h5JA==
        "]]}]}, 
    {Hue[0.5424987973778448, 1, 0.24884781901529185`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmgt4z2X/x29UUk6pNMTmtINtRm1y2GTiiW3oCpvDNvyY2UYzM+scOiCl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        "]], PolygonBox[CompressedData["
1:eJwtmnmAz9Xexw/Zt4TKUgwzmGHMoBkNZjAiy8xEYRYMYyxjjIyxp8XWQpZU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        "]]}]}, 
    {Hue[0.5298515151997696, 1, 0.2663594404926267], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmgmcz3X+xz+IkAgVVsaMY8wwjGOGMDMMYphxhXGfOfrNDGbMjKNLpXKU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        "]], PolygonBox[CompressedData["
1:eJwtmnlc1mXWxm+jXNBcKzUDATdAClTQShAxUxQ0UxM3ctcAQxAe0SltsdzK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        "]], PolygonBox[CompressedData["
1:eJwtkD0vQ3EUxp8Q7Fr1Uu9hsJDKTaQSA6qDKyq1emlvbuNl0JhsLBXUa4nB
IPENxGCwiIhIfQarz0CY/E7+HX45N895nvs/5/QFxexWnaQ2aAB/VZqFDJx0
SvPU6rY0MCh9ULN5aRGiK1IELgJpv0uaGpGWc9IS5OGTbI46g16mf4uvA38c
WiEGN2iH9FJ4puGA7+vA9cwTGZUq3dJZQWrhXzGoRyuhhWjfzPYDk2RLZE8D
N1O09o69d4d2TC+Nxyd7T/ar4Oa0ed/YqZ/d3qkZ9lqAJv7ZCEMhc+DfTbA7
pPl+RNugtwkvZHrJvlJ9cnPwhC+J7yh0d/RrXss8oKXoVRPuhnbLnTVpoke6
8twuttMfPHO/X+oe3nYyw6GbyWazd+y9dbJjZCuem9vmL6KNo1167l52tzL7
nvOPZvb/B4xyVV8=
        "]]}]}, 
    {Hue[0.5172042330216944, 1, 0.2838710619699617], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmnd8lVW2hrd0ULoIKIQWaQkETaEkAQJBSgIiJbSEEko8IYYcQghXHfQO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        "]], 
       PolygonBox[CompressedData["
1:eJwtmnmAz3X+x985EiKR3EfIOQzmcMw4xj1mSI6ZkWFcY3zHYAZjbKR+S5Ls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        "]]}]}, 
    {Hue[0.5045569508436192, 1, 0.30138268344729663`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmXl4ltW1xQ/IICgINMygQZEhZAISwAwkYcYEVAhJGAIhEsKXYPKFENE6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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXl0ltW1xo9MIVAQaJhBmQwQSAhDEEMChDEQAgohCTNGQkgCGUgQhwoI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        "]], 
       PolygonBox[CompressedData["
1:eJwtjrtKQ1EQRRdCIHZC8AHaRCwUTZlgyEVN0sm1EUWFpElno1+gxC5i2hT6
G6bRWFjY6j/oJ0h8pNJ1OLfYzLBnz5opds73z6aAGZVTw0N4mYelBG534S5T
6N9b0F2ED+tJE45VvwLXBXjag4mZX5W6+ynjT1ZTXdoPazDrbE497sCDOtVL
nD0fwHQbBrLz7ciYZNmwc2/uwlxdVsnbK+Y2WpERWNUGbKqvshx/eUth5D89
+5tK/DP8W9JL9Nb0iluwrOp6qd623reMn0b0w3xVr+Zs3cyrzLz9uBxvVbNs
2OkeeXsBrqz/o647sQ==
        "]]}]}, 
    {Hue[0.4919096686655439, 1, 0.31889430492463156`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmXd8l+W5xp+KEBmCgCAylBUUQhJGEmYgCSuQX0ghg5GBhBETRhIS5KBW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        "]], PolygonBox[CompressedData["
1:eJwtmXd8l+W5xh8RiOydgoAyEgQCYSUBA5mIBPKDVLIgASTIShhJAKWOI0Rc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        "]], 
       PolygonBox[CompressedData["
1:eJwtkU8rRGEUxp+m7NhRYpBSJpOZRhoiVjTDRtmMyNw7170zu7kNPoCxtCN/
Ir6BlVIIC2XDVqJ8COID+J3eWTy9c8953vN7zjuDQbxcT0jqRm2omZOS/VI+
lNo9qQNFWem8T3oKpNGylGnJfj9Tu6BXxbM4Jl1y9yuSSr60giYr0gQq1qTU
gLQ5LsXMrKNbGAX8LzCrDeljSKpxzuCfRRVmHjP7CsYwrBQK6L/jCzmn8Eyj
DXyn+O7wjeBJozL9N3x+w/Etxw/Mb/SH7pPSr+cyWtY19EltlbOLPQ7JdcQe
vXwnfce2DNcwTmAFWce2DEvslma3LXabZ+YcKqI95hU8l8dyPXL3jLshdxMw
mjDWI5fJsr3yDgvUHkL3PnHr/e1/yFHrobeTc29jb1SCm4G7DfeGep7+buj4
lsNyW/59GAf0OmH+Az2+Vj4=
        "]]}]}, 
    {Hue[0.47926238648746866`, 1, 0.3364059264019665], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXd81+W1xx9my0ZAyhAFkxBmIhkEQhJIQoCQsCHMEAiJmCAQdqtepuJF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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXd411WWxi9dCEUBIZSICCHSQk2CIYlJIEBIQGkJJaGExEgikBjKDLrS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        "]], PolygonBox[CompressedData["
1:eJwlkk1I1FEUxX8mQ9C0Scs+NEi0DxujlQ2IA2O1qMkxaCamSCGiVkFFEm0z
MYI2fUAU1iqSWiTtgsKIilZFtWthuomoBIWkNmH1u7zF4c7c994595z7bz12
+sCpJcAGkRHTu+CzGD8EF9bCfWvdSSi0Qr11wLNB0VCCFWJoAIrNMJWDhV74
Ka70wUwDPO+CZ3vhqXh1BObXwT3v5f2/Q+Sq8LXJN90wfAa62mHE+kve36Ju
EK7LXW8t7oNecWknjIprZ+HuRrhq/dEJ38VHdZc1wgfrpNrTznC5L80UswVn
cGfkuyFvi2+O5mH9Sj33J9/hf2sPvF8Nrw9CVs3lYq4D2sxjqgartkGTyBw2
J3tLreXd0C8+qftP3ZfqLhbgr3ij57HN5nkuZRGZtJXNwVnby8lP+Mo6z7Bz
fTHTMee8U0rvg6dR3SdrzL2W+nF+03s178/mknbMUNoPFf1M5NOeYl8Fvb1V
q8d6ogjHxcOKMPvb3clf+Hyh33f67tD/gv1vnm+vpl3Fzm7Ze2BvvJI4gity
iDxazsPjLdBsnTSri5vcyVDaS+wndhc7/KPGvBp71Hgkd6e/J6rpW4pv6j8z
NXwx
        "]]}]}, 
    {Hue[0.46661510430939346`, 1, 0.3539175478793014], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmXl4kNWVxi8UUNnXsCogAk1CwhYIhADZA0nYAkkEE4NpMpEEJBBSQCsq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        "]], PolygonBox[CompressedData["
1:eJwtmXl419WVxg+RTXZZQiRQE1lsQgiBJKyBQCBAFpYESACNIE/yIMFCCqhg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        "]], 
       PolygonBox[CompressedData["
1:eJwtkktI1FEYxY9SUAbay2rsaUZBD0ozRNPpYVQj/8ZhnBc1ZkVB2otc1zY3
4ZQJM8tq0YvI0pUUFtK2Vi0qF5VSbTQoxxGKZvp93BaHc7n3fuc736Py1KXw
xWJJO8BcsGGvVAV+haXAMuknfLhWOgRWx6SyFdIquLtZugwaElLEJ9XDn/3S
J3C6VTqzFMCz4CHnHDxOkgkwC3LgAnedvJ2HR5PwSuk1PN0iZcH3Gukb6MBD
oVw6CU+Bg/j6EXY+zW8X8WfR6Wx1+c3HDO8t/MvCvp1SBVCd9GGJFAw671ZD
cLe0Zbn0OCI9COAVrCV+DWiPS1+oNxl3vs1/gRwD5CoKSbe2S33guSf9WSy9
8Fy86TxCbzO6R9Af5D7L+zPP/be4O9R3GySiUop/H/lXiuYw2mUh1x/rk/k2
/9fapH7q6YGvEn8FnEBvGN0OeNs+aSvwM5v1eG6C68A6zvUx92Z/rjOnbubV
C49Q/0uQoYdp4OE5T44FeMnvkhbSq/do+/dLe0CSXuaZw3H4HnO5D4rx+hTP
c+CqauZR7e7tPcG/3/yPw2No3qDOo1FXt9XfhfYo/s/BvdSTAhV4LcWzD25m
5w7UOo/m9RVzKyFXgDmWoPcXr4GI8241TDVJkyCF3ji6Nz23R7ZPd8k7RP6i
Rmkj2uXk2BRze237PZ++xtCb1+Z2znYvQ/xXdNKe0zV964P1Y4y7RfSnQJ9q
uG9Hryfm9sb2p4/3CWL7PTcrm1kOD5N4mIGPkTP5vz6r8w1373h7G3U9tF5m
6KnoXzrkemM9GkBvGt0nnos3nQbyVpK/Ef4Hdj2zHg==
        "]]}]}, 
    {Hue[0.45396782213131825`, 1, 0.3714291693566363], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmWlgl9WVxq9URMAsyBYWCQilIFkhQBaCZCUkISE72lCcDIgT1GRYZHHc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        "]], 
       PolygonBox[CompressedData["
1:eJwtmXl419WVxo8MyBpCIAhBBNlkSYAETSALS0KAAGFLCIuG6kNBHECJ7NBH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        "]], PolygonBox[CompressedData["
1:eJwtks1LlGEUxQ9Bi6BSSwZzcqYB87t0zCiUEm1TopXDCGFW+jpDC6H8IAY3
UdNEim0kKyHc6EhW+xZBQS1sE4HQB7Rw0yLyq3+h3/W6ONz3Oe+957n33CcW
3E7c2iWpCuwGJ69LTeB7IC2WSdl6qYVzM/gD9wZuAu4051NgFW4J7iHc4gUp
D/b0SQVh6X2tNHZDGgUfU1JHRPoSlz6d4ww+X5T2FUvLxBz1L9H5Fbiu6X+o
lh5USOtjoE7aAPtHpJlyqZBYNSBVg0S/1A16wM/DUpJ4H708eiuBz2Nz5Tuk
BTBHf730t0l/IXRm0SshHkerHjQkpb8hKZ70eWyuVmY4C9rBBHe0EQ9Q84za
YmItdXXgEfe+5t7fgXtm3mWG0SRvnLjF/f92YN+6Jk3TS5jZngxRH5OeDrk/
5lO2nVnA41HpxVFpihhjviNgNk0unoYavW/rv+Um/6N40eT9WF+NcBG4BFwR
fReCZvZRRm027h5ue0lemLxL5J1H8xX/v6XdW/PY/Lc9/OhkDwd5I8Qc9VHy
WlOua/qi9i5cD7VrnNfBW/JOwI2n3Efzs4S853BzaZ/H5urG68sgcZX9l0r3
2FGkix1yX7TLvTBPvqLXSe1yyt+XvbOiGu48JJ25ItUcY3YwT/1kpTR4x3VN
33j7X5mhLx5+RcZ7tF63wDv2u0ncy6w5drPW5+/G3s9/96+Rmw==
        "]]}]}, 
    {Hue[0.44132053995324305`, 1, 0.38894079083397126`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHt8z/Uexz8kl5Frs42TXGY22+xiGzbb7GczNrO7uZXO3LJhYxviyKUo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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHmcz3Uex99U7lwZM9jKHUZzYBzjGAbJmDHDGIaUHq4ysxhXipCSFl2r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        "]], 
       PolygonBox[CompressedData["
1:eJwtlFlI1WEQxQ9FtFJQrhhRUg8F5VJcbbFFzTaXXO7VQCsKNIrste0pEkKt
oKCdaFNMy8rqLRXaXpIWeikil0xbTNrsIbDlN8x9OJyP+c83M9+cmf+MLbsK
KkdIWg1GgbSgtDdaal4sTVwrTQIPi7Bj246tgHMhqA5Jm2Kk1DSpJUe6Deqy
pcHJ0hW4JkGqBV+SpQEwvlAqjpLGGS+QQiCRGHHESIZvJUo3wYdcaWaE1A9n
ZUorQXqelIetKUXqXC69BUvCdS6G53A/mjiz4bXEXQfmrZHmgnhqfUfewUVS
O/W0gWhqTZwiRcHbiFUBWqirGb9z+O1fKu0D3QHpEX4J1JKJbw7nLGzD6dKf
dM9j+V5RwxtqeQ0Pgo+cv8JTVkgR4D3nHmy9QX+3vf80tVZQ81k4kr5GgRrO
m7Edhg+SpyrgeSzfoWLpN9+q4cokaSeYlk/+SGk6/AMdvoPz9P4zGlyAp/KG
OFDCnS7uFsNlaFEKCrizg7tFcCzI4hyT73Et/jh0HwuuUdduak8J+izYTFzH
tgfbQmxd5ImgLz1wHb2tT/D5sDmZVyrNiqPXcDkalqNhRZ7rbHrH0ocY0Eqc
DuLdg5/S55PEq+Pt/3i3MjymxT5Djn7edho+iF7H0asKDqFfMejHtw80lUgH
YqXGErfb9xr8TuBfDW9ljmZQS2+u+9u9Z+Q9Rd4X8GhqGwNWkT8L9JEvim8j
Az7nNu8L01yrWrT6ysz0Entmkc+czZ7pabo+CO/OffjqevpHnxvg3GXMNGgl
9jBvasv22bQZ7ST3W/CLXjVQ5xB8F20uc/cOfAT9joJA0LVJDfpO2G7M502P
TY+Az7DNciX9X4oOO0tdU9PWdtN2tJG838jfBOeSJ0S+9Xme3+r4jO8ncIEc
LeT6w5tSiTObeCnwPXK2gqv4NICN+B3DrxO/v/T/Mjpog++x7fMI6oqkvnfZ
3lvrcTy2ALb4HJ9Xm1vbG9ufIeINEO8n/AS85NwR9Lmx+blEnAHqv5jt8297
YNqZhhnhnU3P8TmyeaoPuM7PsbXTy0Z62pbvO1EW7qv1N6OAuHzLhM+i73X0
vVHo/4pt4Tfb2w+k+R6fCfm+2t4mhzVIgrvpw3Fq3hz0/lifWunbdvrXXuq9
tR5HEnsjOaIL/X9p/02bD5uTOuZlArXUw/8BO24LAw==
        "]]}]}, 
    {Hue[0.42867325777516785`, 1, 0.40645241231130613`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHt8z/Uexz9u0Vya68wt5m62uczGZheLmdl9+23DelQOidnMdTmI0iGX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        "]], PolygonBox[CompressedData["
1:eJwtmHd01+UVxl8gKpuArCSsEIZACMhIgJAEYgiQQcL4sWkLJxgZCYEQosWB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        "]], PolygonBox[CompressedData["
1:eJwtlOtPzXEcx9/CPNJcIl2RRMJZOeQuFXXo5HJCkojSEMelo7ESO+6XlQcu
88gYcxuP5FKjzQON5QE2ZmIaNib8A8brs+958N7nnO/v8/1c3p/35zt6Q3D5
9ihJhaA/qNoibQQ7Qe8oadE0KbhDykjlDPtlkfQV5E6S5gNvvdQ+XpqCPTRH
6pcmBXZLLeXSGeDLJzYoWiKVxEiLsSm10ovRUmqt+2Y+39YRF/TJkpqSpdJq
zmdJrWOktqB0D7SCmsnSJtCeIUUnSAPIMbWYOsD4CfiSf2GdlL5eep7IGTYV
jAVN3NkzTpobkrpo+CWInigdJc5v4tyir9vgF2e9oLtIGjJU+oDtXCM9A+XU
0EJN0dR21y/dAf3IOztOGlzq8li+WPo4Rx8X6aOW2FvBIPj7zt1b3N1DryHQ
lQkn+D2tkn5sIH+SdNwjFVTADUirkeJHSsVeaVilNByM4F4DvcVih4IYkMx5
EgjgNxJ/L/f81FEEfNRykxxvqaWePFn8vkfeGdybCT6tkj6CedS/kj7mYl/h
ex2/giwXw2I9xOcBaAMD8XuE9a6gl1jmj21gLo0gGx1cHStd2uX87Z7lsXz3
yeslbgN1DISHZvhYHXTcGsf59JwHHm2mVvTXjj0WkM4Ohxdsmk8a53MaNC3+
hddm5hfHvA6gwR602FTvNGJa+QynN+D0iMfFtfjvOLvGWZizefzPiXBtnD8m
317ydmBzInwMYb6hPPoEJ9HOZTR0OuRmarONicwhTG/J9Da7ysW02K3ECRHv
AbYHHtKI9yddiiJWX7CPexeY5d6IHkwXfbOlSvZj5lY3F5vPEWo5DE5wFuZb
AT4L6pzeC+rcN/PxUGuYHHdK3X7anprOTe+/ytjJeKmCPTi/UqoegUaxT+C1
I+C0bztwhZ7W2k7g1x6ZdU+607ppPh6dxYGlaC0RrWWgtQB6aaT3f5luj22f
i3kHoqjPj11Vwk6DGO572Klh2MZcaX+u07Rp20+8OOKl1Lhdt50/GJlp4Syn
LdPY+ww3g1Mhx6FxuY336ic8B7EJ9J5DzQMmuHfB3gfLY/nG8L0Nv5Qtrh6r
6xnIQcOdWA+5k6hhmdf1aL36prnY2yNvo72R0/EbhV+J1+2d7Z/pw3Tymt4u
0uMbv+PV+C0NOq2XBd27aO/jkgg/YfalA34P8bt3t3t77A0ynZver7EX3czt
PH3/BwRBCEk=
        "]]}]}, 
    {Hue[0.4160259755970926, 1, 0.423964033788641], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmH98z/UWxw+TYcb8iJmfw4htvsxs8rWf1jDGzJbF4prNbGzfhSFT6Zfb
vXXd6/Ho5kdKGDF1c5Pf616UjLrKj5RsFvIjCt1bjxJxn6fz/mOP8977e97n
fc7r/Hx/QvN8maUNReRmAxE/6J0EkQn3iRRkijTIFVnTTGSzV+RAmci7gSIB
SSJtIkTOcih0FPz8FtFTZDa//wD/Cx1FWvJ7C/7eh+edNJFV/UX+1Eik1yyR
JTkiXZuIPDRX5MM+IpXc+WueSCr/H2ojMmiMyArH/+BYkX9MEPHvIPJMsUgH
ZH6EzIvI3MVdM7hrJ3RxDH+cvQvPuWx4Wokcgyc5HDtCRF6aKDIcnjHwpKbz
f7nIK9jyRD/0SLf94dA1oSJr+RsIFrtn2ro4FlweEdmADo2g1+eInAwWGYZe
S5D5HGfD0XlHuq33zBY53xfbkTGqQOQa6xrWK1m/k256VnP2mVCzV7H4G//f
QeYy6EdgsgFM/KbxO+uNrJuz7tEDmdiShP0x2LwEvzyDHd0GiOwDqxczRMrA
q7itiA9ag94lrMtZb3kIWS1FtsEzOdxkHB0BPpFmqwcdq3wis5CZhj+rx4tk
sG7htTN6No57bqssZLYfzB/7W7n3V3wVwno/+x2ge8Ctgv2d8SLfwr+e/avQ
X/irYn0L+nKJyBnunQAmHVJFbiA/GLqR/Uvsb2A/Fj1vsZ43XOTgOLC7H2yg
i/HlZHAYzO85DpOlxOu4LJH7m3N3nEg2fClB3IlMDzLXIKcH61Y5hr/6IZn9
KvaH54tkgnsd+GdBR6FfCvsjU0T2JhrOJeCQlwy+LUTujQYn8H+D/RfBf39f
k+9DTlv4/NqLHEaXLlPJg87oWSiyiN+e7yQyZAo681tjeMYQR1PBaA06f44+
nby2/x1++Liv6XaAczNcDmouZmWZ/BOTiCf+zyH+vwOHSs5XYNcC4jGB37aC
yQZocKTJ7zIfbLi7Ah2GIbPG6aC6fOXy5VPyZenDFsMa1zn4YCf8lzh3I9xy
+S14fis2Ho333eD1UwC+AvPVxH1lmMjrUM9QkVPIP4bsc/B85k/sgF87MAkE
k15gcgF7l8MzA54Vzpbl0DLqSG/qSSF0Gf7d0c5i8TT8S+HPhv/qA8ajtSDR
2ftVKXFIfr5LnnaC7nG6qY4h+P0O6yfAO551Q3Kunv3n0DsEfI5mWU1ReT7u
Xe/wXAddF2m+UJ/8OMdiQGOhhhjbSkzOfZCcIdcCiO0D1IH9Y2z9AfQ+9s8g
J4P1Ks43QM/D6PY4+C5ifwPyT/J3DZnzhlHr2D8GVg1YrwL/w+Af9gd8hs4T
sKsNMr5g/yT76ezvnGk1qxpay9nLnH0v3fJZ87qCGN7I+iXW3nyrrVpzOiLv
YycnDTnjsMuvF3pCn3WYLMMXye7epByrF1o3ngq32FF+5csvsVpXgfwo6sIB
bO9IHajFT3Xw1UEDqV9x3DVyMhiDbz1yVlB7/0cudUafZuheUWq5PNb509eb
vNTGRP6nkstTo0QG4L/V2JgG/7ecDeZsY9a1rP8N6/UIqztaf65h693p1qf2
c+exSVYfFmLfkRKrLafAoBG6DUW3h9DtNn3IyzqJ9a3+Vt9aY8t/6U0+dHgM
XcKI/+pu1BPuXR5uOvYeabapja2mWb9aCT416BRJrH8NTz9061lotkeybjrX
eJpAf0y1uheKPD/+f5n9L6j9MfCfg98Df5CTcwRb7qUaJnehJeC7EpxnQa9E
ml3ByLkGJh3Axx89Y6dY/RkKLaavNyKnPiFuEyebvV9id3Pipi/8AdDuxab7
k8R5ymTD5xw8R8tMn1X47hXuu03djYgW+Zm7OoFVc7D/ItJs8Q83XVXnlfB/
Emk1/w7x2GWu1SWtT8fTba21UHFTbOMb2XmVo9hE8Vs0e3PR6/0i64lnwWQe
9ixHt4XQ+W59hDj0dzhrrM1Dz5/QMyTa5hStGxfus1qsmMyHfxf58wZ5lE++
xpRb7A2CjnA+vYrtryPnn+B8mzq0vcjmllp02F1k/bouwnJR5Wj87Wf/Tfbr
2V+WYT06dIDFlmJ+D5nVkTYb6IzQnHpUSh14NNnkqvxNxMDETJvHqoj/jmAV
hY9CoG3TzUe/wHsmxXqW9i6Ne71/NvHbDNwWgm1T6AmHQ+Mkm+1U5mZknnF1
ozU5Pnii9c1fwTzAnb0RYXGv8b9N+7CrURfdzKKzkObeJ9hd2cHmtivcdQGs
4ukDAWk2VzSmnoxE57HoPwIZIfSCFvQCD74qLzEcjubbzKcydGasR85Z5HiR
c9XFWyv0f7eb3asxEYJOTZjlFjG3Ph5nOa6zwN/pZfnwFLE3i5p7At1mujlO
9VS8NqdbrGVg6+JiW//ooV9x1+fc+yk0odzqUgb1I8TNKkUDbJ7Qvn8/92+L
tBqoc9/6DKu3L7LX0c0ArbFxKDGWB0ZeqF+s9aAl8ZYPmhdHCqwGaa41oYaM
TTf7NPbbuL4phdYrVI6eHx5r86PO1OeJgYXodg76Cjrcow4voB5fcPv1/W1G
1Djsjv7tHf5NC62eal3NB4ODxE9zzo5CdmutBfC3ibe5aWOY9dR1s229FppO
HJwG58PEahfw3Qa2mdiUHGc9twLdnsfmp9H5Oeje2daDzsfY3KDy+nDPcVef
tU7vGG337sEXZS72niQ2X8UfW/HLamgfZpqdzAHh0DI3X2mduzXL5lWdeeMT
zF7NP53btHfvRObiNJvftnht7vl9/qFW5JN7j8EzHbrLY+sC1lPd7LcZGV96
zC/qn3nsL2B/AXSfx9bzk833GgPae4PJn6XMNreJ/1ruOsJdZ6Bho6yWfo0t
r7n6uQkZfvT+fyHnPLhu8trsFwh/v2iLf82DIUPsPfB4qc3HWvO1p2VhQ2fq
Wy3nXhti8/FVeEYnW45qn5yUbHXmJr1+OrH9Z2pdJbX2CjVhGH3hMjQXfbsi
57TWnRib3/ZrfvS3+DvIeqObT3oxP/Qm377h7E3uvDvQ6usMdGnP+mt8t4LZ
4VS2vR+bkb81k2ymC0RP7xiLYY3lQ/D7wGcT8paPsLMroZnsr0ZmV/bbg0M1
PO+ByYqHbR7Wuds/zc4WgfNor9UcrT0652muaM61dm+W29jxbLmd1Zm61Gtz
vs77eofelcWdgUmm88/IvANGReCyl3UvZ28YtD7P6r/2AfWT+qsKeT97bU5d
SnzuybWz1dC3PIb/LXxRSYweJFY3Qr0DbL2B9dvuzdsTnE/lWS/QnqPzt87h
+rae6LPZeN94mx3VL4nkWlWs1eIw8uDDYoulpthb7TN8FKdL3N2eHLysM0KC
YaLvuUHZxqN+mEiclHB2C/rucHPmIGwZ7d4FF8i1TaOtxwUl26yg/Uj7ks6v
2iPejrF6qnVVa21LdJ2IztHEyXecDUGH76GPuLtytPcNtLg7Dbaegfa2W1hq
8adx+BYy61weeYiFEfn2rtH3zQvjbR5bTcxEunzROWUvvgsE/0a51rdUt85z
Lc41XxTTJzj7V3RbNN7qgtYHfedtirJeqX1Y66PWyZEx5j/1o+ZToxjrSUH8
vtljuaw5XeXWOh+1g6cX9jYEh5wyy696r31D0Rk1Ap+2c72sAp9UF1kv0PlL
Z3Sd1cdCz7p3in4LeZg82kdvyoE+HW7rCaw/gucD8KlJs3eCnj2O3y5iQyG2
nIiy9632wO7Eic/Fidae7DLDX/0QR8xUUEOuD7H3m+K/BTt2FdkMo/Oj+l5j
QOed8GirpfqmDCJ3tmHLq8x+a3MN63XQEM6Hg0MgOAzItlqhNWNfkc1aOnNt
S7Mc3w5t6eS0SLL5Q3vBS1H2bUJriNaSN5z8CegeyN8VdG5RZu8I1V/zubzY
ZoZk/D+Y+NiLnKvIScq3Wv0LOLR1b+Rg6Jeldk5rT8tpZmMNPW5hgvlI546B
8+2dpd9R3qZ2PMv++z6b9XXuHUhvPVxmfVb77Q/geJEYe4DYPoCsU+iTij5D
XQzr/dGFNjPo94Mq992mMsO+Vek3q2gw6z3LZpiG9Ntc7j5G37xAjz4fb+tv
oN0LbWbQN/dudNoODrt89vbQ2bhvob2HtUcPi7P4+/2bXqG9o7Rf7EPHwn5m
12JsDS80W3R2a8h+NPs3Emz2UkzWklPXE2z/JvR6N4srzZkd3D0Tf43Eb7EO
/xhoAPhcRrdm0B28Sb7nTT2cOA1n5jtGfT6EvcejLG7r2C/Pt7lLv+vo9x2d
V98ssfeqvkf1TR9EDk8C51bQD/LtXaBvhTUFNmfqvKlvKu2/2oe11mjMn8HX
xYlWc7ZzdlyBzXX6xq1zuXMyyuJLfaE1ogKf/oW7FsDfw/mlAX4pct8xpkM7
wZMCz7eZVje1fl6ZYr1Te+ha7ukYbfO5vld0FteZ/KsYm5/URylx9s7U+qZ1
7pKTM77A3vzKH5Rj3wtUZh/owTKLAZ0fOzn5+g5Q29RGra/aP7SPLKeX1uTb
tw79NqZ+Un+t507/XIsBjYVPHZ763ho6x85uxj6JtlzWnP7jTPu++QL0UZ99
x5kM7RptdekQed14mr3j9Bvn7GKLlTn6tvbY7Kez5wing8ZO0zLDvBb/jHL9
Xb9ZhiaaX7S2Bbh+rbPGlTyTr+/FKVEWJ/pdUO3QXFC5PfvZNw39JvqfMss7
ndl9bh7Q76x7nT46kx6BL4I6k8j+ZwU2t+u3zN/cDKDfbv8PYm8z+g==
        "]], 
       PolygonBox[CompressedData["
1:eJwtmHlYl1UWx49ILimoWSKgGWpuECQikiAKbmS4IQgqbQqiiPILJUt8JqtJ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        "]], PolygonBox[CompressedData["
1:eJwtlGtM1nUUx78hmCtlcyCXBy9jKbdHbZJxE5SrPBHX5+Emsl602iJEWVnp
AC+ba62LvdEpm6iB60W9UHPTCb0Ia0nNti6TYg1W04Zj2bR3SFM/p/O8+O78
9zvndy7f8/3901/eE94dI6kRxIGn8qRVCdK/tVK4XIqAI93S4XTpXWxhvVQE
Jlqkn5KlYLF0tUYaBUvKpCfBz/gm8T2Lr22n9FVAasXuKpV6wIqtUiJIpVYO
tZbWUbdXmn2Gb+wBch0Ev2ZLxzKkmL3Sog1SLOjnvA8sbJEuUmOIWl/Tz9OJ
Uk2+VFIpbQW38Q/i78F/gfiLILFKSgCrdkiXUqXV2Fb8R4mbIn4TMbk1ft/y
vEi+peT9hvxbmGWGuBnifyNmCnRz/xfy9GCniZ8Bc2GpMklaWQQXITgJeW3r
oYu7J8hxi1oN8FoP7sJzAA6WwMXeQuJWSNebpJPV9F/tM9vs2+Gonrgq7CS5
blqf9HSLfLPk/bBDehWeP8A+3CY9AmvImcudNO6kGN/gT+79AU4ZL9ydp5dP
8fcTt5/4JmLCYKyTftPYa6fzbby/3cCs8DGR7zwan63M0AIWczeFHHeYZyN9
3ST3jy2uh/91gT8V/1ytz23zL5D7KDUedPo8NpdpyzR2LbrT8Xrnwfj4Fl7O
w8+b8DQA1/0gDe6/YAcB7Gm4HgL7I9JH7KCPHYzxPQraozo8HJTimTdIL4E8
16Hp0fZk+0rjTgV374R9x7braeaYZp6iYte56f0ePb9H7/exyfCQBFbyiK7R
c24B+mUPL1HvEDaWvHEh15Zp7AR32rk7iN0FD91gET1l0FNSnu/OdniDOWPp
pYteNvNungPLmWUnZ8/T5ybqjFMv0Oj1rY99nD3i7DhnpeQoA/9UoDNQ1s57
hKsK7PAL0icgjh6W0csYvGxAZ+tBzjvSlSwpG7uOmLXgHvVuUzejmbNm/85s
9hyWKyHHc5e3ew7LdYXcr5H7aqdrzrR3jjrvZ6LVt3wvtp/qqLarmf0MXJwF
s+gkmbO4PNeX6cz+CfZv+DKqzf+C/ubs7c2hzRHmXl7g+jUd7+NuHzlGyN+E
jn63fPnOhXEyXOf+c9hMkFXne7J9heD8Llq7XOj/LPt3dZVIr6TwT2qlD7ge
MM6p9zl1H1A/Gz7+gpf7Rc6ZcWf/T/uPbm9D39ytwvbj/5i4gYjr1XT7d9A1
cZLZbpDnhyjsu4yz9fi+D/obtrccIc80+cJtvmPb9Xe8gSfQ3AS2lvMp/HVt
ri/T2WbqdlA3PuJaMk0Z18Z5CK4a4CIEB/PM8hkzJRX4jDZrVpSjoTfgax3/
D+x1uHyduN4Gf4v2Jh8DVRwZ3Q==
        "]]}]}, 
    {Hue[0.4033786934190174, 1, 0.441475655265976], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHd8l9UVxo/MsMIOI4BsISEEQgyQhBBCMBASwgozLSPMBEwgCUGGiIpo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        "]], 
       PolygonBox[CompressedData["
1:eJwtmHl0ltURxodF9k3AsIRFdiEiENJAViCyhoRAAAFJCyasCZqwI7graA/K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        "]], PolygonBox[CompressedData["
1:eJwlk9tPz3EYx98zNs1pOqJ0kuqCdVz60VBW8VP9Orph1O9Xskp+lMOcxkXY
+AMsN+oicxgjHYQbZkZrcsFkuTA2NrZQbZqR17PPxXvP9/f9fZ/neT/v9/Mk
+A9Uts6RlAvmgZRaKRl0NUiXY6XlmZJ3t7QNLA1Ij1dKfWlSEb8LwXzeDfHu
Hu9y90jrQB44FyNtIF5JlzpBcos0kiClEp8Hpfok6QUxqk5aBhbmSwvA2xpp
LErKypOqsqRKEFctfYyU4olrPVJLhFRTIf0ukmbAZ/p8Al/BIH2/ENPJSwPH
W6WkVdJJ4qlNRNDVLk0nS1eJi3OkhDDqlEg7C6RdYHCjNAC+lcE7XPpOHIbr
XjiPEKPhGwNuFUo3QW+5FAqnS4j4N0M6gW4lDY6TcctkljpynwTdjDbrffR6
hG6LAk5b0ziT2Q8zewbxH9xnwWvq+aj3ql46Sq1j4Da5/eT+8Uv55BWAn8yy
OUX6RTxYLB0CH8gfB2Potp2676ud1qZ5SCM84qTV2S7f6sxSb4C6d6ifxfyZ
oL1JmoiXjhAL2YUeuAwzm5cd2Q6m+XYKXC+VTqPjjVLniXlzbT/6JEpr8Ows
+ZPUOdPkvre8h81SNzsx1Oz0Nt0D6O8Hs/iRRL3wHNfH+vnAG/wtq3U+mV8/
2qQOvJwg3qXmA/jPDbjdtB1d7yMfDz0+t4e2j9HM0ckcPQ1u123nJ8m/QJ2p
NtffeJxH+0S+24r2EegeCUa9eGHAy0Y8zcXbHTzH8lwTdHqb7hfZBQ+zz7S4
HbFdsZ2x3QlF+yVon5rtPDav95GbSo2moPPYvH5J31LzHh5j7K+XPX7X6m7C
bsM8Nq97uYVu9q8OnT3wGTevaxxP41uOJ1Vo6St1npq3NovNtIUe8fTooEc4
3MKA4BcCv0T49fI+nf+D9e627cZHma2Yfisq3D3ZXfVXoT832lfl7s7u7ymz
+JnpWdDVtfr/ARY11Qk=
        "]]}]}, 
    {Hue[0.39073141124094213`, 1, 0.45898727674331097`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHd41tUVxw8jEChDAgQkEEHKJpJF1puEkJ3ISwIhDKGAEAgkhTch7I1t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        "]], PolygonBox[CompressedData["
1:eJwtl3tU1/UZx59MUjulIAgqiJfU0HlBJRDxitxk/OTHLaZyJomC4klFvBxv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        "]], PolygonBox[CompressedData["
1:eJwtlW1M1WUYxi9sGH4qE8S3WqYSvn6pwDyByIEgXgwhlyJbCmR2ztZBDoY1
QYHQlEATspquPugETJ1KWbPWB1/ayg++Zi9mrpm5NldozqU263d3/z9cu5/z
PP/7fq7nul/O+OpY+StDJC0DieDXDOkS6IxK7eOljdjCTF93sX5zgbQeDGVv
KXt57F16Hj9wcpF0AtTGpO4J0gMhqYjzl/nuGey6bPxBw3QpDlLKpC+TpWTs
tgJpK8iulGaPkSZOlerxP0+cP4iXVcUZaF4o/TxaWjlFGpUvjQYzi6RM8AHn
i8ZKH2Lfmi/1pUod2I4Z/J7hdxuHcNS552OTeMcy1oWsM8FM0EbMVtADr7vw
68aW8b7zo6Tjk6VTudLpXOdjvK7B7yd4xuFbx34M3F8qTRsh3Vfq2phG+ei2
AO552FY0bgEH66WBSdJn2C18c5c7vueOfmLsAm/kwQfsx6cd3wPY13j7RdZr
FrqOpqflxHLTAZZztgH71WPSMTC0TroMvyTsjpCv72UtkACeDnglE7cxjLYg
mb0RYCTI5iwF+2O5FBop/YAdi57jQE6W8/+03r83vxi8zuITtXjouBLsoC62
g6fQ6nXuvzpL+otcd5Pr69iZOdKTOa6r6XsRDRKJsQtNmoi5CrSRmzXkKkzO
hK6T0Deh1PU23YtZl7FXjK47+d0baGha3iiRHuLsJraPu3vB+Lj0O9wnYMPU
Ty5YQr30UDfV2GiWnz/C+VG4HwPX5krp1EQ00/Ni+ZnYwD1p8MEmwXMYOAL/
78hlAfwHp+EHmol3h3i5xHucunkCjCUfY8CcuJ+FsV34dIIrIB0NfsMmFPJm
cB6t2tGsgv4IBVrOwnaR540gtkLa9Cg1gB1C/HuqnI/x+ieCxuh3Dn3WUdM3
ecf6Mq/1tqCXrKeansWfs2bsOd73LdjDe+exl89ea5CHlqjPCpsZqUGdJJLz
aWg0HVSh4dtoeSHk/Wl9ajmx3JTgM498lJCzcriuhnPFCq8Rq5VeZsFOUE2t
iZqrxTbgHwd/E28vcd8l/mbwEese7GnOzoB6vk3CZ3m5x7BYd4K3345431n/
5XN+NYX6L3dtTeMXqelacGiq61gHp7nMjFIQx+dVOL8P56ZG6Zd06rLRvzc/
09o0/5h8DJCXAnjWBLOwOuY1Z7XXz7oPNAcxwnx3Bl6T4XcaW81dNWA4+5vx
XRzzuWrztaUCTXlbM3Hege8WsB9e6fiexPcwOGLgu8PghZjHWBLzfTs/G9x1
IMPnnc294mBODyPP+9hPY/1NxOvQ6jEhmBdr4XwZzttDXm9Wd7uJvY879mLz
Q77eE7zR3ppHzZRRO7szvZaspqz2rQdmU++3qPtVWf5me/vXEb//eMT75v/+
oW/Hof1gic9ym+m3ydFS5v1Alfem9eiDxLtCvAjxcunHQ/RlXoPPD5sjVpdW
n2lT/Czc4HPM5tlzxFtLb12o9FlkMymEzjXo/TBabiXvjXBoyPB6sLoYDrcN
cLgBh8+pvS+KPCeWmyZ8N+G7Gt85xK4l9vpK/5+z/7s4NbuN2q2f77PHZpDN
XpvBJyKe01MRj2mx+7ljMXddJ1Z2oFtW3PNs+R4M/of+jPlMsdlis9dm8Hu8
91/68yizeSCozwMx/3+w/wnrG+ufW9zRyR2pvOsg65dYf1LlfWf99x9wqI9z

        "]]}]}, 
    {Hue[0.3780841290628669, 1, 0.47649889822064584`], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHl0ltURxodVCEJkDSIQUhDEkAQUEkhKCNn5ShYSUAw5DQqBQiofZAHh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        "]], PolygonBox[CompressedData["
1:eJwtmHl4ltURxQckbAIRAgQjkFCKVhI20SQkCjErSQmEhMj6iMpWk8LHE0BK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        "]], PolygonBox[CompressedData["
1:eJwtlX1M1XUUxp+hGF1WLgUtLlwk0jsBubxcuQ43cxWUrAvC5ZJi4WtZOF4C
XIMwbWs2W01z2aZ/aEtvtpSt1Jmspm3VFo05+6fsTe29bNjStmpi63N27h/P
Dr/v/Z7vOec5zzkUretp6c6QtAJkgkRcap0pNdVIWfdKN4OLTdL+HOkC9usK
6RtQXCotyZNq26Xr9dIkqH9YKg9KddgzS6UPQEeH9AgIdkqn5kgF2Ffx3wNi
vNfAuzXYjPX8XiC9HZGS3G8D14h9FTwRk8Lcu9IoTTT6339g+3ljAFSvlqrA
iUqpMsT5BumTLun0ndIYtut+qRuUrZFKQV6VtJd7Bx8ln4S0dpaUj53g/Ar4
rlq6BH5plZpnS79iv6KWL0EkSUzOyrGfLZHOgUPkt4ycok0ex+I9DS+r4Gch
PO2C0z443Yn9k/qugo/nS+dvx+8hvsuoFWQ2SFNBajE1EKMs6Rwal0OcNXD2
BblcpNYL4D/qHaaOJur4vNV/P489SO6HwA8t0lJq+x6bw3cumEGc0bA0sln6
kFgfgXa4Xglm05uT9OiOTve3d671SN8Wk2OPa8E0sZucb5D7K9huuI6Qw7FK
74H14gXy3QEW4TOIbwwb5a1qcAqej5HTuwnXkelpAt5S1lNsIf7P5EshbB4I
gg3wsIfa1ie9L9afEvzmg3/IdVGR9Dd2Sq/0I/Eye71X1rNPqW8MvEO971P3
LOrfRpw+4m3F/kT/fgbZa6UAmBeVbinkeyPvpvWZinmfrd81YCFoo5dt9HRF
3DVj2tkMzwFqewp7GX3OxXdjzDVsWn5tFfWiiQPY0DJqBc2cLwfDzNtW3jvK
e6Npjl6vpa8P0HMQaJbuziU3bJBZyweP38P7IBOfML5T437XfBLEOEOsJPal
BdKL4OhyaTpvHMHmo5NLxAi1eq+sZ6YF08QI87uOOf4L7ZbCeR/cl2Cvw/tk
tevXdLyfeIPEPRD3ObR5jG+SOunHg9gGdDmENiYrXa+m24r0/Lyx2LVump8C
7xlgDtzfBPf/Poblexoo5izAWQb9qGB2x9FGJD3HNs+2d2z//DbALqK/WaXO
q/F7udZrLKDGcfQRJq+z2AB5ZoN6/OtAPb07TJ5nyTebPfQee+h4xGfCZuM5
ck6R8/NJ15Jpyvi3PpSzX9rZMwu6nBvjaCf33uL+y9hd8LCduLs3+c6z3RdM
a3s7vBQRt44ZGiN2ir/vq0rntMZ3oO3CmeR8grnMxeaQ32nyOxnxvWr71eba
5rsX3eyg3icTvk9sr8zA5zi+t2FX06eV9Ksj7ho2Lb/J31s4G6pxHZoeb8B/
FpwXRb0v1p8Q/qO8U9jpmjPtTaMn2dy7K+q9sp4dibuOR+I+nzan07l3K/fC
UZ8xm7VQP3t1Lj3v971g+8Hm0OZxkLnrYXaGsFvgaRicg6tG+BmHq2f53ocO
tqV/szvWT+trS/r/VzP2cIn0+zz21IDr3+bgf3+WQKo=
        "]]}]}, 
    {Hue[0.36543684688479167`, 1, 0.4940105196979808], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHd4l9UVxw87gILIchACAqUZP1Y0jGAIBEKIhBASDBBkmIEkZphBKpYh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        "]], PolygonBox[CompressedData["
1:eJwtmHd01+UVxi9DlogiCBWMMUXUJEypCSQSIiBiJIlklCCx0uaXpBCTnyRi
XAiCW3GcY2udeJBSWtCIQtWe1roVnNA6Akr1qHUgUxxQ7enn6fP94z2539+7
7njuc++brF+lK1q6RsSJXSK68/ed+RGH+Ds8K+Jd5NmXRJx2SsTz/JZZF7Gh
ht+OjRjM+rE5EamiiFI23j8gorM04oZREc9xYAl7rmZvJb89089rZiIfSEfk
DOW3wyL2I28+O2J5n4jywREfV0X82BDRIyPibPYvYf+XsyKyuS8HfR7Pi5jD
b3nMvSAd0adHY0TPDN+3lLkzJqLj8Ih57GlF1/OS9WceF3Es9vREhx6MFydH
vMSYhg0rWbu5L/qNjKivjeiDfjdjQ2duxO1N2ITuD7DmDuQL5mDfkIhfMr+M
+ak59p3mL7g44qMLIjZy1zZ+e5Xz8lhTy/pxR0R0wTfn1Nge+XgQey+dFNHO
OHxmRF/Gxlbrfhj7NyDvb/F9t+Gvfcg/w2fb+H6c71ORy5ocjyvRcQbytdjW
TCxO53vPaPxRH/HXLtZpMvJs5mcxn8f8B8y/Pd++TfE9aUzEVU22p5kzFyNf
nMRrCfa2IjcxvuP+TGI2D/lGbHqeuXPw8TJ8fUkhPiWWt2Dv08URRxKfXhme
v4b5Tdj0eU+fvxm511nE+ihsPSbiTez/eFzEdmz7LWc0VoPBqcSiV8QW1v96
NvHhzjuH+f6OAuwkHh+wvwvfBchrsfEz+R571yF3gJ9e7O3gznKwWlJvX8gn
05E3j48o5u6vjow4alrE+finBv88yPq+U7Anz3tXg+EVzB3EXwWcNwt/fYf8
6LkR/dn/CvuLxnIemFrB2mzO+Al7f97kXKnHx7OQU6fa3kfY8zz2fpBnfwiz
T+GPfjU+X/HvBj5eqDeWtqLzi8gpdKhN4vc+8Tsxx2uFmTPA30v4KIbYnv7Y
0zMfP2b5/mLu3zbH8VM8V4PNpTWOhWJ+MmctKIm4rz/riflB5tvLuZvcaCEG
mzhrHfrXEJ+N6L8V/Z9pMvaEwWeRX0fH7xN930B+bb5zX3zyOvJXk5wL/2Z/
x4SIY3LsH+0fif7ng5F8sPIiZowmv2eQjzf1N0eUSJ5qXTaw/gRsXY4/FiR4
340/apP907g/g/sOEMMMfJEzkH3oX5b4UxgoR65J+G0q38ewflGTfamYXIE8
Bgw2c/9mbB6FvK7YudcBBteCxbtmGSvL8dHvkC9nzYNg9w72fAGWpxZ6rXL2
Pnx/x3nEA/lpMDBpOlw00nursaEKW/6QNv/ovtVp56RyUzGchj6ZZWB3gPGX
y9xJbRFfJ3x0InJ38qkbo5B7Tmc8mWsu05ktC7Gr2Pl1LzouQNfWCcaiMNmb
felRzl3l8FvwcSZ8tgjfrMVnD6HrO1Xmbq15F/ltbDjE3sZB4J98nJHy+uWs
L0E+jf3Lknx7jP3ra40tYawVrH2Y8P0z6LgD+Vby6RCx+jv2FYCVPdjwSW/7
ay9y1zrH6jnwEcitKZ+tO9qQP6lyLRFe8jh/OOe9zHnrOW8o570FfhvQ/wts
PqMiYleCR3H0lZxfVWwuuR57Lqwknvx2GaMB3zTKrxXGrvbsZG/vUue6cv5L
8LcXf/9iqDE7gfs7wWs7+FuFDjvJpdunm6+KOH8w/pqHzg8k+s9HLgev73JW
PhgMcmN3g/lTNfUr5IF1xrbq39HIiwttq+77HNvb046POPtS5KPgl2Hodzdn
Pg43bcp17mv+GvCQXenYKYb/RLc1k41ncWAttu3BHyuxdTU+vQG83DTK3w/x
vYTvrdx51mDfuRK8X1RtbAljnwj/KWNBmDgTeWeD6/Wz6PAF8lLWr2L9R6w/
xPqWlH0hn1yIPH2uuUSc8hn4Ka5w7BTDN4nl4XWu7epPeiOPLzI3iiPr0f9P
9a4Fm9i/BnlTvc8TB7yMPKfJ3Kgcm43cc4r7lRz8v5N8vg8friF/H2NMw9cj
271enDUCeQl7FmeZL8Tlj5zpWvAS8c6jtuwqMz+Kg3Yjn9Lm2qWczUZux/+3
4P97sWcm9l9Nvtyd6Ps37P2+wbmhHDmI3He866EwtR08dWm0L+XTrsjL8ecf
E38e5Ly1peYKYWod8lL2tCX58AP8cdkE117lfx/wPWau/aUa+h7392k09oTB
w5G3JPkzCZ0/IhZvzLEtqskD8M+otG1p5Xs0ckPaeFPNaUSuI/8nKP/xwXtg
q9tF5jrxU3fkAyMcS3Hy/7mZPWpQdV4e8pHTXNtU4+4mP36fa+6TDo3g+QT6
yYH97dPLya+h+HfuIHPI2eC7fqz3q+b3o37tGu3aoZ7pOvzTkTZfKuaPImcl
fCN91At/O8K1STVGtea9lGOlmHUi76hwbivHb+O+6UU+XzXqVs4vK3FtUI34
En/dzG8XDXB/sZ3c25zv+qaaezmxOq7OXCcdMpB/Wmf/CPPDkB9Iux5J3xXI
nxV570bwm0V9HFFnrhBnjEQem/CH9Fetba4014nz7kTf/GL7Sj4bwtyBMtdO
YfgvnP3NCJ+nnlq99clJ/ulbvXkb9vce5B4hOGsi+OgY4pgoNrtbHC/1tHuQ
f5Pr+Ko+ziR+W4vci6sn/4He5NWUa4/8+xryP1KW9dsW5OPb3BvrvEzkLTPd
m+j+tWB1YYmxJsylwF5DtXtL8dOn5McJ7e5N1I9nIn9YYWwL45nov22+59XD
dCLPmOJ+UD3lo/BD5mz3IorZUri+oMRcrBqwivtyq13rpMNK4p1R6VomH48H
n+0F9r3wsoC5HdnkxLGuJ6+Ah9IEL/eg86fsH3auuUUc8zBc063E/Ukz8/cz
f/yFfovozZKBXNFkbtObo1Lvl1L3G+L4Cvjq+lHmD723FhO/W5q8X/3gzcjd
a1yLxB8V2P7NfPeb6lG/Vf/ban7R93rkR9DvYcZGdPsz48FC2y4fnKz+CZ+s
ZezCt7sZewpdS1RT9hb7Dae3nDinO3zzVKVrk2L8BPJxVeYX4SkDeV+ha5P2
72P/9+PMfaopy+T7UueWYrYQexvxVwPjWuauY7RU27fy8Qx+z0j4Q5hdADb/
VW6uFef2g3v3F/t8ceyt7N2U9PuK2Srw8P5k36ecbuG+NeRz6UBjWtjeMdq1
WDX5hxl+E+ltpDfUEY1+Q+lbfJuCD5vZnz3Q9UO97P5sY1XxzKRffmyyzwu+
O7P9ZlYsFdP/UC/uGmMsSIeicsdY86ontZx/Rbu5Q5x3Wbvf7PK/6slc5lfW
m99UEx5C/u8Y1w71VCcR58yx7tXUs93Gd9Q6l5XTT+G/xtl+u8l/W8mPc/Pc
6wqD+fjj1HGO7TxybmSl34zqLdVTtBPb9WnXXnGceu+92LA66Q8zuPuq5P2i
GjwZX40vt69lc16534iqt4d4XxXDD8UFvkuYUu/6dbZrvWp+D/x79Hj3aor5
NvRdNNF7Vb864bKsaueacq4reHkS/z/BKCH25zDumeVYKCYb+L0j6Qf0RryJ
szfm+X8luk+9RtF084HeBFPw14+Jf1Wjl6F/VY65XJx+PvW4NOFD9VNlyAvb
XRvl7zbkF8a5nqbRcXi1c1a5qzfDVu7el7yHhKn9cPuKQq+VPeKSCWmfpxzL
Rz4+ia98vg99Hk7ef+L4i+HK7aPdb+l/CueRa/8D2+8vng==
        "]], 
       PolygonBox[CompressedData["
1:eJwllGtMzmEYxq/KsWwOOURMxWzva3xgSt4OhEpJJe86MqO8o5PEKHxwikxt
fPChNgtvbdbZevHR6IDNvH3zzWIyFiIfDOH37Plw7fn///fz3Pd13df9/CMP
VO6uCJS0GUwFIVulYFCYIeWFSntZZ2cTXyC92CidTJROgZ5cacZiacQhpbE/
HYy7JO8i6bxbqkiTKsGFTKl6vvQyRlq6XVoGatdKNeD1aik2XDpYJK3nfR2o
4lv3EimhUBreJvnBYSfP1PLkS6mpUgpYnCPtXyiFs9az5wr4vktyUGuC9T1c
muBSCZePiPsEepLIDbKjpVy05aOtn/cBdE/heRqYDsbg7CXPPPQeh+8J0E8P
uujBsVgpKIX9YGS3lAiHsE3SX97/gTI0l4If1L9H/Qa3/W7ii9iXwP43nEun
f2lggP49ob4PHtXU+0Xdxiwpjh7HAzd83HDNirbcjYZO0AGaOS/60sR6o4D+
0LfrrIFoDQLR5Bsk30ryLUdDBPBz7hWoI285eY+Qt4weXoZXaY71wHiRgIZ4
4MWbfXjUylqHlkvgInjK0BQTbyRPFXkqybMjAU2gjvOPif/Ay3bOdYB3e6RM
+vGW9dkO6TmIwM8++Oc4rX/Gx0HjBwgjn4O8weT30LtDoJvej+JBHP2LQ6cL
rKDGhwApgHgtcR/xYbxq4f026ENzA/F2etAJusADvvnAVfozl/29fJvMk+7A
JdlpZ87MnpkZMztV6G2G+yie/iHnb7AFDh85e5+aUcTLiUe67Vyb+TbeGQ+H
0Ch8GWSdBa8QEAxuwalpje2X6VsFeo+i9xp6S8j/k/gGtNWgsbbA3htzfyLJ
44NnVL710/i6Cv5D+ByDnsmd9IQ8c8j3kD4+SrJ9MP3wU7cPzjVwdhMvYl9x
hp0lM1NnqFME17MFVqPRWo+mNrR9Q/sh/Pak2ftg7kUo9dqoO55p77q58+fY
f5f9X13WY+O1H8+T+TbMOsasOuE/4bD/GfO/cTJ3HubPkWPvtrnj5n9i/ivC
jxj2T82zM21m2w//meyvxoMvvH8295t6LdQ4TX0vNYI405prZ93MvIfvN838
uexcm/m+z1yWMNu9RfbOmrv7H7jd6kY=
        "]]}]}, 
    {Hue[0.35278956470671646`, 1, 0.5115221411753157], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHlwz2cawB9HV6vBKtODROImRCTpCgm/nCQikbs51ZEDEUkqIhHRjmUV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        "]], PolygonBox[CompressedData["
1:eJwtl3lw19UVxS8OYGFY1DClIzsELAFCSDoJMZgEAgQCPwhZWEIsS34/yxJC
sJRARGdaqUXq0tqqiKBSAbFuQAEdOp1BRa1Aa8EWZRFsKTgoVFBbS4GxnzMn
f3wn9+W9d5dz7z3v/vrMXVzRcF1EXORrzbesIGJN+4iaGyMOVUX0mBTxt04R
p69nnRvx80TEGc79qkPEA8gD6iL+2CPi8QERbZdG/HB4xJvfitjROeLh8ohR
tdY3FX0lyOMKfXdpWsSj3L9QFPFku4gJbSI+Qy6uiHj2Bv9vR37E+WkRr2P/
r9j/DHnLrRG1/SKucObYuIh/4990bBVgc3FexLujIn7L2QKC+XRoRDI7YgS6
V6KvfSnxLcKfvujvGbE1FdF9fEQavi1F5xl0n58csQ19c1phD3k7+tZi//v4
O5X4G6sjHuT8W8R0FqyWc+e69i06KiP+hM9tvx2xCv82Y+/adDBB31T8u4r8
NHee5Hw95/ujaz0YLE8zpsex9Wfi38zdHJJyEHlOGX85/zExfJ0TcdtM25vZ
MaIQOS3f8VQQz7EkseJzXou958Bj/OyI97tHFN1CjsnP5VLjm4ePN+H7l+T4
AXx5BnuXkH9Uad2ysUKxcb6U8y9iYxi2jo42Nuu74C+27uJr7OIc7MqKqCr2
/dXoX8b97fnOpWwWEU9H6mNDF2NyGF2f3hHxDb73TQd7sOlPzZylPjbhfx5n
L7AfvSLS2b/Afgo81uLvANb/Yr1viv1Tjt9E3s5Xf4Pr6RXk18jZ4D4RG9GZ
ovYyFzvXytcU8GyFvwUdnTPl7iF8qiC+BnxcTmzLxrgevmDdgD9bap171cBz
yDv41kkGv8uDIpoqrVv4NRP/3eW+Kx09hkU81ZL/X2MznfwPx6eHOri+5lML
JdTnPLAuB5ND5PP0cK/TWU9O2gfpU3+txLcj1MyzndxPS4j1g4RjVb/sZN1E
vOv7uf9+Q7zJQu8Lk6MLIk6B71V09wbPc/h2f7XxVb2tRn55jHNxkH4qxP/e
xLOvi3PUjX6dVoIe7G/rT35vI6dVtqWeb0LfKL6X+rneW5G77w33/V/ifzd0
30SOjqP7evBIQ04kHatiFhZ/yTX3yEZ3er3tkIiTlMQ338FP+CA1zPfFOTeO
Za/CvaMeOoX8fpW5TP4sx5dD2d5T/R9ivzcx1nd1Di+DT+vptifOa4Ncl3B+
NvK/KnzpDd+9Dd89Bt+1oZ/WF/j+E9xfQHyXaiIeuZkY8GEk/JTF+QOcX8v5
6zl/d7WxFcb3IP83x3elQ74055urxB+HwWNbrffFAa8g7ybf6/DtUfS1Rt/z
ee519VMx9To/1/ynmliF70XDnDvl8HfgnZ1j7hSHXmqgb+CQl282Zg/j7+kc
88E0/PkP2C0pc203sr4F/+bWOpeq4dnIDZXudfV8Jb00utDcKx/GIB/Jsm/q
+RP4l09PzOX8G/gwHnu9Jjm3wvwwvq/AxkZ0nQCjJuQVRa6Nr4j3aeIt4v4n
7Xx/MLYPJ90rqhf1yoBq+yqfr8DtX2T7rGz25Hx1rnOpnKbA5yRvRF5r/28n
2Ba36BdGQzi/kfwu6ep+/ZD4+lZbVvwb2EuUmQ/k7zmwe7Dcval6vBN/due6
F/WGHcfee0XOr/jqIPIjNeYf1UsJ/LGr5bx69CjnO09x/KrxTsgXB5mrlaPN
4H+5xr7K56+RMyodr9aFxPIHMEuD+5eDUQnvXYcs+1IDX8xG/98zvL+KN2IH
vbU6M6Jfuvl2TmPE7Y3mZnH0Obii6yC/JXpTPuF87izflQ7Z+gfr3ayHsj6x
1JwtXdI5C13VCb+n6uGqhDlcXN6fr479+zMt638p1is581Qn11Qz8t4M14Iw
WYf97kXmInGKuGVNtrlfb059qXtcva735z329oxyrpXzU0NdU9KXSXwLk45Z
/urNOU+8dyTsq3z+AfKVDMemGA8M8ZsqPPTmzMNeu4R9lc/tkX+acC+qHxaQ
232jvCc++GhgxE8K3GvK54gy95zWel/+ST3ty3G/iUO3wOUvZpsb9F41EFvN
FNeS3sCZyBNLzF3N5LcJe7unezZ6HYxeRV6U57Xe6y/pvSOD3Cviv1nU0xns
l3c1Z27F9rY7ze3q0UHUTkGF8VW8I5BTpZaFgWpjUcLYiqMaEp4xhL8495rm
oYne05mryM+nPItphtEs8/tC+7qJ96k+zzWgWhBfJss8I6ge+/DNbDQHi4vf
gWPT61xzys8mdL6N7uIa46WeK0JeM9qxa2Y5gP7HszwvvYu9HvXGVNiqJ4N+
r8x1r6hnOoDtjEa/lXozT1IfX02yv8K0Ic9vsN5izbgTiOVsjrlBHDEO/5sm
e7bQjHE79fNBsflEHPNduOWxDM9XmhfemBHx4xl+K3W+mb1ew8wvmgE0W1zL
8r7qX29zY6b5Iasb9snnHv63v7PfgNeQm6vtjzj2LuS94/1ea0boDbYjy1x7
qkHV5gvTHIvm04+p13tn+C1Rz61C/h+Y3Uru+oFHWdIzhPCR/vPEtrDC3CY8
6ys842jWUT99NNQztdbi43zw+jDpWVb1oFn9F8OtXzG8yvu1teW9U84KJ/s3
hPBWj32OvglJ+6I7ursv5VpQTah3x5Y4Fs3cGzQr5Tn30jeC2hiZMleKz8SN
exe6FpXjPfj3Avvre3oe3op/xyZ7FlbO5pHPZxLuPfXgAM3DGc6dctQXvDqM
9dsgPk+Sy8HU7P6W308nwPfzYs8Heu8vIheOM36aKS5Sv09M8+wjTupILMcH
uv41k/Sq84whbhHHvAPX3JfpXCgnql35LN/FF61KzUE6rxllKPe3lbtWhPd2
5J1jLAtP5XpirWtLNZZPrVwssK+aUe6t9kyi2eQt9PVE3/ykuVUcK+5eVGau
0byj2Wn/eHONOOce1t3rfFc6jg30b0phI4wy64yR1vrN2Z913zr3vjAQFj/L
NDeII/R2rR7n2UYzTsFM/4ZR/MrhSynbkC1x0i7w+j++IaT7
        "]], 
       PolygonBox[CompressedData["
1:eJwtlXtM1WUYx79dV/PWZlMrLjHuhwSRQuUMEWSDlITA4gQIimgFdCDOIQgV
u60Zq9nazJVgunXZXDlbN1utrZqCUv/kSnNRuKyonGa3ra2kz7Pn98d3zznv
+7zP9fs8v5TWrtro5ZLWg6tAuFE6eKNUhHyqUhoCs5ZI0RSpvkMqBWVgY67U
Cg7nSDszpQd6pb9XSn+BuztcP4L8Pk8aTZRSN0qNzVITiPdJE1lSDLkaG1Xg
UL6UmyS1t0mLWqR8UFUsfZQuHe+RtkekR8APRbxPlfK6pGwQAsl1xDJPWsbd
SuItB98VSt+CYz1uYxw5US2NXE8+S8m1RLoaDOE3Db9r8JuAz0QwtJzcQS3x
d5LHWuR2zgfBCfRq0P+Cd9XkPEjudyJHqNfeRn9vdqrQS0VvB3qd1O9l7HyM
nQpyqAQD5D5JDR7u8zpaPUvI9xCxvkmsM9CZCapAww3SvBC61HYANHdjO42e
Ia/cQC6gld/pnLUhr+H/tWCS2h+h9onUvp66R5q91lbzXTkeew2x/4mPP0BS
J/Uizv3EO0pNj4LN1HcX9b4P+RP2jmNvIfZasLUedPZ6/6PIS+Q/DcoWky+5
H9lEPyBWOagk7grQR08G5uLjDvIi1hRibkKKeC8DN4elYfz146+oCT42eY+t
170Bb87S5/lhj+tezk/i8xSYscT7VUedp+qln8Er6DaidyGKH3TWgVziWQgO
EN8e4kwg3ku3S/+Bfdjtni9l3OW+LYY4Pl7ERjJ3WWukTJBGP97PkFbEve/W
/1vR60NvCp8NxNBFLPd0OJeMU7HATk+X19Zq3M7v5zm7H/kG7w6CgsDOYuTT
BdIzBc5p4/aFBuk55vMi8jrqOQfsJs/pBdIL9f7e7GTFpHNwKRTznlhvXjMf
2C0jjzj9joFtxLeNOJdTu37mI8p8HOP3znLp2XKfdZv5xiCf2dylY/MXbKch
l5LDMrCOOoxSj5a4c8k49Q54Eu7mh3wv2H74kNp9AMpDrt+M/uPoRdHLDPmd
6RgXjBOTm6V/6dG5Aue58f1XzqY5u8hZNn16kH7tD3v/rI/WY+v179Zz8n21
yOfB5uI8b5VMfLzdY/0AW4JZLAn7vrO99xBvdrBTusjt0xXSJ2CQ+xp8/biW
GYIXi26SVjX5nekYB42LHUFPF4R9hm2WZ4MwOc6K+G6zHXcbeCIB3rT4brMd
91hQi0cjvittZ2Yyb2PM3dk8nzmbvXzOxjmbynN+GE/24vcAfvchN9h8MWd1
hc4R40oSPB+mbq9vcv7bHNgusp30dtCrtyLed+v/OL3uhg9b4UVp2G2/FNTM
amfzZXO2OthRq5Aj+O3Hb2+hz7vN/efU5DOQEfCms9h3ke2kFPI4Sh5nyOM9
3uTAsZPtcAOMgTlB3a4I+dzZ/I0F96fBLegfLvRdbjt9Jrt9mJhPV/uutJ35
VbvbPYWMFvtcZMc8JovtH3Z0P3Upoy7f0IuJAPb7DHiXHk22OM+N7+ejvlN+
Q24N5mdLh39v7LvzJfZqsfd1m38z7NthO9B2YSU4gb0KZEncd0hp3GfRZvJ/
mNVy3A==
        "]]}]}, 
    {Hue[0.34014228252864126`, 1, 0.5290337626526507], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHtc1+UVx48ttYuaRjeTLKeZZYpIgoL8fj8BEX/eQiAQUFDAEBBIQdPc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        "]], 
       PolygonBox[CompressedData["
1:eJwtl3twltURxldHJBUSsAERgQjDTYiQhBSCAb4vJCGQwEfITUK+YIAQCLnS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        "]], 
       PolygonBox[CompressedData["
1:eJwtlGtM1XUYx7+1kdiLtriUHNCJzm5keZmgoBwEXOgEOQdQhFMpNCQljsPL
4WKzGZuWolteXhjRlBo1NZgzs5qXtlovxKaNIKoX2pvc8g0tFWamn2fPefHd
89/v/3u+3+f2ezLrouHmRyWVgwSQly/lgrdKpfXJUhT7K+jm+0y29GSRlAQ2
rpV+TsO+wJ1l0mZwco30GGfXn5eWcqcQhCNSCCxdIR14XFrFd2uV9PHTUgz7
13zpJhgtQQdM1EiHA9K6LOlNfBrBAD5vpEvjnG2YKzWApJBUlCqlYO/gfxu8
Dd9xeHdiO4jrBrF0Eue22dJ2UBmUKsAZkk3G90vsT8XSFfB5jlSWIgVXSe/N
k/aAOWHpT+7Nxe6C5zp87fBmkusMkIxOA3pJVa5vcQy8IvWDTfgkPEUdw14b
q9ERfO/D8d1az9ly/69SqoXjPnYyueSjlxjyHC3XDmrfSO3bsX+/LN0Cx6LS
iZlSL/bBcppGjRLJbxKo514t9+uwU5qkHzOlADaXHPPARe5fADdqpXvU+TNq
Oo06TAUZ1KY3UZq/UJpHrLuJ9atqqRjeZaCb/h6fJC1iPj7iuwe8i04Tep3Y
oULpF3CnTMqillFqug/NLhDg7BvuZWCrmIvVYAs+9Zy1lPrM2ezZXfM5W+36
56o9bot/Mb1ZCW8edjw+J3exiwukJWAa3N/Cd405bYWrDdTTxzpQQ02j1DaC
bSK/S+S5g560kXd7ufsbTzCXetO3rApmBuzlu42zLmZzf4lzGvfVbM8nHc1U
+r+BHqZgYy/xH4xR19eZ2T5mN0h/CsAQPS7hXmue9D09+GG5cxp3Kxrvo7UF
zXTOA+BDejRKjofgaqnw/1sr/J/d6SL3/snSp8zbfr4P1Li2xTCMTw76r6E/
SM6nyf1yyGthNfkEn15QgE8BGrO4n06PA2Ak/t6HsWP0+EX6cJs3nULPUsEu
7saexW+bv1l7uyPwDIMJOAeJaYjvAHGkgTD3O9EYrfG+W/+/aCH2WdKpFuc0
7gb0XkW3EXsZn9nEXxTxeb0Yn3Ob9zrOFvJvJMvn0uYzJyadf07Kjnldrb6F
EecojvjOst11lr71oPEbGgfBB2CYmT3FXG/m3wA1Okat+kO+A2wXXIPrKvid
/q2kf39U+ju097gb/2b49pT6vrO99z+1WkDNHmF2O5ixdtDFjE0wu/uw+eyE
m2gEsXep1ziYgH8c9DAbzWjMZJb+hafvGWn6Vu+L9ecftKv4P1bpMVlsX8OZ
Ct+5ct9vtueOwnOUfbuRmmXANRWsj9dtXcS1TNP2mO2zvbypmMWHXRJ/Z305
vhttR75DrE8wfzvDvt9sz13hewFng2Hvs/X7IZ58J2s=
        "]]}]}, 
    {Hue[0.327495000350566, 1, 0.5465453841299855], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHt8DuYVx4/NvSUIDcmkizRl0iBJm5jIRd7kzaWfSESS5ubSoMibm9yJ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        "]], 
       PolygonBox[CompressedData["
1:eJwtl3lwltUVxg8dJKKGLSwCgmJEkRgEUsMSSEICiUknLIEIgUAgISBJIEBM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        "]], PolygonBox[CompressedData["
1:eJwlk1tIlFEUhVdRSpTmaDdHSNIiewhK0UxJw0i7YGM2JjOawXgpHS1Jp3wI
IsyUQJMSLS8lBAppDwb1UgQVGlaaRWUviXSjHgKNfCgq+g7nYbHPf84+a++1
9n/W+I7nHpsvKRksBMVJkg88ypB6QqUzFZI/S6oAG3Ol6eXSza1SAAyxHt0v
jaVL4+AHObPAkSIlrZAmyK/jfusSKT1NOgRvkeFOkB6CVXlS+UrJSVwLXyz4
mCmlhkmXqqS53dJP0JlKffKiyPOx7+T8AnlB5AeDPGr/psadHKkZIS0gi3qZ
oD9fWhAp9RFPcz67TKrifAt3ksFALXrAOdaLQ6RB1u82SZPgg0vqJf8TMZx+
HaDkALloKyW2ZUs1EVI1mtJ2oBH42TvMXj57kXw7Qfg+6S57DuJ6eOPAKfo+
CZ7j3y70BOGbx3hv+OC4h//3M+x9w9NN//PQcZ24jtql9LCWOBOPJlCN18Hs
jcM5ANcg2LsH7x3SX7fUiIdNoJ91HF72ue0MzCzMfcNTD0cYHA3EV2i+gvaX
LuuF8aSD++0ggjm0w1sEv6dQSoySCog+votBND4/5m4CPsftlDaAArR5QQ3a
LjKrbczmNvtDYMKDfqf0gvgM/6Pwo4X5jrJ+Wmu1GE3NXqmMvFav9dB4GYOn
D/AsljiyXRoGZ+nxIBrn0PgHztXc+UcMgTMUjOFrL/92E7346akyyfZoek2k
52F6j8mx8zRzPcF5gBod5PfjVx84CncINcqJT7gzAhYxy+9L8Yca39D3FZzH
vwB8jcTOgHQVuPHoMv51sT5CThmYgruXGtPEL+AG68/Z9szkvEFzPTpee+0b
M29titrZ9PDebXsyvUUzGz97Xan27Zg31ELtOnpodtmeTG8l3Pfj82ZmPcg/
cwvkMMN4ZukqtD4aPyc5T+GfeJtr/3/zDsy7Me+nEs0z8NbhVRaaMsEvevFQ
v4H619DXhk4P+92se8B/lXLRVg==
        "]]}]}, 
    {Hue[0.3148477181724908, 1, 0.5640570056073205], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1mHl4zlcWxw+DMJWE6ENRglijyKJJSLOMROI1sniTkI1ok1ANWUWCGmVa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        "]], PolygonBox[CompressedData["
1:eJwtl31wldURxpcWCAghaippUD6DYEMTPkJDIIYw3pDLTRuS3CTEhIiVBEUd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        "]], 
       PolygonBox[CompressedData["
1:eJwtlXdslWUUh39OIkYKlLBbKNBCqEhqSW+HtzZiiyXe0iGrLS10GOC23+W2
vXREMUaNCJiIqLRRgbqIiP84wnBb48JtK5jIKI6YaKWadGk0Pifv98eT8913
nP2em1QTKfUul7QRroIHqqX7oTdNKkmU+uqkgoCUD3MapE+TpCTkq9nSK5DW
LF1KltKRewqk3XCqhbMLpYHFUjP3XuTOF2HpbXgHCoPSG9zpaZK2r5Na4fNC
6TO4rVJaOoszyCLWQ3ASds6QTiBT8qVkWLBeOsZaMnKQe5egK0faPE2auhp9
2BY+HMWX55ZIz0NePbaIaZTYThPjGehfJR2cIsVlSg3obYQO7IRNNzqOFUnH
fex7OWsfpkgV6O2/Ax+xd3eO891imEBueoj3ugaXM8ud2TF7/2C3Hfv5+FHe
4vRUIn/D3u8w5knV8/EPeSu5zYco9w+j7+Owy4XlJBp0Ob+RnPdWUCPYSd4f
hJpG6a550ibk6HJpBDZytwkdNcgdIfyFnluoyzipPkN6NuDqOhefh9E/Anty
qSVs4E6UvWrkGE0yCn+kS/8Sx8U7qaNfm/TFzpbZnBRwd6q4M7CW83BZljTv
GukhfCwokVbAIdZfwIc87HTz/QwsjHCXHKQgd2FnN+ylRu3U6JuAq731wPf4
fQbeb3K99AFyLzE/TeyPIvuxcxGirdIPi6RtyMIbpJVwjnydhSg2urCVSP36
SqWsqdIUcj60gjzANn8/EnG9bj0/OeByuYnYiqEEtlZJW6Bjq/TnXPKL7EJ/
Jyzy4/mRu3X8roW//Tq/5NfYaj2RWvYTx2TksnLyCT/h/2Zyllbu+tL6cyJ9
2k0ufiYnC8jhfLjvZmkc586z9xa5fBM+Cru++QR5Lb0/HtrwaxD/WpGptewl
SL8sdb5bDNPxdRo0+Tk7h1+t3O9Az/awy7flvZiarIIEznrEMQd5Idt9J/o6
TNcR1qpYG/Zc3BZ/sEy6CYY8tzfiuX6zvhuDQ/TSKDKLs5lwmv1CzsWy3Zyw
edHuv882pAeN0Ob7mUl9HqGeT4yX1q2UrmAWXAkbmCcZzJXKSjcrbGZMJ68h
8vYweZ7B90yoQ08zemrDrv/tHVjPWO/sS6W2zJRQjDowC16P592TjxbOxHJd
L1hP1Ps64vHl9pi7UxRz/WB9kc63x9qymIvRYrV+s76LJ85M+vBb+vFxcvgY
tFGP89QjO8fZMXunsPsa9ifgx3783jKTmJFX59ELsIMa/0Wt70G+y1t/D77z
c9nnufoV++/L3tl+7Bxmrws5RJxH8e9J/Cslh2WwFtbAAdZeZm+YM7/y/v9j
Dgymu7lg88Fsmw+9vPc44riXONaQ89UG9/dRlzK+c3KcvU4/Rot1NrNjFpwk
tm5i6w+52WYzbgnvYoD3EWH2nWX9IPsnMtx5u7eL+frUbOaL//9l/2P1Qfem
JnF3PTrKK9yctXkb58/pAwH3n2T/TV/DEdZaWPvK//4y7N6TvasEfO7EZy/i
5ofNket9v1KbXV9bf5sdsxfH2gX26vAjyJw/zrzPbXH9an1rc9HmYwnflfRz
MfJ/Qd2C7Q==
        "]]}]}, 
    {Hue[0.3022004359944156, 1, 0.5815686270846554], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmH90zvcVxy9aoUL9WtFRpX4mni6RNE9+iKR98uvJFuQHiTypqDyJiiUP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        "]], 
       PolygonBox[CompressedData["
1:eJwtl3t013UZxx8HDZExGOM2BScExm1jF8Zuji1/bGzU7mMb+wFDt7FwuA22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        "]], 
       PolygonBox[CompressedData["
1:eJwtlG1M1WUYxi+OE3LDhIFKEi6MF98CDyRyIEyLHG6dAxxONA5tCYKgS9ia
UVttsFgs8UuYsxWENk1TSdic6NTkg36pcUxhfXBLnQ4WptHmCJyu1e/ecz5c
u855nvu57+t++6fXtwZbPJIqwHyw2SttAnkcRJIlL+wtl8r4nQ/fWCeNgXa/
tDNJaiyQcl6XcsHfnB3n7BGcgE0i6Nsk9YIXi6X4pdKOkHT/VWkKrA9KE4ul
l+HYgDTE2/lwBu8yQegdYqZKVfAoPiJgDt8nsJu1+BulXSAd2xeAh7eD3MUE
XGzT8AF2DZztgU/lSydBGxqS0PIh3Bhyuprg97jbDXLJeZR8c+A0dC4HmZWS
H613CqXCLZIP1PqkMLjM/YqF0gA2T/ATxt9TeBBfQ2B9LXfLyBNuL5M6wPPU
OBV0EGOGWJ/CneAffnfBddzVg3n49oA44h7kbpQebCVOSgJv0OAh/jyf02ha
V/H2Z+xWw2vpyRpw+G3snpOOwLN5xADZVfRiiZQFp1Ovn6jROL08i/0waOX9
Q/y0VDidpndl9E1JkfQmOfjL3CzYTPyKrq+wvwbvR1cPSAmjgbxT4XvovwsK
OH+yCF/k0IyOJnCN32eobQQ+RA79IIacGjh7g7N7W3kLvmCG3qW2nreoGxrb
wSNyeoncZuAFnG/nPh4eY1bGQQ6zdRc/uUE3czZ7g8Q8DW7h+6L1FL4JLvD7
90qnybRFwCi4wlsveV+FR+jnZbCQGA3EWgTHgh76f4N4PWjcD4apWzL+zlW4
fbK9qsF3Gn07QA1yyW8dqKOmnfjeDlfwvtJ8VPM/Rfqy2vXKemYzY7PzfpGz
r8e+j5r0gleIl4WW70Jub2x/ltDT8/R0acD5NN87edPF22b4PDbnwGPu19K3
uYCbVZvZafyE8PcXnEfvfPTQC99G9x3wGT3eY73eIH1dKn1T6mbBZmIGuwPY
z8Jh/NeAH/HtwX4AfoDPKnz/GXK7aDt5PTo7zxS6WbeZt722/X7I3h4jj2m/
2wfbizjqWEJtY+F+yxl/h+EfyPEE+Bx/bfjrLnc5Wq6m0bRe3+Du9pa7Obd5
/425HyFGJvq+xU8G/vpCrs8j0W+CfRvCnMVxVwPvo+bd4Db1r0uU/uOsGT9N
IB+fkWfZTzTfB0fxfanAzavN7Uec/cJ9Nr+3cV4HXkPjZjAVtf8DDqHnFr+r
A+7ObDICTmtWwNXWajzJd+Vfaj5R6761fdHZtx1IZDYb0ZwA+5jfSepWGHRz
bfNt9bK6HUV/NnZH4E+4j2dOPg66PbF9+T56X1LsZs5mby8aW9HS7XffX/sO
/w9brB3k
        "]]}]}, 
    {Hue[0.2895531538163403, 1, 0.5990802485619904], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3tw1dURxxdQQECBShEhSCNEIjbh5gbIgzEJeRCCk1xyc0Mgl2diHhJM
MIRHp4KYGIF2ihgSUAREGKZQEUpLa2sxAa28QniElvIsGKZlMBXaEaGINP0s
e/7InJNz9+zu+e7ud/cXWlDhL+8sIgWdRLqwHs8RiegrEsgQ+WWSyIs9RGLH
ivwiQaT4IZGpWSIbY0Q+CxXpOVfkXeSSkf8gINLMPoh8OPJlyG/tJXIjU6SB
83HIrAmK9E0X8T0i8lWVyEuxIo3dRcrTRIqmipx8EhusPeaa/l6sv08R6XhM
JBS7HdiY9oTIz9HfJ1fk0MMip/HxJH8N2F3F+TGfyEXsdknk7iSRFnxOiRJZ
slDkylCRqkiRFdEie7jbgL4Nzv9tAbuveto5643+Ys6bkB3N+RDs1iHzA4/I
JHRW8a4azlcjfwn5a7zrKO96NF5kNm+o6I1/qYaL6lc7sbx3G++N5r2nHc65
nF/H14n4E+kXueX0PIae8Gyw+qFIG/fWOj3rkV+kOLD/EN9SF4gsHi7yxnMi
I8HqGFi9hm87kuyNm5B93Pl8n/NX+L8vb5nPGkUMfvuMiIf1ZXTtQL6Ic687
HzAC7Jz+ZNZifvvpo7wlyXBX/B8BpzD0n8ZuV2J0Gf8K8K0z59nIvIbMbN4a
WgEm4P8j1pnE4tRgdBdynxgfINYbyKlxURYvjdusLMs3zbv48SL3wHMVv3d3
8t1YD44R+Xs3kbG8+5Db/2uOyD4w3AOGrXEifwbTzX3Q6xXZic5ydObj72a3
D7Lfz93zqgd/nsHXBfh8G/m4IvZPiXyL3TvIv4P8H5CvwZ9viWMHcW5E/8j+
6PCbXtU5DNkeTuYwsVvD33n2oznLy7C4BwOWW5pjG9mP5M3XyNsh5MIZl8MP
sff6LJcOkkvvBkz+a3Skphjm/bD1SbRhfoXzT6MtLlof+9x+Nfeedvh/SV79
mvPPOf8uYPmq+RZCrHa582WcXyb3loPbbnB4FlvN2NqaZzmnudeOTH+PnY/g
91LknufuOe7VURezyLGuufZ+xaHwRcsJ9bMtw2yrrUPYXZ9keTWLs3lTRP7I
2+MjRJaCyTf9yCHWN8nvIwP5PWj5p/L/CJpP6sOPUyzGGus4YpELLv/mvJrz
w0lWp1qvuQ5/5blSbBXBOSVTLPaaAwfIhXWOrwbiT80E3oTOKcjvdXm1Jl+k
Htt/w5+1rMPJg2nEqJ4YzSJXzpMDAg430s2fU8jHjTUu/Q+69xebP7XU1KfY
XokP+1hnkK8vof8z8i7ZY/kfyLK60lin8ZYGn9lqwNZ0J5+PnS3UTzpYefh9
GT6fxe5ofJvHeWM4eC6ixhPsjZrvMxw+Negc4XLvKfKtFbtbsBuFnjLOd2Or
Er76GXLnuHs7z+7o3QJ09EH/xcdFctjHLTJbY1lvIXcTmWXI/oXYjRoEhtNE
MvHtc3wLB8+KoMX0FdbwFPPtLvcGBIy7lKdnBIyX5rCfzr47eRUKllPdufKW
8qnyajy59iF+dAKHGPyqe85i1ID+7/OMH7zY+SLVakp5OldxB//JrHeQ64qf
v+Oex3HpII/FSeN1lthFuZ6iXPU0vwXY98TmIGIcwrvqqPHrQeuDm8i7/7Lv
hs67QeNl1RmB7nrHCX7qYnqO5ZjmWsN4649eYrtygfWj1mLTpTqH8/ZS1zdH
Ea+SNNvr2deuprS+412vieD3i9i+Cw4XWMOyjUtjsNMPjKrg0pIycq3M9qWs
CdjyU19e/BqTYrgpfmpbfSgGh45n+Q3cOoPbPzPMT/V3KDwzD54JY93q4qi9
qJZ8mo7dd8C+Ld5khlUYnyqvrvAZd6st5fVX6T1t6K8lRivd3fXcvVdOjXH3
Put7qXa+yWecpW//KNo4S7nrVb9xn3LgnzgPibJ8riCG89NsX81+Z7zp/L7c
Zh2t07e1j+VYHWk9Xcu0etS6XJJiua05fhSe2htCLGfCVV7rHW9j93VXI1pn
652fioFnPrwQxvufF/kVMm2898QYmxU0Jw8jcyfPZqfB6D430/RfYP1NlnHj
Dur4CccJ2nsjcyxeGjflHeWfwijTq/p3pxinKFcoZ/wE/3rSsxZr73L+RLJO
dLV5m1z+2M1dW7AzI93ujub8tOOHv+LncscJTdg5WAmHoeeLSqt5xec6mNU6
/pyDj42udpLx7XiG6yPKn9RbMvmZmm999wGGk5nrEq2nnOFNVYn2rq7s87NM
/1Ls5CWazge6lefBITDN+FrtVk8wHtQ4LmU/G1+L4avF+FbNXxn7Us5CXS2v
zLQ5Vflf+0DvaJthpuVYv9detjDR+pnuj1BnCxMM5+PoScO//vjwPjIXkMlh
frjE2gXci5jlMrKNu5XDtW+MK7RZSGeiWq/NgUOJS4HrIzW863XH581+40Hl
vVb8mUAOfQLm+8G8hP9riWlVvOGluBWjrz7fauGjdNOr+pdzPsrtdfasdjyv
9RF0M8weMD4VZ/3u4SSb4zUn5/DWJz3mc3KhzVgqo73xkMuBifgVjf6rvNfr
Ny5TTuuVbnO5zjYnfcb1yvmhxLGp0t5ygLU0xzDX+TF2lt2NRsdX+LCNeLWz
rnMY3sVPj5vZtP7uVdicr/P+CvC9CocsgUsuw3fx4ODNtxxSbBXjYa53xMVa
3mv+a48qcvNMC7L3OV9Hfv4v32pPa1DnFA8+lfPGqdkmp/I6Bz34ViE/9+qM
xp1q7raynsi3WUu/FSId/m8iv93p3JVlNaa11gRO59Dfj5iu8hsfKS/FwE/v
Byw/13KWRa5H0V9aqKH2BOPSep/1Fe0vDczyfd38fxPcwiKNK5Qzmukrt8nP
FtZd6ZYnOvcd8Rv+mvslERYv/a5aFGFzwvBJ9v2mcdH46Nyg5zrDhoD/y+B/
mTz8ONr0H0N/IrlykpxJYP3Oxegu6xCv9c3VxOcqPucif5a4NKWZ/zo7K78o
z+gMcos3bCcHvmE97jMu0pml3X0TnQCTOr/F8YUJNgvqDHaT99VNtrcnkVdt
ztaXrG+47zidy3by/k3ENAj2B51+5TzFUf2Zmmj9XrmiArwbnW+DdUamd26n
hx5lHeRwGMi6J8I4QblBuLsL/zsyrX9r7y7hjRt8FjuNYZLDagB2b2TYzK/f
o/r9pnGcm2Dfn7rX2Op8oP33Lf3+dT5U0ttj3fdLDGuc+4bS/q8cp/4P8dgM
rbN0XqTVttb4nUzjUOXS+ZyHuXzWb/EW11O0dzVSX/eor3rqq9lx71HWM1HG
exfBdmOivX0z63u8cQmz2Rl8u+LqMZH4d3J4Kge/Nd7yQecprVWVucTZ/wFj
Hho5
        "]], PolygonBox[CompressedData["
1:eJwtlnlQ1VUUx08CaWamhpiKMaCJgiCgsU6CPhCwAfTxiFVDFHCFUpJp0UYn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        "]], 
       PolygonBox[CompressedData["
1:eJwtlW1MlWUYx/+KyVsfcmKCYnV8SQTDczjEkeMIJyZqE5SDhUUIKkcL4eE1
WKu1lJeavTqprdJvLZfAF602hYwSzcqi1MqTluCH2povxXBjGPS7dz8ffrue
8zz3fd3Xy/++jmebU1QzVVI53AUzHOkeGApKzgLJw3PNU1I11OZINxZJyxqk
3WVSFeRtl36cJyV5pY8LpCkJ0hHsEkiFMfZfxc84dpRDbkNUiZSVJE0ukbrz
pB5YGZByIX639KVHisMOVEmnoJ73h3n3Lc8vb+DcmdIebDJnzoPbxjdcWSe9
FSe1rpA6VkrtsJD3tZy/AJvE90R4h1x+mSPtT5NWPymt4jkP+1OudB4ecGzu
87EHWX8I/NlSYazUuYY8q8kRun1SF6zbJFXOktZi/yGuW3ATNk6TZhLf0kel
NHivUHqR+ryPLU+XtsInxDB9LjkQ0xzOq+bcZMfGbnJ4nFqVUaukVKmNOrXD
3/j+kBr0ZZEXvxdCGP+VcIB146zv20JexHaOGHwbiR8y4W63vgep6XV834BW
YmhZTA2a6EtICsAd1o3Dw+QbicHvcqkX/yegA9/XOOMVbCL5DdL/3O1WD0YX
H+FvjJpeJqdT+BqAdtYOs+eFVFsLU5NtfK+AVU32/NXYTL6/auInrjUPSfkw
UM/Z6O5MvdWI0Uo0sfWTRyy2D519DonsPfog+TZKXvb5oJn4noOdaKeR9WHs
D9T1e5i+mT7MRvfYFc34SEErAas5o71iYgiBt9H6zcCOPCv9CxnU/PdoYsqy
mjbaPhfm+T7pMz/fycsHfwRtT+fS0zbq3wp7IUJfyunPEP6vwvocm+Npctzl
xpoQsOebOBajrUI0loLdx77XfDZnk7sXPeWjq2XYRa7eh4P2Hpv7fHGrdAEi
cCxZuoStJbaz9Mhx77a546bvpv8T3IV3+VZBH18i1hF8O/R/KlqIgtNofwBO
clee4U6UZdsem17XuX7b2XuWPaNoZy970li/1OwpIs57iR07G/0nptsem14H
3R5kY/+roT7k0RW0GjFaeYzn9XDH/TaO7cjgHYMrE39ZEIAwcbRxxs6Qve/m
3lfkswd6iPUadfSzbqJYKqX/k9ij9OyY384sM7u+oA/H6cdJ7DdVdv58V2W1
ZDTVT98j9D8FHQyhh2F4k7nTyfwZRFsT1H3SsffV3NsR7uxh7uwo9gRxHIcW
YognzuexR+jrIeLqwvZS1z6YxTkJ0MKeMHubsfPJ1wNbWFfD+hLsr2hhM7ob
3sF59LYDLpLzBdhQig6ZLwXY31gbgUuQQ80Gc+0dMXclRM6XOaOowM47M/fG
qHk0ez+ll/XUaAa1qsPu4FsljHJuE+cur7T6MjrrdGfrAVf/5h44j6Bh9D4F
31EwrcD23fR/E773sP48mqtjXS18TW17iEWse4PaJFCj14tszUztTH4mzyvk
G+L8n302HhNXKfHFEOfT2PQG+3/lbbC6Mfrpd/u6NsfeO3P/SqhNJnk+gf0T
H39BN1r4ihpdx89NuAVhZtggs2lXqp21Zubu5/39nPd2sZ3nZq7HM0/iIBbO
4KPXb//jzH+dx+w1PtzZa2bwBwE7y2KYZf8DP3xyUg==
        "]]}]}, 
    {Hue[0.2769058716382651, 1, 0.6165918700393253], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtmHtU1/UZx59SZ2KlpiJiNcEZCnH7oSDgBAUEjkdEwPz9JLkI/GRcJ8qh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        "]], PolygonBox[CompressedData["
1:eJwtl2lw1tUVxg8MlEVBlCwsiiaZGJoUyCKBEEtSw5ZxCPqSyhtSBArENIRE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        "]], PolygonBox[CompressedData["
1:eJwtlEtI1FEUxj+iFi2k6GHazgKtiLR8jTNhD41qkcaMlTqWz0rGzBa1CozQ
Io0K01Hp3TKjRS9MSMwKH4EZarUqy02ltoiix0Lqd7qz+Dgz9557zvm+c84/
rqzGf3iWpI1gDqj1S1HR0kiG9GCr9BAUJUlBcDdHmr1Iuo+dnyzNA0UB6ST+
+7BNQenNUqkZ27ZdageBCskPwkel6XipFXs2S2oEP/dIibHSb+xn8nwCUV4p
iXhPqeNVIbGJN1zo7syn8Zh0M0FqwI4ckEbBknTp40JqoK464taDMc6OU2s4
F2STN9ud230ZfhP4x+AzBq9R8Bq/S/i/xaZskZKB1yO94Gz1Tiz1pFDXoN/x
Nv6lkTgl2HOZ0nmwASEzwTr0qMJ/M3xWVkv5y6QB4pWjRQX4s0Pq4G1PmtPC
NLH3FqeAeOPcBbG98HsCTsH3GrxPYzvwuQWO5EuV6FeDrfG6Puwlb902uIIp
tPbxZhLrKZEywI910nfQBI9o/Juxu+nTLvCSt92cdRLrKjrUwv0Kdopc05ku
psXOx+8EftVe12Pr9dI86T1n7zibOURe+LZ4XO9tBtZG9EgKuPxWRzW6TpGj
Er+UDVIqGA9Ja+LgjC6+cmk9KCb23CX0FxtC9yoQG8kXgz3D/wZwHd2vgQSf
tAD/Y3mOs3FPZp7vUNMteuFNd3N8L8fp2BHhZzxbct3ctGI3wSVEjjUB11Pr
bXGBNITmpdh+ZmoAXIR/E0gn7zLytpP32X5mGOwl72PyPq92NVqtYe7j8GvL
c1yM0wg5esg1FnCcjXsvGiSixYeQm3Ob9wvkmFiOxjVOL9PtIPpNUnMIPX/g
m8abft5O8/tryO2w7XIze1TJPoWxXV6XbzTgem8z8IuY74ld73MzZ7N3mRqX
U6vH5zga1360aSFfX67bHdshm2mb7UFqKYDvKviuoJ4B/Dwet0+2V7aHto8J
6PcIHeOxN+nDDPN+I8d9Z+x708/7buLsy3A6mp6TfFf+Uv+XoOuz9dv0/9+H
SE2zybWYOJ3EG0KDDvbqdpbTwfTo4ywVfb6F3LndD3PWhX8s7/4BhxsCLQ==

        "]]}]}, 
    {Hue[0.26425858946018993`, 1, 0.6341034915166601], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl2l01eURxodNEavCARIWtUEOVMDQ5CYQuEASTYDkgwmEW7PcSoCQ0Ga7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        "]], PolygonBox[CompressedData["
1:eJwtlnlQ1GUYxx9ME6lEhkvwCGrMK03AJFcDDVH4IxbWnVjYEvOq5NhI0GbK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        "]], 
       PolygonBox[CompressedData["
1:eJwtlGtMzmEYxi/GUIaNaqLj5tBLVu/flCiZiT441Nq8ibe8wpbFl3LYnL7w
gU4YG+Ywhw8YhmkaOtCa+VDrQNacEzNnQsur/J49fbh2v4fnvu7rvq/7eaJ8
mzM3DZa0GAwF1eulH+HSvmKpcZrUBNqWScfGSQGJ0pqFkg+ELpLGg9YMqTJI
ekysXSedI7e+ULoPHoB3eVIXuO1If/ivCf59WeSGSHuJq2dIXuBwxg0i3dJJ
zl2Dq446tWDucqmZ+snENvJ7+L/KsbyGfzIa54eCldIoNI0Gs8gv4lx3PH3k
UhfspF4QdXcQC9OlTeAMve2Guz1BiqNWPLiQIp0Hbn77OxY9S6VsOD2gmBoe
armp+Znvn0y9JL4HSw2Z0hv0vAa30NdN/Qb09sdKfcAhJ5vcrXAkcKZxIjoH
+jb9t6PnCfiSIw2aIF3h/HN+fwauO9aXGvjqwU8+33Dsf+ZMBfzl4C4zCsaP
O8RA8gPAxyJbq8PooL9/4J5LCkNLb7b0CL5f8FU6VrvpwczLzO0389vCf3OY
5wl0byTnODEwVRoJdnmZK/hYIM2MQjuxFk7/eOmIy9YyNV/w+3PwEjSFSUlr
pXX50nS4L1PDRa1poH8FPOT+i8GDBXgBPMz/BT4E4UcJ30tBCXM6AGbNYWfw
9DCe1qDxLHwp7FAKPcwDD/HEwZsxSdYr45mPswHkRJPrhSMXpKGnBV2hcdI2
+tnutXqMrqvoi4V3A3qjY22f3+njK/hWYPMNzxt88zOfTmIbMxjO54suu8Nm
lw+iuwL0LqFn+vETk9faeYRQt4iaxV57H8y9uIl3Q9iDHzl2L81+xsBbxXxc
xCS4ZoMRzOc6fMOX2p5N76luexfrmMkv8ofC051jZ2ZmV0ZfpaCd3rI495Le
WqnXAvYX2zvWzF5M5Q5PATGF1itfvvXEeBNJb/loWe+xb4J5GwJ5I05wn55y
r/zsYCK72Eccloa+tAHvQDBevkLzKjRPRsce9nMSMQpEgx78j4e7l30IZ+YR
sXY2ZkadzDwOD7qI73h3qqnRlWHfI/MumXtt7ncBPo/C541ZltNwl9LvJPrI
oI8cdOdRI9RlfTH+HObMKbQcGpiPmVMJ+RPhKSN2wvs23e6H2ZP3aHCj5QPx
NL346clJsO+HeUfS8bcVf8Pj7D0x9yWSnexAc0SmfRfM+7A83+o6yl29hJ7L
Lnu/zD3rmM3us8PlnP8PwIkfXg==
        "]]}]}, 
    {Hue[0.2516113072821146, 1, 0.6516151129939952], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl2tw1tURxpekVrC0KBIYQavAGDHpmyEECIRLooGEfDA3MpAbJs2bNy0k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        "]], PolygonBox[CompressedData["
1:eJwtlmls1VUQxQfUBAwIUsAFjYIRsbWVVoQuYKttKf1gacuLlBbzoK+vKhUq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        "]], PolygonBox[CompressedData["
1:eJwtlEtsTWEUhZdWMUMf93pMNOLVxqslty5aiVdNblttKR0IJcK9elEXFQMD
lSBB28RrgBGJRKKCaAfq0UqQtlQk3m9CJKaiIfXt7DNYWeec//x7r732/v/c
DcmV9WmSSkEGKFskxcDTemn5ROkJnFsiTQBF5VJftjQP3gC+8bweDs+WxoDj
tdLzcdIxOA/kgxLW+/mvuNxjWKz7NdI9ULZLujNZqoAbZ0l7wcaY9DlLqoOH
s/8s8YbBQ0EGyFkhZYPXUelNSMqqkpqLpRNgC3u+sjcOz83z2OXELp0urQDz
K6UoGBHErcv377a+cI/UOVVaAPcHte8gRyfPd8CHuHQ1F40R1241HFkpZaLh
MNxWIF0DTXh3EITQ9Za1HDiP9fc50jT4If88At1lUiu+pBdJg2hXiftlvr0i
71byZyWlVWukanCBvA/IH0r4fovTTrzp5OiA+6jrNs9P4UghvQLb0ZEEt6K+
9oS1XjzuAV1B/vvwTvz6jm87Yu6j+ZmZdA3ZSa/H6pqJtsv4NgNuZGD2gW3U
NzIsJeCk5QS7WX/Mf6laz286chKuP5zw/KajcIlUAOZTWwZabsRct+lPI28d
+YfAmezpYu/5iHthngzlWyffTvPtM734AoqDHqb41k+/noEwsxICJ4LZbKbn
c/EhgR+L8aWKGqpLfbZsxjYvJN4k9DZIm4JZHEu8v4ulfyCTOl+zdzTchM5D
ID3Q2mZ9I0YcZDd4nBD8h14NgFa83kedz4h3jrrPgx5maxl7++pdp+kNB7Pz
JuqzbjNvtVhNu9l7hbpfxn0ubT63Rz1GL88daG4HowPPRsGD/Hub5yEJX7N/
avB/NbjI8yA1Xor5Gbaz3MBZ/YXOFHw95r25CTfzfws4RR37+XYGbue9Y5bX
YjU9j/ja6TL3xjw6TD3jmZGjVd4n69epiGsSmlqJ/RsNLTHXVBPEtNjvg3P3
Lu59sn4NrJVO0su/8FX2pNudFPFZspmyGbRZ/Eifu/HxE7wGHOC5ttLvN7vn
XsTdy1dxv3vsDrLeWQ+Xpnifwj2Q8nNt5/tHBZ5zjn/CTfm+vizld4rdLTYf
NierqW/dWHLW+Bmxs1If9fxrK30WbCbmBHNYWOm+mr/pwVynJfxOsLshjTui
hRrv4ul/kdsPvg==
        "]]}]}, 
    {Hue[0.23896402510403947`, 1, 0.66912673447133], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3twFdQRxheQse2o5WGgVdoOjwkd8miSKw0KJUF53RmbhJuoCQESuSFF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        "]], PolygonBox[CompressedData["
1:eJwtlntszmcUx78dImSXupTMsBjBVIuVKaUt2pR/2mq7TC+087ad6et9pUqL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        "]], 
       PolygonBox[CompressedData["
1:eJwtlVlMlFcYht+4xCVGRQXjAkmhGXV0pi7oKAyIG8IN6GCsQkHDDASQCqUN
Yk0U3EGQIhC9EBTUqrXqhYgUG000GmgTEuOCYtWmajG11jaNTWwT7XNy5uLJ
d/6zfPs5/wfZRb6NAyStgcFwMl76GgqYyJ0g5SN7F0r3oGKBdDVU6l8ppcyU
noRLn/mlbVlSOcR+IV1ySF5k6xLpGDT6pPFhUgPy2nLpOsxdL0VDW47UHCFF
zZamsv4Y3aexsZo9H8OWVdKXcDRBOoNzZYw96L6IjXCn5Md2AOLQ5YVFcGuy
lIBMwr8+/MtkvRTfNmVZnUb3KWw8wpYDm88D0jNY9ikxR0qJyDC3FAorphPX
RKknXVrOdyJ8xdwd5qozpH0ZdlyDrEmW9sPiFdLtcfgwX7qxTLoJhxh70f2+
UOriuxvy8SsPIoijnXhiiOsb8noadpCPZOI9yTgA8YzzmcthnAsvieE3aMf/
6eR2SIy0HdsVMDtWmjhe2kOuCvjOh378e4efL5AebM+DllRiw8/WVJsbk6Ns
/HlIzpLJ3bR11ARcsJ2czkA+x2bTaKkTu8OwORwqsHMe/3bOYR/jHTANH5qi
qF0RdqhdK+SlkOex+OaRDtIXhyCSnnoxQlpAzrzkKA62cKaZs1uRfdTxIYRi
dxycpTbnyON86udeim+QQP4a6dM++tRBjo7QT+05tr9Mnw0gXw8GScXYGsh4
ELzH9jvYiE/9+FSMPJ5Lv8I27B7BfjnyaZL0C3SlSZfJczeyivlW1iuR6fRD
htvW2NS6ei05wpcaZARxhkMJui8QYz13ah/zz1jf6rQ1MLUoJl+jqZcj1tbK
1MwPs0Kwjb0r5PgqdLvwA95y1jWFeOmXu+QhBL/2mHqQ4+EJ9n6Ze7bbZ9f2
Iu9zvhfGYCsOvZXo7+XsPahivYqadnDmEfauc+anNBu3ib+E2ryiTwqozb/4
+x94yXMLee7MsffO3L8W4jsKLmJ+Q05rTb2ZfwpnyOtL9pfTI5XM7wUfPVZI
XXan2F4wPTGJs79ytpC5yR5bmyLG+1mrhQA++CEbn74dhU9Bf4xfG5h/jZ+l
rJ2axb3A3vqA7WHTy3Xo+Qd9bo/10/j7F/dh4CTpzwx7d8wd2gU7oZ76nqDO
M6nLj+j8ARLR24PPXYw304vV9GIZ8nfsvIKLwfvY5rPvh3lHLlOnEOr1hLrN
IF8u2BB8WyOdtodNL2di8xN4HKzB9zG2980dOEz++olnM/m7wdlqzs5z2h42
vXzB9PNI3gtijCa+uTCUWveat2GVfbfM+9XAvnqIxqc23pw5yCxylwkH0PcW
vd/Ro7XEfpzY64ps/UwdO9ba9U6kn/0B+Jw7VQLN6PkbfU3IZN7Kpbw1Sen2
n2H+HX8wH08OXiN99FkafEhNomA1eXMQWy259aO7Bxu5TuuT8e0jcENV8O5U
IkuJM486JNJDmxiXQR3np6BnTcDqNfrNP8n8m0p5137mXUtl//+mOVZr
        "]]}]}, 
    {Hue[0.22631674292596415`, 1, 0.686638355948665], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtl3tw1dURxxcUixRQiw98YEuEaIwhN6R4w0VCzOvmagshxJqQ8E6D5Ca5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        "]], PolygonBox[CompressedData["
1:eJwtlX1M1WUUx48OikwQByK9rcnC+RICotwLFJd5gct1SxBwAQLxYiDyZnop
4VrUoAkT0c1SGTUb0kRrLW0C1nWuSVuE2h8JA6fmKltZf7Rabk1rfc7O/eNs
z3Pveb7ne77n5besprWwZb6I9GAhWESxyFyMSNICkV6vyOk6kVPYmgyRRMyR
LfJCmMiGaJH4fJH2TSK/RfGO345kivzbKJK8yHwOO0TqN4v4lohsfkQk1iMy
VSbS+bjI19y/575/q8VqDhfp49y9ljeRIjO8iSkUKcoTGdW3cDrKPRS85/jv
L/Dn5YocJ+bYQpF/4HAULmHphp0N3jj+B1tFPgkVqSLGIc4frSYnrIrcqrFL
+E+CnbJYZDv33CaRAfi3gX8d/h+S41vRdv+A3OtbDHuSGAt5e8dj8TSny+T2
KPrNgpdIvMXgXcAnnrOAf7tIZHetyC7Mh05tWDf+sUuNXyf+F8H7DLwd4A2A
N8Z9FFsB55WYP9dy/5tinUymVg7jppyH4PouOfdHmmY300SulBlX5XyVc5LD
tFLNhtAuzSfi9Bkn5RZ4WeQLrL8Z7bB33FZbrfEe9O0L4ivHWfAji612WsMZ
cu3F5098o3hzgrdxLnhyvoqGqQW8A/sstoS3MVgHfLL4Pw7+P6PHQ056kfsI
9x5qcZt6B6j3SmJcA+tEmvWG9sgWdMlBg2/xfYLfLoG/F87+ZouhseLh+wz2
A74/Yh3w+x1+9yJEPEnUl/t/3GOJuYr6lm0TKcW8YGzExkuJH+RznvP+UtNa
c+rl/Ct8f3HaG32b6jAsnYFTYI8kW620ZtX8P51m2qmGPfA6TX7vaz78VgS/
sKCe2j/X0HOKnJ7i/xu8n8wRaUKjRqyKWlVjeeTQEGI1quT+gJgJ0abpl9T3
FvMTB1aAnpyi/5bn2+zqfK4j37Zaq1UjGPlg7UqxWdCZuIt/bWmwFvjUcL5c
ZFiK2ZJFz7gsN53JEHJxFFitVR8nfH2brLbh3J9Gm69K7K78Jjj38/8B7FN6
5YzbctLc1tOTqdgh9LsbYvln0vuNJaatatzAuYeZ2YedYTbOYq/lWb+vgWMA
fctd9lY1nITbtMt6SXvqDWoxR4xZn/W89n6t1+b1CvPnZx/9kWnzpTtgGO0G
M00r1ew9zh1bzVff+NBjQ5XVMoGdk8V5yzaLrzkcJJdjhbbLdD5fhGs5OVQ/
ZvocBu8AO6qv1Xau7t4jTutt7fEJ9JxOt97QHonA781V7A1sTwK7GHt+rcVW
DjfQaxCMcvw/5rd2anvfbdprj9xH9wKP+WoPjlC/m0W2qzSfALGSXdb/P+Ff
gX7LwY8LtX0+pnPssbPu+Drer4NDClYHdj3WAOft2E7evoIl8A15FtsL99ex
0FaLp/00SrxjZbb7dEbGdRe6rdY6o8PgLfLartFvVDiz8mqK5aY57vYapmJ3
Yd1Y4kv0AnaeGn+O3Uoz7XX+VrPLM53WqzrTGfCrLLBcNecd8D5XaLtTd/zD
Oo+6Y6NtHiaYHz8copda/CHqPxjclzqTG5mnt72223XHd+E74LbdoztoGfNQ
VWDzpfFq4HKP+3q0vMNv5fRLk9ewNUY77/1BPP2mdZJ7F/cM9JtBj+/gd9Jl
9dAaDXN+kGNYinkR/LkSm32doeuc52db72kPVnC/UGizozPkpz+jvNZv+k1b
QPx5LstdNfgGLZ502Hud6Z3U51y61VJrOkkvhRYbN+XYBd8Rt82OfiP24V/J
jq1othpprf4HdSp29w==
        "]], PolygonBox[CompressedData["
1:eJwtlX1MlWUYxq9RtrWUailaZpsZZHIOoAQi2heGRBkckIqUsBL5OOdwKDqm
eCg4aGoFGKnlbP1R2mzVWlrLpWQ2bQuxcqUEfUz7MPlwWa40W3P97j3vH7/d
z3nf93me676e+37O5EcbSiMJkh6GUfBIIWOILZK+uEZ6NlWaOI3nV0sV5VKm
X7oZ2sLSf5OlOPGrDOkwpC2TwjdKGUQf8/3wKXP2ge9BaTdrpBL33Sp9Av8W
8c1Y1iHexD5ToXAh4zHSX+zRG5Hyp0gHifMzpXvB761TjqbX7pReh+yolAUz
4YdJUs0SaSdr7YA/0TD7SqmVnN4skV4dJ20nxmeQwwyn0bQe8vYK50qXlEl9
SfhBjLNnG+zPJ8/LpQ72b2HvVmiuxCcIs9+P7DsfD3oXSN3MPUjMYl42JBdL
eeR5A3ED32yEpFnSOGiqJ5frpD+q0I3GTLQOoucttL8NZQU8v0JKKWU+JMM9
GS7P6iVuf9PxC9/9DIfwr4VzK2ZuE/rHjpdWEJ9ARxRC5JdHngfI92PYC0FP
fy7+5cAsA/93jZbWczYd0AkVAelX8qgk1uJHHTzO+DFohBP4c55niewzxjyL
uL0+I4bwOghVeB/lDGqIo9E1gFeJxLXkvg4uIvcEaGNOCnPvynXnbud/Kd/1
8/1lZa7erO568HQTmnqJ5ZzNA7DKq80LM6Uz09GGv+lL8WYxNQ1d8AIM4vn9
vBvgm++nu3M4XeXe2TfdeJ3GfntKXT6W1268+Qj2RN26GUvdGdtZd6HZj+YN
xA5IZdxO3ML8V+Af8j8HLzGewLqbib95GuZRB4M50lCOq0urzyTe9+HVePuO
HjoBg7CF+j9JXBbCSyjCh9DF6GF8FI7AKfgAD5rx4Bty2Xmt9B2a+2EA7mNO
GbzMuZ6/Ci3EQK7T/yKaazmDOlh0m7QQ9nO+E9FyIODq1+r4aCO/k6Vviemz
8Qqea6AvWWMNcTWsghi8w+USJy7G50pI4PznsN4o4jPenHXEY1xEx+Ennnfz
/niJqxurn5Jb3H59jc4L86QAzcnMfTri6sbqx08t+KCKHj2SQu2Tbw+6J7He
5wGXj+V1N54XQhd6hvGvoN6dk53XUxG3bgsxhofv4+Wg5615vIn7ayM8iW8j
+NdEjMEpxiuL3Dv7Zsdc6T3YxrMLvNta5Hw1fzu9GikmhyBr1qGh0M6ScRjW
o6cT5tg9hX/tjPPp6yD9vZk+/5B+3wXpaXgPDanu/k3n/j1Hnlnkezbg/Dbf
G6POj2jU9Yn1i92fdo+eDLkch4gr2ed69pvCvjHGzbAW3WfQv6bI1Y3Vj90n
dq8Mc9f1UM8jC9xdaXdmnB6dwN2zmli/nNqbirblTqfp7cfTY+x3R9j9P9j/
xGn8+h1uD7t3ecTnqYl30dLKmu2MO6CJu2kFZJPbl/R+FrEGXdVQC2cT6bG5
rtet57/26v8wsYJc/sZnH+OHGFdC3LtrWiOuP61PrQatFrdXkx/92cz+I15P
DYfc/5f9j22jzuJo2FrstFsOe727NeLlHeR8h7y+zZvmatNq9A1v7VZy8tE7
fvgf0gN+1g==
        "]]}]}, 
    {Hue[0.21366946074788906`, 1, 0.7041499774259998], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l39s1tUVxg8KBGehILMYTXS1VqSvpS0V2vdltrj+1tmWFrJSsEXoD2zL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        "]], PolygonBox[CompressedData["
1:eJwtl31s1fUVxk+ZmKJIYQw1kGV2CEgr2NrBba+jd+72lha13CJubVE6gaKx
7e1oKYS2UFRwc7PiyyBWMDodgywuWTa3/TGMQ+pgviQsrMrLNrfEzSBjvJkQ
HSz7PHnuHzc5/X3P97w9zznn2+IVXUtyYyLiML8r+DWXRLw3M2J0fMR35kS0
JyP+O46/J0a8lYu4oyziIRQnFkY8sDLiW3URBznLTY2oK43Y1hmx86sR1dzZ
1xZxqj1iBFu3oz+Q4C53vlhoG3dia3sD9idEXMu3Wzgf5pf5Et+KIwY7ItbV
2fde7Oewv3RhxGQC/hH270EuaIy4bQr30emrjZhZY1s3FETciDyG3/SiiJOT
I76C7ZFK63/MtwL05/ZGXMJW0zX4Rz50a8QubN18bcRvl0TMaaYO6K7FZily
Fp9tnO/CRnNVxM9WR7ReFfHK9Iihrogt1GgW8ifYLFgWsZvz5Zz/fCz5V0Sk
iXdlPt495RGLqFc79boa/ZZV2KlybvJxHf5vaY0o5u8+dJaj+/ndERMmUT9q
8BnyG8TzBLqTifcod2vWR7x5k+NdQP0ONbn2+8F0yVpq2O7aC4Mu5ESJz4TR
IvD+aaNzk//F2J5P/eaR/4EZEUe6I3rrnc9L5PgI+Y4Hk7lgcz31O8H9adib
VuCa34fvJ7tcG9VoA3ePJhyb+PVN4usH/9eQi/hWzNn9+O+eYns/SUVcaHR+
heR7HvntJtuWj0p8baPeN2N/Kvl/RP5fbnE8Ddy5nvjXtDgX1bQL+fsp11o1
r6Oe5aXmkzDv4XwITpZhP+DgXmJbn+ffFHxcTS/kVpr7quFd6B6gPjn0L8PX
LeTzT/iVJf5LfPs6/HqnxbblYzG+Oteba+qph7DXCwYbio1HD7YnwJnT45zT
U+SWKjGXFdMouf+uzHz8NXdOc3d3g8+k80qDOSn8qvD5F/xPX+jaDWLzRuTW
LDGS2xlqXkYtMi0+U71qkT9KuVaK9zJ4/pEYaqa7R36JXMm333D3HP20FX/3
4G847+84/h7OeR6I/3Xktzft/pb+bPA91OLcb8fmm+guTFpX+A3ydzX1O0x8
z5NTZQbbaXNDeO9A/gM6ae4W0QMT6x2TYtO3g8iJrO92oz8PeZSeHTfVeFQT
36+YSRXoD4H/APifpwcnjXWPlbW5ZxXP6lkRM5gHP873t/q3n/7dQA6/v8n9
sr+aHqAGZ8jtIjkuApv9OecmjO/6BjYTnkeqwXPojq00V8SZEbhzA+efTHYP
7MDevcS8scD43IecTZoPl6nps9heg80HsT1CvT6k/0f5tY3xt/eRXy3J58v9
p8HqQMa1OEEMIxn3iGqtGfUo9hbcauyE4Uv014tpc1Gc7IFfUetZqZmpWVs1
x1xTTi8Tb2+D41f+z3P3WK3tiYOaJY90ONet6P+PXAdqPfs0Ay9Ti9f5nS20
j/Pk+3KLd4k49G16rzDpWawe+hD+Xsjjpf1SAV4lbcZO385xtifl2aEZoFmw
s9V4X8n5MPK/Vrn/9fcx9MeWmy/iXBL/X6gx18S5K5CXN1kWPq3IO9POVTkL
u/vz82Ad9eqgXhcyxk85fYr8527PzgLu3wkXf7jEs1oz7TXtmrw9cWgG9o6X
OzbFeIpY700ZS2EqLotT4pZ68hD4HWl1LZT/YeRH6Ym5V3k/bEbena+HZuo8
sN8Mv79G78xCZxPyX+vMrRewv4r51FHv85gW8W/OV5S6F4SHdv1T5e4lzbjZ
4HuU/N6a4Z2t3a0clau+HePsdJ19iaOnkP/R6FmjmbOJeN7JuZfVwx1gfSKf
vzA7S/7prPkrjGqQ5yc8mzXzSsCnn3iruD+GeM8Q72jKtjXzPoWrt9U6XtVP
vdHT4LeAdsgA/ZqGn38v9kzVbNUOVG+rx1PM6iuXwotJrukR4ruYNVeF7xtw
d/xS11o7+RrkVTnvCu0MvV3OVnvX6U21mv07b465JP6odzbi//P8PNAuaW52
r+jbJs6KlhkbzQDthoF8vofh0HvE09lu7omDw/i6bqHrK/5rN7+bce+rhm8j
78+aT/q2nfhbO/22UA9tplY7Kn0mnZGsOSAuzMdnD77/lHQtVJMC8k3k3wf7
iOEZsPluvXV151X8r6vw3+8S71nmU3/C7xHV+ySxZ+a6frL5MNz+RamxVI59
2LqUca3VU58h/6fdu0829LaRD/kSZ9vRL6o3Fsfx937SnJA9xTvI2Qe17he9
UYfI/YF6c1McfRB5U711dUexfI9f3yz3iHplZ7X33wXw+wH4da81XuJ/D3JJ
wmfSeQHdzR1+y0pH2D5OPEemmvOT8DWU8zwWvouJt6/Cu0ZvrBfZPSebbFs9
9THy3/L9qpjqer1Tz+X97ar2Ttbf2jd70n4D6r0ljteIa+3GSpjpbVe01LVS
ze7Ad39+Pmve6618MGnshOEa4r14t7knfAbR39fsXSV8nqW/Xk96N2kfrQXP
xgWOXf4+YB5kSt2bmn/DzOfylO/rTbKi0v9zqF/0hk3Tf1u6/NZUPTYib+z0
7tZ8eK7WbwDVUjXdhu2tXa6fdvZjyLOX+X8HvTn09jiQNNbiyyly6VvmWMWB
x7n/f45SKlo=
        "]], PolygonBox[CompressedData["
1:eJwtk01IVHEUxQ/luMk+aFLInX1oWpDZInsDJfShbeKN08I0sKxUfM4IzpQ5
YdCIfThqUIuKNpqbbJcLbVHQomWBEG0qKiMDVxktKkrpd/m/xeG89//fe9+5
595X1tbTmFolqRpEwPYaaRvIJqXRLdIAXNcnvdgh9e+T5gPpC4jtlTwQ6ZHO
bZUK4MHj0veolIPvHpDugemT0hNQWCutlEnXu6Vr3e75BrxxjxQFs43SrhLp
Kby5TioFs+iYASOcRbnLwzHePTAel+4XSxPwYXCW50PwFLUehzWt9mlfWtgk
tfpOj+nqQv9Fvp+EH6FV3E/BY5hwCxSQtxocRd88cUfgOOc+GCbuJz3m4frw
/h2+7KbHalCED534sQ7O0cMgqExJf/ByZ8r1Y31VtEjl4K3n4tcSn+E9DRou
4H+FdAz+lJBe0vvnhPPbfL8CBkCenElyx+A2eu/FgzNxNz+bY47zce6vwn3E
XwK/qTNHvV8JV8NqtaCrGaxBSzHx53kuDOc64zlNps16sZ42nKBnaqyHhzl/
UyrdDPuxvsxD83IZf5/jz7/AeWMetWek1+VSB9zAbgX4Ug8PHWQvgMec5phH
zHczsFl0oqcELUWe02l6LdZyKunXp+8qeKKZfsHH/c7vKuLSfLsfDb2Bm5/N
cZKYFJofhvGWd5nzLMgw10Xmm4ZXQv13mO/7JulDk9t9+weynE1ztxC4fbO9
O0UfWb7bmnRem+dL+PwKr34kXL7VuU3uM3L/kjtK7ANyRpJur22/bfftH+gI
+26Hvwbue98Cp9P0DrF/y5xFat0/Zv/af1bTttc=
        "]]}]}, 
    {Hue[0.20102217856981375`, 1, 0.7216615989033348], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l3tslVUWxTe01TFWwAAaGWQEWpXbKRaqtkLgor29bVX6ZBxvyVht4Srp
5bvSB3UQLlWgGAwPY3grD41iJv7hMBAmARPRESqaSCOo+EAFjE8cAVFE0fnt
rG/+aPa55ztnn7XXXnuf05HN6fqgv5mN6meWhX24yKw72+xEq9mfx5pN5ePs
ArMXqs16mF/O9/KU2Q7G2ePM+k03WzfMbHFgVsHvvoFmlbVmMf4ODTErw665
ymxvvvb/3mD2zhVmByfge4rZghy+sXdCrXzm4ONFzkty7oNVZulGs7vwPwfb
NNvsykFm/2BNTYXZWTA/X2f20ygwsmY6vkZ0mmUYv8H6ofwVMB6CnYevWfh8
Cd9LiOVP7C0tNDt2i9m/LyGWdrPT+PrPULMz2BPh/EqwHShXXG9hB442u5y/
Fs7aVG8Wx+cS1tTDyQbwn5qMnwadVQZ/a+NgAvOauDA5thbWPwSe0svNurDd
4PlusFleidmuevnuHW92O/hKwVkSgVNwX4fPuyrNNrL+POvXY7/irF74/AK7
KWn25Qizp5OK0zFk8H+wTfzXTDLLZf5rfF4Jf1uJsxRsEznrGPn+50izKV1m
H9+tnB3Fflio9b6vg1wfAP9FabOfOa+Pc89jn4OrI/B2Ndhj8HAUP5OwTfif
w/yNfB8zkzHYCrClxLMC/wfwf2qc5iPM57RLS7/DU16gnG72HJLfH1m/B35/
aRW2j9i7KFCOPFcT8DkcnANi6LPU7DDaK0dT7xB7lPmbmX8sXO85X0dcG5nf
E9F5fm5/zq/vQOP478X/62j0ADF+S4yF6Goba66HgyfYu4q9L7L3FN9KyOND
xcQcka6u4ax2fP6V9ePgrf808OAnG1sUVRxNYMvg623WdGMbE2Zvcu7fEsqH
52U5ej8MjieZj+L7nkDaywLX52G+PG+tVaoXr5vOuWgCPp9JKjaPsSOumnQN
v4mGP66Ubpe6RvAVxecefA8lf4fJ12BsIpDWk+jhHHncx3wPvL0aSMO9zlmo
7QXgvFAnfY7m+6NpcdIJrkFV6iH7mP8ArrKY/5bz58DzfuKaSrw/VAr/8Qbl
yfN1vlX9xXuC94ZJxdrrPqaH2B4IpAPXw2+s31Ym/r2+PTeeo4lgnFGgeD3u
v4d1twKMcWIoI5Zy7B+JuegyeCU/ueTjKeaXBeov3meO4OcOMKylNgdOU8we
ez65ujjsLV73DXC0Fq6eYt8r6GTLcPpCE7XapPFG7KpA/gdwzuP16lu78DPT
c+yarDG7gV5wjhpfTSw/4ques9Ks6Y6rB3ovnAUvx8lpAp5+KNf4DPZsOPbv
eRXaOxr7zQw0iTY+YP3msFfMIybz86iXDGduKFMddVZLf67D9zjzvkC9+lLW
30tcf2FNIqJ+533vDur9GDhfJvYT2DtTqqN9d4sj56qZ+Z3e68ndS9imUtX2
Jylx6twu4k5oC/vMJtYMKRD/FeBfWaQ7xO+i44Wa9+/z+X0SrjLYTEp1lEBX
yUC9dNgUce2cD8TuDzFsx/bj3EPUZh91sDDkNoNtR0/nBsATfMyLq476gf/7
sO6OY9+Ni5/3sYPp9UVooBo8dyak7UP0nk1l8rMFG41LkwfJyyNgSqG3cvY9
iK8ufN5P7R5p0173sRV8xeBsAFsWOcojpwvg4PFq+axjfD91tJv1Ray/0CCf
GXyvLFDdef3Nxv/OXOqVXG1tVF99tlE4HE9fuXh3/nPT4st587vI8+AYnuD3
yVblejfnBgWKd26lep/Xu9d9b6gTv9udL+fNiHt++K5oB3tVp/z6feJ90Pvh
YDT5SES6mgieSrSXSyyPUY9PMn/e+z8x1ob3y2SstavneO/5plL94SS2o0p4
5mIzxar3c3BzmrOK0efL6G4/4+GMX8deFJPm/Q7ZMV716HWZHRPnWdj8Tt0R
/t5ZSZ1EqZcR5GQqcR29Gj5aqBG03gLOFmwkvL+c73c5+xU0drhBfDlvMwLV
gOuwlR67frJy5LnyPuj9cArauCyte+c6zo3UiZOeqO4nr6/vWL89oftxCZzM
DHuj98jJIVfTsMPBOpZY8onl11bVkdfTuvDcRdWqB8fzBvbDW/SuupZxd6hV
15dr1LVaUij9uQ69VsZzf7fTT8ZhZ3QpRq+JYTH1ZL8be8K+5/11Q3juzYXq
fc75GL7P6pJu/e3pWnHN+Jv0kwZpcA5YZreI83SL+pTn7ib8ZMH1KPznuMbr
9G7ZjPbSYX0F2IeLdT9upf8Vh5jPoL0kOviSnCbRxmLw9eFnkfeMQHeHv/Um
FguDY9lNTe4lp+8xPsPeG9HS2VrdZ16/81Pq497PVxH7tkLlbim5y4spF9di
l3Uod/9iX1mX9O/9dTU4huFzLz6XFWm95/BCoe6pE/iZxxm1f4BL9Hgsqnm/
xyaFeY91qQ96P+xOqXd7be4IVG9edz0pvSm9jpr9jVmj+7cZzE/zLRcN3AaW
9SU6633609KUMLvuNoTzn7bpTeBvgzHTpVGP1+v41oh8um+/d70evS6/Du+j
r7BN6LkZn/dgxybU01aE1jH4O2DXSPVe18TCEv0+TU4bI3onPwufn7UpXn9P
FYX7K1K6h7xexjO3MOTNY1qcUo5ei6mveX8rS+l/DL8LYugoP7xD/R72t5LX
o/dK3+N7F3h9VUhvrjvvX57HGuajXcLmb/nstPTjOtqSlA79vea4fc1/W1Xn
7n8ZNuf//Qfe/gfVZ2zN
        "]], PolygonBox[CompressedData["
1:eJwtlntMF1QUx48KVhtqztdiiimQCpNQU8AyLOCHZgGCmj9YWqCU/X78EMSR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        "]], 
       PolygonBox[CompressedData["
1:eJwtk9tLVGEUxVdlkKFSpEliilI9NIHpWM4MlYG3fOjmlJaB2Zi+RJoKFeXl
QbKHIINQyVIssP+gl0wpKW/QxcuEGURBRQUJIpEIWb/N18Nin3P2/ta39tr7
pIRqiqpXSvKB1aA3R1qMkW4ckrZnSR5QRfJbrFR5RMrIlrygifzPDVIq+TW5
UiRo4jmNur/kxPsK8IszmXHSIBznOVcNcnmepi6XnD9PCoBlvv0BuUel+HVS
c77jNO6yE1Jok1ROTOU9BaRz1xL33+WusXJpFFzxojNJ6qmSYgqlaLAUlCY2
Sq8DcJ4iJqCTeGm/dBn07JO6QQjuCu44Q8z0S7VoLkNLH3ofgr3o2QMiStEA
xyripwLpI0gqkt5R38e5mgrpw2bp4E6prUy6BWY456On+/Adp6YYTNHzJOik
50TOjuDFyGlpGCykS/X0kVEpraWHSDCB/mn60DEplrs9aIgnNsDdCKbRfRv9
YaIHf3aAC+SLqashHkBnIdiGb1tBC749ipK66P06/UVFM2/0fUHPV/CK+16C
RfzzrccrNNTjVx2Y4dsztPQH3OxshvnoDzPTPM5GoDFMfjLgtFsPQ+QT6LPd
5/q2/s1/m8MQdaPUfw+6nbHdGaePm/QzRnxDfor8ctDN1GZrvVhPD/AyDG8c
M/DgVy2+zac7H81P21Xb2Scn2QX4+olb6H+O3WnGg3vsezdohWcYnt94MADv
oHGzR9/hu+p1+2V79h6vZ0EPdZ3UB/2u1s4s8O053675nf82h+TDUja+tHFn
su0KyGMeOcylgNiBhkW0pGW5vbb9ruN7Cfn6Urdftmf239j/M4B/Xu6Yx8/P
ppXnZr/jNf6LeJPFvObxasR8BV340Jso3SG2g47/sOdZvCqhxx9npcfUPsXn
t0E3Z5t3C//KBFpaiQ1wNxa6nbbdrj7H/FLYM+JuNOwCITQlseudeFRHbS2Y
g28c3hfw/wOmXtQc
        "]]}]}, 
    {Hue[0.1883748963917386, 1, 0.7391732203806696], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlmlwzWcUxk/se5miaOyxhUvQkeSSELlJXCGJ3NRkqdiSoG5uiC2lQbXW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        "]], PolygonBox[CompressedData["
1:eJwtlXtM1nUUxp8EDUlF5yt5eTENMFAhsS3hLS7i+3LRBgS2Ca5syUVmgnMg
tELNUZbN61YmxKWWa/ZH/tFqs6y5NnBdbFhNnVZuUpnNlnddy+hzOu8fZzvv
7/v9Puec5zznvLOfaa5sGiWpE4vFdqyWku6SnghKO/HXL5SasfOPS8NYQabU
OF4aTOR3lXSTbwNTpK1jpdRiqX2llBIvjUyUnsPfXS29HyddHCftwQ/N5ds0
7iZIY8LS3WH37du3K6Q/wbyEXS+RbmAXa6UPyKePfP7A37RIKgRvADyVS71N
Ulay9BfxNxBvCIw9YGWAmQz2Ld58E31/Gz9YKZ0m39e5X0a+D2d4vZPA7MqT
anm/GpvO2xlYOjFErH1gnuP7rLBjW4xcagnDxxKsk9gvYT31UgOE3iJeL35h
tnQwWn/Ps9JZavsi0Tm6QH1VLbyP1rMc/17wZ5JPgG9T8bvKpP3Y9gXSa9jp
IqmO3E9x5yT+zys8N8vxJ/zufOk+zg9zfoja7hDvO+JlEG9LARxvkBYm+P2y
XCmNnP/m/toHuNNKz+F3WZzfmU7tm4jZgb1ADh3Yr/nOnXE4Ay5jSx3bYvxD
rHXooZ2zCvofhN/m1a4l43gdfstGOEtzfuKbwS/yXC3nzfiRIu93PL+L8C9H
pM+Mv4C0pkKqb6N23g9yXk3vr6517ozDzeS+BvxH05zD3cRbnOn9SCfH56m/
FIyTAdfkENhXyfk4uY+bhBapZTwcfAT2DvKfgP9gjZQ9HU3weyn1zGnyM7tz
Nkdqjdazhhj99Duu1LEM86uQtDdav+VkueVGXA+/0bNdzMOiDM/Vzhs4T6Dn
E7AtcP0i1lnvXFkNW/HLc7131p8helna5toyzMVobajItWEaOYHfTL9imdcg
Ndwm3qto7Pwc6RPuf05/e+jXWzbb5PELFqlwPOMnAt6ZfJ9tm/Eb3Ota5bNk
M3WU+4PcH8CKs6QS7GjId4PtiI3w/Tv8XsByH5LysHPMwMEEj78K/FT4vHm/
8zkC/rVaxzcNXMHflu9asN/vEW9jqffS+GjBT0KD3RNdkwfoxz1h3w8L6PEo
6pvf6to2jT9GPkMh1+t4ejRCXl9Sz6Ggc3YM/Cvo6ePZrqcDYE1d6bvM9ksi
fhKYeQGfkePsi6Ri17pp/hHiTw77Lvl/p4S9p9Zb08B6sIfXOrbFuIxfW+F8
mMbr4KOt1LU0nxzb8Y/VeH2m9wH8ZTWuP+vJUvziYtemaTQwjxmgxk3YqOVS
DPZyjt+1N7fhtxtNVIz1/u3HT66L7gryS8HvJodZ1PI9Of2AVo80OVfGXyPc
fVjtvTMNbUdLJyJ+194MUUtMyHO1nJ/i7dcR15LNXAnnqWHnzjgMwmV9ttdu
HNRzPq/Oc7Gc0vED9Hcydh4dDGNvFHnuVsM+/J3VPkum/0z8fr71Yauo9Wms
Bk1WY9fAvo69stLrMQ1sw28IeW327TD5Xirx3Ww7+gz6yKpzbVhOC/GfzPb6
Ld8f0fKpKteHvfkUrP4lvrttpnvx34nOr+0I2xXv5rhWjZ9p1DWz3GfZONnF
/qoKudYM823yKcx0Pdh7250x5a5t0/houByDBkZj+dRcgE0tcP5tR9axG0ZK
XEuGcQe/v9Lx7T+zB/xW3rRgU8BIxP4t831q+B3k01fjs2kzmsL9I3N9l9hO
eZN5aazw3Ww9vEGv/wO7cnHX
        "]], PolygonBox[CompressedData["
1:eJwtlOtPzXEcx9+6mEuRdWpTxyW5drHCllsXc6tRnS4zHXSPpeOUy8FQGCEe
yCMTuYw/gA1P8MSmpjGXNtRMnHLbmCFtmMvru+958Nrn2/f3Od/P+3MrrrK+
0BskKRtC4QeHQegvkjqipQFseYFUBvMWSK6R0qUV+Lik7/ADQsIlT6bkxWd3
lLQFewGfi9DPvR9iC6UXfIvB1u+QuqdLW7G5JVIezIXb4yV3gnR5mXQFVi+U
ZsZLR7xS2DopHH6j5ym6/mCbsqT9WdbX/OZLnXQzTvqKDS6WgiAEwsZJOXOl
n8RwxhCHGDvQ5oO+tdJp4i7hbkY+8WAJ96PIM9hNTWA4PMKvFb+F+I0h1ljo
J08/DIArgrznSKXEeIBfDX63eesOrOPODRsC39ZjL1CH89DstTkexdbskp7P
lKqxkbMlBziJ4xghVRC/CqohC32Z8JjaT6amT7BFHukduRdiv2ZI3+BVmvSW
Oxd3GZAJlcRxEK8CO5qahMEBdFehPwo9keCAZGInwZZEqW4GZ5+0eLm0CPI9
9t0Cj+2d6eE+zj+5+5Vm+2T6dZwYs4iVSx8b8/CBJpg2lr6lWD1GV3FAex+/
7WfG/BCyXXo5jdpjy9PtOZTzP3oh3t7Im4t5+wYxrsI1+M5MPGQ2vmGXon0Z
ZKdKKyGbGj1zcMa+NHGIt5q4HdSzE/YG9O/BtvH9bJrtnelhK730M68tzGsO
b3Wjv5N37kGHy/qa37zeJnWh04/dTA976GXtLltHU08fs1rLrnxE33v4ABnU
Px16Od9Fe0+Rzc/kGUS+vbxXSv5O6l9GHyZi7/Oty211G/1zAruTih2G3hTy
DMY2UuOmFFsbU6O6gKZqatfO36nU75zXzqGZxxZ8k8ntLD06A21wi92tYReK
6Mk55ry9wO6I2ZXKBLvHDdRlWECrsH/w+QtD/B+ZNYo6Ee8TeX2GQe7vMbND
2HrmrgEOEucATKWG45j1CGb+BFqOg5M4GeQTm29zNrlXBWZ4OO9uov4f+V6L
LaE3bhhIpr/gYHbns+8p/OYktXlHjQ4m2Bk2s9xMnQ/DIUhCZyP9WZNue/hm
m91Zs7smF5NTPHGHpjC/Xrs3Zn+ue+0c3sTGojsG0olxilhP6E1LYAeOee1c
m/mORk8UOGAStd25wu662fm8RNvnCT67w2aXV3nsvOZi/wPHmREs
        "]]}]}, 
    {Hue[0.17572761421366334`, 1, 0.7566848418580047], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlnlQ1VUUxw+iuOcS7mjhgohBojOyJIIJj4cLoM+FRcUF0JQehuCSmuKS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        "]], 
       PolygonBox[CompressedData["
1:eJwtVmlslFUUvS2lq41laym2akFaaKFOS+K0hdJiZ6Ydls5MR1qgSJEuIAxT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        "]], PolygonBox[CompressedData["
1:eJwtkk1IVHEUxQ9CIJXWQssRDexTZ7CsFn6AQeSgZk0yFWiiI804BY1vQBSp
CKJauBJyUxSVy9q1KCraVORHoAlugtLBVrZrUQs3hb/LfYvDffDuPfec8781
l/PJoEhSLdgCCjkpulcaaJJe9UqvwdygNAvuZaW1PVLbcak9JvUckkrHpA/t
0kfwIpCegystUus+6S3fFUnpW7kUoa7SUwDbO6VtYKJPWq6UJuFaGoHngJRo
hZ+dcfAmcJ53gffb3Hf01aFvhZqKS4PgTL3UBf4npMNl0r+E6zb9/U3e/yPn
nMbdzY5P7FpmZ3FeyrJja949mtfFHmkBnB+l76B0kTo1IN0HU2npVzVZNEjD
l6QcKMLvTjj60bkbT9N42kUtA+WgOeo8F0Zdp+m1vCy3Lubj9EfJ4GFKegD+
ZKRecl45Kt1hdj3CbnTfYO4mmKB3gZnrcK91SD9B5BxZ4b2SeqRNagC/mc/D
s39I+gzvDPh7jXepkW43ukfzWqCvj76NjO83HXfxt47PyXToG5weh4NDOUmm
j8jzMXiP5xN4v9rib283MIunW+ibCfOxnEyjaa0I88nG3It56gx5O8Y9L8st
Cd8xeKcD92KevoY3sjjiu03DKbSU8L7Pcu7PfH4BL6uk+ZTfm93dXKjpbMxv
xm4n041HMktTn/L/CSgZ87veQa1l94bdWrP/s55Nt8ah0A==
        "]]}]}, 
    {Hue[0.1630803320355882, 1, 0.7741964633353394], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFl2ls1VUQxYdNaIEIBUQwUQpiSwvShVhata3YvlZZW9ICrUClgBieT4WH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        "]], PolygonBox[CompressedData["
1:eJwtlnlsVWUQxYelQFuQrYVQE0JBaGmBboZHq0CFbspSSsPSVixQFg0vD6Rg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        "]], PolygonBox[CompressedData["
1:eJwlkcsrhGEYxU+K5LbQUCww+QNcM/NNQs24FQ2jGOzYE7JQKMOKjYWNWxay
4T+wwkaRIbfBntWU+wIbv6d3cXrf75znPd/znMc/Mh4by5BUATJB+ZBUVSqV
ce43SwcgMSxdwS1w/nZIf+BzUCqF++Z8b5U+wEufdFosHYekV2reQFYnvqAf
bR5tFC3hUVMkpXulB/wfQRx+Gr2dumfevYDzJukMLAckzyf5otJdm3QLBvDY
wGMXj0z4GvQF6nwRqQgscq+Dy0bL4zsfFHMPwa0EnK/5//RIDfgcBaUJfCfB
JXwSpOLSWol0H3cz2+zn9Jmkzy/6XMWnBT9/1NXbuwjvw+CRXHLJ54nzhn/4
+cdW0GlWs869DO4CLUl2l6C7XeoCBTHpGm3bc7zpKXxy8LsfdLPYTLn8t57/
LwVc/raHNH7VvD0MuhwsjwR6LXVZUZer5Rum/ynm6A+5/G0Pr2R5wttFz+3d
9t/IfQZuHM3P/vfooXLY7dR2azu2Xc/CJdHmrIbaTd7EPbcr29mO3eEKY25G
m9WytsyP6TWA9kvv/z/Sfdw=
        "]]}]}, 
    {Hue[0.15043304985751282`, 1, 0.7917080848126745], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlnlQ1VUUx4+5wehTFHWGygUdAUEUdBrAGcHwAQ+LHg8MhdeIgJoG83Qe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        "]], PolygonBox[CompressedData["
1:eJwtVXtM1WUYfimYuHUCAmxsiRxcgBwPiqwdDk1QOjfSOhwsk8NmiloWp1+O
vNCii3QV9Q8EpzFwi5pgaf5XM7v+UdpNy4xas8uqrcRyklwbq56n5/zx297v
933f+z7v8z7v+7mbH25wrjGzg/hS8Z3ZalZYbFaQaXYoZNbfYHZ5ttmi+WYH
HLNMfItcZt3495LfzL/EzIezPbnYj5ndU2U2ir1P8C+4yiy7SffLcH8/7l4o
NetNwX/sZ8fNOh8ye7HQ7BasP0e81ojZFM6vAKgtsOv98s0YX2H/2zVmLRlm
K9PNhmHPgo9/sO6Czy/ge3eNmQv4rkUOx5HLWqy/T9f+Pq/Z1Ubgwfon3BmD
PSdgtgC2L8fseZ9ZH/ylXwffN5tNtJot9pjFipXzDO4fgb882NuByQ9sTlxc
8EzaNuCDz/MZijkMe7rF7KTbbCH+zUWsv5BTWpbZYzh/O873OOKGfDVhb6Re
2IjxRKXZvIDu3gp8e4BvQUC5L0U+xbAHwPlYivh5GfadwHgK+E8g5jhiTwTF
N/1Nwl4PnyeT+f+WMCtZoloznxbcP5YQ/qM4U4ezw0Fxx3y+gf0pOG+DfRH+
4zj7L860oX658PEo6lPgVz235MP3JqzDZpdwfyc4csO+Uip9Ddxk9oFXMRmb
nA6B2zMhaYE+6KvDr7t349+fOLsc3/pc6eeVcnC2VPXi/hjqtTwsPvbhTi3s
zTtQkxLkjvUguH7qPrMfga0dGFaAf1fUrBn5BpHTs+D370r5Zz5tId3hXT9q
9LojjVOPxOgDd3dB46td0mwztD9wr3JjjuylHaGkL+QTh9Z7HdWaPRHD+SMB
xa4C5kHYh8t1nhiYqwf4dmJ/HHxvA98XwtLbJfjLhq+FONOQK83vAn83RqUV
auaFxdAY8KVCbxH0UwT2SKXOs2dqgS0tKv0zfmpUmmY9qIl+7J9N1oM5sxfd
qKmTr3xYe6tTrzL/lDr1EHuJGjxdbZYV1ZoxOoDH3aSz5KwQdge+9Cz52OsR
R/TNGAWIdaxU+iPe79BPxx3VgjXZGlFPMN/TiPcZ4vWFhJ38U2uHA6rvu3nQ
Ctb7Y+oVaqSb/JYJCzVyP7RSEpbeqNki2I+EpDXW439tVCk27xwFli6f+pEz
aT5yfaNR/eVFDr+gXusQ81yR9t8DltpVqj9n5Gr4asLXNkc1uhyRJqnNWVhP
Y91bqd5jT57FbGhKqPfYg+PI96Cj2Uw9cdZ6wuqF85hfV9APbwLPVJ4wEduX
pZqN1MuQVzOS6zj4nthoVlMhLMS0EliDFcLSjnUD1kWb1NvsT87uTo+0xTuP
I/68uHqZ/Lmwtz0h7VLDIcTPcaRdapizc3NMZ3nnAdgP1mhWcWYdAL6xjcJG
jMT+GvzdUKj51Af7Z5+4YI3XYn1ujbTA+ViN853J94Cap/ZdDZrlnA/90HMo
LJt6CMCejCTzRbw9wN/ikTap0Xzk92tCtSWf71PbjdIWMXA2jkRUW3Lye0Q+
6Isz50nMnnVV4pIxpng2pnpRc8/4xRG5omYc1CY/Of/5huzyqSasDd+QZRWq
Cf0RXwjrKDh7y63zfHuuJt8b3qHWJlv1tnFmziD2aKu0wjXfvnZg/CFf79Nu
YH87IC6p8XcC+sc9+hyNCBNjMeYk4h3yi09ynAmuWxPSPnMaw9npevUT6zsF
exD7WYXS99d4X4rKxB05vG0Z3rga1Zo1fxVnu8s1C1hPzr7ro5pdnC8ZsJ/z
6e3j/DmF/vi4WnrgjOBs/Khae5xJnE18I3n+4lz43mB2h1f+OJM/rJbGGJ8Y
h2D/EdTbyZ7qgr6yo+KHMXJg92yQL/oklqd98kV9zo7qzSd/5PgJcD0TUe1Y
Q2rjP85KoGA=
        "]], PolygonBox[CompressedData["
1:eJwtk0tsjGEYhY8mwrQuUau6Ja20ldLLKGEk2oSIEEpnBNNJ2k6nbEx+ojOx
shBxXVigtSFBCSYRS5cNiVvssLBh1KWJNhWRMAginjfvvzg5f77v+99z3vN+
X3Xf3nhQJqkFTAYPeqT74GtU2rdAqt8lFbJSZY10A65tl+rAoy7pIdgZSDMW
SpNWSU+WSo9BJ2sVrCXgFvCHf5vhEzHpJLjOf9dANNx7x1qG2p+rpT74W5v0
HbwwPfafw1qJBqjBT4CvL1H3aX4LSbyBl+H5FOfu9Eq3wZpW6S3nD+6WRtD5
zX5j4PrmYyP/bAD9of7oCjwckF4tktLwrCZ6B5fQuTxPugifBxfAIatJ7bWt
rmWa1p/1WdpPjVrpJ7wePzPRvYLGMnwuB1V5qbtempv3HC3PwYw0Pl86wjCG
uzkPhvAzCF5T5yn1inBitX+/4XsrtTrBR85M4L837Mf62sb6syqybZDubpHu
gQz/jvDvtAEpkpLKwRh+P4GKAd+bDv+L+QzjZLUZdASeg+WxabF7n4P3sjhz
AUsCz7YJng0m+K4M/D7YvbDZ2Qw/4KuRvVF4KjpF9KYMeA2rZR7N6yk8v6+T
juW8P+szEfYTh8vJPAJuohHD5y04T80SGeSynpll1xH6z4Qz/UtfR3Ne+3jO
700hnInN5gwYQ+N00mdssy5y17qYc6nf87LcIqH3NHm2r5PaQE/WZ5DO+hux
tzKc9dlfhc/hoxmvQ4HnbbmfDfUON3gNq7UjfFPbA+/RerX3YO8iSZ1xNFJZ
vx92T37sITfWfsH/AfRgwV0=
        "]]}]}, 
    {Hue[0.13778576767943762`, 1, 0.8092197062900094], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlmls1GUQxqf4AUQKRZQEELm0xdZWKMHuFuhF2S6V9DbYrRztshXodqGX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        "]], PolygonBox[CompressedData["
1:eJw1lXtM1nUUxg/WFhQMSmUTM5IaMAgyWnEp5Pb2glSCQFNeasTltbj4GjfJ
DWttVFt/tEU6m8OmpYmmuS5buC6iWdFKXbLSZRdd9Yf90SrTXNHlc/b8+uPd
zvf9nsvzfc5zzm9x+9qG2BwzG+V3Ob+R1WbL+OO3a802YMcPmH063+yqRLO2
UrM3ImYLU3V+HfuvFWbT3NekmeXmmn3VbxaaZzaH+wb8NzabjSebvRpvNoZ9
voZfgmr8in08bNbB+cs4s6PYa3u5X6wcOXVmg+TfQP7GFLPMavzuMvuCfDfy
36l6s5Qhs7cThOFq7PQWsx1gmcF/kPy5dcrlOc8XUov8J8G2Hjw/cB6g5iLi
c4iZy3s2dZhFePsd4Hke+0CZ8I2RfyNYavFP5HwD/vH4z1LjIueXOV9H7cx8
sCaZ9cHR0kazlTFh+RCfuBKzX8jxQfCevgKzrQ3i8+Ess2zw1xSJK+fsFbBu
WqHajmGG2nV5ZneCrTTbrGudWTf4LqPezfgcIHZJTFw4J2eKzfYG73H/bvyr
g/w/wcHOXuXwO/e51GP2Zkj5a/F5C/ueW8R3OjmPwfd3xcrtmsin1gDxVcTX
0s/H0cuD5L8pw+w5OJ+C+27wD+HbQMwe8D+xWtryGI/9t1jcOEdN5GtCI8/+
r59mYXZ8jmkPbzneq/tJ8EWoVVEuvgfhMATfE2DuAO/UAnpI/PeF6rXz2UZs
96DOroEe7Giv7vy/H/EdB+PROOHdip1HjwvpbRv4qtDfQwF+128UO6tavXSN
lvOWRS3SgmuiBmwLhvS+SjCmYfcHfHmOnbz3RWJm5it/Jbk+DmsWvN/T2NdE
pE3X6BrOO8LC5hhfwl6eJ61Wg396KQMc1d128sdhv5ODvtKkkc34fk2NLdQ6
R4+2Ufv+HHHlnO2Cu0+WwBF2BRxn0L+GiGbbNTVLL98N6f4wMa3EPlOmedhP
zQnyNxepN97/Y3C7PKw796nDfmpQ997Dp7GbStVrP3/L7kik5m3zhOcgWLID
fn1mRsGbGtJbb8cnGd/JkLQ6Bp6ZVWbtpdpNrs8r2V0H64TFNXkGPHcPS/s+
A2Gw9jO/J7x/6Ked+RwG42Sc+H7Ud1OQz2c0iXzn6jVrzmcXb3+sQL3zHiYz
y5/3qp6/sYX8mVH1cx/9yMLeXab++Ux0wWdaVPX8fiH2FRHtFuerkvpbijR7
PoMn2X2/d4pP7+8F7H/g5EiCetqInrLzNYuuMddaesCPz88i7F0d0ovP+wR2
RbXwu8bnsr9rmaF1qdrRP8NNebN67T1/n/iBGs2q79he/EfRwOlMcTpC//+o
UX3X/yXs/UG/vOY+7KSYtOd4T1O7IKZe+U45y1uiudqFzvc4fO4O5tk18STz
ebhVXDmnH1GvsVG98x7G3wr3hdKu432P2O2t4spn4hD+fwd8+TzWU/te4tcH
8Y+Atz1Pu+EI/IXRSla+Zt35CDPPTSXa7b5zKjmn1EmL/sa91OsJ9rHP3EW4
6wy+d87pMmplRIXfe3499prg++Gc9WD3BXp0TA9Qa2WJdpvXq6LebKfe4xr4
E/tsobA65gvM/30xvc13jhGbVabeeI9GmLfGYN78m/gN87atSN9S19cp9HVi
lWbJNfMZ+dqHlc85m4W7F8o0G47/Nbg6FFEv/X4K+z9wdGgo
        "]], 
       PolygonBox[CompressedData["
1:eJwtk81vjGEUxU98JBa00xYJItWOjxqMkjDTBtWkdKZC50NaOvXR2giToe0M
keg/gRBsCAvasmQhbQQrEiSNhLDQJkhno3QSGxK/mzuLk/Pmfe5zz73n3qeu
/1wqN09SI1gIOvZKcXA4LQ0vl9Lwt6wUrpd+wF3bpG7wb7v0F9zKcTco3YR/
D0of1kkleIizPFjA//ngTpM0Q44KvtM9UmyllIITINnjsXbnV1J6uUyahd8m
pFq+38EdaB4A01ukKVCzSYqQI8zd0TZpBFR0SjuXSgE4FJY2grPE3SNudUaq
TEmT5AvAX1vIA7L7iQFfQtwhrpp8cXq+QO8xuD8mnQIj1B2lz7Gc+2M+xY5K
7WAuAuqk8/jzGNTQZzwqXefsBnhI/gfgND0V0D8D/+H/KvSehVzf6jAd09uD
7gD6LfAEgxkHS+hpB70thq9x/wp5ribdC/Nk8gj/VnCXfE/w4ilovyi9aiCG
+rqoqxvsQvc5cb0h98y8u12eYbJZqsKn6ox7Yx4FOCvSTyVcQG8Y3XzS+7G+
psi5mfOT9PuT3LOgnhpbqTUIv6b2N42e03I3FPBhA7OBF+F1EA/eU0uMXPEy
7PsjM1+L1id4CI0S/pYi7rf5PsHdcdDX7HMZpb42/Mrj276076btqNVjdfVF
fYe/k2sNddxHtzbjOSyX7Zbt2KPy/MbgXlBE93jWZ2CzOETuS2gcTPt+2Z6Z
1+b5Cfp4gbet6FWVfbvb5Ptv78B2wXbicl76vB4v8/6W7E0V6XMr/c4kfE42
r+mI6x/Luofm5WDZi4Gsvxt7P5nd/u7meHf/AS5Etqs=
        "]]}]}, 
    {Hue[0.12513848550136242`, 1, 0.8267313277673444], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtlmlsVGUUhg+bQQK0EH9AAQMt6yCVgggDQgeddsoSWtoSmGETaFlvBymt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        "]], PolygonBox[CompressedData["
1:eJwtVltsVFUU3TQglfBoDZDSIIEWKUxtheHRaaF0qsPMAA3TZ2AGCuVREHvn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        "]], 
       PolygonBox[{{12769, 7774, 25857, 24478, 24479}, {28323, 9013, 28325, 
        24757, 24758}, {12780, 7788, 25883, 24509, 24510}, {24479, 24478, 
        25852, 7772, 12767}, {24510, 24509, 24514, 7342, 24513}, {24230, 
        24229, 25516, 7665, 12484}, {24758, 24757, 26215, 7895, 13059}, {
        12483, 7664, 25512, 24229, 24230}}]}]}, 
    {Hue[0.1124912033232871, 1, 0.8442429492446794], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtln1M1WUUx08IaUXiWhQ5V8NS6xLGBRGuCdyaFxBoIpbzXhAh5NLLBdud
jV79Q3LZ1srNgUKKU5qMVQIZL5oryNQsW2sz33pBt16MgMxSQSb0OTu/P56d
c889zznf8/r84p9eV1QTISJ9nCl6UkRejhLpLhN5v0bkv1tEShaJVOUan/Ci
SOsakWnotECLPCINsSJNy0V8XpHL6PjRLw8a70J/n1/kyj0iHdCuJSIbpolU
rxfZlS4yAP+jTyRuGb8jRY4mibzrMv129LdzBuGboDsd/Z/RjwDbFuy/h/+9
pSLN3D3M3WtpIhvRKUanA5ub78QO9IojX4l8v+NrPBNs+IqeCQbs34F8J/I+
7Hzk8KOZ5k/9Kt7pCSJJ6McHSFa1yES0SFkWftE7A38VusvJzwW3SKbf5BWJ
Ir3IY5API9+aaHdPFtp95cuhbfitA/Mf4A0nizw5Q+Qn/JzJIT7iHSPecY/x
n4MhjzxMvV9kKTSVc2O2yG/8v8DhU6D5js4o8j+x+yqx+IipyWM5HMBvI/Wr
p47boZuR1yGfj89y8nOU/OcRx9voDZGT+ehsg/8X3gt/PFtkMfqnqOkmzvm5
6HLvdfCXgd+LnVDI6j6SZrVX/oMK5PCvwe+jL95w7tZB6/2W82Zy/pmTtyHy
lpVjNp8h9l4wJCBvAMMml/VJI/c+RP4A8jDyPuyGYug78voCOO8F5zg2Z1Ua
37Pefisfh6zebTEmcrcV/VTk36FTgE4c+TxIHAdCxn8Kvc9jsR9B96KT21XI
gwHL7WLwRtUYZs1HF/JDyKczK8eSrA+1979yeO3NbnwNYecfv82Y9tJ5cP2N
PEbxr8VvpflV/zs4F8FzG34G3KavPXhrjcmjobu5O4f6nqPfvgHfbOTfQqs4
I/HghS5EbwJ5OvR3j/Fp8I9yhP7JgEZUWk7i+P8Ud+ah8wP0tMOX4Gdlutk/
gcyVbLUIkc8vkmymdLZ0v+ieacHml0k2vzrHf7mt1jorM4vBzaxVMXOTay32
DmoxmOb0DP1zCf4t5qUTm0ccO12l1rvawwXkez84YsGTB64FydYzW8DzsSPv
hPZw7obvhhauEHnlLpHSRRanxtuSbb2rfXuQnup3YtGdUVpLDh6kxtDdbpuL
DOz/Sq4v0HvDzNqIz/hV/N/r+MoHTzF3TnJ3NbQ2ZL16AtuuHJt93QHXPGZ/
DTp78beReFuhTwRM5yF0C7MtP9oj+eB/iRiXeG0f6f55FtvLNS7kOcgzyftx
7o5j/znyu4c8zyLfk8l2t63IZltj2QPmqBS72468FvkGeukxcA0Toxt+pNBi
0xjnVlv8ercFWazX9tV19CfDImfnEG8Gu8mpke6bqdj/HjwF4LqErWRsHiKW
X5iB28HWznx3FplODW/RoM9mpCvdjvJB3aOO/RthmzGdtSGP7QLtw4RkewP0
LdC3QneWztFh+u0p6h2m7t4VNrc6v7oj9Q3Tt6ws13yor0/SrU5ar376IQ6d
1fPIPbmMhC+EfwR+isNHQNsqrG91563LtVg07rFMk2tf3+zkWWulb62+uRVB
mx/F/zD4/blWu56A1U/5ALJ+Z0/qvpQUq6P2wjnq8TX9drba5kf75B3ieNxn
+0rfBK236k9gbwc6l9nDB1z2TqhOht/qp3XUt0j7QHFGptgO1f3ZmGW7WOcr
FTsRzrdEc5ntUJ2jNrCVUPvT1GgsbHOo+gvRHw2b/HrYZlhn+Xn6dkax1XHY
Y98impMQ8S71Wx2vgv9N581aFjB/6vemFHurdJ83uO27ROsYDNp+V/k2t/WH
2j9GXP8Duhm4PQ==
        "]], PolygonBox[CompressedData["
1:eJwtlG9o1XUUxp9WCwNrvnCpGZX9UdsK5pbpQO9dce82tbj3ul64u8TZcrO8
u0ZoKwtf1IsKIoKYVvMPc5EORZm0igxyLjV7F/ginLGEiKhNy8ySQfY5PPfF
D875fc/3nOc55znfec9sXl0sk9TOdxNfqkF6uVy6fIuUxv5lifT6TOmH6dI/
Camz02evEHNjnXS8RtrNxTeIGcxIY93Sd/fiE1PXJD2Rt/3UDOlJ7HyzdAa7
/w5pTpu0sSBdnCe9Ok16PC2tbJVOzaEm/grsvnrpPe63c6e8KGVK+aLGOWo9
VCvdD5btlVJPTlqflP4D663k/5H7ny6VJsh1oUL6OctZrfm9eLv0WIvUBMdt
+Nvws/inwfwV+XWftIx6p+C3F37byTGckgYWSX/h30XMC43SmoKxB4cu7A+T
PouYndgXiJ9G/sX8K9sgXV1ibgXw9BC/MW9uwbETewzM08E+Tkwv9r5SvVr4
/QH+Iv37nvh9xDxfLU1yXkH+Zdy/m/xfk2MUe+0CafZW6Rj8F1Wa/0X6+2XK
XILTt3BraHL9XmJy9PqGOs82ZryeWQ8U7V/B/xh7bY90dqHxluH/2er+Xp4v
7doiHe6QXsPfQ/6T5H+uYO1Ej36F+7V64wsOQ6vRXJ37H/m74LZnqbnHDMV8
d8JvglwVnGfp93jStQPD02ApNPtu5LiZXP8mrMfAcA37CJp8a6b7fRzuUwlz
f5t/Rzm7lHVvo8f91Po8b32GBoaxOx42/tiBT4hf3mou8S+B3VVtLcedVrA8
ir6qwbKDnH3ocW6bZxV8N3M+UZpXaORO5vVSztoNDR+C28EOzyf69w39O5wy
l+A0gj+Z9ixjppNgX1yqF/M/Q3+qS/sQetuP/2CTd68GDLeBdSTlXkRPLjGP
k42+Gzke4e7gOt8Nze7HnnrWvQ9/HOwf5cwt4r8Ab0OLdyl2SvR/oNH3A0MV
+X4q6T9yXCfX7A3mHj34nbPRda4f/gh2W9r7EW/AKvo7nDHe+Pc3eA9k/NZE
P07Qj3P04IFKa6SXfO8mXSv8d7CXF73LMc8ZzOKevHsRPamK96no2YQmp9Dm
jpLeIucYuWdt9S7FeSVvxWiNZxMzGWRW7c3eleB/Hb5jaes3dvg8+Ds6rc/Y
oTL6czZrbUfMbrQ+lLEWQ5OnyX2kym9XxLyP9jYVXC80UcA+323s8Qa+Cd75
3dZD7OBn5JusN9fQYwJuH+S827HjSfhmWvzWxb6Ug6dvi3c37v8G9v8BdXkR
kA==
        "]], PolygonBox[CompressedData["
1:eJwtk0lI1WEUxQ9WBA3UIjOtRRqmFU02vGezoA1qqEWBL7VhEVr/XvDQghYt
MqGgYVVktdGMWpRTUJntGhYNuwbMijaZtdAIIjOtfpf7Xxzue9//fvfec+75
0vcd3hZPkhQF40BniXR6mvQ9Io2sk0ZBW0xqBdG49DdD6suVisqlp6nS3vlS
eYEUA585H+X78rjn273KtVJPJvcSUgv/r4Pb3L0F2sBParQSL4Nv/G6g3gZq
5YHHOdIjsIV64+fQk9ge3jlPXj85X8E5+p613gnv9Y84UCotTZa6IVa9UaoB
a7gv6qwmPtnE/OBKmXSRvG3cf07OCzCU6/0KycsHBSBvu5SYLu1YBafNUhVo
W8/sII/849Q4Qq33zDcpjXPm62G2dwWuoWk5iKan0LYdjSdSsx+tJsSdo3E1
bUyjYeZ/C48KtMthxqWg55D0jPxeYgs9roGXgZTB2c6oczFOy+K+gxXEIs5T
+H2PvCbQDCqOSq+ypV3E4YXSH9CLVpnM30R+Mfy3hrDfH+gzGT4fy52zcU/d
RS5nacSkOqk0SxpLPMDsB2Ne02ovXuDfxvCtIx/e4Asa1KPBzRLfse16P3MN
pLMn4ixqNlN7JrGaXjVgN7O+ZuYq4pRF0lTwIuT+nDhCzdGI7852WMY+LsCn
kX3kMncUNIb+ukSMhD5eGXffmH8K4Z7MWWfg+XYvHS5LmGV2zPds+77B3CeY
vy/ifIzX73BfQwnfle3MfGn+7MIHP+bis1ppHvezQUfgve4E7g/zyd3Ad3U/
cL+Z7/aEvH/l+vuyd3aGep+od7LWdTA9itC5Ep1T6nzHtutuMIN6xVHX0LSs
wrvH8HAJXq7gPIvvbwJ/i/YmTUPT8nXg394S62u9X0Ote8689yCs3RU4H+Nl
78ve2UPq5qD9YKl7wTwxKfT6VXj8Bwfb5pM=
        "]]}]}, 
    {Hue[0.09984392114521201, 1, 0.8617545707220141], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1lmtM1nUUx49YJmlGzksyLwFlAsIMKnkqIBV5CGRcXE0Qwwug5uNjOsVq
qzdZbU3stjnNfGEiaKmgSSraVqZhxmot8wYzXyStzFy1lmhKn+/O3xf/nfP8
/uec3/d8z+X/JMxfVh6NMbMjPP15PomYXRpslpxrVlxplh9vNgM5PYpNrNnV
kNmJ4WaVD5od5Pe06Waz+pm9kWLWl2HWGWc2twCfLLPdA80+JN7QVW7/VKrZ
8jKzl/DPJs5HJWZrhpl9jBzCu9+JkxzGr4LY+O5CniP+qbvNutF/RT+P3oqe
i93f2G8gXj1P/F1mLWB+uczjtOablWE/G/1NsFVlm8WS1zZy+SXRLB37d8A/
uNzse/AMQvZx/nac51VEvhvRj5JTxwTnZBeYvgq7zRO837TS8QjXI1E/1/v/
VpidecDsOnIvcVNGwCtyXp3Zj2PN+mWaTSTfIridBZ6hqZ7L4/jODWyqkUfS
zBpHm22v5v6HzJZwfm+t2cha10chN5Hvw9z7KDgXw/t36KNnm7URt574+5HV
BV6XeQXOk/gXR6MSnVvVaQvx47C5UgqmOMcvvrZTmzps9uQ5XtVe5z0h56mF
+KGoc/cY8jlySaOhotxViP4iPoex2VDh/IWQn+d5XVqIHQ/Wb7jvWew/CHlN
lmBfTP36cd5V6ncLQzP2b9Ev93HXp8SaGPY8VPN78Enmrjjkz/ikgnMfPdiK
zznw3sjBn5hJxEyFq0bqMY66bFXda8zmwOcFOLiM70ZiXqamTYH9tnzvA/XD
IHL8LehD1X8NTxN6JWd13D0TDIuQO6jdELhuoCeX18Mz8Wuo6a4FZn+NIXfk
4nzn/A/uXIY+FD2KfD7Qt4JnKnE3E39RxOWIROexZKbXWjU/Nslj7ibm7Zl+
rvdX4DOBHJvJ8TR3JMHJKeRmeElEP4k+lh5aCrYxyHGBfpl7u3n3Ljx0c/8z
Wc53I7WbQk4DknwXCLs4F1+HyPkF9PZK7wn1xsWQz616rIs4w590/5Hsg/YU
96sh15sB/zdqHLviqIc0z+rXBOLF8tzP+Z3IzLD3aNdSs4Ko4wkjq1b7XP+E
3xbNHTEGpXtPC6v4/jfk2LXP1HPqvSkzvX6qYxF4c3i+GMWOQrZFnPN9yEJ8
G+BtHf32CnXvHm/2eorvBumaowP0WwM9uh+5BwzJ8N8b8n0qu/aIz4R6STh+
4Pd44p9EbgxmuROc8+u8Z9Q7MZmuL9BZ2LnZWe47SDung7NefDvAdq3Me3NC
ou9QcSSuMrCpI99v0WuRxyM+Rx3IG5N9rjrRr6c5h+JyKvl/CQ/TkNeYn7Pg
r+F9b6BfzfEdrXuq6JHTEY+jeJpbze96eulwxHfNZxHPTTlqb2kXa5fMyXZ8
wtm7wussX/Vf3wrfOetC/kifTN5NJf7dWQCeuHTvq2owf80dCdx1Anm+wuNo
l4gv8TYk3ftP9vLrDHufqF/6r/LcxYHy1t7Qntob7JDr5HuRvCaCoafU95T2
VQx+x5nBxfDezq46G3H+zyAXBpzflum41GOapRmr/btSjFyf5rOgmfgH7tbC
YRt3RvD/M4F7Ij578nt1pfeLeBbvR8ktQ98d8Zrh+jH0gVH/zsUi30tzLltS
vNfV8zexvYN3PdgMQC69dVe996bOlVtztX+DdlT77tbuKcxyO9nXEvtAxGdc
32rtG8UXp9rZrw3zOlUU+NlCvglTgp32PvHK8oM9U+o7WjyL71v7TrZHJnks
fYs0n+Jw9nT/rqs+T6PvDHaF/guszfXduw65s8QxXILXC2n+ndX3VnOsPtTv
g3leu0N5/n9Fc1yU5f9phD1M/P8Bg+itxw==
        "]], PolygonBox[CompressedData["
1:eJwtlmlsllUQhQdUBFGohKI0LLZVlkKJFLStphSBLlKw/Soq/QArtKyWDyUI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        "]], PolygonBox[CompressedData["
1:eJwtkM8rw2Ecx99WbuKCTEzj5EdYDqasuXznIpuvIgqL+e6w4eYvcHDgH1A4
WFEOFNYcHeTsMD8OpJQSDpRkB3k9PTu8+9TneX/eP57g/Iq77JPUACpBaUy6
qpPWB6TuYakHvCSkLnZnYcmLSmmQm5P2wFNImglIfykpPy2tNsJjVg9JNeAw
Lq3VSq/9kuNIMcfeG51T9DrRfUY/D28D3je8CTiTjr03Ou9kaanH05UO8Mw1
Sftlf5Mjjd84vh5zkLwRcM6+AD7It0S+wKL0iOYD2MW3Dd/bhO1neo5wG0Nj
lHm0IH01S5e9dJklG/Bzn0HnLWR1jb7Zm/dMVvoM4pO1/UzPyJR04ZeizJQn
3XDr65N2kviDIt6tZNgO20wm2wn9OuhZou8dme7LXUynLXbX8Ktcuzfvv+za
4R+79r/Mv/3wf5v8YyFufYxfBb5F/JPk+AeuzGGo
        "]]}]}, 
    {Hue[0.0871966389671367, 1, 0.8792661921993491], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VltsVFUU3VCQVl4FWg0+UPyQZNpp0/5AVToVmDuFQqczocWZEFvaTtFm
ZoiV2sQIIZoY+UCjRkOUSCIUUBioiG2xyCs+EYkiT5XSxICEilqjNUUgrpV1
/JjcM+fus8/aa6+9953ZuCqaHm1m5/DLwu9inlnnZLO+MWZT4maTcs2aPbOE
p/XmErMDpWavY/1NyOztmNngdJzD89psszXZZlVBs+Mh2WyPmr3nN+saZXbS
ZzaAd+1YH0yazco3O4u7vsNdq+D/7hyzf+aYLSnR3pkas+oys1dh91rErDGg
/ayUWXbCbMs9wFoPO9y1EXd14a6+sNmz8P8F/N9qls1W2OxfYBbHfhr7v+D8
eAT9PHxeBe78u8xOYX/vAuEfnC2sxHwTPvbgXd4DwNWB+BvwHj6bW8yGYLcO
9n0496uLnT7Ww/9pnL0XGNf4Fe+L8FcE3mYB59O493SNYv8JfAzA5r6JZi9j
/xL2zyDGpeBgEWJfAU6OgZtdyEUbcF6B7/k48w7OBoA9B3absd6NuOvg+wVw
9ehYs1HtZlHYJ3BuG+yGkKPteK6NyGYBfAfSZgXgYUKR2WHE2IN7feA4D7h3
IsZu8PYDuM2FzW2wHcSZGXeYvQueD3vCVoW9y23yz3sWAlsM8b6EeCuDwkaM
S1LisxbnxsFXP/i8jr0q6gp+riHvu8KyD+HcMPwewX5rpdlXSekxF35ak/Lf
DM76cX4RYqxDjIsdV5/DXwb4HgTOv8qkC64bwEnnHGnuAji+PyWea+Hzb3fX
qZDu4/pj+JxcYVaOvHRj3R1QjnrwfGu1NDOIeI8CxwngGfJJZ9TbDjx3etpf
h3viNdJkj0923O/E+2GfdHII68ICadKA/QNPOqFeJuB/PdZzga3L6fAInosK
lBfmZ1lQNdsN/jJN4oc8TQX+CmDeDR83U+J8JCVNUBujkIcnCqSBeuj5vKuj
D2E/JqW6Zn1Ta+fypI9NTv/zYD8vJv3fKjcbjXuK8sXpxZQ02A78J5pUd+sR
64/49WA9Dfr61FPsrJUrNTrbi/w8FVHsXXh/Z0L2MdhUx6XvYmDsD6p2WEPd
jwM78OxpUp6Yr/HQ8zQXOzmY2q7ayeB9XoW0EELsfXHZTIL9m37F8DN81jlN
/gY8I37xXASe+pF7D2fHg59i4MwCno0lqgneuxzvCkPCSbzvh8VZdol6DfN7
AbHsr1d9TUd8M1ytcc/Swna0VLVN3j3E+kpE2qMG2RfI8TnkNzstPMTV0KK8
sD+lkuKE3LAOqYevwU9vWDqhXpgP5qUa6/NJ6Zm9sNX14Vzgz/jFP/PW7DRz
AM+9UeEkl0+Cl0LElUDdVNVIJ9Xgrb5SuqK+ul28fezDpeJpC3zsiGpGcJ6U
owaX4t5MQD2a2BJ+8Uueo576BTWcw16UUk7ZF9k7mK8NOBvrUL6Ytw0+1R3r
75CrHdbQ77jrIOyXV4pf8rwT3EzCXVuwjmIvEtR6fkz9l72FPeb7pHxyzlS0
KEb20U7XY4/h/UfuLs6NfWH5oe+Ip1huB+Ybbepdy7CuTItbckz9UYcrEUuX
T7ODM7PX8XY1pX7HswMpxcBYhoCtxfUu9k72C/aNlbAN/M+tp/nNOf4INPWZ
XzXIPlTsdHsd+4s7dC9nV6fraWNZi67WvoWWGluUd+b/rJtlrMv5ae1PLNIs
p5aoqSHH+QpgnFKh9R9lip+xPBZX7olzLva/TIpP8ppxs++htGYAZ0FPWByR
q8u4f4rbvwRet3nyQ01dL9dc5nzm9wH7G/vc2tXqb5ti4ohcPYz950pVUzfA
7dao6ppzIBxUr/sTfpbO0XdSHe4diajXPYNzWQnNOM66nLg0yfk27Hh4I6Ae
zRqshb+ytHLKmuB5+vm3TTOAvWJhgXor7+W3xojTf7xD30TETKzz0qp99uZN
7nvsk6RmD2fNuIRmFWt8Zkr9lHWdBrbjTcopc3sypNwxhweS+tbitxj7F/vY
Puz9B30017k=
        "]], PolygonBox[CompressedData["
1:eJwtlmls1FUUxW9ZhMpWpGCKgELCkrbUwAfpuLQIdKaA0s4ECNOYFKFDTJwZ
BEUSI8RgookRjRqNMREXQFSoomKKFNniLhIXBE3YvoCEKiouiQjG38mZD03O
+7+7nHvveXc6dsnyTLFXRDzOXx/+5tVH/FAZsWFIxKymiNtXR1SOi1hVFnEb
eMayiJ5RETU4TQd3VUc8wN3wkREv3Bfx78qIW/tGzOF8CdwzLWJN/4iXiLet
JWJjJuIO7hsGRWwCD+Avybm9ImIguLYt4oaRPjekIn5LROwpj3iG8+vc/8F5
/Ahy4z9sOt/aiQmfQ3A4MDniKD7PV9hGtlfVON612J/ivn2ZuauGxeDBdY4l
+23E/yIf8XtVRDfN+Bw8oM5cR3P/Cvf78+5HF/f7wLvgu7/cMbrBnyQj7uT8
PXw+Ap8quBfqyUnwbmwynCvgMAduu+hfFede+D8Hvwrur8F/MDUMBS9qs/8A
7Guxvynl3qgm1baAHNvJNRifheALWceTf47zPfczs0mud0YxYnaNY62U/yp8
WuFV6XqHTomoqzE3cSzjfkXJv5ZvS+hXkZhdZea4HHxz2rl0/rveMxO/p4aj
Jfp/ucP8NKP/wP1ynpXO/cF9c8ay6Q1+ttGxlKOTfjyR9uzU0znE6+Bbtsya
utiAVpnBkT7W34/g49Qzkdzf8G0Jseah4TbsH8K+BXy84PrV0xPgsqJrXcx8
AtyNnraO8vw+JtcifDYPcY/mU9+WrPUhza9ndqmifRWjGTwsZ+6KUQmemzB3
1fAktZRjc2KcNd8fPGi69TUGffVg27ba95pBFnym1dpQjafBHaX3p5loNpvg
NIF6j4ojXCfT/4X0fx3fZhLvXMLaVQ7lyuPTMMk9ObSUb3WereJJK1/zrX2U
bWTb1WJtqAc7wXvy3gV6A3vBvQvudQ896QPOTXZs+d+N/41Fa01vPgE+1mSu
4nyMej7Nu5fq6WfgrS3ePXpfb4J35I2V733w6ZXmI/sz4EeZwc9V9plJ7Itp
16/39k/aHMRFNRXwXzDFvawj/9lWv2n1R/vlYMqcxK035zT6/pP+TRjhnaLd
0tXoWer9aVe9l/GdNPAu+MBUY/l0ct5Z71ya4V34XphmLW6E7w7q25u01qSR
feAjre6nenQUnGry7lSNqvVeappIvvnYN8Lt6bTfmvT04FTvsPElvkfguznp
9yb718Dn670rVN/1+L7V4vh6T7/A7WX0fb7K85b2H6v2WXzTnF/Mmot8mjlv
ybh32tG/SuvNxtqx7eDuWa5XmvgAfDjlfSnNfQv+KmV/zUBavaJo7esN9ANf
Krg2nS+DB9Y5tnIMRc8zs+amHDPAJ7PWojS6He6ZJt+rBtVWlfPb1Bu9GtyR
9P7SztQu7ky6V+rZVvDcJvdGO2c2+GzBetYO+Qn8asZvV/reSf8/zDu/Zrg7
75lr9oqv3Ty24F0lDV4Hfrv03hS/E7ygtG/EV72/ss2z0szK9duR9Fka1dsf
nbN+VNOYnH+zN5T0oll9udSxleMg+JFq90Yc1/J7vWqq38rDxFuLHnLNno1m
tKzZO0Va1E7dTL5ZCdvqjWnXVDf6fep/hrnodXvS+tT+WSN9ZfzbqHh/JbyT
dCebd7Bd3+jatP/fYHecK7iX6nEP+HDe/dKO+C7vmOtK+WvJf0vC81K8Fdz9
D5Wldzw=
        "]]}]}, 
    {Hue[0.0745493567890616, 1, 0.896777813676684], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFllts1FUQxqe2DRdbKWkhERVlCWKKi3QxcdcLW5BulV7YLZSyG6CxTQ0m
bDW1aGII+uIlUdpgFIREJShihGJRktbW2IL6YAAlgNGXSosol4LRKj4IiL/J
9098+OecnTOXb76ZM2dnND1Z13qDmfXx5fLtSJsdGG9WV2G2MWx2scBsSdJs
e7vZH3ea9ZSaXbrP7OUSs31LzU6XSH4Bm6a42XX0h9Avf9zs8HSzRayJmNlL
U8xGsmZx9hvYP50y68J/caHZm9gN8YXZX0dnICLbhdi+EZbP2mfN1qJziTi9
UbPBdWa3hMwOss5B3ptnVk3cvzlbjf8HU8K4Y5LOXmhXLp7TxDLJkuifZt9I
rLwW8m/RPp+1nrPd2K6ChytZYXOM+ex/RF6L3Uha2BzjUvR2upx1cjl5ol8w
1+wO9JeBcwZrVVIYSvGzA/sxMCwAZ09UeTUlzBr48ovM7kX+QyV5TjD7C872
1JltQX4C2QF4f5XcxqhDTVI5LiHuYr6P8VOLvzR8nbjLLMNaE5W8ukI5e+7O
2YogVn1CnHktHNPYzaprHljvAUc9Z7/hozRj1gGereAZD0ePwdW4FuXtePqw
fSfI6wHsJgQ6Z5Dtwv40GE6B4ZEA59vpID7+L2EzL6V1G/oFfNduM/uu2ewo
/DWg9yKx4ynh3AL+SWWK2UBO3fyelW/2XEr9NatIv/+MiUPnsgsOtyI/FBE+
x+l16Gs023ur2eesX4e172c/e6o4b8TPLmxXs/Zj24ltBzGqYupBr2k3+cwr
krwUvVNZ4R5mvdIu/PPAEInofBM+psDPE/BzHgzVKWHeSy0m1inmYER9FJqq
2B/Waf87cVdW6J76fd2M7Rps78d/MiX/HmduXDrL4P7frHL/Hp2fQ9p3wktD
VLW+nfN308rjefCGI+KvCn/fNqsW655hQLTKPof1KPKryG8E/7iAnz7sHgZf
A77DleLL5X5+AXk/8qPIF2GfO9PsKXyeJfZxfJ5jPZ/VrPCZ0Rn/vy8ORsSJ
c3OOep+i5+qJWxJwWMw6PSv5aIX4dR7mYzeYUG0GEuoPz8vz20nuI+Sbg92R
IJfDrLXEbgLnAr9r9Hwntl+xX/mQ7sQv8PRrG3nMYt+mOeF7PxsMcH4EztEg
30Lmwfygtz0nt3fdNP42ptQb67E726ZaeE3eD+5LHZiPV6oPT7K+FtM9qM/o
8/0/7eLsSEi/ezPq+WOVqrfX+jNk+xOqi9fH8/G81iBfxfcK8s3Iu5nvN02D
x7RmnM+6Q8zY3oj0d5JXS0Lzaiwt2cmQ7PdH9Q5cRD65TLysSGqG+v5Mm2rj
NTqL/MuEeK6JiWvf3w2WZDBLlyfly3124zuUEf5P4HA0q7gXWFcH+D0Pxzst
pD6+HNMd3gfm4nJx4vNgW0y9fxnbDRHdnddTiu0YevB/jbNh/FzNasbHQ+qV
Rys0b6tY87KS52blw/U7gr53nIuJ81NWdRnK6n66XjNxDgY9mSLu0qjw+v3b
k9Ac6EqoLz3me1HdD6+x5+n30O/jMXr1m0r12KcZ9Znv/Z757Pc3y/H4nPV5
6++D5+y5v4XOwDpx9QVrUfBmfQBXy5Kaqz5fc9aDbzazZI7mrMvDcfWIcz0S
zHTvVe/Z5VHNHJ9P/u55rb1+yxPSGQZLU/CO+HuyqVTvze60+sn7am3wX8Dj
OtaFwawob9UM9fsyM6PZ4fJC3tn/ANwjmM0=
        "]], PolygonBox[CompressedData["
1:eJwtlX1o1XUUxo/uSi3UtGmgleXEjBtbzYJ2obpKbZZzL/e6zXZhjjYWBLsG
NvEfKRMqo9IM8qWgwlAjN5sluizSGf0RtQo1CELd7GXWmuQooczs8/DcPy73
fH/f83vOOc95zvnNbX8iu2piRGzkl+A3uTwiPSVi4jz+V0XcnI84OyPit6sj
9ldG/Lw6YnB+xJ5rI6ZXRPyRiii93u9MXxRxpiVi6uyIYfzfwH6n0vb3+E8C
6+4M/9Mixgh2F/YDxEgQayvPji/h2cKI5KSI9uKIz6oj/uWdodKIldyv4+5J
3lk3M2I+PuWcV+YiNnO3Ef9W7N3ETEx2jr+Q63niN810zGbwXs0YS/h1KWMI
awXn/dzXEm8V8drmRBR1Rgx0RdzAuY8a+rBHGqiRWsY4HwL7CO/cCV5yQcTF
ZERPzrmc5J1RsJ7pjjh9K3XcRE4d3CV9fhuMh6vASDsX1XwQO5Mp4HFuwE50
OhfldEG1VDj+cs63gD+eMn9F/BbDZU2VsZ+nZ2P3REwp9518xPVH5LcN/KPE
7MdeSj2/w9f71FMLfvntEfXUUkY//y7jR4xNxe7BZeyOnPnTs3bspmpzq/zE
3ZaU638Ozn/l/An8tk6yRt7NRkwghx/x3YxPZ84/2Yo5YQ06y5s79bSfdx9M
uTcrOD8FH6fI9wr5niXfXeSbWxtx4jbno1yXcd+fMAe12LkG63d8VsTLcN9f
6d6Jw3PcvcCzM/TjMv35usM9VC97boz4nPo3dPt+J/4NcLuVHpXAzVR8DnL3
Xbf91bMBuBhEwx8Xu2bV/g/3zxbyv4S9vcLalybvoJ57+bVij/PsLe5OUcNX
peZvQ8YxFOtxNDATLaxZaKxBfM7gez5VmFVymsb8lZHfYbAOUGM59gdp8yeN
92Ef6/IsSs/1cLE9Zf6lif/A20ePFtCrNvyvA6855/yV02nus1XGVoyp5Hu4
0F/V/AW1t9zn+RPnI8zfjkK96ldjtWtSbcfBG5E+2sy1OBSXxRXun/T4UJVn
TrnOxv8IdhHvpEutgXbq6QVz/jTvhDS17Glxr5WDdsFPq72rdH6E3MaZiRdn
uJ/14A/lzaVqVK3qgXohjXSCnUx7PrQDjnZ5p2mfKYcE7/6Z8iyJv164G23x
rryAZl6nnr5Kn6W3OXnPlGZLmm1Bu+3VjqWYbxL72yXGE/8DcFtXaS6UQw16
3Zn1bIjvUWJnq82tOJa2vuzwrtGO0a7RztBsakZX4Luv3rtBHIvroRa/Lz6H
sT/tMtfSyBD8zM1716gG1XZ/xrlqBtLYu7PWnjSwC/u1wnxI0xeJ3VPozytg
zCLfeTnrV5osxT6UNFfSi2b15BJ/C6TBv/A/l7dWtFO0W7UjtRs3gb+Z+Msr
rUf1uIn3mxts61kjdzUp+2o+j1a7JtWmb1RfsqDhhDVxoN6aF/fqQQl2Sadn
TzP4A/41Gc+SalqGPZy3nqWfl4hVm/I+147cwv22lHeTen4pbw7ExaNgFoO9
tLCv1S99K57utt7V7/XYdWsLveHZTupZ/Bg9nuOZ1+xf1WksYa4Hv67K2tbO
0m5bVmX9qN/XVLgG1aIe9aLF97KuV5zvzfqbL2zFWESsE4V+6Puhb01jg/HF
2XLsD3PWojR5APtK3rVqp+zA/9hCz4Z2foD9TYd3rfLTblXOyl187qU//wOc
NIwv
        "]], 
       PolygonBox[{{24503, 24502, 24507, 7340, 24506}, {12777, 7785, 25876, 
        24502, 24503}, {28224, 8963, 28226, 24732, 24733}, {24248, 24247, 
        25552, 7677, 12556}, {24486, 24485, 25861, 7775, 12770}, {12555, 7676,
         25548, 24247, 24248}, {24733, 24732, 26178, 7883, 12991}, {12772, 
        7777, 25864, 24485, 24486}}]}]}, 
    {Hue[0.06190207461098629, 1, 0.9142894351540191], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlW9MlXUUx0+ITRK9aMBmkdXVrEHUrma7rAX4gksZ4L0XmlxaatyBW+Oh
jUHm2rJ61b8X0l99kZtZvqBSEMs/Sw2tZlQosdacMwNJs4KWa4vlVn2+O8/W
i2fnPL/n9zu/7/ec7znPra1PpDtzzKyfZxbP/haznhvMBrEvBGZ3F5gdSZjt
6zaLzDPrKzdr5D2X9bnsacZ/7Rp89s6LmR3KNRteZ1ZexDt7tvHtnbjZyTvM
GjaZVbYTL8/s+h6zIp5j+FWs5YdnD3I2HTUrBsOBOTzrzebPNrsc87VU1GMu
DtzvJ/Z7abNbis12px2rMB/FlgQeo5k9M/hn2f9n4O9aXyJ+VWbT+WY7M2ZT
cFzJHWXw2pDwe86Umn1Za9ZLzMPLzdbCIULCZsjDVfY/cLvZ39gRYj/I2Qx8
rgPrzohZXQ18Sj2O4vVz143kcB/2It82s/4R3xs4V8+Tn+P5VZ63sudcodm7
xBkEa1OY8+3E/qLD1xuJkQeHqUVmO8C/IgU38n4P9vtCx/AkdxRUe86nKzgP
1oXcdZH9T8Onhtz+RYzd5DkPf5L4faF/AT8Ljm+pyxz2nABDDAwrOJfDeyWc
52OT5HMAjKNZah74fp07HNZONdSdI7d53oeIcx94vgNLcZv7i8G2JumY6+FV
U+G5nO4ye7TFc7QOG+WJ4S/BTsQcp7Bf6vL4mfvNWvmWYk9W+uT9a9Yn+f55
h+cyDd730cpSNNOHzQPDvdy1iDtfL/B16fJKhdsx6r80cP1NkbfZ+NVw3xX3
HMgX52SNx38eXo8XuQ7FrZd6bOW9nnjtcI+w3hx4LrV+hRrVsWcj/kPYZQXu
C9MrFa6tcfbviHlPtRLjmQ3kA+5HqMWvcJuSllg/COdN4DzU4vesJ04JcYra
3H4Mtm+yXq/n8GelXXcra1330v8Qd23n3gnu/TdwPuJ1inMvphzveXT6B/wX
EDOX2B+GmpF2pDPpbVW761F61j71tnp8bszngXKn2VGVcpyV2HHyGwHDjxnv
J/WXuEVanHsWjmu4t4Szx6nn22EeqjvhEWpS2nwWzOeWmW3pdp7iu5r61KOx
M/RGHXYm7jlZCP6Hef+B9UbWPg28L9Qfv3c5jibu35zy/h1A2yfDmZBL/raQ
iylmyIkOnzHjUZ8R6kthUA+O1Lq2intcQ9LSNHaIO95g/TTf6+Pet6vBcm2b
52wgnEnno45Js0o4NTs0M8ai3id3VjkGYRkr9bxqNqve4vgm35Mp12UKe7rb
9bWHeu1JuOZGu70npdlPWL8Q+B2PwH28xnk0gG0YrK+y/yvsXeH8LK9yDUlL
E5xrTPr8asKuTTgX6WUycLzq78FwPvwS87ms3DUzXy8Hzqu3wvtY/KU58VPt
VEvlviecmdKivi8o8x4Wrw8SPuM0d24KfAbIV95Wdf7f34U9zkWcji53Lam3
VG/V/TfqfyqsnWqo3lK9VF/1x9mwLpq/qvdExrUpXzNBM1t6Vj2GQ/1/hk4O
xP0feYn8PNbiMUeJvzGcD5oTyrvy/1Pgva0+eIraHQ/n8Ev4/wSut21wGYj7
v/PmwP9Pwlhe5vNSutV5/TP072jCXg1cV29x9uVSz43+SwOlXmvVXP9V5Uf9
fCzMj3pub6gZaefnmNdR9fwPSVFzww==
        "]], PolygonBox[CompressedData["
1:eJwtlVlslWUQhgcsCrTlAEITa0UtgqZY4RQ1rUQOmLRHsS3nFLA9DUKkURLT
g0lTRL1QLl0wgiDSGxW3C1cKGhZlV4NRWSTGEIKyBhGKRmMkmqjP6/tf/MnM
/8038847y3f9okfalgyOiJV8JXyfLoyYNixixJCIbcjZhogVYyPSIyP2NEWc
b4xYNygiXx0xrhixod5yRWXEhULErFzE92MiHsXmydqIl7n/I+e3cV7TGVFb
FzERX8vx+UQ+YvSDEVVJvJ/SnGciLpZFHMdHO77a8L9paMSbqYgvuiNSacvH
OJ/D+STsB7A/ip5DX1/w/ceJ/1xNxCriHyZ+C/HnE/9Al/1tJdkyfD0GhgFs
ry7nDnLF0og14NsJprHI67h/gvtH+f4g3zXktBr7FP5OEOsDOLod22Hgf3+h
ORAXbdj3g30od74l1sBV2CA3w9/6lDlq4fwY+BuHmKO/OZ9aZ67F+fPgOV5w
rBL+zYX/vd3Ot58ccvW2ke1kzuu4+3GNcx/Nnb7eiNM9EV9P8L/5xC6B71EJ
3pPk/10W/4Od4z9F+5Cvh/GZw/d4/m0e6pxuQO7PmCvV7y64mZtzLcRpDv8j
sJle7ZzLkf/lO1ntHJXrqwVzUcW/2eC/g/i/gW0l/lYR7wVsUvjvQJ+K3tLg
M3Gyl/w3UcOlYFmF/iV332kDV4Vrtgvs07gzH/ty9FfIb0rW9b37RviFjwXc
b+V+GTl/lnVNVVth7CPW7qJ7VXh3IW+rc6z9+LyCWJ+gv4h+HTHfQh+U5Lvv
pojXyWdHk/lTTTQ7mYfcSwvwt4O7M9G3J/pO9L96je0eYs4D28aE3zR6NfqZ
gmupGnbcCeZu9674/rzbd3R3PxhWEO9Ql3tDNuXk38V5vtIci+trivanmlYh
j2vwvAvz0+g/pz2L+ldBr8whpx/GeKZuyZhjcX2Q/IaT/6Imc12Lvhnb2knu
p5f490Cne069Jx/z6JWt/FtWaRv1nnaAekk5b8D/e02ep8X8a+bsRNG5FfjX
1OCdoN2gHaBdMK/euvBN5v507izkbor4r3F+b96+tHO0e1qS+dO+yHP3dNqz
8P8Mk+/cRvuWT/luTbuXZ4BhCFjGd7o26in1lnaKdot66n7kWY3m/4jmO+cZ
WZ7E/7DJO1D9pZosQi4tep+oh8qQ36h3LOnqLWEUVs38zRnvOOnKYTjYOpa5
f8VnO3JrzrtX57ORO4rmQjv2Er5+r/d86N9i8BzKulaq51qwfpV1f6vfV6Mf
qfG+V41TnZ4BnclGszBqkntLOQ3Qyxd7XCv15C899iF7zdC+rGdOs6cZ/qjT
NRIWYdLsHuo1V6rHQeSzOfeWMOjt6Ur6TfbK5c+iZ1UcXEJ+u82zqRkbOYPd
n/X8aUe8y1mBGdo/wTOg2Wqv9yzo39ke95jw6804p91VNF7V+FTRPS+uxNnu
OnMmXTNxgFjnkvkR32Ppp1NJf2nnXo6+Mtlv93HnV72dee9azdtucjtTdCxh
OI18MXlPlP+WGr+pqu+xifQV/KzNOJZ6PoOvK5c6d9VnDPKzee9O1egZ5As9
ro369zxyadq7Qj37DbvjYNIPmtEt1OepXsfSztbuLu30W6SePQyekjbXVhxd
hjwl79yUo3b5tUW/heJYXG+v8+4TxunswhlLkl2IPhP51rx3v/hqh4++tOPJ
p3w35zxbmge9/eJQZ7KZg31/r+8q/kbkk8l7I876wdu6zLta+PWW7+n2W6QZ
16z/B5LygRY=
        "]]}]}, 
    {Hue[0.04925479243291109, 1, 0.9318010566313538], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVVtsVFUU3YrUlnZoix0MlY7xSulkpJHpj3dMsNEwM/qhnRlBOlNgKs2M
hnAkacDWSGL6YdSCCYkBlPDjh1XkYToEIyFWXhrlkVLxB1I/aOsj8mgTI5Dw
iGu5JvHjZp97z97r7L322uc+tm5j5o37zexLPLPwbEubbQ3iga2oM1uFdV2V
2VizWQTvD9aYBXJmVyrNDvlmbWn5RGFnfPlubzc76pmtgX833ptzisstMxtp
MzsdMmsvmk07s4mFZlu6zZ4N6zvfR4G3JGD2IWJ3R5VHLXyfi5m9gm/DwH8X
PheahctzfsV527DXD/wc3n+H/3SvfK7DnllrVgT2vR6zH5Nmg/D9CHh/I+cF
WPckzO5uEu5AWrW+E9R5b6W17ocdTSqvnYgtRcz67jO7DcyBoGLof6VXfF2F
veFUyzhyjiXLnICPyozqrILd0Qri4dPRp7OZQwt8DiMmhO/fAaMCzyQ4/xz5
plDrZIPZn3j/AP6D8B+E/XiTcIi3FblNLzD7NAs/cPg6uJ1XMNuPva+R8yXs
J1FDHvmOJFQP6xpDjgfyZkPg6mBe51MP9CPeeC3yqhR35PAM/E8ktE+8U8D/
Bfj/AL8CtZ1D7OyMesI1YzJR4TziZC83CDOEutrD6tMS1F7CtzTqvQq/AER6
o1W4xD+aUA2spQ511TWaXawVR2+n1Y8tsCVwMrsFmoFt2GzWhfVDsN2h8nfE
vxCTTo845TmKPN7D+6TTegJ2CjxOAXsXcH4KCYc5fYL3mcXIP6JauGZf/sjK
HkD+1+CzDP71T5g9U1T8t9DpIcT04/ypuNmdHtVNnW6P6fwcNDCDs+finJuo
PYZ6ulDX07CvJaRb6verhHTH+ehKSRse4oZ88UHtrG7RfBHrltO83IT9OSx9
cnbOe9Iezw7n9G0HMOOedMX668H1XuQ5nNfccl7nFYXNGSb+k+3q50pf+6yX
XNUXZdnP8Qb1iz0+GxTv1AZxiX8Ydh+ez7CuxpkjTrPDGbrXJK44e08ldSZ5
SqeEm0mJO9ZxB9xXIy7cKL5qc1pfBPfnsbcIvIzBNjrxRv4eblQM77i7PeoR
e/UqYlPYa0Ufv98gvZ6CLYH/UfgMACNf5o38HXO6B4877dGnpqBzVnrCn4/3
9eDnr6jq5pr6nuPETwe+L3Sa+SanWedMct54Ly731Bd+o8b+u2+d8t8TFd4u
T5gTcXHGe4s9Zy2c+Tc93Q+cJfLN2eBc3PK11wm8VX3SSidsyVfu/A/MKcg3
xTuqoNjJqLh51BN3nOlQed3kqX/MY5ETD487xRMnCy6zKd0JnbBTTrr8DfZ9
p1pC0OS1Xt23S9s0E6yX/T3o/z9/i8v/Hf5/Xk7o38R/VKCgOqmvWRnp7wHY
4GbNyXzYC+ComTrIScfU84q47kXGspcpX/WchAZqnHpR7XRnUdcvxoXBPvHs
Kv7D4FMJ+4WvvvFe4b3Dvj2PugJR8TMG3QWcZm+uk06HyueyV9QK+9UBji6B
q5dghyO6ByeA+cMG8Z/xNbs8l3fBNxHp+3pW+mIsc/0XGWtjAg==
        "]], 
       PolygonBox[CompressedData["
1:eJwtlW1o1XUUx89MzTnnnDnDtS1azsn0UhtEd4FdirbVi/JuVu6h2uqyFbGb
IFe3MJKCqJyBLworIuhFVpLGNhZBuZ4syh7msjfWItxsSDXXizAhlT7fvvfF
H87/d87vPHzP95zfNQ9ta3tsQUQ8zbeQr6854v2CiDWFEQ8jr+yNeKQqYmd1
xPlkRPtAxA/rI/ai/zsb8VtTxNiSiFOrIjrSEccewEdFxKXKiOL6iKLOiJry
iBXYb8Hfp9z5EF89/G9A18HZcIH1nc32Kd+/KB7ywYT1i2ojRnIR0x3Y4m+G
mK8j70v5rmxkO4nNWmwn+D+Mv2Mt5EGBXZyt2uEz6e7lznvIbdR0NbGq+L7o
j1hOzCbk0/hfgFzNN0Ntf/A/gm1TY8QzZRHHZYPuKr6pkogz6A+jv2KHY30N
Zjf3RYw2O5ZijiDXt0Zs5f7iFRGv1rtm5a+zBnT7c44dxREvIw9ythtdHfZj
wipnLHrwv5jejHZHvFPhHp3B30H+3+T/AN8h5HHudOP/R+IfQT4LZleWu545
5Pak60tTTwW1HEq6Fp2V8/8N+O0pNIbCsoiz26qdfzv+2tPuvTBoI/4W+DBY
YEy/7DeGqkd3liGfS9iXfP5M74ZTxkc1Pk6tS7C5tdr1Z9Ad7XdvxClxa/OA
der/AXL9npyW4+8FYYy8Gvzvq/WZdNfi755q16Na/8maW/eT/64G+Jt1L5/l
fhd8vJCzrB5fzBlzYT9ZA2bbI94As/k15vx15LewLeLbMtfzFfEmW5xLGowf
xN/1Db7/FDa7qC+xwbqN1HAeLIY4G0JXxf9YymfSaca2UuvvYPpolXusXp/O
46v4mr3N6E+C/RT1tdKLfzMRAwXG60LGGCu378Q5ci3kmyhzjklyPdXk+5qp
4TpsyWdPmTnzGbXPNrm3qnkIfVvasUbEEXSL2uy7kxoHqfUsGJ2oMX6ald0J
5yP7jeRyKePcUtSX3ekeq5+auWJ68WQPM65eU/M4/u5s8t2fiLmZ2L8mjJVy
fJ5cZ+o9C+K8uJ9p9u5aTz0l4F/Ua532w1LkyYx3UyXx0vDhSINnVTEVuyRr
bouzb4svCXPpFvLdRr5TKfdHGC6h9rH8/Gm+jmL7UX7e1NO9reaYuKad9wm+
b2gxVuLMZdw/Wedcizjr0S7o9f6Vz1Lku9KuXT1Sr+6mpsuXGeP57Z5pxd6P
/+fwn+ozdpqBsh3GWFiLMxcz5rj4PaGZwP7P7ea2fMr3aNK7QfnUoJ/O2lY5
/5/7JtuK03Pcvb3Ru1w1jmPb02lZO7wbeYz6/lpnDolLsx3eLzp7JWdMha3w
n9fbkK9HGArL9qzfHmGitymZny/15Ebkz/vdS3FMXHui1bOmnaLdexP/XWXm
xIv07q2kd4fwXIrvUuZxU605JW7JRraK927Cb5Tqk81czpwXHxVvWv3Iv3/C
V7tvWa93vThXjPxx1r7l4w6weqnR2IhD56RrdO8046uxr8x6FwsjYaUdrX5o
h61Ft7LPWGmHliLPZt0b9XRfo3ey+Ks39wTY13Z6FtWzdciHu/026I08Tj2v
1bvXwqix1RzUv96ID+r8xgov7eRCYv0HfcRviw==
        "]]}]}, 
    {Hue[0.03660751025483577, 1, 0.9493126781086889], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVVlsjGEUvfalLVVbjJL4o1MqxQzRGYlMLDM0EdMZtXRIiipPHyJDbW+E
CA9IhQiv9r1LqOLFi3ixhiAeVJWESq0P1nOc/2Hy3f9+97v3nnOXGbNqfXpd
dzM7jl8P/MIpsz75ZpmEWVPMbHwvs33QLcN3fTezwc7sdMQs4ZkNhLwlbDYL
Nr3SZmegb+9rlg/93n5mE/J0F5lrthw++8GmALq8YrMA7l/EZPO91OwVfl3w
nz/BrAM+Xgw0e9LT7DN8DoZtqs6sMSv5UEz5Mc8qnHV+Dk2IuzCkd+82mqV9
eWmF2flSxa7H2/a4/L/BeRDfnbBZgLcbgOneOLNVoxWPsRhzcZ3w/IX8rgr6
gNl7nPvBy0Tk0IocbBN4gk0X/LThbhBscjP6pr4+Ci7xPRX6m9C1IFazJ37v
ILezhci/2qwaNknYrMgoPjEyv0NR5cBcHiGPMsg74edrRFwuIvY6cUgun8D3
fWBpBZaqCuEl7mtOcSthOx9xylGLTrypyui70SmX8dBPh9/fWdn8whmEzRTY
FOM8FlJeIXDwfqM4ITcPPPlhPT5khZe4F8JvF+xP4F0lbIqhP4K4l6EPwnYS
anguotp3xFUH1oMcPC5R77EH2XfklrGTnuKyxg1OOJLIpz/k2bg7BX8zPcmP
YDMqKky7nThmbuRrqNP96phws6a06+P0fpjTG+oK4eNAVDjfOuFY7AlbkZPc
EBFP4YByYr4fg8JQ6OfQAizlUfXBbdakRHy8Rq1yUbNPQXFxNKu3R3A+Rw07
g5qxrWHV9g/0g9ZILlgjG94TzyWnHMaC/2lz1Yfs0/M+z8PJg1N+7Fn2DOeR
ffYM8lNPbwKwWQD5At6FwurZFqe+J1c3EsJEmXesCe3/44krp7a45oe+pyKX
cbA96KmP+9dq5nJwNjv1D/uxPSR9A941JmTL3k9VCF8S96mQ+BqBdwX45UCu
gO5XjeSfOPPgtwZybq145SwQP/cBZ4e1+10jP24zbJywr4fcOy1OuKt2Ofl5
G1KdiO9piXYbeZoD7Fcj6m/PaT6ZcwB1/ogZeViEvTVDNaHMvt+e0jk5rL3J
2p2FjwEZ9Val085irtNT6m/21EXob/izzJmOpoTjeEjcMi79Eg9x/QG+k/B7
F3OVxOw3JGS3A+9qY4rL/d03LRwvY9op5OdbRDt77Wh9X4xo9kY61ZCcMF6r
09ttYeV13dN8MSbniP3/xee202k/sefYE+Sa+h+l6kvWh/uAvUu+rvj7mfuQ
O+GWk/954LaxWjtrD3u5Vnnm41ziJHeAk6s+XuIe4s8155vzxD4hftbxmd/z
3A0vPeFp83s4jZqvTIgD7t2mrGrEWpX5/3H8r/vu9PYwcvsHOfFDeA==
        "]], 
       PolygonBox[CompressedData["
1:eJwtlElI1VEUxk+RppY4VdBrgB5omlj5inpPCGnwlRC9QRt8BZVmrf4VERjV
JggialGiGFHbimjUDLJp0ybaNFKUq2iEtAlt0UC/j/MWF869Z/rOd865s1p3
pXeONbMMZxxnIDCryjG7GTa7jXy21uw7ilC+2da42ecWs7KQWc8YbOaY9XG+
VphNnGn2t81sCj5L8X2Gz2TkP3vNGmebrcYnQ5KPDZw8sxfom4i9hbcEuu/E
i600+1Vj9hL/V5xv+PfgP0T8EmzekftG4LGGse9D/pjFk8D+StRsBDxV5Ls4
3exBjeeU/RP0J2K8Y/Oe/BPAW4p/NzZdYzzHKXKFeWsOe30bk8jcZ4ecgybk
f9jcwfdxpdnaDscorJuKzRaD/zr3CPYVcHgNuQ/7VuwfYZ/E/lDKsYuTv+iK
sInjP0z80/AxMeO1CtNzaukG8yD6hbxVouvifizfOfqJ7yrut8Ler1vc7wZu
u4L8d5AH611WjFHVQowFWf6EZX/E9Yq5CPzb6r134qgdeWrgvVXPLsHdazAV
gr20kDvchci/GN82bA5jW57x+pWjAnkhMY+iX0aODnIdS/l8zYWv48i34y6r
Z+pdL2eYXrwuMnvLrBzEprLY+TyQ8p6oN2uoJ0S+RK3jXc69IHAOxMUApzHm
PVKvhKGT++Wo+2pmNDuaOc2eOLynWtu9lpPcD3H/EPjsCP8+8I9EfRd2YLMe
3cs5jkcz0k8/NyR9tt+AvwV5XsSxi6Mb1Fqb8l6Pp6YIckvc5d3kSBLvSuC9
EYdXkfsDz60Zvol8P/DaxGE//Smudvzq+Rfyf9rj+VXfZ+Q1gefTTCWQO/Ep
y/e3k/U+k5pNvf2gtncNjl07rd0+Evgu1aGfEXNOxI160gv2M9n/YR1v5cIW
d1vhq6X2dNJ7qR6lkDNLzJ6We32aldzsf/EQDOeizoG40M4U0IvCjHOrneyN
+h+gWrQzF7jPz/KrmEPU29zh/RcnTcj5ad9NzXge8vmoz4pyKrd2StzpD9qM
/LvN/wbNoGYx0eHYtI/6K3LS3o9q5j8XuS7luyAOYsijNa57QfwvxC8L3Ff5
Juk/iDpXqkm1Fbf7LGmntFvyka/+mJLtZtMC/9vU0zRc/wcXCfvJ
        "]], 
       PolygonBox[{{24268, 24267, 25598, 7692, 12625}, {24498, 24497, 24501, 
        7338, 24500}, {12624, 7691, 25596, 24267, 24268}, {12774, 7779, 25869,
         24491, 24492}, {12775, 7783, 25873, 24497, 24498}, {28142, 8919, 
        28143, 24700, 24701}, {24492, 24491, 25867, 7778, 12773}, {24701, 
        24700, 26130, 7868, 12921}}]}]}, 
    {Hue[0.02396022807676068, 1, 0.9668242995860237], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtVd1PzmEYvkMUtd7R62tr9G76eK1ZjZTZOjBvlOhX+Uj60Oqgg19Nyjs2
Y0Q5QoUj/wAmXn0tHDmz5jOhCSc+MsPCqbmurufgt/t+7ud+7ue+r/u6n196
Y1tF6zwzu4ZvPr4jIbOETLNYnNkV6DkBs5fQh32ze1gPQcbw/YTtXY7ZHeh3
YL8LORw2S11tNlMNX/rBPggZDpo1rjSLTzK7tE/6RcjqgGLWJJrdh98I9DHI
T7lmi+PNbtWblSKXULbZNqxz85TPWMRsN+xv4f8LeTzPMtuF9STWKc3IEbbf
yKUMthLn9yyKD/a3UcXgXbWJil3qzlbi3ukUsy/bzTzoEwvMxuvM1sInPVvn
p0KKy5iMTZ25jfjKZRqYZGTKPzuguMyNeJVSx3cVek1ANfDMYdSThPV13FmC
/bhks88Jis37GL+2Cf3gOchB4JIMWwxyAnVmAPOkg2YHg8J6BeoajSg28xoM
6866Jn3UJ2FLK4SO+N2+aiEWzPdRjnr+Bz6zBWaLsFcO3DZ7uqMA8rev3PoR
40WHWS/0M75qJl4HkMMDrEdhf+grxpps9ZUYP10nPsy0S/8K+a1dGLNXvI9n
7iF2F+5sCSpmJWIdRcwqX3Un4L6lidofCMnnPPLrwfqcp/uJdZ3z6Q6Kb+NZ
4jn5npYsf/JhocuT9i5P/mchyzzlxhwDybqTM5IPezV8NnnKhTr3movUxybI
rKD22NOgrx4vh7wFbMugr/KFCfFgbwZ81XIb8maO+PwGvbgQVK6sZTas+yvg
E83TLG0sFjbkEjnAWSQfGLf1mDg76ysP5nbF8ZU8SVmveWN/PoOHWxrE2dFm
4cSaeV/Mce8LfHoLNTt7o/qo/+vQzHB2ynM1C5mZwm6gXrwiv2jjHnnzGL0o
DimfSsR5inVVVDWzds408dsZUu5PsN8R0h7nidgRN3K5P6T83pcL9w+QFVHl
XoeZWIr6d8DnBrAfjIivG/I0r2vdzJJ35Ac5sNDlSFyIMblDXC4XCZPeIuXO
mKyZuLIe1sLeljo738IWx72TDZrpH74w4/vFuSPWjB1zbypzIZ/ZT9bMetl7
8pk9yy+WfgL578GZNpzZDZnqC6tlvrjMGpj/KU+zdBpyP/Y64fO3QBya4xJw
GkL/lsD/NbDvgr0PPqsLhUGfw4HvJ2eFvez2xMseTz3pdPi/CgsDvlvsCf8l
9D8UkZ3733HXVnJrvfjKOlkjOU47a52KiisTHaplkZtZvqnsB/EiX3iGOR3P
E7bEmD3NcNzj21bi3mq+a3P/tIjmg/Xy/kn3Tn4sV2+JJ2f5PyU1IwE=
        "]], 
       PolygonBox[CompressedData["
1:eJwtlVtv1FUUxfcYKgULjMAooiQ6UYaOIaaN4oya8EAYFAT6t1CcKffAAyR/
iFhs9EUjhcITWJEX4wdQjK10WsrtA2gMKBAJRAExcklUoOAr+luuPpzk7LP3
2WfttS/nmY3b39r2UERsZY1jDc6P6JwQ0ZuL6EkiXl0fsbgQ8XM+4q804kpb
xBx01xsj1lQimmsRa7F/DZs/uyL+Zb3J/qc5ER3dEcvw8Tb6p5sjvkOOnZyh
78xGzFsUkX3ed2dNirg8N2IT72fYL+a9HO99ivw494cyEYfRT8H+DvuL6Le9
F/FVKeJ19otYWew7N0V8lrH8KHKJ92s5+5CvhLN30B3BZrSIHzD9yL4Ahkvs
byyM+HUKMWBzGN/LsN8u32D6hPu/VyOmTvDZcnTHKo5fmEbYr+Ds3bzfmww3
11siJjbwNmc9qTEK2/fw8yX+94JvX84+5Gs3+oPoz+Gvf13EAGtSg8+ke6pM
fHnLe5Bnlu27j7UL+Sg+1uBrLz734Ht34r34rYO/DTznx5mzqdhPY73BvpF8
dHL3b+QFvHeJs3vsz5HP2XDTjL6O/mDZOvF/F/0g+vEFx/gHvm+0GO9O9KvQ
70pcS1tYT3K3g7OuvG0U2z8l2+psJbp7RedasmyXJ757BHkQ+Tfqr6EpYuOM
iAMdjkmxicNebC9w/xHwFJGvtTkmxTZ7JnEXzZm4O8SaVXaOlCvdGSKWL8Df
lHUO27HtTW0rvHXw1rFpxPYH8pdQL/0lv6Uae5n3R1Lzf5Q7J1LXoPItzldT
m5+3GI966DL4RlNzqR5Trwmz/E0H73DRPaPeUY0uxf/41L2nnE1nv7biWlZN
rqu4BlQLyplyd5yzuVnXjGrnJXxUc8YgLA+wWVJwzt9vhQvuL8F2KevrknOi
XJwm3vvIV8F3KOMcKBfKqfLTw/owMQZh0RvzkJ9I7UvxJ7zXN9+9JA7F5d2x
+DUTNBteZCZUs54hmiXiTHeFaQa237IG8p4pz9a8tO/nrB/dC62uVdkMIJ/v
cm+Lk7Nd7jn1nmbMZrBM3hzxcMEzQbPhsdSzRxyLa80wzTJx1Fc2B+JCNbKB
WD9o9Swb4c7J1DNDs0N4xeX+DteqcqpauVk1d2eei7i1wzWkWlIPjZY8A1XP
ZzhrR3c8dS0phy2t5kC+lYM69VGteV4PcjaM7uYO+9YMa4fvFd32pZpUbTbV
3AvKkWbZx2P1Ig7ExTepuVRO1Xu/gOd2ZuwN+LpVdW0qBsWiP0BcaeauZj9c
8ez6vwfY11P3ru4Lq/4Q/SXy+Qr1PpQau3LeTXynUnOpeai/5aPEtaUc6y/5
D/heIx0=
        "]]}]}, 
    {Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], EdgeForm[None], 
     GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1lMtrk1EQxafaimmjttCWgiVgoeRRXbioJrqoq4BgQj4jXcTUiqTFTSpI
sbhS1KjgQsGlG3cWXFRpfP0JLsQHbhTxsXQhlvoPOD/OZHGZ+81358ycM3Pv
gQuXTq/sMLOrvnb6qufNzvja7DNbuWJ2Ime2b8ZsKWN2z/dDA2bdKfnfT5o1
UmZFXx/9fNNt1v9/6tO/xxl9VxOzi2Nm191WYv92TZjTWbOW24m2Wc5ts2V2
/Lzit9237jbnZ0qOfdtjZ4bNXpXN9peU96b7Lk+pNnDA/jBttittlvK4vPtG
U8IgFpw7HpODx5ziiIfXc7eTe8QpPaCzcPm92+vzfdf3zxbNnnhN823xRQs4
/u1XHnR755iDnmvMv6t5WfyD1OP1jaekDfnIdS0RFzihPT045WvW18m8NEJf
fNTDWfjhgys68n00Ua0bRS329+eVj7x8P3TOI86x6GefHtIeX2pYesGBmtCB
PGiEVh0/v12Qxolz35zTmW+OsXdJ/hvu/1VTrp818UYXuHcL6i99pifst/qF
RSwYX9fE94vb5Yx0pg/0ppIXX/SpxHzCHY3gfytRPdRFP+kB+dGMvqHb95rq
eXRYGpOff4WMeoNO6JHOqt+9/pG/GnnZM7vMGXMNxnjMBnHUTSzzQf3/CrLr
waVZltYLZZ3jPH5mqBH3CDx6BSb92AoNFyL2R036FULD1+4/6P43bv+0dXe4
Qxsxq522aq+GbiNx1862hDEeOciVD0xmn/tC79GBeUY7/tUDh7sKDniLZZ05
V5bm9Z7uq5rfz6vSHYzZRLVS891Es0sP0fZIIpzF0AdtwHkwr7livtCemN49
IA7dKvF2kZ8+ToSO5HkxpfsKn2bc60qcJbYU//Cnw5KXuG7E8lZQJ/N6LN4o
9KYnozHr5Orl6cQM8GbMxj0mnlkoBTfegUa8m+QBkz0zjO5DUUs2OPL20ZeX
bv8DbG/GzA==
        "]], PolygonBox[CompressedData["
1:eJwlUb0vQ3EUPRESryFqsDVNkMZ7r95YxGRqYpD0vaELSqTE0kqaRkfie+NP
sJEYhBTdzUIEQXytLJLyBzjHHW7e+b37dc65vXNLUbkFQD+jldGYB/aTwHUC
GJ0FVkNgsQcYcYAV4vXQcKIT2CDeYQzGAbcN2CbuYv8C+zsGgEcfmC4CHt8O
3/d8N0s2e8wFysvATQ3IePymgK8K+9OWq/cBr4GF8BnjomQhrJ2NLPASGJcT
/jstWQhLg7RkyOmbwmKsHyKOuO+K8yusiVi7xiiyNkV+t1Xglxxd4kNyvAxM
g7R0c8dRYBzFVZ5McN4D8zHmfc4oFK1HvQeM4xl6FVrvZzswHJoH8sIhnyny
n2SPmzSP5NVd1biM05Nncj1nTTpunMTtPWe90vSWMw3SIg1N5nfztssjv728
cRI37agzX8iaF/JAXvz4xlU30+02Q7uldm4Rf+RsljRK61PNuP3fjPgPAV1j
5A==
        "]]}]}}],
  AspectRatio->1.,
  Axes->True,
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Frame->True,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.5633675901921587`*^9, 3.566087044194708*^9, 
  3.56610182449609*^9, 3.5661392703942413`*^9, 3.614707858789701*^9},
 CellTags->{
  "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"},
 CellLabel->
  "During evaluation of \
In[66]:=",ExpressionUUID->"2c1a3fe1-f530-44e5-ad59-dc837b0018fa"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "FindIntensity", 
   "RG17."},ExpressionUUID->"7db99dae-8ac2-4250-90f0-8207449940a8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindFocus", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "FindFocus", "RG17.", "RG17.2", 
   "17.2"},ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250"],

Cell[TextData[{
 "In the previous example, we examined the intensity at a single surface. \
However, if multiple surfaces are reported, ",
 StyleBox["FindIntensity", "Input"],
 " can measure the energy losses in the system that occurs between the first \
reported surface and every subsequent reported surface. We will see this in \
the next example. Here, we use an ",
 StyleBox["ApertureStop", "Input"],
 " as a pupil that restricts the transmitted light through a lens. In \
addition, we will use ",
 StyleBox["FindIntensity", "Input"],
 " to calculate the point spread function of the optical system by placing \
one of the reported surfaces at the lens focal point. Before running ",
 StyleBox["FindIntensity", "Input"],
 ", we will first use ",
 StyleBox["TurboPlot", "Input"],
 " to show a ray-trace of our intended system."
}], "Text",
 CellTags->{
  "FindIntensity", "FindFocus", "RG17.", 
   "RG17.2"},ExpressionUUID->"1e979e95-2969-4469-bdb2-4b4c0c51ff29"],

Cell[CellGroupData[{

Cell["\<\
trace = TurboPlot[{GaussianBeam[5,.05,NumberOfRays->12, FullForm->True],
\tMove[ApertureStop[50,15],49],
\tMove[PlanoConvexLens[100,50,10],50],
\tMove[Screen[50],225]}, PlotType->Full3D];\
\>", "Input",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->"In[67]:=",ExpressionUUID->"bf84e43a-fae7-473b-aa4b-b5e31a85f037"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyVmX9o1HUYx8fMkNK5cc0ttQv3A1tSWKY0OLtvFnUzS/EP7Q/7J+iX/wSN
iGpsR1oEaUUZJSsqLY0xnZrOmbv2aRaFFKtQNEb+2naMtsg4PQ63WOs+7+fs
nu/e++5zMO54eHjt4fm8vx9euy14/Nm1T0wrKCiIjf9MH//573P2FY959kPY
K/j/a7zekn3d6qsn6546Oqu7xms+9PGKhubrPalXLTnx3Oor871HWlPHh4rG
okF81s/4/dFLc0rKF2Kuubn6ue9/rQ2N3OiNZV+zAudh/Ywf39DVcntvhdeE
d6kXx8ri25aVerPxHsRn/YzfijkuYC6pF2Y/FHln8XuC+Kyf8Xdg73IOUl+H
PVZir0F81s/4p5Z/tvKjwr8jebkbr7/zXSZ1saIvkpejSfgPzunrOfaG8fXP
vP+FlujGn3z89+08Rs+z0vK7qqbIZ/2Mv9vu3/Sr/Y/a3Jhzap+Mz/oZHzkz
cZU35MYUq/wwPutnfMxhyPNr9PPC+GfQfy1yJ3Xk2OxTfOzd7FD3CXJj1qv7
gfFZP+MjZ8bm7veI1JEbY3P0cySIz/oZX+b5ELmTOnJj1iBHQfxq9N+r+gfB
f0vx5Xx3IXdSP499jiBHQXzWz/jImZHcSb0E+ZEcBfFD6Jup+l8Bt0Hx92MO
yZ3UZ9jcGMlREJ/1M/4B7H0A5yD1p7HHCuw1iM/6Gb9905qHHyorTkjupH7b
tivtd80tTEiOgvjPfHri8Oe/nO7U/TPqf+tqm53s1Pw38VwNqnmieE6qp8hn
/Yz/Ce6RpNr/ZdxTfWqfjM/6Gf8l3Juvqbxdh3uwTOWH8YvQX6L6G8GPK754
wH71fCE3uRwF8Vk/4yNn3kF1nyA33kZ1PzA+62d88QDrHSUJqSM38I5piSA+
82RbXuKrh5cfOPPipju9149fWP3NqZAndea9rh7O+MNbm2Krti/GXJW5OvNe
Vw9n/MwN9aWheYu8NN6lzrzX1cMZvxVzDGGuvPoE3uvq4Yy/BXu/Cecgdea9
rh7O+APlq+Z112ciebmbxKsZn3nyYMer3Y9VnfTxN9t5TFjNw7zX1cMZ/wu7
fzOs9s+819XDGR85MxmVN+a9rh7O+JjDkOfX59WMzzz5D/D3Kj5yZrZOfF/5
vNfVwxkfOTM2dwNT9t6pejjjI2cG96fRfO3VjM88WfhNii/nuxu50+ervdfV
wxkfOTOSO6kzr2Z85smj4KYUvw1zSO6kzrzX1cMZ/wPsfT7OQerMe109nPHX
JSqjDQvKEpI7qTOvZnzmyRve+2Hnlva/OjW/Ec9VWM3DvNfVwxl/J+6RP9X+
mfe6ejjjX5R7szQ/b8yrGZ958mXwMyrPyFkud1Jn3uvq4YyPnHnb1X3CvNfV
wxlfPMB6R3kirz6BV0/q4RN4sv1Q66vHTu47O1x9t7fiq+cbvz1/9fso5r2M
z/oZPzmyefrbu5bie91bcnXmva4ezvgdT4bMy3vu8A7jXerMe109nPHt97o1
3gDmkjrzXlcPZ/wY9i7nIHXmva4ezvipVGoo2T+G73Vrc3Xm1YzPPPnHnp62
5nd7ffx77DxGz8O819XDGf8fmzOTVPtn3uvq4YyPnJkOlTfmva4ezviYw5Dn
1+fVjM88uR/8a7KFq39fYO+mTt0nzHtdPZzxkTNjczcU6L2uHs74Ms99yJ3U
mVczPvPkOvCXKb6c7yhyp89Xe6+rhzP+EeRNcid15tWMzzz5KLiHFN/+f6LG
SO6kzrzX1cMZfz32/gDOQerMe109nPHT6fTiPYvCCcmd1JlXMz7z5NO9vccO
7r3UqflL8VzVqXmY97p6OOOncU8Nqv0z73X1cMb/Evfm1ypvzKsZn3lyO/hH
FB85y+VO6sx7XT2c8ZEz71F1nzDvdfVwxkfO4B035/vzBF6t+f8CqZwNCQ==

    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[CompressedData["
1:eJxdkj9IwkEUx8UwGsoMqRAiqBRyjEoSJM9JbShoyOagqJYgaArCoa0lqK2p
oab+DYUmQgcGQQ1WGAhCKpYEtlUEadgv7/t+5Ts47vjw7t3n3buemaXJ2QaD
wWDUpk2bv/vaCAeE2nQLw/+hcftganniq0uMH7xdl8xVL/Hc1b3bWraJam20
COKWQGd429UuWrESN9Y2ZpHFOeJTyNuHe4j7OwrJxIb01HlpfEzFX9hZfEV5
yBzLDw9pYT6PKk42wos4PGSI1QsPqbxuPcQdiPfBi3ge+cvwIm6FTzNW4k3K
Q5IX8Xnk7cU9xBd2U5G9u3ScvIh74e1g8R/oU4HlN+Nd2pgPPHQv4vAQi6xe
6pN6n1y8nruxYmg88HCSfXWMCF9sZe0y/9evYnndtLk/jH/Vr/PonFWuHg6I
CFbi6l85xTPOEfcjL91D/CaZPN7ZynjqvDQ+quIlj/9WHrLI8sNDRpnPk4qT
JnixemWQ1QsPqbxK+r8KIt4FL/Y+sgIv4jH4nGElrv63UxZwjngIef24h3g6
k0mcHr3HyYv4ELyDLP4TfXph+alP58wHHrqX3i+8+zSrl/qk3qcc/wF7JKCY

      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
    EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyNkr9Lw0AYhk+Kmzg76qhQ7CQGTjhwaUQ6OIijFMTR2b+gaVbdXB2kig7+
2AJBtwYpOAnZKri4ObgU1Pbue1Mu8hI/CISHj4e7996l9tHOQU0pNTf+Zsff
5D883tusrW0bZSdIlTetgmeDwc3ZyUiDX/Um00hX6vVkZvSlo3Dhfn5/y1wK
h4H52T7z+3wxjeK4f9j+1KtvD7cbu2HBq/xsn/n9HFTybHP40D92mkaVhvnZ
fsmvMvGD95zHuPMMi/teCK/ys33m93nDdC1/Kd4XvMrP9sv+WPzg7h7r5jXP
n+6uz4Om9OdbeJXf7xsGvWsZP98pdz171+gd/B17vkeNHjE/22d+cOSOviDP
juRS9JH42T7zg7se55KDStCfzOeK+dm+n/NfHokHvfP9Q40e/e88033mB+9K
bugL8lyWdwFnfrYPf1zyg7senwboNfrclx6i18z/C6rAGhY=
     "]], 
    {GrayLevel[0.], AbsoluteThickness[0.5], 
     StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYAADywMMUNDhKbGVL8HLYfUqEDCA
i+s/3rbZNszTYQ1YXAEu/h8MPKDmfNiDrn4FRL0DTLwdaj5E3AAu7gF1zz+w
eRZwcQjwg7kTQ3w1mjkw8TVo9qKa88EGXXwFmr9QxQ0wxKHuhIvjCk8ASLtW
ow==
        "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYEABlgc6PCW28iV4wcVXrwIBgwP6
j7dttg3zhIuvAYsrHPgPBh5o5nzYg65+BUS9Qzua+RBxAwcPNPf8A5trAeX7
obsTQxzqTgxxqDtxmPPBBl0c6s4D2MUNMMSh7jyAKzwBioVWow==
        "], {{
        56.421974580955585`, 25., 0.}, {60., 25., 0.}, {60., 
        24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 
        24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 25., 
        0.}}, {{56.421974580955585`, 24.148145657226706`, 
        6.4704761275630185`}, {60., 24.148145657226706`, 
        6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, 24.148145657226706`, 6.4704761275630185`}}, {{
        56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {60., 
        21.65063509461097, 12.499999999999998`}, {60., 17.67766952966369, 
        17.677669529663685`}, {56.421974580955585`, 17.67766952966369, 
        17.677669529663685`}, {56.421974580955585`, 21.65063509461097, 
        12.499999999999998`}}, {{56.421974580955585`, 17.67766952966369, 
        17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
        60., 12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
        12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
        17.67766952966369, 17.677669529663685`}}, {{56.421974580955585`, 
        12.500000000000004`, 21.650635094610966`}, {60., 12.500000000000004`, 
        21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
        56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {
        56.421974580955585`, 12.500000000000004`, 21.650635094610966`}}, {{
        56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {60., 
        6.470476127563024, 24.148145657226706`}, {60., 
        7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
        7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
        6.470476127563024, 24.148145657226706`}}, {{56.421974580955585`, 
        1.5308084989341915`*^-15, 25.}, {60., 1.5308084989341915`*^-15, 
        25.}, {60., -6.470476127563016, 24.148145657226706`}, {
        56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
        56.421974580955585`, 1.5308084989341915`*^-15, 25.}}, {{
        56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
        60., -6.470476127563016, 24.148145657226706`}, {
        60., -12.499999999999995`, 21.65063509461097}, {
        56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
        56.421974580955585`, -6.470476127563016, 24.148145657226706`}}, {{
        56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
        60., -12.499999999999995`, 21.65063509461097}, {
        60., -17.677669529663685`, 17.67766952966369}, {
        56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
        56.421974580955585`, -12.499999999999995`, 21.65063509461097}}, {{
        56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
        60., -17.677669529663685`, 17.67766952966369}, {
        60., -21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, -21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, -17.677669529663685`, 17.67766952966369}}, {{
        56.42197458095559, -21.650635094610962`, 12.500000000000009`}, {
        60., -21.650635094610962`, 12.500000000000009`}, {
        60., -24.148145657226706`, 6.470476127563026}, {
        56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
        56.42197458095559, -21.650635094610962`, 12.500000000000009`}}, {{
        56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
        60., -24.148145657226706`, 6.470476127563026}, {60., -25., 
        3.061616997868383*^-15}, {56.421974580955585`, -25., 
        3.061616997868383*^-15}, {56.421974580955585`, -24.148145657226706`, 
        6.470476127563026}}, {{56.421974580955585`, -25., 
        3.061616997868383*^-15}, {60., -25., 3.061616997868383*^-15}, {
        60., -24.148145657226706`, -6.47047612756302}, {
        56.421974580955585`, -24.148145657226706`, -6.47047612756302}, {
        56.421974580955585`, -25., 3.061616997868383*^-15}}, {{
        56.421974580955585`, -24.14814565722671, -6.470476127563009}, {
        60., -24.14814565722671, -6.470476127563009}, {
        60., -21.65063509461097, -12.499999999999993`}, {
        56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
        56.421974580955585`, -24.14814565722671, -6.470476127563009}}, {{
        56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
        60., -21.65063509461097, -12.499999999999993`}, {
        60., -17.677669529663692`, -17.677669529663685`}, {
        56.421974580955585`, -17.677669529663692`, -17.677669529663685`}, {
        56.421974580955585`, -21.65063509461097, -12.499999999999993`}}, {{
        56.421974580955585`, -17.677669529663696`, -17.677669529663678`}, {
        60., -17.677669529663696`, -17.677669529663678`}, {
        60., -12.50000000000001, -21.65063509461096}, {
        56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
        56.421974580955585`, -17.677669529663696`, -17.677669529663678`}}, {{
        56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
        60., -12.50000000000001, -21.65063509461096}, {
        60., -6.470476127563038, -24.148145657226703`}, {
        56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
        56.421974580955585`, -12.50000000000001, -21.65063509461096}}, {{
        56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
        60., -6.470476127563038, -24.148145657226703`}, {
        60., -2.6796885989305705`*^-14, -25.}, {
        56.421974580955585`, -2.6796885989305705`*^-14, -25.}, {
        56.421974580955585`, -6.470476127563038, -24.148145657226703`}}, {{
        56.421974580955585`, -4.592425496802574*^-15, -25.}, {
        60., -4.592425496802574*^-15, -25.}, {60., 
        6.470476127563007, -24.14814565722671}, {56.421974580955585`, 
        6.470476127563007, -24.14814565722671}, {
        56.421974580955585`, -4.592425496802574*^-15, -25.}}, {{
        56.421974580955585`, 6.470476127563007, -24.14814565722671}, {60., 
        6.470476127563007, -24.14814565722671}, {60., 
        12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
        12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
        6.470476127563007, -24.14814565722671}}, {{56.421974580955585`, 
        12.499999999999984`, -21.650635094610976`}, {60., 
        12.499999999999984`, -21.650635094610976`}, {60., 
        17.67766952966367, -17.67766952966371}, {56.42197458095559, 
        17.67766952966367, -17.67766952966371}, {56.421974580955585`, 
        12.499999999999984`, -21.650635094610976`}}, {{56.421974580955585`, 
        17.677669529663685`, -17.677669529663692`}, {60., 
        17.677669529663685`, -17.677669529663692`}, {60., 
        21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
        21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
        17.677669529663685`, -17.677669529663692`}}, {{56.421974580955585`, 
        21.65063509461096, -12.50000000000001}, {60., 
        21.65063509461096, -12.50000000000001}, {60., 
        24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
        24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
        21.65063509461096, -12.50000000000001}}, {{56.421974580955585`, 
        24.148145657226703`, -6.470476127563039}, {60., 
        24.148145657226703`, -6.470476127563039}, {60., 
        25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
        25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
        24.148145657226703`, -6.470476127563039}}}],
      FontColor->GrayLevel[0.]]}, 
    {GrayLevel[0.], AbsoluteThickness[0.5], 
     StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihQyHGAMCwPMCADoPjqVSBggCG+BiyugCEOYXzY
gy6+AqLeAbu4AYb4v/8gYIEhDnUnhvhqHOaswWEv1J02ONyJ4a8VOMIB6k4M
cag74eIAUi9FdQ==
        "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmBihQyHFgQAGWB9DFV68CAQMM8TVgcQUMcQj4sAdd
fAVEvQN2cQMM8X//QcACQxzqTgzx1TjMWYPDXqg7bXC4E8NfK3CEA9SdGOJQ
dx4AAJP5RXU=
        "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmBihQyHGAMCwdGJABUNzj6ob7b1QtHBx3ldYdeSjp
ABN/9ruFdcIyU4f/YKABF9+RJnygeq2hw3YoDRNnAjM0HZ5C9cHE3aHmwuyB
iZ8+f3797Mm3bVDcBRS3g6g/gK7+L8QdB56hmQ91x4EdaO55AlF3gBXqLjT/
HvBE8y/UHQcg7nptAxP3hKo3g7oLLXwO/IG6Cya+C+qerVAaJs4GcceBx1B9
MPFwqLnuUHtg4jdu3z68Zd2XPTB3wcRNoO72RFP/HRpPL9DMh8XTTjT3QN0B
dxc8vqDhHoHmX1g8QcLn9x4A5HbTgw==
        "]}],
      FontColor->GrayLevel[0.]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJx1WXt41dWVvShJC5gHkyCRAAbs6AcVzSACA9LfsagQBIygpSDoVfCF4gsf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      "]], 
     {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["
1:eJx1V310zecdv0bSM2mEkzhBSi86TtRLVoql9HkUlWteUto60eJ6G7JmtKai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       "]]}}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367591374455*^9, 3.5660870451108837`*^9, 
  3.566101826047195*^9, 3.566139271905733*^9, 3.61470785978938*^9},
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->
  "During evaluation of \
In[67]:=",ExpressionUUID->"b3b339b6-d05a-4a26-9fcc-fc53d96f9d15"]
}, Open  ]],

Cell[TextData[{
 "In order to measure the point spread function of the lens system, you first \
need to determine the focal point of the system. You can use the ",
 StyleBox["FindFocus", "Input"],
 " function for this. Here is a description of ",
 StyleBox["FindFocus", "Input"],
 "."
}], "Text",
 CellTags->{
  "FindIntensity", "FindFocus", "RG17.", 
   "RG17.2"},ExpressionUUID->"f5f2213a-8c67-4cc7-a6e0-6cc3d95ece0b"],

Cell[TextData[{
 StyleBox["FindFocus[",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["objectset",
  FontSlant->"Italic"],
 StyleBox[",",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " determines the minimum spot size for a locus of rays at the last reported \
surface in the system and plots the results."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "FindFocus", "RG17.", 
   "RG17.2"},ExpressionUUID->"a33391f6-588e-4017-94b4-c9b65311d253"],

Cell[TextData[{
 "Next, we can use the ",
 StyleBox["FindFocus", "Input"],
 " function to find focal point of our lens system. In this case, since we \
have already calculated a ray trace using ",
 StyleBox["TurboPlot", "Input"],
 ", we can simply pass to ",
 StyleBox["FindFocus", "Input"],
 " the result of our previous calculation."
}], "Text",
 CellTags->{
  "FindIntensity", "FindFocus", "RG17.", 
   "RG17.2"},ExpressionUUID->"72ac0498-3b0e-4219-8bae-6f4e17c2f6fa"],

Cell[CellGroupData[{

Cell["focus = FindFocus[trace]", "Input",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->"In[68]:=",ExpressionUUID->"9f4a8b78-0096-4924-824c-df2fc5d1f38e"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`],
    AbsolutePointSize[2.5], 
   PointBox[{0.03470947816415118, 0.054543465686528625`}], 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01787038323580359, 0.03931484311876607}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.007964626200122782, 0.029203629400448017`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.002196391553096439, 0.02416030708406633}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0021963915530968277`, 0.02416030708406633}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.00796462620012274, 0.029203629400448017`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.017870383235802673`, 0.03931484311876432}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.034709478164151125`, 0.054543465686528625`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.04046644145420342, 0.04046644145420081}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01858412780677579, 0.023893878608714114`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.006408230094927206, 0.011534814170871821`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.001109544875346008, 0.0033286346260399113`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0000849507569712811, -0.0007645568127432889}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.00008495075697131926, -0.0007645568127432889}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0011095448753463966`, 0.0033286346260399113`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.006408230094926734, 0.011534814170871821`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.018584127806775236`, 0.023893878608712393`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.04046644145420164, 0.04046644145420081}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.054543465686527765`, 0.0347094781641529}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.023893878608714114`, 0.01858412780677493}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0057776586327130675`, 0.005777658632712235}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.002695097859707382, -0.003773137003589555}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.004334926084596083, -0.01011482753072565}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0018968667461095497`, -0.013278067222769974`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.001896866746109914, -0.013278067222769974`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.004334926084597193, -0.010114827530726511`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.00269509785970784, -0.003773137003589555}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.005777658632711707, 0.00577765863271093}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.023893878608712393`, 0.018584127806775763`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.054543465686527765`, 0.0347094781641529}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.03931484311876607, 0.017870383235804005`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01153481417087357, 0.00640823009492765}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.003773137003588667, -0.002695097859707382}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.009484333720720967, -0.009484333720720967}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.008395462298623937, -0.013992437164372082`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0032482210901132666`, -0.016241105450566215`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0032482210901130966`, -0.016241105450566215`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.008395462298623133, -0.013992437164373789`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.009484333720722285, -0.009484333720721813}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0037731370003687703`, -0.002695097857408374}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.01153481417087096, 0.006408230094928066}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03931484311876607, 0.017870383235804005`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.029203629400447184`, 0.007964626200122574}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0033286346260381627`, 0.001109544875346008}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.010114827530723486`, -0.004334926084596513}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.013992437164372082`, -0.008395462298623937}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.011091719512427281`, -0.011091719512426837`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.004145545824139302, -0.012436637472417647`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0041455458241393475`, -0.012436637472417855`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.011091719512427517`, -0.011091719512427697`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.013992437164373414`, -0.008395462298624146}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.010114827530728732`, -0.004334926084598012}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.003328634626036414, 0.0011095448753453696`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.029203629400447184`, 0.007964626200122574}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.02416030708406458, 0.0021963915530963316`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0007645568127441493, -0.00008495075697138865}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.01327806722277039, -0.0018968667461096538`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.016241105450566215`, -0.003248221090113159}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.012436637472417647`, -0.0041455458241395175`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0045931412201930845`, -0.004593141220193088}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.004593141220193879, -0.0045931412201940455`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.012436637472419604`, -0.004145545824139944}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.016241105450569254`, -0.003248221090113586}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.013278067222774748`, -0.001896866746110195}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0007645568127450375, -0.0000849507569714962}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.02416030708406458, 0.0021963915530963316`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.02416030708406458, -0.002196391553096824}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0007645568127441493, 0.00008495075697143029}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.01327806722277039, 0.0018968667461100215`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.016241105450566215`, 0.0032482210901128815`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.012436637472417855`, 0.004145545824139559}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.004593141220194042, 0.004593141220193879}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0045931412201948366`, 0.004593141220194729}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.012436637472419604`, 0.004145545824139982}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.016241105450569254`, 0.0032482210901137384`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.013278067222774748`, 0.0018968667461101256`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0007645568127450375, 0.00008495075697154131}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.02416030708406458, -0.002196391553096824}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.029203629400447184`, -0.00796462620012274}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0033286346260381627`, -0.0011095448753463966`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.010114827530726511`, 0.004334926084597401}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.013992437164373789`, 0.008395462298623133}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.011091719512427697`, 0.011091719512427309`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.004145545824139944, 0.012436637472419174`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.004145545824139878, 0.012436637472419174`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.011091719512429238`, 0.0110917195124286}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.013992437164374705`, 0.008395462298624201}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.010114827530729564`, 0.0043349260845989}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.003328634626036414, -0.0011095448753457582`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.029203629400447184`, -0.00796462620012274}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.03931484311876432, -0.017870383235802673`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01153481417087357, -0.006408230094926762}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.003773137003588667, 0.0026950978597082703`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.009484333720721813, 0.009484333720722285}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.008395462298624146, 0.013992437164373414`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0032482210901136933`, 0.016241105450568824`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0032482210901138425`, 0.016241105450568824`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.008395462298624201, 0.013992437164374705`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.009484333720722701, 0.009484333720722701}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0037731370003687703`, 0.002695097857409262}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.01153481417087096, -0.006408230094926762}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.03931484311876432, -0.017870383235802673`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.054543465686526044`, -0.034709478164152846`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.02389387860871328, -0.018584127806774375`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.005777658632712235, -0.005777658632710847}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0026950978574074996`, 0.003773137000370047}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.004334926084598012, 0.010114827530729592`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0018968667461101915`, 0.013278067222774331`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0018968667461101256`, 0.013278067222774331`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.004334926084599122, 0.010114827530729592`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.002695097857408388, 0.003773137000370047}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.005777658632710431, -0.005777658632710014}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.023893878608710672`, -0.018584127806774375`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.054543465686526044`, -0.034709478164152846`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.04046644145420081, -0.04046644145419903}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.018584127806775763`, -0.023893878608712393`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.006408230094927622, -0.0115348141708701}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.0011095448753455778`, -0.0033286346260381627`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.00008495075697138518, 0.0007645568127450375}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.00008495075697143029, 0.0007645568127450375}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0011095448753461884`, -0.0033286346260381627`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.006408230094926734, -0.0115348141708701}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.018584127806775236`, -0.023893878608709812`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.04046644145419903, -0.04046644145419903}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.03470947816415118, -0.054543465686528625`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.01787038323580359, -0.03931484311876607}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.007964626200122782, -0.029203629400448017`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{0.002196391553096439, -0.02416030708406633}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.0021963915530968277`, -0.02416030708406633}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.00796462620012274, -0.029203629400448017`}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.017870383235802673`, -0.03931484311876432}]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    PointBox[{-0.034709478164151125`, -0.054543465686528625`}]}, 
   {RGBColor[0, 0, 0], Thickness[0.0002], 
    LineBox[{{0.11570416336907957`, 0.}, {0.10570101287616006`, 
     0.04706112299863339}, {0.07742119699339661, 0.08598495029392254}, {
     0.03575455280098086, 0.11004119853464213`}, {-0.012094378390639409`, 
     0.11507032385581735`}, {-0.057852081684539786`, 
     0.10020274480124779`}, {-0.09360663448552065, 
     0.06800920085718397}, {-0.11317574979437747`, 
     0.024056248240719585`}, {-0.11317574979437747`, -0.024056248240719585`}, \
{-0.09360663448552065, -0.06800920085718397}, {-0.057852081684539786`, \
-0.10020274480124779`}, {-0.012094378390639409`, -0.11507032385581735`}, {
     0.03575455280098086, -0.11004119853464213`}, {
     0.07742119699339661, -0.08598495029392254}, {
     0.10570101287616006`, -0.04706112299863339}, {0.11570416336907957`, 
     0.}}], 
    {GrayLevel[0.5], CircleBox[{0, 0}, 0.01325326301611985]}}},
  AspectRatio->Automatic,
  Frame->True,
  PlotRange->All]], "Print",
 CellChangeTimes->{3.56336759175362*^9, 3.566087045326614*^9, 
  3.566101826545909*^9, 3.566139272426565*^9, 3.61470786005835*^9},
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->
  "During evaluation of \
In[68]:=",ExpressionUUID->"16d21f8f-ecc7-4ca0-8326-e017183ba907"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Screen", "\[Rule]", 
    TagBox[
     StyleBox[
      TagBox[
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Screen", "[", "0.23140832673815914`", "]"}], ",", 
         "218.52191023431297`"}], "]"}],
       HoldForm],
      FontColor->RGBColor[0., 0.392193, 0.]],
     DisplayForm]}], ",", 
   RowBox[{"TurboSystem", "\[Rule]", "\<\"-traced system-\"\>"}], ",", 
   RowBox[{"FocalPoint", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"218.52191023431297`", ",", "0.`", ",", "0.`"}], "}"}]}], ",", 
   RowBox[{"FocusType", "\[Rule]", "RMSFocus"}], ",", 
   RowBox[{"WeightedSpotSize", "\[Rule]", "0.01707283719487994`"}], ",", 
   RowBox[{"SpotSize", "\[Rule]", "0.0265065260322397`"}], ",", 
   RowBox[{"BackFocalLength", "\[Rule]", "158.52191023431297`"}], ",", 
   RowBox[{"FocalPlaneTilt", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1.`", ",", "0", ",", "0"}], "}"}]}], ",", 
   RowBox[{
   "TurboRays", "\[Rule]", "\<\"-ray intercepts of 1 surfaces-\"\>"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367591763019*^9, 3.566087045338579*^9, 
  3.566101826582443*^9, 3.566139272442189*^9, 3.614707860069008*^9},
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->"Out[68]=",ExpressionUUID->"8a13b68c-4edf-455a-bfd8-08aa9b5a8063"]
}, Open  ]],

Cell[TextData[{
 StyleBox["FindFocus", "Input"],
 " has automatically generated a plot of the locus of rays at the focal \
plane. In addition, ",
 StyleBox["FindFocus", "Input"],
 " returns a series of rules that describe various aspects of its focus \
calculation. You can learn more about ",
 StyleBox["FindFocus", "Input"],
 " in ",
 ButtonBox["Section 1.3.5",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>{"General Architecture"}],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " discussion. Of the different rules returned by ",
 StyleBox["FindFocus", "Input"],
 ", we are only presently interested in the ",
 StyleBox["FocalPoint", "Input"],
 " rule since it holds the three-dimensional focal-point coordinates. As \
such, we can assign the focal point result to a ",
 StyleBox["focalpoint", "Input"],
 " variable in the following way:"
}], "Text",
 CellTags->{
  "FindIntensity", "FindFocus", "RG17.", 
   "RG17.2"},ExpressionUUID->"ef728d99-f6af-4701-821f-7667055c288e"],

Cell[CellGroupData[{

Cell["focalpoint = FocalPoint/.focus", "Input",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->"In[69]:=",ExpressionUUID->"d1fc3e93-d0bb-4abd-abbd-f079d7dd2d57"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"218.52191023431297`", ",", "0.`", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.563367591822751*^9, 3.566087045557281*^9, 
  3.566101826631752*^9, 3.56613927252295*^9, 3.614707860214551*^9},
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"},
 CellLabel->"Out[69]=",ExpressionUUID->"591b7135-4c02-4d42-8df1-963cbf3dd8a1"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "FindIntensity", 
   "RG17."},ExpressionUUID->"0767282a-0043-4f56-9f76-2b558adf3ab0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measuring the Point Spread Function", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", "17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176"],

Cell[TextData[{
 "We are now ready to apply ",
 StyleBox["FindIntensity", "Input"],
 " to our lens system to measure the point spread function of the system. \
This time, we will place a ",
 StyleBox["Screen", "Input"],
 " object at the focalpoint determined by ",
 StyleBox["FindFocus", "Input"],
 "."
}], "Text",
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"7ee32d46-f354-4350-98ce-745d5fe62fb5"],

Cell[CellGroupData[{

Cell["\<\
focusintensity = 
FindIntensity[{GaussianBeam[5, .05, NumberOfRays->32, FullForm->True],
\tMove[ApertureStop[50,15],49],
\tMove[PlanoConvexLens[100,50,10],50],
\tMove[Screen[{.6,.6}],focalpoint]}, Plot2D -> False]\
\>", "Input",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->"In[70]:=",ExpressionUUID->"03f38441-916b-4472-a72f-cebe22f1de4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "956"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.009487737662714256`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 3., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 956, Optica`Optica`SmoothKernelSize -> 
    0.009487737662714256}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563367593993874*^9, 3.5660870479853783`*^9, 
  3.566101829378634*^9, 3.5661392752617826`*^9, 3.6147078629278383`*^9},
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"a389c04a-1214-4a12-9503-59d753754c5f"],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxcnWWY1UqzRnF3d3d3h71hcHd3dxjk4M7gLoMc3N3d3Qd35+A+yOByuXmz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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxEnXm8VdP//88dz3Dne8+58znn3tskKg1CCA1UVCikIlTIkIyhIlOojBmT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         "]], Polygon3DBox[CompressedData["
1:eJw0nQV0XUXXhm/SSNO0Sdv4zb1RoLhDW9ytuLu7FfdSoLi7u7trcXeHIsWK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         "]], Polygon3DBox[CompressedData["
1:eJwt13mcz3UeB/APg5zDMKZdzSRXKq2OYaNtI61jG2WZ6KKiVM6UK0fO5GhM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         
         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl1F9MlmUYx/FLkBJC/INKCi8KmqYCvUXLzWi1eZK0TspVWpiaf4gIBRIF
I0WbdVId9MfClavVUSetcssDW8NipkUJaE7dtMWBtam5lW6OUZ+7tvd9r+/v
uq/7d1/v81zPU7Fu8yMt4yJii5/sLRGJDxdEnB0fUUvPpofowryIhtKI++jX
CiOeFF8X18h14jfxPrF7TsR+fBCvnhDRxmMIF8if4/MRn6v0p2omOewV+YO4
Gn8tHuH3EO7Hz4q1N0V0VDhvslp6hMfjcu/x/YTeWx7RQx/BN6x9gI9a+5Ue
o3utfyP3D32SZyZHr848j+/FF8V5ZREr8RW8LeX0Xa9mhM/bdJ649uaIL/Co
mjr1J3DORHvED9Xm44m5zp8asVjc6cJNzY84pO/ldPukiFy+M+zfRE/mmUMf
td5Il4il6oem+d/0Kj5VxRFNuJj3sPxzeDpuFhtm8sLP4wI+JXxb8MCtETW8
M7w202vkt4h3qF+LbzinlV6HR/FJvm30M/QY3Y6n8MuonyX3QuqNX7FcGb2V
Pl6iD7oDl1qbkerTtaOb9T1gfabc9rSux07xaX4Z3IXLxVPO3YFn4xdTTn25
mnI+3anfNHv+w0t4vdwv6nfiDXjclIhdOKt+I51L99CbcB7ejYf1cBvPCrk9
dCW/BfRc+mV6Dj2frqQ30kV00Lvd2wfpp+QXiSvFDXKF+DF82f1udb8fxT/j
a/b8bu/nOFf8zbytNitv0X+r6RB71V/CT+AR8UfXaC7PpfQP+H3X/ax8Gd3P
r8e875cbM7OjZviw+R3kfYHuxZc8I334D2vd9GfWPqbP0w3OXyG3l76LZ6O4
3vlZXI9rxD77q3AVLhKbnNmVnif5P12GM3wOeE4H8QE1r8p/id/F74hd/N7A
2/Eyfa4S76/0Na9LeNXJ1cmdEPP51PPWVgzynUBn5TP0Ic9EVv1P9rkcUZ2e
AXEP7wG5WbgHu82xxM8ubLyjxp7lPN3iWCCeAtXp2UrvHzXTxXvU78DGJjrF
Y/x8Yht2yeO699sws2X2G5k4pre/5B6gtRFX8fc2aDH6rF2h66wVpXelDSsc
dlnO+MZWnj5R68x2kEapTey339ZoxUY5FupxqcXviv8btZiHbwfGJVrUfCvv
1kVzmmPxTn5N2DHRmOZcfNi55yTuTu8P+isHnB7//7v7X0Xlrsw=
       "],
       VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwV0slOVFEUheHtOxgUwSAaAfUhHDpAJ8JUMRKwQTRxYDM0CkprA0WfOFGR
AhR7BcXYgoJAUTRCeBi+M1hZe69/73PuvVWlZ6+cvLwjIrJ0qiji2b6If6UR
w/zb3oiukoh6/e3iiHn+RJ6lp/Qd78bPybd2Rizw5/JxGqGfeAY/L79j/4d+
VD5Gv9V1ByJ68At4E/5L9gJ7SbPqXqxZPqNu2u98+qO+K7tmppDuqffwDLZI
Lfoye3/NtarneIV7htOz0XWzlbwNKze3qF6iCflxXueMW+YrsAL1LsrJq3m7
nSremXZ4h/4Yn3fHtP1leadsledphXL4V2xNfR9b56/0b+l1+tZ2+9x1Uf4A
/8/fyD/QVc8xmd7LTL+ZBuyhmQX9O3yS3lNOP4Bfwh/hS/pDdj9inyivH8Qb
8S58WT8l/0yr6qH0G7un3s6K/mDal3WbvWGmKL0bntEXp3fBe9SHzayr81hv
enb1iDuydNPcCd4nP2JuQ72ZvonZL1i//LT/25xsQH1G/tj9NXxQX4NtOG+3
vpBqaUh+lG8DTsJ6nA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lSk1EUhuHjLqwiUcAqkZAAsgJ0AaHKFUhskoDNQEfikDU4S59AJAMW
4ETBlnaETRr7Duxmjn0cvPU1597/nn8kd/PCjWMRsYyLQxGPhiM6IxGnkxE9
WjoZUUZffmg2Rt+iokucilgfjRjIG2Zn6HtUzWp4x4/jI7LHI+q6D3wKpUTE
vPcO3C/zOb5CL9GXuip/ma/RK/SVrs5f5fP8X+T5hq5AZ+XC/2/Z6Rw9j653
Mt5M2m3Ov5ygaTnL3zN/jX1dXx7gk/Ob8mNM8M9pw/kntEk/657yz3DLO2n5
K1pmK/jCvzDbQob/jlV9G9/4CXcm6aTctHfR3j25aI+U2YLc0i/SQ/2CPq2f
cv5IXjGb5n/wb8xW5bPyT7nNX3Ovq7/PX+d/6WfM1+RtOz0wu+17v/V/0NEv
6e9iSt6jO9jFHfwDG3JeOg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DdSA1EQhOHBQ06GkQQx3nufU2SkEAIS3hvhuQGXAG5BFSE5l8B79yn4
q3t6+82+3dRUZiKdFxFrOKuI2E1GjFVF/GIUp7Jb2Q/fkYj4pvW1ESfyL75d
9kmPzR+0zfxO63SOZGXVEaU4zD2viZjDAV8iK8Y+P6lbxBciax5xfhh7fJNn
Q/wgds0FOvlolO+Y3+St3vlKt80D9AX9qNbZkiXcv8/8jF6kzIupiAXk2ZWm
h7rn7pbh55HUedJtsfuRjss27ZrWC2f+ZBvmq8qIdfru7CzW+EvZHb/K9+h1
Y4Xvopf2dNIqe651luUduf+IJf6n3N3ohR0Lue/TmcE836aTdZ9WmjE32NHC
P6AZN56lc/+Mv0cjLrxvx7f8A5qSRd0=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Us3lWEYxvG7WTYR2gysCMU8E3wAIqc2I2aMmuw98AFCZS2HnU2O5UzT
ytlHMHVqWN8DtfoZ/Nd1vf/nuZ/nffeuHsyk0g8iYgTfKiLyn0UUYKwq4k91
xG/s8s+5Yb1Wvq2N2OHq9Tps648qI5rN9FtbqYnY4gq4Ji5fbnpe5v+hkUtw
G1y5LMO6/tdaBmt6knuCVX3Amdfu+YV3KOW/8ife5xQfub6nEVX2feF79RRW
9DdyyHra2rizl7kS84PcFS6xxL2Qd9b3sej5lWxDzvkzWOCO5DFu+Q/29zh7
nu+WXfisN7inU9+37xAHmOM7uFEz7+9/W2Tsm+Vf8+3I6W3yLOm++/v1VnzS
W+SImayZPef9RJb/Ib9jWr/xTmlM6cW+7zEm9ZdmivQa84VygjvXLzDqf8iT
D5HAfwywS64=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lOlFEUxfELugikqoCqUkQ6jdEwQPcAJIAgYjNkYJOgLoBEKrIDLae0
ShWgdIUIDExAlEYRBkpsFqI/Bif3nf85973vS9970HG/LCJGaCMRcTcVUVcV
8b064oDWsYaaiEY6j3/DrmYjipmINdkd/SHstvmBv6xzWv5KvsrX8tfl58z3
fA4/JT/L99tZwW6ZWb7PLPFH3nqis6J7zW5GtoxfMi/SkvO2LK/TYv5OR/yi
RbxZfmj/sSwvW8B+8sf0jJrk89gf/b/0A3uq+1L3Hd4ob6C3zvVmueyFbI5v
M9tp2d4SzWLDfJlOWverb92nGfymf6nB9vhdKmJzugO6g3brvFst35F9oYK8
104V9pl/XhExjfVgKWwb+0RvsBtYEiu554r7Prr3Nd6Nd9GUc+CP8EnnQjJi
wvzHP6Rx54T9VvdVmmP84klmJ+e7zmD15gUalW3qbVEF3un+Yfw/u4BYAQ==

       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0cdOlGEUBuDjRbgSCxgXLg0ygwpTGNoWE3euKC41ITHhFoam3oCuRenN
NhY66A1gY2AKM16Fz79487Zzvu/L/7cOP7n/+EJEFGH7UsTktYhaa8QUbr8S
cYaXWvT4J/yCzNWIITMPr0cs645lN80+aItY4Xec85tepXfpNbyH/8jW6X36
k/0NuoSL8r/Q4YzXzt6U36aHL0ek8Jzsnaxu9oU7K+6rQqfuje69Lk2PmL+L
38puXIy4Q4/KuvC87IO5e/SY7MR9H/mD5C34EL+UlaHEZ813m/1M5+hX8lP4
wuf5jO4rfWTvuTdVve0bf44b0IQec+N2UvoT7y3DKWTtbpmdoWfhGeRkaXPb
8mn+kTcW7O/w391xK/kXztrlf/B5fo/uwZPyCvTSC3b25QW65pw69NOL8gN5
H10yO+Gupm6AX9Id6v5583nyXfUNPJh8K/xUfqQfpf8DuVxj8g==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0FtTjmEUxvHVF5CYhqlJvZnBkSRUkm1HnL0VwqSiknZk00YlVDaHZggf
wofgO9hvEkVkJpsZsonfc3DN/76ute617udJNXWnuzIi4j59zo3IKogYWxWx
EkdxOS6lbbSFMlIRV+QH8TLuXh3xsDBizt3f6pdkB9RGcD9+kv+SX+SP5EcM
4y53atU+qi2oDckOqw3irGxIbVzPBf6QfAA/yPfZc1ftHt2h97J1SaZ3szmt
tIlm5GvlJc4ttJGmZTv19ZtVZ2YfvpP1Jt/Cn8cd6m9l55JvkJ3FKf5M8i18
D27X80Y2aP9pvlZ+CoOvsGcEi/Ef9eRF/MQf2RGLuDX5D+ob8C91u7fHO7uw
CnNp0uwJOzplNWZ34GtZO1bzJ/EVX6XnhvN1eslfw6vJPPkLfo1ZRXbcpPX0
XFaOZdSu5xm/V89t75mgW/RU1mZG2p4TWKkvR8+T5C62Jv8BW/C7/hp6rDaA
Y3qb5V+dj+M3rKZH6v14TDaPTfgF05Qy6wGNutvLFzg3qvc5N+Afby2lYT4T
l9FR+QqsxyU4jv8B8RVrbg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0blOlGEUh/FDxTIMO8gOAxV03ANLIktBhRQUBKkIlmprx06i0FARVmWH
oLKEioJwDyAogoLXoP6meHLOef7n+973m0kNvuodzYiIKTRWRzQ1RDTjXSpi
vj5itzaiVF+CBnmRWozhuoh+daAx4tx+SnZq9wT1+jz+DV+nv0Ytktxrrka/
4NkufQ+6Uc21qAt2LtUd7/njjCdUyaZrIra5R/NvVHIjdtvdsQNbsl/8Aypk
U/Y3uXvzYnlEOTfJbXA/uTs84ya4XO+ZdWaZ+QqlOLaX4Nf4EvOR+SuK9atc
juyLucj8WT1Eof5Cli3rU/vxAgX8P98b+pfO/WS3004+X8AXYoj/yOdxH3zP
HNbNz+3NeC7Jj7vrGjeWvrP5QJ8lX5EnzPvmPeSkfy8uU7Zq/uHd35Gd/l+c
lY8V/pa7QRZ/Zv+t/aRsWfaNv0amrNVd2rDE58r/IoH33H86oE+T
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lSk2EUheEbUHYgKpAOBAGJM12FTtyAVUwMgkGmNjuwUHqbDbgAqywH
gTTYK+AKVFRiEhN7QUc+DE7dc9/znfsn2fHpc4VERNygY30Rp/ojTtNqKqKY
jniLddqPZCOOUglfxc8MRLyTrdlvJiNmsff2C2YZ29HZtg9SxZ7HP/BDNCer
URX/aD9Ot9yY8OYTv5JxV37FNw775kV8B+/mH+jU+A75sjxhdtFnbJjW5Vnv
rsvq9kndHnsv3XO3gU1hB3QOUh9+1dsmfgl/rD+Gf7EX7Pf3b1OOWtgIlXUq
1OZHaV5Wp6e6azpfsSf8nP/03Cxh37Bn+967a76X0k/SS6ws/y5/wc/rvDYr
2PlDEa/4BWzTrGI/vNvgF7Et86F7Z937ief9vyX8F3+CGrLf5hj9oRw1sV3z
JBX1p93c42/rPpLNuHWHv4yn/b6/sozZsrfpjc4/7K43/wEnRWS/
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Mky3HEUxfFrl9iImILWhhTFPkvzPFYZsmNDWZNQZZ5egReQoEk8CAuv
YZ7nIat8LE6d7z331P3/uktHxvvH0iJilqoTEeslEb+KIs6TERm8vDSigg7N
FzRfFtH7NaJG98g8VRzxSa/WfGyeNi/o9OnUyU5kmfb1+E7+GTfgS3kWntEf
1r0yZ5uv+W+eQze4324D59Ks7q1s0Z0BeeP7TfM95dk3mTf5o3lJp1znAVd6
/5b8CQ/iIZpzK6GzS/f0gT5SOj3rVemcvv9evW7/SQ+t4lE3z+RDel/cbPbN
fN7CH2QFuBUv4wzdNpySFVI73uYptw/sK+y/8R9u78hHcYJ36K3kRHTyInMX
f7RL4m78h695SzF/8Zbv7vzFb3hPvk+veFf2j0+4P0k/6T/hLEnj
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0UtTkmEYxvGbslIpI3VamQE600wH0Fr1IQKCgLKgpNrWpmUHyrDv4KrW
kEaZdrBFnyjtsCrTH4tr/tf9v5/3eV+GTOth+UEiIjpyfyriQibi26mIZDZi
C3+fjqikI8ry1XzY/AXPzET0nbnKl+Qzd8juE/7Ce+7a1If0yycjfuJdboP7
KC190h1L7ljUZ7k7OMG94G7rM1wTx7nnXEPPcn/0W3pGv4n5wU5ysuJsExf4
OTzovU/lgFzy24q+9RUuS4p7NJg903P2JdeRAtfAdfefxw94EXecvzG4V5+X
tufe2yX4Pm7jdfucXV7eccGt4Q+s29U9s2rem454izXuuN2Y1Oyq5jR/DY9x
R6XKV8xJfVTK+gie4LuD/8A8bD4iJT3Ft/mi/t97nvC7WDB/55/Z/zM/5v/i
Ff6139zz3nO+u4tn8Q23Dw9lSHI=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0slSU1EUheENKE5EpQkkQAgBfQN7sUPBZkghAjaQ2CA2IGjsAaUcAOrM
J9AqqxjgDIfqzOZ9FERFvzv4a+211tnnpG4lXxzvGSuLiEXMNkdcaI14lY+4
SJtzEZtoB19Jn+nP0Zf8edqk30gP8MvpiKf6Af4FP0gb9Rvofr6CzuhPmU8j
o7vWHlEu38eX0Wn9CfNJpPUh+0en5K/bvOd8A/85G/FEVtAP47H5vb5Rv0P/
iN9O2/HQXJR/c+d3vHW+m3bhga7aXg2O81dwGbPO39dtlW/DFrS5654sZc4k
99ES30W7sdPeJRRxVz5M36GAkjfn7Qwl3xV39GdlC+Z+Wu/udezl/9JJfV+y
w8/ZW3Z/Sv4He2S/6YQzvc7M8WdonWwNu/lf9La+324nfwy1slXsMq/Qcf0R
81HU8D/xAyN2xnSffONq/iO9xQ95I6374Lfc5PO6Vtww52iDbkl3nf/izq94
Y+cwPYRR+WZ9FeqdPShrSf4D8jpZLUaS76t7br5qzuqz5hxaMMP/BwoFVVs=

       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0TlP1GEUxeHrB7CkcoEBLClNRCgFYWbYRkRQaWgAQcCINLRswcSIUljC
RxBXxNhasO+LrTRsgystzxQn5z2/e+77/ieTaOvN9FyIiElqvRrxNT/if0HE
HD/jT65E/OW/6aH5F/yP8yz/x/vMT3mWyosiHuh8NvtEv7Be82N+H/+IfaDj
RMQr3eeFESdmLWbv8Xd0ZNZj5wi/h/+4HFGm2+z8GG/iM3pvaYzuyoe6CZ0B
9zVg3XoT2J7derlLPpBLdZ7p1GEpe5uXInZ1auWkfMN8A9vBarBGbF3eltPy
HblVJ+m8haV4Bqvmm/Kgb993/zTdxjawKt6gU8Gv50VU8np5zb3r5qu8wJ39
dh75zrrcDM/InfJNs1psFRu124Ft8xpsBfvmzXbshd53Oy/9zmV8RCetc1G+
5byEDfOfOlO04t1F7JpzMS3LC/Ib9xTJhbSEzWNZb5zQojxu/tRsIvcf0iS9
piF3V+f+C+cSbw7wczKLZ3U=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Us71GEYx/GbYaS1rhZSDi/AXohcpK2Ny8Jp7LWoRCWmFGXG5FgUOb0P
vYH2Hd9CJ+dT+Vjc1/f5fe/7OfxnKlJ32vrzImJBLV2N+Hwtorgi4m5ZRD7e
wyKsK49oUF/0L8j3+QQO4EWs12utimjEr2Ye8AX8IN7gbqpv/JB8wM+azVRG
FFr/LI34rvdQ71B+hEn8xWfNNJud9LbH/G+uxFnv5Jf2vMc/XKWZYf2M/AT/
ciOYlUdxW24xMyV32pfDHe41dsnTeEt/l5ux7uZmcU+ewx65UH/de/a5ea6X
W8ADeYOf0z/y7mXukHuDKTNv8UiuvhzRJy/Kx+fffCXiBKvsS3vjU3UqP8Mx
dZv/Jz+3fmXfC/yB/7lx6y13TWDO3EfrcN6KsyfNfMBLfqc8btU6wyXNbXpn
PleDteq66lUJ7hMum6nHOpVSBfyus/fVnmo//8+4eXPH8olKyqe45p6se9ax
Q25yfxrPALr5Yhg=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LlO1XEQxfFhRxA6qNgxsbCQXdEXYEkgoaWA0CmbgBZQkBBLSSAxQZZ7
QYWGnjdgeQD2XZYWlx63zy2+mTNn5szvf29l33DXUFpETOG2LGK7PGILszjU
V1dGVKGwNOK9esDrqI54WRJRwNvXv6Af0r+qIprpfPqL3a9YwyqmZYYrIlbM
ntvJU5fxjH5TFJGkm+gHagI37n6Q+Sy7giHZJf41v947dVjmL/I67V3xc+lu
/oL6TZ+jJuV+8j5ix/42svk5+k260ZtZqRv6H9jAgEzSLIFB+tKtd/6PTHuT
3nrMn6cv+BnqJ5zTj8wm5BMyc7wte2f89NRv5Z2mdni99t66l8Y/4TX4hqC/
y9bT/7DHr1P/Yszundk6avV/MMrbtVND/0aPmyO8Y95T/T1avflEZtBsXG3X
t+AV+vEaMzJHMsV0G/4DjmBQtw==
       "],
       VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwVz7sv5GEUh/GDLagEi5mlcVkiRDGJhIKCoJxZvSxbrUioUPAHUEh2S4lL
NyRmG6VbQ8ZUG1tsI9luQ4REJCjc4qP45nnOec/vvO+v4dv0yFRRRMzJcVVE
KhmxXh2RronYwAwuJCI2+Rjfwt+NEeM8x1POfuGZby8/Rvx1ds7v+C2+4BMe
mDmUPvuXPkUsN0Xk1Yv8BMvNneIfSfJwXs+beDP+s7eTd/AevHL/tfzX7/aG
GymqdZcUS4O9z3iPJdhr3wn/wAtYjfve8mhfy/t3eKRu5YNmX9Rd/BW/uq+f
l7ljACfVpWbSPCNfpMJbKuXCe0bVCZ6UhG++qyfk2lmdeobPyoo98/bf6mf5
D72fssMr7F/ln82v4YHeNrapc5hX15rZ5e16e3juvx78w5B7C+phzOqN6r0B
K1VJdg==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzss3XEYxvHXQlwSQuuco5FwqlKTpZEYxGKpQeJgRDDRpswdKoIek9uh
Q4caMZs6uAwEiRAkRCpNp0qa2FUkfAzfPM//eW//X+3gaOZTXkRMYK8iYisZ
sY1GrFdFrGEwhcqIX7IhepKOONU7yo895/y/FxEX8ht+0swUpvEVWVS/jmix
5+fLiAc923QH+eYO6CHK+DN6jg1735mZMzuP92av5ZvyRd85LOCP7Le7R/K/
/A2u+FvaYWbWjm/6lrGE5KuIFEb44ee9bt551wd9zfL//D12ze6hDm8TEQ14
tDOt740s3GiS5dMCtPHtaiV8p3oXMii1K6PWzV/iAp/1lcv75P3I+oePdt96
xzz/RTaO73yW1ugdMDPDr8oWaVqWoxu+f9Ae9XrZCr8lK3enAvt8Uq2S7/Xe
BC2kRShGq5lDHOAYTwn7TrY=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzztIFXAUx/GjEIJrpd6yoFy0IUfpcTOTJGopB8FNLBAMvOQiOpWLWVSU
TxDsMUVQQSo6SGqDpXTFQair9+p6QXIQpBqMPg5ffr/zO+f8H6daU40dBRHx
BIuHI04cjziJWyURPWUR3Xh3LOJ2IuLOAfJedWVFxAN6TnZPlimN6KRZZ2wf
ifhxOiLP7/G79B/dkO3zC0cjvqDW7mWknFVHP9hfln+kfe59iEl+TTZFH6kf
4zOfk83Rp+pnSPMvnTHvTc+dN86vyF7oDWCdz9vZoCPqUfziz5vdkSf9+RJq
MeqMEVz35hL/qjdTKC/lC+yV0QQO8Wdog/6i+77hK4rkNfKbfBrfUSy7Krth
dlXdwNc58wrqkXHfsN5PmkW7/l3kzHbRcvtbfIuZTdqMSu+/r1dFx7z1LO1X
N5qp5t/KBtUVdofopPoVbdJ/Td/ggrmk/kX6Xv2Jb9OfoLPqP+75jb+Yls1g
SX7NfLXsP/ENWkc=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j1I1WEUx/GTS13vXUKvrxXYi5JooIWGVlNGrlEZEVQXrM2WrCYLgiQr
chC0hqYcNaEaNW0o6hrUEERoJWmYQ5RDL6Tg5z98+T7nd849z8O9typ34UjX
uogYxauiiMmyiGMlEXk+ztM8hfelETNcWhHRIR/lE/xua8SIc095xFVclH00
283l8huy3qSnnpVf4w8+U6F3V96PPtmc3i3eLz+A69si7qm/ye9zU2VEMzr1
zuMcUsURK3Z99a69evO8Il/FovNBu7/zJnMF9k3Zs8/cc66WvU3ejy92NKhn
nZfd9ymZU//k3+pfvGCmzd5DWC9bxQY8ccdjpJz/u+up859sxAT/5Wrz484F
esE16s1mt3vHFt7B07I8BryxJdlrtpVz3nCYM+p27lKnzRx13pj8TnxFdpaz
6hwvemfKzkKk3LcThUirM0g71yKDH2ZbZK3odv9lXMIDO2/bVWXnHV4290/+
GYPJ2+VDvGBHHU7Ke73roaxGb5iX5PVo0CuyvxiP5KfUY8l3qrcLu9U3ffY0
Z81M6J1xfsZ7uBF1dr7AG0zKXyf/SX7JeV4DHNVnig==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T9I1HEYx/HnnFpS+mdZRNS1XBIEdSGBCN6Wg+jS0VAQodtdDVIXoXR6
Q1Di0ur1Ry7FyUO4q5ZAa2i5vURIXTuFOqPJXje8+Xyez/N8n+/3x+/8vfxo
LhERz/HtWMS1nogbpyPS9HZ3xAOax0NMnoqYwpj8iTqVjCjQcfUzeRGP+GlZ
EY/5GVmp3eN7za+eiNg8aabdQ8ud8/SKXpnG8Yg1MxV+nQ7a06Dn9KuyWW97
iYy8rm7aVVfX8Eo2Ye6LfE/+lX6Sf8Cc/CO9av9P+Rb+mNmmfXo79J96n/7F
AX8YA3qddMS5jHdkaUI/Ke+g/Xpl3/caN/lDsiH6Rv0Wt/guWZa+Uy/gPv/D
W7/jqT0btCJ/j5zeWfN5uqheQoEfNnex/T98Qw55lL1l0pt+X4hY5kt8jb6g
LdlnfsXZKg7ckXamaM91etneBA3c0TtKU2f8I1xCw5mmbBe/cAR3zf0H+LhV
Vw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzFI1GEYx/HnxNmhO8/Mpf4HlUQQQVEuFbbp5G231WJiGOoSeFhBjUGe
EgS5dKXgHVyDnoNTWFBLU0aIk52YKFGXtdTQ54aH7/f5Pf/3fZ//iZt3hsZS
EfFIfUxHTHZHTB+LeNkZcQ9f4X2ckF9So9mIL10Rt/FTEvHabEo+pd+SF3Hb
PT8zEZvm3/kT2YxqmJfwbC5iFvf0L7CsDnhBvsQrKut8t7ePY7v8veyDOqNv
yDf4Dn71xmc+dzRiX7/bugvf2GvRXt/0z8yasr/8F5bct25eMf8ne25e5b/N
VvEP5szrPMwSfsR+15xLZGl+WtZultL38kR2XuVas56Ied+exLw6pYbtnXfv
JHaYFXiR38B9//CQj/DHOI4/ZE/5XV7GB3goq/ELdr7Y+i9vVe1wmS/wPlzE
muwKX+FXsWnHOl+W3/J2v+yt/jq22f0dXzMb0Gf0g5jGc879Bwp3VJ4=
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0EtI1GEYxeFXyqVJ5ExlQYRGkGZgtNGgcN+F8JZIixZZm8Jo0cJ9UWoF
TQsvBV1Ai9GCvERKEOGiFmWaWq26mDS6KUdqI/jM4sc57znv933/mZ2nL5w4
nxcRabzfFLFcHJHFXzRsi6hHHU6iCcdxryTiGJ21/9zeEH7wV5IR17ZGXNK3
0+u4KuugnajCQVRjfnPEbV2F3RTNmB/SRzjkvm9bIs7pvtN5fElEvNR9pWP0
QO4NeQfemnvd2YN3/E1ZBrcwa34gv4/LzsyZU/JF3MFvc7/utTf7aMbcJV9C
N1bNA7nvdvaNnTQ/iF5dFndR5NtfyCb0o/QfLcUu1DhXIivj9+A/yrEXr+Sl
zjYXRXwwp+we9r9O8mdlR3TT/Aw+ocBbp+xU8Psw6fwUPqLJ7hz9jDo0oB6t
9pPOndG3oJhvpUflF2lj7l57G1CISr+3U16r38/f4B878wRd/IKdX+jm07KN
/ADdbb9PtmReRD//VJ7gn9ERc5b/6b1luoIh+XY6TCf063ULWId8jMl36Mfp
lP6PLIk2JDAtWwOXhnO9
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j9IlWEUx/FTXSuIlspuqRUWLRFk18Gl4epgl0i7iPTvapAuJlghLqIS
RA42RJNWc9BioIMSRTYURENqVniDoJKGtiAoqEj7PMOXc87ve57nva+vtV1X
2i6vi4gZvN0Rca8y4m9VxB+8zEa8lo3LKg9EvNDf1n/mnujHUr874hq3on7B
lPy6vM7OeXMHSrgvH5QX7Q67d8Lcbx7S39L36vu4jdURm7EJo/Iu+Rl3ZXdh
Z8SI7KS9krxbVnL+vfvfYYBrly/bv8i1cgvyeQw6cymd5Zf4Tj7PZ7gKbEAn
38zP8+f4en5NLTi7nl/Vt9vJ23ll57T5oJ1f6j/8RFFe4befUlvRgsfOTuOG
e/aZV7EXayi4r0ltRB57MJWe5V0buZxn3XSuR95gPmQ+6/6n5meYw2F5h539
XI15wvm7uINarkpeLW82F3AcV+1nuW3cQ8/aqt+iz8knzRlzJn1Hz8rhKH5v
978hP+aucTtH7D6y813+Q170/mPy0fSu+Cr/Jp9Nfweuxv5I+obcMMr8Cj/N
n+D7uA/qJ5SxyH/kJ9NvN1/gl9RlvMFzvsw/4JvS9+YX1Qbzgtpi/g9jFmq6

       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D9I1GEYB/DnhuuCJIIrO7tF7xYhHMIGwanOUkiUOzkUEy+VFgUdzpYg
l9DARaLFxamuoaYTgqIGFW4xqCGXolU3I2g4EkE/N3z5/nuf3/u8v67ZpdJi
IiJewMHViIs3ImqQgtdwrz3iDb4A3/SD2Yj78Ol6xEdoz0cc6hq6l9ciujMR
7+Rf+HX+ir5OP6fX5DX6KV2UP+M3+Sq/TG/QFfkCX+XX+Dl6BR/lIqboKfkT
vkxfdtcl+6XMzLdm+Wm440xS/t1eXztkuofySbitOzX7ysy+fk9f1k/odulx
vIP/O/MZN/kx50pQhG3ZqtnwnQZfgAH441wnPsYnujP3J/ynu7696Xyv7wXf
x9+ke/Bvb8rTOTqLz/gMnW69DbfhE1mSTrZ02u50U/aX/kd/kB/So+4dgRX3
1mU/ZcP8A1iUvZf9ovvtOIQf22kQV3RvdT/ovtZbcAFmvHNL/gjfgnOcyU44

       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T1IlWEYxvHbpRBsEDWPiuFXiyINCqm0iIKDiHgyawlErED8CDpJgRKC
g+ikgw5+LE4iiIttoluRg1BIaB0hglLoYwgkDMzfGW6u6/pfz/2+78Nb3jeS
HM6KiBlzkB+xWBDxsjgix5yYd4URRUURCbOvX9A/TURs4/+wB5UR5/Stbk43
pNvQ/cJ+mh18Bh/AV/H7zt++HrGFT+Lz2Bo/xt/VTctLckq+Yafa2Vl5SK7S
v9Cv+K5lM4X344PYsZw2r7Bx5x7iefY/YUdmFO/BPvDZ+kG5Q26w28u38W14
jdwjN8slfCd/h2/VFcvtcqPcQutpGf6bNsm19J53fvbNp/wt7CbtxvaxL5k7
YKWZu2K72Hf6zQxknq/L1yXl17oDPhe7RruwTazOuT35Kn6FTrvPRV7Ef/lv
RcQf/ow/pT/oGZbmv/LP7L/n0/yE5yTsfnSn5/5TyrzRHerKSiKeyOU0aWfd
ucdyI31E68wlBVlUAQ==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D1Im2EUxfEbCtW6BPyqH9SgIoqFilQCUggd6hAwUDMZIrQELR1KTYcO
cRGXDha76CA1QyKtk4PgouLSwaVdHNTBRRA6BR1LR38Oh3vP/9z7PM/79pcW
8x8TEfGNLtojqh0Rqd6I08cRR10Rh3SKb+K93RHP+O2eiNJgRF39LVuXjeL7
dn7xa3yr/ED/Rb+rLqtJrKb/rH/aaU+/qP+Kf3LWkv0hfBV/hy84s4z1YSvY
G2weW8A6sAo2i5WwAtbkfc30wXkP1bL8tfytfFr+yM48lsXmsAyWNfsAL+Cv
8C3v+E55PsO/lCfN5fgX/H+zU/q0flL2wz079JMy+Bie09epRhPYMJY2u8Wf
2R/BUtixewb96wGqyp/gnXien6E5KlIbnsRvvGPDGUWz62oL3ow38BM1wSfU
mjvGzRzr/7V5M35tZg1v8Lf8qLzCX/F/+ef+x575M/7q/v/Ls9h7MxfqOf2R
Xcqm9EV8+/67vOMOr1lNVw==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0L0rxmEUxvGjpwyiyDsDD4MogwWlkEVhEkpSMggDhRJSSj0ZlMk/wMLC
bjWIWCiSwUuhlPI2IMnHcHWu63uf+9zn90sOT3ZPpEXEHF3kRSyURMzTaWFE
R4GKzRRFTNM+1oaVVkYc4+v5Ec14M7Yvr8l5zvb4FX5HXVI31Fm1Vt/6/zzz
V/VNq1NUhXeVYs5G9ZXLy/xTRcSQvMD3q1nuTPHdfI/+Eb6Tb7FXurMB+ag4
4pDqsCT92K/PG73UQx2U0pvjrJPvonc9b5SNfZj3yreb1aSvUf62z6vaitWp
D/I91ct3dqzGDuQaOclfU8LdMrmIv6R8Pkfd1vfrTqacIW/JCT7Bf+Gfud77
/5f4M3+Jvcg3dktht9ijfCXPy+fymZ5bbFweo13fdIJfYYPyptmLWIP/8geU
DEob
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0UtLVWEUh/HlwJQkkTzejimo6EjtDI6YioMiKEEkNBAJwgt5IT2iYA1C
sVmioyB0Yh+gYYFfwEmDBoLg8AjqwAQvgy4Drz8Hf9Z6nrX2++7Nrhme7s3k
RMQXeVkaMV4RMSF9+lR5RGllRJn8LI5oUYeTEWk1m4jYqo3Y5r9zP+SAy+JG
8yb5WhdxzB1xzfih/Md/8KrzR8zT7oiSiGtuU7/Gt6h5XL7dFeeeu+cXXtYX
qvf5JTs7+la1RK3kcpyX1VdLPd5TG2TX8yncrO9QT9zxt8w9+Ck+xbm4HXfj
O/pVZ/1zXyf3gnvANcoT3I9zzZtwmzznhrhn+gLv04On8F07fVwR18+95wZx
Ar/GH8wXuaT7K7g33BKuwVU4gxfsfOY+3r4fNypjss6l7C3z9Xbm7X7j9v27
NH+gjtubkA3+ED/iF+3+1r/lJ2XANxbhTrNTNcNNyyv+k90EdyaPzS/UGbNL
dfb2G+wk9VfSZX4Pz/GF6ju1ir8BRpFOzA==
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T1I1XEYxfEnggbzqpXmK2Y6uJUUCKJFQ1LpEDSEDS1pi28XFFQQ4fpK
gYstgSnm4FBDUkEXakyHIB0qyC2tQSxB0kQn6XOHw/ec5zm/3/93uecfJO90
H4uIp7RaGJFbEpFHK/y1oojPuC3/od90uTRiC4urIj7lR/zkf9EGNdpdp1N0
mqZ18rCZmiiHcilBt+gmjbu/Ta/Bt8b4c7hMo3w9jmBLccRz9+9URlSdjZjj
K7HLbkGnjK/DUmw129LL58/QXTkHE5TtO0lvvl2ghzV2DXSRTjhfgRcyb6Dj
cjbe8K2rzp3kj2jfPVn4Dw9xD+/bH/C7/BX3ruOe/AMvyRve85X/a/YFq82W
cEf+iP3OT/uNa96Vlr9jo7yKr+UV7NapMJuVa71tBpdw0x0f7J/J5Trv+Ul+
SjfNP8F3OKE7bP5Ifiv36j7m3/Cjdn12KXlRHsZXmDJ/aN6j22c2QC/N+/FF
5k04pHNPp53vonnzjsz/hZ04aP+N/gOkmlqQ
       "],
       VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DtInFEQhuHx0mgawWt2RV2FVdFCC7FcUkS8i1opNt6w8JpGJWVISBEw
jQiLNlaBQLo0Wm6rFgraqQuCiAjaiYXgY/Ex77xn5uyePzWzOrZSEBHf5aI6
IlcTMVUV0anOJiLm5Lg84lJ/JfmKiLPGiHMur7/V5/EPO9f225siHrkHbou7
4V70z/p9/YTzO66wUvg/XAn+gF/dW4Yr8AFfjevwup2djxGHXL/awLfyg/gG
D6gtare5Lv4ed0gGP6l/naecdeMe7sU9Ka7X2/pkmCtOmvWerLkinDE7zmed
n8hn/aR+Dxfb/21uxB39/Dxfyo3iL3jXWcIdZdyi+SVZlq/Oqri0veb3/yxD
Zr/x9fyC/V84jdfwNm7H63gfd+I2O2k7SffXyj9+WN10/5D60+wBV25mC+fw
f997Gx/hBJ/TT5vPcqfv3wifcp+8f0M2pc7vvAHnKUnq
       "],
       VertexColors->None]}, {}, {}}},
   VertexColors->{
     Hue[0.6499999999669532, 1, 0.10000000004575714`], 
     Hue[0.6499999852880078, 1, 0.10000002037045079`], 
     Hue[0.6499998575374961, 1, 0.1000001972557747], 
     Hue[0.6499991538514573, 1, 0.1000011715902899], 
     Hue[0.6499968622093047, 1, 0.10000434463327044`], 
     Hue[0.6499926810152515, 1, 0.10001013397888259`], 
     Hue[0.6499886753209286, 1, 0.1000156803248681], 
     Hue[0.6499871827318621, 1, 0.10001774698665249`], 
     Hue[0.6499886974241673, 1, 0.10001564972038382`], 
     Hue[0.6499925949688808, 1, 0.10001025312001116`], 
     Hue[0.6499966840514407, 1, 0.10000459131338975`], 
     Hue[0.6499990174111819, 1, 0.10000136050759434`], 
     Hue[0.6499998034253445, 1, 0.10000027218029237`], 
     Hue[0.6499999729662879, 1, 0.10000003743129375`], 
     Hue[0.6499999980637757, 1, 0.10000000268092593`], 
     Hue[0.6499999980108732, 1, 0.10000000275417563`], 
     Hue[0.649999972502692, 1, 0.10000003807319564`], 
     Hue[0.6499998007707878, 1, 0.10000027585583228`], 
     Hue[0.6499990071984714, 1, 0.10000137464827052`], 
     Hue[0.6499966598024274, 1, 0.10000462488894667`], 
     Hue[0.6499925622199799, 1, 0.1000102984646433], 
     Hue[0.6499886739785015, 1, 0.10001568218361344`], 
     Hue[0.6499871792649814, 1, 0.10001775178694884`], 
     Hue[0.649988696060685, 1, 0.10001565160828231`], 
     Hue[0.6499927167322246, 1, 0.10001008452461209`], 
     Hue[0.6499968893754299, 1, 0.10000430701863561`], 
     Hue[0.6499991646891583, 1, 0.10000115658424233`], 
     Hue[0.6499998599977125, 1, 0.1000001938493212], 
     Hue[0.6499999856334239, 1, 0.10000001989218238`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999852880078, 1, 0.10000002037045079`], 
     Hue[0.6499998368066057, 1, 0.10000022596008445`], 
     Hue[0.6499987662030103, 1, 0.10000170833429345`], 
     Hue[0.6499935549624519, 1, 0.10000892389814346`], 
     Hue[0.6499778300417067, 1, 0.10003069686532913`], 
     Hue[0.6499505462683586, 1, 0.10006847439765738`], 
     Hue[0.6499252913219769, 1, 0.10010344278495513`], 
     Hue[0.6499158508823386, 1, 0.10011651416291577`], 
     Hue[0.6499247160158207, 1, 0.10010423936270982`], 
     Hue[0.6499489183734026, 1, 0.10007072840605798`], 
     Hue[0.6499755737898713, 1, 0.1000338209063321], 
     Hue[0.6499918966134397, 1, 0.10001122007369896`], 
     Hue[0.6499980735657545, 1, 0.10000266737049385`], 
     Hue[0.6499996593138839, 1, 0.1000004717192377], 
     Hue[0.6499999506826558, 1, 0.10000006828555356`], 
     Hue[0.6499999500906315, 1, 0.10000006910527945`], 
     Hue[0.649999655185399, 1, 0.10000047743560135`], 
     Hue[0.6499980549290366, 1, 0.10000269317518012`], 
     Hue[0.6499918370195641, 1, 0.10001130258829587`], 
     Hue[0.6499754483540974, 1, 0.10003399458663449`], 
     Hue[0.6499487609293296, 1, 0.10007094640554366`], 
     Hue[0.6499246089762626, 1, 0.1001043875713287], 
     Hue[0.6499158353957267, 1, 0.10011653560591685`], 
     Hue[0.6499253861002506, 1, 0.10010331155349914`], 
     Hue[0.6499507186578939, 1, 0.10006823570445467`], 
     Hue[0.6499779704371008, 1, 0.10003050247170654`], 
     Hue[0.6499936165544795, 1, 0.1000088386168745], 
     Hue[0.6499987823857478, 1, 0.1000016859274261], 
     Hue[0.6499998396191935, 1, 0.1000002220657321], 
     Hue[0.6499999856334239, 1, 0.10000001989218238`], 
     Hue[0.6499998575374961, 1, 0.1000001972557747], 
     Hue[0.6499987662030103, 1, 0.10000170833429345`], 
     Hue[0.6499924447114087, 1, 0.10001046116881876`], 
     Hue[0.649966803005242, 1, 0.10004596506966493`], 
     Hue[0.6498986870713849, 1, 0.10014027943962096`], 
     Hue[0.6497903076682764, 1, 0.10029034322854044`], 
     Hue[0.6496956694759822, 1, 0.10042138072556306`], 
     Hue[0.6496598500920082, 1, 0.10047097679568098`], 
     Hue[0.6496884070778483, 1, 0.10043143635374868`], 
     Hue[0.6497763140913129, 1, 0.10030971895048985`], 
     Hue[0.6498816573421481, 1, 0.100163859064718], 
     Hue[0.6499540431582559, 1, 0.10006363255010721`], 
     Hue[0.6499865511173065, 1, 0.1000186215298833], 
     Hue[0.64999697736963, 1, 0.10000418518051227`], 
     Hue[0.6499994121848602, 1, 0.10000081389788582`], 
     Hue[0.6499994075356613, 1, 0.10000082033523827`], 
     Hue[0.6499969516884851, 1, 0.10000422073902053`], 
     Hue[0.6499864629461425, 1, 0.1000187436130335], 
     Hue[0.6499538247815461, 1, 0.10006393491785928`], 
     Hue[0.6498812811242848, 1, 0.10016437998175962`], 
     Hue[0.6497759033253894, 1, 0.10031028770330704`], 
     Hue[0.6496881578673747, 1, 0.10043178141440438`], 
     Hue[0.6496598197797228, 1, 0.10047101876653777`], 
     Hue[0.6496958940624493, 1, 0.10042106975968566`], 
     Hue[0.6497907590832415, 1, 0.10028971819243498`], 
     Hue[0.6498991064821327, 1, 0.10013969871704716`], 
     Hue[0.6499670218094749, 1, 0.100045662109958], 
     Hue[0.6499925169058931, 1, 0.10001036120722495`], 
     Hue[0.6499987823857478, 1, 0.1000016859274261], 
     Hue[0.6499998599977125, 1, 0.1000001938493212], 
     Hue[0.6499991538514573, 1, 0.1000011715902899], 
     Hue[0.6499935549624519, 1, 0.10000892389814346`], 
     Hue[0.649966803005242, 1, 0.10004596506966493`], 
     Hue[0.649879101783133, 1, 0.10016739753104668`], 
     Hue[0.6496852145273001, 1, 0.10043585680835372`], 
     Hue[0.6494162997265167, 1, 0.10080820037866924`], 
     Hue[0.6492010682900416, 1, 0.1011062131368654], 
     Hue[0.6491137171780911, 1, 0.10122716083033544`], 
     Hue[0.6491563829934823, 1, 0.10116808508594756`], 
     Hue[0.6493416527692054, 1, 0.10091155770417709`], 
     Hue[0.6495997554994432, 1, 0.10055418469307868`], 
     Hue[0.6498113105300759, 1, 0.10026126234297193`], 
     Hue[0.6499305428935218, 1, 0.1000961713782006], 
     Hue[0.6499799856500064, 1, 0.10002771217691427`], 
     Hue[0.6499948089502459, 1, 0.10000718760735187`], 
     Hue[0.6499947831523833, 1, 0.1000072233274692], 
     Hue[0.6499798727551617, 1, 0.1000278684928531], 
     Hue[0.6499302554975778, 1, 0.10009656931104621`], 
     Hue[0.6498107930448382, 1, 0.1002619788609932], 
     Hue[0.6495991042255871, 1, 0.10055508645687941`], 
     Hue[0.6493411176280112, 1, 0.10091229866890762`], 
     Hue[0.6491561566068836, 1, 0.10116839854431495`], 
     Hue[0.6491137403392346, 1, 0.10122712876105974`], 
     Hue[0.6492013214066819, 1, 0.10110586266767127`], 
     Hue[0.649416890241138, 1, 0.10080738274303964`], 
     Hue[0.6496859288220751, 1, 0.10043486778481918`], 
     Hue[0.6498796003047549, 1, 0.10016670727033943`], 
     Hue[0.6499670218094749, 1, 0.10004566210995798`], 
     Hue[0.6499936165544795, 1, 0.1000088386168745], 
     Hue[0.6499991646891583, 1, 0.10000115658424232`], 
     Hue[0.6499968622093047, 1, 0.10000434463327044`], 
     Hue[0.6499778300417067, 1, 0.10003069686532913`], 
     Hue[0.6498986870713849, 1, 0.10014027943962096`], 
     Hue[0.6496852145273001, 1, 0.10043585680835371`], 
     Hue[0.6493047777680848, 1, 0.10096261539803639`], 
     Hue[0.6488673490985243, 1, 0.10156828586358183`], 
     Hue[0.6485502856265529, 1, 0.10200729682477297`], 
     Hue[0.6483902795375447, 1, 0.10222884371724578`], 
     Hue[0.6483816036130576, 1, 0.10224085653576644`], 
     Hue[0.6485957628883882, 1, 0.10194432830838562`], 
     Hue[0.6489939519074331, 1, 0.10139298966663111`], 
     Hue[0.6494149503656054, 1, 0.1008100687245465], 
     Hue[0.6497275525921767, 1, 0.10037723487237067`], 
     Hue[0.6498986949687521, 1, 0.10014026850480488`], 
     Hue[0.6499645086924556, 1, 0.10004914181044619`], 
     Hue[0.6499644084648013, 1, 0.10004928058719827`], 
     Hue[0.6498983451179355, 1, 0.10014075291362773`], 
     Hue[0.6497269063824568, 1, 0.10037812962429069`], 
     Hue[0.6494141593805527, 1, 0.10081116393461945`], 
     Hue[0.6489933573089761, 1, 0.10139381295680236`], 
     Hue[0.6485955693237665, 1, 0.10194459632093877`], 
     Hue[0.6483817334719172, 1, 0.10224067673119161`], 
     Hue[0.6483905107237508, 1, 0.10222852361326827`], 
     Hue[0.6485504399625566, 1, 0.10200708312876784`], 
     Hue[0.6488676434233365, 1, 0.10156787833691877`], 
     Hue[0.6493054326597033, 1, 0.10096170862502624`], 
     Hue[0.6496859288220751, 1, 0.1004348677848191], 
     Hue[0.6498991064821327, 1, 0.10013969871704712`], 
     Hue[0.6499779704371008, 1, 0.10003050247170653`], 
     Hue[0.6499968893754299, 1, 0.10000430701863561`], 
     Hue[0.6499926810152515, 1, 0.10001013397888259`], 
     Hue[0.6499505462683586, 1, 0.10006847439765738`], 
     Hue[0.6497903076682764, 1, 0.10029034322854043`], 
     Hue[0.6494162997265167, 1, 0.1008082003786692], 
     Hue[0.6488673490985243, 1, 0.10156828586358178`], 
     Hue[0.6483447647008006, 1, 0.10229186426042995`], 
     Hue[0.6479786482228467, 1, 0.10279879476836613`], 
     Hue[0.6477162367776388, 1, 0.10316213369250021`], 
     Hue[0.647562318571634, 1, 0.10337525120850674`], 
     Hue[0.6476410815525707, 1, 0.10326619477336373`], 
     Hue[0.6480080185451157, 1, 0.10275812816830143`], 
     Hue[0.648579486372906, 1, 0.10196686502213027`], 
     Hue[0.6491668432411315, 1, 0.10115360166612573`], 
     Hue[0.6495970754140722, 1, 0.10055789558051553`], 
     Hue[0.6498068783412693, 1, 0.10026739921978108`], 
     Hue[0.6498066105961633, 1, 0.10026776994377398`], 
     Hue[0.6495963220340493, 1, 0.10055893872208573`], 
     Hue[0.64916586418334, 1, 0.10115495728460613`], 
     Hue[0.648578777570923, 1, 0.10196784644026052`], 
     Hue[0.6480079461523003, 1, 0.10275822840450731`], 
     Hue[0.6476414975569021, 1, 0.10326561876736627`], 
     Hue[0.6475628209177057, 1, 0.10337455565240761`], 
     Hue[0.6477166871005474, 1, 0.10316151016847287`], 
     Hue[0.6479788895815403, 1, 0.10279846057940578`], 
     Hue[0.6483448000569576, 1, 0.10229181530575106`], 
     Hue[0.6488676434233366, 1, 0.10156787833691866`], 
     Hue[0.6494168902411381, 1, 0.10080738274303949`], 
     Hue[0.6497907590832415, 1, 0.1002897181924349], 
     Hue[0.6499507186578939, 1, 0.10006823570445465`], 
     Hue[0.6499927167322246, 1, 0.10001008452461209`], 
     Hue[0.6499886753209286, 1, 0.1000156803248681], 
     Hue[0.6499252913219769, 1, 0.10010344278495513`], 
     Hue[0.6496956694759822, 1, 0.10042138072556304`], 
     Hue[0.6492010682900418, 1, 0.10110621313686535`], 
     Hue[0.6485502856265529, 1, 0.10200729682477291`], 
     Hue[0.6479786482228467, 1, 0.10279879476836615`], 
     Hue[0.6475401197544662, 1, 0.10340598803227762`], 
     Hue[0.6471492185716042, 1, 0.10394723582393262`], 
     Hue[0.6468120214679307, 1, 0.10441412412132671`], 
     Hue[0.6466225588476567, 1, 0.1046764569801677], 
     Hue[0.6467189588664768, 1, 0.10454298003103212`], 
     Hue[0.6471926206447458, 1, 0.10388714064573666`], 
     Hue[0.6479416314291787, 1, 0.10285004879036792`], 
     Hue[0.6486847327742014, 1, 0.10182113923572118`], 
     Hue[0.6491330712110971, 1, 0.101200362938481], 
     Hue[0.6491325955422843, 1, 0.10120102155683719`], 
     Hue[0.648683647156053, 1, 0.10182264239931124`], 
     Hue[0.6479407143627663, 1, 0.10285131857463126`], 
     Hue[0.6471924667805575, 1, 0.10388735368845883`], 
     Hue[0.6467195342872655, 1, 0.10454218329455547`], 
     Hue[0.6466234011364024, 1, 0.10467529073421211`], 
     Hue[0.6468126895154238, 1, 0.1044131991324902], 
     Hue[0.6471496978926512, 1, 0.1039465721486368], 
     Hue[0.6475405484301956, 1, 0.10340539448126762`], 
     Hue[0.6479788895815403, 1, 0.10279846057940577`], 
     Hue[0.6485504399625567, 1, 0.10200708312876777`], 
     Hue[0.649201321406682, 1, 0.1011058626676712], 
     Hue[0.6496958940624493, 1, 0.10042106975968564`], 
     Hue[0.6499253861002506, 1, 0.10010331155349914`], 
     Hue[0.649988696060685, 1, 0.10001565160828231`], 
     Hue[0.6499871827318621, 1, 0.10001774698665249`], 
     Hue[0.6499158508823386, 1, 0.10011651416291577`], 
     Hue[0.6496598500920082, 1, 0.10047097679568097`], 
     Hue[0.6491137171780911, 1, 0.10122716083033541`], 
     Hue[0.6483902795375447, 1, 0.10222884371724579`], 
     Hue[0.6477162367776386, 1, 0.10316213369250041`], 
     Hue[0.6471492185716038, 1, 0.10394723582393323`], 
     Hue[0.6466247658365454, 1, 0.10467340114939871`], 
     Hue[0.6460970638205105, 1, 0.10540406547929318`], 
     Hue[0.645589268197284, 1, 0.10610716711145293`], 
     Hue[0.6452371269589686, 1, 0.10659474728758193`], 
     Hue[0.6452105445038666, 1, 0.106631553763877], 
     Hue[0.645564334064698, 1, 0.10614169129503348`], 
     Hue[0.6461188517281143, 1, 0.1053738976072263], 
     Hue[0.6465292695559217, 1, 0.10480562676872378`], 
     Hue[0.6465287438944914, 1, 0.10480635460762724`], 
     Hue[0.646117940680914, 1, 0.10537515905719602`], 
     Hue[0.6455640968389634, 1, 0.10614201976143531`], 
     Hue[0.6452112044766596, 1, 0.1066306399553944], 
     Hue[0.6452381831863726, 1, 0.10659328481886882`], 
     Hue[0.6455902756764894, 1, 0.10610577214024544`], 
     Hue[0.6460978666860379, 1, 0.10540295381933218`], 
     Hue[0.6466253190276136, 1, 0.10467263519253509`], 
     Hue[0.6471496978926508, 1, 0.10394657214863749`], 
     Hue[0.6477166871005472, 1, 0.10316151016847318`], 
     Hue[0.6483905107237506, 1, 0.10222852361326844`], 
     Hue[0.6491137403392345, 1, 0.1012271287610599], 
     Hue[0.6496598197797226, 1, 0.10047101876653787`], 
     Hue[0.6499158353957267, 1, 0.10011653560591688`], 
     Hue[0.6499871792649814, 1, 0.10001775178694884`], 
     Hue[0.6499886974241673, 1, 0.10001564972038382`], 
     Hue[0.6499247160158207, 1, 0.10010423936270982`], 
     Hue[0.6496884070778483, 1, 0.10043143635374868`], 
     Hue[0.6491563829934823, 1, 0.10116808508594757`], 
     Hue[0.6483816036130574, 1, 0.10224085653576663`], 
     Hue[0.6475623185716332, 1, 0.10337525120850805`], 
     Hue[0.6468120214679272, 1, 0.10441412412133169`], 
     Hue[0.6460970638205038, 1, 0.10540406547930246`], 
     Hue[0.6453297342290453, 1, 0.10646652183670652`], 
     Hue[0.6444525596532943, 1, 0.10768107124928494`], 
     Hue[0.6433834721860854, 1, 0.10916134620388175`], 
     Hue[0.6419342693173481, 1, 0.11116793479136415`], 
     Hue[0.6399724772615234, 1, 0.11388426225327539`], 
     Hue[0.6378190830503149, 1, 0.11686588500725631`], 
     Hue[0.6363437737647057, 1, 0.11890862094117663`], 
     Hue[0.6363435021480464, 1, 0.11890899702578202`], 
     Hue[0.6378192495710805, 1, 0.11686565444004243`], 
     Hue[0.6399739959560372, 1, 0.11388215944548692`], 
     Hue[0.6419364029752823, 1, 0.11116498049576298`], 
     Hue[0.6433852867591608, 1, 0.10915883371808509`], 
     Hue[0.6444538432672651, 1, 0.107679293937633], 
     Hue[0.6453306991597083, 1, 0.10646518577886538`], 
     Hue[0.6460978666860311, 1, 0.10540295381934163`], 
     Hue[0.6468126895154199, 1, 0.10441319913249546`], 
     Hue[0.6475628209177045, 1, 0.10337455565240919`], 
     Hue[0.6483817334719169, 1, 0.1022406767311921], 
     Hue[0.6491561566068834, 1, 0.10116839854431524`], 
     Hue[0.6496881578673745, 1, 0.10043178141440455`], 
     Hue[0.6499246089762626, 1, 0.10010438757132877`], 
     Hue[0.6499886739785015, 1, 0.10001568218361344`], 
     Hue[0.6499925949688808, 1, 0.10001025312001116`], 
     Hue[0.6499489183734026, 1, 0.10007072840605798`], 
     Hue[0.6497763140913129, 1, 0.10030971895048985`], 
     Hue[0.6493416527692054, 1, 0.10091155770417717`], 
     Hue[0.6485957628883876, 1, 0.10194432830838648`], 
     Hue[0.6476410815525666, 1, 0.1032661947733693], 
     Hue[0.6466225588476413, 1, 0.10467645698018899`], 
     Hue[0.6455892681972526, 1, 0.10610716711149638`], 
     Hue[0.6444525596532654, 1, 0.10768107124932486`], 
     Hue[0.6428646294941891, 1, 0.10987974377727662`], 
     Hue[0.6397787456596381, 1, 0.11415250600973181`], 
     Hue[0.6332784547823019, 1, 0.12315290876296653`], 
     Hue[0.622205306537433, 1, 0.13848496017893902`], 
     Hue[0.6090491411989667, 1, 0.1567011891091231], 
     Hue[0.5998736460104983, 1, 0.1694057209085409], 
     Hue[0.5998738052387638, 1, 0.16940550043863484`], 
     Hue[0.6090518863173507, 1, 0.15669738817597592`], 
     Hue[0.6222118250047584, 1, 0.1384759346087962], 
     Hue[0.6332852682945339, 1, 0.12314347466910694`], 
     Hue[0.639783111261144, 1, 0.1141464613307238], 
     Hue[0.6428668818449628, 1, 0.10987662513774389`], 
     Hue[0.6444538432672381, 1, 0.10767929393767041`], 
     Hue[0.6455902756764588, 1, 0.10610577214028791`], 
     Hue[0.6466234011363869, 1, 0.10467529073423344`], 
     Hue[0.6476414975568979, 1, 0.10326561876737213`], 
     Hue[0.6485955693237656, 1, 0.1019445963209399], 
     Hue[0.6493411176280109, 1, 0.10091229866890794`], 
     Hue[0.6497759033253893, 1, 0.10031028770330719`], 
     Hue[0.6499487609293295, 1, 0.10007094640554372`], 
     Hue[0.6499925622199799, 1, 0.10001029846464331`], 
     Hue[0.6499966840514407, 1, 0.10000459131338975`], 
     Hue[0.6499755737898713, 1, 0.1000338209063321], 
     Hue[0.6498816573421481, 1, 0.10016385906471802`], 
     Hue[0.649599755499443, 1, 0.1005541846930789], 
     Hue[0.6489939519074316, 1, 0.10139298966663324`], 
     Hue[0.6480080185451057, 1, 0.10275812816831516`], 
     Hue[0.6467189588664403, 1, 0.10454298003108281`], 
     Hue[0.6452371269588972, 1, 0.10659474728768085`], 
     Hue[0.6433834721860215, 1, 0.10916134620397015`], 
     Hue[0.6397787456596258, 1, 0.11415250600974894`], 
     Hue[0.6301844468266199, 1, 0.1274369197785264], 
     Hue[0.6080792206635541, 1, 0.15804415600430965`], 
     Hue[0.5717905289829107, 1, 0.20829003679289282`], 
     Hue[0.5317029461800612, 1, 0.26379592067376145`], 
     Hue[0.5054104508359922, 1, 0.3002009142270876], 
     Hue[0.5054110463243464, 1, 0.3002000897047511], 
     Hue[0.5317100440196496, 1, 0.2637860928958698], 
     Hue[0.5718071228013197, 1, 0.20826706073663426`], 
     Hue[0.6080965938095235, 1, 0.15802010087912133`], 
     Hue[0.6301948999416345, 1, 0.12742244623466004`], 
     Hue[0.6397831112611579, 1, 0.11414646133070443`], 
     Hue[0.6433852867591167, 1, 0.10915883371814625`], 
     Hue[0.6452381831863105, 1, 0.1065932848189547], 
     Hue[0.6467195342872314, 1, 0.10454218329460267`], 
     Hue[0.6480079461522906, 1, 0.10275822840452063`], 
     Hue[0.6489933573089745, 1, 0.10139381295680457`], 
     Hue[0.6495991042255869, 1, 0.10055508645687973`], 
     Hue[0.6498812811242847, 1, 0.1001643799817597], 
     Hue[0.6499754483540974, 1, 0.1000339945866345], 
     Hue[0.6499966598024274, 1, 0.10000462488894668`], 
     Hue[0.6499990174111819, 1, 0.10000136050759434`], 
     Hue[0.6499918966134397, 1, 0.10001122007369898`], 
     Hue[0.6499540431582559, 1, 0.10006363255010724`], 
     Hue[0.6498113105300757, 1, 0.10026126234297222`], 
     Hue[0.6494149503656031, 1, 0.10081006872454952`], 
     Hue[0.6485794863728921, 1, 0.10196686502214951`], 
     Hue[0.6471926206446967, 1, 0.10388714064580462`], 
     Hue[0.6452105445037793, 1, 0.10663155376399788`], 
     Hue[0.6419342693172904, 1, 0.11116793479144421`], 
     Hue[0.6332784547823264, 1, 0.12315290876293279`], 
     Hue[0.6080792206635947, 1, 0.15804415600425353`], 
     Hue[0.5535172220443463, 1, 0.23359153870782828`], 
     Hue[0.47393025290694657`, 1, 0.3437888805903817], 
     Hue[0.3965448698524707, 1, 0.4509378725119636], 
     Hue[0.3505683074570688, 1, 0.5145977281363663], 
     Hue[0.35057138237062935`, 1, 0.514593470563744], 
     Hue[0.3965589856306645, 1, 0.45091832758831074`], 
     Hue[0.47395746658768534`, 1, 0.34375120010935883`], 
     Hue[0.553545544713231, 1, 0.23355232270475706`], 
     Hue[0.6080965938097692, 1, 0.15802010087878113`], 
     Hue[0.6332852682947127, 1, 0.12314347466885944`], 
     Hue[0.6419364029753274, 1, 0.11116498049570052`], 
     Hue[0.6452112044766228, 1, 0.10663063995544537`], 
     Hue[0.6471924667805229, 1, 0.10388735368850681`], 
     Hue[0.6485787775709114, 1, 0.10196784644027657`], 
     Hue[0.6494141593805507, 1, 0.1008111639346222], 
     Hue[0.649810793044838, 1, 0.1002619788609935], 
     Hue[0.6499538247815461, 1, 0.10006393491785932`], 
     Hue[0.6499918370195641, 1, 0.10001130258829588`], 
     Hue[0.6499990071984714, 1, 0.10000137464827052`], 
     Hue[0.6499998034253445, 1, 0.10000027218029237`], 
     Hue[0.6499980735657545, 1, 0.10000266737049385`], 
     Hue[0.6499865511173065, 1, 0.10001862152988332`], 
     Hue[0.6499305428935217, 1, 0.10009617137820083`], 
     Hue[0.649727552592175, 1, 0.10037723487237314`], 
     Hue[0.6491668432411204, 1, 0.10115360166614108`], 
     Hue[0.647941631429142, 1, 0.10285004879041884`], 
     Hue[0.6455643340646423, 1, 0.1061416912951107], 
     Hue[0.639972477261512, 1, 0.1138842622532912], 
     Hue[0.6222053065374926, 1, 0.13848496017885642`], 
     Hue[0.5717905289829407, 1, 0.20829003679285135`], 
     Hue[0.47393025290686036`, 1, 0.34378888059050106`], 
     Hue[0.350516590379209, 1, 0.5146693363980183], 
     Hue[0.24717815546080268`, 1, 0.6577533232081193], 
     Hue[0.192019443012804, 1, 0.7341269250591944], 
     Hue[0.19203201182186103`, 1, 0.7341095220928078], 
     Hue[0.2472070239801022, 1, 0.6577133514121661], 
     Hue[0.35054863766858774`, 1, 0.5146249632281092], 
     Hue[0.47395746658837945`, 1, 0.3437512001083977], 
     Hue[0.571807122802092, 1, 0.2082670607355649], 
     Hue[0.6222118250052738, 1, 0.13847593460808238`], 
     Hue[0.6399739959563222, 1, 0.11388215944509239`], 
     Hue[0.6455640968390548, 1, 0.10614201976130883`], 
     Hue[0.647940714362772, 1, 0.10285131857462335`], 
     Hue[0.6491658641833358, 1, 0.10115495728461198`], 
     Hue[0.6497269063824556, 1, 0.10037812962429228`], 
     Hue[0.6499302554975777, 1, 0.10009656931104641`], 
     Hue[0.6499864629461425, 1, 0.10001874361303353`], 
     Hue[0.6499980549290366, 1, 0.10000269317518012`], 
     Hue[0.6499998007707878, 1, 0.10000027585583228`], 
     Hue[0.6499999729662879, 1, 0.10000003743129375`], 
     Hue[0.6499996593138839, 1, 0.1000004717192377], 
     Hue[0.64999697736963, 1, 0.10000418518051228`], 
     Hue[0.6499799856500063, 1, 0.10002771217691438`], 
     Hue[0.6498986949687512, 1, 0.10014026850480605`], 
     Hue[0.6495970754140672, 1, 0.10055789558052244`], 
     Hue[0.6486847327741864, 1, 0.10182113923574201`], 
     Hue[0.646118851728098, 1, 0.1053738976072489], 
     Hue[0.6378190830503302, 1, 0.11686588500723522`], 
     Hue[0.609049141199, 1, 0.1567011891090769], 
     Hue[0.5317029461799629, 1, 0.26379592067389745`], 
     Hue[0.3965448698520418, 1, 0.45093787251255757`], 
     Hue[0.24717815546023186`, 1, 0.6577533232089097], 
     Hue[0.13586707405626453`, 1, 0.8118763589990183], 
     Hue[0.07851354847794556, 1, 0.8912889328766908], 
     Hue[0.07853633966851448, 1, 0.8912573758435953], 
     Hue[0.13590944914320868`, 1, 0.8118176858017111], 
     Hue[0.24720702397992556`, 1, 0.6577133514124108], 
     Hue[0.3965589856317552, 1, 0.4509183275868006], 
     Hue[0.5317100440208999, 1, 0.2637860928941386], 
     Hue[0.6090518863181518, 1, 0.15669738817486675`], 
     Hue[0.6378192495715569, 1, 0.11686565443938277`], 
     Hue[0.6461179406811218, 1, 0.10537515905690827`], 
     Hue[0.6486836471561027, 1, 0.10182264239924246`], 
     Hue[0.6495963220340547, 1, 0.10055893872207818`], 
     Hue[0.6498983451179356, 1, 0.10014075291362756`], 
     Hue[0.6499798727551617, 1, 0.10002786849285314`], 
     Hue[0.6499969516884851, 1, 0.10000422073902054`], 
     Hue[0.649999655185399, 1, 0.10000047743560135`], 
     Hue[0.649999972502692, 1, 0.10000003807319564`], 
     Hue[0.6499999980637757, 1, 0.10000000268092593`], 
     Hue[0.6499999506826558, 1, 0.10000006828555356`], 
     Hue[0.6499994121848602, 1, 0.10000081389788582`], 
     Hue[0.6499948089502459, 1, 0.1000071876073519], 
     Hue[0.6499645086924554, 1, 0.1000491418104465], 
     Hue[0.649806878341268, 1, 0.1002673992197828], 
     Hue[0.649133071211094, 1, 0.10120036293848536`], 
     Hue[0.6465292695559209, 1, 0.10480562676872485`], 
     Hue[0.6363437737647146, 1, 0.11890862094116436`], 
     Hue[0.5998736460104778, 1, 0.16940572090856923`], 
     Hue[0.5054104508357453, 1, 0.3002009142274296], 
     Hue[0.35056830745625983`, 1, 0.5145977281374865], 
     Hue[0.1920194430115696, 1, 0.7341269250609037], 
     Hue[0.07851354847718961, 1, 0.8912889328777374], 
     Hue[0.016906005021812276`, 1, 0.9765916853544138], 
     Hue[0.016918907565830477`, 1, 0.9765738202934655], 
     Hue[0.07853633966586049, 1, 0.8912573758472702], 
     Hue[0.1920320118201158, 1, 0.7341095220952243], 
     Hue[0.35057138237145397`, 1, 0.5145934705626022], 
     Hue[0.5054110463257803, 1, 0.30020008970276585`], 
     Hue[0.5998738052395493, 1, 0.16940550043754726`], 
     Hue[0.6363435021483804, 1, 0.11890899702531947`], 
     Hue[0.6465287438946181, 1, 0.10480635460745186`], 
     Hue[0.649132595542316, 1, 0.10120102155679332`], 
     Hue[0.6498066105961676, 1, 0.10026776994376801`], 
     Hue[0.6499644084648015, 1, 0.10004928058719788`], 
     Hue[0.6499947831523833, 1, 0.10000722332746918`], 
     Hue[0.6499994075356613, 1, 0.10000082033523827`], 
     Hue[0.6499999500906315, 1, 0.10000006910527945`], 
     Hue[0.6499999980108732, 1, 0.10000000275417563`], 
     Hue[0.6499999980108732, 1, 0.10000000275417563`], 
     Hue[0.6499999500906315, 1, 0.10000006910527945`], 
     Hue[0.6499994075356613, 1, 0.10000082033523827`], 
     Hue[0.6499947831523833, 1, 0.1000072233274692], 
     Hue[0.6499644084648013, 1, 0.10004928058719831`], 
     Hue[0.6498066105961631, 1, 0.10026776994377418`], 
     Hue[0.6491325955422841, 1, 0.10120102155683748`], 
     Hue[0.6465287438944921, 1, 0.1048063546076263], 
     Hue[0.6363435021480459, 1, 0.11890899702578257`], 
     Hue[0.5998738052387229, 1, 0.16940550043869146`], 
     Hue[0.5054110463240795, 1, 0.3002000897051206], 
     Hue[0.3505713823697989, 1, 0.5145934705648939], 
     Hue[0.19203201182058266`, 1, 0.7341095220945779], 
     Hue[0.07853633966768225, 1, 0.8912573758447476], 
     Hue[0.016918907565741215`, 1, 0.9765738202935891], 
     Hue[0.016906005018723635`, 1, 0.9765916853586903], 
     Hue[0.07851354847341785, 1, 0.89128893288296], 
     Hue[0.19201944301049073`, 1, 0.7341269250623975], 
     Hue[0.35056830745800077`, 1, 0.5145977281350759], 
     Hue[0.5054104508375454, 1, 0.3002009142249371], 
     Hue[0.5998736460110626, 1, 0.1694057209077594], 
     Hue[0.6363437737646683, 1, 0.11890862094122849`], 
     Hue[0.6465292695558271, 1, 0.1048056267688548], 
     Hue[0.6491330712110641, 1, 0.10120036293852665`], 
     Hue[0.6498068783412636, 1, 0.10026739921978885`], 
     Hue[0.649964508692455, 1, 0.10004914181044693`], 
     Hue[0.6499948089502459, 1, 0.10000718760735192`], 
     Hue[0.6499994121848602, 1, 0.10000081389788582`], 
     Hue[0.6499999506826558, 1, 0.10000006828555356`], 
     Hue[0.6499999980637757, 1, 0.10000000268092593`], 
     Hue[0.649999972502692, 1, 0.10000003807319564`], 
     Hue[0.649999655185399, 1, 0.10000047743560135`], 
     Hue[0.6499969516884851, 1, 0.10000422073902053`], 
     Hue[0.6499798727551617, 1, 0.10002786849285311`], 
     Hue[0.6498983451179355, 1, 0.10014075291362773`], 
     Hue[0.6495963220340493, 1, 0.1005589387220857], 
     Hue[0.6486836471560531, 1, 0.10182264239931109`], 
     Hue[0.6461179406809142, 1, 0.10537515905719567`], 
     Hue[0.6378192495710786, 1, 0.11686565444004504`], 
     Hue[0.6090518863173231, 1, 0.1566973881760142], 
     Hue[0.5317100440194852, 1, 0.2637860928960975], 
     Hue[0.3965589856301587, 1, 0.45091832758901107`], 
     Hue[0.24720702397933064`, 1, 0.6577133514132345], 
     Hue[0.13590944914274938`, 1, 0.811817685802347], 
     Hue[0.07853633966592277, 1, 0.8912573758471839], 
     Hue[0.07851354847355607, 1, 0.8912889328827686], 
     Hue[0.13586707405281984`, 1, 0.8118763590037879], 
     Hue[0.24717815545988908`, 1, 0.6577533232093843], 
     Hue[0.3965448698539299, 1, 0.4509378725099432], 
     Hue[0.5317029461815325, 1, 0.26379592067172436`], 
     Hue[0.6090491411993084, 1, 0.15670118910864986`], 
     Hue[0.6378190830500777, 1, 0.11686588500758477`], 
     Hue[0.6461188517279151, 1, 0.10537389760750222`], 
     Hue[0.6486847327741383, 1, 0.10182113923580859`], 
     Hue[0.6495970754140618, 1, 0.10055789558052991`], 
     Hue[0.6498986949687511, 1, 0.10014026850480622`], 
     Hue[0.6499799856500064, 1, 0.10002771217691435`], 
     Hue[0.64999697736963, 1, 0.10000418518051228`], 
     Hue[0.6499996593138839, 1, 0.1000004717192377], 
     Hue[0.6499999729662879, 1, 0.10000003743129375`], 
     Hue[0.6499998007707878, 1, 0.10000027585583228`], 
     Hue[0.6499980549290366, 1, 0.10000269317518012`], 
     Hue[0.6499864629461425, 1, 0.10001874361303352`], 
     Hue[0.6499302554975778, 1, 0.10009656931104624`], 
     Hue[0.6497269063824568, 1, 0.10037812962429073`], 
     Hue[0.64916586418334, 1, 0.10115495728460613`], 
     Hue[0.6479407143627665, 1, 0.10285131857463113`], 
     Hue[0.6455640968389635, 1, 0.10614201976143513`], 
     Hue[0.6399739959560363, 1, 0.11388215944548823`], 
     Hue[0.6222118250047468, 1, 0.13847593460881222`], 
     Hue[0.5718071228012546, 1, 0.20826706073672444`], 
     Hue[0.47395746658748916`, 1, 0.34375120010963045`], 
     Hue[0.35054863766829164`, 1, 0.5146249632285194], 
     Hue[0.24720702397975558`, 1, 0.6577133514126461], 
     Hue[0.19203201182016771`, 1, 0.7341095220951525], 
     Hue[0.19201944301058688`, 1, 0.7341269250622643], 
     Hue[0.2471781554599206, 1, 0.6577533232093407], 
     Hue[0.3505165903801044, 1, 0.5146693363967786], 
     Hue[0.47393025290842367`, 1, 0.34378888058833645`], 
     Hue[0.5717905289838813, 1, 0.20829003679154906`], 
     Hue[0.6222053065376022, 1, 0.13848496017870468`], 
     Hue[0.6399724772613484, 1, 0.11388426225351767`], 
     Hue[0.645564334064564, 1, 0.10614169129521904`], 
     Hue[0.6479416314291371, 1, 0.10285004879042564`], 
     Hue[0.6491668432411246, 1, 0.10115360166613523`], 
     Hue[0.6497275525921761, 1, 0.10037723487237159`], 
     Hue[0.6499305428935218, 1, 0.10009617137820066`], 
     Hue[0.6499865511173065, 1, 0.1000186215298833], 
     Hue[0.6499980735657545, 1, 0.10000266737049385`], 
     Hue[0.6499998034253445, 1, 0.10000027218029237`], 
     Hue[0.6499990071984714, 1, 0.10000137464827052`], 
     Hue[0.6499918370195641, 1, 0.10001130258829587`], 
     Hue[0.6499538247815461, 1, 0.1000639349178593], 
     Hue[0.6498107930448382, 1, 0.10026197886099324`], 
     Hue[0.6494141593805526, 1, 0.10081116393461954`], 
     Hue[0.6485787775709229, 1, 0.10196784644026062`], 
     Hue[0.6471924667805575, 1, 0.10388735368845878`], 
     Hue[0.6452112044766597, 1, 0.10663063995539425`], 
     Hue[0.6419364029752817, 1, 0.11116498049576384`], 
     Hue[0.633285268294527, 1, 0.12314347466911642`], 
     Hue[0.6080965938094919, 1, 0.15802010087916515`], 
     Hue[0.5535455447131511, 1, 0.2335523227048677], 
     Hue[0.4739574665882697, 1, 0.34375120010854965`], 
     Hue[0.3965589856316865, 1, 0.45091832758689565`], 
     Hue[0.35057138237145447`, 1, 0.5145934705626015], 
     Hue[0.3505683074580232, 1, 0.5145977281350448], 
     Hue[0.3965448698539395, 1, 0.45093787250993], 
     Hue[0.4739302529084245, 1, 0.34378888058833534`], 
     Hue[0.5535172220453116, 1, 0.2335915387064916], 
     Hue[0.608079220663972, 1, 0.15804415600373106`], 
     Hue[0.633278454782362, 1, 0.12315290876288346`], 
     Hue[0.6419342693172857, 1, 0.11116793479145054`], 
     Hue[0.6452105445038205, 1, 0.10663155376394089`], 
     Hue[0.6471926206447316, 1, 0.10388714064575626`], 
     Hue[0.6485794863729036, 1, 0.10196686502213353`], 
     Hue[0.649414950365605, 1, 0.10081006872454687`], 
     Hue[0.6498113105300758, 1, 0.10026126234297196`], 
     Hue[0.6499540431582559, 1, 0.10006363255010721`], 
     Hue[0.6499918966134397, 1, 0.10001122007369896`], 
     Hue[0.6499990174111819, 1, 0.10000136050759434`], 
     Hue[0.6499966598024274, 1, 0.10000462488894667`], 
     Hue[0.6499754483540974, 1, 0.10003399458663449`], 
     Hue[0.6498812811242848, 1, 0.10016437998175964`], 
     Hue[0.6495991042255871, 1, 0.10055508645687948`], 
     Hue[0.648993357308976, 1, 0.10139381295680251`], 
     Hue[0.6480079461523002, 1, 0.10275822840450749`], 
     Hue[0.6467195342872655, 1, 0.1045421832945555], 
     Hue[0.6452381831863728, 1, 0.1065932848188684], 
     Hue[0.6433852867591614, 1, 0.10915883371808421`], 
     Hue[0.6397831112611403, 1, 0.11414646133072888`], 
     Hue[0.6301948999416069, 1, 0.12742244623469806`], 
     Hue[0.6080965938096965, 1, 0.15802010087888185`], 
     Hue[0.5718071228019954, 1, 0.20826706073569862`], 
     Hue[0.5317100440208316, 1, 0.2637860928942333], 
     Hue[0.5054110463257548, 1, 0.300200089702801], 
     Hue[0.5054104508375404, 1, 0.30020091422494405`], 
     Hue[0.5317029461815312, 1, 0.2637959206717261], 
     Hue[0.5717905289838803, 1, 0.2082900367915504], 
     Hue[0.6080792206639716, 1, 0.1580441560037317], 
     Hue[0.6301844468267296, 1, 0.1274369197783744], 
     Hue[0.6397787456596526, 1, 0.1141525060097118], 
     Hue[0.6433834721860744, 1, 0.10916134620389706`], 
     Hue[0.6452371269589603, 1, 0.10659474728759341`], 
     Hue[0.6467189588664743, 1, 0.1045429800310355], 
     Hue[0.6480080185451152, 1, 0.10275812816830196`], 
     Hue[0.648993951907433, 1, 0.10139298966663116`], 
     Hue[0.6495997554994433, 1, 0.10055418469307864`], 
     Hue[0.6498816573421482, 1, 0.10016385906471795`], 
     Hue[0.6499755737898713, 1, 0.10003382090633207`], 
     Hue[0.6499966840514407, 1, 0.10000459131338975`], 
     Hue[0.6499925622199799, 1, 0.1000102984646433], 
     Hue[0.6499487609293296, 1, 0.10007094640554366`], 
     Hue[0.6497759033253894, 1, 0.10031028770330705`], 
     Hue[0.6493411176280112, 1, 0.10091229866890768`], 
     Hue[0.6485955693237664, 1, 0.10194459632093891`], 
     Hue[0.647641497556902, 1, 0.10326561876736648`], 
     Hue[0.6466234011364024, 1, 0.1046752907342122], 
     Hue[0.6455902756764903, 1, 0.10610577214024428`], 
     Hue[0.6444538432672702, 1, 0.10767929393762596`], 
     Hue[0.6428668818449762, 1, 0.10987662513772525`], 
     Hue[0.6397831112611666, 1, 0.11414646133069248`], 
     Hue[0.633285268294681, 1, 0.1231434746689032], 
     Hue[0.6222118250052016, 1, 0.13847593460818255`], 
     Hue[0.6090518863180883, 1, 0.1566973881749547], 
     Hue[0.5998738052395204, 1, 0.16940550043758723`], 
     Hue[0.5998736460110543, 1, 0.16940572090777092`], 
     Hue[0.6090491411993062, 1, 0.15670118910865305`], 
     Hue[0.6222053065376013, 1, 0.13848496017870593`], 
     Hue[0.6332784547823616, 1, 0.12315290876288401`], 
     Hue[0.6397787456596524, 1, 0.11415250600971207`], 
     Hue[0.6428646294942048, 1, 0.109879743777255], 
     Hue[0.6444525596532982, 1, 0.10768107124927954`], 
     Hue[0.6455892681972842, 1, 0.10610716711145265`], 
     Hue[0.6466225588476566, 1, 0.10467645698016773`], 
     Hue[0.6476410815525707, 1, 0.10326619477336363`], 
     Hue[0.6485957628883883, 1, 0.10194432830838548`], 
     Hue[0.6493416527692056, 1, 0.1009115577041769], 
     Hue[0.649776314091313, 1, 0.1003097189504897], 
     Hue[0.6499489183734026, 1, 0.10007072840605792`], 
     Hue[0.6499925949688808, 1, 0.10001025312001115`], 
     Hue[0.6499886739785015, 1, 0.10001568218361342`], 
     Hue[0.6499246089762626, 1, 0.1001043875713287], 
     Hue[0.6496881578673747, 1, 0.10043178141440437`], 
     Hue[0.6491561566068836, 1, 0.10116839854431495`], 
     Hue[0.6483817334719172, 1, 0.10224067673119168`], 
     Hue[0.6475628209177056, 1, 0.10337455565240777`], 
     Hue[0.6468126895154237, 1, 0.10441319913249028`], 
     Hue[0.6460978666860392, 1, 0.10540295381933039`], 
     Hue[0.6453306991597177, 1, 0.10646518577885243`], 
     Hue[0.644453843267272, 1, 0.10767929393762347`], 
     Hue[0.643385286759181, 1, 0.10915883371805703`], 
     Hue[0.6419364029753845, 1, 0.11116498049562153`], 
     Hue[0.6399739959563322, 1, 0.11388215944507858`], 
     Hue[0.6378192495715385, 1, 0.1168656544394084], 
     Hue[0.6363435021483664, 1, 0.11890899702533884`], 
     Hue[0.6363437737646637, 1, 0.11890862094123503`], 
     Hue[0.6378190830500764, 1, 0.1168658850075865], 
     Hue[0.6399724772613479, 1, 0.11388426225351829`], 
     Hue[0.6419342693172855, 1, 0.11116793479145093`], 
     Hue[0.6433834721860742, 1, 0.10916134620389735`], 
     Hue[0.6444525596532981, 1, 0.10768107124927964`], 
     Hue[0.6453297342290546, 1, 0.1064665218366937], 
     Hue[0.6460970638205118, 1, 0.10540406547929135`], 
     Hue[0.6468120214679307, 1, 0.10441412412132668`], 
     Hue[0.647562318571634, 1, 0.10337525120850674`], 
     Hue[0.6483816036130577, 1, 0.10224085653576623`], 
     Hue[0.6491563829934826, 1, 0.10116808508594727`], 
     Hue[0.6496884070778484, 1, 0.10043143635374849`], 
     Hue[0.6499247160158208, 1, 0.10010423936270975`], 
     Hue[0.6499886974241673, 1, 0.10001564972038382`], 
     Hue[0.6499871792649814, 1, 0.10001775178694883`], 
     Hue[0.6499158353957267, 1, 0.10011653560591685`], 
     Hue[0.6496598197797228, 1, 0.10047101876653775`], 
     Hue[0.6491137403392347, 1, 0.10122712876105969`], 
     Hue[0.6483905107237508, 1, 0.10222852361326822`], 
     Hue[0.6477166871005474, 1, 0.10316151016847291`], 
     Hue[0.6471496978926512, 1, 0.10394657214863678`], 
     Hue[0.6466253190276147, 1, 0.10467263519253359`], 
     Hue[0.6460978666860392, 1, 0.10540295381933043`], 
     Hue[0.645590275676491, 1, 0.10610577214024328`], 
     Hue[0.6452381831863822, 1, 0.10659328481885547`], 
     Hue[0.6452112044767101, 1, 0.10663063995532446`], 
     Hue[0.6455640968391104, 1, 0.10614201976123169`], 
     Hue[0.6461179406811379, 1, 0.10537515905688595`], 
     Hue[0.6465287438946186, 1, 0.1048063546074513], 
     Hue[0.6465292695558261, 1, 0.10480562676885623`], 
     Hue[0.6461188517279146, 1, 0.10537389760750286`], 
     Hue[0.6455643340645638, 1, 0.10614169129521937`], 
     Hue[0.6452105445038203, 1, 0.10663155376394112`], 
     Hue[0.6452371269589602, 1, 0.10659474728759356`], 
     Hue[0.6455892681972842, 1, 0.10610716711145261`], 
     Hue[0.6460970638205119, 1, 0.10540406547929121`], 
     Hue[0.6466247658365464, 1, 0.10467340114939741`], 
     Hue[0.647149218571604, 1, 0.10394723582393292`], 
     Hue[0.6477162367776387, 1, 0.1031621336925004], 
     Hue[0.6483902795375448, 1, 0.10222884371724564`], 
     Hue[0.6491137171780913, 1, 0.10122716083033519`], 
     Hue[0.6496598500920083, 1, 0.10047097679568083`], 
     Hue[0.6499158508823387, 1, 0.10011651416291573`], 
     Hue[0.6499871827318622, 1, 0.10001774698665247`], 
     Hue[0.649988696060685, 1, 0.10001565160828231`], 
     Hue[0.6499253861002506, 1, 0.10010331155349914`], 
     Hue[0.6496958940624493, 1, 0.10042106975968562`], 
     Hue[0.649201321406682, 1, 0.10110586266767116`], 
     Hue[0.6485504399625567, 1, 0.1020070831287677], 
     Hue[0.6479788895815404, 1, 0.10279846057940567`], 
     Hue[0.6475405484301957, 1, 0.1034053944812675], 
     Hue[0.6471496978926513, 1, 0.10394657214863673`], 
     Hue[0.6468126895154237, 1, 0.10441319913249034`], 
     Hue[0.6466234011364024, 1, 0.1046752907342121], 
     Hue[0.646719534287268, 1, 0.10454218329455199`], 
     Hue[0.647192466780572, 1, 0.10388735368843882`], 
     Hue[0.6479407143628089, 1, 0.10285131857457236`], 
     Hue[0.6486836471561178, 1, 0.10182264239922159`], 
     Hue[0.6491325955423191, 1, 0.10120102155678898`], 
     Hue[0.6491330712110643, 1, 0.10120036293852638`], 
     Hue[0.6486847327741382, 1, 0.10182113923580877`], 
     Hue[0.647941631429137, 1, 0.10285004879042578`], 
     Hue[0.6471926206447316, 1, 0.1038871406457563], 
     Hue[0.6467189588664745, 1, 0.10454298003103545`], 
     Hue[0.6466225588476568, 1, 0.10467645698016752`], 
     Hue[0.6468120214679309, 1, 0.10441412412132642`], 
     Hue[0.6471492185716041, 1, 0.10394723582393277`], 
     Hue[0.6475401197544659, 1, 0.10340598803227799`], 
     Hue[0.6479786482228466, 1, 0.10279879476836637`], 
     Hue[0.6485502856265529, 1, 0.10200729682477296`], 
     Hue[0.6492010682900418, 1, 0.10110621313686532`], 
     Hue[0.6496956694759822, 1, 0.10042138072556303`], 
     Hue[0.6499252913219769, 1, 0.10010344278495513`], 
     Hue[0.6499886753209286, 1, 0.1000156803248681], 
     Hue[0.6499927167322246, 1, 0.10001008452461209`], 
     Hue[0.6499507186578939, 1, 0.10006823570445467`], 
     Hue[0.6497907590832415, 1, 0.10028971819243494`], 
     Hue[0.6494168902411381, 1, 0.10080738274303955`], 
     Hue[0.6488676434233366, 1, 0.10156787833691865`], 
     Hue[0.6483448000569576, 1, 0.10229181530575097`], 
     Hue[0.6479788895815404, 1, 0.10279846057940568`], 
     Hue[0.6477166871005474, 1, 0.10316151016847291`], 
     Hue[0.6475628209177055, 1, 0.10337455565240786`], 
     Hue[0.6476414975569019, 1, 0.10326561876736656`], 
     Hue[0.6480079461523006, 1, 0.10275822840450693`], 
     Hue[0.6485787775709253, 1, 0.10196784644025733`], 
     Hue[0.6491658641833469, 1, 0.1011549572845966], 
     Hue[0.6495963220340597, 1, 0.10055893872207124`], 
     Hue[0.6498066105961688, 1, 0.10026776994376628`], 
     Hue[0.6498068783412638, 1, 0.10026739921978865`], 
     Hue[0.6495970754140618, 1, 0.10055789558052994`], 
     Hue[0.6491668432411246, 1, 0.10115360166613523`], 
     Hue[0.6485794863729036, 1, 0.10196686502213344`], 
     Hue[0.6480080185451154, 1, 0.1027581281683018], 
     Hue[0.6476410815525709, 1, 0.1032661947733634], 
     Hue[0.6475623185716342, 1, 0.10337525120850653`], 
     Hue[0.6477162367776387, 1, 0.1031621336925003], 
     Hue[0.6479786482228466, 1, 0.1027987947683664], 
     Hue[0.6483447647008004, 1, 0.10229186426043022`], 
     Hue[0.6488673490985242, 1, 0.10156828586358195`], 
     Hue[0.6494162997265166, 1, 0.10080820037866929`], 
     Hue[0.6497903076682764, 1, 0.10029034322854048`], 
     Hue[0.6499505462683586, 1, 0.1000684743976574], 
     Hue[0.6499926810152515, 1, 0.10001013397888259`], 
     Hue[0.6499968893754299, 1, 0.10000430701863561`], 
     Hue[0.6499779704371008, 1, 0.10003050247170653`], 
     Hue[0.6498991064821327, 1, 0.10013969871704714`], 
     Hue[0.6496859288220751, 1, 0.10043486778481912`], 
     Hue[0.6493054326597033, 1, 0.1009617086250262], 
     Hue[0.6488676434233366, 1, 0.10156787833691865`], 
     Hue[0.6485504399625566, 1, 0.10200708312876779`], 
     Hue[0.6483905107237506, 1, 0.1022285236132684], 
     Hue[0.648381733471917, 1, 0.10224067673119189`], 
     Hue[0.6485955693237663, 1, 0.10194459632093905`], 
     Hue[0.648993357308976, 1, 0.10139381295680246`], 
     Hue[0.6494141593805528, 1, 0.10081116393461917`], 
     Hue[0.6497269063824574, 1, 0.1003781296242898], 
     Hue[0.6498983451179365, 1, 0.1001407529136264], 
     Hue[0.6499644084648017, 1, 0.10004928058719757`], 
     Hue[0.649964508692455, 1, 0.10004914181044688`], 
     Hue[0.6498986949687511, 1, 0.1001402685048062], 
     Hue[0.6497275525921762, 1, 0.10037723487237155`], 
     Hue[0.6494149503656051, 1, 0.10081006872454676`], 
     Hue[0.6489939519074331, 1, 0.101392989666631], 
     Hue[0.6485957628883884, 1, 0.10194432830838535`], 
     Hue[0.6483816036130579, 1, 0.10224085653576616`], 
     Hue[0.6483902795375448, 1, 0.10222884371724568`], 
     Hue[0.6485502856265528, 1, 0.10200729682477307`], 
     Hue[0.6488673490985241, 1, 0.10156828586358203`], 
     Hue[0.6493047777680847, 1, 0.10096261539803657`], 
     Hue[0.6496852145273001, 1, 0.1004358568083538], 
     Hue[0.6498986870713849, 1, 0.100140279439621], 
     Hue[0.6499778300417067, 1, 0.10003069686532914`], 
     Hue[0.6499968622093047, 1, 0.10000434463327044`], 
     Hue[0.6499991646891583, 1, 0.10000115658424233`], 
     Hue[0.6499936165544795, 1, 0.1000088386168745], 
     Hue[0.6499670218094749, 1, 0.100045662109958], 
     Hue[0.6498796003047549, 1, 0.10016670727033941`], 
     Hue[0.6496859288220751, 1, 0.1004348677848191], 
     Hue[0.6494168902411381, 1, 0.1008073827430395], 
     Hue[0.649201321406682, 1, 0.10110586266767124`], 
     Hue[0.6491137403392345, 1, 0.10122712876105991`], 
     Hue[0.6491561566068835, 1, 0.10116839854431522`], 
     Hue[0.649341117628011, 1, 0.10091229866890786`], 
     Hue[0.6495991042255871, 1, 0.10055508645687952`], 
     Hue[0.6498107930448382, 1, 0.10026197886099321`], 
     Hue[0.6499302554975778, 1, 0.10009656931104617`], 
     Hue[0.6499798727551618, 1, 0.10002786849285303`], 
     Hue[0.6499947831523835, 1, 0.10000722332746916`], 
     Hue[0.6499948089502459, 1, 0.10000718760735192`], 
     Hue[0.6499799856500064, 1, 0.10002771217691434`], 
     Hue[0.6499305428935218, 1, 0.10009617137820065`], 
     Hue[0.6498113105300759, 1, 0.10026126234297192`], 
     Hue[0.6495997554994433, 1, 0.10055418469307857`], 
     Hue[0.6493416527692056, 1, 0.10091155770417684`], 
     Hue[0.6491563829934826, 1, 0.10116808508594727`], 
     Hue[0.6491137171780912, 1, 0.10122716083033526`], 
     Hue[0.6492010682900416, 1, 0.10110621313686542`], 
     Hue[0.6494162997265166, 1, 0.10080820037866937`], 
     Hue[0.6496852145273, 1, 0.10043585680835385`], 
     Hue[0.6498791017831329, 1, 0.10016739753104674`], 
     Hue[0.649966803005242, 1, 0.10004596506966494`], 
     Hue[0.6499935549624519, 1, 0.10000892389814348`], 
     Hue[0.6499991538514573, 1, 0.1000011715902899], 
     Hue[0.6499998599977125, 1, 0.1000001938493212], 
     Hue[0.6499987823857478, 1, 0.1000016859274261], 
     Hue[0.6499925169058931, 1, 0.10001036120722495`], 
     Hue[0.6499670218094749, 1, 0.10004566210995798`], 
     Hue[0.6498991064821327, 1, 0.10013969871704712`], 
     Hue[0.6497907590832415, 1, 0.10028971819243492`], 
     Hue[0.6496958940624493, 1, 0.10042106975968565`], 
     Hue[0.6496598197797226, 1, 0.10047101876653788`], 
     Hue[0.6496881578673745, 1, 0.10043178141440456`], 
     Hue[0.6497759033253893, 1, 0.10031028770330719`], 
     Hue[0.6498812811242847, 1, 0.10016437998175969`], 
     Hue[0.6499538247815461, 1, 0.1000639349178593], 
     Hue[0.6499864629461425, 1, 0.1000187436130335], 
     Hue[0.6499969516884851, 1, 0.10000422073902053`], 
     Hue[0.6499994075356613, 1, 0.10000082033523827`], 
     Hue[0.6499994121848602, 1, 0.10000081389788582`], 
     Hue[0.64999697736963, 1, 0.10000418518051227`], 
     Hue[0.6499865511173065, 1, 0.1000186215298833], 
     Hue[0.6499540431582559, 1, 0.1000636325501072], 
     Hue[0.6498816573421482, 1, 0.10016385906471793`], 
     Hue[0.649776314091313, 1, 0.10030971895048969`], 
     Hue[0.6496884070778484, 1, 0.1004314363537485], 
     Hue[0.6496598500920083, 1, 0.10047097679568086`], 
     Hue[0.6496956694759822, 1, 0.10042138072556307`], 
     Hue[0.6497903076682763, 1, 0.10029034322854052`], 
     Hue[0.6498986870713849, 1, 0.10014027943962103`], 
     Hue[0.649966803005242, 1, 0.10004596506966494`], 
     Hue[0.6499924447114087, 1, 0.10001046116881876`], 
     Hue[0.6499987662030103, 1, 0.10000170833429346`], 
     Hue[0.6499998575374961, 1, 0.1000001972557747], 
     Hue[0.6499999856334239, 1, 0.10000001989218238`], 
     Hue[0.6499998396191935, 1, 0.1000002220657321], 
     Hue[0.6499987823857478, 1, 0.1000016859274261], 
     Hue[0.6499936165544795, 1, 0.10000883861687448`], 
     Hue[0.6499779704371008, 1, 0.10003050247170653`], 
     Hue[0.6499507186578939, 1, 0.10006823570445465`], 
     Hue[0.6499253861002506, 1, 0.10010331155349914`], 
     Hue[0.6499158353957267, 1, 0.10011653560591689`], 
     Hue[0.6499246089762626, 1, 0.10010438757132877`], 
     Hue[0.6499487609293295, 1, 0.10007094640554372`], 
     Hue[0.6499754483540974, 1, 0.1000339945866345], 
     Hue[0.6499918370195641, 1, 0.10001130258829588`], 
     Hue[0.6499980549290366, 1, 0.10000269317518012`], 
     Hue[0.649999655185399, 1, 0.10000047743560135`], 
     Hue[0.6499999500906315, 1, 0.10000006910527945`], 
     Hue[0.6499999506826558, 1, 0.10000006828555356`], 
     Hue[0.6499996593138839, 1, 0.1000004717192377], 
     Hue[0.6499980735657545, 1, 0.10000266737049385`], 
     Hue[0.6499918966134397, 1, 0.10001122007369896`], 
     Hue[0.6499755737898713, 1, 0.10003382090633207`], 
     Hue[0.6499489183734026, 1, 0.10007072840605792`], 
     Hue[0.6499247160158208, 1, 0.10010423936270976`], 
     Hue[0.6499158508823387, 1, 0.10011651416291573`], 
     Hue[0.6499252913219769, 1, 0.10010344278495513`], 
     Hue[0.6499505462683586, 1, 0.10006847439765741`], 
     Hue[0.6499778300417067, 1, 0.10003069686532914`], 
     Hue[0.6499935549624519, 1, 0.10000892389814348`], 
     Hue[0.6499987662030103, 1, 0.10000170833429346`], 
     Hue[0.6499998368066057, 1, 0.10000022596008445`], 
     Hue[0.6499999852880078, 1, 0.10000002037045079`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999856334239, 1, 0.10000001989218238`], 
     Hue[0.6499998599977125, 1, 0.1000001938493212], 
     Hue[0.6499991646891583, 1, 0.10000115658424232`], 
     Hue[0.6499968893754299, 1, 0.10000430701863561`], 
     Hue[0.6499927167322246, 1, 0.10001008452461209`], 
     Hue[0.649988696060685, 1, 0.10001565160828231`], 
     Hue[0.6499871792649814, 1, 0.10001775178694884`], 
     Hue[0.6499886739785015, 1, 0.10001568218361344`], 
     Hue[0.6499925622199799, 1, 0.10001029846464331`], 
     Hue[0.6499966598024274, 1, 0.10000462488894668`], 
     Hue[0.6499990071984713, 1, 0.10000137464827052`], 
     Hue[0.6499998007707878, 1, 0.10000027585583228`], 
     Hue[0.649999972502692, 1, 0.10000003807319564`], 
     Hue[0.6499999980108732, 1, 0.10000000275417563`], 
     Hue[0.6499999980637757, 1, 0.10000000268092593`], 
     Hue[0.6499999729662879, 1, 0.10000003743129375`], 
     Hue[0.6499998034253445, 1, 0.10000027218029237`], 
     Hue[0.6499990174111819, 1, 0.10000136050759434`], 
     Hue[0.6499966840514407, 1, 0.10000459131338975`], 
     Hue[0.6499925949688808, 1, 0.10001025312001115`], 
     Hue[0.6499886974241673, 1, 0.10001564972038382`], 
     Hue[0.6499871827318622, 1, 0.10001774698665247`], 
     Hue[0.6499886753209286, 1, 0.1000156803248681], 
     Hue[0.6499926810152515, 1, 0.10001013397888259`], 
     Hue[0.6499968622093047, 1, 0.10000434463327044`], 
     Hue[0.6499991538514573, 1, 0.1000011715902899], 
     Hue[0.6499998575374961, 1, 0.1000001972557747], 
     Hue[0.6499999852880078, 1, 0.10000002037045079`], 
     Hue[0.6499999999669532, 1, 0.10000000004575714`], 
     Hue[0.6499999849238686, 1, 0.10000002087464362`], 
     Hue[0.6499998410900942, 1, 0.10000022002910035`], 
     Hue[0.6499989027437987, 1, 0.1000015192778172], 
     Hue[0.6499950637214474, 1, 0.10000683484722672`], 
     Hue[0.6499858880248885, 1, 0.10001953965784668`], 
     Hue[0.6499738433200122, 1, 0.10003621694152162`], 
     Hue[0.6499736137013089, 1, 0.10003653487511074`], 
     Hue[0.6499852820270374, 1, 0.10002037873179444`], 
     Hue[0.6499944257549256, 1, 0.10000771818548765`], 
     Hue[0.6499985573975376, 1, 0.10000199744956326`], 
     Hue[0.6499999644133952, 1, 0.10000004927376044`], 
     Hue[0.649999963849577, 1, 0.10000005005443176`], 
     Hue[0.6499997310457263, 1, 0.1000003723982252], 
     Hue[0.6499985427449788, 1, 0.10000201773772166`], 
     Hue[0.6499943838807886, 1, 0.10000777616506201`], 
     Hue[0.6499852093278041, 1, 0.10002047939227127`], 
     Hue[0.6499735432029402, 1, 0.10003663248823666`], 
     Hue[0.6499739154396369, 1, 0.1000361170835797], 
     Hue[0.6499859694850614, 1, 0.1000194268668381], 
     Hue[0.6499951095696064, 1, 0.10000677136516045`], 
     Hue[0.6499999852765213, 1, 0.10000002038635529`], 
     Hue[0.6499998410900942, 1, 0.10000022002910035`], 
     Hue[0.6499987284592187, 1, 0.10000176059492807`], 
     Hue[0.6499926958443384, 1, 0.10001011344630079`], 
     Hue[0.6499709105190519, 1, 0.10004027774285126`], 
     Hue[0.6499228820634163, 1, 0.10010677868142358`], 
     Hue[0.6498632426034409, 1, 0.10018935639523571`], 
     Hue[0.6499166783476851, 1, 0.10011536844166691`], 
     Hue[0.6499995658652175, 1, 0.10000060110969894`], 
     Hue[0.6499975345136633, 1, 0.1000034137503124], 
     Hue[0.6499892148045759, 1, 0.10001493334751028`], 
     Hue[0.6499646928280673, 1, 0.10004888685344525`], 
     Hue[0.6499164076341196, 1, 0.10011574327583442`], 
     Hue[0.649859297955133, 1, 0.10019481821596973`], 
     Hue[0.6499231865672959, 1, 0.10010635706066737`], 
     Hue[0.6499989027437987, 1, 0.1000015192778172], 
     Hue[0.6499926958443384, 1, 0.10001011344630079`], 
     Hue[0.6499655474797963, 1, 0.1000477034895128], 
     Hue[0.649883813694463, 1, 0.10016087334612819`], 
     Hue[0.6497258842286484, 1, 0.10037954491417912`], 
     Hue[0.6495470248985343, 1, 0.10062719629433715`], 
     Hue[0.6499962208090388, 1, 0.10000523272594622`], 
     Hue[0.6499834211304725, 1, 0.10002295535780738`], 
     Hue[0.6499425936539298, 1, 0.10007948570994332`], 
     Hue[0.6498463773044624, 1, 0.10021270834766752`], 
     Hue[0.6496866431313959, 1, 0.10043387874114412`], 
     Hue[0.6499950637214474, 1, 0.10000683484722672`], 
     Hue[0.6499709105190519, 1, 0.10004027774285126`], 
     Hue[0.649883813694463, 1, 0.10016087334612818`], 
     Hue[0.6496719726032052, 1, 0.10045419178017752`], 
     Hue[0.6493325519861007, 1, 0.10092415878847594`], 
     Hue[0.6499750001267646, 1, 0.10003461520909523`], 
     Hue[0.6499160398116125, 1, 0.10011625256853653`], 
     Hue[0.6497718388043817, 1, 0.1003159155016253], 
     Hue[0.6495107697330291, 1, 0.10067739575426744`], 
     Hue[0.6499951095696064, 1, 0.10000677136516044`], 
     Hue[0.6499858880248885, 1, 0.10001953965784668`], 
     Hue[0.6499228820634163, 1, 0.10010677868142358`], 
     Hue[0.6497258842286484, 1, 0.10037954491417911`], 
     Hue[0.6493325519861007, 1, 0.10092415878847591`], 
     Hue[0.6498706375066201, 1, 0.10017911729852608`], 
     Hue[0.6496722119092209, 1, 0.1004538604333865], 
     Hue[0.6493021059490827, 1, 0.10096631483973172`], 
     Hue[0.6499231865672959, 1, 0.10010635706066733`], 
     Hue[0.6499859694850614, 1, 0.10001942686683808`], 
     Hue[0.6499738433200122, 1, 0.10003621694152162`], 
     Hue[0.6498632426034409, 1, 0.10018935639523571`], 
     Hue[0.6495470248985343, 1, 0.10062719629433713`], 
     Hue[0.647580489015451, 1, 0.1033500921324526], 
     Hue[0.6472836152052587, 1, 0.10376114817733419`], 
     Hue[0.6471229934816806, 1, 0.10398354748690382`], 
     Hue[0.6494582860502159, 1, 0.10075006546893182`], 
     Hue[0.6489836000327871, 1, 0.10140732303152564`], 
     Hue[0.6472221007030101, 1, 0.10384632210352455`], 
     Hue[0.6471236667804909, 1, 0.10398261522701252`], 
     Hue[0.6499739154396369, 1, 0.1000361170835797], 
     Hue[0.6475804890154508, 1, 0.10335009213245272`], 
     Hue[0.6471111373540478, 1, 0.10399996366362618`], 
     Hue[0.6466655980999736, 1, 0.10461686416926731`], 
     Hue[0.6462649933797092, 1, 0.10517154762809496`], 
     Hue[0.6460136181207266, 1, 0.10551960567899407`], 
     Hue[0.6460894082914638, 1, 0.10541466544258865`], 
     Hue[0.6460145578411789, 1, 0.1055183045275985], 
     Hue[0.6472836152052579, 1, 0.10376114817733527`], 
     Hue[0.6466655980999717, 1, 0.10461686416927002`], 
     Hue[0.6460502287342637, 1, 0.10546891406025037`], 
     Hue[0.6453869809034413, 1, 0.10638725721061978`], 
     Hue[0.6447122845415751, 1, 0.10732145217320362`], 
     Hue[0.6441102689755968, 1, 0.10815501218763528`], 
     Hue[0.6436464972274288, 1, 0.10879715768509854`], 
     Hue[0.6433361223092663, 1, 0.1092269075717851], 
     Hue[0.6433360175588242, 1, 0.1092270526108588], 
     Hue[0.6436473955325628, 1, 0.10879591387799005`], 
     Hue[0.6441116193627917, 1, 0.10815314242074998`], 
     Hue[0.6499736137013089, 1, 0.10003653487511074`], 
     Hue[0.6471229934816762, 1, 0.1039835474869099], 
     Hue[0.6462649933796968, 1, 0.10517154762811219`], 
     Hue[0.6453869809034246, 1, 0.10638725721064288`], 
     Hue[0.6443765815752575, 1, 0.1077862716650282], 
     Hue[0.6429887403224448, 1, 0.10970789801507655`], 
     Hue[0.6406162192000339, 1, 0.11299292726149159`], 
     Hue[0.6364545540009836, 1, 0.1187552329217151], 
     Hue[0.6305924039164738, 1, 0.12687205611565178`], 
     Hue[0.625034954606874, 1, 0.1345669859289438], 
     Hue[0.630594812444056, 1, 0.12686872123130705`], 
     Hue[0.6364584596844344, 1, 0.11874982505232165`], 
     Hue[0.6471236667804864, 1, 0.10398261522701893`], 
     Hue[0.649859297955133, 1, 0.10019481821596983`], 
     Hue[0.6499735432029402, 1, 0.10003663248823669`], 
     Hue[0.6499852820270374, 1, 0.10002037873179444`], 
     Hue[0.6499166783476851, 1, 0.10011536844166691`], 
     Hue[0.6460136181206872, 1, 0.10551960567904847`], 
     Hue[0.6447122845415196, 1, 0.10732145217328057`], 
     Hue[0.6429887403224135, 1, 0.10970789801511988`], 
     Hue[0.6394886467886375, 1, 0.11455418136957889`], 
     Hue[0.6310134115394466, 1, 0.12628912248384325`], 
     Hue[0.6140784301117376, 1, 0.14973755830682497`], 
     Hue[0.5901149258211708, 1, 0.18291779501684047`], 
     Hue[0.6460145578411413, 1, 0.10551830452765065`], 
     Hue[0.647222100702996, 1, 0.10384632210354394`], 
     Hue[0.6496866431313958, 1, 0.1004338787411443], 
     Hue[0.6499164076341196, 1, 0.10011574327583449`], 
     Hue[0.6499852093278041, 1, 0.10002047939227128`], 
     Hue[0.6499944257549256, 1, 0.10000771818548765`], 
     Hue[0.6441102689755097, 1, 0.10815501218775583`], 
     Hue[0.6406162192, 1, 0.1129929272615385], 
     Hue[0.6310134115394676, 1, 0.1262891224838142], 
     Hue[0.6058582780000794, 1, 0.1611193073845055], 
     Hue[0.5584199878537663, 1, 0.22680309374093893`], 
     Hue[0.4978115944517789, 1, 0.3107224076821523], 
     Hue[0.6441116193627406, 1, 0.1081531424208207], 
     Hue[0.646089408291409, 1, 0.10541466544266438`], 
     Hue[0.6495107697330285, 1, 0.10067739575426836`], 
     Hue[0.6498463773044623, 1, 0.10021270834766764`], 
     Hue[0.6499646928280673, 1, 0.10004888685344528`], 
     Hue[0.6499943838807886, 1, 0.10000777616506201`], 
     Hue[0.6499985573975376, 1, 0.10000199744956326`], 
     Hue[0.6436464972273616, 1, 0.10879715768519174`], 
     Hue[0.636454554000992, 1, 0.11875523292170333`], 
     Hue[0.6140784301118009, 1, 0.1497375583067373], 
     Hue[0.558419987853781, 1, 0.2268030937409187], 
     Hue[0.4653501926787307, 1, 0.35566896398329606`], 
     Hue[0.6364584596846764, 1, 0.11874982505198657`], 
     Hue[0.6436473955326357, 1, 0.10879591387788896`], 
     Hue[0.6493021059490783, 1, 0.10096631483973767`], 
     Hue[0.6497718388043812, 1, 0.10031591550162612`], 
     Hue[0.6499425936539298, 1, 0.10007948570994339`], 
     Hue[0.6499892148045759, 1, 0.1000149333475103], 
     Hue[0.6499985427449788, 1, 0.10000201773772166`], 
     Hue[0.6433361223092463, 1, 0.10922690757181291`], 
     Hue[0.6305924039165115, 1, 0.12687205611559949`], 
     Hue[0.5901149258212088, 1, 0.18291779501678784`], 
     Hue[0.49781159445165823`, 1, 0.31072240768231946`], 
     Hue[0.6305948124445969, 1, 0.1268687212305581], 
     Hue[0.6433360175591031, 1, 0.10922705261047262`], 
     Hue[0.6489836000327963, 1, 0.10140732303151286`], 
     Hue[0.6496722119092204, 1, 0.10045386043338717`], 
     Hue[0.6499160398116123, 1, 0.10011625256853683`], 
     Hue[0.6499834211304725, 1, 0.10002295535780742`], 
     Hue[0.6499975345136633, 1, 0.1000034137503124], 
     Hue[0.6499997310457263, 1, 0.1000003723982252], 
     Hue[0.6499999644133952, 1, 0.10000004927376044`], 
     Hue[0.6250349546068943, 1, 0.13456698592891564`], 
     Hue[0.6494582860502358, 1, 0.10075006546890423`], 
     Hue[0.6498706375066219, 1, 0.10017911729852358`], 
     Hue[0.6499750001267647, 1, 0.10003461520909515`], 
     Hue[0.6499962208090388, 1, 0.10000523272594623`], 
     Hue[0.6499995658652175, 1, 0.10000060110969894`], 
     Hue[0.649999963849577, 1, 0.10000005005443176`], 
     Hue[0., 1, 1.], 
     Hue[0.649999963849577, 1, 0.10000005005443176`], 
     Hue[0.6499995658652175, 1, 0.10000060110969894`], 
     Hue[0.6499962208090388, 1, 0.10000523272594622`], 
     Hue[0.6499750001267646, 1, 0.10003461520909523`], 
     Hue[0.6498706375066201, 1, 0.10017911729852609`], 
     Hue[0.6494582860502159, 1, 0.10075006546893184`], 
     Hue[0.6250349546069032, 1, 0.1345669859289033], 
     Hue[0.6499999644133952, 1, 0.10000004927376044`], 
     Hue[0.6499997310457263, 1, 0.1000003723982252], 
     Hue[0.6499975345136633, 1, 0.1000034137503124], 
     Hue[0.6499834211304725, 1, 0.10002295535780739`], 
     Hue[0.6499160398116125, 1, 0.10011625256853654`], 
     Hue[0.6496722119092209, 1, 0.1004538604333865], 
     Hue[0.6489836000327871, 1, 0.10140732303152555`], 
     Hue[0.6433360175588241, 1, 0.10922705261085894`], 
     Hue[0.6305948124440502, 1, 0.12686872123131515`], 
     Hue[0.49781159445338463`, 1, 0.310722407679929], 
     Hue[0.5901149258219073, 1, 0.18291779501582073`], 
     Hue[0.6305924039163933, 1, 0.12687205611576322`], 
     Hue[0.6433361223090291, 1, 0.10922690757211345`], 
     Hue[0.6499985427449788, 1, 0.10000201773772166`], 
     Hue[0.6499892148045759, 1, 0.10001493334751028`], 
     Hue[0.6499425936539298, 1, 0.10007948570994334`], 
     Hue[0.6497718388043817, 1, 0.10031591550162536`], 
     Hue[0.6493021059490827, 1, 0.1009663148397318], 
     Hue[0.6436473955325627, 1, 0.10879591387799013`], 
     Hue[0.6364584596844316, 1, 0.11874982505232544`], 
     Hue[0.46535019268013794`, 1, 0.3556689639813475], 
     Hue[0.5584199878547623, 1, 0.22680309373955995`], 
     Hue[0.6140784301120935, 1, 0.14973755830633206`], 
     Hue[0.6364545540009346, 1, 0.11875523292178278`], 
     Hue[0.6436464972273148, 1, 0.10879715768525641`], 
     Hue[0.6499985573975376, 1, 0.10000199744956326`], 
     Hue[0.6499943838807886, 1, 0.10000777616506201`], 
     Hue[0.6499646928280673, 1, 0.10004888685344525`], 
     Hue[0.6498463773044624, 1, 0.10021270834766756`], 
     Hue[0.649510769733029, 1, 0.10067739575426754`], 
     Hue[0.6460894082914639, 1, 0.10541466544258854`], 
     Hue[0.6441116193627918, 1, 0.10815314242074982`], 
     Hue[0.49781159445338496`, 1, 0.3107224076799285], 
     Hue[0.5584199878547618, 1, 0.22680309373956073`], 
     Hue[0.6058582780004875, 1, 0.16111930738394037`], 
     Hue[0.6310134115395549, 1, 0.12628912248369326`], 
     Hue[0.6406162192000211, 1, 0.11299292726150936`], 
     Hue[0.6441102689755677, 1, 0.10815501218767563`], 
     Hue[0.6499944257549256, 1, 0.10000771818548763`], 
     Hue[0.6499852093278041, 1, 0.10002047939227127`], 
     Hue[0.6499164076341196, 1, 0.10011574327583443`], 
     Hue[0.6496866431313959, 1, 0.10043387874114416`], 
     Hue[0.6472221007030099, 1, 0.10384632210352472`], 
     Hue[0.646014557841179, 1, 0.10551830452759829`], 
     Hue[0.5901149258219057, 1, 0.1829177950158229], 
     Hue[0.6140784301120928, 1, 0.14973755830633298`], 
     Hue[0.6310134115395546, 1, 0.12628912248369367`], 
     Hue[0.6394886467886615, 1, 0.11455418136954568`], 
     Hue[0.6429887403224473, 1, 0.109707898015073], 
     Hue[0.6447122845415725, 1, 0.10732145217320734`], 
     Hue[0.6460136181207251, 1, 0.10551960567899599`], 
     Hue[0.6499166783476851, 1, 0.10011536844166684`], 
     Hue[0.6499852820270374, 1, 0.10002037873179442`], 
     Hue[0.6499735432029402, 1, 0.10003663248823666`], 
     Hue[0.649859297955133, 1, 0.10019481821596973`], 
     Hue[0.6471236667804908, 1, 0.10398261522701273`], 
     Hue[0.6364584596846646, 1, 0.11874982505200281`], 
     Hue[0.6305948124445522, 1, 0.12686872123062018`], 
     Hue[0.6250349546068997, 1, 0.1345669859289081], 
     Hue[0.6305924039163923, 1, 0.12687205611576466`], 
     Hue[0.6364545540009342, 1, 0.1187552329217834], 
     Hue[0.6406162192000208, 1, 0.11299292726150978`], 
     Hue[0.6429887403224471, 1, 0.10970789801507319`], 
     Hue[0.6443765815752722, 1, 0.10778627166500773`], 
     Hue[0.6453869809034444, 1, 0.10638725721061551`], 
     Hue[0.6462649933797096, 1, 0.10517154762809447`], 
     Hue[0.6471229934816807, 1, 0.10398354748690375`], 
     Hue[0.6499736137013089, 1, 0.10003653487511072`], 
     Hue[0.6441116193628278, 1, 0.1081531424207001], 
     Hue[0.6436473955327029, 1, 0.10879591387779611`], 
     Hue[0.6433360175591226, 1, 0.10922705261044566`], 
     Hue[0.6433361223090287, 1, 0.10922690757211413`], 
     Hue[0.6436464972273146, 1, 0.10879715768525677`], 
     Hue[0.6441102689755674, 1, 0.10815501218767593`], 
     Hue[0.6447122845415724, 1, 0.10732145217320749`], 
     Hue[0.6453869809034444, 1, 0.10638725721061548`], 
     Hue[0.6460502287342674, 1, 0.10546891406024508`], 
     Hue[0.6466655980999738, 1, 0.10461686416926702`], 
     Hue[0.6472836152052586, 1, 0.10376114817733438`], 
     Hue[0.6460145578411807, 1, 0.10551830452759606`], 
     Hue[0.6460894082914773, 1, 0.10541466544256996`], 
     Hue[0.6460136181207252, 1, 0.10551960567899595`], 
     Hue[0.6462649933797097, 1, 0.10517154762809428`], 
     Hue[0.6466655980999739, 1, 0.10461686416926684`], 
     Hue[0.6471111373540477, 1, 0.10399996366362627`], 
     Hue[0.6475804890154506, 1, 0.10335009213245296`], 
     Hue[0.6499739154396369, 1, 0.1000361170835797], 
     Hue[0.6471236667804907, 1, 0.10398261522701283`], 
     Hue[0.6472221007030102, 1, 0.10384632210352437`], 
     Hue[0.648983600032812, 1, 0.10140732303149122`], 
     Hue[0.6494582860502409, 1, 0.10075006546889727`], 
     Hue[0.6471229934816808, 1, 0.10398354748690349`], 
     Hue[0.6472836152052587, 1, 0.10376114817733417`], 
     Hue[0.6475804890154507, 1, 0.1033500921324529], 
     Hue[0.6495470248985343, 1, 0.10062719629433717`], 
     Hue[0.6498632426034409, 1, 0.10018935639523573`], 
     Hue[0.6499738433200122, 1, 0.10003621694152162`], 
     Hue[0.6499859694850614, 1, 0.1000194268668381], 
     Hue[0.6499231865672959, 1, 0.10010635706066735`], 
     Hue[0.6493021059490841, 1, 0.10096631483972977`], 
     Hue[0.6496722119092239, 1, 0.10045386043338231`], 
     Hue[0.6498706375066231, 1, 0.1001791172985219], 
     Hue[0.6493325519861006, 1, 0.10092415878847606`], 
     Hue[0.6497258842286484, 1, 0.10037954491417919`], 
     Hue[0.6499228820634163, 1, 0.1001067786814236], 
     Hue[0.6499858880248885, 1, 0.10001953965784668`], 
     Hue[0.6499951095696064, 1, 0.10000677136516045`], 
     Hue[0.6495107697330291, 1, 0.10067739575426747`], 
     Hue[0.6497718388043818, 1, 0.10031591550162516`], 
     Hue[0.6499160398116127, 1, 0.10011625256853622`], 
     Hue[0.6499750001267648, 1, 0.10003461520909494`], 
     Hue[0.6493325519861006, 1, 0.10092415878847612`], 
     Hue[0.6496719726032051, 1, 0.10045419178017764`], 
     Hue[0.649883813694463, 1, 0.10016087334612823`], 
     Hue[0.6499709105190519, 1, 0.10004027774285129`], 
     Hue[0.6499950637214474, 1, 0.10000683484722674`], 
     Hue[0.6496866431313958, 1, 0.10043387874114428`], 
     Hue[0.6498463773044624, 1, 0.10021270834766757`], 
     Hue[0.6499425936539298, 1, 0.10007948570994332`], 
     Hue[0.6499834211304725, 1, 0.10002295535780736`], 
     Hue[0.6499962208090388, 1, 0.1000052327259462], 
     Hue[0.6495470248985342, 1, 0.10062719629433724`], 
     Hue[0.6497258842286484, 1, 0.10037954491417923`], 
     Hue[0.6498838136944629, 1, 0.10016087334612825`], 
     Hue[0.6499655474797963, 1, 0.10004770348951282`], 
     Hue[0.6499926958443384, 1, 0.10001011344630079`], 
     Hue[0.6499989027437987, 1, 0.1000015192778172], 
     Hue[0.6499231865672959, 1, 0.10010635706066733`], 
     Hue[0.6498592979551329, 1, 0.10019481821596984`], 
     Hue[0.6499164076341195, 1, 0.10011574327583449`], 
     Hue[0.6499646928280673, 1, 0.10004888685344526`], 
     Hue[0.6499892148045759, 1, 0.1000149333475103], 
     Hue[0.6499975345136633, 1, 0.1000034137503124], 
     Hue[0.6499995658652175, 1, 0.10000060110969894`], 
     Hue[0.6499166783476851, 1, 0.10011536844166684`], 
     Hue[0.6498632426034409, 1, 0.10018935639523575`], 
     Hue[0.6499228820634163, 1, 0.10010677868142362`], 
     Hue[0.6499709105190519, 1, 0.10004027774285129`], 
     Hue[0.6499926958443384, 1, 0.1000101134463008], 
     Hue[0.6499987284592187, 1, 0.10000176059492807`], 
     Hue[0.6499998410900942, 1, 0.10000022002910035`], 
     Hue[0.6499999852765213, 1, 0.10000002038635529`], 
     Hue[0.6499951095696064, 1, 0.10000677136516044`], 
     Hue[0.6499859694850614, 1, 0.10001942686683808`], 
     Hue[0.6499739154396369, 1, 0.1000361170835797], 
     Hue[0.6499735432029402, 1, 0.10003663248823669`], 
     Hue[0.6499852093278041, 1, 0.10002047939227128`], 
     Hue[0.6499943838807886, 1, 0.10000777616506201`], 
     Hue[0.6499985427449788, 1, 0.10000201773772166`], 
     Hue[0.6499997310457263, 1, 0.1000003723982252], 
     Hue[0.649999963849577, 1, 0.10000005005443176`], 
     Hue[0.6499999644133952, 1, 0.10000004927376044`], 
     Hue[0.6499985573975376, 1, 0.10000199744956326`], 
     Hue[0.6499944257549256, 1, 0.10000771818548763`], 
     Hue[0.6499852820270374, 1, 0.10002037873179442`], 
     Hue[0.6499736137013089, 1, 0.10003653487511072`], 
     Hue[0.6499738433200122, 1, 0.10003621694152164`], 
     Hue[0.6499858880248885, 1, 0.10001953965784668`], 
     Hue[0.6499950637214474, 1, 0.10000683484722674`], 
     Hue[0.6499989027437987, 1, 0.1000015192778172], 
     Hue[0.6499998410900942, 1, 0.10000022002910035`], 
     Hue[0.6499999849238686, 1, 0.10000002087464362`], 
     Hue[0.6499999965856617, 1, 0.10000000472754546`], 
     Hue[0.6499999480469419, 1, 0.10000007193500345`], 
     Hue[0.6499999480469419, 1, 0.10000007193500345`], 
     Hue[0.6499999965856617, 1, 0.10000000472754546`], 
     Hue[0.6499999509486679, 1, 0.10000006791722911`], 
     Hue[0.6499995605902448, 1, 0.10000060841350733`], 
     Hue[0.6499995314220489, 1, 0.10000064880024004`], 
     Hue[0.6499975387906934, 1, 0.10000340782827066`], 
     Hue[0.6499970370468677, 1, 0.10000410255049084`], 
     Hue[0.649991166860452, 1, 0.10001223050091258`], 
     Hue[0.6499873787655159, 1, 0.10001747555543954`], 
     Hue[0.6499797890669986, 1, 0.10002798436877125`], 
     Hue[0.6499650867010297, 1, 0.10004834149088197`], 
     Hue[0.6499365186637519, 1, 0.10008789723480505`], 
     Hue[0.6499660419264217, 1, 0.10004701887110848`], 
     Hue[0.6499660352996491, 1, 0.10004702804663976`], 
     Hue[0.6499689720806963, 1, 0.10004296173442062`], 
     Hue[0.6499793572109922, 1, 0.10002858232324167`], 
     Hue[0.6499904847358855, 1, 0.10001317498108164`], 
     Hue[0.6499630030101804, 1, 0.10005122660128868`], 
     Hue[0.649997032693306, 1, 0.10000410857849946`], 
     Hue[0.6499997344623704, 1, 0.10000036766748721`], 
     Hue[0.6499999234519708, 1, 0.10000010598957898`], 
     Hue[0.6499999917956835, 1, 0.10000001135982291`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499999878784672, 1, 0.1000000167836607], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499999916279817, 1, 0.10000001159202533`], 
     Hue[0.6499998974223291, 1, 0.10000014203062124`], 
     Hue[0.6499998686930739, 1, 0.10000018180959001`], 
     Hue[0.6499999222917153, 1, 0.10000010759608655`], 
     Hue[0.6499993483460993, 1, 0.10000090229001642`], 
     Hue[0.6499991515859967, 1, 0.10000117472708145`], 
     Hue[0.6499970064878591, 1, 0.10000414486296436`], 
     Hue[0.6499958569645508, 1, 0.10000573651062201`], 
     Hue[0.6499904256749581, 1, 0.10001325675775032`], 
     Hue[0.6499852021769049, 1, 0.10002048929351634`], 
     Hue[0.6499792798726709, 1, 0.10002868940707105`], 
     Hue[0.6499628521968075, 1, 0.10005143541980506`], 
     Hue[0.6499353113077606, 1, 0.1000895689584853], 
     Hue[0.6499660027761931, 1, 0.10004707307911731`], 
     Hue[0.6499660613044453, 1, 0.10004699203999874`], 
     Hue[0.6499690957937134, 1, 0.10004279043947381`], 
     Hue[0.6499798735525514, 1, 0.100027867388775], 
     Hue[0.6499912329900899, 1, 0.10001213893679865`], 
     Hue[0.6499989171085051, 1, 0.10000149938822367`], 
     Hue[0.6499998438351633, 1, 0.10000021622823552`], 
     Hue[0.6499999966971565, 1, 0.10000000457316796`], 
     Hue[0.6499999966971565, 1, 0.10000000457316796`], 
     Hue[0.6499995314220489, 1, 0.10000064880024004`], 
     Hue[0.6499995605902448, 1, 0.10000060841350733`], 
     Hue[0.6499999509486679, 1, 0.10000006791722911`], 
     Hue[0.6499968197541345, 1, 0.10000440341735237`], 
     Hue[0.6499968197541345, 1, 0.10000440341735237`], 
     Hue[0.6499846921337001, 1, 0.10002119550718443`], 
     Hue[0.6499834669215924, 1, 0.10002289195471835`], 
     Hue[0.6499501069361, 1, 0.10006908270386163`], 
     Hue[0.6499391582420061, 1, 0.10008424243414546`], 
     Hue[0.6498923240356159, 1, 0.10014908979683958`], 
     Hue[0.6498470503888287, 1, 0.10021177638469872`], 
     Hue[0.6497372360371154, 1, 0.10036382702553248`], 
     Hue[0.6498246858302774, 1, 0.10024274269653898`], 
     Hue[0.6498595392714196, 1, 0.10019448408572672`], 
     Hue[0.6498872063550267, 1, 0.10015617581611685`], 
     Hue[0.6499648695962024, 1, 0.10004864209756598`], 
     Hue[0.6499892896045865, 1, 0.10001482977826487`], 
     Hue[0.6499995706076633, 1, 0.10000059454323541`], 
     Hue[0.6499998222703252, 1, 0.1000002460872421], 
     Hue[0.6499998205406813, 1, 0.10000024848213372`], 
     Hue[0.6499989347644688, 1, 0.1000014749415048], 
     Hue[0.649998672028374, 1, 0.10000183872994367`], 
     Hue[0.6499946619760952, 1, 0.10000739111002195`], 
     Hue[0.6499933666375028, 1, 0.10000918465576535`], 
     Hue[0.6499797258816096, 1, 0.100028071856233], 
     Hue[0.6499741382710061, 1, 0.10003580854783767`], 
     Hue[0.6499433111349449, 1, 0.10007849227469179`], 
     Hue[0.6499231631029164, 1, 0.10010638954980806`], 
     Hue[0.6498869310750488, 1, 0.10015655697300938`], 
     Hue[0.6498302874016713, 1, 0.10023498667460903`], 
     Hue[0.6495193091275062, 1, 0.10066557197729911`], 
     Hue[0.6498258485023254, 1, 0.10024113284293408`], 
     Hue[0.6498634903348335, 1, 0.10018901338253836`], 
     Hue[0.6498926261234818, 1, 0.10014867152133293`], 
     Hue[0.6499711016483095, 1, 0.10004001310234079`], 
     Hue[0.6499998438351633, 1, 0.10000021622823552`], 
     Hue[0.6499970370468677, 1, 0.10000410255049084`], 
     Hue[0.6499975387906934, 1, 0.10000340782827066`], 
     Hue[0.6499834669215924, 1, 0.10002289195471835`], 
     Hue[0.6499846921337001, 1, 0.10002119550718443`], 
     Hue[0.6499339441898728, 1, 0.10009146189094531`], 
     Hue[0.6499339441898728, 1, 0.10009146189094531`], 
     Hue[0.6498131704790807, 1, 0.10025868702896522`], 
     Hue[0.6497964648039245, 1, 0.10028181796379686`], 
     Hue[0.6495530687696348, 1, 0.10061882785742883`], 
     Hue[0.6494292804404583, 1, 0.1007902270824424], 
     Hue[0.6495197235700737, 1, 0.10066499813374416`], 
     Hue[0.6496872006198551, 1, 0.10043310683404684`], 
     Hue[0.6498468322258638, 1, 0.10021207845649631`], 
     Hue[0.6499962490896035, 1, 0.10000519356824138`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499751193911049, 1, 0.10003445007385486`], 
     Hue[0.6499981815209614, 1, 0.10000251789405334`], 
     Hue[0.649991888260414, 1, 0.10001123163942685`], 
     Hue[0.6499899581044661, 1, 0.10001390416304694`], 
     Hue[0.649968151589994, 1, 0.10004409779846983`], 
     Hue[0.6499613986682437, 1, 0.10005344799781657`], 
     Hue[0.6499029637901637, 1, 0.1001343578290042], 
     Hue[0.6498815309986415, 1, 0.100164034001881], 
     Hue[0.6497727314760293, 1, 0.10031467949472868`], 
     Hue[0.6497158718365242, 1, 0.10039340822635104`], 
     Hue[0.6491676275232411, 1, 0.10115251573705085`], 
     Hue[0.6494394618677293, 1, 0.10077612972160567`], 
     Hue[0.6495474566380963, 1, 0.1006265985010974], 
     Hue[0.6497265096835253, 1, 0.1003786788997342], 
     Hue[0.6498842956213006, 1, 0.10016020606281466`], 
     Hue[0.6499989171085051, 1, 0.10000149938822367`], 
     Hue[0.6499975662514333, 1, 0.10000336980570772`], 
     Hue[0.6499873787655159, 1, 0.10001747555543954`], 
     Hue[0.649991166860452, 1, 0.10001223050091258`], 
     Hue[0.6499391582420061, 1, 0.10008424243414546`], 
     Hue[0.6499501069361, 1, 0.10006908270386163`], 
     Hue[0.6497964648039245, 1, 0.10028181796379684`], 
     Hue[0.6498131704790807, 1, 0.10025868702896522`], 
     Hue[0.6495129010015269, 1, 0.10067444476711664`], 
     Hue[0.6495129010015269, 1, 0.10067444476711662`], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6498709896006915, 1, 0.100178629783658], 
     Hue[0.6499859604962616, 1, 0.1000194393128687], 
     Hue[0.6499533005675091, 1, 0.10006466075267968`], 
     Hue[0.649941462651146, 1, 0.1000810517137978], 
     Hue[0.6498573946453188, 1, 0.1001974535680202], 
     Hue[0.649828893698698, 1, 0.10023691641718743`], 
     Hue[0.6496559963280033, 1, 0.1004763127766109], 
     Hue[0.6495884346066919, 1, 0.10056985977534973`], 
     Hue[0.6488022469143933, 1, 0.10165842734930168`], 
     Hue[0.6487517211908194, 1, 0.10172838604348085`], 
     Hue[0.6488011994693257, 1, 0.10165987765785683`], 
     Hue[0.6489976573214437, 1, 0.10138785909338578`], 
     Hue[0.6493332016432399, 1, 0.10092325926320626`], 
     Hue[0.6498842956213006, 1, 0.10016020606281463`], 
     Hue[0.6497265096835254, 1, 0.10037867889973409`], 
     Hue[0.6499711016483095, 1, 0.10004001310234076`], 
     Hue[0.6499503668772793, 1, 0.10006872278530574`], 
     Hue[0.6499912329900899, 1, 0.10001213893679864`], 
     Hue[0.6499650867010297, 1, 0.10004834149088197`], 
     Hue[0.6499797890669986, 1, 0.10002798436877125`], 
     Hue[0.6498470503888287, 1, 0.10021177638469872`], 
     Hue[0.6498923240356159, 1, 0.10014908979683958`], 
     Hue[0.6495530687696348, 1, 0.10061882785742882`], 
     Hue[0.6499289484739935, 1, 0.10009837903600899`], 
     Hue[0.6494589962075535, 1, 0.10074908217415667`], 
     Hue[0.6499147887623509, 1, 0.10011798479059121`], 
     Hue[0.6497916794686949, 1, 0.10028844381257641`], 
     Hue[0.6497289407483949, 1, 0.1003753128099147], 
     Hue[0.6495085615470422, 1, 0.10068045324255707`], 
     Hue[0.6494073982064067, 1, 0.10082052556035999`], 
     Hue[0.6483053260376217, 1, 0.10234647164021618`], 
     Hue[0.6483163987955445, 1, 0.1023311401292462], 
     Hue[0.6480161564309219, 1, 0.10274686032641583`], 
     Hue[0.6479796182166929, 1, 0.10279745169996367`], 
     Hue[0.6481284893528518, 1, 0.10259132243451285`], 
     Hue[0.6483958281620501, 1, 0.1022211610063922], 
     Hue[0.64933320164324, 1, 0.10092325926320615`], 
     Hue[0.6489976573214438, 1, 0.10138785909338563`], 
     Hue[0.6495474566380964, 1, 0.1006265985010973], 
     Hue[0.6498634903348335, 1, 0.1001890133825383], 
     Hue[0.6499798735525514, 1, 0.10002786738877499`], 
     Hue[0.6499365186637519, 1, 0.10008789723480505`], 
     Hue[0.6497372360371154, 1, 0.10036382702553247`], 
     Hue[0.6489846669012644, 1, 0.10140584582901847`], 
     Hue[0.6473523532851713, 1, 0.10366597237437833`], 
     Hue[0.6496234965987956, 1, 0.10052131240166763`], 
     Hue[0.6480476331533843, 1, 0.1027032771722371], 
     Hue[0.6495819204902942, 1, 0.10057887932113115`], 
     Hue[0.6492559152561154, 1, 0.10103027118384031`], 
     Hue[0.6480467041527054, 1, 0.10270456348086947`], 
     Hue[0.6473513706733502, 1, 0.10366733291382275`], 
     Hue[0.6476433233638824, 1, 0.10326309072693203`], 
     Hue[0.6473931627551948, 1, 0.10360946695434578`], 
     Hue[0.647134233734633, 1, 0.10396798405973895`], 
     Hue[0.6472841430793683, 1, 0.10376041727472078`], 
     Hue[0.6475809298216182, 1, 0.10334948178545172`], 
     Hue[0.6483958281620502, 1, 0.10222116100639211`], 
     Hue[0.6481284893528518, 1, 0.10259132243451291`], 
     Hue[0.6488011994693256, 1, 0.10165987765785686`], 
     Hue[0.6494394618677293, 1, 0.10077612972160571`], 
     Hue[0.6498258485023254, 1, 0.10024113284293411`], 
     Hue[0.6499660613044453, 1, 0.10004699203999876`], 
     Hue[0.6499660419264217, 1, 0.10004701887110848`], 
     Hue[0.6465822717265688, 1, 0.1047322391478279], 
     Hue[0.6462861242777479, 1, 0.10514228946157993`], 
     Hue[0.6460011934807784, 1, 0.10553680902661455`], 
     Hue[0.6462658582790937, 1, 0.10517035007510118`], 
     Hue[0.6466661863103492, 1, 0.10461604972413183`], 
     Hue[0.6475809298216181, 1, 0.10334948178545186`], 
     Hue[0.6472841430793674, 1, 0.10376041727472206`], 
     Hue[0.6479796182166926, 1, 0.1027974516999641], 
     Hue[0.6487517211908193, 1, 0.10172838604348111`], 
     Hue[0.6499875583936996, 1, 0.10001722683949292`], 
     Hue[0.6499660352996491, 1, 0.10004702804663974`], 
     Hue[0.6499689720806963, 1, 0.10004296173442062`], 
     Hue[0.6499875752276579, 1, 0.10001720353093523`], 
     Hue[0.6498246858302774, 1, 0.10024274269653896`], 
     Hue[0.6498595392714196, 1, 0.1001944840857267], 
     Hue[0.6494292804404583, 1, 0.10079022708244238`], 
     Hue[0.6495197235700737, 1, 0.10066499813374416`], 
     Hue[0.6450459043341157, 1, 0.10685951707583985`], 
     Hue[0.6449078143256106, 1, 0.10705071862607762`], 
     Hue[0.644397187686445, 1, 0.1077577401264608], 
     Hue[0.6439515530904346, 1, 0.10837477264401368`], 
     Hue[0.6438587986192775, 1, 0.10850320191176961`], 
     Hue[0.6427201663461681, 1, 0.1100797696745365], 
     Hue[0.6434731972963169, 1, 0.10903711143586889`], 
     Hue[0.6410125786951648, 1, 0.11244412180669497`], 
     Hue[0.6388740031493004, 1, 0.11540522640866098`], 
     Hue[0.6431577560121023, 1, 0.10947387629093527`], 
     Hue[0.6432314603305186, 1, 0.10937182415774348`], 
     Hue[0.6434736200020822, 1, 0.10903652615096315`], 
     Hue[0.6438600147950488, 1, 0.10850151797608631`], 
     Hue[0.6447135116824771, 1, 0.10731975305503161`], 
     Hue[0.6453879602649294, 1, 0.10638590117163631`], 
     Hue[0.6466661863103472, 1, 0.1046160497241347], 
     Hue[0.646265858279081, 1, 0.10517035007511863`], 
     Hue[0.6471786129927855, 1, 0.10390653585614328`], 
     Hue[0.6480161564309208, 1, 0.10274686032641733`], 
     Hue[0.6499660027761931, 1, 0.10004707307911734`], 
     Hue[0.6499793572109922, 1, 0.10002858232324166`], 
     Hue[0.6498872063550267, 1, 0.10015617581611685`], 
     Hue[0.6496872006198551, 1, 0.10043310683404687`], 
     Hue[0.6449078143255991, 1, 0.10705071862609364`], 
     Hue[0.6450459043340817, 1, 0.10685951707588696`], 
     Hue[0.6437573464570181, 1, 0.10864367413643647`], 
     Hue[0.6437573464570021, 1, 0.10864367413645863`], 
     Hue[0.6419793946935759, 1, 0.11110545350120263`], 
     Hue[0.6416150548927508, 1, 0.11160992399465273`], 
     Hue[0.6387923231016593, 1, 0.11551832185924087`], 
     Hue[0.6370814322963922, 1, 0.1178872475896108], 
     Hue[0.6336566410847779, 1, 0.12262926619030753`], 
     Hue[0.6282683067128656, 1, 0.13009003685910922`], 
     Hue[0.6155545287377167, 1, 0.14769372944008474`], 
     Hue[0.6250352667022192, 1, 0.13456655379692734`], 
     Hue[0.6275873411445113, 1, 0.1310329122614459], 
     Hue[0.6336600539028828, 1, 0.1226245407498546], 
     Hue[0.6406195765724375, 1, 0.11298827859200967`], 
     Hue[0.6429908696471925, 1, 0.10970494971927194`], 
     Hue[0.6453879602649129, 1, 0.10638590117165914`], 
     Hue[0.6447135116824265, 1, 0.10731975305510176`], 
     Hue[0.6461108778787858, 1, 0.10538493832168114`], 
     Hue[0.6471342337346244, 1, 0.1039679840597509], 
     Hue[0.6483163987955415, 1, 0.10233114012925029`], 
     Hue[0.6495193091275061, 1, 0.10066557197729935`], 
     Hue[0.6497261232417286, 1, 0.10037921397299124`], 
     Hue[0.6499353113077606, 1, 0.10008956895848536`], 
     Hue[0.6498869310750488, 1, 0.10015655697300946`], 
     Hue[0.6499792798726709, 1, 0.10002868940707106`], 
     Hue[0.6499630030101804, 1, 0.10005122660128868`], 
     Hue[0.6499904847358855, 1, 0.10001317498108164`], 
     Hue[0.6499648695962024, 1, 0.10004864209756599`], 
     Hue[0.6498468322258637, 1, 0.10021207845649638`], 
     Hue[0.6439515530903862, 1, 0.1083747726440807], 
     Hue[0.6443971876863692, 1, 0.10775774012656568`], 
     Hue[0.6416150548927391, 1, 0.11160992399466907`], 
     Hue[0.6419793946935369, 1, 0.11110545350125665`], 
     Hue[0.6361335930405146, 1, 0.11919964040544136`], 
     Hue[0.6361335930405176, 1, 0.1191996404054371], 
     Hue[0.623696762682929, 1, 0.1364198670544061], 
     Hue[0.621035954087277, 1, 0.14010406357146268`], 
     Hue[0.6025635060503066, 1, 0.1656812993149601], 
     Hue[0.591356231466683, 1, 0.18119906412305425`], 
     Hue[0.5511449764429753, 1, 0.23687618646357272`], 
     Hue[0.55917054482559, 1, 0.22576386101072146`], 
     Hue[0.568122959888174, 1, 0.21336820938560533`], 
     Hue[0.5901231464870408, 1, 0.18290641255640516`], 
     Hue[0.6140905734391747, 1, 0.14972074446883504`], 
     Hue[0.6310228082209636, 1, 0.12627611169405048`], 
     Hue[0.6429908696471691, 1, 0.1097049497193044], 
     Hue[0.6406195765724637, 1, 0.11298827859197333`], 
     Hue[0.6443985210226438, 1, 0.10775589396864699`], 
     Hue[0.6460011934807279, 1, 0.10553680902668437`], 
     Hue[0.6476433233638594, 1, 0.10326309072696392`], 
     Hue[0.6491676275232406, 1, 0.10115251573705152`], 
     Hue[0.6494692059492381, 1, 0.1007349456087473], 
     Hue[0.6498302874016711, 1, 0.10023498667460914`], 
     Hue[0.6497727314760292, 1, 0.10031467949472883`], 
     Hue[0.6499628521968075, 1, 0.1000514354198051], 
     Hue[0.6499433111349449, 1, 0.10007849227469183`], 
     Hue[0.6499904256749581, 1, 0.10001325675775032`], 
     Hue[0.649997032693306, 1, 0.10000410857849946`], 
     Hue[0.6499892896045865, 1, 0.10001482977826487`], 
     Hue[0.6427201663461, 1, 0.11007976967463086`], 
     Hue[0.6438587986191934, 1, 0.1085032019118861], 
     Hue[0.6370814322963932, 1, 0.11788724758960933`], 
     Hue[0.6387923231016436, 1, 0.11551832185926283`], 
     Hue[0.6210359540872956, 1, 0.14010406357143684`], 
     Hue[0.6236967626829744, 1, 0.1364198670543432], 
     Hue[0.5848239391333233, 1, 0.19024377658462932`], 
     Hue[0.5848239391333415, 1, 0.19024377658460404`], 
     Hue[0.5284611999947693, 1, 0.2682844923149349], 
     Hue[0.5155200401453298, 1, 0.2862030213372357], 
     Hue[0.4280417126309771, 1, 0.4073268594340317], 
     Hue[0.44738231990342936`, 1, 0.3805475570567901], 
     Hue[0.49782834784076413`, 1, 0.31069921068201894`], 
     Hue[0.5584448138850497, 1, 0.22676871923608494`], 
     Hue[0.631022808221062, 1, 0.12627611169391412`], 
     Hue[0.6140905734395959, 1, 0.14972074446825182`], 
     Hue[0.6387961530918295, 1, 0.11551301879592843`], 
     Hue[0.6438600147950412, 1, 0.10850151797609685`], 
     Hue[0.646582271726557, 1, 0.1047322391478442], 
     Hue[0.6488022469143883, 1, 0.10165842734930862`], 
     Hue[0.6492111455095844, 1, 0.10109226006365249`], 
     Hue[0.649715871836524, 1, 0.10039340822635136`], 
     Hue[0.6496559963280025, 1, 0.10047631277661184`], 
     Hue[0.6499231631029164, 1, 0.10010638954980812`], 
     Hue[0.6499029637901635, 1, 0.10013435782900432`], 
     Hue[0.6499852021769049, 1, 0.10002048929351635`], 
     Hue[0.6499797258816095, 1, 0.10002807185623301`], 
     Hue[0.6499970064878591, 1, 0.10000414486296437`], 
     Hue[0.6499997344623704, 1, 0.10000036766748721`], 
     Hue[0.6410125786951287, 1, 0.11244412180674491`], 
     Hue[0.6434731972962738, 1, 0.10903711143592851`], 
     Hue[0.6282683067129132, 1, 0.13009003685904325`], 
     Hue[0.633656641084807, 1, 0.12262926619026732`], 
     Hue[0.591356231466732, 1, 0.18119906412298648`], 
     Hue[0.6025635060503691, 1, 0.16568129931487363`], 
     Hue[0.5155200401453158, 1, 0.28620302133725506`], 
     Hue[0.5284611999947402, 1, 0.26828449231497525`], 
     Hue[0.28735888634961493`, 1, 0.6021184650543793], 
     Hue[0.26072995684233446`, 1, 0.6389892905259984], 
     Hue[0.2873725448605462, 1, 0.602099553270013], 
     Hue[0.3624655433976934, 1, 0.4981246322185784], 
     Hue[0.5584448138855233, 1, 0.22676871923542932`], 
     Hue[0.4978283478418999, 1, 0.3106992106804463], 
     Hue[0.5901231464879024, 1, 0.18290641255521203`], 
     Hue[0.6336600539032805, 1, 0.12262454074930401`], 
     Hue[0.6434736200022606, 1, 0.10903652615071605`], 
     Hue[0.6483053260376065, 1, 0.10234647164023727`], 
     Hue[0.6488831338517029, 1, 0.10154643005148822`], 
     Hue[0.6495884346066901, 1, 0.1005698597753521], 
     Hue[0.6495085615470396, 1, 0.10068045324256061`], 
     Hue[0.6498815309986413, 1, 0.10016403400188124`], 
     Hue[0.6498573946453183, 1, 0.10019745356802079`], 
     Hue[0.6499741382710061, 1, 0.1000358085478377], 
     Hue[0.649968151589994, 1, 0.10004409779846989`], 
     Hue[0.6499958569645508, 1, 0.10000573651062203`], 
     Hue[0.6499946619760952, 1, 0.10000739111002195`], 
     Hue[0.6499993483460993, 1, 0.10000090229001643`], 
     Hue[0.6499999234519708, 1, 0.10000010598957898`], 
     Hue[0.6489846669012489, 1, 0.10140584582904005`], 
     Hue[0.6473523532851375, 1, 0.10366597237442497`], 
     Hue[0.6388740031493075, 1, 0.1154052264086511], 
     Hue[0.6155545287377708, 1, 0.14769372944000964`], 
     Hue[0.5511449764429537, 1, 0.2368761864636027], 
     Hue[0.2335219919339223, 1, 0.6766618573222615], 
     Hue[0.1499765696284696, 1, 0.7923401343605806], 
     Hue[0.14997656962768036`, 1, 0.7923401343616734], 
     Hue[0.12170305563956019`, 1, 0.8314880768067628], 
     Hue[0.06372301272420777, 1, 0.91176813622802], 
     Hue[0.15000883322846736`, 1, 0.7922954616836606], 
     Hue[0.2335584141616424, 1, 0.6766114265454182], 
     Hue[0.06375799796092974, 1, 0.9117196951310205], 
     Hue[0.1500088332269906, 1, 0.7922954616857053], 
     Hue[0.36246554339828446`, 1, 0.49812463221775993`], 
     Hue[0.28737254486065156`, 1, 0.6020995532698671], 
     Hue[0.44738231990483157`, 1, 0.38054755705484866`], 
     Hue[0.5681229598892839, 1, 0.21336820938406859`], 
     Hue[0.6250352667028372, 1, 0.13456655379607163`], 
     Hue[0.6431577560124171, 1, 0.10947387629049946`], 
     Hue[0.6473513706734314, 1, 0.10366733291371037`], 
     Hue[0.6483330201390716, 1, 0.10230812596128551`], 
     Hue[0.649407398206408, 1, 0.10082052556035821`], 
     Hue[0.6492559152561338, 1, 0.1010302711838148], 
     Hue[0.6498288936986976, 1, 0.10023691641718807`], 
     Hue[0.649791679468696, 1, 0.1002884438125748], 
     Hue[0.6499613986682435, 1, 0.10005344799781668`], 
     Hue[0.6499533005675091, 1, 0.10006466075267974`], 
     Hue[0.6499933666375028, 1, 0.10000918465576536`], 
     Hue[0.649991888260414, 1, 0.10001123163942686`], 
     Hue[0.6499991515859967, 1, 0.10000117472708145`], 
     Hue[0.6499989347644688, 1, 0.10000147494150481`], 
     Hue[0.6499999222917153, 1, 0.10000010759608655`], 
     Hue[0.6499998974223291, 1, 0.10000014203062124`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999917956835, 1, 0.10000001135982291`], 
     Hue[0.6499995706076633, 1, 0.10000059454323541`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499962490896035, 1, 0.10000519356824139`], 
     Hue[0.6499751193911047, 1, 0.10003445007385507`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6498709896006902, 1, 0.10017862978365968`], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.6494589962075485, 1, 0.10074908217416359`], 
     Hue[0.6499289484739933, 1, 0.10009837903600931`], 
     Hue[0.6480476331533758, 1, 0.10270327717224897`], 
     Hue[0.6496234965987948, 1, 0.10052131240166877`], 
     Hue[0.28735888634874723`, 1, 0.6021184650555808], 
     Hue[0.2607299568411386, 1, 0.6389892905276543], 
     Hue[0.10026584227806645`, 1, 0.8611703722303696], 
     Hue[0.12170305563831785`, 1, 0.8314880768084829], 
     Hue[0.03305932787493082, 1, 0.9542255460193266], 
     Hue[0.03305932787447774, 1, 0.9542255460199538], 
     Hue[0.04091504616611452, 1, 0.9433483976161491], 
     Hue[0.008564162898874406, 1, 0.9881419282938663], 
     Hue[0.1003038852266922, 1, 0.8611176973784263], 
     Hue[0.03305932787175336, 1, 0.9542255460237261], 
     Hue[0.12170305563598427`, 1, 0.831488076811714], 
     Hue[0.26072995684171757`, 1, 0.6389892905268526], 
     Hue[0.4280417126324545, 1, 0.4073268594319861], 
     Hue[0.5591705448267148, 1, 0.2257638610091642], 
     Hue[0.6480467041528128, 1, 0.10270456348072075`], 
     Hue[0.6489583372556369, 1, 0.10144230226142584`], 
     Hue[0.6497289407484016, 1, 0.10037531280990554`], 
     Hue[0.649623496598795, 1, 0.10052131240166845`], 
     Hue[0.6499414626511464, 1, 0.10008105171379728`], 
     Hue[0.6499289484739933, 1, 0.1000983790360093], 
     Hue[0.6499899581044661, 1, 0.10001390416304694`], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.649998672028374, 1, 0.10000183872994367`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499998686930739, 1, 0.10000018180959001`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499999916279817, 1, 0.10000001159202533`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499999878784672, 1, 0.1000000167836607], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499998205406813, 1, 0.10000024848213372`], 
     Hue[0.6499981815209614, 1, 0.10000251789405334`], 
     Hue[0.6499859604962616, 1, 0.10001943931286872`], 
     Hue[0.6499147887623508, 1, 0.10011798479059132`], 
     Hue[0.649581920490294, 1, 0.10057887932113145`], 
     Hue[0.5591705448254737, 1, 0.22576386101088267`], 
     Hue[0.568122959888075, 1, 0.21336820938574236`], 
     Hue[0.4280417126304372, 1, 0.4073268594347793], 
     Hue[0.44738231990300226`, 1, 0.3805475570573815], 
     Hue[0.2873725448596086, 1, 0.6020995532713111], 
     Hue[0.15000883322750808`, 1, 0.7922954616849889], 
     Hue[0.008564162898749728, 1, 0.9881419282940389], 
     Hue[0.0637579979606423, 1, 0.9117196951314183], 
     Hue[0.00856416289715567, 1, 0.988141928296246], 
     Hue[0.0330593278718706, 1, 0.9542255460235638], 
     Hue[0.0637230127197419, 1, 0.9117681362342035], 
     Hue[0.14997656962507233`, 1, 0.7923401343652845], 
     Hue[0.28735888634955103`, 1, 0.6021184650544679], 
     Hue[0.649458996207529, 1, 0.10074908217419068`], 
     Hue[0.6498709896006885, 1, 0.10017862978366218`], 
     Hue[0.6499751193911046, 1, 0.10003445007385516`], 
     Hue[0.6499962490896035, 1, 0.10000519356824138`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499995706076633, 1, 0.10000059454323541`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499999880630696, 1, 0.10000001652805754`], 
     Hue[0.6499998686930739, 1, 0.10000018180959001`], 
     Hue[0.6499998974223291, 1, 0.10000014203062124`], 
     Hue[0.6499999916279817, 1, 0.10000001159202533`], 
     Hue[0.649998672028374, 1, 0.10000183872994367`], 
     Hue[0.6499989347644688, 1, 0.1000014749415048], 
     Hue[0.6499899581044661, 1, 0.10001390416304694`], 
     Hue[0.649991888260414, 1, 0.10001123163942685`], 
     Hue[0.649941462651146, 1, 0.10008105171379782`], 
     Hue[0.6499533005675091, 1, 0.10006466075267968`], 
     Hue[0.6497289407483949, 1, 0.10037531280991473`], 
     Hue[0.6497916794686949, 1, 0.10028844381257641`], 
     Hue[0.6480467041527056, 1, 0.10270456348086918`], 
     Hue[0.6492559152561154, 1, 0.10103027118384024`], 
     Hue[0.6431577560121026, 1, 0.10947387629093487`], 
     Hue[0.6432314603305186, 1, 0.10937182415774356`], 
     Hue[0.6250352667022085, 1, 0.13456655379694196`], 
     Hue[0.6275873411445028, 1, 0.1310329122614577], 
     Hue[0.5901231464869925, 1, 0.18290641255647203`], 
     Hue[0.4978283478405595, 1, 0.3106992106823023], 
     Hue[0.3624655433972453, 1, 0.4981246322191988], 
     Hue[0.1003038852272069, 1, 0.8611176973777135], 
     Hue[0.23355841416119505`, 1, 0.6766114265460376], 
     Hue[0.040915046164483715`, 1, 0.9433483976184072], 
     Hue[0.15000883322690067`, 1, 0.7922954616858299], 
     Hue[0.040893852336497005`, 1, 0.9433777429186965], 
     Hue[0.10026584227413049`, 1, 0.8611703722358194], 
     Hue[0.14997656962515238`, 1, 0.7923401343651736], 
     Hue[0.23352199193288742`, 1, 0.6766618573236943], 
     Hue[0.6480476331532764, 1, 0.10270327717238656`], 
     Hue[0.6489591993613006, 1, 0.10144110857666067`], 
     Hue[0.6497294663699528, 1, 0.10037458502621935`], 
     Hue[0.6499416771509483, 1, 0.10008075471407167`], 
     Hue[0.6499900187740281, 1, 0.10001382015903812`], 
     Hue[0.6499999917956835, 1, 0.10000001135982291`], 
     Hue[0.6499991515859967, 1, 0.10000117472708145`], 
     Hue[0.6499993483460993, 1, 0.10000090229001642`], 
     Hue[0.6499999222917153, 1, 0.10000010759608655`], 
     Hue[0.6499933666375028, 1, 0.10000918465576535`], 
     Hue[0.6499946619760952, 1, 0.10000739111002195`], 
     Hue[0.6499613986682437, 1, 0.10005344799781657`], 
     Hue[0.649968151589994, 1, 0.10004409779846984`], 
     Hue[0.649828893698698, 1, 0.10023691641718745`], 
     Hue[0.6498573946453188, 1, 0.10019745356802023`], 
     Hue[0.6494073982064067, 1, 0.10082052556035996`], 
     Hue[0.6495085615470421, 1, 0.1006804532425571], 
     Hue[0.6473513706733505, 1, 0.1036673329138225], 
     Hue[0.6434736200020821, 1, 0.10903652615096326`], 
     Hue[0.633660053902879, 1, 0.12262454074985986`], 
     Hue[0.6140905734391554, 1, 0.14972074446886185`], 
     Hue[0.5584448138849759, 1, 0.2267687192361872], 
     Hue[0.18507857487504847`, 1, 0.7437373578653175], 
     Hue[0.12170305563612982`, 1, 0.8314880768115126], 
     Hue[0.1287910267796043, 1, 0.821673962920548], 
     Hue[0.18504088594804108`, 1, 0.7437895425334816], 
     Hue[0.5511449764442349, 1, 0.23687618646182867`], 
     Hue[0.5284611999960993, 1, 0.26828449231309326`], 
     Hue[0.6155545287379652, 1, 0.14769372943974055`], 
     Hue[0.6025635060508471, 1, 0.16568129931421172`], 
     Hue[0.6388740031490734, 1, 0.1154052264089754], 
     Hue[0.6336566410847063, 1, 0.12262926619040662`], 
     Hue[0.6434731972961383, 1, 0.10903711143611633`], 
     Hue[0.6473523532850615, 1, 0.10366597237453028`], 
     Hue[0.6489846669012399, 1, 0.10140584582905249`], 
     Hue[0.6499997344623704, 1, 0.10000036766748721`], 
     Hue[0.6499993557516623, 1, 0.10000089203615993`], 
     Hue[0.6499958569645508, 1, 0.10000573651062201`], 
     Hue[0.6499970064878591, 1, 0.10000414486296436`], 
     Hue[0.6499741382710061, 1, 0.10003580854783768`], 
     Hue[0.6499797258816096, 1, 0.100028071856233], 
     Hue[0.6498815309986415, 1, 0.10016403400188102`], 
     Hue[0.6499029637901637, 1, 0.10013435782900423`], 
     Hue[0.6495884346066918, 1, 0.1005698597753498], 
     Hue[0.6496559963280032, 1, 0.10047631277661098`], 
     Hue[0.6483053260376217, 1, 0.10234647164021617`], 
     Hue[0.6465822717265689, 1, 0.10473223914782774`], 
     Hue[0.6462861242777479, 1, 0.1051422894615798], 
     Hue[0.6438600147950487, 1, 0.10850151797608636`], 
     Hue[0.6406195765724355, 1, 0.1129882785920124], 
     Hue[0.6310228082209484, 1, 0.12627611169407155`], 
     Hue[0.3624655433981332, 1, 0.49812463221796943`], 
     Hue[0.2873725448606186, 1, 0.6020995532699127], 
     Hue[0.26072995684176997`, 1, 0.6389892905267801], 
     Hue[0.2873588863495887, 1, 0.6021184650544156], 
     Hue[0.5155200401465881, 1, 0.28620302133549336`], 
     Hue[0.5155200401465878, 1, 0.2862030213354939], 
     Hue[0.5913562314673553, 1, 0.1811990641221235], 
     Hue[0.584823939133998, 1, 0.19024377658369515`], 
     Hue[0.6282683067129716, 1, 0.1300900368589624], 
     Hue[0.6236967626831381, 1, 0.13641986705411643`], 
     Hue[0.6410125786950517, 1, 0.11244412180685161`], 
     Hue[0.6387923231016319, 1, 0.1155183218592789], 
     Hue[0.6438587986192152, 1, 0.1085032019118559], 
     Hue[0.6499892896045865, 1, 0.10001482977826487`], 
     Hue[0.6499648695962024, 1, 0.10004864209756596`], 
     Hue[0.649997032693306, 1, 0.10000410857849946`], 
     Hue[0.6499852021769049, 1, 0.10002048929351634`], 
     Hue[0.6499904256749581, 1, 0.10001325675775032`], 
     Hue[0.6499231631029164, 1, 0.10010638954980809`], 
     Hue[0.6499433111349449, 1, 0.10007849227469179`], 
     Hue[0.6497158718365242, 1, 0.1003934082263511], 
     Hue[0.6497727314760293, 1, 0.10031467949472872`], 
     Hue[0.6488022469143931, 1, 0.10165842734930183`], 
     Hue[0.6476433233638824, 1, 0.10326309072693211`], 
     Hue[0.6473931627551947, 1, 0.1036094669543459], 
     Hue[0.6460011934807786, 1, 0.10553680902661441`], 
     Hue[0.6447135116824785, 1, 0.1073197530550298], 
     Hue[0.6429908696471961, 1, 0.10970494971926699`], 
     Hue[0.5584448138854339, 1, 0.22676871923555317`], 
     Hue[0.4978283478418154, 1, 0.3106992106805634], 
     Hue[0.4473823199047938, 1, 0.38054755705490095`], 
     Hue[0.4280417126324526, 1, 0.40732685943198865`], 
     Hue[0.528461199996099, 1, 0.26828449231309376`], 
     Hue[0.5511449764442337, 1, 0.2368761864618304], 
     Hue[0.5848239391339978, 1, 0.1902437765836954], 
     Hue[0.5913562314673545, 1, 0.18119906412212453`], 
     Hue[0.6210359540875073, 1, 0.1401040635711437], 
     Hue[0.6210359540875072, 1, 0.1401040635711439], 
     Hue[0.6370814322964223, 1, 0.11788724758956906`], 
     Hue[0.636133593040564, 1, 0.11919964040537295`], 
     Hue[0.6427201663461387, 1, 0.11007976967457717`], 
     Hue[0.641979394693572, 1, 0.11110545350120805`], 
     Hue[0.6443971876864337, 1, 0.10775774012647635`], 
     Hue[0.6498468322258638, 1, 0.10021207845649628`], 
     Hue[0.6496872006198552, 1, 0.10043310683404671`], 
     Hue[0.6499435436197024, 1, 0.10007817037271977`], 
     Hue[0.6499904847358855, 1, 0.10001317498108163`], 
     Hue[0.6499628521968075, 1, 0.10005143541980507`], 
     Hue[0.6499792798726709, 1, 0.10002868940707105`], 
     Hue[0.6498302874016713, 1, 0.10023498667460905`], 
     Hue[0.6498869310750488, 1, 0.10015655697300938`], 
     Hue[0.649167627523241, 1, 0.10115251573705095`], 
     Hue[0.6483163987955443, 1, 0.10233114012924638`], 
     Hue[0.6480161564309218, 1, 0.10274686032641599`], 
     Hue[0.6471342337346329, 1, 0.10396798405973914`], 
     Hue[0.6462658582790939, 1, 0.10517035007510085`], 
     Hue[0.6453879602649326, 1, 0.10638590117163177`], 
     Hue[0.6310228082210256, 1, 0.12627611169396455`], 
     Hue[0.6140905734395123, 1, 0.14972074446836753`], 
     Hue[0.5901231464878142, 1, 0.18290641255533424`], 
     Hue[0.5681229598892343, 1, 0.21336820938413703`], 
     Hue[0.5591705448266987, 1, 0.22576386100918644`], 
     Hue[0.602563506050846, 1, 0.1656812993142133], 
     Hue[0.6155545287379638, 1, 0.14769372943974254`], 
     Hue[0.6236967626831377, 1, 0.13641986705411707`], 
     Hue[0.628268306712971, 1, 0.13009003685896328`], 
     Hue[0.6361335930405639, 1, 0.11919964040537312`], 
     Hue[0.6370814322964221, 1, 0.11788724758956945`], 
     Hue[0.6416150548927615, 1, 0.11160992399463798`], 
     Hue[0.6416150548927614, 1, 0.11160992399463811`], 
     Hue[0.6439515530904331, 1, 0.10837477264401578`], 
     Hue[0.643757346457027, 1, 0.10864367413642426`], 
     Hue[0.6450459043341169, 1, 0.10685951707583816`], 
     Hue[0.6495197235700738, 1, 0.10066499813374392`], 
     Hue[0.6499630030101804, 1, 0.10005122660128865`], 
     Hue[0.6498595392714197, 1, 0.10019448408572659`], 
     Hue[0.6499793572109922, 1, 0.10002858232324165`], 
     Hue[0.6499353113077606, 1, 0.1000895689584853], 
     Hue[0.6495193091275062, 1, 0.10066557197729913`], 
     Hue[0.6479796182166929, 1, 0.10279745169996372`], 
     Hue[0.6472841430793682, 1, 0.10376041727472092`], 
     Hue[0.6466661863103496, 1, 0.10461604972413144`], 
     Hue[0.6429908696472039, 1, 0.10970494971925615`], 
     Hue[0.6406195765724956, 1, 0.11298827859192927`], 
     Hue[0.6387961530918427, 1, 0.11551301879591018`], 
     Hue[0.6336600539032469, 1, 0.12262454074935054`], 
     Hue[0.6250352667028026, 1, 0.13456655379611943`], 
     Hue[0.6336566410847058, 1, 0.12262926619040751`], 
     Hue[0.6388740031490726, 1, 0.11540522640897635`], 
     Hue[0.6387923231016316, 1, 0.11551832185927938`], 
     Hue[0.6410125786950513, 1, 0.11244412180685208`], 
     Hue[0.6419793946935718, 1, 0.11110545350120836`], 
     Hue[0.6427201663461385, 1, 0.1100797696745775], 
     Hue[0.6437573464570269, 1, 0.10864367413642435`], 
     Hue[0.643951553090433, 1, 0.10837477264401599`], 
     Hue[0.644907814325618, 1, 0.10705071862606744`], 
     Hue[0.644907814325618, 1, 0.10705071862606746`], 
     Hue[0.6494292804404584, 1, 0.10079022708244216`], 
     Hue[0.6498246858302775, 1, 0.10024274269653886`], 
     Hue[0.6499660352996491, 1, 0.10004702804663972`], 
     Hue[0.6499660027761931, 1, 0.10004707307911731`], 
     Hue[0.6487517211908195, 1, 0.10172838604348083`], 
     Hue[0.6488011994693257, 1, 0.10165987765785672`], 
     Hue[0.6481284893528519, 1, 0.10259132243451279`], 
     Hue[0.6475809298216183, 1, 0.10334948178545168`], 
     Hue[0.6453879602649328, 1, 0.10638590117163146`], 
     Hue[0.6447135116824834, 1, 0.10731975305502306`], 
     Hue[0.6443985210227201, 1, 0.10775589396854145`], 
     Hue[0.6438600147951252, 1, 0.10850151797598054`], 
     Hue[0.6434736200023033, 1, 0.10903652615065697`], 
     Hue[0.6431577560124131, 1, 0.10947387629050494`], 
     Hue[0.6434731972961379, 1, 0.10903711143611679`], 
     Hue[0.643858798619215, 1, 0.10850320191185622`], 
     Hue[0.6443971876864336, 1, 0.1077577401264766], 
     Hue[0.6450459043341169, 1, 0.10685951707583821`], 
     Hue[0.6499875752276579, 1, 0.10001720353093521`], 
     Hue[0.6499660613044453, 1, 0.10004699203999874`], 
     Hue[0.6499690957937134, 1, 0.1000427904394738], 
     Hue[0.6499875583936996, 1, 0.10001722683949292`], 
     Hue[0.6498258485023254, 1, 0.10024113284293407`], 
     Hue[0.6498634903348335, 1, 0.10018901338253833`], 
     Hue[0.6494394618677293, 1, 0.1007761297216056], 
     Hue[0.6495474566380964, 1, 0.10062659850109733`], 
     Hue[0.6489976573214438, 1, 0.10138785909338563`], 
     Hue[0.6483958281620502, 1, 0.10222116100639206`], 
     Hue[0.6466661863103496, 1, 0.10461604972413144`], 
     Hue[0.6462658582790938, 1, 0.1051703500751009], 
     Hue[0.64611087787881, 1, 0.1053849383216477], 
     Hue[0.6460011934807838, 1, 0.10553680902660717`], 
     Hue[0.6465822717266224, 1, 0.10473223914775362`], 
     Hue[0.6473513706734652, 1, 0.1036673329136637], 
     Hue[0.6483330201390971, 1, 0.10230812596125023`], 
     Hue[0.6480467041528214, 1, 0.10270456348070894`], 
     Hue[0.6489583372556444, 1, 0.10144230226141537`], 
     Hue[0.6480476331532762, 1, 0.10270327717238693`], 
     Hue[0.649458996207529, 1, 0.10074908217419068`], 
     Hue[0.6473523532850612, 1, 0.10366597237453057`], 
     Hue[0.6489846669012398, 1, 0.10140584582905257`], 
     Hue[0.6499660419264217, 1, 0.10004701887110846`], 
     Hue[0.6499798735525514, 1, 0.100027867388775], 
     Hue[0.6498926261234819, 1, 0.10014867152133292`], 
     Hue[0.6497265096835254, 1, 0.10037867889973415`], 
     Hue[0.64933320164324, 1, 0.10092325926320618`], 
     Hue[0.6475809298216183, 1, 0.10334948178545166`], 
     Hue[0.6472841430793682, 1, 0.1037604172747209], 
     Hue[0.6471786129927874, 1, 0.10390653585614049`], 
     Hue[0.6471342337346329, 1, 0.1039679840597392], 
     Hue[0.6476433233638853, 1, 0.10326309072692814`], 
     Hue[0.6483053260376332, 1, 0.10234647164020018`], 
     Hue[0.6488831338517164, 1, 0.10154643005146977`], 
     Hue[0.6492559152561433, 1, 0.10103027118380156`], 
     Hue[0.649407398206416, 1, 0.10082052556034711`], 
     Hue[0.6496234965987958, 1, 0.10052131240166731`], 
     Hue[0.6497289407484043, 1, 0.10037531280990179`], 
     Hue[0.6495822971313279, 1, 0.10057835781816142`], 
     Hue[0.6498709896006885, 1, 0.10017862978366215`], 
     Hue[0.6497372360371154, 1, 0.1003638270255325], 
     Hue[0.6499365186637519, 1, 0.10008789723480506`], 
     Hue[0.6498923240356159, 1, 0.1001490897968396], 
     Hue[0.6499797890669986, 1, 0.10002798436877125`], 
     Hue[0.6499912329900899, 1, 0.10001213893679865`], 
     Hue[0.6499711016483095, 1, 0.10004001310234077`], 
     Hue[0.6498842956213006, 1, 0.10016020606281464`], 
     Hue[0.6483958281620502, 1, 0.10222116100639209`], 
     Hue[0.6481284893528518, 1, 0.10259132243451285`], 
     Hue[0.6479796182166928, 1, 0.10279745169996383`], 
     Hue[0.6480161564309217, 1, 0.10274686032641614`], 
     Hue[0.6483163987955443, 1, 0.10233114012924639`], 
     Hue[0.6488022469143936, 1, 0.10165842734930128`], 
     Hue[0.6492111455095863, 1, 0.10109226006364978`], 
     Hue[0.6495085615470444, 1, 0.10068045324255397`], 
     Hue[0.6495884346066922, 1, 0.10056985977534917`], 
     Hue[0.6497916794686982, 1, 0.10028844381257172`], 
     Hue[0.6498288936986989, 1, 0.10023691641718625`], 
     Hue[0.6499289484739935, 1, 0.10009837903600897`], 
     Hue[0.6499414626511469, 1, 0.10008105171379662`], 
     Hue[0.6499149607103801, 1, 0.10011774670870442`], 
     Hue[0.6499751193911046, 1, 0.10003445007385514`], 
     Hue[0.6495530687696347, 1, 0.10061882785742893`], 
     Hue[0.6495129010015268, 1, 0.10067444476711676`], 
     Hue[0.6498470503888287, 1, 0.10021177638469878`], 
     Hue[0.6498131704790806, 1, 0.10025868702896529`], 
     Hue[0.6499650867010297, 1, 0.10004834149088199`], 
     Hue[0.6499501069360999, 1, 0.10006908270386165`], 
     Hue[0.649991166860452, 1, 0.10001223050091258`], 
     Hue[0.6499989171085051, 1, 0.10000149938822367`], 
     Hue[0.64933320164324, 1, 0.10092325926320615`], 
     Hue[0.6489976573214437, 1, 0.10138785909338567`], 
     Hue[0.6488011994693256, 1, 0.10165987765785689`], 
     Hue[0.6487517211908193, 1, 0.1017283860434811], 
     Hue[0.649167627523241, 1, 0.10115251573705104`], 
     Hue[0.6494692059492382, 1, 0.10073494560874716`], 
     Hue[0.6496559963280033, 1, 0.10047631277661086`], 
     Hue[0.6497158718365242, 1, 0.1003934082263511], 
     Hue[0.6498573946453189, 1, 0.10019745356801998`], 
     Hue[0.6498815309986415, 1, 0.10016403400188097`], 
     Hue[0.6499533005675093, 1, 0.10006466075267935`], 
     Hue[0.6499613986682437, 1, 0.1000534479978165], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6499899581044661, 1, 0.10001390416304687`], 
     Hue[0.6499860137071367, 1, 0.10001936563627234`], 
     Hue[0.6499962490896035, 1, 0.10000519356824138`], 
     Hue[0.6495129010015268, 1, 0.10067444476711679`], 
     Hue[0.6495530687696347, 1, 0.10061882785742898`], 
     Hue[0.6497964648039245, 1, 0.10028181796379694`], 
     Hue[0.6497964648039245, 1, 0.10028181796379694`], 
     Hue[0.6499391582420061, 1, 0.10008424243414549`], 
     Hue[0.6499339441898728, 1, 0.10009146189094534`], 
     Hue[0.6499873787655159, 1, 0.10001747555543954`], 
     Hue[0.6499846921337001, 1, 0.10002119550718444`], 
     Hue[0.6499975387906934, 1, 0.10000340782827066`], 
     Hue[0.6498842956213006, 1, 0.10016020606281462`], 
     Hue[0.6497265096835254, 1, 0.1003786788997341], 
     Hue[0.6495474566380964, 1, 0.10062659850109733`], 
     Hue[0.6494394618677292, 1, 0.10077612972160574`], 
     Hue[0.6495193091275061, 1, 0.10066557197729935`], 
     Hue[0.6497261232417286, 1, 0.10037921397299124`], 
     Hue[0.6497727314760292, 1, 0.10031467949472878`], 
     Hue[0.6498302874016713, 1, 0.10023498667460914`], 
     Hue[0.6499029637901637, 1, 0.10013435782900423`], 
     Hue[0.6499231631029164, 1, 0.1001063895498081], 
     Hue[0.649968151589994, 1, 0.10004409779846982`], 
     Hue[0.6499741382710061, 1, 0.10003580854783767`], 
     Hue[0.649991888260414, 1, 0.10001123163942684`], 
     Hue[0.6499933666375028, 1, 0.10000918465576535`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.649998672028374, 1, 0.10000183872994367`], 
     Hue[0.6499981929645616, 1, 0.10000250204906862`], 
     Hue[0.6498468322258638, 1, 0.10021207845649625`], 
     Hue[0.6496872006198552, 1, 0.10043310683404669`], 
     Hue[0.6495197235700738, 1, 0.10066499813374391`], 
     Hue[0.6494292804404584, 1, 0.10079022708244217`], 
     Hue[0.6497372360371154, 1, 0.10036382702553254`], 
     Hue[0.6498131704790806, 1, 0.10025868702896532`], 
     Hue[0.6498470503888286, 1, 0.1002117763846988], 
     Hue[0.6499339441898728, 1, 0.10009146189094535`], 
     Hue[0.6499391582420061, 1, 0.1000842424341455], 
     Hue[0.6499834669215924, 1, 0.10002289195471836`], 
     Hue[0.6499834669215924, 1, 0.10002289195471836`], 
     Hue[0.6499970370468677, 1, 0.10000410255049084`], 
     Hue[0.6499968197541345, 1, 0.10000440341735237`], 
     Hue[0.6499995605902448, 1, 0.10000060841350733`], 
     Hue[0.6499998438351633, 1, 0.10000021622823552`], 
     Hue[0.6499711016483095, 1, 0.10004001310234076`], 
     Hue[0.6499503668772793, 1, 0.10006872278530574`], 
     Hue[0.6498634903348335, 1, 0.10018901338253831`], 
     Hue[0.6498258485023254, 1, 0.10024113284293411`], 
     Hue[0.6498869310750488, 1, 0.10015655697300946`], 
     Hue[0.6499353113077606, 1, 0.10008956895848536`], 
     Hue[0.6499433111349449, 1, 0.10007849227469183`], 
     Hue[0.6499628521968075, 1, 0.1000514354198051], 
     Hue[0.6499797258816096, 1, 0.10002807185623301`], 
     Hue[0.6499852021769049, 1, 0.10002048929351635`], 
     Hue[0.6499946619760952, 1, 0.10000739111002195`], 
     Hue[0.6499958569645508, 1, 0.10000573651062203`], 
     Hue[0.6499989347644688, 1, 0.1000014749415048], 
     Hue[0.6499991515859967, 1, 0.10000117472708145`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499998686930739, 1, 0.10000018180959001`], 
     Hue[0.6499995706076633, 1, 0.10000059454323541`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499892896045865, 1, 0.10001482977826487`], 
     Hue[0.6499648695962024, 1, 0.10004864209756596`], 
     Hue[0.6499435436197024, 1, 0.10007817037271975`], 
     Hue[0.6498595392714197, 1, 0.10019448408572659`], 
     Hue[0.6499630030101805, 1, 0.10005122660128864`], 
     Hue[0.6498246858302775, 1, 0.10024274269653886`], 
     Hue[0.6498923240356158, 1, 0.10014908979683962`], 
     Hue[0.6499365186637519, 1, 0.10008789723480506`], 
     Hue[0.6499501069360999, 1, 0.10006908270386165`], 
     Hue[0.6499650867010297, 1, 0.10004834149088199`], 
     Hue[0.6499846921337001, 1, 0.10002119550718444`], 
     Hue[0.6499873787655159, 1, 0.10001747555543954`], 
     Hue[0.6499968197541345, 1, 0.10000440341735237`], 
     Hue[0.6499970370468677, 1, 0.10000410255049084`], 
     Hue[0.6499995314220489, 1, 0.10000064880024004`], 
     Hue[0.6499995314220489, 1, 0.10000064880024004`], 
     Hue[0.6499999509486679, 1, 0.10000006791722911`], 
     Hue[0.6499999480469419, 1, 0.10000007193500345`], 
     Hue[0.6499999966971565, 1, 0.10000000457316796`], 
     Hue[0.6499999966971565, 1, 0.10000000457316796`], 
     Hue[0.6499998438351633, 1, 0.10000021622823552`], 
     Hue[0.6499989171085051, 1, 0.10000149938822367`], 
     Hue[0.6499975662514333, 1, 0.10000336980570772`], 
     Hue[0.6499912329900899, 1, 0.10001213893679864`], 
     Hue[0.6499798735525514, 1, 0.10002786738877499`], 
     Hue[0.6499660613044453, 1, 0.10004699203999876`], 
     Hue[0.6499875583936996, 1, 0.10001722683949292`], 
     Hue[0.6499660027761931, 1, 0.10004707307911734`], 
     Hue[0.6499792798726709, 1, 0.10002868940707108`], 
     Hue[0.6499904256749581, 1, 0.10001325675775033`], 
     Hue[0.6499970064878591, 1, 0.10000414486296437`], 
     Hue[0.6499993483460993, 1, 0.10000090229001643`], 
     Hue[0.6499998974223291, 1, 0.10000014203062124`], 
     Hue[0.6499999222917153, 1, 0.10000010759608655`], 
     Hue[0.6499999878784672, 1, 0.1000000167836607], 
     Hue[0.6499999916279817, 1, 0.10000001159202533`], 
     Hue[0.6499999880630696, 1, 0.10000001652805754`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499999917956835, 1, 0.10000001135982291`], 
     Hue[0.6499997344623704, 1, 0.10000036766748721`], 
     Hue[0.6499993557516623, 1, 0.10000089203615993`], 
     Hue[0.6499999234519708, 1, 0.10000010598957898`], 
     Hue[0.649997032693306, 1, 0.10000410857849946`], 
     Hue[0.6499904847358855, 1, 0.10001317498108163`], 
     Hue[0.6499793572109922, 1, 0.10002858232324165`], 
     Hue[0.6499660352996491, 1, 0.10004702804663973`], 
     Hue[0.6499875752276579, 1, 0.10001720353093521`], 
     Hue[0.6499660419264217, 1, 0.10004701887110846`], 
     Hue[0.6499797890669986, 1, 0.10002798436877126`], 
     Hue[0.649991166860452, 1, 0.1000122305009126], 
     Hue[0.6499975387906934, 1, 0.10000340782827066`], 
     Hue[0.6499995605902448, 1, 0.10000060841350733`], 
     Hue[0.6499999480469419, 1, 0.10000007193500345`], 
     Hue[0.6499999509486679, 1, 0.10000006791722911`], 
     Hue[0.6499999965856617, 1, 0.10000000472754546`], 
     Hue[0.6499999965856617, 1, 0.10000000472754546`], 
     Hue[0.6499875499410278, 1, 0.10001723854319232`], 
     Hue[0.6499875752276579, 1, 0.10001720353093523`], 
     Hue[0.6499993557516623, 1, 0.10000089203615993`], 
     Hue[0.6499999880630696, 1, 0.10000001652805754`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499875610519944, 1, 0.10001722315877695`], 
     Hue[0.6499875583936996, 1, 0.10001722683949292`], 
     Hue[0.6499975662514333, 1, 0.10000336980570773`], 
     Hue[0.6499999519224451, 1, 0.10000006656892216`], 
     Hue[0.6498378759096497, 1, 0.10022447950971584`], 
     Hue[0.6499435436197024, 1, 0.10007817037271981`], 
     Hue[0.6499798465258424, 1, 0.10002790481037209`], 
     Hue[0.6497261232417287, 1, 0.10037921397299106`], 
     Hue[0.6498403530877374, 1, 0.10022104957082523`], 
     Hue[0.6499503668772791, 1, 0.10006872278530578`], 
     Hue[0.6499999519224451, 1, 0.10000006656892216`], 
     Hue[0.6494616792468534, 1, 0.10074536719666463`], 
     Hue[0.6495984682510236, 1, 0.10055596703704421`], 
     Hue[0.6497732626026613, 1, 0.1003139440886228], 
     Hue[0.6499981929645616, 1, 0.10000250204906862`], 
     Hue[0.6499900187740281, 1, 0.10001382015903805`], 
     Hue[0.6494692059492383, 1, 0.10073494560874698`], 
     Hue[0.6494812112006415, 1, 0.10071832295295798`], 
     Hue[0.6496330749346824, 1, 0.10050805009043988`], 
     Hue[0.649813758879976, 1, 0.10025787232003332`], 
     Hue[0.6499860137071368, 1, 0.10001936563627217`], 
     Hue[0.6499416771509491, 1, 0.10008075471407049`], 
     Hue[0.6492111455095863, 1, 0.10109226006364984`], 
     Hue[0.648758555220787, 1, 0.10171892354044881`], 
     Hue[0.6488795947841098, 1, 0.10155133029892492`], 
     Hue[0.6491535472148489, 1, 0.10117201154867078`], 
     Hue[0.6498137588799761, 1, 0.10025787232003325`], 
     Hue[0.6499149607103819, 1, 0.10011774670870197`], 
     Hue[0.649729466369962, 1, 0.10037458502620653`], 
     Hue[0.648883133851712, 1, 0.10154643005147576`], 
     Hue[0.6481345467524913, 1, 0.10258293526578137`], 
     Hue[0.647966797245455, 1, 0.10281520381398546`], 
     Hue[0.6480385917352298, 1, 0.10271579605891265`], 
     Hue[0.6482450581235273, 1, 0.10242991952126995`], 
     Hue[0.649153547214849, 1, 0.10117201154867062`], 
     Hue[0.6496330749346825, 1, 0.10050805009043975`], 
     Hue[0.6498926261234819, 1, 0.10014867152133289`], 
     Hue[0.6483341237539456, 1, 0.10230659787915224`], 
     Hue[0.6495822971313424, 1, 0.10057835781814135`], 
     Hue[0.6489591993613566, 1, 0.10144110857658323`], 
     Hue[0.6489583372555867, 1, 0.10144230226149542`], 
     Hue[0.6483330201390396, 1, 0.10230812596132983`], 
     Hue[0.6471786129927877, 1, 0.10390653585614024`], 
     Hue[0.6474234415840103, 1, 0.10356754242213957`], 
     Hue[0.6482450581235273, 1, 0.10242991952126992`], 
     Hue[0.6488795947841098, 1, 0.10155133029892484`], 
     Hue[0.6494812112006415, 1, 0.10071832295295793`], 
     Hue[0.6498403530877374, 1, 0.10022104957082521`], 
     Hue[0.6499690957937134, 1, 0.1000427904394738], 
     Hue[0.6499875499410278, 1, 0.10001723854319232`], 
     Hue[0.6461108778788095, 1, 0.10538493832164841`], 
     Hue[0.6464564564606159, 1, 0.10490644490068565`], 
     Hue[0.64742344158401, 1, 0.10356754242214004`], 
     Hue[0.6480385917352296, 1, 0.10271579605891286`], 
     Hue[0.6487585552207868, 1, 0.10171892354044898`], 
     Hue[0.6498378759096497, 1, 0.10022447950971583`], 
     Hue[0.6494616792468534, 1, 0.10074536719666462`], 
     Hue[0.6443985210227051, 1, 0.1077558939685622], 
     Hue[0.6450470004719606, 1, 0.10685799934651607`], 
     Hue[0.6464564564606102, 1, 0.10490644490069351`], 
     Hue[0.6479667972454544, 1, 0.10281520381398628`], 
     Hue[0.6499875610519944, 1, 0.10001722315877697`], 
     Hue[0.6495984682510236, 1, 0.10055596703704424`], 
     Hue[0.6387961530917176, 1, 0.11551301879608337`], 
     Hue[0.6419821243866809, 1, 0.11110167392613411`], 
     Hue[0.6450470004719279, 1, 0.1068579993465614], 
     Hue[0.6481345467524894, 1, 0.10258293526578396`], 
     Hue[0.6499435436197024, 1, 0.10007817037271981`], 
     Hue[0.6497732626026613, 1, 0.10031394408862286`], 
     Hue[0.5614916278741021, 1, 0.22255005371278172`], 
     Hue[0.57812541033916, 1, 0.19951866260731693`], 
     Hue[0.6025745294274645, 1, 0.1656660361773569], 
     Hue[0.6237081735896381, 1, 0.13640406733742408`], 
     Hue[0.6419821243866659, 1, 0.11110167392615486`], 
     Hue[0.6473931627551752, 1, 0.10360946695437283`], 
     Hue[0.6499798465258424, 1, 0.1000279048103721], 
     Hue[0.43299533247763233`, 1, 0.40046800118481685`], 
     Hue[0.4697754323597277, 1, 0.34954170904037707`], 
     Hue[0.5284835431577712, 1, 0.2682535556277013], 
     Hue[0.623708173589869, 1, 0.1364040673371045], 
     Hue[0.6462861242777049, 1, 0.10514228946163941`], 
     Hue[0.6499993557516623, 1, 0.10000089203615993`], 
     Hue[0.2674438253340051, 1, 0.6296931649221468], 
     Hue[0.267450645458638, 1, 0.6296837216726551], 
     Hue[0.3196540147172407, 1, 0.5574021334684359], 
     Hue[0.5284835431585925, 1, 0.2682535556265643], 
     Hue[0.6025745294281106, 1, 0.1656660361764622], 
     Hue[0.6483341237539202, 1, 0.10230659787918744`], 
     Hue[0.18504088595038598`, 1, 0.7437895425302348], 
     Hue[0.18504088595001256`, 1, 0.7437895425307519], 
     Hue[0.12879102678331356`, 1, 0.8216739629154121], 
     Hue[0.10026584227849467`, 1, 0.8611703722297765], 
     Hue[0.12880990328898734`, 1, 0.8216478262152483], 
     Hue[0.18507857487579976`, 1, 0.7437373578642772], 
     Hue[0.10030388522786648`, 1, 0.8611176973768003], 
     Hue[0.1850785748753384, 1, 0.743737357864916], 
     Hue[0.31965401471773736`, 1, 0.5574021334677483], 
     Hue[0.46977543236106056`, 1, 0.34954170903853155`], 
     Hue[0.5781254103401833, 1, 0.1995186626059001], 
     Hue[0.627587341145137, 1, 0.13103291226057956`], 
     Hue[0.6432314603308535, 1, 0.10937182415727968`], 
     Hue[0.6499999880630696, 1, 0.10000001652805754`], 
     Hue[0.6499998222703252, 1, 0.1000002460872421], 
     Hue[0.6499900187740281, 1, 0.1000138201590381], 
     Hue[0.6499981929645616, 1, 0.10000250204906863`], 
     Hue[0.6499416771509486, 1, 0.10008075471407114`], 
     Hue[0.6499860137071367, 1, 0.10001936563627227`], 
     Hue[0.6497294663699593, 1, 0.10037458502621026`], 
     Hue[0.6499149607103814, 1, 0.10011774670870276`], 
     Hue[0.648959199361349, 1, 0.10144110857659368`], 
     Hue[0.6495822971313402, 1, 0.10057835781814445`], 
     Hue[0.267443825332904, 1, 0.6296931649236714], 
     Hue[0.12879102678220322`, 1, 0.8216739629169494], 
     Hue[0.04089385234061427, 1, 0.9433777429129957], 
     Hue[0.04089385234029075, 1, 0.9433777429134436], 
     Hue[0.040915046164482605`, 1, 0.9433483976184087], 
     Hue[0.12880990328631003`, 1, 0.8216478262189554], 
     Hue[0.26745064545827635`, 1, 0.6296837216731559], 
     Hue[0.432995332479051, 1, 0.40046800118285253`], 
     Hue[0.5614916278752367, 1, 0.22255005371121075`], 
     Hue[0.6495819204903069, 1, 0.10057887932111356`], 
     Hue[0.6499147887623521, 1, 0.10011798479058953`], 
     Hue[0.6499859604962616, 1, 0.10001943931286864`], 
     Hue[0.6499981815209614, 1, 0.10000251789405334`], 
     Hue[0.6499998205406813, 1, 0.10000024848213372`], 
     Hue[0.6499999878784672, 1, 0.1000000167836607], 
     Hue[0.5614916278739857, 1, 0.22255005371294295`], 
     Hue[0.43299533247711963`, 1, 0.4004680011855267], 
     Hue[0.26745064545750746`, 1, 0.6296837216742204], 
     Hue[0.12880990328781605`, 1, 0.8216478262168702], 
     Hue[0.04091504616570485, 1, 0.9433483976167164], 
     Hue[0.008564162897190197, 1, 0.9881419282961982], 
     Hue[0.0408938523364103, 1, 0.9433777429188165], 
     Hue[0.12879102677946985`, 1, 0.821673962920734], 
     Hue[0.26744382533350425`, 1, 0.6296931649228403], 
     Hue[0.6495822971313276, 1, 0.10057835781816173`], 
     Hue[0.6499149607103801, 1, 0.10011774670870452`], 
     Hue[0.6499860137071367, 1, 0.10001936563627235`], 
     Hue[0.6499981929645616, 1, 0.10000250204906863`], 
     Hue[0.6499998222703252, 1, 0.1000002460872421], 
     Hue[0.6489583372555867, 1, 0.10144230226149535`], 
     Hue[0.5781254103390867, 1, 0.19951866260741846`], 
     Hue[0.4697754323594143, 1, 0.34954170904081094`], 
     Hue[0.3196540147165537, 1, 0.5574021334693872], 
     Hue[0.18507857487510665`, 1, 0.743737357865237], 
     Hue[0.10030388522652434`, 1, 0.8611176973786585], 
     Hue[0.10026584227419488`, 1, 0.8611703722357301], 
     Hue[0.1850408859480107, 1, 0.7437895425335237], 
     Hue[0.6483330201390397, 1, 0.10230812596132967`], 
     Hue[0.6025745294274348, 1, 0.16566603617739795`], 
     Hue[0.5284835431576489, 1, 0.2682535556278708], 
     Hue[0.1288099032863832, 1, 0.821647826218854], 
     Hue[0.6483341237538894, 1, 0.1023065978792301], 
     Hue[0.6499999234519708, 1, 0.10000010598957898`], 
     Hue[0.6488831338517119, 1, 0.1015464300514758], 
     Hue[0.6387961530917151, 1, 0.11551301879608673`], 
     Hue[0.6237081735896223, 1, 0.1364040673374461], 
     Hue[0.319654014717638, 1, 0.5574021334678859], 
     Hue[0.2674506454582996, 1, 0.6296837216731236], 
     Hue[0.26744382533355726`, 1, 0.6296931649227668], 
     Hue[0.6499798465258424, 1, 0.10002790481037209`], 
     Hue[0.6492111455095861, 1, 0.10109226006364998`], 
     Hue[0.6443985210227057, 1, 0.10775589396856143`], 
     Hue[0.6419821243866807, 1, 0.11110167392613443`], 
     Hue[0.5284835431584985, 1, 0.2682535556266944], 
     Hue[0.46977543236099784`, 1, 0.3495417090386184], 
     Hue[0.43299533247903554`, 1, 0.40046800118287396`], 
     Hue[0.6497732626026613, 1, 0.10031394408862274`], 
     Hue[0.6494692059492383, 1, 0.10073494560874705`], 
     Hue[0.6481345467524912, 1, 0.10258293526578155`], 
     Hue[0.6461108778788097, 1, 0.10538493832164814`], 
     Hue[0.645047000471963, 1, 0.10685799934651287`], 
     Hue[0.6237081735898071, 1, 0.1364040673371902], 
     Hue[0.602574529428017, 1, 0.1656660361765918], 
     Hue[0.5781254103401121, 1, 0.1995186626059986], 
     Hue[0.5614916278752068, 1, 0.2225500537112522], 
     Hue[0.6495984682510237, 1, 0.10055596703704404`], 
     Hue[0.6498872063550268, 1, 0.10015617581611677`], 
     Hue[0.6497261232417287, 1, 0.10037921397299107`], 
     Hue[0.6479667972454549, 1, 0.10281520381398558`], 
     Hue[0.6471786129927874, 1, 0.10390653585614043`], 
     Hue[0.6464564564606162, 1, 0.10490644490068528`], 
     Hue[0.6419821243867047, 1, 0.11110167392610121`], 
     Hue[0.6275873411450932, 1, 0.13103291226064023`], 
     Hue[0.6494616792468535, 1, 0.10074536719666437`], 
     Hue[0.6498378759096498, 1, 0.10022447950971572`], 
     Hue[0.6499689720806963, 1, 0.1000429617344206], 
     Hue[0.6499875610519944, 1, 0.10001722315877695`], 
     Hue[0.6487585552207871, 1, 0.10171892354044876`], 
     Hue[0.6480385917352298, 1, 0.10271579605891265`], 
     Hue[0.6474234415840103, 1, 0.10356754242213963`], 
     Hue[0.6450470004719643, 1, 0.10685799934651109`], 
     Hue[0.6432314603308571, 1, 0.10937182415727481`], 
     Hue[0.6498403530877374, 1, 0.10022104957082521`], 
     Hue[0.6494812112006415, 1, 0.1007183229529579], 
     Hue[0.64887959478411, 1, 0.10155133029892478`], 
     Hue[0.6482450581235274, 1, 0.10242991952126983`], 
     Hue[0.6464564564606162, 1, 0.10490644490068533`], 
     Hue[0.6462861242777769, 1, 0.10514228946153971`], 
     Hue[0.6489591993613006, 1, 0.10144110857666075`], 
     Hue[0.6483341237538893, 1, 0.10230659787923027`], 
     Hue[0.6499875499410278, 1, 0.1000172385431923], 
     Hue[0.6496330749346824, 1, 0.10050805009043981`], 
     Hue[0.649153547214849, 1, 0.10117201154867066`], 
     Hue[0.6474234415840103, 1, 0.10356754242213959`], 
     Hue[0.6473931627551958, 1, 0.10360946695434443`], 
     Hue[0.6495819204903092, 1, 0.10057887932111045`], 
     Hue[0.6497294663699528, 1, 0.10037458502621932`], 
     Hue[0.6499503668772793, 1, 0.10006872278530576`], 
     Hue[0.649813758879976, 1, 0.10025787232003329`], 
     Hue[0.6482450581235273, 1, 0.10242991952126988`], 
     Hue[0.6480385917352297, 1, 0.10271579605891275`], 
     Hue[0.6479667972454548, 1, 0.10281520381398572`], 
     Hue[0.648134546752491, 1, 0.10258293526578166`], 
     Hue[0.6499147887623526, 1, 0.10011798479058873`], 
     Hue[0.6499416771509483, 1, 0.10008075471407167`], 
     Hue[0.6499975662514333, 1, 0.10000336980570773`], 
     Hue[0.649153547214849, 1, 0.10117201154867064`], 
     Hue[0.6488795947841098, 1, 0.10155133029892488`], 
     Hue[0.6487585552207868, 1, 0.10171892354044898`], 
     Hue[0.6499859604962617, 1, 0.10001943931286852`], 
     Hue[0.6499900187740281, 1, 0.1000138201590381], 
     Hue[0.6498137588799761, 1, 0.10025787232003325`], 
     Hue[0.6496330749346824, 1, 0.10050805009043978`], 
     Hue[0.6494812112006415, 1, 0.10071832295295796`], 
     Hue[0.6499981815209614, 1, 0.10000251789405334`], 
     Hue[0.6497732626026614, 1, 0.1003139440886227], 
     Hue[0.6495984682510237, 1, 0.10055596703704402`], 
     Hue[0.6494616792468535, 1, 0.10074536719666437`], 
     Hue[0.6499999519224451, 1, 0.10000006656892216`], 
     Hue[0.6498926261234819, 1, 0.10014867152133289`], 
     Hue[0.6498403530877374, 1, 0.10022104957082523`], 
     Hue[0.6499998205406813, 1, 0.10000024848213372`], 
     Hue[0.6499998222703252, 1, 0.1000002460872421], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499798465258424, 1, 0.10002790481037208`], 
     Hue[0.6498872063550268, 1, 0.10015617581611676`], 
     Hue[0.6498378759096498, 1, 0.10022447950971572`], 
     Hue[0.6499999519224451, 1, 0.10000006656892216`], 
     Hue[0.6499690957937134, 1, 0.10004279043947381`], 
     Hue[0.6499875610519944, 1, 0.10001722315877697`], 
     Hue[0.6499689720806963, 1, 0.1000429617344206], 
     Hue[0.6499875499410278, 1, 0.1000172385431923], 
     Hue[0.6499690478431731, 1, 0.10004285683252959`], 
     Hue[0.6499650382974362, 1, 0.10004840851124211`], 
     Hue[0.6499998988706782, 1, 0.10000014002521485`], 
     Hue[0.6499689178987232, 1, 0.10004303675561406`], 
     Hue[0.6499650303492368, 1, 0.10004841951644139`], 
     Hue[0.6496325065507648, 1, 0.10050883708355646`], 
     Hue[0.6495979512450224, 1, 0.10055668289150747`], 
     Hue[0.6496325065507649, 1, 0.10050883708355643`], 
     Hue[0.6499690478431731, 1, 0.10004285683252959`], 
     Hue[0.6492568700596784, 1, 0.10102894914813774`], 
     Hue[0.6499650382974362, 1, 0.1000484085112421], 
     Hue[0.647733989804249, 1, 0.1031375525787322], 
     Hue[0.6477329026591776, 1, 0.10313905785652336`], 
     Hue[0.6469512230735474, 1, 0.10422138343662676`], 
     Hue[0.6499650303492368, 1, 0.10004841951644142`], 
     Hue[0.6499689178987231, 1, 0.10004303675561409`], 
     Hue[0.6275861158776409, 1, 0.13103460878480497`], 
     Hue[0.6495979512450223, 1, 0.1005566828915077], 
     Hue[0.6469512230735815, 1, 0.10422138343657948`], 
     Hue[0.6499998988706782, 1, 0.10000014002521485`], 
     Hue[0.6492568700596688, 1, 0.10102894914815094`], 
     Hue[0.6477339898042302, 1, 0.10313755257875815`], 
     Hue[0.6275861158776742, 1, 0.13103460878475878`], 
     Hue[0.6477329026592883, 1, 0.10313905785637009`], 
     Hue[0.6477329026591778, 1, 0.10313905785652307`], 
     Hue[0.6275861158775875, 1, 0.1310346087848789], 
     Hue[0.6477339898041263, 1, 0.1031375525789021], 
     Hue[0.6492568700596507, 1, 0.10102894914817598`], 
     Hue[0.6499998988706782, 1, 0.10000014002521485`], 
     Hue[0.6469512230735475, 1, 0.10422138343662657`], 
     Hue[0.6495979512450224, 1, 0.1005566828915075], 
     Hue[0.6499689178987232, 1, 0.10004303675561406`], 
     Hue[0.6275861158775856, 1, 0.13103460878488143`], 
     Hue[0.6499650303492368, 1, 0.10004841951644139`], 
     Hue[0.6499650382974363, 1, 0.10004840851124208`], 
     Hue[0.6469512230736324, 1, 0.10422138343650898`], 
     Hue[0.647732902659307, 1, 0.10313905785634415`], 
     Hue[0.647733989804126, 1, 0.10313755257890245`], 
     Hue[0.6499690478431731, 1, 0.10004285683252957`], 
     Hue[0.6492568700596506, 1, 0.10102894914817606`], 
     Hue[0.6496325065507648, 1, 0.10050883708355651`], 
     Hue[0.6495979512450223, 1, 0.10055668289150767`], 
     Hue[0.6496325065507648, 1, 0.10050883708355657`], 
     Hue[0.6499650303492368, 1, 0.10004841951644142`], 
     Hue[0.6499689178987231, 1, 0.10004303675561409`], 
     Hue[0.6499998988706782, 1, 0.10000014002521485`], 
     Hue[0.6499650382974363, 1, 0.10004840851124208`], 
     Hue[0.6499690478431731, 1, 0.10004285683252959`], 
     Hue[0.6499999477487557, 1, 0.10000007234787675`], 
     Hue[0.6499995415164597, 1, 0.1000006348233636], 
     Hue[0.6499972508920432, 1, 0.10000380645717097`], 
     Hue[0.6499891948964658, 1, 0.10001496091258584`], 
     Hue[0.6499727635994403, 1, 0.10003771193923645`], 
     Hue[0.6499999833152275, 1, 0.10000002310199285`], 
     Hue[0.6499998838143439, 1, 0.10000016087244698`], 
     Hue[0.6499992517330715, 1, 0.10000103606190107`], 
     Hue[0.6499964365371523, 1, 0.10000493402548141`], 
     Hue[0.6499878785449099, 1, 0.10001678355320162`], 
     Hue[0.64997163313836, 1, 0.10003927719303991`], 
     Hue[0.6499995415164597, 1, 0.1000006348233636], 
     Hue[0.6499967956750783, 1, 0.10000443675758397`], 
     Hue[0.6499839080767035, 1, 0.10002228112456447`], 
     Hue[0.6499439425821281, 1, 0.10007761796320734`], 
     Hue[0.6498689637672006, 1, 0.10018143478387614`], 
     Hue[0.6499988129691915, 1, 0.10000164358111958`], 
     Hue[0.6499940313665191, 1, 0.10000826426174277`], 
     Hue[0.6499769587829002, 1, 0.10003190322367668`], 
     Hue[0.6499332213778155, 1, 0.10009246270764012`], 
     Hue[0.6498591025961614, 1, 0.10019508871300734`], 
     Hue[0.6499972508920432, 1, 0.10000380645717097`], 
     Hue[0.6499839080767035, 1, 0.10002228112456447`], 
     Hue[0.6499333273424222, 1, 0.1000923159874155], 
     Hue[0.649802635479388, 1, 0.10027327395161664`], 
     Hue[0.6499910204721564, 1, 0.10001243319239884`], 
     Hue[0.6499648950093987, 1, 0.10004860691006341`], 
     Hue[0.6498924977752071, 1, 0.10014884923432864`], 
     Hue[0.6497443765290007, 1, 0.10035394019061437`], 
     Hue[0.6499891948964658, 1, 0.10001496091258584`], 
     Hue[0.6499439425821281, 1, 0.10007761796320734`], 
     Hue[0.649802635479388, 1, 0.10027327395161664`], 
     Hue[0.649507963302497, 1, 0.10068128158115795`], 
     Hue[0.6499481872069947, 1, 0.10007174079031515`], 
     Hue[0.6498438427337278, 1, 0.1002162177533], 
     Hue[0.6496234428209622, 1, 0.10052138686328319`], 
     Hue[0.6499727635994403, 1, 0.10003771193923645`], 
     Hue[0.6498689637672006, 1, 0.10018143478387613`], 
     Hue[0.6497656401713836, 1, 0.10032449822423818`], 
     Hue[0.6494616592083259, 1, 0.10074539494231807`], 
     Hue[0.649978647617328, 1, 0.10002956483754584`], 
     Hue[0.6441375780758971, 1, 0.10811719958721938`], 
     Hue[0.6432396388960604, 1, 0.1093604999900703], 
     Hue[0.642231751769465, 1, 0.11075603601151002`], 
     Hue[0.6499798790222463, 1, 0.10002785981535132`], 
     Hue[0.6437344762513189, 1, 0.10867534057509703`], 
     Hue[0.6417513908539809, 1, 0.11142115112525726`], 
     Hue[0.6378571080019445, 1, 0.11681323507423075`], 
     Hue[0.6309283188212801, 1, 0.12640694317053525`], 
     Hue[0.6441375780758337, 1, 0.10811719958730724`], 
     Hue[0.6417513908539563, 1, 0.11142115112529143`], 
     Hue[0.6360099177032927, 1, 0.11937088318005631`], 
     Hue[0.6220664870179633, 1, 0.13867717182128156`], 
     Hue[0.5965457485369448, 1, 0.17401357894884573`], 
     Hue[0.6498013526819988, 1, 0.10027505013261706`], 
     Hue[0.6499532866781321, 1, 0.10006467998412484`], 
     Hue[0.6432396388959816, 1, 0.10936049999017944`], 
     Hue[0.6378571080019386, 1, 0.11681323507423888`], 
     Hue[0.6220664870179979, 1, 0.13867717182123368`], 
     Hue[0.5839593231110924, 1, 0.19144093723079508`], 
     Hue[0.5205040684996355, 1, 0.2793020590005047], 
     Hue[0.6496866182982453, 1, 0.10043391312550666`], 
     Hue[0.6499131219491169, 1, 0.10012029268583819`], 
     Hue[0.6499824722110213, 1, 0.10002426924627814`], 
     Hue[0.6422317517694232, 1, 0.11075603601156796`], 
     Hue[0.63092831882132, 1, 0.1264069431704799], 
     Hue[0.5965457485370032, 1, 0.1740135789487649], 
     Hue[0.520504068499611, 1, 0.2793020590005387], 
     Hue[0.6495503990542772, 1, 0.10062252438638544`], 
     Hue[0.6498698870997501, 1, 0.10018015632342288`], 
     Hue[0.6499712182270595, 1, 0.10003985168560998`], 
     Hue[0.6499952676247932, 1, 0.10000655251951718`], 
     Hue[0.6480874779838659, 1, 0.10264810740695487`], 
     Hue[0.6498119241509249, 1, 0.10026041271410392`], 
     Hue[0.6499575857662996, 1, 0.10005872740050828`], 
     Hue[0.6499926578215517, 1, 0.1000101660932362], 
     Hue[0.6499990466030793, 1, 0.10000132008804404`], 
     Hue[0.6499999100348424, 1, 0.10000012456714136`], 
     Hue[0.6499314498889781, 1, 0.10009491553833798`], 
     Hue[0.6499884615950133, 1, 0.10001597625305847`], 
     Hue[0.6499984854790767, 1, 0.10000209702897084`], 
     Hue[0.6499998499633765, 1, 0.10000020774301727`], 
     Hue[0.6499999901267185, 1, 0.10000001367069754`], 
     Hue[0.6499999833152275, 1, 0.10000002310199285`], 
     Hue[0.649999996933637, 1, 0.1000000042457334], 
     Hue[0.6499998838143439, 1, 0.10000016087244698`], 
     Hue[0.6499988129691915, 1, 0.10000164358111958`], 
     Hue[0.6499910204721564, 1, 0.10001243319239884`], 
     Hue[0.6499481872069947, 1, 0.10007174079031517`], 
     Hue[0.6497656401713836, 1, 0.10032449822423817`], 
     Hue[0.6499999689061249, 1, 0.10000004305305792`], 
     Hue[0.6499992517330715, 1, 0.10000103606190107`], 
     Hue[0.6499940313665191, 1, 0.10000826426174277`], 
     Hue[0.6499648950093987, 1, 0.10004860691006343`], 
     Hue[0.6498438427337278, 1, 0.10021621775330003`], 
     Hue[0.6494616592083259, 1, 0.10074539494231807`], 
     Hue[0.6090241519504237, 1, 0.15673578960710566`], 
     Hue[0.6363371711390605, 1, 0.11891776303822395`], 
     Hue[0.6499964365371523, 1, 0.10000493402548141`], 
     Hue[0.6499769587829002, 1, 0.1000319032236767], 
     Hue[0.6498924977752071, 1, 0.10014884923432867`], 
     Hue[0.6496234428209621, 1, 0.10052138686328327`], 
     Hue[0.5138230752066207, 1, 0.2885526650985252], 
     Hue[0.5873524065680152, 1, 0.1867428216750559], 
     Hue[0.6258101614488276, 1, 0.1334936226093157], 
     Hue[0.6398547950462351, 1, 0.11404720685905909`], 
     Hue[0.6499878785449099, 1, 0.10001678355320162`], 
     Hue[0.6499332213778155, 1, 0.10009246270764013`], 
     Hue[0.6497443765290007, 1, 0.10035394019061443`], 
     Hue[0.5873524065680147, 1, 0.18674282167505662`], 
     Hue[0.6206832762213136, 1, 0.14059238677048885`], 
     Hue[0.6364974200212797, 1, 0.11869587997053574`], 
     Hue[0.6423011565880341, 1, 0.11065993703195276`], 
     Hue[0.64997163313836, 1, 0.10003927719303991`], 
     Hue[0.6498591025961614, 1, 0.10019508871300735`], 
     Hue[0.6090241519504225, 1, 0.1567357896071074], 
     Hue[0.625810161448827, 1, 0.1334936226093165], 
     Hue[0.6364974200212795, 1, 0.11869587997053603`], 
     Hue[0.6415696507928466, 1, 0.11167279120990485`], 
     Hue[0.6438278308474126, 1, 0.10854608036512113`], 
     Hue[0.6363371711390599, 1, 0.11891776303822488`], 
     Hue[0.6398547950462348, 1, 0.11404720685905957`], 
     Hue[0.6423011565880339, 1, 0.11065993703195309`], 
     Hue[0.6438278308474125, 1, 0.1085460803651213], 
     Hue[0.6499786571222672, 1, 0.10002955167686084`], 
     Hue[0.6480874779838893, 1, 0.10264810740692248`], 
     Hue[0.6499798927908357, 1, 0.10002784075115065`], 
     Hue[0.6499153777187439, 1, 0.10011716931250861`], 
     Hue[0.6495503990542805, 1, 0.10062252438638086`], 
     Hue[0.6498119241509267, 1, 0.10026041271410145`], 
     Hue[0.6499314498889787, 1, 0.10009491553833723`], 
     Hue[0.6495278596636377, 1, 0.10065373277342475`], 
     Hue[0.6498281137840707, 1, 0.1002379962989791], 
     Hue[0.6499573290700602, 1, 0.10005908282607058`], 
     Hue[0.6496866182982456, 1, 0.10043391312550613`], 
     Hue[0.6498698870997506, 1, 0.10018015632342239`], 
     Hue[0.6499575857662998, 1, 0.100058727400508], 
     Hue[0.6499884615950134, 1, 0.10001597625305839`], 
     Hue[0.6495278596636377, 1, 0.1006537327734248], 
     Hue[0.6497944442738895, 1, 0.10028461562076833`], 
     Hue[0.649935848726795, 1, 0.10008882483982239`], 
     Hue[0.649985852682855, 1, 0.10001958859296996`], 
     Hue[0.6498013526819988, 1, 0.10027505013261703`], 
     Hue[0.6499131219491169, 1, 0.10012029268583815`], 
     Hue[0.6499712182270595, 1, 0.10003985168560994`], 
     Hue[0.6499926578215517, 1, 0.10001016609323618`], 
     Hue[0.6499984854790767, 1, 0.10000209702897084`], 
     Hue[0.6498281137840707, 1, 0.10023799629897913`], 
     Hue[0.649935848726795, 1, 0.10008882483982239`], 
     Hue[0.6499833260191297, 1, 0.10002308705043594`], 
     Hue[0.6499968965922412, 1, 0.10000429702612754`], 
     Hue[0.6499532866781321, 1, 0.10006467998412485`], 
     Hue[0.6499824722110213, 1, 0.10002426924627814`], 
     Hue[0.6499952676247932, 1, 0.10000655251951718`], 
     Hue[0.6499990466030794, 1, 0.10000132008804404`], 
     Hue[0.6499998499633765, 1, 0.10000020774301727`], 
     Hue[0.6499153777187437, 1, 0.10011716931250862`], 
     Hue[0.6499573290700602, 1, 0.10005908282607058`], 
     Hue[0.649985852682855, 1, 0.10001958859296996`], 
     Hue[0.6499968965922412, 1, 0.10000429702612754`], 
     Hue[0.6499995283469943, 1, 0.10000065305800795`], 
     Hue[0.6499999489931797, 1, 0.1000000706248282], 
     Hue[0.649978647617328, 1, 0.10002956483754584`], 
     Hue[0.6499798790222463, 1, 0.10002785981535132`], 
     Hue[0.6499999100348424, 1, 0.10000012456714136`], 
     Hue[0.6499999901267185, 1, 0.10000001367069754`], 
     Hue[0.649999996933637, 1, 0.1000000042457334], 
     Hue[0.6499999689061249, 1, 0.10000004305305792`], 
     Hue[0.6499786571222672, 1, 0.10002955167686084`], 
     Hue[0.6499798927908357, 1, 0.10002784075115065`], 
     Hue[0.6499999489931797, 1, 0.1000000706248282], 
     Hue[0.6499999965648129, 1, 0.100000004756413], 
     Hue[0.6499999965648129, 1, 0.100000004756413], 
     Hue[0.6499999850058028, 1, 0.10000002076119612`], 
     Hue[0.6499999850058028, 1, 0.10000002076119612`], 
     Hue[0.6499999489931797, 1, 0.1000000706248282], 
     Hue[0.6499717446721232, 1, 0.1000391227616756], 
     Hue[0.6499999689061249, 1, 0.10000004305305792`], 
     Hue[0.6499999903087575, 1, 0.10000001341864341`], 
     Hue[0.6499999901267185, 1, 0.10000001367069754`], 
     Hue[0.6499999683904712, 1, 0.1000000437670398], 
     Hue[0.6499999583631957, 1, 0.10000005765095982`], 
     Hue[0.6499999100348424, 1, 0.10000012456714136`], 
     Hue[0.649999996676745, 1, 0.10000000460143], 
     Hue[0.6499999489931797, 1, 0.1000000706248282], 
     Hue[0.6499995283469943, 1, 0.10000065305800795`], 
     Hue[0.6499968965922412, 1, 0.10000429702612754`], 
     Hue[0.649985852682855, 1, 0.10001958859296996`], 
     Hue[0.6499573290700602, 1, 0.10005908282607055`], 
     Hue[0.6499153777187439, 1, 0.1001171693125086], 
     Hue[0.6499534788862268, 1, 0.10006441384983993`], 
     Hue[0.6499998499633765, 1, 0.10000020774301727`], 
     Hue[0.6499990466030794, 1, 0.10000132008804404`], 
     Hue[0.6499952676247932, 1, 0.10000655251951718`], 
     Hue[0.6499824722110213, 1, 0.10002426924627812`], 
     Hue[0.6499532866781321, 1, 0.10006467998412481`], 
     Hue[0.6499968965922412, 1, 0.10000429702612754`], 
     Hue[0.6499833260191297, 1, 0.10002308705043593`], 
     Hue[0.649935848726795, 1, 0.10008882483982234`], 
     Hue[0.6498281137840707, 1, 0.10023799629897905`], 
     Hue[0.6499984854790767, 1, 0.10000209702897084`], 
     Hue[0.6499926578215517, 1, 0.10001016609323618`], 
     Hue[0.6499712182270595, 1, 0.10003985168560994`], 
     Hue[0.6499131219491169, 1, 0.10012029268583812`], 
     Hue[0.6498013526819989, 1, 0.10027505013261694`], 
     Hue[0.649985852682855, 1, 0.10001958859296996`], 
     Hue[0.649935848726795, 1, 0.10008882483982234`], 
     Hue[0.6497944442738897, 1, 0.10028461562076825`], 
     Hue[0.6495278596636378, 1, 0.10065373277342464`], 
     Hue[0.6499884615950133, 1, 0.1000159762530585], 
     Hue[0.6499575857662997, 1, 0.10005872740050815`], 
     Hue[0.6498698870997505, 1, 0.10018015632342248`], 
     Hue[0.6496866182982456, 1, 0.10043391312550612`], 
     Hue[0.6499573290700602, 1, 0.10005908282607055`], 
     Hue[0.6498281137840707, 1, 0.10023799629897903`], 
     Hue[0.6495278596636378, 1, 0.10065373277342463`], 
     Hue[0.6499314498889773, 1, 0.1000949155383391], 
     Hue[0.6498119241509249, 1, 0.10026041271410391`], 
     Hue[0.6495503990542795, 1, 0.10062252438638224`], 
     Hue[0.6499153777187439, 1, 0.10011716931250858`], 
     Hue[0.6438278308474092, 1, 0.10854608036512567`], 
     Hue[0.6423011565880492, 1, 0.11065993703193187`], 
     Hue[0.6398547950463043, 1, 0.11404720685896333`], 
     Hue[0.6363371711392205, 1, 0.11891776303800249`], 
     Hue[0.634412731493343, 1, 0.12158237177844815`], 
     Hue[0.6499717446721232, 1, 0.1000391227616756], 
     Hue[0.6499534788862268, 1, 0.10006441384983993`], 
     Hue[0.643827830847377, 1, 0.1085460803651703], 
     Hue[0.6415696507928302, 1, 0.11167279120992746`], 
     Hue[0.636497420021236, 1, 0.11869587997059636`], 
     Hue[0.625810161448658, 1, 0.13349362260955047`], 
     Hue[0.6090241519500147, 1, 0.15673578960767195`], 
     Hue[0.6498591025961613, 1, 0.10019508871300743`], 
     Hue[0.64997163313836, 1, 0.10003927719303994`], 
     Hue[0.6423011565879951, 1, 0.1106599370320068], 
     Hue[0.63649742002124, 1, 0.11869587997059089`], 
     Hue[0.6206832762210897, 1, 0.14059238677079894`], 
     Hue[0.587352406567333, 1, 0.18674282167600043`], 
     Hue[0.6497443765290006, 1, 0.10035394019061458`], 
     Hue[0.6499332213778155, 1, 0.10009246270764016`], 
     Hue[0.6499878785449099, 1, 0.10001678355320164`], 
     Hue[0.6398547950462775, 1, 0.11404720685900034`], 
     Hue[0.6258101614487078, 1, 0.13349362260948144`], 
     Hue[0.587352406567368, 1, 0.18674282167595202`], 
     Hue[0.5138230752053732, 1, 0.28855266510025257`], 
     Hue[0.6496234428209611, 1, 0.10052138686328474`], 
     Hue[0.649892497775207, 1, 0.10014884923432879`], 
     Hue[0.6499769587829002, 1, 0.10003190322367671`], 
     Hue[0.6499964365371523, 1, 0.10000493402548143`], 
     Hue[0.6363371711392378, 1, 0.11891776303797848`], 
     Hue[0.6344127314933686, 1, 0.12158237177841268`], 
     Hue[0.6090241519500755, 1, 0.15673578960758772`], 
     Hue[0.6494616592083241, 1, 0.10074539494232045`], 
     Hue[0.6498438427337273, 1, 0.10021621775330074`], 
     Hue[0.6499648950093986, 1, 0.1000486069100635], 
     Hue[0.6499940313665191, 1, 0.10000826426174277`], 
     Hue[0.6499992517330715, 1, 0.10000103606190107`], 
     Hue[0.6499999689061249, 1, 0.10000004305305792`], 
     Hue[0.6499999903087575, 1, 0.10000001341864341`], 
     Hue[0.6497656401713869, 1, 0.10032449822423352`], 
     Hue[0.6499481872069948, 1, 0.10007174079031503`], 
     Hue[0.6499910204721564, 1, 0.10001243319239886`], 
     Hue[0.6499988129691915, 1, 0.10000164358111958`], 
     Hue[0.6499998838143439, 1, 0.10000016087244698`], 
     Hue[0.6499999683904712, 1, 0.1000000437670398], 
     Hue[0.6499999583631957, 1, 0.10000005765095982`], 
     Hue[0.6499999901267185, 1, 0.10000001367069754`], 
     Hue[0.6499999583631957, 1, 0.10000005765095982`], 
     Hue[0.6499999683904712, 1, 0.1000000437670398], 
     Hue[0.6499998499633765, 1, 0.10000020774301727`], 
     Hue[0.6499984854790767, 1, 0.10000209702897084`], 
     Hue[0.6499884615950133, 1, 0.1000159762530585], 
     Hue[0.6499314498889773, 1, 0.10009491553833913`], 
     Hue[0.6499999903087575, 1, 0.10000001341864341`], 
     Hue[0.6499999100348424, 1, 0.10000012456714136`], 
     Hue[0.6499990466030794, 1, 0.10000132008804404`], 
     Hue[0.6499926578215517, 1, 0.10001016609323618`], 
     Hue[0.6499575857662997, 1, 0.10005872740050817`], 
     Hue[0.6498119241509249, 1, 0.10026041271410392`], 
     Hue[0.6344127314931636, 1, 0.12158237177869655`], 
     Hue[0.6499952676247932, 1, 0.10000655251951718`], 
     Hue[0.6499712182270595, 1, 0.10003985168560996`], 
     Hue[0.6498698870997505, 1, 0.1001801563234225], 
     Hue[0.6495503990542795, 1, 0.10062252438638229`], 
     Hue[0.5205040685009305, 1, 0.2793020589987117], 
     Hue[0.5965457485375734, 1, 0.1740135789479753], 
     Hue[0.6309283188213023, 1, 0.12640694317050455`], 
     Hue[0.642231751769313, 1, 0.11075603601172052`], 
     Hue[0.6499824722110213, 1, 0.10002426924627812`], 
     Hue[0.6499131219491169, 1, 0.10012029268583815`], 
     Hue[0.6496866182982456, 1, 0.10043391312550619`], 
     Hue[0.5205040685009303, 1, 0.2793020589987119], 
     Hue[0.5839593231117566, 1, 0.19144093722987549`], 
     Hue[0.6220664870181908, 1, 0.13867717182096656`], 
     Hue[0.637857108001951, 1, 0.11681323507422176`], 
     Hue[0.6432396388960145, 1, 0.1093604999901337], 
     Hue[0.6499532866781321, 1, 0.10006467998412481`], 
     Hue[0.6498013526819989, 1, 0.10027505013261696`], 
     Hue[0.5965457485375725, 1, 0.1740135789479767], 
     Hue[0.6220664870181905, 1, 0.13867717182096712`], 
     Hue[0.6360099177033423, 1, 0.11937088317998765`], 
     Hue[0.6417513908539852, 1, 0.11142115112525128`], 
     Hue[0.6441375780758909, 1, 0.10811719958722801`], 
     Hue[0.6499534788862268, 1, 0.1000644138498399], 
     Hue[0.6499717446721233, 1, 0.10003912276167556`], 
     Hue[0.6344127314931625, 1, 0.12158237177869816`], 
     Hue[0.6309283188213016, 1, 0.12640694317050544`], 
     Hue[0.6378571080019506, 1, 0.11681323507422223`], 
     Hue[0.641751390853985, 1, 0.11142115112525151`], 
     Hue[0.6437344762513346, 1, 0.10867534057507511`], 
     Hue[0.6422317517693127, 1, 0.11075603601172099`], 
     Hue[0.6432396388960143, 1, 0.10936049999013404`], 
     Hue[0.6441375780758908, 1, 0.10811719958722825`], 
     Hue[0.6494616592083307, 1, 0.10074539494231151`], 
     Hue[0.6497656401713895, 1, 0.10032449822422998`], 
     Hue[0.6498689637672006, 1, 0.10018143478387617`], 
     Hue[0.6499727635994403, 1, 0.10003771193923647`], 
     Hue[0.6496234428209623, 1, 0.10052138686328298`], 
     Hue[0.6498438427337282, 1, 0.10021621775329947`], 
     Hue[0.6499481872069951, 1, 0.10007174079031451`], 
     Hue[0.6495079633024969, 1, 0.1006812815811581], 
     Hue[0.649802635479388, 1, 0.10027327395161673`], 
     Hue[0.6499439425821281, 1, 0.10007761796320737`], 
     Hue[0.6499891948964658, 1, 0.10001496091258584`], 
     Hue[0.6497443765290007, 1, 0.10035394019061446`], 
     Hue[0.6498924977752071, 1, 0.10014884923432864`], 
     Hue[0.6499648950093987, 1, 0.10004860691006338`], 
     Hue[0.6499910204721564, 1, 0.1000124331923988], 
     Hue[0.6498026354793879, 1, 0.10027327395161674`], 
     Hue[0.6499333273424222, 1, 0.10009231598741554`], 
     Hue[0.6499839080767035, 1, 0.10002228112456447`], 
     Hue[0.6499972508920432, 1, 0.10000380645717097`], 
     Hue[0.6498591025961613, 1, 0.10019508871300745`], 
     Hue[0.6499332213778155, 1, 0.10009246270764016`], 
     Hue[0.6499769587829002, 1, 0.1000319032236767], 
     Hue[0.6499940313665191, 1, 0.10000826426174277`], 
     Hue[0.6499988129691915, 1, 0.10000164358111958`], 
     Hue[0.6499534788862268, 1, 0.10006441384983988`], 
     Hue[0.6498689637672006, 1, 0.1001814347838762], 
     Hue[0.6499439425821281, 1, 0.10007761796320738`], 
     Hue[0.6499839080767035, 1, 0.10002228112456449`], 
     Hue[0.6499967956750783, 1, 0.10000443675758397`], 
     Hue[0.6499995415164597, 1, 0.1000006348233636], 
     Hue[0.649999996676745, 1, 0.10000000460143], 
     Hue[0.64997163313836, 1, 0.10003927719303995`], 
     Hue[0.6499878785449099, 1, 0.10001678355320164`], 
     Hue[0.6499964365371523, 1, 0.10000493402548143`], 
     Hue[0.6499992517330715, 1, 0.10000103606190107`], 
     Hue[0.6499998838143439, 1, 0.10000016087244698`], 
     Hue[0.6499999583631957, 1, 0.10000005765095982`], 
     Hue[0.6499999683904712, 1, 0.1000000437670398], 
     Hue[0.6499999903087575, 1, 0.10000001341864341`], 
     Hue[0.6499717446721233, 1, 0.10003912276167556`], 
     Hue[0.6499727635994403, 1, 0.10003771193923647`], 
     Hue[0.6499891948964658, 1, 0.10001496091258585`], 
     Hue[0.6499972508920432, 1, 0.10000380645717098`], 
     Hue[0.6499995415164597, 1, 0.1000006348233636], 
     Hue[0.6499999477487557, 1, 0.10000007234787675`], 
     Hue[0.6499999850058028, 1, 0.10000002076119612`], 
     Hue[0.6499999850058028, 1, 0.10000002076119612`], 
     Hue[0.6499999925396918, 1, 0.10000001032965763`], 
     Hue[0.6499999924509668, 1, 0.1000000104525075], 
     Hue[0.6499999714959052, 1, 0.10000003946720826`], 
     Hue[0.6499999718281185, 1, 0.1000000390072206], 
     Hue[0.6499999714959052, 1, 0.10000003946720826`], 
     Hue[0.6499999987909204, 1, 0.1000000016741103], 
     Hue[0.6499999924509668, 1, 0.1000000104525075], 
     Hue[0.6499798927908357, 1, 0.10002784075115066`], 
     Hue[0.6499786439810903, 1, 0.10002956987233663`], 
     Hue[0.6499786571222672, 1, 0.10002955167686085`], 
     Hue[0.6499999958851704, 1, 0.10000000569745643`], 
     Hue[0.6499999823388529, 1, 0.10000002445389598`], 
     Hue[0.649999996933637, 1, 0.1000000042457334], 
     Hue[0.6499999968907343, 1, 0.1000000043051372], 
     Hue[0.6499999834633291, 1, 0.10000002289692897`], 
     Hue[0.6499999747414913, 1, 0.10000003497331982`], 
     Hue[0.6499999923535981, 1, 0.10000001058732584`], 
     Hue[0.6499999790874041, 1, 0.10000002895590207`], 
     Hue[0.6499999843722919, 1, 0.10000002163836517`], 
     Hue[0.6499999820241611, 1, 0.10000002488962312`], 
     Hue[0.6499999385497581, 1, 0.10000008508495034`], 
     Hue[0.6499999199446159, 1, 0.10000011084591645`], 
     Hue[0.649999930191259, 1, 0.10000009665825685`], 
     Hue[0.6499798790222463, 1, 0.1000278598153513], 
     Hue[0.6499786432660215, 1, 0.10002957086243183`], 
     Hue[0.649978647617328, 1, 0.10002956483754584`], 
     Hue[0.6499999988522372, 1, 0.10000000158920994`], 
     Hue[0.6499999726116505, 1, 0.10000003792233012`], 
     Hue[0.6499885213023262, 1, 0.10001589358139451`], 
     Hue[0.6499316532667695, 1, 0.10009463393831913`], 
     Hue[0.648088593100504, 1, 0.10264656339930217`], 
     Hue[0.6480874779837993, 1, 0.10264810740704716`], 
     Hue[0.6499798927908357, 1, 0.10002784075115066`], 
     Hue[0.6499786439810903, 1, 0.10002956987233663`], 
     Hue[0.6499872728813456, 1, 0.10001762216429065`], 
     Hue[0.6499786571222672, 1, 0.10002955167686085`], 
     Hue[0.6499872851621001, 1, 0.10001760516016904`], 
     Hue[0.6499786432660215, 1, 0.10002957086243185`], 
     Hue[0.6480885931004806, 1, 0.10264656339933452`], 
     Hue[0.6499999531810358, 1, 0.10000006482625813`], 
     Hue[0.6499999385497581, 1, 0.10000008508495034`], 
     Hue[0.649999996933637, 1, 0.1000000042457334], 
     Hue[0.6499999834633291, 1, 0.10000002289692897`], 
     Hue[0.6499999968907343, 1, 0.1000000043051372], 
     Hue[0.6499999846564967, 1, 0.10000002124485077`], 
     Hue[0.6499999823388529, 1, 0.10000002445389598`], 
     Hue[0.6499885213023262, 1, 0.1000158935813946], 
     Hue[0.649931653266769, 1, 0.10009463393831988`], 
     Hue[0.6499999199446159, 1, 0.10000011084591645`], 
     Hue[0.649999930191259, 1, 0.10000009665825685`], 
     Hue[0.6499999957862591, 1, 0.10000000583441045`], 
     Hue[0.6499999820241611, 1, 0.10000002488962312`], 
     Hue[0.6499999833152275, 1, 0.10000002310199285`], 
     Hue[0.6499999968907343, 1, 0.1000000043051372], 
     Hue[0.6499999834633291, 1, 0.10000002289692897`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499999946476501, 1, 0.10000000741094602`], 
     Hue[0.6499999923535981, 1, 0.10000001058732584`], 
     Hue[0.6499999790874041, 1, 0.10000002895590207`], 
     Hue[0.6499316532667682, 1, 0.10009463393832103`], 
     Hue[0.6499885213023261, 1, 0.10001589358139462`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499999924343713, 1, 0.10000001047548586`], 
     Hue[0.649999930191259, 1, 0.10000009665825685`], 
     Hue[0.6499999459827224, 1, 0.1000000747931536], 
     Hue[0.6499999385497581, 1, 0.10000008508495034`], 
     Hue[0.6499999957862591, 1, 0.10000000583441045`], 
     Hue[0.6499999820241611, 1, 0.10000002488962312`], 
     Hue[0.6499999846564967, 1, 0.10000002124485077`], 
     Hue[0.6499999823388529, 1, 0.10000002445389598`], 
     Hue[0.6499999531810358, 1, 0.10000006482625813`], 
     Hue[0.6480874779837994, 1, 0.10264810740704695`], 
     Hue[0.6480885931004169, 1, 0.10264656339942274`], 
     Hue[0.6499798790222463, 1, 0.1000278598153513], 
     Hue[0.6499786432660215, 1, 0.10002957086243183`], 
     Hue[0.6499872851621001, 1, 0.10001760516016903`], 
     Hue[0.649978647617328, 1, 0.10002956483754584`], 
     Hue[0.6499872728813457, 1, 0.10001762216429065`], 
     Hue[0.6480885931004168, 1, 0.10264656339942299`], 
     Hue[0.6499786439810903, 1, 0.10002956987233662`], 
     Hue[0.6499316532667682, 1, 0.100094633938321], 
     Hue[0.6499885213023261, 1, 0.10001589358139462`], 
     Hue[0.649999930191259, 1, 0.10000009665825685`], 
     Hue[0.6499999833152275, 1, 0.10000002310199285`], 
     Hue[0.6499999834633291, 1, 0.10000002289692897`], 
     Hue[0.6499999968907343, 1, 0.1000000043051372], 
     Hue[0.6499999726116505, 1, 0.10000003792233012`], 
     Hue[0.6499999714959052, 1, 0.10000003946720826`], 
     Hue[0.6499999988522372, 1, 0.10000000158920994`], 
     Hue[0.6499786432660215, 1, 0.10002957086243186`], 
     Hue[0.6499999459827224, 1, 0.1000000747931536], 
     Hue[0.6499999385497581, 1, 0.10000008508495034`], 
     Hue[0.6499999946476501, 1, 0.10000000741094602`], 
     Hue[0.6499999790874041, 1, 0.10000002895590207`], 
     Hue[0.6499999923535981, 1, 0.10000001058732584`], 
     Hue[0.6499999843722919, 1, 0.10000002163836517`], 
     Hue[0.6499999820241611, 1, 0.10000002488962312`], 
     Hue[0.6499999947460028, 1, 0.10000000727476545`], 
     Hue[0.6499999924343713, 1, 0.10000001047548586`], 
     Hue[0.6499999958851704, 1, 0.10000000569745643`], 
     Hue[0.6499999823388529, 1, 0.10000002445389598`], 
     Hue[0.6499786439810903, 1, 0.10002956987233662`], 
     Hue[0.6499999718281185, 1, 0.1000000390072206], 
     Hue[0.6499999714959052, 1, 0.10000003946720826`], 
     Hue[0.6499999987909204, 1, 0.1000000016741103], 
     Hue[0.6499999924509668, 1, 0.1000000104525075], 
     Hue[0.6499999925396918, 1, 0.10000001032965763`], 
     Hue[0.6499999924509668, 1, 0.1000000104525075], 
     Hue[0.6499872705232843, 1, 0.10001762542929866`], 
     Hue[0.6499999924343713, 1, 0.10000001047548586`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499872761827475, 1, 0.1000176175931189], 
     Hue[0.6499999947460028, 1, 0.10000000727476545`], 
     Hue[0.6499999924343713, 1, 0.10000001047548586`], 
     Hue[0.6499999747414913, 1, 0.10000003497331982`], 
     Hue[0.6499999790874041, 1, 0.10000002895590207`], 
     Hue[0.6499999923535981, 1, 0.10000001058732584`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499872761827474, 1, 0.1000176175931189], 
     Hue[0.6499872705232843, 1, 0.10001762542929865`], 
     Hue[0.6499999987909204, 1, 0.1000000016741103], 
     Hue[0.6499999718281185, 1, 0.1000000390072206], 
     Hue[0.6499998378409675, 1, 0.10000022452789123`], 
     Hue[0.6499999925396918, 1, 0.10000001032965763`], 
     Hue[0.6499999726116505, 1, 0.10000003792233012`], 
     Hue[0.6499998474023537, 1, 0.10000021128904879`], 
     Hue[0.6499987373870405, 1, 0.1000017482333285], 
     Hue[0.6499930394481843, 1, 0.10000963768712945`], 
     Hue[0.6499740840158208, 1, 0.10003588367040199`], 
     Hue[0.6499368000496959, 1, 0.10008750762349808`], 
     Hue[0.6499872851621001, 1, 0.10001760516016904`], 
     Hue[0.6499997694648034, 1, 0.10000031920257986`], 
     Hue[0.6499999846564967, 1, 0.10000002124485077`], 
     Hue[0.6499999947460028, 1, 0.10000000727476545`], 
     Hue[0.6499999946476501, 1, 0.10000000741094602`], 
     Hue[0.6499999328468428, 1, 0.1000000929812946], 
     Hue[0.6499999957862591, 1, 0.10000000583441045`], 
     Hue[0.6499999459827224, 1, 0.1000000747931536], 
     Hue[0.6499996132007059, 1, 0.10000053556825345`], 
     Hue[0.6499999531810358, 1, 0.10000006482625813`], 
     Hue[0.6499997664208694, 1, 0.1000003234172578], 
     Hue[0.6499978004542722, 1, 0.1000030455248539], 
     Hue[0.649990533972543, 1, 0.1000131068072481], 
     Hue[0.6499701121736939, 1, 0.10004138314411615`], 
     Hue[0.6499332456084079, 1, 0.10009242915758908`], 
     Hue[0.6499872728813457, 1, 0.10001762216429065`], 
     Hue[0.6499999988522372, 1, 0.10000000158920994`], 
     Hue[0.6499997205474622, 1, 0.10000038693428308`], 
     Hue[0.6499988198134662, 1, 0.1000016341044314], 
     Hue[0.649997998599588, 1, 0.10000277116980137`], 
     Hue[0.6499925051018157, 1, 0.10001037755133219`], 
     Hue[0.6499899497720244, 1, 0.10001391570027392`], 
     Hue[0.6499658530333119, 1, 0.10004728041541434`], 
     Hue[0.6498899315253245, 1, 0.10015240250339691`], 
     Hue[0.6498257856160936, 1, 0.10024121991617815`], 
     Hue[0.6498206455449007, 1, 0.10024833693782984`], 
     Hue[0.6499999333097417, 1, 0.10000009234035774`], 
     Hue[0.6499999042768432, 1, 0.1000001325397556], 
     Hue[0.6499993878957052, 1, 0.10000084752902356`], 
     Hue[0.6499966175523572, 1, 0.10000468338904392`], 
     Hue[0.6499967448026513, 1, 0.10000450719632889`], 
     Hue[0.6499849888742334, 1, 0.1000207846356768], 
     Hue[0.6499482995199596, 1, 0.10007158528005594`], 
     Hue[0.6498637789166501, 1, 0.10018861380771515`], 
     Hue[0.6498245814294037, 1, 0.10024288725159497`], 
     Hue[0.6498206206758443, 1, 0.10024837137190787`], 
     Hue[0.6499980650680817, 1, 0.10000267913650228`], 
     Hue[0.6499887061646138, 1, 0.10001563761822711`], 
     Hue[0.6499957081322433, 1, 0.10000594258612468`], 
     Hue[0.6499929243432877, 1, 0.10000979706314017`], 
     Hue[0.6499949826603763, 1, 0.10000694708563292`], 
     Hue[0.6499777227220929, 1, 0.10003084546171759`], 
     Hue[0.6499234404741348, 1, 0.1001060054973519], 
     Hue[0.6497919036628964, 1, 0.1002881333898358], 
     Hue[0.6494291374898146, 1, 0.1007904250141029], 
     Hue[0.6499942406207414, 1, 0.10000797452512729`], 
     Hue[0.6499908589738949, 1, 0.10001265680537647`], 
     Hue[0.6499711554269493, 1, 0.10003993863960878`], 
     Hue[0.6499552803098146, 1, 0.10006191957102599`], 
     Hue[0.6499690892099143, 1, 0.10004279955550338`], 
     Hue[0.649886621235013, 1, 0.10015698598228986`], 
     Hue[0.6497011754290651, 1, 0.1004137570982175], 
     Hue[0.6495400008935742, 1, 0.10063692183966653`], 
     Hue[0.6498257856160936, 1, 0.10024121991617815`], 
     Hue[0.6496731893555393, 1, 0.10045250704617642`], 
     Hue[0.6496727141920235, 1, 0.10045316496489053`], 
     Hue[0.6499872705232843, 1, 0.10001762542929866`], 
     Hue[0.6498206455449007, 1, 0.10024833693782982`], 
     Hue[0.6498245814294036, 1, 0.10024288725159507`], 
     Hue[0.6430994341869618, 1, 0.10955462958728375`], 
     Hue[0.6431138697201356, 1, 0.10953464192596608`], 
     Hue[0.6494291374898145, 1, 0.10079042501410311`], 
     Hue[0.649461400807902, 1, 0.10074575272752026`], 
     Hue[0.6498376968729129, 1, 0.10022472740673605`], 
     Hue[0.6499872761827474, 1, 0.1000176175931189], 
     Hue[0.6319953620941587, 1, 0.12492949863885709`], 
     Hue[0.6227153440039706, 1, 0.13777875445604082`], 
     Hue[0.6233200715729882, 1, 0.1369414393604779], 
     Hue[0.6499334584002099, 1, 0.10009213452278638`], 
     Hue[0.6499332456084078, 1, 0.10009242915758913`], 
     Hue[0.6499558704947553, 1, 0.10006110239187734`], 
     Hue[0.6498637789166501, 1, 0.10018861380771525`], 
     Hue[0.6499035776827975, 1, 0.1001335078238189], 
     Hue[0.6499701121736939, 1, 0.10004138314411617`], 
     Hue[0.6499807215560938, 1, 0.10002669323002401`], 
     Hue[0.649791903662896, 1, 0.10028813338983632`], 
     Hue[0.6498491275148004, 1, 0.10020890036412251`], 
     Hue[0.6499482995199596, 1, 0.100071585280056], 
     Hue[0.6499651447615216, 1, 0.10004826109943168`], 
     Hue[0.649990533972543, 1, 0.10001310680724812`], 
     Hue[0.6499941257642842, 1, 0.10000813355714501`], 
     Hue[0.6499978004542722, 1, 0.10000304552485391`], 
     Hue[0.6499997664208694, 1, 0.1000003234172578], 
     Hue[0.6499999113420365, 1, 0.10000012275718022`], 
     Hue[0.649701175429064, 1, 0.10041375709821909`], 
     Hue[0.6497822958439443, 1, 0.10030143652376938`], 
     Hue[0.6499234404741345, 1, 0.10010600549735216`], 
     Hue[0.6499477127625017, 1, 0.10007239771345909`], 
     Hue[0.6499777227220929, 1, 0.1000308454617176], 
     Hue[0.6499849888742334, 1, 0.10002078463567683`], 
     Hue[0.6499904461340845, 1, 0.10001322842972922`], 
     Hue[0.6499966175523572, 1, 0.10000468338904392`], 
     Hue[0.6499987037961257, 1, 0.1000017947438261], 
     Hue[0.6499996132007059, 1, 0.10000053556825345`], 
     Hue[0.6499999459827224, 1, 0.1000000747931536], 
     Hue[0.6499999958851704, 1, 0.10000000569745643`], 
     Hue[0.6499957081322433, 1, 0.1000059425861247], 
     Hue[0.649971155426949, 1, 0.10003993863960904`], 
     Hue[0.6495407493861274, 1, 0.10063588546536209`], 
     Hue[0.6227153440039657, 1, 0.1377787544560476], 
     Hue[0.06744763098817208, 1, 0.9066109724779156], 
     Hue[0.03698777989743762, 1, 0.9487861509112402], 
     Hue[0.02100855953590086, 1, 0.9709112252579835], 
     Hue[0.06747929559368648, 1, 0.9065671291779726], 
     Hue[0.021017919604245705`, 1, 0.9708982651633521], 
     Hue[0.004312626695720967, 1, 0.9940286707290017], 
     Hue[0.06747929559223431, 1, 0.9065671291799833], 
     Hue[0.622715344004319, 1, 0.13777875445555823`], 
     Hue[0.6430994341870176, 1, 0.1095546295872063], 
     Hue[0.649540000893586, 1, 0.10063692183965024`], 
     Hue[0.6496696618168508, 1, 0.10045739133051425`], 
     Hue[0.6496727141920339, 1, 0.10045316496487627`], 
     Hue[0.6498866212350136, 1, 0.10015698598228884`], 
     Hue[0.6499227855829618, 1, 0.10010691226974526`], 
     Hue[0.6499857386104357, 1, 0.10001974653939676`], 
     Hue[0.6499979781484426, 1, 0.10000279948677178`], 
     Hue[0.6499997857288967, 1, 0.10000029668306615`], 
     Hue[0.6499999328468428, 1, 0.1000000929812946], 
     Hue[0.6499999843722919, 1, 0.10000002163836517`], 
     Hue[0.6499999946476501, 1, 0.10000000741094602`], 
     Hue[0.6499999333097417, 1, 0.10000009234035774`], 
     Hue[0.6499999747414913, 1, 0.10000003497331982`], 
     Hue[0.6499995050240461, 1, 0.10000068535132074`], 
     Hue[0.6499956798469451, 1, 0.10000598175038378`], 
     Hue[0.6499710401022167, 1, 0.10004009832000761`], 
     Hue[0.6430994341869646, 1, 0.10955462958727992`], 
     Hue[0.6431138697201368, 1, 0.1095346419259644], 
     Hue[0.6233200715729781, 1, 0.13694143936049186`], 
     Hue[0.004309068890287815, 1, 0.9940335969211399], 
     Hue[0.02101791960398325, 1, 0.9708982651637156], 
     Hue[0.03701244893325295, 1, 0.9487519937847267], 
     Hue[0.021017919602528856`, 1, 0.9708982651657293], 
     Hue[0.004309068888626699, 1, 0.99403359692344], 
     Hue[0.02100855953301084, 1, 0.9709112252619849], 
     Hue[0.06744763098356343, 1, 0.9066109724842968], 
     Hue[0.6233201302809892, 1, 0.13694135807247645`], 
     Hue[0.6496731893555265, 1, 0.10045250704619413`], 
     Hue[0.6499999658355468, 1, 0.10000004730462761`], 
     Hue[0.6499999333097417, 1, 0.10000009234035774`], 
     Hue[0.6499999947460028, 1, 0.10000000727476545`], 
     Hue[0.6499999199446159, 1, 0.10000011084591645`], 
     Hue[0.6499996941293525, 1, 0.10000042351320422`], 
     Hue[0.6499999843722919, 1, 0.10000002163836517`], 
     Hue[0.6499991262252099, 1, 0.10000120984201699`], 
     Hue[0.6499972533523636, 1, 0.1000038030505735], 
     Hue[0.6499928827959313, 1, 0.10000985459024907`], 
     Hue[0.6499817331204784, 1, 0.10002529260241469`], 
     Hue[0.6499551253828276, 1, 0.1000621340853157], 
     Hue[0.021017919602568935`, 1, 0.9708982651656738], 
     Hue[0.03698777989336832, 1, 0.9487861509168746], 
     Hue[0.6499711554269488, 1, 0.10003993863960928`], 
     Hue[0.6499957081322433, 1, 0.1000059425861247], 
     Hue[0.6499999958851704, 1, 0.10000000569745643`], 
     Hue[0.649999454487984, 1, 0.10000075532432992`], 
     Hue[0.6499983016594818, 1, 0.10000235154840982`], 
     Hue[0.6499954680826809, 1, 0.10000627496244185`], 
     Hue[0.6499719284481866, 1, 0.10003886830251078`], 
     Hue[0.6499999113420365, 1, 0.10000012275718022`], 
     Hue[0.6499997694648034, 1, 0.10000031920257986`], 
     Hue[0.6499971342997227, 1, 0.10000396789269159`], 
     Hue[0.6499878647654108, 1, 0.1000168026325082], 
     Hue[0.649981132862961, 1, 0.10002612372820785`], 
     Hue[0.6499931260501088, 1, 0.1000095177767724], 
     Hue[0.6499888903804653, 1, 0.10001538255012504`], 
     Hue[0.6319953620942506, 1, 0.12492949863873], 
     Hue[0.6353293129837486, 1, 0.12031325894557884`], 
     Hue[0.6498245814294037, 1, 0.10024288725159497`], 
     Hue[0.6494291374898146, 1, 0.10079042501410287`], 
     Hue[0.622715344004306, 1, 0.13777875445557644`], 
     Hue[0.6233201302809824, 1, 0.13694135807248597`], 
     Hue[0.6499872761827475, 1, 0.1000176175931189], 
     Hue[0.6498206206758443, 1, 0.10024837137190785`], 
     Hue[0.6430994341870134, 1, 0.10955462958721218`], 
     Hue[0.6498257856160936, 1, 0.1002412199161781], 
     Hue[0.6498401940009914, 1, 0.1002212698447812], 
     Hue[0.6499872705232843, 1, 0.10001762542929865`], 
     Hue[0.6495407493861158, 1, 0.10063588546537817`], 
     Hue[0.6499710401022171, 1, 0.10004009832000711`], 
     Hue[0.6499368000496959, 1, 0.1000875076234981], 
     Hue[0.6499579090308498, 1, 0.10005827980343877`], 
     Hue[0.6499817331204784, 1, 0.10002529260241466`], 
     Hue[0.6499956798469451, 1, 0.10000598175038375`], 
     Hue[0.6499711554269488, 1, 0.10003993863960926`], 
     Hue[0.6498899315253245, 1, 0.10015240250339695`], 
     Hue[0.649920525041201, 1, 0.10011004225064477`], 
     Hue[0.6499740840158208, 1, 0.10003588367040202`], 
     Hue[0.6499830415932077, 1, 0.10002348087094316`], 
     Hue[0.6499930394481843, 1, 0.10000963768712946`], 
     Hue[0.6494291374898145, 1, 0.10079042501410312`], 
     Hue[0.649461400807902, 1, 0.10074575272752026`], 
     Hue[0.6499878647654108, 1, 0.1000168026325082], 
     Hue[0.6499871127135868, 1, 0.10001784393503366`], 
     Hue[0.6499972533523636, 1, 0.1000038030505735], 
     Hue[0.6499995050240461, 1, 0.10000068535132073`], 
     Hue[0.6499957081322433, 1, 0.1000059425861247], 
     Hue[0.6499658530333119, 1, 0.10004728041541437`], 
     Hue[0.649976311639638, 1, 0.10003279926819361`], 
     Hue[0.6499925051018156, 1, 0.1000103775513322], 
     Hue[0.6499955738243941, 1, 0.1000061285508389], 
     Hue[0.6499987373870405, 1, 0.1000017482333285], 
     Hue[0.6499998474023537, 1, 0.10000021128904879`], 
     Hue[0.6498245814294036, 1, 0.10024288725159508`], 
     Hue[0.6498376968729129, 1, 0.10022472740673605`], 
     Hue[0.6499931260501088, 1, 0.1000095177767724], 
     Hue[0.6499983016594818, 1, 0.10000235154840982`], 
     Hue[0.6499981812644314, 1, 0.10000251824924883`], 
     Hue[0.6499996941293525, 1, 0.10000042351320422`], 
     Hue[0.6499999199446159, 1, 0.10000011084591645`], 
     Hue[0.6499999333097417, 1, 0.10000009234035774`], 
     Hue[0.6499999661022928, 1, 0.10000004693528683`], 
     Hue[0.6499334584002099, 1, 0.10009213452278633`], 
     Hue[0.6499560274362279, 1, 0.10006088508829983`], 
     Hue[0.6498257856160936, 1, 0.10024121991617813`], 
     Hue[0.6498401940009914, 1, 0.10022126984478122`], 
     Hue[0.6499942406207414, 1, 0.10000797452512729`], 
     Hue[0.649995048229519, 1, 0.10000685629758907`], 
     Hue[0.6499988198134662, 1, 0.1000016341044314], 
     Hue[0.649999231209965, 1, 0.10000106447851004`], 
     Hue[0.6499998378409675, 1, 0.10000022452789123`], 
     Hue[0.6499999718281185, 1, 0.1000000390072206], 
     Hue[0.6499999988522372, 1, 0.10000000158920994`], 
     Hue[0.6499872728813456, 1, 0.10001762216429065`], 
     Hue[0.649998861931212, 1, 0.10000157578755257`], 
     Hue[0.6499998099007703, 1, 0.10000026321431808`], 
     Hue[0.6499999531810358, 1, 0.10000006482625813`], 
     Hue[0.6499999747414913, 1, 0.10000003497331982`], 
     Hue[0.6499999957862591, 1, 0.10000000583441045`], 
     Hue[0.6499999846564967, 1, 0.10000002124485076`], 
     Hue[0.6499872851621001, 1, 0.10001760516016903`], 
     Hue[0.6499992554553338, 1, 0.10000103090799936`], 
     Hue[0.6499999068044836, 1, 0.10000012903994587`], 
     Hue[0.6499999726116505, 1, 0.10000003792233012`], 
     Hue[0.6499999925396918, 1, 0.10000001032965763`], 
     Hue[0.6499999987909204, 1, 0.1000000016741103], 
     Hue[0.6499182640119672, 1, 0.10011317290650702`], 
     Hue[0.6499998703971854, 1, 0.100000179450051], 
     Hue[0.6499179671599283, 1, 0.10011358393240688`], 
     Hue[0.6499999490745912, 1, 0.10000007051210441`], 
     Hue[0.6499182640119672, 1, 0.10011317290650702`], 
     Hue[0.6499453175635969, 1, 0.10007571414271206`], 
     Hue[0.6463627197888726, 1, 0.10503623413848405`], 
     Hue[0.6458360441378571, 1, 0.10576547734758247`], 
     Hue[0.6499904192577803, 1, 0.1000132656430734], 
     Hue[0.6499855624175456, 1, 0.10001999049878305`], 
     Hue[0.6499947544739892, 1, 0.100007263036015], 
     Hue[0.6499927474735677, 1, 0.10001004195967546`], 
     Hue[0.6499980833227129, 1, 0.10000265386085902`], 
     Hue[0.6499975602665753, 1, 0.10000337809243423`], 
     Hue[0.6499995339718821, 1, 0.10000064526970168`], 
     Hue[0.649999442352031, 1, 0.10000077212795708`], 
     Hue[0.6499998703971854, 1, 0.100000179450051], 
     Hue[0.6499999589602237, 1, 0.1000000568243058], 
     Hue[0.6369343337826544, 1, 0.11809092245478625`], 
     Hue[0.6233200715735031, 1, 0.13694143935976502`], 
     Hue[0.6463627197890695, 1, 0.10503623413821153`], 
     Hue[0.6431138697203481, 1, 0.10953464192567193`], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.649952257675664, 1, 0.100066104756773], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499930428076302, 1, 0.10000963303558903`], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499992118878316, 1, 0.10000109123223314`], 
     Hue[0.646362719788873, 1, 0.10503623413848345`], 
     Hue[0.647195627881372, 1, 0.10388297677963883`], 
     Hue[0.6458360441378573, 1, 0.10576547734758222`], 
     Hue[0.6464975004715674, 1, 0.10484961473167599`], 
     Hue[0.6453822585486565, 1, 0.10639379585570642`], 
     Hue[0.6451837682394977, 1, 0.10666862859146468`], 
     Hue[0.6233200715734802, 1, 0.1369414393597967], 
     Hue[0.6369343337826358, 1, 0.11809092245481205`], 
     Hue[0.6466909526577987, 1, 0.10458175785843253`], 
     Hue[0.6464557249198083, 1, 0.10490745780334242`], 
     Hue[0.6499179671599284, 1, 0.10011358393240688`], 
     Hue[0.6499452554080252, 1, 0.10007580020427294`], 
     Hue[0.6431138697203426, 1, 0.10953464192567951`], 
     Hue[0.6463627197890748, 1, 0.10503623413820415`], 
     Hue[0.6453822585486565, 1, 0.10639379585570649`], 
     Hue[0.6474229577245602, 1, 0.10356821238137827`], 
     Hue[0.6464557249198084, 1, 0.10490745780334221`], 
     Hue[0.646690952657799, 1, 0.10458175785843228`], 
     Hue[0.6474229577245603, 1, 0.10356821238137813`], 
     Hue[0.6499904693183663, 1, 0.1000131963284158], 
     Hue[0.6499857545886895, 1, 0.10001972441566084`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6499949320825263, 1, 0.10000701711650203`], 
     Hue[0.6499931307624713, 1, 0.10000951125196281`], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499982711804069, 1, 0.10000239375020598`], 
     Hue[0.6499978877143096, 1, 0.10000292470326372`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499996319583529, 1, 0.1000005095961268], 
     Hue[0.649999590533435, 1, 0.1000005669537054], 
     Hue[0.6499999490745912, 1, 0.10000007051210441`], 
     Hue[0.6499999853568917, 1, 0.10000002027507307`], 
     Hue[0.6499904192577803, 1, 0.1000132656430734], 
     Hue[0.6499947544739892, 1, 0.100007263036015], 
     Hue[0.6499980833227129, 1, 0.10000265386085902`], 
     Hue[0.6499995339718821, 1, 0.10000064526970168`], 
     Hue[0.6499904693183663, 1, 0.1000131963284158], 
     Hue[0.6499949320825263, 1, 0.10000701711650203`], 
     Hue[0.6499982711804069, 1, 0.10000239375020598`], 
     Hue[0.6499996319583529, 1, 0.1000005095961268], 
     Hue[0.6499996319583529, 1, 0.1000005095961268], 
     Hue[0.649999590533435, 1, 0.1000005669537054], 
     Hue[0.6499982711804069, 1, 0.10000239375020598`], 
     Hue[0.6499978877143096, 1, 0.10000292470326372`], 
     Hue[0.6499949320825263, 1, 0.10000701711650203`], 
     Hue[0.6499931307624713, 1, 0.1000095112519628], 
     Hue[0.6499904693183663, 1, 0.10001319632841578`], 
     Hue[0.6499857545886895, 1, 0.10001972441566084`], 
     Hue[0.649982351773809, 1, 0.10002443600549525`], 
     Hue[0.6499904494586252, 1, 0.10001322382651898`], 
     Hue[0.6499947848408922, 1, 0.10000722098953381`], 
     Hue[0.6499981001297528, 1, 0.10000263058957315`], 
     Hue[0.6499852938294347, 1, 0.10002036239001359`], 
     Hue[0.6499995394710767, 1, 0.10000063765543235`], 
     Hue[0.6499958918832327, 1, 0.10000568816167785`], 
     Hue[0.6499995339718821, 1, 0.10000064526970168`], 
     Hue[0.649999442352031, 1, 0.10000077212795708`], 
     Hue[0.6499980833227129, 1, 0.100002653860859], 
     Hue[0.6499975602665753, 1, 0.10000337809243423`], 
     Hue[0.6499947544739892, 1, 0.100007263036015], 
     Hue[0.6499927474735677, 1, 0.10001004195967544`], 
     Hue[0.6499904192577803, 1, 0.10001326564307339`], 
     Hue[0.6499855624175456, 1, 0.10001999049878303`], 
     Hue[0.649982271892414, 1, 0.10002454661050371`], 
     Hue[0.6499905001789897, 1, 0.10001315359832193`], 
     Hue[0.649994966060422, 1, 0.10000697007018497`], 
     Hue[0.6499652560339055, 1, 0.10004810702997693`], 
     Hue[0.6499982896776413, 1, 0.10000236813865063`], 
     Hue[0.6499874785448396, 1, 0.10001733739945283`], 
     Hue[0.6499999490745912, 1, 0.10000007051210441`], 
     Hue[0.6498401940009914, 1, 0.10022126984478122`], 
     Hue[0.6498965941389109, 1, 0.10014317734612337`], 
     Hue[0.6498307067503871, 1, 0.10023440603792551`], 
     Hue[0.6498376968729129, 1, 0.10022472740673594`], 
     Hue[0.6498948240795815, 1, 0.10014562819750247`], 
     Hue[0.6499575453317327, 1, 0.10005878338683179`], 
     Hue[0.6498475221859048, 1, 0.10021112312720874`], 
     Hue[0.6499996319583529, 1, 0.1000005095961268], 
     Hue[0.6499982711804069, 1, 0.10000239375020598`], 
     Hue[0.6499982896776413, 1, 0.10000236813865063`], 
     Hue[0.64999791089883, 1, 0.10000289260162012`], 
     Hue[0.6499874785448396, 1, 0.10001733739945283`], 
     Hue[0.6499892785262673, 1, 0.10001484511747614`], 
     Hue[0.6499949320825263, 1, 0.10000701711650203`], 
     Hue[0.6499652560339055, 1, 0.10004810702997692`], 
     Hue[0.6499575453317327, 1, 0.10005878338683176`], 
     Hue[0.6498475221859049, 1, 0.10021112312720867`], 
     Hue[0.6498693537502516, 1, 0.10018089480734399`], 
     Hue[0.649994966060422, 1, 0.10000697007018497`], 
     Hue[0.6499931798173987, 1, 0.10000944332975563`], 
     Hue[0.6499728876119557, 1, 0.10003754022959982`], 
     Hue[0.6499904693183663, 1, 0.10001319632841578`], 
     Hue[0.649982351773809, 1, 0.10002443600549525`], 
     Hue[0.6498401940009914, 1, 0.1002212698447812], 
     Hue[0.6474229577245604, 1, 0.10356821238137796`], 
     Hue[0.6499905001789897, 1, 0.10001315359832193`], 
     Hue[0.6499858078426721, 1, 0.10001965067937708`], 
     Hue[0.6466909526577986, 1, 0.10458175785843268`], 
     Hue[0.646455724919808, 1, 0.1049074578033429], 
     Hue[0.645383322492119, 1, 0.1063923227032198], 
     Hue[0.6474229577245602, 1, 0.10356821238137834`], 
     Hue[0.6453822585486587, 1, 0.10639379585570329`], 
     Hue[0.6451837682394984, 1, 0.10666862859146374`], 
     Hue[0.6458367128760315, 1, 0.10576455140241796`], 
     Hue[0.6410145533798334, 1, 0.11244138762792309`], 
     Hue[0.6451760894519943, 1, 0.10667926075877707`], 
     Hue[0.6427222120230419, 1, 0.11007693719886505`], 
     Hue[0.6499904494586252, 1, 0.10001322382651898`], 
     Hue[0.6499856125038711, 1, 0.10001992114848617`], 
     Hue[0.6464557249198024, 1, 0.10490745780335048`], 
     Hue[0.6466909526577906, 1, 0.10458175785844377`], 
     Hue[0.6233201302808182, 1, 0.13694135807271327`], 
     Hue[0.6388748463426085, 1, 0.11540405891023438`], 
     Hue[0.6398576691566518, 1, 0.11404322732155919`], 
     Hue[0.6282755077833603, 1, 0.1300800661461166], 
     Hue[0.6498948240795815, 1, 0.10014562819750256`], 
     Hue[0.649982271892414, 1, 0.10002454661050372`], 
     Hue[0.6499947848408922, 1, 0.10000722098953381`], 
     Hue[0.6499927911642357, 1, 0.10000998146490438`], 
     Hue[0.6498307067503871, 1, 0.10023440603792552`], 
     Hue[0.6498594518723236, 1, 0.10019460509985961`], 
     Hue[0.6453822585486075, 1, 0.10639379585577424`], 
     Hue[0.6453833224920709, 1, 0.1063923227032865], 
     Hue[0.6456533105267098, 1, 0.10601849311686341`], 
     Hue[0.6499852938294347, 1, 0.10002036239001359`], 
     Hue[0.6499879539739198, 1, 0.10001667911303415`], 
     Hue[0.6499981001297528, 1, 0.10000263058957315`], 
     Hue[0.6499975817595002, 1, 0.10000334833299979`], 
     Hue[0.6451760894519326, 1, 0.10667926075886258`], 
     Hue[0.6447422602882784, 1, 0.10727994729315303`], 
     Hue[0.6427222120230224, 1, 0.11007693719889208`], 
     Hue[0.6432412882885953, 1, 0.10935821621579125`], 
     Hue[0.6499958918832327, 1, 0.10000568816167785`], 
     Hue[0.6499964672535286, 1, 0.10000489149511434`], 
     Hue[0.6499995394710767, 1, 0.10000063765543235`], 
     Hue[0.6499994488275219, 1, 0.10000076316189273`], 
     Hue[0.6410145533799854, 1, 0.11244138762771266`], 
     Hue[0.6398576691567839, 1, 0.11404322732137623`], 
     Hue[0.6282755077836939, 1, 0.13008006614565468`], 
     Hue[0.6309334967136163, 1, 0.12639977378114664`], 
     Hue[0.6422329045977426, 1, 0.11075443978774097`], 
     Hue[0.6458367128759976, 1, 0.1057645514024648], 
     Hue[0.6388748463430168, 1, 0.11540405890966907`], 
     Hue[0.6363391370261278, 1, 0.11891504104074618`], 
     Hue[0.6233201302808241, 1, 0.13694135807270516`], 
     Hue[0.6499998703971854, 1, 0.100000179450051], 
     Hue[0.6388748463426072, 1, 0.11540405891023633`], 
     Hue[0.6363391370257134, 1, 0.11891504104131992`], 
     Hue[0.645836712875852, 1, 0.10576455140266648`], 
     Hue[0.6499995339718821, 1, 0.10000064526970168`], 
     Hue[0.6410145533798326, 1, 0.11244138762792409`], 
     Hue[0.6422329045975737, 1, 0.11075443978797506`], 
     Hue[0.6282755077833523, 1, 0.13008006614612758`], 
     Hue[0.6309334967132403, 1, 0.12639977378166728`], 
     Hue[0.6398576691566503, 1, 0.1140432273215611], 
     Hue[0.6499995394710767, 1, 0.10000063765543235`], 
     Hue[0.6499994488275219, 1, 0.10000076316189273`], 
     Hue[0.6499958918832327, 1, 0.10000568816167785`], 
     Hue[0.6499964672535286, 1, 0.10000489149511434`], 
     Hue[0.6499980833227129, 1, 0.100002653860859], 
     Hue[0.6427222120230416, 1, 0.1100769371988655], 
     Hue[0.643241288288611, 1, 0.10935821621576942`], 
     Hue[0.6451760894519946, 1, 0.10667926075877684`], 
     Hue[0.644742260288343, 1, 0.1072799472930636], 
     Hue[0.6499981001297528, 1, 0.10000263058957315`], 
     Hue[0.6499975817595002, 1, 0.10000334833299979`], 
     Hue[0.6499852938294347, 1, 0.10002036239001358`], 
     Hue[0.6499879539739198, 1, 0.10001667911303413`], 
     Hue[0.6499947544739892, 1, 0.100007263036015], 
     Hue[0.6453833224921196, 1, 0.10639232270321906`], 
     Hue[0.6456533105267612, 1, 0.10601849311679216`], 
     Hue[0.6498307067503872, 1, 0.10023440603792542`], 
     Hue[0.6498594518723237, 1, 0.10019460509985952`], 
     Hue[0.6499947848408922, 1, 0.1000072209895338], 
     Hue[0.6499927911642358, 1, 0.10000998146490438`], 
     Hue[0.6499904192577803, 1, 0.10001326564307339`], 
     Hue[0.649982271892414, 1, 0.10002454661050371`], 
     Hue[0.6498376968729129, 1, 0.10022472740673594`], 
     Hue[0.6282755077836376, 1, 0.13008006614573261`], 
     Hue[0.6410145533800203, 1, 0.11244138762766413`], 
     Hue[0.6388748463430075, 1, 0.115404058909682], 
     Hue[0.6499904494586252, 1, 0.10001322382651896`], 
     Hue[0.6499856125038711, 1, 0.10001992114848615`], 
     Hue[0.6427222120230901, 1, 0.1100769371987983], 
     Hue[0.6451760894520181, 1, 0.10667926075874427`], 
     Hue[0.6422329045977838, 1, 0.11075443978768394`], 
     Hue[0.6458367128758516, 1, 0.10576455140266693`], 
     Hue[0.6453833224921226, 1, 0.10639232270321484`], 
     Hue[0.6499905001789897, 1, 0.10001315359832193`], 
     Hue[0.6499858078426721, 1, 0.1000196506793771], 
     Hue[0.6498965941389109, 1, 0.10014317734612337`], 
     Hue[0.649982351773809, 1, 0.10002443600549525`], 
     Hue[0.6499652560339055, 1, 0.10004810702997693`], 
     Hue[0.6499728876119557, 1, 0.10003754022959983`], 
     Hue[0.649994966060422, 1, 0.10000697007018497`], 
     Hue[0.6499931798173987, 1, 0.10000944332975564`], 
     Hue[0.6498475221859048, 1, 0.10021112312720871`], 
     Hue[0.6498693537502516, 1, 0.10018089480734403`], 
     Hue[0.6499575453317327, 1, 0.10005878338683179`], 
     Hue[0.6499874785448396, 1, 0.10001733739945283`], 
     Hue[0.6499892785262672, 1, 0.10001484511747614`], 
     Hue[0.6499982896776413, 1, 0.10000236813865063`], 
     Hue[0.64999791089883, 1, 0.10000289260162012`], 
     Hue[0.6498475221859049, 1, 0.10021112312720867`], 
     Hue[0.6499652560339055, 1, 0.10004810702997692`], 
     Hue[0.6498948240795815, 1, 0.10014562819750256`], 
     Hue[0.6498307067503872, 1, 0.1002344060379254], 
     Hue[0.6498965941389109, 1, 0.10014317734612338`], 
     Hue[0.6499999490745912, 1, 0.10000007051210441`], 
     Hue[0.6499999853568917, 1, 0.10000002027507307`], 
     Hue[0.6499874785448396, 1, 0.10001733739945283`], 
     Hue[0.6499982896776413, 1, 0.10000236813865063`], 
     Hue[0.6499728876119557, 1, 0.10003754022959982`], 
     Hue[0.649994966060422, 1, 0.10000697007018497`], 
     Hue[0.6499905001789897, 1, 0.10001315359832193`], 
     Hue[0.649982271892414, 1, 0.10002454661050372`], 
     Hue[0.6499998703971854, 1, 0.100000179450051], 
     Hue[0.6499999589602237, 1, 0.1000000568243058], 
     Hue[0.6499958918832327, 1, 0.10000568816167785`], 
     Hue[0.6499995394710767, 1, 0.10000063765543235`], 
     Hue[0.6499852938294347, 1, 0.10002036239001358`], 
     Hue[0.6499981001297528, 1, 0.10000263058957315`], 
     Hue[0.6499947848408922, 1, 0.1000072209895338], 
     Hue[0.6499904494586252, 1, 0.10001322382651896`], 
     Hue[0.649982351773809, 1, 0.10002443600549525`], 
     Hue[0.6499998378409675, 1, 0.10000022452789123`], 
     Hue[0.6499999079226575, 1, 0.10000012749170509`], 
     Hue[0.6499999079226575, 1, 0.10000012749170509`], 
     Hue[0.6499999105318043, 1, 0.10000012387904018`], 
     Hue[0.6499988198134662, 1, 0.1000016341044314], 
     Hue[0.649999732409757, 1, 0.10000037050956732`], 
     Hue[0.6499992964406758, 1, 0.10000097415906437`], 
     Hue[0.6499997205474622, 1, 0.10000038693428308`], 
     Hue[0.6499997241332024, 1, 0.10000038196941208`], 
     Hue[0.6499992203039526, 1, 0.10000107957914259`], 
     Hue[0.649999015708746, 1, 0.10000136286481327`], 
     Hue[0.649998333888502, 1, 0.10000230692361262`], 
     Hue[0.6499942406207414, 1, 0.10000797452512729`], 
     Hue[0.6499964646335001, 1, 0.10000489512284605`], 
     Hue[0.6499980650680817, 1, 0.10000267913650228`], 
     Hue[0.6499981753461317, 1, 0.10000252644381777`], 
     Hue[0.6499952966832021, 1, 0.10000651228479705`], 
     Hue[0.6499959630133506, 1, 0.10000558967382225`], 
     Hue[0.6499933017246096, 1, 0.10000927453515605`], 
     Hue[0.6499818743816113, 1, 0.10002509701007671`], 
     Hue[0.6499886776939561, 1, 0.10001567703913772`], 
     Hue[0.6499908589738949, 1, 0.10001265680537647`], 
     Hue[0.6499484530937932, 1, 0.10007137263936332`], 
     Hue[0.6499180307352563, 1, 0.10011349590502969`], 
     Hue[0.6499927911642357, 1, 0.10000998146490438`], 
     Hue[0.6499806446197294, 1, 0.10002679975729786`], 
     Hue[0.6499879539739198, 1, 0.10001667911303415`], 
     Hue[0.6499956092416016, 1, 0.10000607951162864`], 
     Hue[0.6499334584002099, 1, 0.10009213452278638`], 
     Hue[0.6499975817595002, 1, 0.1000033483329998], 
     Hue[0.6499931770229507, 1, 0.10000944719899144`], 
     Hue[0.6499964672535286, 1, 0.10000489149511434`], 
     Hue[0.6499987913150758, 1, 0.10000167356374128`], 
     Hue[0.6499999113420365, 1, 0.10000012275718022`], 
     Hue[0.6499998555397438, 1, 0.10000020002189328`], 
     Hue[0.6499996941293525, 1, 0.10000042351320422`], 
     Hue[0.6499998322292071, 1, 0.10000023229802099`], 
     Hue[0.6499997586209825, 1, 0.10000033421710122`], 
     Hue[0.6499998535240952, 1, 0.10000020281279137`], 
     Hue[0.6499983016594818, 1, 0.10000235154840982`], 
     Hue[0.6499995771839885, 1, 0.10000058543755444`], 
     Hue[0.6499990154332835, 1, 0.10000136324622286`], 
     Hue[0.649999454487984, 1, 0.10000075532432992`], 
     Hue[0.6499995171479255, 1, 0.10000066856441088`], 
     Hue[0.6499985394928872, 1, 0.10000202224061779`], 
     Hue[0.6499987788443321, 1, 0.10000169083092485`], 
     Hue[0.6499978883756586, 1, 0.10000292378754969`], 
     Hue[0.6499931260501088, 1, 0.1000095177767724], 
     Hue[0.6499958515834572, 1, 0.10000574396136695`], 
     Hue[0.6499971342997227, 1, 0.10000396789269159`], 
     Hue[0.6499975148056737, 1, 0.100003441038298], 
     Hue[0.6499955764751569, 1, 0.1000061248805519], 
     Hue[0.6499925770634212, 1, 0.10001027791218614`], 
     Hue[0.6499805463167408, 1, 0.10002693586912803`], 
     Hue[0.6499879519206576, 1, 0.1000166819560126], 
     Hue[0.6499888903804653, 1, 0.10001538255012504`], 
     Hue[0.6499482456526285, 1, 0.10007165986559136`], 
     Hue[0.6499183018776694, 1, 0.10011312047707317`], 
     Hue[0.6499931798173987, 1, 0.10000944332975564`], 
     Hue[0.6499819848662312, 1, 0.10002494403137233`], 
     Hue[0.6499892785262672, 1, 0.10001484511747614`], 
     Hue[0.6499959994335225, 1, 0.10000553924589196`], 
     Hue[0.6499999500040863, 1, 0.10000006922511127`], 
     Hue[0.6499999853568917, 1, 0.10000002027507307`], 
     Hue[0.6499999926512596, 1, 0.10000001017517901`], 
     Hue[0.6499999853568917, 1, 0.10000002027507307`], 
     Hue[0.6499999926512596, 1, 0.10000001017517901`], 
     Hue[0.6499987373870405, 1, 0.1000017482333285], 
     Hue[0.6499997241332024, 1, 0.10000038196941208`], 
     Hue[0.6499992203039526, 1, 0.10000107957914259`], 
     Hue[0.6499998474023537, 1, 0.10000021128904879`], 
     Hue[0.649999590533435, 1, 0.1000005669537054], 
     Hue[0.649999732409757, 1, 0.10000037050956732`], 
     Hue[0.6499992964406758, 1, 0.10000097415906437`], 
     Hue[0.6499999105318043, 1, 0.10000012387904018`], 
     Hue[0.6499925051018157, 1, 0.10001037755133219`], 
     Hue[0.6499979682031483, 1, 0.10000281325717941`], 
     Hue[0.6499951269450512, 1, 0.10000674730685209`], 
     Hue[0.649997998599588, 1, 0.10000277116980137`], 
     Hue[0.6499979682031483, 1, 0.10000281325717941`], 
     Hue[0.6499951269450512, 1, 0.10000674730685209`], 
     Hue[0.6499892997103437, 1, 0.10001481578567803`], 
     Hue[0.6499684714090721, 1, 0.10004365497205403`], 
     Hue[0.6499786307209967, 1, 0.10002958823246613`], 
     Hue[0.6499887061646138, 1, 0.10001563761822711`], 
     Hue[0.64998889575535, 1, 0.10001537510797696`], 
     Hue[0.6499758863201647, 1, 0.1000333881720797], 
     Hue[0.64990986881594, 1, 0.10012479702408313`], 
     Hue[0.6499371615166366, 1, 0.10008700713081094`], 
     Hue[0.6499354525471791, 1, 0.10008937339621354`], 
     Hue[0.6499825790660813, 1, 0.10002412129311823`], 
     Hue[0.6499234644088201, 1, 0.1001059723570184], 
     Hue[0.6499998517472398, 1, 0.1000002052730525], 
     Hue[0.6499995050240461, 1, 0.10000068535132073`], 
     Hue[0.649999724803093, 1, 0.10000038104187135`], 
     Hue[0.6499972533523636, 1, 0.1000038030505735], 
     Hue[0.6499993159067812, 1, 0.10000094720599527`], 
     Hue[0.6499983662639025, 1, 0.10000226209613496`], 
     Hue[0.6499991262252099, 1, 0.10000120984201699`], 
     Hue[0.6499992335415801, 1, 0.10000106125012002`], 
     Hue[0.6499977398917669, 1, 0.10000312938063041`], 
     Hue[0.6499963413007848, 1, 0.1000050658912211], 
     Hue[0.6499878647654108, 1, 0.10001680263250819`], 
     Hue[0.6499923453330904, 1, 0.10001059876956729`], 
     Hue[0.6499954680826809, 1, 0.10000627496244185`], 
     Hue[0.6499959176232237, 1, 0.1000056525216902], 
     Hue[0.6499850753312237, 1, 0.1000206649259979], 
     Hue[0.6499592661856974, 1, 0.1000564006659575], 
     Hue[0.6499729800552231, 1, 0.10003741223122968`], 
     Hue[0.649981132862961, 1, 0.10002612372820784`], 
     Hue[0.649898911013796, 1, 0.10013996936551317`], 
     Hue[0.649930414075084, 1, 0.10009634974219148`], 
     Hue[0.6499366633612995, 1, 0.10008769688435451`], 
     Hue[0.6499394811751557, 1, 0.1000837952959383], 
     Hue[0.6499999500040863, 1, 0.10000006922511127`], 
     Hue[0.6499930394481843, 1, 0.10000963768712945`], 
     Hue[0.6499981753461317, 1, 0.10000252644381777`], 
     Hue[0.6499952966832021, 1, 0.10000651228479705`], 
     Hue[0.649999015708746, 1, 0.10000136286481327`], 
     Hue[0.6499978877143096, 1, 0.10000292470326372`], 
     Hue[0.649998333888502, 1, 0.10000230692361262`], 
     Hue[0.6499964646335001, 1, 0.10000489512284605`], 
     Hue[0.6499658530333119, 1, 0.10004728041541434`], 
     Hue[0.64998889575535, 1, 0.10001537510797696`], 
     Hue[0.6499758863201647, 1, 0.1000333881720797], 
     Hue[0.6499899497720244, 1, 0.10001391570027392`], 
     Hue[0.6499892997103437, 1, 0.10001481578567803`], 
     Hue[0.6499684714090721, 1, 0.10004365497205403`], 
     Hue[0.6498018332354732, 1, 0.10027438475088327`], 
     Hue[0.6499986841176894, 1, 0.10000182199089175`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499992118878316, 1, 0.10000109123223312`], 
     Hue[0.6499992084380691, 1, 0.10000109600882744`], 
     Hue[0.6499956798469451, 1, 0.10000598175038376`], 
     Hue[0.6499974203571485, 1, 0.10000357181317905`], 
     Hue[0.6499817331204784, 1, 0.10002529260241469`], 
     Hue[0.6499944407952419, 1, 0.10000769736043427`], 
     Hue[0.6499883164518722, 1, 0.10001617722048475`], 
     Hue[0.6499928827959313, 1, 0.10000985459024905`], 
     Hue[0.6499937882615862, 1, 0.10000860086857298`], 
     Hue[0.649984029121582, 1, 0.10002211352396337`], 
     Hue[0.6499768388087087, 1, 0.10003206934178795`], 
     Hue[0.6499366088679227, 1, 0.10008777233672245`], 
     Hue[0.6499568986091695, 1, 0.10005967884884229`], 
     Hue[0.6499719284481867, 1, 0.10003886830251077`], 
     Hue[0.6498288316135646, 1, 0.1002370023812183], 
     Hue[0.6498768869650648, 1, 0.10017046420221798`], 
     Hue[0.6498286531654709, 1, 0.10023724946319418`], 
     Hue[0.6499942951189157, 1, 0.10000789906611669`], 
     Hue[0.6499965007467773, 1, 0.10000484511984688`], 
     Hue[0.6499740840158208, 1, 0.10003588367040199`], 
     Hue[0.6499959630133506, 1, 0.10000558967382225`], 
     Hue[0.6499931307624713, 1, 0.1000095112519628], 
     Hue[0.6499818743816113, 1, 0.10002509701007671`], 
     Hue[0.6498899315253245, 1, 0.10015240250339691`], 
     Hue[0.64990986881594, 1, 0.10012479702408313`], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499930428076303, 1, 0.10000963303558898`], 
     Hue[0.649993024783002, 1, 0.10000965799276645`], 
     Hue[0.6499710401022167, 1, 0.1000400983200076], 
     Hue[0.6499815839206784, 1, 0.10002549918675308`], 
     Hue[0.64996575997617, 1, 0.10004740926376463`], 
     Hue[0.6499078273563339, 1, 0.10012762366046074`], 
     Hue[0.6499369681039932, 1, 0.10008727493293267`], 
     Hue[0.6499551253828276, 1, 0.10006213408531567`], 
     Hue[0.6499614584941964, 1, 0.1000533651618819], 
     Hue[0.6497502919378658, 1, 0.10034574962449345`], 
     Hue[0.649818266637786, 1, 0.10025163080921945`], 
     Hue[0.649828653165471, 1, 0.10023724946319411`], 
     Hue[0.6499394811751558, 1, 0.10008379529593828`], 
     Hue[0.6499442388258546, 1, 0.10007720777958594`], 
     Hue[0.6499102360885619, 1, 0.10012428849276052`], 
     Hue[0.6499374484373719, 1, 0.10008660985594665`], 
     Hue[0.6499959994335225, 1, 0.10000553924589196`], 
     Hue[0.6499933578423218, 1, 0.10000919683370825`], 
     Hue[0.6499819848662312, 1, 0.10002494403137231`], 
     Hue[0.649988752611403, 1, 0.10001557330728819`], 
     Hue[0.6499368000496959, 1, 0.10008750762349808`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6499522576756646, 1, 0.10006610475677218`], 
     Hue[0.6499521921357778, 1, 0.10006619550430762`], 
     Hue[0.6498464094443002, 1, 0.10021266384635359`], 
     Hue[0.6498967127539552, 1, 0.10014301310990814`], 
     Hue[0.6496383427872282, 1, 0.10050075614076096`], 
     Hue[0.6497373247140593, 1, 0.10036370424207171`], 
     Hue[0.6499366633612995, 1, 0.10008769688435448`], 
     Hue[0.6499155953597011, 1, 0.10011686796349073`], 
     Hue[0.6499183018776694, 1, 0.10011312047707317`], 
     Hue[0.6499453252164491, 1, 0.10007570354645513`], 
     Hue[0.6499484530937932, 1, 0.10007137263936332`], 
     Hue[0.6466917429014707, 1, 0.10458066367488676`], 
     Hue[0.6499180307352563, 1, 0.10011349590502969`], 
     Hue[0.6499452847292683, 1, 0.10007575960562864`], 
     Hue[0.6499354525471791, 1, 0.10008937339621354`], 
     Hue[0.6499128808040171, 1, 0.10012062657905335`], 
     Hue[0.6450730162623393, 1, 0.10682197748291487`], 
     Hue[0.6451848600758754, 1, 0.10666711681801869`], 
     Hue[0.6439530905198237, 1, 0.10837264389562865`], 
     Hue[0.6466917429014625, 1, 0.10458066367489817`], 
     Hue[0.6465519871630898, 1, 0.1047741716203372], 
     Hue[0.6499179671599283, 1, 0.10011358393240694`], 
     Hue[0.6499482456526284, 1, 0.1000716598655914], 
     Hue[0.6498018332354732, 1, 0.1002743847508833], 
     Hue[0.6369343337822009, 1, 0.11809092245541414`], 
     Hue[0.6313031433718986, 1, 0.12588795533121733`], 
     Hue[0.6423035647750807, 1, 0.11065660261911912`], 
     Hue[0.6370871379712647, 1, 0.11787934742440272`], 
     Hue[0.6451848600758338, 1, 0.10666711681807642`], 
     Hue[0.6439530905197821, 1, 0.10837264389568639`], 
     Hue[0.6441390283451809, 1, 0.10811519152205727`], 
     Hue[0.6499806446197294, 1, 0.10002679975729786`], 
     Hue[0.649988018614091, 1, 0.10001658961125877`], 
     Hue[0.6499956092416016, 1, 0.10000607951162864`], 
     Hue[0.6499926276132632, 1, 0.10001020792009714`], 
     Hue[0.6499234644088201, 1, 0.10010597235701842`], 
     Hue[0.6499334905618971, 1, 0.10009208999121949`], 
     Hue[0.6499825790660813, 1, 0.10002412129311823`], 
     Hue[0.6155593700329793, 1, 0.14768702610818243`], 
     Hue[0.6258195092726606, 1, 0.1334806794686238], 
     Hue[0.5913746289044831, 1, 0.18117359074763875`], 
     Hue[0.6423035647750619, 1, 0.11065660261914508`], 
     Hue[0.6370871379713364, 1, 0.11787934742430345`], 
     Hue[0.6378619063741078, 1, 0.11680659117431233`], 
     Hue[0.649898911013796, 1, 0.10013996936551324`], 
     Hue[0.6499805463167408, 1, 0.10002693586912804`], 
     Hue[0.6499955764751569, 1, 0.10000612488055191`], 
     Hue[0.6499987913150758, 1, 0.10000167356374128`], 
     Hue[0.6499931770229507, 1, 0.10000944719899144`], 
     Hue[0.6499958852039428, 1, 0.10000569740992535`], 
     Hue[0.6499979082329089, 1, 0.10000289629289531`], 
     Hue[0.6319953620941843, 1, 0.12492949863882186`], 
     Hue[0.625819509272948, 1, 0.13348067946822578`], 
     Hue[0.5913746289049686, 1, 0.1811735907469666], 
     Hue[0.5965604897306293, 1, 0.17399316806528264`], 
     Hue[0.6498288316135644, 1, 0.10023700238121848`], 
     Hue[0.6499931260501088, 1, 0.1000095177767724], 
     Hue[0.6499592661856973, 1, 0.10005640066595754`], 
     Hue[0.6499850753312237, 1, 0.10002066492599791`], 
     Hue[0.6499958515834572, 1, 0.10000574396136695`], 
     Hue[0.6499987788443321, 1, 0.10000169083092485`], 
     Hue[0.6155593700336652, 1, 0.14768702610723275`], 
     Hue[0.6090317928650011, 1, 0.15672520987922933`], 
     Hue[0.6497502919378649, 1, 0.10034574962449469`], 
     Hue[0.6499878647654108, 1, 0.1000168026325082], 
     Hue[0.6499366088679226, 1, 0.10008777233672257`], 
     Hue[0.6499768388087087, 1, 0.10003206934178799`], 
     Hue[0.6499983016594818, 1, 0.10000235154840982`], 
     Hue[0.6499975148056737, 1, 0.100003441038298], 
     Hue[0.6499923453330904, 1, 0.10001059876956729`], 
     Hue[0.6499963413007848, 1, 0.10000506589122111`], 
     Hue[0.649998861931212, 1, 0.10000157578755257`], 
     Hue[0.6499990154332835, 1, 0.10000136324622286`], 
     Hue[0.6499995771839885, 1, 0.10000058543755444`], 
     Hue[0.6499997694648034, 1, 0.10000031920257986`], 
     Hue[0.6458360441380219, 1, 0.10576547734735442`], 
     Hue[0.6496383427872298, 1, 0.10050075614075889`], 
     Hue[0.6499817331204782, 1, 0.10002529260241473`], 
     Hue[0.6499078273563338, 1, 0.10012762366046096`], 
     Hue[0.64996575997617, 1, 0.1000474092637646], 
     Hue[0.6499972533523636, 1, 0.1000038030505735], 
     Hue[0.6499959176232237, 1, 0.10000565252169022`], 
     Hue[0.6499871127135868, 1, 0.10001784393503371`], 
     Hue[0.6499883164518722, 1, 0.10001617722048477`], 
     Hue[0.6499944407952419, 1, 0.10000769736043427`], 
     Hue[0.6499996941293525, 1, 0.10000042351320422`], 
     Hue[0.6499985394928872, 1, 0.10000202224061779`], 
     Hue[0.6499995171479255, 1, 0.10000066856441088`], 
     Hue[0.6499981812644314, 1, 0.10000251824924884`], 
     Hue[0.6499983662639025, 1, 0.10000226209613496`], 
     Hue[0.6499993159067812, 1, 0.10000094720599527`], 
     Hue[0.6499998535240952, 1, 0.10000020281279137`], 
     Hue[0.6499998099007703, 1, 0.10000026321431808`], 
     Hue[0.6499998322292071, 1, 0.10000023229802099`], 
     Hue[0.6499998517472398, 1, 0.1000002052730525], 
     Hue[0.6499986841176894, 1, 0.10000182199089175`], 
     Hue[0.6499984977543622, 1, 0.1000020800324216], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499992084380691, 1, 0.10000109600882745`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.649993024783002, 1, 0.10000965799276647`], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.6499521921357778, 1, 0.10006619550430775`], 
     Hue[0.03701244893343003, 1, 0.9487519937844815], 
     Hue[0.021008559536129012`, 1, 0.9709112252576675], 
     Hue[0.010667080107161664`, 1, 0.9852301967746991], 
     Hue[0.018968293162326844`, 1, 0.9737362094675474], 
     Hue[0.0021628179028305716`, 1, 0.9970053290576192], 
     Hue[0.6471956278815293, 1, 0.10388297677942109`], 
     Hue[0.649971040102217, 1, 0.10004009832000738`], 
     Hue[0.6499614584941966, 1, 0.1000533651618817], 
     Hue[0.6499521921357782, 1, 0.10006619550430726`], 
     Hue[0.6499956798469451, 1, 0.10000598175038376`], 
     Hue[0.649984029121582, 1, 0.10002211352396334`], 
     Hue[0.6499937882615862, 1, 0.10000860086857298`], 
     Hue[0.649993024783002, 1, 0.10000965799276644`], 
     Hue[0.6499995050240461, 1, 0.10000068535132073`], 
     Hue[0.6499977398917669, 1, 0.10000312938063043`], 
     Hue[0.64999923354158, 1, 0.10000106125012002`], 
     Hue[0.6499992084380691, 1, 0.10000109600882745`], 
     Hue[0.6499997586209825, 1, 0.10000033421710122`], 
     Hue[0.6499999328468428, 1, 0.1000000929812946], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.6499999042768432, 1, 0.1000001325397556], 
     Hue[0.6499997599027079, 1, 0.10000033244240446`], 
     Hue[0.6499998715320819, 1, 0.10000017787865574`], 
     Hue[0.649999724803093, 1, 0.10000038104187135`], 
     Hue[0.6499989528715463, 1, 0.10000144987016665`], 
     Hue[0.6499975708283137, 1, 0.10000336346848884`], 
     Hue[0.6499986013933341, 1, 0.10000193653230671`], 
     Hue[0.6499974203571485, 1, 0.10000357181317905`], 
     Hue[0.6499913752726683, 1, 0.10001194193015173`], 
     Hue[0.6499815839206784, 1, 0.10002549918675308`], 
     Hue[0.6499445462876953, 1, 0.10007678206319122`], 
     Hue[0.6498464094443002, 1, 0.10021266384635365`], 
     Hue[0.6496727141920234, 1, 0.10045316496489064`], 
     Hue[0.004312626695688215, 1, 0.9940286707290471], 
     Hue[0.01896829316206161, 1, 0.9737362094679147], 
     Hue[0.0021628179027942673`, 1, 0.9970053290576695], 
     Hue[0.02100855953293701, 1, 0.9709112252620872], 
     Hue[0.0021628179019673732`, 1, 0.9970053290588144], 
     Hue[0.01896829315981796, 1, 0.9737362094710214], 
     Hue[0.6499986841176894, 1, 0.10000182199089175`], 
     Hue[0.6499984977543622, 1, 0.1000020800324216], 
     Hue[0.6499999661022928, 1, 0.10000004693528683`], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.6499998517472398, 1, 0.1000002052730525], 
     Hue[0.6499999589602237, 1, 0.1000000568243058], 
     Hue[0.6499999794211159, 1, 0.10000002849383967`], 
     Hue[0.6499996132007059, 1, 0.10000053556825345`], 
     Hue[0.6499997586209825, 1, 0.10000033421710122`], 
     Hue[0.6499998322292071, 1, 0.10000023229802099`], 
     Hue[0.6499966175523572, 1, 0.10000468338904392`], 
     Hue[0.6499992335415801, 1, 0.10000106125012002`], 
     Hue[0.6499977398917669, 1, 0.10000312938063041`], 
     Hue[0.6499993878957052, 1, 0.10000084752902356`], 
     Hue[0.6499993159067812, 1, 0.10000094720599527`], 
     Hue[0.6499983662639025, 1, 0.10000226209613496`], 
     Hue[0.6499777227220929, 1, 0.1000308454617176], 
     Hue[0.6499937882615862, 1, 0.10000860086857298`], 
     Hue[0.649984029121582, 1, 0.10002211352396337`], 
     Hue[0.6499949826603763, 1, 0.10000694708563292`], 
     Hue[0.6499944407952419, 1, 0.10000769736043427`], 
     Hue[0.6499883164518722, 1, 0.10001617722048475`], 
     Hue[0.649886621235013, 1, 0.10015698598228986`], 
     Hue[0.6499614584941964, 1, 0.10005336516188192`], 
     Hue[0.6499690892099143, 1, 0.10004279955550338`], 
     Hue[0.64996575997617, 1, 0.10004740926376463`], 
     Hue[0.6499078273563339, 1, 0.10012762366046075`], 
     Hue[0.6495400008935742, 1, 0.10063692183966651`], 
     Hue[0.6496383427872282, 1, 0.10050075614076094`], 
     Hue[0.64507301626234, 1, 0.10682197748291387`], 
     Hue[0.6369343337821991, 1, 0.11809092245541672`], 
     Hue[0.6155593700329609, 1, 0.14768702610820794`], 
     Hue[0.6090317928642983, 1, 0.15672520988020228`], 
     Hue[0.06747929559215904, 1, 0.9065671291800874], 
     Hue[0.06744763098364448, 1, 0.9066109724841845], 
     Hue[0.6495407493861158, 1, 0.10063588546537816`], 
     Hue[0.6499978004542722, 1, 0.10000304552485391`], 
     Hue[0.6499995171479255, 1, 0.10000066856441088`], 
     Hue[0.6499985394928872, 1, 0.10000202224061779`], 
     Hue[0.6499997664208694, 1, 0.1000003234172578], 
     Hue[0.649999442352031, 1, 0.10000077212795708`], 
     Hue[0.6499995771839885, 1, 0.10000058543755444`], 
     Hue[0.6499990154332835, 1, 0.10000136324622286`], 
     Hue[0.6499998535240952, 1, 0.10000020281279137`], 
     Hue[0.6499849888742334, 1, 0.10002078463567682`], 
     Hue[0.6499959176232237, 1, 0.1000056525216902], 
     Hue[0.6499967448026513, 1, 0.10000450719632889`], 
     Hue[0.6499963413007848, 1, 0.10000506589122111`], 
     Hue[0.6499923453330904, 1, 0.10001059876956729`], 
     Hue[0.6499234404741348, 1, 0.10010600549735192`], 
     Hue[0.6499768388087087, 1, 0.10003206934178796`], 
     Hue[0.6499366088679227, 1, 0.10008777233672247`], 
     Hue[0.6497011754290651, 1, 0.10041375709821751`], 
     Hue[0.6497502919378658, 1, 0.10034574962449351`], 
     Hue[0.5913746289044425, 1, 0.18117359074769507`], 
     Hue[0.5965604897300106, 1, 0.17399316806613918`], 
     Hue[0.6258195092726493, 1, 0.1334806794686394], 
     Hue[0.6499983183666825, 1, 0.1000023284153627], 
     Hue[0.6499990259760979, 1, 0.1000013486484798], 
     Hue[0.649990533972543, 1, 0.1000131068072481], 
     Hue[0.6499975148056737, 1, 0.100003441038298], 
     Hue[0.6499987788443321, 1, 0.10000169083092485`], 
     Hue[0.6499975602665753, 1, 0.10000337809243423`], 
     Hue[0.6499978883756586, 1, 0.10000292378754969`], 
     Hue[0.6499958515834572, 1, 0.10000574396136695`], 
     Hue[0.6499482995199596, 1, 0.10007158528005596`], 
     Hue[0.6499850753312237, 1, 0.1000206649259979], 
     Hue[0.6499592661856973, 1, 0.10005640066595752`], 
     Hue[0.6497919036628963, 1, 0.10028813338983586`], 
     Hue[0.6498288316135645, 1, 0.10023700238121833`], 
     Hue[0.6370871379712585, 1, 0.11787934742441139`], 
     Hue[0.6378619063740117, 1, 0.11680659117444533`], 
     Hue[0.6423035647750802, 1, 0.11065660261911969`], 
     Hue[0.6499825790660813, 1, 0.10002412129311823`], 
     Hue[0.6499234644088201, 1, 0.10010597235701837`], 
     Hue[0.6499334905618971, 1, 0.10009208999121945`], 
     Hue[0.6499987913150758, 1, 0.10000167356374128`], 
     Hue[0.6499979082329089, 1, 0.10000289629289531`], 
     Hue[0.6499931770229507, 1, 0.10000944719899142`], 
     Hue[0.6499958852039428, 1, 0.10000569740992533`], 
     Hue[0.6499701121736939, 1, 0.10004138314411615`], 
     Hue[0.6499955764751569, 1, 0.1000061248805519], 
     Hue[0.6499927474735677, 1, 0.10001004195967544`], 
     Hue[0.6499805463167408, 1, 0.10002693586912803`], 
     Hue[0.6498637789166501, 1, 0.10018861380771518`], 
     Hue[0.649898911013796, 1, 0.10013996936551318`], 
     Hue[0.6439530905198263, 1, 0.1083726438956252], 
     Hue[0.6441390283452353, 1, 0.10811519152198196`], 
     Hue[0.6451848600758766, 1, 0.1066671168180171], 
     Hue[0.6498018332354732, 1, 0.10027438475088318`], 
     Hue[0.6498992374175553, 1, 0.10013951742184662`], 
     Hue[0.6499306690177541, 1, 0.10009599674464822`], 
     Hue[0.6499956092416016, 1, 0.10000607951162864`], 
     Hue[0.6499926276132632, 1, 0.10001020792009714`], 
     Hue[0.6499806446197294, 1, 0.10002679975729785`], 
     Hue[0.649988018614091, 1, 0.10001658961125875`], 
     Hue[0.6499332456084079, 1, 0.10009242915758908`], 
     Hue[0.6466917429014706, 1, 0.10458066367488687`], 
     Hue[0.646551987163097, 1, 0.1047741716203272], 
     Hue[0.5913746289048778, 1, 0.18117359074709227`], 
     Hue[0.6258195092728863, 1, 0.1334806794683113], 
     Hue[0.615559370033591, 1, 0.14768702610733564`], 
     Hue[0.6319953620942502, 1, 0.12492949863873053`], 
     Hue[0.6353293129837483, 1, 0.1203132589455794], 
     Hue[0.6499334584002099, 1, 0.10009213452278633`], 
     Hue[0.6499560274362279, 1, 0.10006088508829984`], 
     Hue[0.6499354525471792, 1, 0.10008937339621347`], 
     Hue[0.6499128808040171, 1, 0.10012062657905328`], 
     Hue[0.6370871379713289, 1, 0.11787934742431384`], 
     Hue[0.6423035647751155, 1, 0.11065660261907082`], 
     Hue[0.6499180307352564, 1, 0.10011349590502963`], 
     Hue[0.6499452847292683, 1, 0.10007575960562862`], 
     Hue[0.6499482456526285, 1, 0.10007165986559136`], 
     Hue[0.643953090519833, 1, 0.10837264389561596`], 
     Hue[0.6451848600758786, 1, 0.10666711681801425`], 
     Hue[0.6499183018776694, 1, 0.10011312047707316`], 
     Hue[0.6499453252164491, 1, 0.10007570354645512`], 
     Hue[0.6499366633612995, 1, 0.1000876968843545], 
     Hue[0.6499155953597011, 1, 0.10011686796349076`], 
     Hue[0.6466917429014706, 1, 0.10458066367488697`], 
     Hue[0.6458360441380555, 1, 0.10576547734730775`], 
     Hue[0.6464975004717023, 1, 0.10484961473148917`], 
     Hue[0.6471956278815415, 1, 0.10388297677940406`], 
     Hue[0.6499182640119672, 1, 0.100113172906507], 
     Hue[0.6499484530937932, 1, 0.1000713726393633], 
     Hue[0.6498286531654709, 1, 0.10023724946319415`], 
     Hue[0.6495400008935912, 1, 0.10063692183964294`], 
     Hue[0.6496696618168546, 1, 0.10045739133050904`], 
     Hue[0.6496731893555265, 1, 0.10045250704619402`], 
     Hue[0.6499819848662312, 1, 0.10002494403137233`], 
     Hue[0.649988752611403, 1, 0.10001557330728819`], 
     Hue[0.6499959994335225, 1, 0.10000553924589196`], 
     Hue[0.6499933578423218, 1, 0.10000919683370825`], 
     Hue[0.6499394811751557, 1, 0.10008379529593829`], 
     Hue[0.6499442388258546, 1, 0.10007720777958597`], 
     Hue[0.6496383427872341, 1, 0.10050075614075284`], 
     Hue[0.6497373247140626, 1, 0.10036370424206716`], 
     Hue[0.6497011754290666, 1, 0.1004137570982155], 
     Hue[0.649782295843946, 1, 0.10030143652376722`], 
     Hue[0.6499521921357784, 1, 0.10006619550430693`], 
     Hue[0.6498866212350147, 1, 0.10015698598228738`], 
     Hue[0.6499227855829625, 1, 0.10010691226974439`], 
     Hue[0.6499614584941968, 1, 0.10005336516188132`], 
     Hue[0.6499522576756641, 1, 0.10006610475677287`], 
     Hue[0.6499446791317119, 1, 0.100076598125322], 
     Hue[0.6498467359396378, 1, 0.10021221177588613`], 
     Hue[0.6499098688159399, 1, 0.10012479702408315`], 
     Hue[0.6499818743816113, 1, 0.10002509701007672`], 
     Hue[0.6499959630133506, 1, 0.10000558967382225`], 
     Hue[0.6497502919378662, 1, 0.1003457496244931], 
     Hue[0.6498182666377861, 1, 0.10025163080921927`], 
     Hue[0.6497919036628964, 1, 0.10028813338983578`], 
     Hue[0.6498491275148006, 1, 0.10020890036412222`], 
     Hue[0.649977722722093, 1, 0.10003084546171745`], 
     Hue[0.6499078273563345, 1, 0.10012762366046009`], 
     Hue[0.6499369681039934, 1, 0.10008727493293235`], 
     Hue[0.6499657599761702, 1, 0.1000474092637643], 
     Hue[0.6499234404741349, 1, 0.10010600549735177`], 
     Hue[0.649947712762502, 1, 0.10007239771345888`], 
     Hue[0.649993024783002, 1, 0.10000965799276641`], 
     Hue[0.6499857386104357, 1, 0.10001974653939667`], 
     Hue[0.6499840291215822, 1, 0.10002211352396323`], 
     Hue[0.6499937882615863, 1, 0.10000860086857295`], 
     Hue[0.6499930428076302, 1, 0.10000963303558902`], 
     Hue[0.6499914127424962, 1, 0.10001189004885144`], 
     Hue[0.6499816678392326, 1, 0.10002538299183177`], 
     Hue[0.6499986841176894, 1, 0.10000182199089175`], 
     Hue[0.6499942406207414, 1, 0.10000797452512729`], 
     Hue[0.6499684714090721, 1, 0.10004365497205404`], 
     Hue[0.6499892997103437, 1, 0.10001481578567803`], 
     Hue[0.6499964646335001, 1, 0.10000489512284606`], 
     Hue[0.649999015708746, 1, 0.10000136286481327`], 
     Hue[0.6498286531654709, 1, 0.10023724946319411`], 
     Hue[0.6498288316135645, 1, 0.10023700238121833`], 
     Hue[0.6498768869650648, 1, 0.10017046420221802`], 
     Hue[0.6498637789166501, 1, 0.10018861380771522`], 
     Hue[0.6499035776827975, 1, 0.10013350782381888`], 
     Hue[0.6499366088679227, 1, 0.10008777233672243`], 
     Hue[0.6499568986091695, 1, 0.10005967884884229`], 
     Hue[0.6499849888742334, 1, 0.1000207846356768], 
     Hue[0.6499768388087087, 1, 0.10003206934178793`], 
     Hue[0.6499482995199596, 1, 0.10007158528005596`], 
     Hue[0.6499651447615216, 1, 0.10004826109943166`], 
     Hue[0.6499966175523572, 1, 0.10000468338904392`], 
     Hue[0.6499883164518722, 1, 0.10001617722048474`], 
     Hue[0.6499944407952419, 1, 0.10000769736043426`], 
     Hue[0.6499904461340845, 1, 0.1000132284297292], 
     Hue[0.6499959176232237, 1, 0.1000056525216902], 
     Hue[0.6499992084380691, 1, 0.10000109600882744`], 
     Hue[0.6499979781484426, 1, 0.10000279948677177`], 
     Hue[0.6499977398917669, 1, 0.10000312938063041`], 
     Hue[0.6499992335415801, 1, 0.10000106125012001`], 
     Hue[0.6499992118878316, 1, 0.10000109123223312`], 
     Hue[0.6499984977543622, 1, 0.1000020800324216], 
     Hue[0.6499974391975304, 1, 0.10000354572649647`], 
     Hue[0.6498018332354732, 1, 0.10027438475088317`], 
     Hue[0.6498899315253245, 1, 0.10015240250339698`], 
     Hue[0.649920525041201, 1, 0.10011004225064478`], 
     Hue[0.6499925051018156, 1, 0.1000103775513322], 
     Hue[0.6499758863201647, 1, 0.10003338817207973`], 
     Hue[0.64998889575535, 1, 0.10001537510797698`], 
     Hue[0.6499658530333119, 1, 0.10004728041541437`], 
     Hue[0.649976311639638, 1, 0.10003279926819361`], 
     Hue[0.6499758863201647, 1, 0.10003338817207973`], 
     Hue[0.64998889575535, 1, 0.10001537510797698`], 
     Hue[0.6499988198134662, 1, 0.1000016341044314], 
     Hue[0.6499952966832021, 1, 0.10000651228479705`], 
     Hue[0.6499981753461317, 1, 0.10000252644381777`], 
     Hue[0.649995048229519, 1, 0.10000685629758907`], 
     Hue[0.6499951269450512, 1, 0.1000067473068521], 
     Hue[0.6499979682031483, 1, 0.10000281325717941`], 
     Hue[0.6499992554553338, 1, 0.10000103090799936`], 
     Hue[0.6499992964406758, 1, 0.10000097415906437`], 
     Hue[0.649999732409757, 1, 0.10000037050956732`], 
     Hue[0.6499999500040863, 1, 0.10000006922511127`], 
     Hue[0.6499394811751558, 1, 0.10008379529593828`], 
     Hue[0.6499575453317327, 1, 0.10005878338683176`], 
     Hue[0.6499102360885619, 1, 0.10012428849276052`], 
     Hue[0.6499366633612995, 1, 0.10008769688435448`], 
     Hue[0.649898911013796, 1, 0.10013996936551324`], 
     Hue[0.6499304140750839, 1, 0.10009634974219153`], 
     Hue[0.6499332456084078, 1, 0.10009242915758913`], 
     Hue[0.6499558704947553, 1, 0.10006110239187734`], 
     Hue[0.6499592661856973, 1, 0.10005640066595753`], 
     Hue[0.649972980055223, 1, 0.10003741223122971`], 
     Hue[0.649990533972543, 1, 0.10001310680724812`], 
     Hue[0.6499850753312237, 1, 0.1000206649259979], 
     Hue[0.6499701121736939, 1, 0.10004138314411617`], 
     Hue[0.6499807215560938, 1, 0.10002669323002401`], 
     Hue[0.6499978004542722, 1, 0.1000030455248539], 
     Hue[0.6499923453330904, 1, 0.10001059876956729`], 
     Hue[0.6499963413007848, 1, 0.1000050658912211], 
     Hue[0.6499941257642842, 1, 0.10000813355714501`], 
     Hue[0.6499975148056737, 1, 0.100003441038298], 
     Hue[0.6499996132007059, 1, 0.10000053556825345`], 
     Hue[0.6499983662639025, 1, 0.10000226209613496`], 
     Hue[0.6499993159067812, 1, 0.10000094720599527`], 
     Hue[0.6499987037961257, 1, 0.1000017947438261], 
     Hue[0.6499985394928872, 1, 0.10000202224061779`], 
     Hue[0.6499995171479255, 1, 0.10000066856441088`], 
     Hue[0.6499997857288967, 1, 0.10000029668306613`], 
     Hue[0.6499997586209825, 1, 0.10000033421710122`], 
     Hue[0.6499998517472398, 1, 0.1000002052730525], 
     Hue[0.6499234644088201, 1, 0.10010597235701836`], 
     Hue[0.6499825790660813, 1, 0.10002412129311822`], 
     Hue[0.6498992374175553, 1, 0.10013951742184661`], 
     Hue[0.6499354525471792, 1, 0.10008937339621347`], 
     Hue[0.6499098688159399, 1, 0.10012479702408318`], 
     Hue[0.6499371615166365, 1, 0.10008700713081096`], 
     Hue[0.6499368000496958, 1, 0.10008750762349812`], 
     Hue[0.6499579090308498, 1, 0.10005827980343879`], 
     Hue[0.6499930394481843, 1, 0.10000963768712946`], 
     Hue[0.6499684714090721, 1, 0.10004365497205406`], 
     Hue[0.6499786307209967, 1, 0.10002958823246615`], 
     Hue[0.6499892997103437, 1, 0.10001481578567803`], 
     Hue[0.6499740840158208, 1, 0.10003588367040202`], 
     Hue[0.6499830415932077, 1, 0.10002348087094316`], 
     Hue[0.6499987373870405, 1, 0.1000017482333285], 
     Hue[0.6499951269450512, 1, 0.1000067473068521], 
     Hue[0.6499979682031483, 1, 0.10000281325717941`], 
     Hue[0.6499955738243941, 1, 0.1000061285508389], 
     Hue[0.6499952966832021, 1, 0.10000651228479705`], 
     Hue[0.6499981753461317, 1, 0.10000252644381777`], 
     Hue[0.6499998378409675, 1, 0.10000022452789123`], 
     Hue[0.6499992203039526, 1, 0.10000107957914259`], 
     Hue[0.6499997241332024, 1, 0.10000038196941208`], 
     Hue[0.649999231209965, 1, 0.10000106447851004`], 
     Hue[0.6499992203039526, 1, 0.10000107957914259`], 
     Hue[0.6499997241332024, 1, 0.10000038196941208`], 
     Hue[0.6499999105318043, 1, 0.10000012387904018`], 
     Hue[0.6499999068044836, 1, 0.10000012903994587`], 
     Hue[0.6499999079226575, 1, 0.10000012749170509`], 
     Hue[0.6499999926512596, 1, 0.10000001017517901`], 
     Hue[0.6499999927381648, 1, 0.10000001005484888`], 
     Hue[0.6499999926512596, 1, 0.10000001017517901`], 
     Hue[0.6499999500040863, 1, 0.10000006922511127`], 
     Hue[0.64999791089883, 1, 0.10000289260162012`], 
     Hue[0.6499942951189157, 1, 0.10000789906611669`], 
     Hue[0.6499892785262673, 1, 0.10001484511747614`], 
     Hue[0.6499959994335225, 1, 0.10000553924589196`], 
     Hue[0.6499931798173987, 1, 0.10000944332975563`], 
     Hue[0.6499819848662312, 1, 0.10002494403137231`], 
     Hue[0.6499183018776694, 1, 0.10011312047707319`], 
     Hue[0.6499179671599283, 1, 0.10011358393240694`], 
     Hue[0.6499452554080251, 1, 0.10007580020427298`], 
     Hue[0.6499482456526284, 1, 0.10007165986559141`], 
     Hue[0.6499805463167408, 1, 0.10002693586912804`], 
     Hue[0.6499927474735677, 1, 0.10001004195967546`], 
     Hue[0.6499955764751569, 1, 0.10000612488055191`], 
     Hue[0.6499925770634212, 1, 0.10001027791218615`], 
     Hue[0.6499975602665753, 1, 0.10000337809243423`], 
     Hue[0.6499987788443321, 1, 0.10000169083092485`], 
     Hue[0.6499958515834572, 1, 0.10000574396136695`], 
     Hue[0.6499978883756586, 1, 0.10000292378754969`], 
     Hue[0.649999442352031, 1, 0.10000077212795708`], 
     Hue[0.6499997664208694, 1, 0.1000003234172578], 
     Hue[0.6499990154332835, 1, 0.10000136324622286`], 
     Hue[0.6499995771839885, 1, 0.10000058543755444`], 
     Hue[0.6499998322292071, 1, 0.10000023229802099`], 
     Hue[0.6499998535240952, 1, 0.10000020281279137`], 
     Hue[0.6499999794211159, 1, 0.10000002849383967`], 
     Hue[0.6499997694648034, 1, 0.10000031920257986`], 
     Hue[0.6499994488275219, 1, 0.10000076316189273`], 
     Hue[0.6499983183666825, 1, 0.1000023284153627], 
     Hue[0.6499999113420365, 1, 0.10000012275718022`], 
     Hue[0.6499998555397438, 1, 0.10000020002189328`], 
     Hue[0.6499987913150758, 1, 0.10000167356374128`], 
     Hue[0.6499975817595002, 1, 0.10000334833299979`], 
     Hue[0.6499964672535286, 1, 0.10000489149511434`], 
     Hue[0.6499979082329089, 1, 0.10000289629289531`], 
     Hue[0.6499931770229507, 1, 0.10000944719899142`], 
     Hue[0.6499879539739198, 1, 0.10001667911303413`], 
     Hue[0.6499956092416016, 1, 0.10000607951162864`], 
     Hue[0.6499927911642358, 1, 0.10000998146490438`], 
     Hue[0.6499806446197294, 1, 0.10002679975729785`], 
     Hue[0.6499180307352564, 1, 0.10011349590502963`], 
     Hue[0.6499182640119672, 1, 0.10011317290650701`], 
     Hue[0.6499453175635969, 1, 0.10007571414271205`], 
     Hue[0.6499484530937932, 1, 0.1000713726393633], 
     Hue[0.6499818743816113, 1, 0.10002509701007672`], 
     Hue[0.6499931307624713, 1, 0.10000951125196281`], 
     Hue[0.6499959630133506, 1, 0.10000558967382225`], 
     Hue[0.6499933017246096, 1, 0.10000927453515607`], 
     Hue[0.6499978877143096, 1, 0.10000292470326372`], 
     Hue[0.649999015708746, 1, 0.10000136286481327`], 
     Hue[0.6499964646335001, 1, 0.10000489512284606`], 
     Hue[0.649998333888502, 1, 0.10000230692361262`], 
     Hue[0.649999590533435, 1, 0.1000005669537054], 
     Hue[0.6499998474023537, 1, 0.10000021128904879`], 
     Hue[0.6499992964406758, 1, 0.10000097415906437`], 
     Hue[0.649999732409757, 1, 0.10000037050956732`], 
     Hue[0.6499999079226575, 1, 0.10000012749170509`], 
     Hue[0.6499999105318043, 1, 0.10000012387904018`], 
     Hue[0.6499983183666825, 1, 0.1000023284153627], 
     Hue[0.6499994488275219, 1, 0.10000076316189273`], 
     Hue[0.6499990259760979, 1, 0.1000013486484798], 
     Hue[0.6499999589602237, 1, 0.1000000568243058], 
     Hue[0.6499999750758687, 1, 0.10000003451033561`], 
     Hue[0.6499999794211159, 1, 0.10000002849383967`], 
     Hue[0.6499999661022928, 1, 0.10000004693528683`], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.64999791089883, 1, 0.10000289260162012`], 
     Hue[0.6499942951189157, 1, 0.10000789906611669`], 
     Hue[0.6499999731984859, 1, 0.10000003710978886`], 
     Hue[0.6498992374175552, 1, 0.10013951742184668`], 
     Hue[0.6499594649681921, 1, 0.10005612542865715`], 
     Hue[0.6499906014956968, 1, 0.10001301331365066`], 
     Hue[0.6499102360885618, 1, 0.10012428849276057`], 
     Hue[0.6499975790673054, 1, 0.10000335206065415`], 
     Hue[0.6499984977543622, 1, 0.1000020800324216], 
     Hue[0.6499974391975304, 1, 0.10000354572649646`], 
     Hue[0.6499812225788024, 1, 0.10002599950627353`], 
     Hue[0.6499816678392328, 1, 0.10002538299183153`], 
     Hue[0.6498467359396423, 1, 0.10021221177587998`], 
     Hue[0.6495407493861327, 1, 0.10063588546535482`], 
     Hue[0.6498992374175552, 1, 0.1001395174218467], 
     Hue[0.6499306690177541, 1, 0.10009599674464828`], 
     Hue[0.6499594649681921, 1, 0.10005612542865716`], 
     Hue[0.6499731279556002, 1, 0.100037207446092], 
     Hue[0.6499906014956968, 1, 0.10001301331365066`], 
     Hue[0.6499996397889839, 1, 0.10000049875371464`], 
     Hue[0.6499983183666825, 1, 0.1000023284153627], 
     Hue[0.6499990259760979, 1, 0.1000013486484798], 
     Hue[0.6499999794211159, 1, 0.10000002849383967`], 
     Hue[0.6499999053015012, 1, 0.10000013112099838`], 
     Hue[0.6499995099093939, 1, 0.10000067858699309`], 
     Hue[0.6499997277891764, 1, 0.10000037690729435`], 
     Hue[0.6499997612218463, 1, 0.10000033061590513`], 
     Hue[0.6499929243432877, 1, 0.10000979706314021`], 
     Hue[0.6499992118878316, 1, 0.10000109123223312`], 
     Hue[0.6499974391975304, 1, 0.10000354572649647`], 
     Hue[0.6499552803098143, 1, 0.10006191957102643`], 
     Hue[0.6499930428076302, 1, 0.10000963303558902`], 
     Hue[0.6499816678392327, 1, 0.10002538299183167`], 
     Hue[0.6499522576756643, 1, 0.10006610475677251`], 
     Hue[0.6498467359396409, 1, 0.10021221177588176`], 
     Hue[0.6498969735437096, 1, 0.10014265201640213`], 
     Hue[0.6496731893555366, 1, 0.10045250704618], 
     Hue[0.0270736379763451, 1, 0.9625134243404452], 
     Hue[0.06744763098777695, 1, 0.9066109724784627], 
     Hue[0.027091472129359362`, 1, 0.9624887308978102], 
     Hue[0.6498464094443034, 1, 0.10021266384634916`], 
     Hue[0.6499811865783439, 1, 0.10002604935306224`], 
     Hue[0.6499815839206784, 1, 0.10002549918675299`], 
     Hue[0.6499975708283137, 1, 0.10000336346848884`], 
     Hue[0.6499974203571485, 1, 0.10000357181317905`], 
     Hue[0.6499986013933341, 1, 0.10000193653230671`], 
     Hue[0.6499997599027079, 1, 0.10000033244240446`], 
     Hue[0.649999724803093, 1, 0.10000038104187135`], 
     Hue[0.6499998715320819, 1, 0.10000017787865574`], 
     Hue[0.06747929559313426, 1, 0.9065671291787372], 
     Hue[0.0106738546460583, 1, 0.9852208166439193], 
     Hue[0.0021628179019727023`, 1, 0.997005329058807], 
     Hue[0.018968293159893457`, 1, 0.9737362094709168], 
     Hue[0.02707363797262352, 1, 0.9625134243455983], 
     Hue[0.6498467359396378, 1, 0.1002122117758862], 
     Hue[0.6498969735437079, 1, 0.10014265201640445`], 
     Hue[0.6499812225788023, 1, 0.10002599950627376`], 
     Hue[0.649977555421589, 1, 0.10003107710856916`], 
     Hue[0.6499816678392326, 1, 0.10002538299183177`], 
     Hue[0.6499975790673054, 1, 0.10000335206065417`], 
     Hue[0.6499969119221585, 1, 0.10000427580008835`], 
     Hue[0.6499974391975304, 1, 0.10000354572649647`], 
     Hue[0.6499997612218463, 1, 0.10000033061590513`], 
     Hue[0.6499995099093939, 1, 0.10000067858699309`], 
     Hue[0.6499998723238989, 1, 0.10000017678229389`], 
     Hue[0.6499997277891764, 1, 0.10000037690729435`], 
     Hue[0.6499998555397438, 1, 0.10000020002189328`], 
     Hue[0.6499906014956968, 1, 0.10001301331365064`], 
     Hue[0.6499594649681921, 1, 0.10005612542865713`], 
     Hue[0.6499731279556002, 1, 0.10003720744609199`], 
     Hue[0.6496727141920364, 1, 0.10045316496487267`], 
     Hue[0.6499102360885618, 1, 0.10012428849276055`], 
     Hue[0.6499374484373719, 1, 0.10008660985594668`], 
     Hue[0.6499445462876963, 1, 0.10007678206318982`], 
     Hue[0.6498464094443047, 1, 0.10021266384634737`], 
     Hue[0.6498967127539578, 1, 0.10014301310990469`], 
     Hue[0.6499552803098139, 1, 0.10006191957102695`], 
     Hue[0.6499942951189157, 1, 0.10000789906611669`], 
     Hue[0.6499965007467773, 1, 0.10000484511984688`], 
     Hue[0.6499913752726683, 1, 0.10001194193015163`], 
     Hue[0.6499815839206785, 1, 0.10002549918675284`], 
     Hue[0.6499929243432876, 1, 0.10000979706314021`], 
     Hue[0.6499989528715463, 1, 0.10000144987016665`], 
     Hue[0.6499974203571485, 1, 0.10000357181317905`], 
     Hue[0.6499975708283137, 1, 0.10000336346848883`], 
     Hue[0.6499999328468428, 1, 0.1000000929812946], 
     Hue[0.649999724803093, 1, 0.10000038104187135`], 
     Hue[0.6499997599027079, 1, 0.10000033244240446`], 
     Hue[0.6499999053015012, 1, 0.10000013112099838`], 
     Hue[0.6499997612218463, 1, 0.10000033061590513`], 
     Hue[0.6499998723238989, 1, 0.10000017678229389`], 
     Hue[0.6499995099093939, 1, 0.10000067858699309`], 
     Hue[0.6499999658355468, 1, 0.10000004730462761`], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.6499906014956968, 1, 0.10001301331365064`], 
     Hue[0.6499594649681921, 1, 0.10005612542865713`], 
     Hue[0.6499999731984859, 1, 0.10000003710978886`], 
     Hue[0.6499999068044836, 1, 0.10000012903994587`], 
     Hue[0.649999746592461, 1, 0.10000035087197716`], 
     Hue[0.649999231209965, 1, 0.10000106447851004`], 
     Hue[0.6499993562029576, 1, 0.1000008914112895], 
     Hue[0.6499985371764694, 1, 0.10000202544796548`], 
     Hue[0.6499955738243941, 1, 0.1000061285508389], 
     Hue[0.6499830415932077, 1, 0.10002348087094315`], 
     Hue[0.6499579090308498, 1, 0.10005827980343876`], 
     Hue[0.6499991746468223, 1, 0.10000114279670756`], 
     Hue[0.6499979082329089, 1, 0.10000289629289531`], 
     Hue[0.6499982700550374, 1, 0.10000239530840976`], 
     Hue[0.6499996397889839, 1, 0.10000049875371464`], 
     Hue[0.6499999658355468, 1, 0.10000004730462761`], 
     Hue[0.6499997857288967, 1, 0.10000029668306613`], 
     Hue[0.6499996352970167, 1, 0.10000050497336162`], 
     Hue[0.6499987037961257, 1, 0.1000017947438261], 
     Hue[0.6499991655407161, 1, 0.1000011554051624], 
     Hue[0.6499982534432173, 1, 0.1000024183093915], 
     Hue[0.6499941257642842, 1, 0.100008133557145], 
     Hue[0.6499807215560938, 1, 0.100026693230024], 
     Hue[0.6499558704947553, 1, 0.1000611023918773], 
     Hue[0.649999637473088, 1, 0.10000050196033976`], 
     Hue[0.6499990284977293, 1, 0.10000134515699023`], 
     Hue[0.6499985546968547, 1, 0.10000200118897033`], 
     Hue[0.6499999927381648, 1, 0.10000001005484888`], 
     Hue[0.6499992554553338, 1, 0.10000103090799936`], 
     Hue[0.649995048229519, 1, 0.10000685629758907`], 
     Hue[0.649976311639638, 1, 0.1000327992681936], 
     Hue[0.649920525041201, 1, 0.10011004225064472`], 
     Hue[0.6498831635659211, 1, 0.10016177352410921`], 
     Hue[0.6499999053015012, 1, 0.10000013112099838`], 
     Hue[0.6499979781484426, 1, 0.10000279948677177`], 
     Hue[0.6499904461340845, 1, 0.1000132284297292], 
     Hue[0.6499651447615216, 1, 0.10004826109943166`], 
     Hue[0.6499035776827975, 1, 0.10013350782381883`], 
     Hue[0.6498822003220268, 1, 0.1001631072464244], 
     Hue[0.6499999731984859, 1, 0.10000003710978886`], 
     Hue[0.6499989602457273, 1, 0.10000143965976213`], 
     Hue[0.6499989528715463, 1, 0.10000144987016665`], 
     Hue[0.6499857386104357, 1, 0.10001974653939674`], 
     Hue[0.6499477127625019, 1, 0.10007239771345894`], 
     Hue[0.6498491275148006, 1, 0.10020890036412224`], 
     Hue[0.6494614008079023, 1, 0.10074575272752002`], 
     Hue[0.649999637473088, 1, 0.10000050196033976`], 
     Hue[0.6499990284977293, 1, 0.10000134515699023`], 
     Hue[0.6499985546968547, 1, 0.10000200118897033`], 
     Hue[0.6499914127424963, 1, 0.10001189004885136`], 
     Hue[0.6499913752726683, 1, 0.10001194193015171`], 
     Hue[0.6499227855829615, 1, 0.10010691226974568`], 
     Hue[0.6497822958439452, 1, 0.10030143652376827`], 
     Hue[0.6499446791317128, 1, 0.10007659812532067`], 
     Hue[0.6499445462876953, 1, 0.10007678206319116`], 
     Hue[0.6496696618168444, 1, 0.1004573913305232], 
     Hue[0.6497907013374782, 1, 0.10028979814810711`], 
     Hue[0.649832150775643, 1, 0.10023240661834047`], 
     Hue[0.6497389422959969, 1, 0.10036146451323512`], 
     Hue[0.649714352432321, 1, 0.10039551201678641`], 
     Hue[0.64973878001104, 1, 0.10036168921548312`], 
     Hue[0.6497140307026751, 1, 0.10039595748860371`], 
     Hue[0.6498206206758443, 1, 0.10024837137190792`], 
     Hue[0.6353293129837054, 1, 0.12031325894563866`], 
     Hue[0.6499560274362279, 1, 0.10006088508829988`], 
     Hue[0.6499991655407161, 1, 0.1000011554051624], 
     Hue[0.6499978883756586, 1, 0.10000292378754969`], 
     Hue[0.6499982534432173, 1, 0.1000024183093915], 
     Hue[0.6499967448026513, 1, 0.10000450719632889`], 
     Hue[0.6499996352970167, 1, 0.10000050497336162`], 
     Hue[0.6499999539215624, 1, 0.1000000638009137], 
     Hue[0.6499690892099143, 1, 0.10004279955550344`], 
     Hue[0.6499949826603763, 1, 0.10000694708563293`], 
     Hue[0.6499993878957052, 1, 0.10000084752902356`], 
     Hue[0.6499999750758687, 1, 0.10000003451033561`], 
     Hue[0.6499991340538082, 1, 0.10000119900241951`], 
     Hue[0.6499996736696589, 1, 0.10000045184201072`], 
     Hue[0.6499997881961503, 1, 0.10000029326686882`], 
     Hue[0.6499998723238989, 1, 0.10000017678229389`], 
     Hue[0.6499994682338144, 1, 0.1000007362916416], 
     Hue[0.6499975790673054, 1, 0.10000335206065417`], 
     Hue[0.6499969119221585, 1, 0.10000427580008835`], 
     Hue[0.6499812225788024, 1, 0.10002599950627365`], 
     Hue[0.6499775554215891, 1, 0.10003107710856897`], 
     Hue[0.07116385446975881, 1, 0.9014654322726416], 
     Hue[0.052429459858746585`, 1, 0.9274053632725047], 
     Hue[0.058101599627731315`, 1, 0.9195516312846796], 
     Hue[0.02707363797620488, 1, 0.9625134243406394], 
     Hue[0.05244141947382608, 1, 0.9273888038054716], 
     Hue[0.05812442404677254, 1, 0.9195200282429303], 
     Hue[0.010673854646939596`, 1, 0.985220816642699], 
     Hue[0.07116385446585682, 1, 0.9014654322780444], 
     Hue[0.05244141947081893, 1, 0.9273888038096353], 
     Hue[0.05812442404452234, 1, 0.9195200282460461], 
     Hue[0.6313031433723827, 1, 0.12588795533054703`], 
     Hue[0.6450730162625566, 1, 0.10682197748261388`], 
     Hue[0.6498321507756426, 1, 0.10023240661834108`], 
     Hue[0.6497387800110438, 1, 0.10036168921547785`], 
     Hue[0.6497140307026826, 1, 0.10039595748859324`], 
     Hue[0.6499445462876959, 1, 0.10007678206319033`], 
     Hue[0.6499913752726683, 1, 0.10001194193015168`], 
     Hue[0.6499989528715463, 1, 0.10000144987016665`], 
     Hue[0.6499999042768432, 1, 0.1000001325397556], 
     Hue[0.6499999661022928, 1, 0.10000004693528683`], 
     Hue[0.6499995599269037, 1, 0.10000060933197948`], 
     Hue[0.6499996708038481, 1, 0.10000045581005648`], 
     Hue[0.6499996266415422, 1, 0.1000005169578647], 
     Hue[0.6499994633943222, 1, 0.10000074299247697`], 
     Hue[0.6499958503661866, 1, 0.10000574564681872`], 
     Hue[0.6499968945489246, 1, 0.1000042998553351], 
     Hue[0.6499964690986961, 1, 0.10000488894026689`], 
     Hue[0.6499952978986884, 1, 0.1000065106018162], 
     Hue[0.6499811865783439, 1, 0.10002604935306235`], 
     Hue[0.6499774815479086, 1, 0.10003117939520355`], 
     Hue[0.010667080107075066`, 1, 0.9852301967748192], 
     Hue[0.027091472129990746`, 1, 0.9624887308969359], 
     Hue[0.010673854646060521`, 1, 0.9852208166439161], 
     Hue[0.010667080104723725`, 1, 0.9852301967780749], 
     Hue[0.05242945985458425, 1, 0.927405363278268], 
     Hue[0.05810159962324535, 1, 0.919551631290891], 
     Hue[0.6497389422959918, 1, 0.10036146451324211`], 
     Hue[0.6497143524323117, 1, 0.10039551201679923`], 
     Hue[0.6499446791317118, 1, 0.10007659812532207`], 
     Hue[0.6499914127424962, 1, 0.10001189004885144`], 
     Hue[0.6499989602457273, 1, 0.10000143965976215`], 
     Hue[0.6499999053015012, 1, 0.10000013112099838`], 
     Hue[0.6499998099007703, 1, 0.10000026321431808`], 
     Hue[0.6499981812644314, 1, 0.10000251824924884`], 
     Hue[0.6499871127135868, 1, 0.10001784393503368`], 
     Hue[0.02709147212931462, 1, 0.9624887308978721], 
     Hue[0.02707363797266582, 1, 0.9625134243455397], 
     Hue[0.6499552803098139, 1, 0.10006191957102697`], 
     Hue[0.6499929243432876, 1, 0.10000979706314023`], 
     Hue[0.649998861931212, 1, 0.10000157578755257`], 
     Hue[0.6499999539215624, 1, 0.1000000638009137], 
     Hue[0.6499996397889839, 1, 0.10000049875371464`], 
     Hue[0.6499993192256, 1, 0.10000094261070784`], 
     Hue[0.6499982700550374, 1, 0.10000239530840976`], 
     Hue[0.6499989057002725, 1, 0.10000151518423804`], 
     Hue[0.6497851328324681, 1, 0.10029750838581342`], 
     Hue[0.6494614008079023, 1, 0.10074575272752002`], 
     Hue[0.6404078578025607, 1, 0.11328142765799296`], 
     Hue[0.6498206455449007, 1, 0.10024833693782975`], 
     Hue[0.6499551253828283, 1, 0.1000621340853147], 
     Hue[0.6499719284481867, 1, 0.1000388683025107], 
     Hue[0.649981186578344, 1, 0.10002604935306213`], 
     Hue[0.6499774815479088, 1, 0.10003117939520317`], 
     Hue[0.6499928827959313, 1, 0.10000985459024901`], 
     Hue[0.6499812225788023, 1, 0.10002599950627371`], 
     Hue[0.649977555421589, 1, 0.10003107710856914`], 
     Hue[0.6499899497720244, 1, 0.10001391570027393`], 
     Hue[0.6499993562029576, 1, 0.1000008914112895], 
     Hue[0.649998333888502, 1, 0.10000230692361262`], 
     Hue[0.6499985371764694, 1, 0.10000202544796548`], 
     Hue[0.649981132862961, 1, 0.10002612372820784`], 
     Hue[0.6499954680826809, 1, 0.10000627496244185`], 
     Hue[0.6499986013933341, 1, 0.1000019365323067], 
     Hue[0.6499968945489247, 1, 0.10000429985533509`], 
     Hue[0.6499991262252099, 1, 0.10000120984201698`], 
     Hue[0.6499975790673054, 1, 0.10000335206065417`], 
     Hue[0.6499969119221585, 1, 0.10000427580008835`], 
     Hue[0.6499887061646138, 1, 0.10001563761822713`], 
     Hue[0.649997998599588, 1, 0.10000277116980137`], 
     Hue[0.649999746592461, 1, 0.10000035087197716`], 
     Hue[0.6499999731984859, 1, 0.10000003710978886`], 
     Hue[0.6498206206758443, 1, 0.10024837137190794`], 
     Hue[0.6499888903804653, 1, 0.10001538255012506`], 
     Hue[0.6499971342997227, 1, 0.10000396789269159`], 
     Hue[0.649999454487984, 1, 0.10000075532432992`], 
     Hue[0.6499997881961503, 1, 0.10000029326686882`], 
     Hue[0.6499998715320819, 1, 0.10000017787865574`], 
     Hue[0.6499996708038481, 1, 0.10000045581005648`], 
     Hue[0.6499998405135435, 1, 0.10000022082740136`], 
     Hue[0.6499997277891764, 1, 0.10000037690729435`], 
     Hue[0.6499996736696589, 1, 0.10000045184201072`], 
     Hue[0.6498206455449007, 1, 0.10024833693782977`], 
     Hue[0.6499908589738947, 1, 0.10001265680537647`], 
     Hue[0.6499980650680817, 1, 0.10000267913650228`], 
     Hue[0.6499997205474622, 1, 0.10000038693428308`], 
     Hue[0.6499999927381648, 1, 0.10000001005484888`], 
     Hue[0.6499999750758687, 1, 0.10000003451033561`], 
     Hue[0.649997537735836, 1, 0.10000340928884255`], 
     Hue[0.6499990259760979, 1, 0.1000013486484798], 
     Hue[0.6499453175635969, 1, 0.10007571414271207`], 
     Hue[0.6499975567721432, 1, 0.10000338293087865`], 
     Hue[0.6499991607215534, 1, 0.10000116207784923`], 
     Hue[0.6499999209879762, 1, 0.10000010940126382`], 
     Hue[0.6499452554080252, 1, 0.10007580020427294`], 
     Hue[0.6499999927381648, 1, 0.10000001005484888`], 
     Hue[0.6499999724303417, 1, 0.10000003817337312`], 
     Hue[0.6483242391402425, 1, 0.10232028426735651`], 
     Hue[0.6431583990632883, 1, 0.1094729859123701], 
     Hue[0.6482530143242407, 1, 0.10241890324335912`], 
     Hue[0.6463635850696269, 1, 0.10503503605743975`], 
     Hue[0.6471956278813717, 1, 0.10388297677963922`], 
     Hue[0.6464975004715672, 1, 0.10484961473167623`], 
     Hue[0.6499975567721432, 1, 0.10000338293087865`], 
     Hue[0.6499991607215534, 1, 0.10000116207784923`], 
     Hue[0.6499996979082646, 1, 0.10000041828086434`], 
     Hue[0.6431583990632911, 1, 0.10947298591236626`], 
     Hue[0.6483242391402418, 1, 0.10232028426735748`], 
     Hue[0.6463635850696212, 1, 0.10503503605744753`], 
     Hue[0.6482530143242377, 1, 0.10241890324336335`], 
     Hue[0.6483242391402463, 1, 0.10232028426735128`], 
     Hue[0.6482524798771888, 1, 0.10241964324696944`], 
     Hue[0.6460888132276699, 1, 0.10541548937707247`], 
     Hue[0.6451751558078836, 1, 0.10668055349677649`], 
     Hue[0.6447410918958293, 1, 0.1072815650673133], 
     Hue[0.6313031433723599, 1, 0.12588795533057862`], 
     Hue[0.6465512173141803, 1, 0.10477523756498112`], 
     Hue[0.6450730162625558, 1, 0.10682197748261514`], 
     Hue[0.6460888132276699, 1, 0.10541548937707258`], 
     Hue[0.6451751558078835, 1, 0.1066805534967767], 
     Hue[0.6451837682394977, 1, 0.10666862859146475`], 
     Hue[0.6479792421191494, 1, 0.10279797245040857`], 
     Hue[0.6476184271540987, 1, 0.10329756240201719`], 
     Hue[0.6475036441269619, 1, 0.10345649274728348`], 
     Hue[0.648324239140247, 1, 0.10232028426735042`], 
     Hue[0.6482524798771917, 1, 0.10241964324696531`], 
     Hue[0.648682976894605, 1, 0.10182357045362386`], 
     Hue[0.6465512173141805, 1, 0.10477523756498087`], 
     Hue[0.6479792421191495, 1, 0.10279797245040849`], 
     Hue[0.6476184271540988, 1, 0.10329756240201703`], 
     Hue[0.6499698377498546, 1, 0.10004176311558596`], 
     Hue[0.6499958626928356, 1, 0.10000572857915081`], 
     Hue[0.6499989602457273, 1, 0.10000143965976215`], 
     Hue[0.6499995620862684, 1, 0.10000060634208989`], 
     Hue[0.6499855624175456, 1, 0.10001999049878305`], 
     Hue[0.6499942635068771, 1, 0.10000794283663174`], 
     Hue[0.6499957594867645, 1, 0.10000587147986459`], 
     Hue[0.6499982534432173, 1, 0.1000024183093915], 
     Hue[0.6499986030712614, 1, 0.10000193420902256`], 
     Hue[0.6499996352970167, 1, 0.10000050497336162`], 
     Hue[0.6499996918089019, 1, 0.10000042672613585`], 
     Hue[0.6499857545886895, 1, 0.10001972441566084`], 
     Hue[0.649994657510819, 1, 0.1000073972927123], 
     Hue[0.6499959545446957, 1, 0.10000560139965206`], 
     Hue[0.6499985371764694, 1, 0.10000202544796548`], 
     Hue[0.6499987724866683, 1, 0.10000169963384406`], 
     Hue[0.649999746592461, 1, 0.10000035087197716`], 
     Hue[0.64999976764185, 1, 0.10000032172666927`], 
     Hue[0.6499856125038711, 1, 0.10001992114848618`], 
     Hue[0.649988018614091, 1, 0.10001658961125877`], 
     Hue[0.6499958852039428, 1, 0.10000569740992535`], 
     Hue[0.6499967008729203, 1, 0.1000045680221105], 
     Hue[0.6499926276132632, 1, 0.10001020792009714`], 
     Hue[0.6499908288660274, 1, 0.10001269849319286`], 
     Hue[0.6499991007478049, 1, 0.10000124511842408`], 
     Hue[0.649997537735836, 1, 0.10000340928884255`], 
     Hue[0.6499858078426721, 1, 0.1000196506793771], 
     Hue[0.649988752611403, 1, 0.1000155733072882], 
     Hue[0.6499728876119557, 1, 0.10003754022959983`], 
     Hue[0.6499965007467773, 1, 0.10000484511984689`], 
     Hue[0.6499970665105199, 1, 0.1000040617546648], 
     Hue[0.6499933578423218, 1, 0.10000919683370825`], 
     Hue[0.6499920691746767, 1, 0.10001098114275549`], 
     Hue[0.6498594518723236, 1, 0.10019460509985961`], 
     Hue[0.6498693537502516, 1, 0.10018089480734406`], 
     Hue[0.6499993562029576, 1, 0.1000008914112895], 
     Hue[0.649997036906219, 1, 0.10000410274523522`], 
     Hue[0.6499886776939561, 1, 0.10001567703913772`], 
     Hue[0.6499857545886895, 1, 0.10001972441566084`], 
     Hue[0.6498965941389109, 1, 0.10014317734612337`], 
     Hue[0.6479792421191494, 1, 0.10279797245040863`], 
     Hue[0.6476184271540988, 1, 0.1032975624020171], 
     Hue[0.6475036441269622, 1, 0.10345649274728327`], 
     Hue[0.6465512173141802, 1, 0.10477523756498137`], 
     Hue[0.645653310526761, 1, 0.1060184931167925], 
     Hue[0.6479792421191491, 1, 0.10279797245040885`], 
     Hue[0.6476184271540985, 1, 0.10329756240201762`], 
     Hue[0.6475036441269617, 1, 0.10345649274728375`], 
     Hue[0.6460888132276827, 1, 0.10541548937705467`], 
     Hue[0.6451751558079051, 1, 0.10668055349674681`], 
     Hue[0.6447410918958457, 1, 0.10728156506729052`], 
     Hue[0.6432319744106683, 1, 0.10937111235445943`], 
     Hue[0.644822685525103, 1, 0.10716858927293434`], 
     Hue[0.642232904597574, 1, 0.1107544397879746], 
     Hue[0.6447422602883427, 1, 0.10727994729306399`], 
     Hue[0.6432412882886112, 1, 0.1093582162157692], 
     Hue[0.6465512173141732, 1, 0.10477523756499099`], 
     Hue[0.6369345841081043, 1, 0.11809057585031717`], 
     Hue[0.6313032801501992, 1, 0.12588776594587803`], 
     Hue[0.5681211260697845, 1, 0.21337074851875992`], 
     Hue[0.6035532562554852, 1, 0.16431087595394364`], 
     Hue[0.6363391370257159, 1, 0.11891504104131655`], 
     Hue[0.6309334967132458, 1, 0.1263997737816596], 
     Hue[0.6451837682394547, 1, 0.10666862859152436`], 
     Hue[0.6460888132276146, 1, 0.10541548937714908`], 
     Hue[0.6451751558078197, 1, 0.10668055349686502`], 
     Hue[0.6447410918957623, 1, 0.10728156506740609`], 
     Hue[0.6432319744106638, 1, 0.10937111235446557`], 
     Hue[0.6448226855250837, 1, 0.10716858927296105`], 
     Hue[0.5681211260697305, 1, 0.21337074851883464`], 
     Hue[0.6035532562554903, 1, 0.16431087595393662`], 
     Hue[0.6175668224059234, 1, 0.1449074766687214], 
     Hue[0.6369345841081185, 1, 0.11809057585029736`], 
     Hue[0.6313032801502132, 1, 0.12588776594585865`], 
     Hue[0.6431583990630713, 1, 0.10947298591267063`], 
     Hue[0.636934584107928, 1, 0.11809057585056115`], 
     Hue[0.6313032801501643, 1, 0.1258877659459263], 
     Hue[0.5681211260708114, 1, 0.21337074851733795`], 
     Hue[0.6035532562559326, 1, 0.16431087595332416`], 
     Hue[0.6175668224060558, 1, 0.14490747666853818`], 
     Hue[0.643231974410409, 1, 0.10937111235481833`], 
     Hue[0.6448226855248737, 1, 0.10716858927325197`], 
     Hue[0.6499991655407161, 1, 0.1000011554051624], 
     Hue[0.6499966739061288, 1, 0.10000460536074483`], 
     Hue[0.6499879519206576, 1, 0.1000166819560126], 
     Hue[0.6499855624175456, 1, 0.10001999049878303`], 
     Hue[0.6498948240795815, 1, 0.10014562819750247`], 
     Hue[0.63093349671357, 1, 0.12639977378121073`], 
     Hue[0.639857669156809, 1, 0.11404322732134148`], 
     Hue[0.6363391370261072, 1, 0.11891504104077469`], 
     Hue[0.5681211260708074, 1, 0.2133707485173436], 
     Hue[0.6035532562559285, 1, 0.16431087595332988`], 
     Hue[0.617566822406053, 1, 0.144907476668542], 
     Hue[0.6431583990630698, 1, 0.10947298591267261`], 
     Hue[0.6369345841079257, 1, 0.11809057585056448`], 
     Hue[0.6432412882886738, 1, 0.10935821621568247`], 
     Hue[0.644742260288362, 1, 0.10727994729303719`], 
     Hue[0.6432319744104082, 1, 0.10937111235481942`], 
     Hue[0.6448226855248731, 1, 0.10716858927325264`], 
     Hue[0.6456533105267654, 1, 0.10601849311678642`], 
     Hue[0.6498693537502516, 1, 0.100180894807344], 
     Hue[0.6499374484373719, 1, 0.10008660985594665`], 
     Hue[0.6498594518723237, 1, 0.1001946050998595], 
     Hue[0.6499933578423218, 1, 0.10000919683370825`], 
     Hue[0.6499920691746767, 1, 0.10001098114275549`], 
     Hue[0.6499965007467773, 1, 0.10000484511984688`], 
     Hue[0.6499970665105199, 1, 0.1000040617546648], 
     Hue[0.649988752611403, 1, 0.10001557330728819`], 
     Hue[0.6499858078426721, 1, 0.10001965067937708`], 
     Hue[0.6499977238559549, 1, 0.10000315158406245`], 
     Hue[0.6499991746468223, 1, 0.10000114279670756`], 
     Hue[0.6499926276132632, 1, 0.10001020792009714`], 
     Hue[0.6499908288660274, 1, 0.10001269849319284`], 
     Hue[0.6499958852039428, 1, 0.10000569740992533`], 
     Hue[0.6499967008729203, 1, 0.10000456802211048`], 
     Hue[0.649988018614091, 1, 0.10001658961125875`], 
     Hue[0.6499856125038711, 1, 0.10001992114848615`], 
     Hue[0.6499999068044836, 1, 0.10000012903994587`], 
     Hue[0.6499992554553338, 1, 0.10000103090799936`], 
     Hue[0.6499452847292683, 1, 0.10007575960562864`], 
     Hue[0.6499560274362279, 1, 0.10006088508829988`], 
     Hue[0.649997310025984, 1, 0.10000372457940669`], 
     Hue[0.6499980905392484, 1, 0.10000264386873307`], 
     Hue[0.6499992600207877, 1, 0.10000102458660165`], 
     Hue[0.6499999539215624, 1, 0.1000000638009137], 
     Hue[0.6499998099007703, 1, 0.10000026321431808`], 
     Hue[0.649998861931212, 1, 0.10000157578755257`], 
     Hue[0.6499453252164491, 1, 0.10007570354645512`], 
     Hue[0.6499927658336027, 1, 0.10001001653808872`], 
     Hue[0.6499970704909728, 1, 0.10000405624326845`], 
     Hue[0.6499999926822643, 1, 0.10000001013224943`], 
     Hue[0.649999231209965, 1, 0.10000106447851004`], 
     Hue[0.649999746592461, 1, 0.10000035087197716`], 
     Hue[0.649995048229519, 1, 0.10000685629758907`], 
     Hue[0.649912880804017, 1, 0.10012062657905337`], 
     Hue[0.6499334905618971, 1, 0.10009208999121949`], 
     Hue[0.6499428471125177, 1, 0.10007913476728314`], 
     Hue[0.6499742829535601, 1, 0.10003560821814764`], 
     Hue[0.6499995099093939, 1, 0.10000067858699309`], 
     Hue[0.6499997612218463, 1, 0.10000033061590513`], 
     Hue[0.6499996736696589, 1, 0.10000045184201072`], 
     Hue[0.6499997277891764, 1, 0.10000037690729435`], 
     Hue[0.6499998723238989, 1, 0.10000017678229389`], 
     Hue[0.6499997599027079, 1, 0.10000033244240446`], 
     Hue[0.6499996708038481, 1, 0.10000045581005648`], 
     Hue[0.6499998715320819, 1, 0.10000017787865574`], 
     Hue[0.6499981812644314, 1, 0.10000251824924884`], 
     Hue[0.6499155953597011, 1, 0.10011686796349077`], 
     Hue[0.6499442388258546, 1, 0.10007720777958598`], 
     Hue[0.6499955738243941, 1, 0.1000061285508389], 
     Hue[0.6499985371764694, 1, 0.10000202544796548`], 
     Hue[0.649976311639638, 1, 0.1000327992681936], 
     Hue[0.6499786307209967, 1, 0.10002958823246613`], 
     Hue[0.649983522105702, 1, 0.10002281554595112`], 
     Hue[0.6499919444905073, 1, 0.10001115378237442`], 
     Hue[0.6499910794886076, 1, 0.1000123514773127], 
     Hue[0.6499975708283137, 1, 0.10000336346848884`], 
     Hue[0.6499968945489246, 1, 0.1000042998553351], 
     Hue[0.6499986013933341, 1, 0.1000019365323067], 
     Hue[0.6499871127135868, 1, 0.10001784393503368`], 
     Hue[0.6499927658336027, 1, 0.10001001653808872`], 
     Hue[0.6499970704909728, 1, 0.10000405624326845`], 
     Hue[0.6499972818328055, 1, 0.10000376361611546`], 
     Hue[0.6499983540750625, 1, 0.10000227897299048`], 
     Hue[0.6499830415932077, 1, 0.10002348087094315`], 
     Hue[0.6499933017246096, 1, 0.10000927453515605`], 
     Hue[0.649920525041201, 1, 0.10011004225064472`], 
     Hue[0.6499371615166366, 1, 0.10008700713081092`], 
     Hue[0.6499811865783439, 1, 0.10002604935306231`], 
     Hue[0.6499774815479086, 1, 0.10003117939520352`], 
     Hue[0.6499579090308498, 1, 0.10005827980343876`], 
     Hue[0.6465824912328809, 1, 0.10473193521601107`], 
     Hue[0.6469518842360068, 1, 0.10422046798091374`], 
     Hue[0.6464981818998694, 1, 0.1048486712155655], 
     Hue[0.6486837082759831, 1, 0.1018225577717157], 
     Hue[0.6471966341309858, 1, 0.1038815835109428], 
     Hue[0.648252479877121, 1, 0.10241964324706332`], 
     Hue[0.6486829768945355, 1, 0.10182357045372016`], 
     Hue[0.6474500234495466, 1, 0.1035307367621662], 
     Hue[0.646551987163097, 1, 0.10477417162032727`], 
     Hue[0.6441390283452341, 1, 0.1081151915219836], 
     Hue[0.6499452554080251, 1, 0.10007580020427298`], 
     Hue[0.6378619063740157, 1, 0.11680659117443976`], 
     Hue[0.6394934187185672, 1, 0.1145475740819838], 
     Hue[0.641618216230081, 1, 0.11160554675834945`], 
     Hue[0.6090317928643224, 1, 0.15672520988016897`], 
     Hue[0.5965604897300457, 1, 0.17399316806609055`], 
     Hue[0.6058778207336497, 1, 0.16109224821494667`], 
     Hue[0.6210502495195851, 1, 0.14008426989595912`], 
     Hue[0.6416182162300761, 1, 0.11160554675835616`], 
     Hue[0.6417543806434738, 1, 0.11141701141672865`], 
     Hue[0.6499304140750839, 1, 0.10009634974219153`], 
     Hue[0.6499879519206576, 1, 0.10001668195601261`], 
     Hue[0.6499925770634212, 1, 0.10001027791218615`], 
     Hue[0.6499982700550374, 1, 0.10000239530840976`], 
     Hue[0.6499428471125177, 1, 0.10007913476728321`], 
     Hue[0.6499742829535601, 1, 0.10003560821814765`], 
     Hue[0.6499770919050559, 1, 0.10003171890069185`], 
     Hue[0.6353293129837174, 1, 0.12031325894562206`], 
     Hue[0.6210502495196695, 1, 0.1400842698958423], 
     Hue[0.6220796274099561, 1, 0.1386589774323685], 
     Hue[0.6498768869650647, 1, 0.10017046420221809`], 
     Hue[0.6499888903804653, 1, 0.10001538255012506`], 
     Hue[0.649972980055223, 1, 0.10003741223122971`], 
     Hue[0.6499980722882938, 1, 0.10000266913928554`], 
     Hue[0.6499992600207877, 1, 0.10000102458660165`], 
     Hue[0.6498182666377854, 1, 0.10025163080922017`], 
     Hue[0.649981132862961, 1, 0.10002612372820786`], 
     Hue[0.6499568986091694, 1, 0.10005967884884236`], 
     Hue[0.6499971342997227, 1, 0.10000396789269159`], 
     Hue[0.6499998555397438, 1, 0.10000020002189328`], 
     Hue[0.6465824912328155, 1, 0.1047319352161016], 
     Hue[0.646951884235956, 1, 0.10422046798098417`], 
     Hue[0.6464981818998243, 1, 0.10484867121562785`], 
     Hue[0.6464975004716572, 1, 0.10484961473155151`], 
     Hue[0.6497373247140598, 1, 0.1003637042420711], 
     Hue[0.6499719284481866, 1, 0.10003886830251084`], 
     Hue[0.6499369681039929, 1, 0.10008727493293283`], 
     Hue[0.6499954680826809, 1, 0.10000627496244185`], 
     Hue[0.649999454487984, 1, 0.10000075532432992`], 
     Hue[0.649983522105702, 1, 0.10002281554595117`], 
     Hue[0.6499919444905073, 1, 0.10001115378237445`], 
     Hue[0.6499910794886075, 1, 0.10001235147731274`], 
     Hue[0.649998606782629, 1, 0.10000192907020604`], 
     Hue[0.6499992903837791, 1, 0.10000098254553669`], 
     Hue[0.6499884844621604, 1, 0.10001594459085487`], 
     Hue[0.6499935635661466, 1, 0.10000891198533556`], 
     Hue[0.6499547241190271, 1, 0.10006268968134718`], 
     Hue[0.6471966341309734, 1, 0.10388158351096], 
     Hue[0.6486837082759777, 1, 0.10182255777172321`], 
     Hue[0.027091472130218897`, 1, 0.96248873089662], 
     Hue[0.6474500234496732, 1, 0.10353073676199107`], 
     Hue[0.649955125382828, 1, 0.10006213408531515`], 
     Hue[0.6499928827959313, 1, 0.10000985459024905`], 
     Hue[0.6499991262252099, 1, 0.10000120984201699`], 
     Hue[0.6499999658355468, 1, 0.10000004730462761`], 
     Hue[0.6498967127539552, 1, 0.1001430131099082], 
     Hue[0.6498321507756425, 1, 0.10023240661834114`], 
     Hue[0.6497387800110396, 1, 0.10036168921548362`], 
     Hue[0.649714030702675, 1, 0.10039595748860397`], 
     Hue[0.010673854646818914`, 1, 0.9852208166428661], 
     Hue[0.010667080104693194`, 1, 0.9852301967781171], 
     Hue[0.649983522105702, 1, 0.10002281554595115`], 
     Hue[0.6499919444905073, 1, 0.10001115378237443`], 
     Hue[0.6499999750758687, 1, 0.10000003451033561`], 
     Hue[0.6499997857288967, 1, 0.10000029668306613`], 
     Hue[0.6499979781484426, 1, 0.10000279948677178`], 
     Hue[0.6499857386104357, 1, 0.10001974653939674`], 
     Hue[0.6499227855829615, 1, 0.10010691226974568`], 
     Hue[0.649936968103993, 1, 0.10008727493293268`], 
     Hue[0.6496696618168444, 1, 0.1004573913305232], 
     Hue[0.6497373247140593, 1, 0.1003637042420717], 
     Hue[0.648252479877121, 1, 0.10241964324706324`], 
     Hue[0.6486829768945355, 1, 0.1018235704537201], 
     Hue[0.647450023449547, 1, 0.10353073676216572`], 
     Hue[0.6313031433718941, 1, 0.12588795533122368`], 
     Hue[0.0711638544660157, 1, 0.9014654322778245], 
     Hue[0.05244141947093095, 1, 0.9273888038094803], 
     Hue[0.05242945985472813, 1, 0.9274053632780688], 
     Hue[0.05810159962336514, 1, 0.9195516312907253], 
     Hue[0.6482530143241786, 1, 0.10241890324344512`], 
     Hue[0.6463635850694541, 1, 0.10503503605767897`], 
     Hue[0.6474507800969185, 1, 0.10352968909657442`], 
     Hue[0.6486837082759177, 1, 0.10182255777180628`], 
     Hue[0.6471966341308304, 1, 0.10388158351115798`], 
     Hue[0.6499910794886075, 1, 0.10001235147731273`], 
     Hue[0.6499938301355157, 1, 0.10000854288928591`], 
     Hue[0.6499987037961257, 1, 0.1000017947438261], 
     Hue[0.6499996352970167, 1, 0.10000050497336162`], 
     Hue[0.6499904461340845, 1, 0.1000132284297292], 
     Hue[0.6499477127625019, 1, 0.10007239771345895`], 
     Hue[0.6499568986091695, 1, 0.1000596788488423], 
     Hue[0.6497822958439452, 1, 0.1003014365237683], 
     Hue[0.649818266637786, 1, 0.10025163080921949`], 
     Hue[0.6465824912328294, 1, 0.10473193521608234`], 
     Hue[0.6469518842359252, 1, 0.10422046798102663`], 
     Hue[0.6499975567721432, 1, 0.10000338293087865`], 
     Hue[0.6499991607215534, 1, 0.10000116207784923`], 
     Hue[0.6499996979082646, 1, 0.10000041828086434`], 
     Hue[0.6499992600207877, 1, 0.10000102458660165`], 
     Hue[0.6499988738287195, 1, 0.10000155931408075`], 
     Hue[0.6499995822700525, 1, 0.1000005783953119], 
     Hue[0.6499941257642842, 1, 0.100008133557145], 
     Hue[0.6499982534432173, 1, 0.1000024183093915], 
     Hue[0.6499651447615216, 1, 0.10004826109943166`], 
     Hue[0.649972980055223, 1, 0.1000374122312297], 
     Hue[0.6498491275148006, 1, 0.10020890036412228`], 
     Hue[0.6498768869650648, 1, 0.10017046420221801`], 
     Hue[0.6058778207335989, 1, 0.161092248215017], 
     Hue[0.6210502495195549, 1, 0.14008426989600098`], 
     Hue[0.6220796274097713, 1, 0.1386589774326244], 
     Hue[0.6499428471125177, 1, 0.10007913476728315`], 
     Hue[0.6499742829535601, 1, 0.10003560821814764`], 
     Hue[0.6499770919050559, 1, 0.10003171890069183`], 
     Hue[0.6499807215560938, 1, 0.100026693230024], 
     Hue[0.6499925770634212, 1, 0.10001027791218614`], 
     Hue[0.6499035776827975, 1, 0.10013350782381886`], 
     Hue[0.649930414075084, 1, 0.10009634974219148`], 
     Hue[0.6394934187185649, 1, 0.11454757408198707`], 
     Hue[0.6416182162300839, 1, 0.11160554675834541`], 
     Hue[0.6417543806434844, 1, 0.11141701141671394`], 
     Hue[0.6499558704947553, 1, 0.1000611023918773], 
     Hue[0.6210502495196204, 1, 0.1400842698959103], 
     Hue[0.6220796274098989, 1, 0.1386589774324477], 
     Hue[0.5965604897305343, 1, 0.17399316806541407`], 
     Hue[0.6090317928649146, 1, 0.156725209879349], 
     Hue[0.6416182162300909, 1, 0.11160554675833581`], 
     Hue[0.6417543806434991, 1, 0.1114170114166936], 
     Hue[0.6378619063741094, 1, 0.11680659117431007`], 
     Hue[0.6441390283452455, 1, 0.10811519152196784`], 
     Hue[0.646551987163097, 1, 0.10477417162032729`], 
     Hue[0.6474500234496774, 1, 0.10353073676198514`], 
     Hue[0.6463635850694534, 1, 0.10503503605767994`], 
     Hue[0.6482530143241784, 1, 0.10241890324344531`], 
     Hue[0.647450780096918, 1, 0.10352968909657513`], 
     Hue[0.64719663413083, 1, 0.10388158351115853`], 
     Hue[0.6486837082759176, 1, 0.10182255777180639`], 
     Hue[0.6465824912328293, 1, 0.10473193521608254`], 
     Hue[0.6469518842359251, 1, 0.10422046798102687`], 
     Hue[0.6464981818997425, 1, 0.10484867121574122`], 
     Hue[0.6499453175635969, 1, 0.10007571414271205`], 
     Hue[0.649832150775643, 1, 0.1002324066183404], 
     Hue[0.6497389422959922, 1, 0.10036146451324161`], 
     Hue[0.6497143524323119, 1, 0.10039551201679897`], 
     Hue[0.649896973543708, 1, 0.10014265201640439`], 
     Hue[0.6499371615166366, 1, 0.10008700713081096`], 
     Hue[0.6499886776939561, 1, 0.10001567703913773`], 
     Hue[0.6499933017246096, 1, 0.10000927453515607`], 
     Hue[0.6499927658336027, 1, 0.10001001653808872`], 
     Hue[0.6499970704909728, 1, 0.10000405624326845`], 
     Hue[0.6499972818328055, 1, 0.10000376361611546`], 
     Hue[0.6499690892099144, 1, 0.10004279955550321`], 
     Hue[0.649983522105702, 1, 0.10002281554595113`], 
     Hue[0.6499919444905073, 1, 0.10001115378237443`], 
     Hue[0.6499910794886075, 1, 0.10001235147731273`], 
     Hue[0.6499908589738947, 1, 0.10001265680537647`], 
     Hue[0.6499786307209967, 1, 0.10002958823246615`], 
     Hue[0.6499984305375945, 1, 0.10000217310179225`], 
     Hue[0.6499949826603763, 1, 0.10000694708563292`], 
     Hue[0.6499983681725562, 1, 0.10000225945338377`], 
     Hue[0.6499887061646138, 1, 0.10001563761822713`], 
     Hue[0.6499980650680817, 1, 0.10000267913650228`], 
     Hue[0.6499442388258546, 1, 0.10007720777958594`], 
     Hue[0.6499155953597011, 1, 0.10011686796349074`], 
     Hue[0.6499967448026513, 1, 0.10000450719632889`], 
     Hue[0.6499993878957052, 1, 0.10000084752902356`], 
     Hue[0.6499428471125177, 1, 0.10007913476728314`], 
     Hue[0.6499742829535601, 1, 0.10003560821814764`], 
     Hue[0.6499770919050559, 1, 0.10003171890069183`], 
     Hue[0.6499334905618971, 1, 0.10009208999121944`], 
     Hue[0.6499306690177541, 1, 0.10009599674464822`], 
     Hue[0.6499128808040171, 1, 0.10012062657905328`], 
     Hue[0.6499899497720244, 1, 0.10001391570027393`], 
     Hue[0.649997998599588, 1, 0.10000277116980137`], 
     Hue[0.6499997205474622, 1, 0.10000038693428308`], 
     Hue[0.6499927658336027, 1, 0.10001001653808872`], 
     Hue[0.6499970704909728, 1, 0.10000405624326845`], 
     Hue[0.6499972818328055, 1, 0.10000376361611546`], 
     Hue[0.649999637473088, 1, 0.10000050196033976`], 
     Hue[0.6499990284977293, 1, 0.10000134515699023`], 
     Hue[0.6499985546968547, 1, 0.10000200118897033`], 
     Hue[0.6499983540750625, 1, 0.10000227897299048`], 
     Hue[0.6499977323549201, 1, 0.10000313981626457`], 
     Hue[0.6499453252164491, 1, 0.10007570354645513`], 
     Hue[0.6499879519206576, 1, 0.10001668195601261`], 
     Hue[0.6499972861634967, 1, 0.10000375761977373`], 
     Hue[0.6499980722882938, 1, 0.10000266913928554`], 
     Hue[0.6499993956352772, 1, 0.10000083681269313`], 
     Hue[0.6499996064912191, 1, 0.10000054485831195`], 
     Hue[0.6499975567721432, 1, 0.10000338293087865`], 
     Hue[0.6499991607215534, 1, 0.10000116207784923`], 
     Hue[0.6499996979082646, 1, 0.10000041828086434`], 
     Hue[0.6499992600207877, 1, 0.10000102458660165`], 
     Hue[0.6499996397889839, 1, 0.10000049875371464`], 
     Hue[0.6499995822700525, 1, 0.1000005783953119], 
     Hue[0.649999402582182, 1, 0.10000082719390185`], 
     Hue[0.6499999539215624, 1, 0.1000000638009137], 
     Hue[0.6499982700550374, 1, 0.10000239530840976`], 
     Hue[0.649997310025984, 1, 0.10000372457940668`], 
     Hue[0.6499452847292683, 1, 0.10007575960562862`], 
     Hue[0.6499886776939561, 1, 0.10001567703913773`], 
     Hue[0.6499977069520597, 1, 0.10000317498945578`], 
     Hue[0.6499984305375945, 1, 0.10000217310179225`], 
     Hue[0.6499995741123579, 1, 0.10000058969058151`], 
     Hue[0.6499997386779457, 1, 0.1000003618305367], 
     Hue[0.6499988738287195, 1, 0.10000155931408075`], 
     Hue[0.6499995822700525, 1, 0.1000005783953119], 
     Hue[0.6499977323549201, 1, 0.10000313981626457`], 
     Hue[0.6499972818328055, 1, 0.10000376361611546`], 
     Hue[0.6499983540750625, 1, 0.10000227897299048`], 
     Hue[0.6499995672298762, 1, 0.10000059922017145`], 
     Hue[0.6499998500410374, 1, 0.10000020763548673`], 
     Hue[0.6499999121863456, 1, 0.10000012158813694`], 
     Hue[0.6499306690177541, 1, 0.10009599674464828`], 
     Hue[0.6499731279556002, 1, 0.10003720744609199`], 
     Hue[0.6499770919050559, 1, 0.10003171890069185`], 
     Hue[0.649985171412803, 1, 0.10002053188996514`], 
     Hue[0.6499374484373719, 1, 0.1000866098559467], 
     Hue[0.6499995672298762, 1, 0.10000059922017145`], 
     Hue[0.6499998500410374, 1, 0.10000020763548673`], 
     Hue[0.6499969119221585, 1, 0.10000427580008833`], 
     Hue[0.6499938301355158, 1, 0.10000854288928589`], 
     Hue[0.6499775554215892, 1, 0.10003107710856879`], 
     Hue[0.6498969735437105, 1, 0.10014265201640095`], 
     Hue[0.649985171412803, 1, 0.10002053188996515`], 
     Hue[0.6499995822700525, 1, 0.1000005783953119], 
     Hue[0.6499998922117048, 1, 0.10000014924533172`], 
     Hue[0.6499997981432292, 1, 0.1000002794939904], 
     Hue[0.6499938301355157, 1, 0.10000854288928591`], 
     Hue[0.6499989602457273, 1, 0.10000143965976215`], 
     Hue[0.6499914127424963, 1, 0.10001189004885142`], 
     Hue[0.6499446791317125, 1, 0.10007659812532119`], 
     Hue[0.6497389422959958, 1, 0.10036146451323662`], 
     Hue[0.6497143524323192, 1, 0.10039551201678877`], 
     Hue[0.07116385446886964, 1, 0.9014654322738728], 
     Hue[0.05242945985811742, 1, 0.9274053632733759], 
     Hue[0.6498967127539569, 1, 0.10014301310990587`], 
     Hue[0.6499774815479087, 1, 0.10003117939520335`], 
     Hue[0.6499968945489246, 1, 0.1000042998553351], 
     Hue[0.6499996708038481, 1, 0.10000045581005648`], 
     Hue[0.05244141947316405, 1, 0.9273888038063882], 
     Hue[0.05812442404615403, 1, 0.9195200282437868], 
     Hue[0.6499996736696589, 1, 0.10000045184201072`], 
     Hue[0.649985171412803, 1, 0.10002053188996514`], 
     Hue[0.6497387800110449, 1, 0.10036168921547634`], 
     Hue[0.6497140307026844, 1, 0.10039595748859087`], 
     Hue[0.649999637473088, 1, 0.10000050196033976`], 
     Hue[0.6499990284977293, 1, 0.10000134515699023`], 
     Hue[0.6499983540750625, 1, 0.10000227897299048`], 
     Hue[0.6499938301355157, 1, 0.10000854288928591`], 
     Hue[0.6499988113356224, 1, 0.10000164584298435`], 
     Hue[0.6499979341247507, 1, 0.10000286044265294`], 
     Hue[0.6499995672298762, 1, 0.10000059922017145`], 
     Hue[0.6499998500410374, 1, 0.10000020763548673`], 
     Hue[0.6499999121863456, 1, 0.10000012158813694`], 
     Hue[0.6499999042768432, 1, 0.1000001325397556], 
     Hue[0.6499998912637305, 1, 0.10000015055791167`], 
     Hue[0.6499997965508454, 1, 0.10000028169882953`], 
     Hue[0.6499998391866144, 1, 0.10000022266468775`], 
     Hue[0.6499997047177185, 1, 0.1000004088523898], 
     Hue[0.649985171412803, 1, 0.10002053188996514`], 
     Hue[0.6499731279556002, 1, 0.10003720744609197`], 
     Hue[0.6499995672298762, 1, 0.10000059922017145`], 
     Hue[0.6499998500410374, 1, 0.10000020763548673`], 
     Hue[0.6499999121863456, 1, 0.10000012158813694`], 
     Hue[0.6499989556520133, 1, 0.10000144602028942`], 
     Hue[0.6499986750923046, 1, 0.10000183448757825`], 
     Hue[0.6499986615165546, 1, 0.10000185328477061`], 
     Hue[0.6361358775823458, 1, 0.11919647719367511`], 
     Hue[0.6305689978315345, 1, 0.12690446454095228`], 
     Hue[0.6499986615165546, 1, 0.10000185328477061`], 
     Hue[0.6499988738287195, 1, 0.10000155931408075`], 
     Hue[0.6499998405135435, 1, 0.10000022082740136`], 
     Hue[0.6499995620862684, 1, 0.10000060634208989`], 
     Hue[0.6499996292674944, 1, 0.10000051332193075`], 
     Hue[0.6499163609929386, 1, 0.10011580785593122`], 
     Hue[0.649953508291059, 1, 0.10006437313545684`], 
     Hue[0.6499778401621346, 1, 0.10003068285242904`], 
     Hue[0.6499484012887502, 1, 0.10007144436942277`], 
     Hue[0.6496729232052973, 1, 0.10045287556189605`], 
     Hue[0.6497922176029923, 1, 0.10028769870354916`], 
     Hue[0.6498869780840074, 1, 0.10015649188368214`], 
     Hue[0.6497661825364089, 1, 0.10032374725728002`], 
     Hue[0.6142939372009442, 1, 0.1494391638756158], 
     Hue[0.5985789422584301, 1, 0.1711983876421737], 
     Hue[0.6125143440885943, 1, 0.151903215877331], 
     Hue[0.6361358775824969, 1, 0.11919647719346589`], 
     Hue[0.6305688882453164, 1, 0.1269046162757158], 
     Hue[0.6465876268599808, 1, 0.10472482434771889`], 
     Hue[0.6451366804176951, 1, 0.10673382711396066`], 
     Hue[0.6499995573613431, 1, 0.10000061288429428`], 
     Hue[0.6499959668971751, 1, 0.10000558429621911`], 
     Hue[0.6499991796688471, 1, 0.10000113584313482`], 
     Hue[0.6499986163812986, 1, 0.10000191577974038`], 
     Hue[0.6499984458205482, 1, 0.1000021519407794], 
     Hue[0.649665854084627, 1, 0.10046266357513191`], 
     Hue[0.6497616318703321, 1, 0.10033004817954015`], 
     Hue[0.6035542763094158, 1, 0.16430946357157808`], 
     Hue[0.598578942259135, 1, 0.1711983876411977], 
     Hue[0.6125143304747075, 1, 0.15190323472732808`], 
     Hue[0.6361358775824881, 1, 0.11919647719347794`], 
     Hue[0.6402282639250334, 1, 0.11353009610379994`], 
     Hue[0.6496729232052978, 1, 0.10045287556189539`], 
     Hue[0.6497922176029911, 1, 0.10028769870355077`], 
     Hue[0.6497661825364055, 1, 0.10032374725728466`], 
     Hue[0.6498869780840066, 1, 0.10015649188368317`], 
     Hue[0.6499163609929388, 1, 0.10011580785593091`], 
     Hue[0.649953508291059, 1, 0.10006437313545678`], 
     Hue[0.6499484012887502, 1, 0.1000714443694229], 
     Hue[0.6499778401621347, 1, 0.10003068285242903`], 
     Hue[0.6499989556520133, 1, 0.10000144602028942`], 
     Hue[0.6499977899595798, 1, 0.10000306005596647`], 
     Hue[0.6499982819147156, 1, 0.10000237888731685`], 
     Hue[0.6499998400120321, 1, 0.10000022152180169`], 
     Hue[0.6499984384726788, 1, 0.10000216211475245`], 
     Hue[0.6499996979082646, 1, 0.10000041828086434`], 
     Hue[0.6474507800970327, 1, 0.10352968909641623`], 
     Hue[0.6449606118130902, 1, 0.10697761441264439`], 
     Hue[0.6474507800970283, 1, 0.10352968909642238`], 
     Hue[0.6404078578025713, 1, 0.11328142765797827`], 
     Hue[0.6464577349439569, 1, 0.10490467469298291`], 
     Hue[0.6486829768945996, 1, 0.10182357045363134`], 
     Hue[0.6446153322487039, 1, 0.10745569380948687`], 
     Hue[0.6447410918958292, 1, 0.10728156506731354`], 
     Hue[0.647503644126962, 1, 0.10345649274728333`], 
     Hue[0.6499893047672064, 1, 0.10001480878386815`], 
     Hue[0.6499911083843236, 1, 0.10001231146785962`], 
     Hue[0.6499896198214707, 1, 0.10001437255488663`], 
     Hue[0.6499914684832315, 1, 0.10001181286937179`], 
     Hue[0.6499999487815362, 1, 0.10000007091787295`], 
     Hue[0.6499999721042841, 1, 0.10000003862483756`], 
     Hue[0.6499895638291427, 1, 0.10001445008272541`], 
     Hue[0.6499914149327589, 1, 0.10001188701617994`], 
     Hue[0.6142939372009378, 1, 0.14943916387562456`], 
     Hue[0.6499998853986138, 1, 0.1000001586788426], 
     Hue[0.6499999311814529, 1, 0.10000009528721902`], 
     Hue[0.6499892543051299, 1, 0.10001487865443559`], 
     Hue[0.6499910605536277, 1, 0.10001237769497713`], 
     Hue[0.6326534458675356, 1, 0.12401830572187386`], 
     Hue[0.6407433486684658, 1, 0.11281690184366276`], 
     Hue[0.6499370372257507, 1, 0.10008717922588375`], 
     Hue[0.6499476195382329, 1, 0.100072526793216], 
     Hue[0.6499896198214709, 1, 0.10001437255488661`], 
     Hue[0.6499914684832315, 1, 0.10001181286937177`], 
     Hue[0.6499893047672064, 1, 0.10001480878386813`], 
     Hue[0.6499911083843236, 1, 0.1000123114678596], 
     Hue[0.6499943020069127, 1, 0.10000788952889027`], 
     Hue[0.6499845467767462, 1, 0.10002139677065916`], 
     Hue[0.6499863220642538, 1, 0.10001893868026403`], 
     Hue[0.6499892412346377, 1, 0.10001489675204013`], 
     Hue[0.6499934844894636, 1, 0.10000902147612738`], 
     Hue[0.6499950367916136, 1, 0.10000687213468888`], 
     Hue[0.6499954637608208, 1, 0.10000628094655577`], 
     Hue[0.6499967513886306, 1, 0.10000449807728083`], 
     Hue[0.6499947006281697, 1, 0.1000073375917652], 
     Hue[0.6499859066827985, 1, 0.10001951382381748`], 
     Hue[0.6499873317975113, 1, 0.1000175405880613], 
     Hue[0.6499902463376951, 1, 0.1000135050708837], 
     Hue[0.6499940295942708, 1, 0.10000826671562513`], 
     Hue[0.6499988353026608, 1, 0.10000161265785429`], 
     Hue[0.6499966447492621, 1, 0.10000464573179094`], 
     Hue[0.6499977585830018, 1, 0.10000310350045905`], 
     Hue[0.649994657510819, 1, 0.1000073972927123], 
     Hue[0.6499858086661352, 1, 0.10001964953919741`], 
     Hue[0.6499872454109917, 1, 0.10001766020016539`], 
     Hue[0.6415728722699721, 1, 0.1116683307031157], 
     Hue[0.6206979778759806, 1, 0.14057203063325774`], 
     Hue[0.6499949966845507, 1, 0.10000692766754513`], 
     Hue[0.6498853473010373, 1, 0.10015874989087152`], 
     Hue[0.6499966447492621, 1, 0.10000464573179095`], 
     Hue[0.03503912140502463, 1, 0.9514842934391966], 
     Hue[0.05053038130689036, 1, 0.9300348566519979], 
     Hue[0.6496729232052978, 1, 0.1004528755618954], 
     Hue[0.6497922176029911, 1, 0.10028769870355077`], 
     Hue[0.6498869780840066, 1, 0.10015649188368317`], 
     Hue[0.6499163609929388, 1, 0.10011580785593092`], 
     Hue[0.649953508291059, 1, 0.10006437313545678`], 
     Hue[0.6499778401621347, 1, 0.10003068285242903`], 
     Hue[0.6476910569498755, 1, 0.10319699806940323`], 
     Hue[0.6499942635068771, 1, 0.10000794283663174`], 
     Hue[0.6499844592214795, 1, 0.10002151800102843`], 
     Hue[0.6499862450977085, 1, 0.10001904524932675`], 
     Hue[0.6499966447492621, 1, 0.10000464573179095`], 
     Hue[0.6499977585830018, 1, 0.10000310350045905`], 
     Hue[0.6499959664758339, 1, 0.10000558487961463`], 
     Hue[0.649998606782629, 1, 0.10000192907020604`], 
     Hue[0.6499283483312326, 1, 0.10009921000290879`], 
     Hue[0.6499327220179499, 1, 0.1000931541289924], 
     Hue[0.6499994416116589, 1, 0.10000077315308772`], 
     Hue[0.6499960082225426, 1, 0.10000552707647957`], 
     Hue[0.6499962429355867, 1, 0.10000520208918776`], 
     Hue[0.6499859066827985, 1, 0.10001951382381748`], 
     Hue[0.6499947006281697, 1, 0.10000733759176518`], 
     Hue[0.6499940295942708, 1, 0.10000826671562513`], 
     Hue[0.6499922175652754, 1, 0.1000107756788496], 
     Hue[0.6499873317975113, 1, 0.10001754058806128`], 
     Hue[0.6499988738287195, 1, 0.10000155931408075`], 
     Hue[0.6499989503600303, 1, 0.10000145334765041`], 
     Hue[0.6499950367916136, 1, 0.10000687213468887`], 
     Hue[0.6499954637608208, 1, 0.10000628094655577`], 
     Hue[0.6499845467767462, 1, 0.10002139677065915`], 
     Hue[0.6499943020069127, 1, 0.10000788952889027`], 
     Hue[0.6499934844894636, 1, 0.10000902147612736`], 
     Hue[0.649991672053883, 1, 0.10001153100231586`], 
     Hue[0.6499863220642538, 1, 0.10001893868026401`], 
     Hue[0.6499960082225426, 1, 0.10000552707647957`], 
     Hue[0.6499962429355867, 1, 0.10000520208918777`], 
     Hue[0.6499999167013311, 1, 0.10000011533661854`], 
     Hue[0.649916360992939, 1, 0.10011580785593062`], 
     Hue[0.6499535082910592, 1, 0.10006437313545645`], 
     Hue[0.6499778401621348, 1, 0.10003068285242887`], 
     Hue[0.6499484012887506, 1, 0.10007144436942225`], 
     Hue[0.6496729232053008, 1, 0.10045287556189123`], 
     Hue[0.6497922176029945, 1, 0.10028769870354609`], 
     Hue[0.6498869780840084, 1, 0.1001564918836807], 
     Hue[0.6497661825364115, 1, 0.1003237472572765], 
     Hue[0.03502800528463057, 1, 0.9514996849905115], 
     Hue[0.05053038130973697, 1, 0.9300348566480565], 
     Hue[0.6494393528554369, 1, 0.10077628066170284`], 
     Hue[0.6496696646085355, 1, 0.10045738746510469`], 
     Hue[0.6497649268362281, 1, 0.10032548591906884`], 
     Hue[0.6499947044858404, 1, 0.10000733225037489`], 
     Hue[0.6499953064467493, 1, 0.10000649876603943`], 
     Hue[0.6499990600199379, 1, 0.10000130151085525`], 
     Hue[0.6499993276345999, 1, 0.10000093096747711`], 
     Hue[0.6499940623865799, 1, 0.10000822131088946`], 
     Hue[0.614294199630169, 1, 0.1494388005120738], 
     Hue[0.649998945518936, 1, 0.10000146005070401`], 
     Hue[0.6499988244681159, 1, 0.10000162765953191`], 
     Hue[0.649999241196809, 1, 0.10000105065057222`], 
     Hue[0.649998945518936, 1, 0.10000146005070401`], 
     Hue[0.6499990565619045, 1, 0.10000130629890147`], 
     Hue[0.6491923510353136, 1, 0.10111828318187353`], 
     Hue[0.6488160455145384, 1, 0.10163932159525459`], 
     Hue[0.6431143057311567, 1, 0.10953403821839845`], 
     Hue[0.6450736851083142, 1, 0.10682105138848809`], 
     Hue[0.6499978209312278, 1, 0.10000301717214612`], 
     Hue[0.6465876268599643, 1, 0.10472482434774179`], 
     Hue[0.6475877606688776, 1, 0.1033400236892465], 
     Hue[0.6365954599072247, 1, 0.11856013243615052`], 
     Hue[0.6491923510353136, 1, 0.10111828318187348`], 
     Hue[0.6488157819929059, 1, 0.10163968647136115`], 
     Hue[0.6462858945624259, 1, 0.1051426075289488], 
     Hue[0.6456956484192908, 1, 0.10595987141944353`], 
     Hue[0.6460003620577588, 1, 0.10553796022771858`], 
     Hue[0.6456223614019657, 1, 0.1060613457511244], 
     Hue[0.6471780107787616, 1, 0.10390736969094559`], 
     Hue[0.6465876268599798, 1, 0.1047248243477203], 
     Hue[0.6475874797640361, 1, 0.10334041263441161`], 
     Hue[0.5614912777433805, 1, 0.22255053850916562`], 
     Hue[0.5849385292515442, 1, 0.19008511334401573`], 
     Hue[0.5781206880423904, 1, 0.19952520117207484`], 
     Hue[0.591348319402325, 1, 0.18121001928908845`], 
     Hue[0.643114305731053, 1, 0.10953403821854209`], 
     Hue[0.6404083161808928, 1, 0.11328079298030237`], 
     Hue[0.649991672053883, 1, 0.10001153100231587`], 
     Hue[0.6499922175652753, 1, 0.10001077567884961`], 
     Hue[0.6499947044858404, 1, 0.10000733225037488`], 
     Hue[0.6499879463772358, 1, 0.10001668963151969`], 
     Hue[0.6499683182643626, 1, 0.10004386701857493`], 
     Hue[0.6499713739907875, 1, 0.10003963601275573`], 
     Hue[0.6499921601348203, 1, 0.10001085519794112`], 
     Hue[0.6361405484872709, 1, 0.11919000978685584`], 
     Hue[0.6304056690287502, 1, 0.12713061211403834`], 
     Hue[0.6499033184273612, 1, 0.10013386679288462`], 
     Hue[0.6499485358404218, 1, 0.10007125806710834`], 
     Hue[0.6499967228926259, 1, 0.10000453753328727`], 
     Hue[0.6499255031609498, 1, 0.10010314946945419`], 
     Hue[0.6499934162037112, 1, 0.10000911602563067`], 
     Hue[0.6499927108076778, 1, 0.10001009272783067`], 
     Hue[0.5848475422716374, 1, 0.19021109531619446`], 
     Hue[0.606443611541854, 1, 0.16030884555743297`], 
     Hue[0.6499916208740619, 1, 0.10001160186668359`], 
     Hue[0.6361405484872588, 1, 0.11919000978687258`], 
     Hue[0.6395664466518229, 1, 0.11444645848209142`], 
     Hue[0.645345147629168, 1, 0.10644518020576754`], 
     Hue[0.6461546244815918, 1, 0.10532436610241147`], 
     Hue[0.6498853473010362, 1, 0.10015874989087303`], 
     Hue[0.6499848149764142, 1, 0.10002102541727263`], 
     Hue[0.6499931061879602, 1, 0.10000954527820886`], 
     Hue[0.649961586942009, 1, 0.10005318731106444`], 
     Hue[0.6499818402890271, 1, 0.10002514421519335`], 
     Hue[0.6499973860644361, 1, 0.1000036192953962], 
     Hue[0.6499988179951584, 1, 0.1000016366220884], 
     Hue[0.6499742521499005, 1, 0.1000356508693687], 
     Hue[0.6499664920844146, 1, 0.10004639557542605`], 
     Hue[0.6499538534713674, 1, 0.10006389519349133`], 
     Hue[0.6499902463376951, 1, 0.10001350507088369`], 
     Hue[0.6499892412346377, 1, 0.10001489675204013`], 
     Hue[0.6499995967086464, 1, 0.10000055840341276`], 
     Hue[0.6499995967086464, 1, 0.10000055840341276`], 
     Hue[0.6499993652334957, 1, 0.10000087890746762`], 
     Hue[0.6499932958795042, 1, 0.10000928262837881`], 
     Hue[0.6499992914358198, 1, 0.10000098108886499`], 
     Hue[0.6499994978653971, 1, 0.10000069526329639`], 
     Hue[0.6499954119884139, 1, 0.10000635263142685`], 
     Hue[0.6494083156717524, 1, 0.10081925522372753`], 
     Hue[0.6496390806277188, 1, 0.10049973451546627`], 
     Hue[0.6498293943271902, 1, 0.10023622323927514`], 
     Hue[0.6499081642305828, 1, 0.100127157219193], 
     Hue[0.6474018333248249, 1, 0.10359746155024246`], 
     Hue[0.6480158984689418, 1, 0.10274721750454217`], 
     Hue[0.647966455917048, 1, 0.10281567642254884`], 
     Hue[0.6477721012453109, 1, 0.10308478289110791`], 
     Hue[0.6481282101836034, 1, 0.1025917089765491], 
     Hue[0.648038233050599, 1, 0.10271629269917062`], 
     Hue[0.6478300313592262, 1, 0.10300457196414828`], 
     Hue[0.6499987450974997, 1, 0.10000173755730814`], 
     Hue[0.6499968555673088, 1, 0.10000435382988013`], 
     Hue[0.6499969315998197, 1, 0.10000424855409581`], 
     Hue[0.644377884125887, 1, 0.1077844681333873], 
     Hue[0.6437589917918137, 1, 0.10864139598056559`], 
     Hue[0.6428975370312371, 1, 0.10983417949521028`], 
     Hue[0.6498293943271902, 1, 0.10023622323927515`], 
     Hue[0.6498124464093857, 1, 0.1002596895870044], 
     Hue[0.649961586942009, 1, 0.10005318731106445`], 
     Hue[0.6499577843531885, 1, 0.10005845243404672`], 
     Hue[0.648306135542982, 1, 0.10234535078664032`], 
     Hue[0.6475476903013399, 1, 0.10339550573660646`], 
     Hue[0.6472851403989724, 1, 0.10375903637065359`], 
     Hue[0.6498258895552936, 1, 0.10024107600036264`], 
     Hue[0.6499995384858683, 1, 0.10000063901956702`], 
     Hue[0.6499995484386257, 1, 0.10000062523882598`], 
     Hue[0.6499997367362648, 1, 0.10000036451901806`], 
     Hue[0.6499997506890729, 1, 0.10000034519974534`], 
     Hue[0.6494809479153911, 1, 0.10071868750176614`], 
     Hue[0.6495779574981979, 1, 0.10058436654095675`], 
     Hue[0.6499879463772358, 1, 0.1000166896315197], 
     Hue[0.6499924023154049, 1, 0.10001051987097787`], 
     Hue[0.6499987539211727, 1, 0.10000172533991486`], 
     Hue[0.6438294336870249, 1, 0.10854386104873467`], 
     Hue[0.6478386059597472, 1, 0.10299269944035015`], 
     Hue[0.6479232892384299, 1, 0.10287544566986638`], 
     Hue[0.6449089059890544, 1, 0.10704920709207866`], 
     Hue[0.6443963651954955, 1, 0.10775887896008324`], 
     Hue[0.6486592591767456, 1, 0.10185641037066004`], 
     Hue[0.6481400490447606, 1, 0.1025753167072545], 
     Hue[0.6499998406376782, 1, 0.10000022065552244`], 
     Hue[0.6499997285869414, 1, 0.10000037580269656`], 
     Hue[0.6499991149582264, 1, 0.10000122544245589`], 
     Hue[0.649990745780477, 1, 0.10001281353472413`], 
     Hue[0.6499872851621001, 1, 0.10001760516016904`], 
     Hue[0.6499928687028823, 1, 0.10000987410370149`], 
     Hue[0.6499902459174384, 1, 0.10001350565277763`], 
     Hue[0.6499993476936773, 1, 0.1000009031933699], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499987762295317, 1, 0.10000169445141764`], 
     Hue[0.649950538320686, 1, 0.10006848540212707`], 
     Hue[0.6499169012778275, 1, 0.10011505976916187`], 
     Hue[0.6499384202733739, 1, 0.10008526423686702`], 
     Hue[0.6499979396020884, 1, 0.10000285285864687`], 
     Hue[0.6499998944694872, 1, 0.10000014611917156`], 
     Hue[0.6499943973499914, 1, 0.10000775751539649`], 
     Hue[0.6496669893384682, 1, 0.1004610916851979], 
     Hue[0.649946398470897, 1, 0.10007421750183501`], 
     Hue[0.649993719165779, 1, 0.10000869653969072`], 
     Hue[0.6497827013349247, 1, 0.10030087507471978`], 
     Hue[0.6496669043016358, 1, 0.10046120942850442`], 
     Hue[0.6497492556366449, 1, 0.10034718450310716`], 
     Hue[0.6499936916833658, 1, 0.10000873459226267`], 
     Hue[0.6499735114284139, 1, 0.10003667648373474`], 
     Hue[0.6497686522347684, 1, 0.10032032767493607`], 
     Hue[0.6493221359730589, 1, 0.10093858096038005`], 
     Hue[0.6491243836319389, 1, 0.10121239189423846`], 
     Hue[0.6493577841898454, 1, 0.10088922189098344`], 
     Hue[0.6497848661512468, 1, 0.10029787763673528`], 
     Hue[0.6499645347886049, 1, 0.10004910567731624`], 
     Hue[0.6493571286681645, 1, 0.10089012953638754`], 
     Hue[0.6491243444061469, 1, 0.10121244620687354`], 
     Hue[0.6493225788760635, 1, 0.10093796771006598`], 
     Hue[0.64975855562808, 1, 0.10033430759188927`], 
     Hue[0.6499720083241632, 1, 0.10003875770500482`], 
     Hue[0.6499179695206531, 1, 0.1001135806637112], 
     Hue[0.6494608701931665, 1, 0.10074648742484656`], 
     Hue[0.6487286338295368, 1, 0.10176035315910295`], 
     Hue[0.648388110556423, 1, 0.10223184692187594`], 
     Hue[0.6486206497020784, 1, 0.10190986964327597`], 
     Hue[0.6493623255583338, 1, 0.10088293384230708`], 
     Hue[0.6498452129760722, 1, 0.10021432049466919`], 
     Hue[0.6486204310728421, 1, 0.10191017236068024`], 
     Hue[0.6483883164107923, 1, 0.10223156189274911`], 
     Hue[0.6487288669092452, 1, 0.10176003043335274`], 
     Hue[0.6494481187205927, 1, 0.10076414330994857`], 
     Hue[0.6498285638060287, 1, 0.1002373731916526], 
     Hue[0.6490732055840215, 1, 0.10128325380673955`], 
     Hue[0.6481845887416958, 1, 0.10251364635765203`], 
     Hue[0.6476640151146047, 1, 0.10323444061054733`], 
     Hue[0.6485080528944321, 1, 0.10206577291540167`], 
     Hue[0.6494626278600282, 1, 0.10074405373226872`], 
     Hue[0.6485074236435951, 1, 0.10206664418579137`], 
     Hue[0.6476644005941146, 1, 0.10323390686968757`], 
     Hue[0.6476782205548369, 1, 0.10321477153945656`], 
     Hue[0.6481847142239625, 1, 0.102513472612975], 
     Hue[0.6497498661728607, 1, 0.10034633914526986`], 
     Hue[0.6487943291253612, 1, 0.10166939044180758`], 
     Hue[0.6477867920179302, 1, 0.1030644418213274], 
     Hue[0.6470649192956859, 1, 0.10406395789828114`], 
     Hue[0.6466285838488329, 1, 0.10466811467084673`], 
     Hue[0.6471334129224622, 1, 0.1039691205688986], 
     Hue[0.6484656021365416, 1, 0.1021245508878656], 
     Hue[0.6471333502188961, 1, 0.10396920738922091`], 
     Hue[0.6466294094583314, 1, 0.10466697151923357`], 
     Hue[0.6470654457983444, 1, 0.10406322889460015`], 
     Hue[0.647787115327827, 1, 0.10306399416147034`], 
     Hue[0.6497201483868429, 1, 0.10038748684898678`], 
     Hue[0.6486615686527496, 1, 0.1018532126346544], 
     Hue[0.6464928403325366, 1, 0.10485606723187232`], 
     Hue[0.6452016973298763, 1, 0.10664380369709445`], 
     Hue[0.6459425149455625, 1, 0.10561805622922109`], 
     Hue[0.6465290067252066, 1, 0.10480599068817552`], 
     Hue[0.6455644065284432, 1, 0.10614159096061725`], 
     Hue[0.6464934559422196, 1, 0.10485521484923437`], 
     Hue[0.6474600972735771, 1, 0.1035167883904317], 
     Hue[0.6497444578897738, 1, 0.10035382753723636`], 
     Hue[0.6486721458807168, 1, 0.10183856724208448`], 
     Hue[0.6472340635887618, 1, 0.10382975810786839`], 
     Hue[0.6459052314226392, 1, 0.10566967956865347`], 
     Hue[0.6421307435745531, 1, 0.11089589351215723`], 
     Hue[0.6384784081121809, 1, 0.1159529733831342], 
     Hue[0.644391249173835, 1, 0.10776596268238246`], 
     Hue[0.6459060748044504, 1, 0.10566851180922257`], 
     Hue[0.6472266389834003, 1, 0.10384003833067652`], 
     Hue[0.6486721421475293, 1, 0.10183857241111328`], 
     Hue[0.6498178986902056, 1, 0.10025214027509997`], 
     Hue[0.6488754715936943, 1, 0.10155703933180799`], 
     Hue[0.6471954778691618, 1, 0.1038831844888529], 
     Hue[0.6343038838830037, 1, 0.12173308385430251`], 
     Hue[0.6131150084106854, 1, 0.151071526815974], 
     Hue[0.599873725624631, 1, 0.16940561067358784`], 
     Hue[0.6427107986431025, 1, 0.11009274034031961`], 
     Hue[0.6453186380741933, 1, 0.10648188574342467`], 
     Hue[0.6471976417124086, 1, 0.10388018839820357`], 
     Hue[0.6488751499378577, 1, 0.10155748470142792`], 
     Hue[0.649904864696231, 1, 0.10013172580521869`], 
     Hue[0.6492211282544359, 1, 0.10107843780155036`], 
     Hue[0.6474440549356896, 1, 0.103539000858276], 
     Hue[0.611318404019485, 1, 0.15355913289609768`], 
     Hue[0.5438542150943828, 1, 0.2469710867923931], 
     Hue[0.5054107485801693, 1, 0.3002005019659194], 
     Hue[0.5442403811389213, 1, 0.2464363953461091], 
     Hue[0.6391838480536877, 1, 0.11497621038720175`], 
     Hue[0.6448183521044771, 1, 0.10717458939380087`], 
     Hue[0.6474700106798146, 1, 0.10350306213564132`], 
     Hue[0.6492205124027042, 1, 0.10107929051933276`], 
     Hue[0.6499637194211009, 1, 0.10005023464770656`], 
     Hue[0.6495635854272803, 1, 0.10060426633145804`], 
     Hue[0.6479727326168065, 1, 0.10280698560749861`], 
     Hue[0.5613439013165955, 1, 0.2227545981770216], 
     Hue[0.420727802056995, 1, 0.4174538125364685], 
     Hue[0.35056984491384907`, 1, 0.5145955993500552], 
     Hue[0.42074601092973296`, 1, 0.41742860025113904`], 
     Hue[0.5603644258502979, 1, 0.2241107949765106], 
     Hue[0.632088131456607, 1, 0.12480104875239027`], 
     Hue[0.644535609635832, 1, 0.10756607896577114`], 
     Hue[0.6479722666001164, 1, 0.10280763086137731`], 
     Hue[0.6499896086305067, 1, 0.10001438805006765`], 
     Hue[0.64980367395518, 1, 0.10027183606205853`], 
     Hue[0.6486308130733798, 1, 0.1018957972830126], 
     Hue[0.4875629896788311, 1, 0.3249127835216185], 
     Hue[0.2794714163728054, 1, 0.6130395773299617], 
     Hue[0.19202572741733248`, 1, 0.7341182235760012], 
     Hue[0.2795012782577532, 1, 0.6129982301046494], 
     Hue[0.6197571630581281, 1, 0.1418746973041303], 
     Hue[0.6445188584206577, 1, 0.10758927295601249`], 
     Hue[0.6486298611368392, 1, 0.10189711534899197`], 
     Hue[0.6499974802341777, 1, 0.10000348890652329`], 
     Hue[0.649939804960482, 1, 0.10008334697779414`], 
     Hue[0.4134396293930329, 1, 0.42754512853272375`], 
     Hue[0.16660070648985764`, 1, 0.7693220987063509], 
     Hue[0.6051860768209053, 1, 0.16205004747874657`], 
     Hue[0.6446747005059876, 1, 0.10737349160709404`], 
     Hue[0.6492984661033738, 1, 0.10097135462609774`], 
     Hue[0.6499996082984593, 1, 0.1000005423559795], 
     Hue[0.6439828956081195, 1, 0.10833137531183465`], 
     Hue[0.5939696963120576, 1, 0.17758042049099715`], 
     Hue[0.3699235753786966, 1, 0.48779812639872777`], 
     Hue[0.10993697241782385`, 1, 0.8477795766522439], 
     Hue[0.5950760330690096, 1, 0.17604856959675602`], 
     Hue[0.6448213068074831, 1, 0.10717049826656197`], 
     Hue[0.37117736989663025`, 1, 0.4860621032200505], 
     Hue[0.10995731693026656`, 1, 0.8477514073273232], 
     Hue[0.36992357538044274`, 1, 0.48779812639631004`], 
     Hue[0.5939696963127171, 1, 0.17758042049008405`], 
     Hue[0.64482178764344, 1, 0.10716983249369852`], 
     Hue[0.6499978738704448, 1, 0.10000294387169176`], 
     Hue[0.6499395617051158, 1, 0.1000836837929167], 
     Hue[0.41486309731247367`, 1, 0.42557417295195954`], 
     Hue[0.16664015272547333`, 1, 0.7692674808416523], 
     Hue[0.41343962939487927`, 1, 0.42754512853016724`], 
     Hue[0.6042150040106968, 1, 0.16339460983134285`], 
     Hue[0.644675413069162, 1, 0.10737250498116035`], 
     Hue[0.6492993957289521, 1, 0.10097006745222023`], 
     Hue[0.6499974802341777, 1, 0.10000348890652329`], 
     Hue[0.6499895375823748, 1, 0.10001448642440418`], 
     Hue[0.6498247725796032, 1, 0.10024262258208785`], 
     Hue[0.6486298611368391, 1, 0.10189711534899205`], 
     Hue[0.48758898573002984`, 1, 0.3248767889891895], 
     Hue[0.2795012782574238, 1, 0.6129982301051055], 
     Hue[0.19202572741537732`, 1, 0.7341182235787083], 
     Hue[0.27947141637247735`, 1, 0.613039577330416], 
     Hue[0.6197500814767575, 1, 0.14188450257064347`], 
     Hue[0.6445187656803512, 1, 0.10758940136566773`], 
     Hue[0.648722707184793, 1, 0.10176855928259446`], 
     Hue[0.6498036739551807, 1, 0.1002718360620575], 
     Hue[0.6499887115763905, 1, 0.10001563012499778`], 
     Hue[0.6499635376940699, 1, 0.10005048626974944`], 
     Hue[0.6495955370911406, 1, 0.10056002556611313`], 
     Hue[0.6479722666001381, 1, 0.10280763086134731`], 
     Hue[0.5613710441027732, 1, 0.22271701585769876`], 
     Hue[0.42074601093061925`, 1, 0.4174286002499118], 
     Hue[0.3505698449147388, 1, 0.5145955993488232], 
     Hue[0.4207278020584655, 1, 0.4174538125344325], 
     Hue[0.6320807432699589, 1, 0.1248112785492878], 
     Hue[0.6445346715615178, 1, 0.10756737783789842`], 
     Hue[0.6479727326168283, 1, 0.1028069856074685], 
     Hue[0.6495635854272815, 1, 0.10060426633145629`], 
     Hue[0.6499045423782823, 1, 0.1001321720916092], 
     Hue[0.6492205124027052, 1, 0.10107929051933137`], 
     Hue[0.6113350077371776, 1, 0.1535361431331387], 
     Hue[0.5442403811399456, 1, 0.24643639534469083`], 
     Hue[0.5054107485816477, 1, 0.3002005019638725], 
     Hue[0.6393231015822665, 1, 0.11478339780916952`], 
     Hue[0.6448171573226971, 1, 0.10717624370703491`], 
     Hue[0.6474440549357099, 1, 0.10353900085824791`], 
     Hue[0.6492211282544369, 1, 0.10107843780154897`], 
     Hue[0.6498175387315117, 1, 0.10025263867944542`], 
     Hue[0.6488751499378581, 1, 0.1015574847014272], 
     Hue[0.6342357357138431, 1, 0.12182744285775579`], 
     Hue[0.6131190636402776, 1, 0.15106591188269267`], 
     Hue[0.6427084326690243, 1, 0.11009601630442792`], 
     Hue[0.6453175862657006, 1, 0.10648334209364542`], 
     Hue[0.6471954778691709, 1, 0.10388318448884043`], 
     Hue[0.6488754715936947, 1, 0.10155703933180728`], 
     Hue[0.6497442349944516, 1, 0.1003541361615287], 
     Hue[0.6486721421475296, 1, 0.1018385724111129], 
     Hue[0.6459060748044588, 1, 0.1056685118092109], 
     Hue[0.6421328552373109, 1, 0.11089296967141571`], 
     Hue[0.6384789975537066, 1, 0.11595215723332938`], 
     Hue[0.64438993383294, 1, 0.1077677839236217], 
     Hue[0.6459052314226476, 1, 0.10566967956864194`], 
     Hue[0.6472260492528706, 1, 0.10384085488064075`], 
     Hue[0.6486721458807171, 1, 0.10183856724208414`], 
     Hue[0.6497201201157684, 1, 0.10038752599355154`], 
     Hue[0.648666544096528, 1, 0.10184632355865361`], 
     Hue[0.6464934559422207, 1, 0.1048552148492328], 
     Hue[0.6452024257205371, 1, 0.10664279515617942`], 
     Hue[0.6459417553417114, 1, 0.10561910798839959`], 
     Hue[0.6455633919912057, 1, 0.10614299570448435`], 
     Hue[0.6464928403325377, 1, 0.10485606723187087`], 
     Hue[0.647459617606195, 1, 0.10351745254526855`], 
     Hue[0.6486615686527497, 1, 0.10185321263465423`], 
     Hue[0.6497500661969323, 1, 0.10034606218886297`], 
     Hue[0.6487973060787215, 1, 0.1016652685063855], 
     Hue[0.6477871153278271, 1, 0.10306399416147022`], 
     Hue[0.6470654457983444, 1, 0.10406322889460012`], 
     Hue[0.6466294094583315, 1, 0.10466697151923335`], 
     Hue[0.6471333502189089, 1, 0.10396920738920298`], 
     Hue[0.6484645052704798, 1, 0.1021260696254895], 
     Hue[0.6491328333766917, 1, 0.10120069224765768`], 
     Hue[0.6471334129224494, 1, 0.10396912056891619`], 
     Hue[0.6466285838488329, 1, 0.10466811467084676`], 
     Hue[0.6470649192956859, 1, 0.10406395789828118`], 
     Hue[0.64778679201793, 1, 0.1030644418213277], 
     Hue[0.6487943291253612, 1, 0.1016693904418076], 
     Hue[0.6498289592233316, 1, 0.10023682569077168`], 
     Hue[0.6490820712669709, 1, 0.10127097824573265`], 
     Hue[0.6481847142239626, 1, 0.1025134726129749], 
     Hue[0.6476782205548369, 1, 0.10321477153945664`], 
     Hue[0.6476644005941143, 1, 0.10323390686968784`], 
     Hue[0.6485074236435971, 1, 0.10206664418578854`], 
     Hue[0.6494782446417824, 1, 0.10072243049599366`], 
     Hue[0.6485080528944301, 1, 0.10206577291540447`], 
     Hue[0.6476640151146049, 1, 0.10323444061054705`], 
     Hue[0.6476673319658688, 1, 0.10322984804725867`], 
     Hue[0.6481845887416956, 1, 0.1025136463576523], 
     Hue[0.6490732055840214, 1, 0.10128325380673972`], 
     Hue[0.6499183291303126, 1, 0.10011308274264412`], 
     Hue[0.6494481187205927, 1, 0.10076414330994854`], 
     Hue[0.6487288669092454, 1, 0.10176003043335265`], 
     Hue[0.6483883164107922, 1, 0.10223156189274928`], 
     Hue[0.6486204310728418, 1, 0.10191017236068052`], 
     Hue[0.6493634059128112, 1, 0.10088143796687682`], 
     Hue[0.649854937980913, 1, 0.1002008551033513], 
     Hue[0.6493623255583336, 1, 0.10088293384230729`], 
     Hue[0.6486206497020787, 1, 0.1019098696432757], 
     Hue[0.6483881105564231, 1, 0.1022318469218758], 
     Hue[0.6487286338295367, 1, 0.10176035315910312`], 
     Hue[0.6499736942470771, 1, 0.10003642335020098`], 
     Hue[0.64975855562808, 1, 0.10033430759188922`], 
     Hue[0.6493225788760636, 1, 0.1009379677100659], 
     Hue[0.6491243444061467, 1, 0.10121244620687374`], 
     Hue[0.6497870627427598, 1, 0.10029483620233268`], 
     Hue[0.6497848661512468, 1, 0.10029787763673526`], 
     Hue[0.6493577841898455, 1, 0.10088922189098319`], 
     Hue[0.649124383631939, 1, 0.10121239189423825`], 
     Hue[0.6493221359730588, 1, 0.10093858096038015`], 
     Hue[0.6499936916833658, 1, 0.10000873459226267`], 
     Hue[0.6499293875019, 1, 0.10009777115121549`], 
     Hue[0.6497492556366449, 1, 0.1003471845031071], 
     Hue[0.6496669043016357, 1, 0.10046120942850455`], 
     Hue[0.6499461593618887, 1, 0.10007454857584651`], 
     Hue[0.649993719165779, 1, 0.10000869653969072`], 
     Hue[0.6497831131736973, 1, 0.10030030483641916`], 
     Hue[0.6496669893384683, 1, 0.10046109168519776`], 
     Hue[0.6497438699910105, 1, 0.10035464155090854`], 
     Hue[0.6499989806170189, 1, 0.10000141145335847`], 
     Hue[0.649985101517905, 1, 0.10002062866751625`], 
     Hue[0.6499903637000147, 1, 0.10001334256921046`], 
     Hue[0.649950695639109, 1, 0.1000682675766184], 
     Hue[0.6499169408087976, 1, 0.10011500503397268`], 
     Hue[0.6499382721143278, 1, 0.1000854693801616], 
     Hue[0.6499998944694872, 1, 0.10000014611917156`], 
     Hue[0.6499979396020884, 1, 0.10000285285864687`], 
     Hue[0.6499988051348664, 1, 0.10000165442864654`], 
     Hue[0.6499928687028823, 1, 0.10000987410370148`], 
     Hue[0.649990745780477, 1, 0.10001281353472413`], 
     Hue[0.6499993476880973, 1, 0.10000090320109607`], 
     Hue[0.6499925368181951, 1, 0.1000103336363452], 
     Hue[0.6499544789815872, 1, 0.10006302910241772`], 
     Hue[0.6499710158419191, 1, 0.10004013191118909`], 
     Hue[0.6499957079341608, 1, 0.10000594286039266`], 
     Hue[0.649956754063224, 1, 0.10005987898938218`], 
     Hue[0.6499973394962008, 1, 0.10000368377449126`], 
     Hue[0.6497967031430824, 1, 0.10028148795573211`], 
     Hue[0.6497422006045632, 1, 0.10035695300906637`], 
     Hue[0.6498543989283845, 1, 0.10020160148377542`], 
     Hue[0.6499796318088381, 1, 0.10002820211083958`], 
     Hue[0.6498201909540229, 1, 0.10024896637135303`], 
     Hue[0.6499821959348161, 1, 0.1000246517825623], 
     Hue[0.6493843083159343, 1, 0.10085249617793718`], 
     Hue[0.6492714389145247, 1, 0.10100877688758132`], 
     Hue[0.6495311358384765, 1, 0.10064919653134018`], 
     Hue[0.6499326287044422, 1, 0.10009328333231075`], 
     Hue[0.6490374185577825, 1, 0.10133280507383961`], 
     Hue[0.6489306887868327, 1, 0.10148058475669318`], 
     Hue[0.6493199214653447, 1, 0.10094164720183046`], 
     Hue[0.6494380510073351, 1, 0.10077808322061302`], 
     Hue[0.6499097362338689, 1, 0.10012498059925846`], 
     Hue[0.6486670765987008, 1, 0.10184558624795277`], 
     Hue[0.6485711159572851, 1, 0.10197845482837456`], 
     Hue[0.6489814055841803, 1, 0.1014103614988274], 
     Hue[0.6496859288220751, 1, 0.10043486778481915`], 
     Hue[0.6498492997424695, 1, 0.10020866189504221`], 
     Hue[0.6492162512642067, 1, 0.10108519055725237`], 
     Hue[0.6484785424654154, 1, 0.10210663350942495`], 
     Hue[0.6485590288669336, 1, 0.10199519079963036`], 
     Hue[0.6486312945647218, 1, 0.10189513060269287`], 
     Hue[0.64964448028359, 1, 0.10049225806887534`], 
     Hue[0.6477258602117325, 1, 0.10314880893760124`], 
     Hue[0.6478481526586202, 1, 0.10297948093421826`], 
     Hue[0.6483894496489135, 1, 0.10222999279381205`], 
     Hue[0.6497669433721043, 1, 0.1003226937924711], 
     Hue[0.6488750409140394, 1, 0.10155763565748402`], 
     Hue[0.6479927325367794, 1, 0.1027792934106133], 
     Hue[0.6475834488846898, 1, 0.103345993851968], 
     Hue[0.647294545382292, 1, 0.10374601408605726`], 
     Hue[0.6488721916036159, 1, 0.10156158085653198`], 
     Hue[0.6466982385822284, 1, 0.10457166965537615`], 
     Hue[0.6472169204860098, 1, 0.10385349471167879`], 
     Hue[0.6479788895815403, 1, 0.10279846057940577`], 
     Hue[0.6497220759135403, 1, 0.1003848179658674], 
     Hue[0.6486943253197311, 1, 0.10180785724960312`], 
     Hue[0.6454301116848207, 1, 0.10632753766717139`], 
     Hue[0.6468897902012749, 1, 0.1043064443366963], 
     Hue[0.6456433109470756, 1, 0.10603233868866456`], 
     Hue[0.6466457526689814, 1, 0.10464434245833346`], 
     Hue[0.6475978994814843, 1, 0.10332598533332953`], 
     Hue[0.6497395116100092, 1, 0.10036067623229504`], 
     Hue[0.648656146199945, 1, 0.10186072064622992`], 
     Hue[0.6425869541067043, 1, 0.11026421739071718`], 
     Hue[0.6412672325871597, 1, 0.1120915241100867], 
     Hue[0.6444863018191666, 1, 0.10763435132730781`], 
     Hue[0.6460978666860328, 1, 0.10540295381933926`], 
     Hue[0.6473189778091596, 1, 0.10371218457193296`], 
     Hue[0.649807523533853, 1, 0.10026650587620367`], 
     Hue[0.6488059954277982, 1, 0.10165323709997189`], 
     Hue[0.6355677813921233, 1, 0.11998307191859846`], 
     Hue[0.6225136803974088, 1, 0.1380579809882031], 
     Hue[0.6428745456415313, 1, 0.10986601372711048`], 
     Hue[0.6454891179706859, 1, 0.10624583665597352`], 
     Hue[0.6471883956275378, 1, 0.1038929906695631], 
     Hue[0.6487415025304522, 1, 0.10174253495783556`], 
     Hue[0.6498948423987034, 1, 0.10014560283256452`], 
     Hue[0.6491243397305968, 1, 0.10121245268071222`], 
     Hue[0.6472376528773863, 1, 0.10382478832361895`], 
     Hue[0.6150728538407592, 1, 0.14836066391279507`], 
     Hue[0.5682104334557555, 1, 0.21324709213818469`], 
     Hue[0.6397468996933341, 1, 0.11419660042461435`], 
     Hue[0.6449758474343685, 1, 0.10695651893702825`], 
     Hue[0.6473203313841579, 1, 0.10371031039116604`], 
     Hue[0.649958109515708, 1, 0.10005800220901968`], 
     Hue[0.6494842522907931, 1, 0.10071411221274804`], 
     Hue[0.6476512819636768, 1, 0.1032520711272168], 
     Hue[0.5687382725777202, 1, 0.2125162379693105], 
     Hue[0.4598365727270398, 1, 0.3633032069933295], 
     Hue[0.6330024607855063, 1, 0.12353505429699133`], 
     Hue[0.6446614119196817, 1, 0.10739189118813307`], 
     Hue[0.6477602551397409, 1, 0.10310118519112803`], 
     Hue[0.6499875975622534, 1, 0.10001717260611061`], 
     Hue[0.6497589618188877, 1, 0.1003337451738478], 
     Hue[0.6483004248350014, 1, 0.10235325792076734`], 
     Hue[0.49721716070323696`, 1, 0.3115454697955181], 
     Hue[0.31803818591272426`, 1, 0.5596394348900742], 
     Hue[0.621196668559564, 1, 0.13988153584060375`], 
     Hue[0.6446057461858452, 1, 0.10746896681959894`], 
     Hue[0.6484128933058226, 1, 0.10219753234578413`], 
     Hue[0.6499971946455725, 1, 0.10000388433689966`], 
     Hue[0.6499119444868917, 1, 0.10012192301814993`], 
     Hue[0.42186155100194733`, 1, 0.4158840063049961], 
     Hue[0.19690139772980203`, 1, 0.7273672954510433], 
     Hue[0.6066857938393704, 1, 0.15997351622241032`], 
     Hue[0.6447269791201125, 1, 0.10730110583369051`], 
     Hue[0.6490601902829536, 1, 0.10130127499283355`], 
     Hue[0.373210137296724, 1, 0.48324750220453605`], 
     Hue[0.12317793669624733`, 1, 0.829445933805196], 
     Hue[0.5959049495707656, 1, 0.1749008390558631], 
     Hue[0.36993896493495954`, 1, 0.4877768177823637], 
     Hue[0.10551553714933015`, 1, 0.8539015639470814], 
     Hue[0.5947857583630186, 1, 0.17645048842043587`], 
     Hue[0.6448143518714223, 1, 0.10718012817803063`], 
     Hue[0.6499983476490149, 1, 0.10000228787059483`], 
     Hue[0.4092648191983703, 1, 0.43332563495610266`], 
     Hue[0.1447215641957238, 1, 0.7996162957289977], 
     Hue[0.37321013729844094`, 1, 0.48324750220215873`], 
     Hue[0.6039331393082457, 1, 0.16378488403473676`], 
     Hue[0.6446386253954931, 1, 0.1074234417600865], 
     Hue[0.649992139261425, 1, 0.10001088409956545`], 
     Hue[0.47992518690075703`, 1, 0.335488202752798], 
     Hue[0.2386766428431551, 1, 0.669524648371016], 
     Hue[0.6189100178908071, 1, 0.1430476675358055], 
     Hue[0.6444502281867965, 1, 0.1076842994336663], 
     Hue[0.6490074389437255, 1, 0.10137431530868783`], 
     Hue[0.6499711752825617, 1, 0.10003991114722234`], 
     Hue[0.5547703620061074, 1, 0.23185642183769747`], 
     Hue[0.3752505842357152, 1, 0.4804222679813174], 
     Hue[0.31803818591257643`, 1, 0.5596394348902788], 
     Hue[0.6314113814489781, 1, 0.12573808722449184`], 
     Hue[0.6444285208655677, 1, 0.10771435572459868`], 
     Hue[0.6483403043967222, 1, 0.10229804006607698`], 
     Hue[0.6497589618188885, 1, 0.10033374517384673`], 
     Hue[0.6499202363144329, 1, 0.10011044202617], 
     Hue[0.6493814166270158, 1, 0.10085650005490128`], 
     Hue[0.607541900540672, 1, 0.1587881377129157], 
     Hue[0.510533983908946, 1, 0.2931067915106903], 
     Hue[0.6389584142500593, 1, 0.11528834949991792`], 
     Hue[0.6476512819636974, 1, 0.10325207112718823`], 
     Hue[0.6494842522907944, 1, 0.10071411221274629`], 
     Hue[0.6498383027784684, 1, 0.10022388846058228`], 
     Hue[0.6490246129733723, 1, 0.10135053588302294`], 
     Hue[0.6327196532762671, 1, 0.12392663392516859`], 
     Hue[0.5972214239241667, 1, 0.17307802841269226`], 
     Hue[0.6425408848188652, 1, 0.11032800563541752`], 
     Hue[0.6472376528774035, 1, 0.10382478832359508`], 
     Hue[0.6491243397305978, 1, 0.10121245268071082`], 
     Hue[0.6497608890911948, 1, 0.10033107664296116`], 
     Hue[0.6487415025304524, 1, 0.10174253495783517`], 
     Hue[0.6416071963746622, 1, 0.1116208050196985], 
     Hue[0.6333039763671718, 1, 0.12311757118391589`], 
     Hue[0.6442963774518267, 1, 0.10789732352824008`], 
     Hue[0.6457420223619781, 1, 0.10589566134495344`], 
     Hue[0.6471779091179248, 1, 0.10390751045210413`], 
     Hue[0.6488059954277986, 1, 0.10165323709997116`], 
     Hue[0.6497216053983531, 1, 0.1003854694484342], 
     Hue[0.6486614185740522, 1, 0.10185342043592767`], 
     Hue[0.6460978666860392, 1, 0.1054029538193304], 
     Hue[0.6449363081982395, 1, 0.10701126557166839`], 
     Hue[0.6443792387298783, 1, 0.10778259252786082`], 
     Hue[0.6454878932078376, 1, 0.10624753248145567`], 
     Hue[0.6463374972854069, 1, 0.10507115760482126`], 
     Hue[0.6486561461999453, 1, 0.1018607206462296], 
     Hue[0.6497446269774029, 1, 0.10035359341590379`], 
     Hue[0.6487385095926335, 1, 0.10174667902558446`], 
     Hue[0.6469167021582983, 1, 0.10426918162697163`], 
     Hue[0.6465464412567904, 1, 0.1047818505675211], 
     Hue[0.6469074083357891, 1, 0.10428204999659982`], 
     Hue[0.6476302589163752, 1, 0.10328117996194215`], 
     Hue[0.6486943253197311, 1, 0.10180785724960303`], 
     Hue[0.6498180333025885, 1, 0.10025195388872371`], 
     Hue[0.6489651538469169, 1, 0.1014328639042689], 
     Hue[0.6479788895815404, 1, 0.10279846057940568`], 
     Hue[0.6483449140191653, 1, 0.10229165751192505`], 
     Hue[0.6492133707832798, 1, 0.10108917891545874`], 
     Hue[0.6472945453822796, 1, 0.10374601408607449`], 
     Hue[0.6475834488846899, 1, 0.10334599385196792`], 
     Hue[0.647992732536779, 1, 0.10277929341061362`], 
     Hue[0.6488750409140392, 1, 0.1015576356574841], 
     Hue[0.6499074536869546, 1, 0.1001281410488322], 
     Hue[0.6493262593973559, 1, 0.10093287160366118`], 
     Hue[0.649261181264013, 1, 0.10102297978828971`], 
     Hue[0.6486312945647198, 1, 0.10189513060269563`], 
     Hue[0.6485590288669338, 1, 0.10199519079963013`], 
     Hue[0.6481847608283471, 1, 0.1025134080838271], 
     Hue[0.6484785424654151, 1, 0.10210663350942521`], 
     Hue[0.6499685517490378, 1, 0.10004354373210153`], 
     Hue[0.6496859288220751, 1, 0.10043486778481911`], 
     Hue[0.649748705671542, 1, 0.10034794599324967`], 
     Hue[0.6494380510073349, 1, 0.10077808322061324`], 
     Hue[0.6493199214653449, 1, 0.10094164720183023`], 
     Hue[0.6489306887868329, 1, 0.10148058475669298`], 
     Hue[0.6490374185577824, 1, 0.10133280507383975`], 
     Hue[0.6499926102537842, 1, 0.10001023195629886`], 
     Hue[0.6498879983365086, 1, 0.10015507922637275`], 
     Hue[0.6499334733653315, 1, 0.10009211380184874`], 
     Hue[0.6497651749073808, 1, 0.10032514243593432`], 
     Hue[0.6495445652662334, 1, 0.10063060193906152`], 
     Hue[0.649577435244752, 1, 0.10058508966111265`], 
     Hue[0.6499987823857478, 1, 0.1000016859274261], 
     Hue[0.6499871546152928, 1, 0.10001778591728701`], 
     Hue[0.6499450533801044, 1, 0.10007607993524002`], 
     Hue[0.6498702683563081, 1, 0.1001796284297273], 
     Hue[0.6499998525302062, 1, 0.10000020418894534`], 
     Hue[0.6499982837325233, 1, 0.10000237637035238`], 
     Hue[0.6499917724184623, 1, 0.1000113920359754], 
     Hue[0.649995513367399, 1, 0.10000621226052449`], 
     Hue[0.6499768211371815, 1, 0.10003209381005643`], 
     Hue[0.6499709311885555, 1, 0.1000402491235386], 
     Hue[0.6499998652875634, 1, 0.10000018652491231`], 
     Hue[0.6499997033584459, 1, 0.10000041073445946`], 
     Hue[0.6499916431084579, 1, 0.10001157108059679`], 
     Hue[0.6499768885403957, 1, 0.10003200048252905`], 
     Hue[0.6499955545015644, 1, 0.10000615530552621`], 
     Hue[0.6499921940479368, 1, 0.1000108082413183], 
     Hue[0.6499724972674363, 1, 0.10003808070662663`], 
     Hue[0.6498762763822666, 1, 0.10017130962455394`], 
     Hue[0.6498541257365453, 1, 0.1002019797493988], 
     Hue[0.6499986685807253, 1, 0.10000184350361113`], 
     Hue[0.6499973236426885, 1, 0.10000370572550824`], 
     Hue[0.6498868726098938, 1, 0.10015663792476255`], 
     Hue[0.6495774352447521, 1, 0.10058508966111257`], 
     Hue[0.6495306842520321, 1, 0.10064982180487866`], 
     Hue[0.6499903486487819, 1, 0.10001336340937898`], 
     Hue[0.6499821551229769, 1, 0.10002470829126286`], 
     Hue[0.6497647458011402, 1, 0.10032573658303667`], 
     Hue[0.6496752830842288, 1, 0.10044960803722157`], 
     Hue[0.6499471992776279, 1, 0.10007310869251525`], 
     Hue[0.6499098804701536, 1, 0.10012478088747968`], 
     Hue[0.6494383119686717, 1, 0.10077772188953145`], 
     Hue[0.6493256084315968, 1, 0.10093377294086603`], 
     Hue[0.649776996090499, 1, 0.10030877464392456`], 
     Hue[0.6496468100677264, 1, 0.10048903221391733`], 
     Hue[0.6498176582689631, 1, 0.10025247316605115`], 
     Hue[0.6472164168884315, 1, 0.10385419200063341`], 
     Hue[0.6492133707832604, 1, 0.10108917891548565`], 
     Hue[0.6488711177040118, 1, 0.10156306779444524`], 
     Hue[0.6475890729501657, 1, 0.10333820668438606`], 
     Hue[0.6476302589163754, 1, 0.10328117996194189`], 
     Hue[0.6475974574857243, 1, 0.10332659732745868`], 
     Hue[0.646907408335789, 1, 0.10428204999659996`], 
     Hue[0.6466451819682595, 1, 0.10464513265933302`], 
     Hue[0.6465464412567904, 1, 0.10478185056752098`], 
     Hue[0.6456423119377144, 1, 0.10603372193239557`], 
     Hue[0.6469167021582841, 1, 0.10426918162699127`], 
     Hue[0.6454307554303607, 1, 0.10632664632719298`], 
     Hue[0.6465472957244994, 1, 0.10478066745838542`], 
     Hue[0.6473386224356839, 1, 0.10368498431982238`], 
     Hue[0.6473184531260547, 1, 0.10371291105623187`], 
     Hue[0.6463374972854046, 1, 0.10507115760482454`], 
     Hue[0.6460736462773837, 1, 0.10543648976977642`], 
     Hue[0.6444850252643294, 1, 0.10763611886477478`], 
     Hue[0.6449354756217992, 1, 0.10701241836981658`], 
     Hue[0.6444510447211438, 1, 0.10768316884764709`], 
     Hue[0.6443792387296079, 1, 0.1077825925282352], 
     Hue[0.6412672295634202, 1, 0.11209152829680277`], 
     Hue[0.6449363081981927, 1, 0.10701126557173327`], 
     Hue[0.6471779091179208, 1, 0.10390751045210966`], 
     Hue[0.6471877544905376, 1, 0.10389387839771733`], 
     Hue[0.6457420223619642, 1, 0.10589566134497266`], 
     Hue[0.6454881245503387, 1, 0.10624721216106962`], 
     Hue[0.642880143347721, 1, 0.10985826305700162`], 
     Hue[0.6416047567880195, 1, 0.11162418290889603`], 
     Hue[0.6334576495991256, 1, 0.12290479286274922`], 
     Hue[0.6333039763666903, 1, 0.12311757118458268`], 
     Hue[0.6225162151465412, 1, 0.13805447133555832`], 
     Hue[0.6471785610476386, 1, 0.10390660778019273`], 
     Hue[0.6497523354002839, 1, 0.10034292021499154`], 
     Hue[0.6498071763115432, 1, 0.10026698664555568`], 
     Hue[0.6449747057502084, 1, 0.1069580997304807], 
     Hue[0.6397424833007522, 1, 0.11420271542972767`], 
     Hue[0.597215256587844, 1, 0.17308656780144682`], 
     Hue[0.6472745253097338, 1, 0.10377373418652247`], 
     Hue[0.6446604067396445, 1, 0.10739328297587684`], 
     Hue[0.6075239849976855, 1, 0.15881294384935868`], 
     Hue[0.5105208513498842, 1, 0.29312497505400636`], 
     Hue[0.6447422602882784, 1, 0.10727994729315306`], 
     Hue[0.649381416627015, 1, 0.10085650005490243`], 
     Hue[0.649486617144909, 1, 0.10071083779935683`], 
     Hue[0.6444285208655705, 1, 0.10771435572459478`], 
     Hue[0.6446054156460019, 1, 0.10746942449015119`], 
     Hue[0.6211894469842812, 1, 0.13989153494484138`], 
     Hue[0.554742913496705, 1, 0.23189442746610078`], 
     Hue[0.6444293000046293, 1, 0.1077132769166672], 
     Hue[0.6496976408126711, 1, 0.10041865118245545`], 
     Hue[0.6497610653711231, 1, 0.10033083256306041`], 
     Hue[0.6444502281869443, 1, 0.10768429943346178`], 
     Hue[0.6066823642767764, 1, 0.15997826484754044`], 
     Hue[0.47990058829306015`, 1, 0.33552226236345517`], 
     Hue[0.6444500571990789, 1, 0.10768453618589077`], 
     Hue[0.6490063830516137, 1, 0.10137577731315026`], 
     Hue[0.6498799412726698, 1, 0.10016623516091878`], 
     Hue[0.649911933583973, 1, 0.10012193811449889`], 
     Hue[0.6494787147610733, 1, 0.10072177956159074`], 
     Hue[0.6499615936668797, 1, 0.10005317799970509`], 
     Hue[0.6499730201144908, 1, 0.10003735676455126`], 
     Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
     Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
     Hue[0.6499730201144907, 1, 0.10003735676455143`], 
     Hue[0.6495118930856678, 1, 0.10067584034292153`], 
     Hue[0.6494787147610555, 1, 0.1007217795616155], 
     Hue[0.6499119335839733, 1, 0.10012193811449864`], 
     Hue[0.6490601902829449, 1, 0.10130127499284557`], 
     Hue[0.6490063830516063, 1, 0.10137577731316062`], 
     Hue[0.6447269791198692, 1, 0.10730110583402727`], 
     Hue[0.6444500571988938, 1, 0.107684536186147], 
     Hue[0.4218615510037922, 1, 0.4158840063024417], 
     Hue[0.47990058829466353`, 1, 0.33552226236123506`], 
     Hue[0.6066823642771331, 1, 0.15997826484704664`], 
     Hue[0.6448226855248735, 1, 0.10716858927325204`], 
     Hue[0.6497610653711238, 1, 0.10033083256305943`], 
     Hue[0.6446057461857632, 1, 0.1074689668197126], 
     Hue[0.6444293000046112, 1, 0.10771327691669216`], 
     Hue[0.5547429134976742, 1, 0.23189442746475877`], 
     Hue[0.6211894469844135, 1, 0.13989153494465828`], 
     Hue[0.6446054156459394, 1, 0.10746942449023777`], 
     Hue[0.64948661714491, 1, 0.10071083779935554`], 
     Hue[0.6446614119197258, 1, 0.10739189118807202`], 
     Hue[0.45983657272859146`, 1, 0.363303206991181], 
     Hue[0.5105208513514403, 1, 0.2931249750518519], 
     Hue[0.6075239849981006, 1, 0.1588129438487838], 
     Hue[0.6446153322487039, 1, 0.1074556938094869], 
     Hue[0.6473203313841712, 1, 0.10371031039114756`], 
     Hue[0.6472745253097465, 1, 0.10377373418650494`], 
     Hue[0.5682104334567644, 1, 0.21324709213678777`], 
     Hue[0.5972152565884311, 1, 0.17308656780063383`], 
     Hue[0.6397424833007788, 1, 0.11420271542969104`], 
     Hue[0.6449747057502664, 1, 0.10695809973040038`], 
     Hue[0.6498071763115433, 1, 0.10026698664555556`], 
     Hue[0.6471883956275423, 1, 0.10389299066955694`], 
     Hue[0.6471785610476427, 1, 0.1039066077801871], 
     Hue[0.6225162151471285, 1, 0.1380544713347452], 
     Hue[0.6225136803974847, 1, 0.13805798098809824`], 
     Hue[0.63345764959897, 1, 0.12290479286296463`], 
     Hue[0.6416047567879692, 1, 0.11162418290896563`], 
     Hue[0.642880143347735, 1, 0.10985826305698226`], 
     Hue[0.6454881245503643, 1, 0.10624721216103408`], 
     Hue[0.6471877544905419, 1, 0.10389387839771125`], 
     Hue[0.6412672295637786, 1, 0.11209152829630659`], 
     Hue[0.6412672325869215, 1, 0.11209152411041637`], 
     Hue[0.6444510447209121, 1, 0.10768316884796794`], 
     Hue[0.6449354756217571, 1, 0.10701241836987481`], 
     Hue[0.6444850252643324, 1, 0.10763611886477062`], 
     Hue[0.6460736462773896, 1, 0.10543648976976822`], 
     Hue[0.6473131697351501, 1, 0.10372022652056141`], 
     Hue[0.6456433109470772, 1, 0.10603233868866238`], 
     Hue[0.6465472957244996, 1, 0.10478066745838509`], 
     Hue[0.645430755430402, 1, 0.10632664632713582`], 
     Hue[0.6456423119377144, 1, 0.10603372193239552`], 
     Hue[0.6466451819682602, 1, 0.10464513265933213`], 
     Hue[0.6475974574857242, 1, 0.10332659732745889`], 
     Hue[0.6466982385822284, 1, 0.10457166965537615`], 
     Hue[0.6475890729501654, 1, 0.10333820668438629`], 
     Hue[0.6488711177040516, 1, 0.1015630677943901], 
     Hue[0.6472164168884315, 1, 0.10385419200063346`], 
     Hue[0.6497585093987792, 1, 0.1003343716016903], 
     Hue[0.6498176582689631, 1, 0.1002524731660512], 
     Hue[0.6496468100677315, 1, 0.1004890322139102], 
     Hue[0.6492162512642066, 1, 0.10108519055725255`], 
     Hue[0.6493256084315967, 1, 0.1009337729408662], 
     Hue[0.6494383119686719, 1, 0.10077772188953124`], 
     Hue[0.649909880470154, 1, 0.10012478088747913`], 
     Hue[0.649589967952851, 1, 0.10056773668066789`], 
     Hue[0.6496752830842288, 1, 0.1004496080372217], 
     Hue[0.6493843083159341, 1, 0.10085249617793741`], 
     Hue[0.6497647458011401, 1, 0.10032573658303681`], 
     Hue[0.6499821551229769, 1, 0.10002470829126284`], 
     Hue[0.6495306842520321, 1, 0.10064982180487875`], 
     Hue[0.6498432245869254, 1, 0.1002170736488725], 
     Hue[0.6498868726098938, 1, 0.1001566379247626], 
     Hue[0.6499973236426885, 1, 0.10000370572550824`], 
     Hue[0.6498541257365453, 1, 0.10020197974939885`], 
     Hue[0.64995742655059, 1, 0.10005894785302934`], 
     Hue[0.6499724972674363, 1, 0.10003808070662665`], 
     Hue[0.6499921940479368, 1, 0.10001080824131829`], 
     Hue[0.6499710158419191, 1, 0.10004013191118907`], 
     Hue[0.6499768885403957, 1, 0.10003200048252905`], 
     Hue[0.6499916431084579, 1, 0.1000115710805968], 
     Hue[0.6499997033584459, 1, 0.10000041073445946`], 
     Hue[0.6499709311885555, 1, 0.10004024912353861`], 
     Hue[0.6499921293089566, 1, 0.10001089787990629`], 
     Hue[0.649995513367399, 1, 0.10000621226052449`], 
     Hue[0.6499998925666856, 1, 0.1000001487538201], 
     Hue[0.6499996894548788, 1, 0.10000042998555234`], 
     Hue[0.6499745865383855, 1, 0.10003518786992782`], 
     Hue[0.6499382721143278, 1, 0.10008546938016159`], 
     Hue[0.6499800978129978, 1, 0.10002755687431077`], 
     Hue[0.6499964589486245, 1, 0.1000049029942124], 
     Hue[0.64999986712212, 1, 0.10000018398475698`], 
     Hue[0.6499999463041645, 1, 0.10000007434808002`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499993787624871, 1, 0.1000008601750178], 
     Hue[0.6499964290356581, 1, 0.10000494441216566`], 
     Hue[0.6499800210545625, 1, 0.10002766315522107`], 
     Hue[0.6499786432660215, 1, 0.10002957086243185`], 
     Hue[0.6499746602037512, 1, 0.10003508587172913`], 
     Hue[0.6499976810908947, 1, 0.10000321079722264`], 
     Hue[0.6499657096233139, 1, 0.10004747898310386`], 
     Hue[0.6498668777824628, 1, 0.1001843230704362], 
     Hue[0.6497438699910105, 1, 0.10035464155090848`], 
     Hue[0.649870268356308, 1, 0.10017962842972737`], 
     Hue[0.6497422679611429, 1, 0.10035685974610997`], 
     Hue[0.6498908903541091, 1, 0.10015107489431062`], 
     Hue[0.6499949427213864, 1, 0.10000700238577273`], 
     Hue[0.6499763529684163, 1, 0.10003274204373135`], 
     Hue[0.6499461593618887, 1, 0.10007454857584648`], 
     Hue[0.6498906156449327, 1, 0.1001514552608625], 
     Hue[0.6498765165910504, 1, 0.10017097702777646`], 
     Hue[0.6498671323084145, 1, 0.10018397064988767`], 
     Hue[0.6499728188455073, 1, 0.10003763544468222`], 
     Hue[0.6499576702370821, 1, 0.10005861044096338`], 
     Hue[0.6499875385469106, 1, 0.10001725431966231`], 
     Hue[0.6498661528906174, 1, 0.10018532676683745`], 
     Hue[0.6495445652662333, 1, 0.10063060193906169`], 
     Hue[0.6492714988092747, 1, 0.10100869395638892`], 
     Hue[0.6497651749073807, 1, 0.10032514243593448`], 
     Hue[0.6493848462505366, 1, 0.10085175134541081`], 
     Hue[0.6499272404251579, 1, 0.10010074402670449`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.649969296003201, 1, 0.10004251322633723`], 
     Hue[0.6498899253776143, 1, 0.10015241101561109`], 
     Hue[0.6497870627427598, 1, 0.10029483620233265`], 
     Hue[0.6493194313649149, 1, 0.10094232580242553`], 
     Hue[0.6495778694437395, 1, 0.10058448846251461`], 
     Hue[0.6498879983365086, 1, 0.10015507922637279`], 
     Hue[0.6498347039214942, 1, 0.1002288714933158], 
     Hue[0.6499510653458983, 1, 0.10006775567491014`], 
     Hue[0.6496322047027856, 1, 0.1005092550269123], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6498549379809121, 1, 0.10020085510335254`], 
     Hue[0.6496196896792598, 1, 0.10052658352102503`], 
     Hue[0.6492611812640128, 1, 0.10102297978828999`], 
     Hue[0.6486346449067906, 1, 0.10189049166752082`], 
     Hue[0.648932730765027, 1, 0.1014777574022703], 
     Hue[0.6490500614364054, 1, 0.10131529954959252`], 
     Hue[0.6499685517490378, 1, 0.10004354373210153`], 
     Hue[0.6499183291303127, 1, 0.10011308274264409`], 
     Hue[0.6498754872667991, 1, 0.10017240224597054`], 
     Hue[0.6499289484739935, 1, 0.10009837903600899`], 
     Hue[0.6499289484739935, 1, 0.10009837903600899`], 
     Hue[0.6494782446417726, 1, 0.10072243049600713`], 
     Hue[0.6485606730077387, 1, 0.10199291429697721`], 
     Hue[0.6481850644702218, 1, 0.10251298765661597`], 
     Hue[0.6484548050697109, 1, 0.10213950067270804`], 
     Hue[0.6493262593973559, 1, 0.10093287160366117`], 
     Hue[0.6492168120882642, 1, 0.10108441403163429`], 
     Hue[0.6489651538469169, 1, 0.1014328639042689], 
     Hue[0.648885852981722, 1, 0.10154266510223119`], 
     Hue[0.6498180333025885, 1, 0.10025195388872368`], 
     Hue[0.6497587426645933, 1, 0.10033404861825539`], 
     Hue[0.6497844884994876, 1, 0.10029840053917118`], 
     Hue[0.6492143200935674, 1, 0.10108786448582988`], 
     Hue[0.6479045331466708, 1, 0.10290141564307125`], 
     Hue[0.6496234965987956, 1, 0.10052131240166762`], 
     Hue[0.6496234965987956, 1, 0.10052131240166765`], 
     Hue[0.6490857182415352, 1, 0.10126592858864364`], 
     Hue[0.6479034511561871, 1, 0.10290291378374103`], 
     Hue[0.6468888344261866, 1, 0.10430776771758775`], 
     Hue[0.6483449140191628, 1, 0.10229165751192838`], 
     Hue[0.6473051809263888, 1, 0.10373128794807714`], 
     Hue[0.6471452171056802, 1, 0.10395277631521214`], 
     Hue[0.6475004150899578, 1, 0.10346096372159684`], 
     Hue[0.6487385095926334, 1, 0.1017466790255846], 
     Hue[0.6486985272829319, 1, 0.10180203914670977`], 
     Hue[0.6497446269774029, 1, 0.10035359341590382`], 
     Hue[0.6497220805506987, 1, 0.10038481154518647`], 
     Hue[0.6462369452811768, 1, 0.1052103834568321], 
     Hue[0.6469079421015003, 1, 0.10428131093638432`], 
     Hue[0.6476306747916084, 1, 0.10328060413469611`], 
     Hue[0.6473382110820148, 1, 0.10368555388644096`], 
     Hue[0.648661418574052, 1, 0.10185342043592796`], 
     Hue[0.6486592242610936, 1, 0.10185645871540887`], 
     Hue[0.6497216634938592, 1, 0.10038538900850272`], 
     Hue[0.6497525816504375, 1, 0.10034257925324044`], 
     Hue[0.6450042018600481, 1, 0.10691725896301033`], 
     Hue[0.6443899338329367, 1, 0.10776778392362601`], 
     Hue[0.6439216662083573, 1, 0.10841615448073602`], 
     Hue[0.6432968085982096, 1, 0.10928134194094055`], 
     Hue[0.6439229159369845, 1, 0.10841442408725224`], 
     Hue[0.6453175862656672, 1, 0.10648334209369166`], 
     Hue[0.6436612706901965, 1, 0.10877670212126647`], 
     Hue[0.6427084326690093, 1, 0.11009601630444861`], 
     Hue[0.6392482971262531, 1, 0.11488697320980351`], 
     Hue[0.6294670107067267, 1, 0.12843029286760918`], 
     Hue[0.6416071963745711, 1, 0.11162080501982463`], 
     Hue[0.645742913475472, 1, 0.10589442749550039`], 
     Hue[0.6451848600758338, 1, 0.10666711681807645`], 
     Hue[0.6497760637592552, 1, 0.10031006556410821`], 
     Hue[0.6498175387315116, 1, 0.10025263867944553`], 
     Hue[0.6448171573226332, 1, 0.10717624370712325`], 
     Hue[0.6413492538797264, 1, 0.11197795616653275`], 
     Hue[0.6393231015822374, 1, 0.11478339780920989`], 
     Hue[0.6255259248970585, 1, 0.13388718091176524`], 
     Hue[0.5591705448255907, 1, 0.22576386101072066`], 
     Hue[0.5591705448255893, 1, 0.22576386101072254`], 
     Hue[0.5972214239234073, 1, 0.1730780284137438], 
     Hue[0.5682182330617682, 1, 0.21323629268370556`], 
     Hue[0.6327196532761413, 1, 0.12392663392534278`], 
     Hue[0.6138281474123832, 1, 0.15008410358285407`], 
     Hue[0.6476889012124133, 1, 0.10319998293665852`], 
     Hue[0.6490246129733719, 1, 0.10135053588302363`], 
     Hue[0.649124059969674, 1, 0.10121284004198979`], 
     Hue[0.6498625824888393, 1, 0.10019027040006866`], 
     Hue[0.6499045423782822, 1, 0.10013217209160925`], 
     Hue[0.6445346715614864, 1, 0.10756737783794197`], 
     Hue[0.6363229297017776, 1, 0.11893748195138483`], 
     Hue[0.6320807432699075, 1, 0.12481127854935892`], 
     Hue[0.5900825238500126, 1, 0.18296265928459798`], 
     Hue[0.42804171263097834`, 1, 0.40732685943403], 
     Hue[0.428041712630976, 1, 0.40732685943403324`], 
     Hue[0.5105339839078467, 1, 0.2931067915122123], 
     Hue[0.4598523370119753, 1, 0.36328137952188033`], 
     Hue[0.6386880733811459, 1, 0.11566266762610583`], 
     Hue[0.6494358636771674, 1, 0.10078111183161441`], 
     Hue[0.6495955370911396, 1, 0.10056002556611444`], 
     Hue[0.649938736749848, 1, 0.10008482603867205`], 
     Hue[0.6499635376940699, 1, 0.10005048626974945`], 
     Hue[0.6445187656804581, 1, 0.10758940136551957`], 
     Hue[0.6264945721377744, 1, 0.13254597704000476`], 
     Hue[0.6197500814766024, 1, 0.14188450257085822`], 
     Hue[0.5262450270724327, 1, 0.2713530394381701], 
     Hue[0.2607299568423358, 1, 0.6389892905259966], 
     Hue[0.2607299568423336, 1, 0.6389892905259997], 
     Hue[0.3752505842350581, 1, 0.4804222679822273], 
     Hue[0.31924359861609497`, 1, 0.5579704019161762], 
     Hue[0.554770362006304, 1, 0.23185642183742522`], 
     Hue[0.4950793034126642, 1, 0.31450557989015726`], 
     Hue[0.4799251869017592, 1, 0.33548820275141034`], 
     Hue[0.42187632618428994`, 1, 0.415863548360214], 
     Hue[0.6483395074792696, 1, 0.10229914349024219`], 
     Hue[0.6483775520143685, 1, 0.10224646644164366`], 
     Hue[0.6497259877549584, 1, 0.10037940157005763`], 
     Hue[0.6498247725796027, 1, 0.10024262258208867`], 
     Hue[0.6499797919710948, 1, 0.10002798034771491`], 
     Hue[0.6499895375823748, 1, 0.10001448642440419`], 
     Hue[0.6490074389437328, 1, 0.10137431530867769`], 
     Hue[0.6490612179653512, 1, 0.10129985204797536`], 
     Hue[0.6123745783732009, 1, 0.15209673763710646`], 
     Hue[0.23864305325650226`, 1, 0.6695711570294584], 
     Hue[0.14468550878839948`, 1, 0.7996662186006775], 
     Hue[0.12170305563956119`, 1, 0.8314880768067614], 
     Hue[0.12170305563955952`, 1, 0.8314880768067637], 
     Hue[0.238676642843565, 1, 0.6695246483704484], 
     Hue[0.19694005227972833`, 1, 0.72731377376653], 
     Hue[0.14472156419557214`, 1, 0.7996162957292078], 
     Hue[0.12320664814156568`, 1, 0.8294061794962936], 
     Hue[0.40926481920002356`, 1, 0.4333256349538136], 
     Hue[0.374774116754797, 1, 0.4810819921856657], 
     Hue[0.6039357705145427, 1, 0.16378124082601786`], 
     Hue[0.6446378483467694, 1, 0.10742451767370392`], 
     Hue[0.6490365748044977, 1, 0.10133397334761854`], 
     Hue[0.6498942532833836, 1, 0.10014641853069964`], 
     Hue[0.6499395617051158, 1, 0.1000836837929167], 
     Hue[0.6499952798767935, 1, 0.100006535555209], 
     Hue[0.6499979498338926, 1, 0.10000283869153345`], 
     Hue[0.6499617603399275, 1, 0.10005294722163892`], 
     Hue[0.6499852500802348, 1, 0.10002042296582875`], 
     Hue[0.6494794345021933, 1, 0.10072078299696322`], 
     Hue[0.6495125444945455, 1, 0.10067493839216769`], 
     Hue[0.6496523580230951, 1, 0.10048135042956073`], 
     Hue[0.649652317451856, 1, 0.10048140660512248`], 
     Hue[0.13133504687157593`, 1, 0.8181514735624333], 
     Hue[0.10550699045289536`, 1, 0.8539133978344525], 
     Hue[0.033059327874931266`, 1, 0.954225546019326], 
     Hue[0.03305932787493049, 1, 0.9542255460193271], 
     Hue[0.008564162898874517, 1, 0.9881419282938662], 
     Hue[0.1313694777268779, 1, 0.8181038000704768], 
     Hue[0.1055155371471872, 1, 0.8539015639500485], 
     Hue[0.10550699045002132`, 1, 0.8539133978384321], 
     Hue[0.36993896493670303`, 1, 0.48777681777994963`], 
     Hue[0.36993665875161313`, 1, 0.4877800109593049], 
     Hue[0.5947858976879443, 1, 0.17645029550900027`], 
     Hue[0.6494921178875066, 1, 0.1007032213865294], 
     Hue[0.6496523174518573, 1, 0.10048140660512081`], 
     Hue[0.6499852320800056, 1, 0.10002044788922304`], 
     Hue[0.6499852500802348, 1, 0.1000204229658288], 
     Hue[0.6499990931632785, 1, 0.10000125562007593`], 
     Hue[0.6496149480433893, 1, 0.10053314886299958`], 
     Hue[0.5947857583623528, 1, 0.1764504884213577], 
     Hue[0.5947858976870672, 1, 0.17645029551021466`], 
     Hue[0.5959049495698923, 1, 0.17490083905707227`], 
     Hue[0.6039357705136676, 1, 0.1637812408272295], 
     Hue[0.36993665874980525`, 1, 0.48778001096180823`], 
     Hue[0.37477411675310107`, 1, 0.48108199218801395`], 
     Hue[0.12320664814257443`, 1, 0.8294061794948969], 
     Hue[0.03305932787187027, 1, 0.9542255460235642], 
     Hue[0.03305932787187105, 1, 0.9542255460235631], 
     Hue[0.12317793669320076`, 1, 0.8294459338094142], 
     Hue[0.14468550878547748`, 1, 0.7996662186047235], 
     Hue[0.6495125444945283, 1, 0.10067493839219155`], 
     Hue[0.6499731374090267, 1, 0.10003719435673222`], 
     Hue[0.6499560132855162, 1, 0.10006090468159291`], 
     Hue[0.6499979498338926, 1, 0.10000283869153345`], 
     Hue[0.6499990931632785, 1, 0.10000125562007593`], 
     Hue[0.6494921178874883, 1, 0.10070322138655469`], 
     Hue[0.6492984661033572, 1, 0.10097135462612092`], 
     Hue[0.6446378483465085, 1, 0.10742451767406523`], 
     Hue[0.6446747005057164, 1, 0.10737349160746958`], 
     Hue[0.606685793838532, 1, 0.1599735162235711], 
     Hue[0.42187632618276033`, 1, 0.41586354836233186`], 
     Hue[0.13136947772739593`, 1, 0.8181038000697596], 
     Hue[0.19694005227927935`, 1, 0.7273137737671517], 
     Hue[0.13133504686846842`, 1, 0.818151473566736], 
     Hue[0.1969013977278607, 1, 0.7273672954537314], 
     Hue[0.23864305325552504`, 1, 0.6695711570308115], 
     Hue[0.6494928049778319, 1, 0.10070227003069428`], 
     Hue[0.6499667588310656, 1, 0.10004602623390928`], 
     Hue[0.6499952798767935, 1, 0.100006535555209], 
     Hue[0.6498942532833839, 1, 0.10014641853069926`], 
     Hue[0.6490365748044896, 1, 0.10133397334762985`], 
     Hue[0.6445188584205228, 1, 0.10758927295619916`], 
     Hue[0.621196668559048, 1, 0.13988153584131827`], 
     Hue[0.495079303411862, 1, 0.31450557989126804`], 
     Hue[0.2153784744288908, 1, 0.7017836507907667], 
     Hue[0.12170305563612915`, 1, 0.8314880768115135], 
     Hue[0.12170305563613082`, 1, 0.8314880768115112], 
     Hue[0.21534157718856928`, 1, 0.7018347392773656], 
     Hue[0.48756298968034184`, 1, 0.32491278351952674`], 
     Hue[0.6123745783734575, 1, 0.15209673763675113`], 
     Hue[0.6490612179653427, 1, 0.10129985204798718`], 
     Hue[0.6499797919710948, 1, 0.1000279803477149], 
     Hue[0.6497259877549593, 1, 0.10037940157005647`], 
     Hue[0.6484128933058365, 1, 0.10219753234576491`], 
     Hue[0.6483395074792844, 1, 0.10229914349022172`], 
     Hue[0.6445356096358542, 1, 0.10756607896574029`], 
     Hue[0.6330024607853297, 1, 0.12353505429723577`], 
     Hue[0.6386880733811164, 1, 0.11566266762614656`], 
     Hue[0.3192435986162432, 1, 0.557970401915971], 
     Hue[0.26072995684176903`, 1, 0.6389892905267813], 
     Hue[0.26072995684177125`, 1, 0.6389892905267783], 
     Hue[0.5262450270736311, 1, 0.27135303943651085`], 
     Hue[0.5613439013174828, 1, 0.22275459817579313`], 
     Hue[0.6264945721378616, 1, 0.1325459770398839], 
     Hue[0.6499875780500365, 1, 0.1000171996230264], 
     Hue[0.649938736749848, 1, 0.10008482603867203`], 
     Hue[0.6477602551397624, 1, 0.10310118519109816`], 
     Hue[0.6476889012124346, 1, 0.10319998293662903`], 
     Hue[0.6474700106798329, 1, 0.1035030621356161], 
     Hue[0.6449758474344257, 1, 0.10695651893694909`], 
     Hue[0.4598523370130185, 1, 0.36328137952043593`], 
     Hue[0.4280417126324515, 1, 0.4073268594319903], 
     Hue[0.4280417126324537, 1, 0.4073268594319872], 
     Hue[0.54385421509572, 1, 0.24697108679054167`], 
     Hue[0.5900825238506199, 1, 0.18296265928375707`], 
     Hue[0.6113184040198553, 1, 0.153559132895585], 
     Hue[0.6363229297018138, 1, 0.11893748195133472`], 
     Hue[0.649904864696231, 1, 0.10013172580521863`], 
     Hue[0.6498625824888394, 1, 0.10019027040006856`], 
     Hue[0.6491240599696747, 1, 0.10121284004198884`], 
     Hue[0.6471976417124166, 1, 0.10388018839819256`], 
     Hue[0.6454891179707115, 1, 0.10624583665593802`], 
     Hue[0.645742913475486, 1, 0.10589442749548107`], 
     Hue[0.5682182330626965, 1, 0.21323629268242025`], 
     Hue[0.5591705448266979, 1, 0.22576386100918752`], 
     Hue[0.5591705448266993, 1, 0.22576386100918563`], 
     Hue[0.6131150084109671, 1, 0.1510715268155841], 
     Hue[0.6255259248972418, 1, 0.13388718091151136`], 
     Hue[0.641349253879749, 1, 0.1119779561665015], 
     Hue[0.6498075235338531, 1, 0.10026650587620355`], 
     Hue[0.6497525816504376, 1, 0.10034257925324029`], 
     Hue[0.6473189778091604, 1, 0.10371218457193178`], 
     Hue[0.6473382110820156, 1, 0.10368555388643992`], 
     Hue[0.6428823803202547, 1, 0.10985516571041662`], 
     Hue[0.6442709715647634, 1, 0.10793250091032752`], 
     Hue[0.639252008962006, 1, 0.11488183374491492`], 
     Hue[0.638478408111949, 1, 0.11595297338345519`], 
     Hue[0.6392482971262289, 1, 0.11488697320983701`], 
     Hue[0.6421307435744987, 1, 0.11089589351223259`], 
     Hue[0.6436612706902044, 1, 0.10877670212125548`], 
     Hue[0.6497395116100093, 1, 0.10036067623229489`], 
     Hue[0.6497216634938593, 1, 0.10038538900850259`], 
     Hue[0.6486592242610939, 1, 0.10185645871540853`], 
     Hue[0.648698527282932, 1, 0.10180203914670959`], 
     Hue[0.6475978994814844, 1, 0.10332598533332933`], 
     Hue[0.6476306747916085, 1, 0.10328060413469593`], 
     Hue[0.6444863018191734, 1, 0.10763435132729843`], 
     Hue[0.6439229159370509, 1, 0.10841442408716043`], 
     Hue[0.643921666208303, 1, 0.10841615448081116`], 
     Hue[0.6450042018600488, 1, 0.10691725896300938`], 
     Hue[0.6497220805506988, 1, 0.10038481154518636`], 
     Hue[0.6497587426645933, 1, 0.10033404861825539`], 
     Hue[0.648885852981722, 1, 0.10154266510223114`], 
     Hue[0.646645752668982, 1, 0.10464434245833251`], 
     Hue[0.6469079421015004, 1, 0.10428131093638407`], 
     Hue[0.6460988378741064, 1, 0.10540160909739126`], 
     Hue[0.6468888344263425, 1, 0.10430776771737202`], 
     Hue[0.6468897902011312, 1, 0.1043064443368952], 
     Hue[0.6479045331465779, 1, 0.10290141564319985`], 
     Hue[0.6488721916035767, 1, 0.10156158085658615`], 
     Hue[0.6492143200935481, 1, 0.10108786448585658`], 
     Hue[0.6492168120882642, 1, 0.10108441403163429`], 
     Hue[0.6472169204860098, 1, 0.10385349471167882`], 
     Hue[0.6475004150899578, 1, 0.10346096372159691`], 
     Hue[0.64714521710568, 1, 0.10395277631521234`], 
     Hue[0.6473051809264003, 1, 0.10373128794806115`], 
     Hue[0.6490857182415612, 1, 0.1012659285886076], 
     Hue[0.6496234965987958, 1, 0.10052131240166731`], 
     Hue[0.6496234965987958, 1, 0.1005213124016673], 
     Hue[0.6497844884994874, 1, 0.10029840053917122`], 
     Hue[0.6498285638060287, 1, 0.10023737319165266`], 
     Hue[0.6483894496489137, 1, 0.10222999279381195`], 
     Hue[0.648454805069711, 1, 0.1021395006727079], 
     Hue[0.6478481526586201, 1, 0.10297948093421838`], 
     Hue[0.6481850644702217, 1, 0.10251298765661612`], 
     Hue[0.6477258602117323, 1, 0.10314880893760156`], 
     Hue[0.6485606730077386, 1, 0.10199291429697746`], 
     Hue[0.6486346449067923, 1, 0.10189049166751832`], 
     Hue[0.6499289484739935, 1, 0.10009837903600897`], 
     Hue[0.6499289484739935, 1, 0.10009837903600897`], 
     Hue[0.6494608701931662, 1, 0.10074648742484672`], 
     Hue[0.649875487266799, 1, 0.10017240224597058`], 
     Hue[0.6499179695206531, 1, 0.10011358066371125`], 
     Hue[0.6489814055841803, 1, 0.10141036149882729`], 
     Hue[0.6490500614364055, 1, 0.1013152995495924], 
     Hue[0.6485711159572849, 1, 0.10197845482837475`], 
     Hue[0.6489327307650269, 1, 0.1014777574022705], 
     Hue[0.6486670765987006, 1, 0.10184558624795306`], 
     Hue[0.6493194313649148, 1, 0.10094232580242575`], 
     Hue[0.6493571286681644, 1, 0.10089012953638776`], 
     Hue[0.6496196896792598, 1, 0.10052658352102502`], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6496322047027855, 1, 0.10050925502691244`], 
     Hue[0.6497686522347683, 1, 0.10032032767493618`], 
     Hue[0.6499510653458982, 1, 0.10006775567491016`], 
     Hue[0.6499735114284139, 1, 0.10003667648373475`], 
     Hue[0.6498347039214942, 1, 0.10022887149331573`], 
     Hue[0.6495311358384767, 1, 0.1006491965313401], 
     Hue[0.6495778694437395, 1, 0.10058448846251451`], 
     Hue[0.6497827013349246, 1, 0.10030087507471992`], 
     Hue[0.6498899253776143, 1, 0.10015241101561112`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6498201909540229, 1, 0.100248966371353], 
     Hue[0.6499272404251579, 1, 0.10010074402670446`], 
     Hue[0.6493848462505368, 1, 0.10085175134541056`], 
     Hue[0.6492714988092748, 1, 0.1010086939563887], 
     Hue[0.6498661528906173, 1, 0.10018532676683752`], 
     Hue[0.6499298416416035, 1, 0.10009714234239514`], 
     Hue[0.6499875385469106, 1, 0.10001725431966232`], 
     Hue[0.6499576702370821, 1, 0.10005861044096336`], 
     Hue[0.6499659179555519, 1, 0.100047190523082], 
     Hue[0.6498543989283845, 1, 0.1002016014837754], 
     Hue[0.6498765165910504, 1, 0.10017097702777641`], 
     Hue[0.6498906156449326, 1, 0.1001514552608626], 
     Hue[0.6499763529684163, 1, 0.10003274204373136`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6497422679611429, 1, 0.10035685974610986`], 
     Hue[0.6498668777824628, 1, 0.10018432307043623`], 
     Hue[0.6499657096233139, 1, 0.10004747898310389`], 
     Hue[0.6499852101793618, 1, 0.10002047821319135`], 
     Hue[0.6499976810908947, 1, 0.10000321079722264`], 
     Hue[0.6499991804292786, 1, 0.10000113479022964`], 
     Hue[0.6499746602037513, 1, 0.10003508587172912`], 
     Hue[0.6499800210545625, 1, 0.1000276631552211], 
     Hue[0.6499964290356581, 1, 0.10000494441216566`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499997070467911, 1, 0.10000040562752005`], 
     Hue[0.64999986712212, 1, 0.10000018398475698`], 
     Hue[0.6499999463041645, 1, 0.10000007434808002`], 
     Hue[0.6499964589486245, 1, 0.1000049029942124], 
     Hue[0.6499800978129978, 1, 0.10002755687431074`], 
     Hue[0.6499452847292683, 1, 0.10007575960562862`], 
     Hue[0.6499745865383855, 1, 0.10003518786992784`], 
     Hue[0.6499996894548788, 1, 0.10000042998555234`], 
     Hue[0.6499998925666856, 1, 0.1000001487538201], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499872761827475, 1, 0.1000176175931189], 
     Hue[0.6499764872407213, 1, 0.10003255612823204`], 
     Hue[0.6499659179555519, 1, 0.10004719052308203`], 
     Hue[0.6496095597971275, 1, 0.10054060951166954`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6495581589251695, 1, 0.10061177994976521`], 
     Hue[0.6498666614359694, 1, 0.10018462262711933`], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.649363405912811, 1, 0.10088143796687704`], 
     Hue[0.6487551382058032, 1, 0.10172365479196484`], 
     Hue[0.6490171435581192, 1, 0.1013608781502964], 
     Hue[0.6499289484739935, 1, 0.10009837903600899`], 
     Hue[0.648157278257873, 1, 0.10255146087371447`], 
     Hue[0.6480091049759613, 1, 0.10275662387943817`], 
     Hue[0.6490820712669709, 1, 0.10127097824573264`], 
     Hue[0.6498289592233316, 1, 0.10023682569077165`], 
     Hue[0.6496234965987956, 1, 0.10052131240166763`], 
     Hue[0.6484645052704197, 1, 0.10212606962557286`], 
     Hue[0.6473537923316893, 1, 0.10366397984843018`], 
     Hue[0.6487973060787215, 1, 0.10166526850638559`], 
     Hue[0.6497500661969323, 1, 0.10034606218886298`], 
     Hue[0.6460988378741057, 1, 0.10540160909739217`], 
     Hue[0.6486665440965278, 1, 0.10184632355865385`], 
     Hue[0.6450053143732752, 1, 0.10691571856008053`], 
     Hue[0.6392520089618975, 1, 0.11488183374506498`], 
     Hue[0.5856239954315853, 1, 0.18913600632549732`], 
     Hue[0.6255368322474695, 1, 0.13387207842658083`], 
     Hue[0.48730850453537505`, 1, 0.3252651475664038], 
     Hue[0.26072995684233463`, 1, 0.6389892905259982], 
     Hue[0.346411220142523, 1, 0.5203536951872758], 
     Hue[0.4875889857309319, 1, 0.3248767889879404], 
     Hue[0.2153415771900969, 1, 0.7018347392752505], 
     Hue[0.1217030556395603, 1, 0.8314880768067627], 
     Hue[0.21537847442945068`, 1, 0.7017836507899914], 
     Hue[0.16664015272578908`, 1, 0.7692674808412151], 
     Hue[0.41486309731408044`, 1, 0.42557417294973476`], 
     Hue[0.6499667588310657, 1, 0.10004602623390908`], 
     Hue[0.6494928049778499, 1, 0.10070227003066942`], 
     Hue[0.649615310956585, 1, 0.10053264636780553`], 
     Hue[0.03305932787493093, 1, 0.9542255460193264], 
     Hue[0.10995731692864064`, 1, 0.8477514073295744], 
     Hue[0.37117736989835204`, 1, 0.4860621032176664], 
     Hue[0.6499817210220852, 1, 0.10002530935403599`], 
     Hue[0.5950760330681312, 1, 0.17604856959797222`], 
     Hue[0.008564162897190308, 1, 0.9881419282961981], 
     Hue[0.10993697241469957`, 1, 0.8477795766565698], 
     Hue[0.6499817845643628, 1, 0.10002522137242076`], 
     Hue[0.605186076820044, 1, 0.16205004747993917`], 
     Hue[0.1666007064873134, 1, 0.7693220987098738], 
     Hue[0.619757163057583, 1, 0.14187469730488508`], 
     Hue[0.12170305563612982`, 1, 0.8314880768115125], 
     Hue[0.648377552014383, 1, 0.10224646644162362`], 
     Hue[0.6320881314564141, 1, 0.12480104875265746`], 
     Hue[0.3464112201429481, 1, 0.5203536951866873], 
     Hue[0.2607299568417701, 1, 0.6389892905267799], 
     Hue[0.6499637194211009, 1, 0.10005023464770654`], 
     Hue[0.6494358636771683, 1, 0.10078111183161315`], 
     Hue[0.6448183521045393, 1, 0.10717458939371491`], 
     Hue[0.4873085045365092, 1, 0.3252651475648335], 
     Hue[0.4280417126324527, 1, 0.40732685943198865`], 
     Hue[0.6453186380742266, 1, 0.10648188574337857`], 
     Hue[0.6255368322476118, 1, 0.13387207842638366`], 
     Hue[0.585623995432426, 1, 0.1891360063243331], 
     Hue[0.5591705448266987, 1, 0.22576386100918638`], 
     Hue[0.6498178986902057, 1, 0.10025214027509986`], 
     Hue[0.6497760637592553, 1, 0.10031006556410807`], 
     Hue[0.6472266389834023, 1, 0.10384003833067385`], 
     Hue[0.6294670107072551, 1, 0.12843029286687765`], 
     Hue[0.6497444578897739, 1, 0.1003538275372362], 
     Hue[0.6474600972735775, 1, 0.10351678839043128`], 
     Hue[0.6450053143732791, 1, 0.10691571856007508`], 
     Hue[0.643296808598523, 1, 0.1092813419405066], 
     Hue[0.646236945281202, 1, 0.10521038345679727`], 
     Hue[0.6484656021364826, 1, 0.1021245508879472], 
     Hue[0.6473537923316893, 1, 0.10366397984843025`], 
     Hue[0.6496234965987958, 1, 0.10052131240166731`], 
     Hue[0.6480091049759613, 1, 0.10275662387943829`], 
     Hue[0.6481572782578727, 1, 0.10255146087371475`], 
     Hue[0.6499289484739935, 1, 0.10009837903600897`], 
     Hue[0.6490171435581193, 1, 0.10136087815029629`], 
     Hue[0.6487551382058031, 1, 0.10172365479196505`], 
     Hue[0.6499892775816672, 1, 0.10001484642538379`], 
     Hue[0.6498666614359694, 1, 0.10018462262711927`], 
     Hue[0.6495581589251697, 1, 0.10061177994976513`], 
     Hue[0.6496095597971278, 1, 0.10054060951166935`], 
     Hue[0.6498671323084145, 1, 0.10018397064988764`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499764872407213, 1, 0.10003255612823203`], 
     Hue[0.6498908903541091, 1, 0.10015107489431052`], 
     Hue[0.6499655367985427, 1, 0.10004771827894093`], 
     Hue[0.6499997961154858, 1, 0.10000028230163507`], 
     Hue[0.649965516562715, 1, 0.10004774629777935`], 
     Hue[0.6495577101050631, 1, 0.10061240139298958`], 
     Hue[0.6496090377308191, 1, 0.10054133237271205`], 
     Hue[0.6490867430856696, 1, 0.1012645095736882], 
     Hue[0.6474954669798254, 1, 0.10346781495101104`], 
     Hue[0.6474944451680356, 1, 0.10346922976733547`], 
     Hue[0.6294650459019114, 1, 0.12843301336658416`], 
     Hue[0.6492993957289686, 1, 0.10097006745219737`], 
     Hue[0.6294650459018397, 1, 0.1284330133666835], 
     Hue[0.6474944451681558, 1, 0.10346922976716888`], 
     Hue[0.6474954669797106, 1, 0.10346781495117001`], 
     Hue[0.6490867430856438, 1, 0.10126450957372388`], 
     Hue[0.6496090377308189, 1, 0.10054133237271225`], 
     Hue[0.649557710105063, 1, 0.10061240139298966`], 
     Hue[0.649965516562715, 1, 0.10004774629777938`], 
     Hue[0.6499997961154859, 1, 0.10000028230163507`], 
     Hue[0.6499655367985427, 1, 0.1000477182789409], 
     Hue[0.649999546284906, 1, 0.10000062822089953`], 
     Hue[0.6499921293089566, 1, 0.10001089787990629`], 
     Hue[0.6499882868309909, 1, 0.10001621823401269`], 
     Hue[0.6499773681890932, 1, 0.10003133635356326`], 
     Hue[0.6499968016948423, 1, 0.10000442842252606`], 
     Hue[0.64995742655059, 1, 0.10005894785302931`], 
     Hue[0.649941550412067, 1, 0.10008093019867641`], 
     Hue[0.6498799739553269, 1, 0.10016618990800887`], 
     Hue[0.6499837977879257, 1, 0.10002243383210294`], 
     Hue[0.6498432245869254, 1, 0.10021707364887242`], 
     Hue[0.6497995501416562, 1, 0.10027754595770676`], 
     Hue[0.6499427464970976, 1, 0.10007927408094187`], 
     Hue[0.6495899679528511, 1, 0.10056773668066774`], 
     Hue[0.649510432152012, 1, 0.10067786317413728`], 
     Hue[0.6498634854226076, 1, 0.10018902018408178`], 
     Hue[0.6435492187576689, 1, 0.10893185095091998`], 
     Hue[0.6383247155518019, 1, 0.11616577846673584`], 
     Hue[0.6228816248504461, 1, 0.13754851943784388`], 
     Hue[0.5843916311222078, 1, 0.19084235690771226`], 
     Hue[0.5180120543224636, 1, 0.2827525401688967], 
     Hue[0.6499987777339871, 1, 0.10000169236832561`], 
     Hue[0.6499615936668796, 1, 0.1000531779997052], 
     Hue[0.6499507438872519, 1, 0.10006820077149743`], 
     Hue[0.649993865184265, 1, 0.10000849436024842`], 
     Hue[0.6498799412726701, 1, 0.10016623516091828`], 
     Hue[0.6498506186895232, 1, 0.10020683566066013`], 
     Hue[0.6139219345410796, 1, 0.14995424448158212`], 
     Hue[0.6499762536549267, 1, 0.10003287955471694`], 
     Hue[0.6496976408126719, 1, 0.1004186511824543], 
     Hue[0.6496397195744826, 1, 0.10049884981994713`], 
     Hue[0.6276537703969356, 1, 0.13094093329655082`], 
     Hue[0.6499307068090907, 1, 0.10009594441818212`], 
     Hue[0.6369354292276367, 1, 0.11808940568481076`], 
     Hue[0.6498518987975389, 1, 0.10020506320340777`], 
     Hue[0.6416037038677828, 1, 0.1116256407984547], 
     Hue[0.6437749675546233, 1, 0.10861927569359858`], 
     Hue[0.6479034511562832, 1, 0.10290291378360782`], 
     Hue[0.6481488635226913, 1, 0.10256311204550442`], 
     Hue[0.649776996090501, 1, 0.10030877464392167`], 
     Hue[0.6498161665378698, 1, 0.10025453863987266`], 
     Hue[0.6496713073131245, 1, 0.1004551129510585], 
     Hue[0.649947199277628, 1, 0.10007310869251507`], 
     Hue[0.6499585389917858, 1, 0.10005740754983512`], 
     Hue[0.6499080428696403, 1, 0.1001273252574212], 
     Hue[0.6499903486487819, 1, 0.10001336340937897`], 
     Hue[0.6499928350255395, 1, 0.10000992073386847`], 
     Hue[0.6499810990463154, 1, 0.10002617055125557`], 
     Hue[0.6499986685807253, 1, 0.10000184350361113`], 
     Hue[0.6499990728488086, 1, 0.10000128374780339`], 
     Hue[0.6498762763822666, 1, 0.10017130962455396`], 
     Hue[0.6499312334274999, 1, 0.10009521525423096`], 
     Hue[0.6499998652875634, 1, 0.10000018652491231`], 
     Hue[0.6499999130990606, 1, 0.10000012032437766`], 
     Hue[0.6499786571222672, 1, 0.10002955167686084`], 
     Hue[0.6499786571222672, 1, 0.10002955167686084`], 
     Hue[0.6499546249480828, 1, 0.10006282699496238`], 
     Hue[0.6499774540762749, 1, 0.10003121743285015`], 
     Hue[0.6499999130990606, 1, 0.10000012032437766`], 
     Hue[0.6499312334274999, 1, 0.10009521525423093`], 
     Hue[0.6499990728488086, 1, 0.10000128374780339`], 
     Hue[0.6499871546152928, 1, 0.100017785917287], 
     Hue[0.6499810990463154, 1, 0.10002617055125557`], 
     Hue[0.6499928350255395, 1, 0.10000992073386847`], 
     Hue[0.6499334733653315, 1, 0.10009211380184871`], 
     Hue[0.6499080428696403, 1, 0.10012732525742117`], 
     Hue[0.6499585389917857, 1, 0.10005740754983526`], 
     Hue[0.649748705671542, 1, 0.10034794599324966`], 
     Hue[0.6496713073131244, 1, 0.10045511295105851`], 
     Hue[0.6498161665378682, 1, 0.1002545386398748], 
     Hue[0.644296377451823, 1, 0.1078973235282451], 
     Hue[0.6437749675546159, 1, 0.10861927569360877`], 
     Hue[0.6355280494073325, 1, 0.12003808543600118`], 
     Hue[0.6425408848188494, 1, 0.11032800563543929`], 
     Hue[0.6416037038677618, 1, 0.11162564079848367`], 
     Hue[0.6498383027784683, 1, 0.10022388846058237`], 
     Hue[0.6498518987975388, 1, 0.10020506320340787`], 
     Hue[0.6389584142500294, 1, 0.11528834949995931`], 
     Hue[0.6369354292276049, 1, 0.1180894056848547], 
     Hue[0.6499202363144327, 1, 0.10011044202617006`], 
     Hue[0.6499307068090907, 1, 0.10009594441818216`], 
     Hue[0.631411381448922, 1, 0.1257380872245697], 
     Hue[0.627653770396862, 1, 0.1309409332966527], 
     Hue[0.6496397195744819, 1, 0.10049884981994829`], 
     Hue[0.6499711752825617, 1, 0.10003991114722235`], 
     Hue[0.6499762536549266, 1, 0.10003287955471696`], 
     Hue[0.6189100178906387, 1, 0.1430476675360388], 
     Hue[0.6139219345408472, 1, 0.14995424448190392`], 
     Hue[0.6498506186895228, 1, 0.10020683566066077`], 
     Hue[0.649992139261425, 1, 0.10001088409956546`], 
     Hue[0.649993865184265, 1, 0.10000849436024842`], 
     Hue[0.6499507438872519, 1, 0.10006820077149738`], 
     Hue[0.6499983476490149, 1, 0.10000228787059483`], 
     Hue[0.6499987777339871, 1, 0.10000169236832561`], 
     Hue[0.49721716070467575`, 1, 0.31154546979352593`], 
     Hue[0.5180120543237592, 1, 0.2827525401671027], 
     Hue[0.5687382725785333, 1, 0.21251623796818472`], 
     Hue[0.5843916311228772, 1, 0.19084235690678542`], 
     Hue[0.6150728538410806, 1, 0.14836066391234995`], 
     Hue[0.6228816248506641, 1, 0.13754851943754204`], 
     Hue[0.6355280494071399, 1, 0.12003808543626789`], 
     Hue[0.635567781392156, 1, 0.11998307191855329`], 
     Hue[0.6383247155517912, 1, 0.11616577846675076`], 
     Hue[0.6425869541066499, 1, 0.11026421739079253`], 
     Hue[0.6435492187576146, 1, 0.10893185095099511`], 
     Hue[0.6498492997424695, 1, 0.10020866189504225`], 
     Hue[0.6498634854226076, 1, 0.10018902018408182`], 
     Hue[0.6495104321520119, 1, 0.10067786317413743`], 
     Hue[0.6499326287044422, 1, 0.10009328333231078`], 
     Hue[0.6499427464970975, 1, 0.1000792740809419], 
     Hue[0.6497995501416562, 1, 0.10027754595770684`], 
     Hue[0.6499796318088381, 1, 0.1000282021108396], 
     Hue[0.6499837977879257, 1, 0.10002243383210295`], 
     Hue[0.6497967031430822, 1, 0.10028148795573225`], 
     Hue[0.6498799739553269, 1, 0.10016618990800896`], 
     Hue[0.649941550412067, 1, 0.10008093019867645`], 
     Hue[0.6499957079341608, 1, 0.10000594286039267`], 
     Hue[0.6499968016948423, 1, 0.10000442842252608`], 
     Hue[0.6499544789815872, 1, 0.10006302910241778`], 
     Hue[0.6499773681890932, 1, 0.10003133635356329`], 
     Hue[0.6499546249480828, 1, 0.10006282699496233`], 
     Hue[0.6499774540762749, 1, 0.10003121743285012`], 
     Hue[0.6499882868309909, 1, 0.1000162182340127], 
     Hue[0.6499993476880973, 1, 0.10000090320109607`], 
     Hue[0.649999546284906, 1, 0.10000062822089954`], 
     Hue[0.6499786571222672, 1, 0.10002955167686085`], 
     Hue[0.6499786571222672, 1, 0.10002955167686085`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499786432660215, 1, 0.10002957086243183`], 
     Hue[0.6481499757638645, 1, 0.10256157201926468`], 
     Hue[0.6481488635226094, 1, 0.10256311204561784`], 
     Hue[0.6481499757637849, 1, 0.10256157201937481`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499786432660215, 1, 0.10002957086243186`], 
     Hue[0.6499786432660215, 1, 0.10002957086243186`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499872761827474, 1, 0.1000176175931189], 
     Hue[0.6499998499361392, 1, 0.10000020778073027`], 
     Hue[0.6499997756993264, 1, 0.10000031057016343`], 
     Hue[0.649998744591033, 1, 0.10000173825856974`], 
     Hue[0.649998257978814, 1, 0.10000241202933446`], 
     Hue[0.6499807313906684, 1, 0.10002667961292076`], 
     Hue[0.6499999454587057, 1, 0.10000007551871525`], 
     Hue[0.6499448820990992, 1, 0.10007631709355502`], 
     Hue[0.6498985097083886, 1, 0.1001405250191543], 
     Hue[0.6499985526901774, 1, 0.10000200396744671`], 
     Hue[0.6499924900042139, 1, 0.10001039845570384`], 
     Hue[0.6499902455567599, 1, 0.10001350615217873`], 
     Hue[0.6499145448836653, 1, 0.10011832246877118`], 
     Hue[0.6498226656875891, 1, 0.1002455398171844], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6498702084125652, 1, 0.10017971142875591`], 
     Hue[0.649822601052624, 1, 0.10024562931175142`], 
     Hue[0.6499915553675152, 1, 0.10001169256805592`], 
     Hue[0.6495444786347687, 1, 0.10063072189032035`], 
     Hue[0.649721605398353, 1, 0.10038546944843432`], 
     Hue[0.6497393167031354, 1, 0.100360946103351], 
     Hue[0.6430994341869618, 1, 0.10955462958728368`], 
     Hue[0.6430994341869617, 1, 0.10955462958728389`], 
     Hue[0.6497442349944514, 1, 0.10035413616152887`], 
     Hue[0.6326369084382304, 1, 0.12404120370091186`], 
     Hue[0.6278460623885441, 1, 0.13067468284663128`], 
     Hue[0.6227153440039708, 1, 0.13777875445604051`], 
     Hue[0.6227153440039702, 1, 0.13777875445604126`], 
     Hue[0.649925810454061, 1, 0.10010272398668485`], 
     Hue[0.6499740052775556, 1, 0.10003599269261546`], 
     Hue[0.6499931350584105, 1, 0.10000950530373938`], 
     Hue[0.6499731374090268, 1, 0.10003719435673206`], 
     Hue[0.6499785845670428, 1, 0.10002965213794066`], 
     Hue[0.6493278398912834, 1, 0.10093068322745373`], 
     Hue[0.645136680417695, 1, 0.10673382711396075`], 
     Hue[0.6493269366654968, 1, 0.10093193384777369`], 
     Hue[0.6495118930856854, 1, 0.10067584034289725`], 
     Hue[0.6496046189157386, 1, 0.10054745073205425`], 
     Hue[0.6499986042640042, 1, 0.10000193255753263`], 
     Hue[0.6499994842091842, 1, 0.10000071417189885`], 
     Hue[0.6499992967751281, 1, 0.10000097369597646`], 
     Hue[0.6499785002992391, 1, 0.10002976881643816`], 
     Hue[0.6448143518714428, 1, 0.10718012817800232`], 
     Hue[0.6448140890407283, 1, 0.10718049209745306`], 
     Hue[0.6448213068073145, 1, 0.1071704982667953], 
     Hue[0.008564162898874295, 1, 0.9881419282938664], 
     Hue[0.6496050201873774, 1, 0.10054689512516983`], 
     Hue[0.6499994103243372, 1, 0.1000008164739948], 
     Hue[0.649997177936394, 1, 0.10000390747268527`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.00856416289719053, 1, 0.9881419282961977], 
     Hue[0.6499785845670427, 1, 0.10002965213794082`], 
     Hue[0.6499968070349429, 1, 0.1000044210285406], 
     Hue[0.6499875143105937, 1, 0.10001728787763953`], 
     Hue[0.6499844331418096, 1, 0.10002155411134056`], 
     Hue[0.6499861817897984, 1, 0.1000191329064331], 
     Hue[0.632957681610334, 1, 0.12359705623184515`], 
     Hue[0.6358099147458792, 1, 0.11964781035185952`], 
     Hue[0.634495825261374, 1, 0.12146731886886677`], 
     Hue[0.6227153440043056, 1, 0.13777875445557686`], 
     Hue[0.6227153440043062, 1, 0.1377787544555762], 
     Hue[0.6430994341870133, 1, 0.1095546295872123], 
     Hue[0.6430994341870135, 1, 0.10955462958721211`], 
     Hue[0.6497220759135403, 1, 0.10038481796586732`], 
     Hue[0.6497444630285241, 1, 0.10035382042204369`], 
     Hue[0.6497498661728607, 1, 0.10034633914526984`], 
     Hue[0.6499766495074196, 1, 0.10003233145126512`], 
     Hue[0.6499380881968962, 1, 0.10008572403506673`], 
     Hue[0.6492714389145244, 1, 0.10100877688758152`], 
     Hue[0.6495444786347686, 1, 0.1006307218903205], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499820089674371, 1, 0.10002491066047177`], 
     Hue[0.6497422006045631, 1, 0.10035695300906648`], 
     Hue[0.6498702084125652, 1, 0.10017971142875598`], 
     Hue[0.6499924815348365, 1, 0.10001041018253413`], 
     Hue[0.649995066268984, 1, 0.10000683131986839`], 
     Hue[0.6499995584935135, 1, 0.10000061131667352`], 
     Hue[0.6498987693663226, 1, 0.10014016549278415`], 
     Hue[0.6499963588136884, 1, 0.10000504164258525`], 
     Hue[0.6499999454587057, 1, 0.10000007551871525`], 
     Hue[0.6499872851621001, 1, 0.10001760516016903`], 
     Hue[0.6499994700011782, 1, 0.10000073384452254`], 
     Hue[0.6459417553415034, 1, 0.10561910798868754`], 
     Hue[0.6447602379007432, 1, 0.10725505521435556`], 
     Hue[0.6499848496426992, 1, 0.10002097741780114`], 
     Hue[0.6499997133311914, 1, 0.10000039692604273`], 
     Hue[0.6447602379004879, 1, 0.10725505521470911`], 
     Hue[0.6445860308483408, 1, 0.10749626497922055`], 
     Hue[0.6450472715451145, 1, 0.10685762401445689`], 
     Hue[0.6451837682394977, 1, 0.10666862859146471`], 
     Hue[0.6451837682394977, 1, 0.1066686285914647], 
     Hue[0.622715344004306, 1, 0.13777875445557644`], 
     Hue[0.6430994341870134, 1, 0.10955462958721218`], 
     Hue[0.6473532864649094, 1, 0.10366468027935616`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.649992836251731, 1, 0.10000991903606476`], 
     Hue[0.6499979189376313, 1, 0.1000028814709721], 
     Hue[0.6499979189376313, 1, 0.1000028814709721], 
     Hue[0.6499892906359471, 1, 0.10001482835022706`], 
     Hue[0.6499987880908246, 1, 0.10000167802808904`], 
     Hue[0.6499982837325233, 1, 0.10000237637035238`], 
     Hue[0.6499972833772172, 1, 0.1000037614776993], 
     Hue[0.649992836251731, 1, 0.10000991903606475`], 
     Hue[0.6499907772481441, 1, 0.1000127699641082], 
     Hue[0.6499851015179049, 1, 0.10002062866751626`], 
     Hue[0.6497831131736972, 1, 0.1003003048364193], 
     Hue[0.6498758963289265, 1, 0.10017183585225567`], 
     Hue[0.649849705083499, 1, 0.10020810065361672`], 
     Hue[0.6498638958591649, 1, 0.10018845188731017`], 
     Hue[0.6473532864649095, 1, 0.10366468027935608`], 
     Hue[0.647459617606195, 1, 0.1035174525452686], 
     Hue[0.6455633919912058, 1, 0.10614299570448421`], 
     Hue[0.6454878932078376, 1, 0.10624753248145562`], 
     Hue[0.6450803703104614, 1, 0.10681179495474584`], 
     Hue[0.6452024257204934, 1, 0.10664279515624006`], 
     Hue[0.6421328552372222, 1, 0.11089296967153851`], 
     Hue[0.6227153440039706, 1, 0.13777875445604082`], 
     Hue[0.6384789975532855, 1, 0.11595215723391242`], 
     Hue[0.6498629460993739, 1, 0.10018976693932855`], 
     Hue[0.649838667427071, 1, 0.10022338356251717`], 
     Hue[0.6498522655918395, 1, 0.10020455533437608`], 
     Hue[0.6450472715450636, 1, 0.10685762401452739`], 
     Hue[0.6450484170872487, 1, 0.10685603787919415`], 
     Hue[0.6446438544073366, 1, 0.10741620158984168`], 
     Hue[0.6447422602882784, 1, 0.10727994729315304`], 
     Hue[0.6265023909906814, 1, 0.13253515093597962`], 
     Hue[0.644586417592622, 1, 0.10749572948713883`], 
     Hue[0.6445864175924405, 1, 0.10749572948739003`], 
     Hue[0.6265023909903279, 1, 0.13253515093646911`], 
     Hue[0.6446438544073931, 1, 0.10741620158976331`], 
     Hue[0.644742260288343, 1, 0.10727994729306359`], 
     Hue[0.644742260288343, 1, 0.10727994729306359`], 
     Hue[0.6450484170872991, 1, 0.10685603787912441`], 
     Hue[0.6498629460993739, 1, 0.10018976693932846`], 
     Hue[0.6498386674270711, 1, 0.10022338356251707`], 
     Hue[0.6498522655918396, 1, 0.10020455533437599`], 
     Hue[0.6459425149453752, 1, 0.1056180562294804], 
     Hue[0.6455644065284449, 1, 0.1061415909606147], 
     Hue[0.6498758963289265, 1, 0.10017183585225571`], 
     Hue[0.649849705083499, 1, 0.10020810065361677`], 
     Hue[0.6498638958591649, 1, 0.10018845188731021`], 
     Hue[0.6499907772481441, 1, 0.1000127699641082], 
     Hue[0.6499902459174384, 1, 0.10001350565277761`], 
     Hue[0.6499987880908246, 1, 0.10000167802808904`], 
     Hue[0.6499971170968787, 1, 0.10000399171201411`], 
     Hue[0.6499941827230284, 1, 0.1000080546911914], 
     Hue[0.6499169408087975, 1, 0.10011500503397273`], 
     Hue[0.6499450533801044, 1, 0.10007607993524008`], 
     Hue[0.6498987693663225, 1, 0.10014016549278425`], 
     Hue[0.649998299585341, 1, 0.10000235442029706`], 
     Hue[0.649997310025984, 1, 0.10000372457940669`], 
     Hue[0.6499954637608208, 1, 0.10000628094655577`], 
     Hue[0.6499999143695201, 1, 0.1000001185652799], 
     Hue[0.6499998973914634, 1, 0.10000014207335849`], 
     Hue[0.6499995584935135, 1, 0.10000061131667352`], 
     Hue[0.6499998069333369, 1, 0.10000026732307205`], 
     Hue[0.6499998959071556, 1, 0.10000014412855386`], 
     Hue[0.6499996498839958, 1, 0.10000048477600589`], 
     Hue[0.6499989198255313, 1, 0.10000149562618747`], 
     Hue[0.6499924815348365, 1, 0.10001041018253413`], 
     Hue[0.649995066268984, 1, 0.10000683131986839`], 
     Hue[0.6499903637000147, 1, 0.10001334256921045`], 
     Hue[0.6499883785355535, 1, 0.10001609125846449`], 
     Hue[0.6499971445555819, 1, 0.1000039536922713], 
     Hue[0.6499872378397605, 1, 0.1000176706834086], 
     Hue[0.6499812127959619, 1, 0.10002601305174516`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499981583263428, 1, 0.10000255000967932`], 
     Hue[0.6499969194200786, 1, 0.10000426541835268`], 
     Hue[0.6499565454836217, 1, 0.10006016779190839`], 
     Hue[0.6499694960336535, 1, 0.10004223626109525`], 
     Hue[0.6499293875018999, 1, 0.10009777115121551`], 
     Hue[0.6499680543081146, 1, 0.10004423249645675`], 
     Hue[0.6499611431173056, 1, 0.10005380183757688`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499766495074196, 1, 0.10003233145126515`], 
     Hue[0.6499870926215222, 1, 0.10001787175481541`], 
     Hue[0.6498198123292014, 1, 0.10024949062110575`], 
     Hue[0.6498658977018641, 1, 0.10018568010511125`], 
     Hue[0.6499070733798012, 1, 0.10012866762796759`], 
     Hue[0.6498941642091621, 1, 0.10014654186423702`], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6498880939419249, 1, 0.1001549468496424], 
     Hue[0.6499317360308979, 1, 0.10009451934183362`], 
     Hue[0.6499513388525884, 1, 0.10006737697333921`], 
     Hue[0.6499329557399242, 1, 0.10009283051395124`], 
     Hue[0.6499430494131799, 1, 0.10007885465867403`], 
     Hue[0.6499074536869546, 1, 0.10012814104883216`], 
     Hue[0.6498945576128976, 1, 0.10014599715137257`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6495806066420229, 1, 0.1005806984956607], 
     Hue[0.6497210465128498, 1, 0.1003862432899004], 
     Hue[0.6454889217763359, 1, 0.10624610830968877`], 
     Hue[0.6450814653729393, 1, 0.10681027871439172`], 
     Hue[0.6342357357137165, 1, 0.12182744285793096`], 
     Hue[0.6451848600758338, 1, 0.10666711681807643`], 
     Hue[0.6499389913540884, 1, 0.10008447350972376`], 
     Hue[0.6499205322569598, 1, 0.10011003225959413`], 
     Hue[0.6499309840236278, 1, 0.10009556058266922`], 
     Hue[0.6131190636396185, 1, 0.15106591188360513`], 
     Hue[0.636329096752552, 1, 0.11892894295800491`], 
     Hue[0.6498945035414182, 1, 0.10014607201957486`], 
     Hue[0.6498817551107648, 1, 0.10016372369278723`], 
     Hue[0.6329576816102909, 1, 0.123597056231905], 
     Hue[0.6358099147458411, 1, 0.11964781035191228`], 
     Hue[0.6314188285392712, 1, 0.12572777586870135`], 
     Hue[0.6276615081560073, 1, 0.13093021947629757`], 
     Hue[0.6499579058346595, 1, 0.10005828422893298`], 
     Hue[0.6499502404150022, 1, 0.1000688978869202], 
     Hue[0.6123798420904445, 1, 0.15208944941323072`], 
     Hue[0.6189168169702053, 1, 0.1430382534258697], 
     Hue[0.613927475741499, 1, 0.14994657205023218`], 
     Hue[0.6498038432915917, 1, 0.10027160159625775`], 
     Hue[0.6499875143105937, 1, 0.10001728787763954`], 
     Hue[0.6499844331418096, 1, 0.10002155411134057`], 
     Hue[0.6445860308485625, 1, 0.10749626497891357`], 
     Hue[0.6499305639619214, 1, 0.10009614220657034`], 
     Hue[0.6499569735915823, 1, 0.10005957502703981`], 
     Hue[0.649997177936394, 1, 0.10000390747268527`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499978738704448, 1, 0.10000294387169176`], 
     Hue[0.6499990165514296, 1, 0.10000136169802062`], 
     Hue[0.6499997433419163, 1, 0.10000035537273123`], 
     Hue[0.6499848496426992, 1, 0.10002097741780114`], 
     Hue[0.008564162898874739, 1, 0.9881419282938658], 
     Hue[0.018968293162327066`, 1, 0.9737362094675472], 
     Hue[0.0021628179028306826`, 1, 0.997005329057619], 
     Hue[0.6499785002992392, 1, 0.100029768816438], 
     Hue[0.6499682293104806, 1, 0.10004399018548843`], 
     Hue[0.6499994806519499, 1, 0.10000071909730011`], 
     Hue[0.6499992967751281, 1, 0.10000097369597646`], 
     Hue[0.6499997221218345, 1, 0.10000038475438296`], 
     Hue[0.6499763120114476, 1, 0.10003279875338035`], 
     Hue[0.6496046189157263, 1, 0.10054745073207125`], 
     Hue[0.008564162897190086, 1, 0.9881419282961984], 
     Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
     Hue[0.6499990165514296, 1, 0.10000136169802062`], 
     Hue[0.6499682293104805, 1, 0.10004399018548858`], 
     Hue[0.6499569735915823, 1, 0.1000595750270399], 
     Hue[0.6499305639619215, 1, 0.10009614220657022`], 
     Hue[0.6493269366654801, 1, 0.10093193384779679`], 
     Hue[0.64507301626234, 1, 0.10682197748291383`], 
     Hue[0.64507301626234, 1, 0.10682197748291383`], 
     Hue[0.6123798420897152, 1, 0.15208944941424052`], 
     Hue[0.618916816969635, 1, 0.14303825342665927`], 
     Hue[0.6139274757407954, 1, 0.14994657205120632`], 
     Hue[0.6494794345021757, 1, 0.10072078299698756`], 
     Hue[0.649327839891267, 1, 0.10093068322747654`], 
     Hue[0.6498038432915922, 1, 0.10027160159625687`], 
     Hue[0.6314188285390578, 1, 0.12572777586899692`], 
     Hue[0.6276615081556767, 1, 0.13093021947675546`], 
     Hue[0.6499579058346595, 1, 0.10005828422893297`], 
     Hue[0.6499502404150022, 1, 0.10006889788692015`], 
     Hue[0.6363290967524697, 1, 0.1189289429581188], 
     Hue[0.6499389913540885, 1, 0.10008447350972371`], 
     Hue[0.6499205322569599, 1, 0.10011003225959408`], 
     Hue[0.6499309840236278, 1, 0.10009556058266918`], 
     Hue[0.6498945035414182, 1, 0.10014607201957479`], 
     Hue[0.6498817551107648, 1, 0.10016372369278714`], 
     Hue[0.6451848600758766, 1, 0.10666711681801709`], 
     Hue[0.6451848600758766, 1, 0.10666711681801709`], 
     Hue[0.6498948423987034, 1, 0.10014560283256446`], 
     Hue[0.6498821047507632, 1, 0.10016323957586633`], 
     Hue[0.6326369084383059, 1, 0.12404120370080722`], 
     Hue[0.6278460623886937, 1, 0.1306746828464241], 
     Hue[0.6343038838830548, 1, 0.12173308385423177`], 
     Hue[0.644391249173842, 1, 0.10776596268237253`], 
     Hue[0.6454889217763379, 1, 0.106246108309686], 
     Hue[0.6450814653729429, 1, 0.10681027871438688`], 
     Hue[0.6499513388525884, 1, 0.10006737697333923`], 
     Hue[0.6499329557399242, 1, 0.10009283051395125`], 
     Hue[0.6499430494131799, 1, 0.10007885465867404`], 
     Hue[0.6495806066420295, 1, 0.10058069849565142`], 
     Hue[0.649721046512853, 1, 0.10038624328989595`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6499070733798011, 1, 0.10012866762796763`], 
     Hue[0.6498941642091621, 1, 0.10014654186423706`], 
     Hue[0.6498880939419255, 1, 0.10015494684964163`], 
     Hue[0.6499317360308982, 1, 0.10009451934183332`], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499680543081146, 1, 0.10004423249645678`], 
     Hue[0.6499611431173056, 1, 0.10005380183757691`], 
     Hue[0.6498198123292014, 1, 0.10024949062110576`], 
     Hue[0.6498658977018641, 1, 0.10018568010511128`], 
     Hue[0.6499870926215222, 1, 0.1000178717548154], 
     Hue[0.6499969194200786, 1, 0.10000426541835268`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499145448836653, 1, 0.10011832246877124`], 
     Hue[0.6499924900042139, 1, 0.10001039845570384`], 
     Hue[0.6499902455567598, 1, 0.10001350615217874`], 
     Hue[0.6499943973499914, 1, 0.10000775751539649`], 
     Hue[0.6499384202733739, 1, 0.100085264236867], 
     Hue[0.6499448820990992, 1, 0.10007631709355508`], 
     Hue[0.6498985097083885, 1, 0.10014052501915438`], 
     Hue[0.6499505383206859, 1, 0.10006848540212712`], 
     Hue[0.6499565454836217, 1, 0.10006016779190842`], 
     Hue[0.6499694960336534, 1, 0.10004223626109526`], 
     Hue[0.6499981583263428, 1, 0.10000255000967932`], 
     Hue[0.6499989198255313, 1, 0.10000149562618747`], 
     Hue[0.6499996498839958, 1, 0.10000048477600589`], 
     Hue[0.649946398470897, 1, 0.10007421750183498`], 
     Hue[0.6499872378397605, 1, 0.1000176706834086], 
     Hue[0.6499812127959619, 1, 0.10002601305174515`], 
     Hue[0.6499807313906684, 1, 0.10002667961292078`], 
     Hue[0.649998744591033, 1, 0.10000173825856974`], 
     Hue[0.649998257978814, 1, 0.10000241202933446`], 
     Hue[0.6499991149582264, 1, 0.10000122544245589`], 
     Hue[0.6499883785355535, 1, 0.10001609125846449`], 
     Hue[0.6499955545015644, 1, 0.1000061553055262], 
     Hue[0.6499971445555819, 1, 0.10000395369227129`], 
     Hue[0.6499169012778275, 1, 0.10011505976916192`], 
     Hue[0.6499452554080251, 1, 0.10007580020427298`], 
     Hue[0.6499452554080251, 1, 0.10007580020427298`], 
     Hue[0.6499972861634967, 1, 0.10000375761977373`], 
     Hue[0.6499998069333369, 1, 0.10000026732307205`], 
     Hue[0.6499998959071556, 1, 0.10000014412855386`], 
     Hue[0.6499999143695201, 1, 0.1000001185652799], 
     Hue[0.6499998973914634, 1, 0.10000014207335849`], 
     Hue[0.649998299585341, 1, 0.10000235442029706`], 
     Hue[0.6499925368181951, 1, 0.10001033363634519`], 
     Hue[0.6499971170968787, 1, 0.10000399171201411`], 
     Hue[0.6499941827230284, 1, 0.1000080546911914], 
     Hue[0.6499998499361392, 1, 0.10000020778073027`], 
     Hue[0.6499997930401497, 1, 0.10000028655979275`], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.6499696557470173, 1, 0.10004201511951462`], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6498821047507631, 1, 0.1001632395758664], 
     Hue[0.6499504648283491, 1, 0.10006858716074747`], 
     Hue[0.6499993034614677, 1, 0.10000096443796776`], 
     Hue[0.6499996952446704, 1, 0.10000042196891794`], 
     Hue[0.6499997231111884, 1, 0.10000038338450845`], 
     Hue[0.6499764116330908, 1, 0.10003266081572036`], 
     Hue[0.6496050201873893, 1, 0.10054689512515333`], 
     Hue[0.6499835735373027, 1, 0.10002274433296544`], 
     Hue[0.6499763120114477, 1, 0.10003279875338018`], 
     Hue[0.6499996718109462, 1, 0.10000045441561291`], 
     Hue[0.6499997221218345, 1, 0.10000038475438296`], 
     Hue[0.0021628179019728133`, 1, 0.9970053290588069], 
     Hue[0.018968293159893457`, 1, 0.9737362094709167], 
     Hue[0.6499836181429695, 1, 0.10002268257127306`], 
     Hue[0.6499764116330907, 1, 0.10003266081572053`], 
     Hue[0.6499996739625998, 1, 0.1000004514364003], 
     Hue[0.6499997231111884, 1, 0.10000038338450845`], 
     Hue[0.6499994854782605, 1, 0.10000071241471627`], 
     Hue[0.6499993034614677, 1, 0.10000096443796776`], 
     Hue[0.6499581095157081, 1, 0.10005800220901966`], 
     Hue[0.6499504648283491, 1, 0.10006858716074744`], 
     Hue[0.6498945576128976, 1, 0.1001459971513726], 
     Hue[0.6499961977161761, 1, 0.10000526470067919`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.6499567540632241, 1, 0.10005987898938216`], 
     Hue[0.6499696557470173, 1, 0.1000420151195146], 
     Hue[0.6499998221998805, 1, 0.10000024618478089`], 
     Hue[0.6499852101793618, 1, 0.10002047821319134`], 
     Hue[0.6499979259072688, 1, 0.10000287182070478`], 
     Hue[0.6499979068548963, 1, 0.10000289820091286`], 
     Hue[0.6499298416416036, 1, 0.1000971423423951], 
     Hue[0.6497773350123875, 1, 0.10030830536746345`], 
     Hue[0.649832150775643, 1, 0.10023240661834047`], 
     Hue[0.649832150775643, 1, 0.10023240661834047`], 
     Hue[0.6497201201157683, 1, 0.10038752599355165`], 
     Hue[0.6499994159454975, 1, 0.1000008086908497], 
     Hue[0.6499994890716042, 1, 0.10000070743931735`], 
     Hue[0.6499995709517367, 1, 0.10000059406682617`], 
     Hue[0.6499836181429696, 1, 0.10002268257127296`], 
     Hue[0.649981784564363, 1, 0.10002522137242062`], 
     Hue[0.07116385446975892, 1, 0.9014654322726414], 
     Hue[0.07116385446975826, 1, 0.9014654322726423], 
     Hue[0.10275085519718585`, 1, 0.8577295851115889], 
     Hue[0.6450730162625566, 1, 0.10682197748261398`], 
     Hue[0.6450730162625566, 1, 0.10682197748261398`], 
     Hue[0.649649578370901, 1, 0.10048519917875254`], 
     Hue[0.6496211353704912, 1, 0.10052458179470464`], 
     Hue[0.6496149480434008, 1, 0.10053314886298349`], 
     Hue[0.6499997099087569, 1, 0.10000040166479822`], 
     Hue[0.649999693272125, 1, 0.10000042470013458`], 
     Hue[0.6499996487226951, 1, 0.10000048638396059`], 
     Hue[0.6499995670990851, 1, 0.10000059940126672`], 
     Hue[0.6499852320800056, 1, 0.1000204478892231], 
     Hue[0.6499835735373027, 1, 0.10002274433296553`], 
     Hue[0.6499817210220851, 1, 0.10002530935403613`], 
     Hue[0.6496523580230942, 1, 0.10048135042956187`], 
     Hue[0.6496214584224937, 1, 0.10052413449193183`], 
     Hue[0.6496153109565737, 1, 0.10053264636782111`], 
     Hue[0.6497703804347833, 1, 0.10031793478260782`], 
     Hue[0.649720148386843, 1, 0.10038748684898668`], 
     Hue[0.649969296003201, 1, 0.10004251322633716`], 
     Hue[0.6499715658257952, 1, 0.1000393703950529], 
     Hue[0.6499949427213864, 1, 0.10000700238577272`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6498226010526239, 1, 0.1002456293117515], 
     Hue[0.6499993787624871, 1, 0.1000008601750178], 
     Hue[0.6499997881961503, 1, 0.10000029326686882`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6498226656875892, 1, 0.10024553981718431`], 
     Hue[0.6499986816144642, 1, 0.10000182545689576`], 
     Hue[0.6499452554080252, 1, 0.10007580020427294`], 
     Hue[0.6499452554080252, 1, 0.10007580020427295`], 
     Hue[0.6483242391402425, 1, 0.1023202842673565], 
     Hue[0.6483242391402425, 1, 0.10232028426735655`], 
     Hue[0.6483242391402425, 1, 0.10232028426735651`], 
     Hue[0.6499906782378703, 1, 0.10001290705525658`], 
     Hue[0.644843834309606, 1, 0.1071393063405455], 
     Hue[0.6447609920664562, 1, 0.10725401098490685`], 
     Hue[0.6446427123917257, 1, 0.10741778284222608`], 
     Hue[0.6447410918958293, 1, 0.10728156506731333`], 
     Hue[0.6447410918958293, 1, 0.10728156506731332`], 
     Hue[0.6454301116847827, 1, 0.10632753766722401`], 
     Hue[0.6469166687904662, 1, 0.10426922782858536`], 
     Hue[0.6452016973298361, 1, 0.10664380369715003`], 
     Hue[0.6450803703104621, 1, 0.10681179495474484`], 
     Hue[0.6473254666988636, 1, 0.10370319995541974`], 
     Hue[0.6473386224356844, 1, 0.10368498431982166`], 
     Hue[0.6474431293251606, 1, 0.10354028247285457`], 
     Hue[0.648324239140247, 1, 0.10232028426735044`], 
     Hue[0.648324239140247, 1, 0.1023202842673504], 
     Hue[0.648324239140247, 1, 0.10232028426735042`], 
     Hue[0.6478300313592262, 1, 0.10300457196414826`], 
     Hue[0.6499979068548963, 1, 0.10000289820091286`], 
     Hue[0.6499768211371815, 1, 0.10003209381005644`], 
     Hue[0.6499892906359471, 1, 0.10001482835022706`], 
     Hue[0.6499998221998805, 1, 0.10000024618478089`], 
     Hue[0.6499893270949103, 1, 0.10001477786858572`], 
     Hue[0.6499965329720212, 1, 0.10000480050027838`], 
     Hue[0.6499942337059641, 1, 0.10000798409943434`], 
     Hue[0.6499906738504719, 1, 0.10001291313011582`], 
     Hue[0.6497970985365656, 1, 0.10028094048783229`], 
     Hue[0.6498802677343509, 1, 0.10016578313705254`], 
     Hue[0.6481847608283471, 1, 0.1025134080838272], 
     Hue[0.647847739448394, 1, 0.10298005307145443`], 
     Hue[0.6476673319658688, 1, 0.10322984804725865`], 
     Hue[0.6475036441269622, 1, 0.10345649274728327`], 
     Hue[0.6475036441269622, 1, 0.10345649274728327`], 
     Hue[0.6473254666988629, 1, 0.10370319995542056`], 
     Hue[0.6474431293251606, 1, 0.1035402824728547], 
     Hue[0.64691666879048, 1, 0.10426922782856618`], 
     Hue[0.643297066847292, 1, 0.10928098436528796`], 
     Hue[0.6450761923628352, 1, 0.10681757980530521`], 
     Hue[0.6425888456319467, 1, 0.11026159835576614`], 
     Hue[0.64355065154183, 1, 0.10892986709592774`], 
     Hue[0.6451837682394547, 1, 0.10666862859152434`], 
     Hue[0.6451837682394547, 1, 0.10666862859152436`], 
     Hue[0.6446427123916647, 1, 0.10741778284231042`], 
     Hue[0.6447410918957623, 1, 0.10728156506740608`], 
     Hue[0.6447410918957623, 1, 0.10728156506740608`], 
     Hue[0.6446754130693809, 1, 0.1073725049808572], 
     Hue[0.6448226855250837, 1, 0.10716858927296101`], 
     Hue[0.6448226855250837, 1, 0.10716858927296102`], 
     Hue[0.5959045810178848, 1, 0.17490134935985185`], 
     Hue[0.5991242399822707, 1, 0.17044336002454824`], 
     Hue[0.6448438343094491, 1, 0.1071393063407628], 
     Hue[0.5959045810185308, 1, 0.1749013493589574], 
     Hue[0.5991242399827919, 1, 0.17044336002382665`], 
     Hue[0.6448226855248735, 1, 0.10716858927325205`], 
     Hue[0.6425888456320292, 1, 0.11026159835565194`], 
     Hue[0.6435506515418995, 1, 0.10892986709583152`], 
     Hue[0.643297066847046, 1, 0.10928098436562861`], 
     Hue[0.6450761923626177, 1, 0.10681757980560624`], 
     Hue[0.6497970985365658, 1, 0.10028094048783215`], 
     Hue[0.649880267734351, 1, 0.10016578313705245`], 
     Hue[0.6499942337059641, 1, 0.10000798409943434`], 
     Hue[0.6499906738504719, 1, 0.10001291313011582`], 
     Hue[0.6499965329720212, 1, 0.10000480050027838`], 
     Hue[0.6499893270949103, 1, 0.10001477786858572`], 
     Hue[0.6499994700011782, 1, 0.10000073384452254`], 
     Hue[0.6499452847292683, 1, 0.10007575960562866`], 
     Hue[0.6499452847292683, 1, 0.10007575960562864`], 
     Hue[0.6499506956391089, 1, 0.10006826757661845`], 
     Hue[0.649997310025984, 1, 0.10000372457940669`], 
     Hue[0.6499963588136884, 1, 0.10000504164258524`], 
     Hue[0.6499996087792145, 1, 0.10000054169031843`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499313963608999, 1, 0.10009498965413857`], 
     Hue[0.6499418600005051, 1, 0.10008050153776214`], 
     Hue[0.6499820089674371, 1, 0.10002491066047176`], 
     Hue[0.6499885678296751, 1, 0.10001582915891155`], 
     Hue[0.649986680500004, 1, 0.10001844238460986`], 
     Hue[0.6499926102537842, 1, 0.10001023195629886`], 
     Hue[0.6499766758185227, 1, 0.100032295020507], 
     Hue[0.6499380881968964, 1, 0.10008572403506669`], 
     Hue[0.6355735873342747, 1, 0.11997503292177353`], 
     Hue[0.6383290297328666, 1, 0.11615980498526153`], 
     Hue[0.607541900540555, 1, 0.15878813771307765`], 
     Hue[0.566628613718335, 1, 0.2154373040823055], 
     Hue[0.6113350077370387, 1, 0.15353614313333103`], 
     Hue[0.6413526165411375, 1, 0.11197330017380966`], 
     Hue[0.649979910447695, 1, 0.10002781630319162`], 
     Hue[0.6499713297183559, 1, 0.1000396973130457], 
     Hue[0.649976389667182, 1, 0.1000326912300558], 
     Hue[0.6344958252613342, 1, 0.1214673188689219], 
     Hue[0.6497842792878252, 1, 0.10029869021685743`], 
     Hue[0.6499861817897983, 1, 0.10001913290643312`], 
     Hue[0.6499223977301634, 1, 0.1001074492966969], 
     Hue[0.6499968070349429, 1, 0.1000044210285406], 
     Hue[0.6499848535204814, 1, 0.10002097204856426`], 
     Hue[0.6499994103243372, 1, 0.1000008164739948], 
     Hue[0.6496495783709008, 1, 0.10048519917875282`], 
     Hue[0.6496211353704804, 1, 0.10052458179471949`], 
     Hue[0.6499986042640042, 1, 0.10000193255753263`], 
     Hue[0.6499223977301635, 1, 0.10010744929669671`], 
     Hue[0.0711638544660157, 1, 0.9014654322778244], 
     Hue[0.07116385446601503, 1, 0.9014654322778253], 
     Hue[0.6447609920662626, 1, 0.10725401098517487`], 
     Hue[0.6499931350584105, 1, 0.10000950530373938`], 
     Hue[0.6497842792878259, 1, 0.1002986902168565], 
     Hue[0.6499971946455725, 1, 0.10000388433689966`], 
     Hue[0.6499906782378703, 1, 0.10001290705525656`], 
     Hue[0.6499740052775556, 1, 0.10003599269261544`], 
     Hue[0.5666286137182638, 1, 0.215437304082404], 
     Hue[0.649979910447695, 1, 0.1000278163031916], 
     Hue[0.6499713297183559, 1, 0.10003969731304568`], 
     Hue[0.649976389667182, 1, 0.10003269123005579`], 
     Hue[0.649925810454061, 1, 0.10010272398668481`], 
     Hue[0.6424451989541748, 1, 0.11046049375575792`], 
     Hue[0.6413526165411441, 1, 0.11197330017380058`], 
     Hue[0.6150881106097981, 1, 0.14833953915566422`], 
     Hue[0.6228939004998529, 1, 0.13753152238481903`], 
     Hue[0.6427107986431155, 1, 0.11009274034030155`], 
     Hue[0.6355735873343954, 1, 0.11997503292160647`], 
     Hue[0.638329029732976, 1, 0.11615980498511017`], 
     Hue[0.649832150775643, 1, 0.1002324066183404], 
     Hue[0.6499766758185227, 1, 0.100032295020507], 
     Hue[0.6499822607431958, 1, 0.10002456204788279`], 
     Hue[0.649988567829675, 1, 0.10001582915891156`], 
     Hue[0.649986680500004, 1, 0.10001844238460987`], 
     Hue[0.6499915553675152, 1, 0.10001169256805592`], 
     Hue[0.6499418600005051, 1, 0.1000805015377621], 
     Hue[0.6499313963608999, 1, 0.10009498965413854`], 
     Hue[0.6499985526901774, 1, 0.10000200396744673`], 
     Hue[0.6499972861634967, 1, 0.10000375761977373`], 
     Hue[0.6499973394962008, 1, 0.10000368377449126`], 
     Hue[0.649998345225296, 1, 0.10000229122651329`], 
     Hue[0.6499993476936773, 1, 0.1000009031933699], 
     Hue[0.6499995636115868, 1, 0.10000060423011056`], 
     Hue[0.6499979259072688, 1, 0.10000287182070478`], 
     Hue[0.649997310025984, 1, 0.10000372457940668`], 
     Hue[0.649997310025984, 1, 0.10000372457940668`], 
     Hue[0.6499452847292683, 1, 0.10007575960562862`], 
     Hue[0.6499997355438514, 1, 0.10000036617005202`], 
     Hue[0.6499996943596676, 1, 0.10000042319430641`], 
     Hue[0.6499998525302062, 1, 0.10000020418894534`], 
     Hue[0.649999779338247, 1, 0.10000030553165791`], 
     Hue[0.6496214584225041, 1, 0.10052413449191748`], 
     Hue[0.10275085519977545`, 1, 0.8577295851080031], 
     Hue[0.6499996049868014, 1, 0.10000054694135192`], 
     Hue[0.6499996082984593, 1, 0.1000005423559795], 
     Hue[0.649832150775643, 1, 0.1002324066183404], 
     Hue[0.6499996709568588, 1, 0.10000045559819547`], 
     Hue[0.649999779338247, 1, 0.10000030553165791`], 
     Hue[0.6361358775823458, 1, 0.1191964771936751], 
     Hue[0.6361358775823456, 1, 0.11919647719367533`], 
     Hue[0.6499997114379519, 1, 0.10000039954745131`], 
     Hue[0.6499996514685767, 1, 0.10000048258197074`], 
     Hue[0.6498691588927477, 1, 0.1001811646100417], 
     Hue[0.6499509547899046, 1, 0.1000679087524398], 
     Hue[0.5936528925793111, 1, 0.17801907181326165`], 
     Hue[0.6448435305234992, 1, 0.10713972696746268`], 
     Hue[0.645136680417695, 1, 0.10673382711396075`], 
     Hue[0.6499996140825955, 1, 0.10000053434717537`], 
     Hue[0.6497253768389183, 1, 0.10038024745380555`], 
     Hue[0.6497432633695928, 1, 0.10035548148825621`], 
     Hue[0.6497376874239058, 1, 0.1003632020284381], 
     Hue[0.598578942259135, 1, 0.17119838764119769`], 
     Hue[0.5985789422591354, 1, 0.17119838764119716`], 
     Hue[0.6361358775824882, 1, 0.11919647719347792`], 
     Hue[0.6361358775824884, 1, 0.11919647719347777`], 
     Hue[0.6496475412721135, 1, 0.10048801977707356`], 
     Hue[0.6497575876165927, 1, 0.10033564791548695`], 
     Hue[0.6497176586044328, 1, 0.10039093424001616`], 
     Hue[0.6499102134211718, 1, 0.10012431987837749`], 
     Hue[0.6499402202393392, 1, 0.1000827719762997], 
     Hue[0.6499302912297339, 1, 0.10009651983575311`], 
     Hue[0.6499977899595798, 1, 0.10000306005596647`], 
     Hue[0.6499977899595798, 1, 0.10000306005596647`], 
     Hue[0.6499997881961503, 1, 0.10000029326686882`], 
     Hue[0.6499997070467911, 1, 0.10000040562752005`], 
     Hue[0.6499995636115868, 1, 0.10000060423011056`], 
     Hue[0.6449606118130902, 1, 0.10697761441264436`], 
     Hue[0.6449606118130902, 1, 0.10697761441264435`], 
     Hue[0.6446153322487039, 1, 0.10745569380948691`], 
     Hue[0.647503644126962, 1, 0.10345649274728334`], 
     Hue[0.647503644126962, 1, 0.10345649274728333`], 
     Hue[0.6499917724184623, 1, 0.10001139203597541`], 
     Hue[0.6499818441000457, 1, 0.10002513893839829`], 
     Hue[0.6499818441000457, 1, 0.10002513893839826`], 
     Hue[0.6499941069072821, 1, 0.10000815966684015`], 
     Hue[0.6499954637608208, 1, 0.10000628094655577`], 
     Hue[0.6425433794512151, 1, 0.1103245515290869], 
     Hue[0.6416068802400501, 1, 0.11162124274454605`], 
     Hue[0.033059327871870714`, 1, 0.9542255460235637], 
     Hue[0.05053038130689047, 1, 0.9300348566519978], 
     Hue[0.6499119444868918, 1, 0.10012192301814975`], 
     Hue[0.6498691588927481, 1, 0.1001811646100411], 
     Hue[0.649939804960482, 1, 0.10008334697779414`], 
     Hue[0.6499941069072821, 1, 0.10000815966684015`], 
     Hue[0.6499954637608208, 1, 0.10000628094655577`], 
     Hue[0.6499954637608208, 1, 0.10000628094655577`], 
     Hue[0.6499402202393393, 1, 0.10008277197629949`], 
     Hue[0.6499302912297341, 1, 0.10009651983575281`], 
     Hue[0.649757587616595, 1, 0.10033564791548386`], 
     Hue[0.649717658604436, 1, 0.1003909342400118], 
     Hue[0.6497282099863698, 1, 0.10037632463425723`], 
     Hue[0.6497476124961666, 1, 0.1003494596206924], 
     Hue[0.6497411112793049, 1, 0.10035846130557781`], 
     Hue[0.6499980775521905, 1, 0.10000266185081316`], 
     Hue[0.6499980775521905, 1, 0.10000266185081316`], 
     Hue[0.6499990826018167, 1, 0.1000012702436384], 
     Hue[0.6491923510353136, 1, 0.10111828318187353`], 
     Hue[0.6491923510353136, 1, 0.10111828318187355`], 
     Hue[0.6430994341869618, 1, 0.10955462958728375`], 
     Hue[0.6448435305234644, 1, 0.1071397269675108], 
     Hue[0.6465876268599798, 1, 0.1047248243477203], 
     Hue[0.6465876268599798, 1, 0.10472482434772026`], 
     Hue[0.5591705448255901, 1, 0.2257638610107214], 
     Hue[0.6051830845544243, 1, 0.1620541906169511], 
     Hue[0.6046239357498318, 1, 0.16282839665407917`], 
     Hue[0.6005020220421993, 1, 0.16853566178772414`], 
     Hue[0.6499949689168733, 1, 0.10000696611509867`], 
     Hue[0.6393277909144052, 1, 0.11477690488774678`], 
     Hue[0.639728945108811, 1, 0.11422146061856951`], 
     Hue[0.6411052738355187, 1, 0.11231577468928183`], 
     Hue[0.649968486457508, 1, 0.10004363413575815`], 
     Hue[0.6499767769522725, 1, 0.10003215498916111`], 
     Hue[0.649972676899105, 1, 0.10003783198585474`], 
     Hue[0.64998086534737, 1, 0.10002649413441077`], 
     Hue[0.6494791005751184, 1, 0.10072124535752844`], 
     Hue[0.6495813893887272, 1, 0.10057961469253159`], 
     Hue[0.6498553820677755, 1, 0.10020024021384928`], 
     Hue[0.6498884717547347, 1, 0.10015442372421353`], 
     Hue[0.6472339664152774, 1, 0.10382989265576983`], 
     Hue[0.6480087375848742, 1, 0.10275713257478956`], 
     Hue[0.6478300313592262, 1, 0.10300457196414828`], 
     Hue[0.6499948524777456, 1, 0.10000712733850615`], 
     Hue[0.6499975641411304, 1, 0.10000337272766563`], 
     Hue[0.643662976523736, 1, 0.1087743401979039], 
     Hue[0.6435436281016695, 1, 0.10893959185922679`], 
     Hue[0.6498946193265016, 1, 0.10014591170176698`], 
     Hue[0.6484137240052498, 1, 0.10219638214657721`], 
     Hue[0.649999065923293, 1, 0.10000129333697895`], 
     Hue[0.6499993569254062, 1, 0.10000089041097601`], 
     Hue[0.6499995531364383, 1, 0.10000061873416236`], 
     Hue[0.6499845305213169, 1, 0.10002141927817669`], 
     Hue[0.6499987610373165, 1, 0.10000171548679268`], 
     Hue[0.6499982793327067, 1, 0.10000238246240618`], 
     Hue[0.644297740872205, 1, 0.10789543571540844`], 
     Hue[0.6437766022656166, 1, 0.10861701224760785`], 
     Hue[0.6499998925666856, 1, 0.1000001487538201], 
     Hue[0.6499720083241632, 1, 0.10003875770500484`], 
     Hue[0.6499989806170189, 1, 0.10000141145335847`], 
     Hue[0.6499979189376313, 1, 0.1000028814709721], 
     Hue[0.6490732055840214, 1, 0.1012832538067396], 
     Hue[0.6487943291253612, 1, 0.10166939044180762`], 
     Hue[0.6486615686527496, 1, 0.1018532126346544], 
     Hue[0.6486721458807169, 1, 0.10183856724208436`], 
     Hue[0.6488754715936946, 1, 0.10155703933180743`], 
     Hue[0.6492211282544369, 1, 0.10107843780154896`], 
     Hue[0.6495635854272818, 1, 0.10060426633145604`], 
     Hue[0.6498036739551811, 1, 0.10027183606205689`], 
     Hue[0.6492205124027053, 1, 0.10107929051933126`], 
     Hue[0.6488751499378582, 1, 0.10155748470142709`], 
     Hue[0.6486721421475297, 1, 0.10183857241111285`], 
     Hue[0.6494481187205927, 1, 0.10076414330994858`], 
     Hue[0.64975855562808, 1, 0.10033430759188922`], 
     Hue[0.6499382721143278, 1, 0.10008546938016159`], 
     Hue[0.6497438699910106, 1, 0.10035464155090847`], 
     Hue[0.6493221359730589, 1, 0.10093858096038001`], 
     Hue[0.6487286338295368, 1, 0.1017603531591029], 
     Hue[0.6481845887416958, 1, 0.10251364635765203`], 
     Hue[0.6477867920179302, 1, 0.1030644418213274], 
     Hue[0.6474596176061952, 1, 0.10351745254526823`], 
     Hue[0.6472340635887639, 1, 0.10382975810786547`], 
     Hue[0.6471954778691708, 1, 0.10388318448884046`], 
     Hue[0.6474440549357112, 1, 0.1035390008582461], 
     Hue[0.6479727326168359, 1, 0.10280698560745806`], 
     Hue[0.6486308130734021, 1, 0.10189579728298169`], 
     Hue[0.6492993957289775, 1, 0.10097006745218497`], 
     Hue[0.6492984661033571, 1, 0.10097135462612099`], 
     Hue[0.6486298611368391, 1, 0.10189711534899212`], 
     Hue[0.6479722666001381, 1, 0.10280763086134728`], 
     Hue[0.6474700106798329, 1, 0.10350306213561597`], 
     Hue[0.6471976417124167, 1, 0.10388018839819235`], 
     Hue[0.6472266389834024, 1, 0.10384003833067365`], 
     Hue[0.6474600972735775, 1, 0.10351678839043123`], 
     Hue[0.647787115327827, 1, 0.10306399416147033`], 
     Hue[0.6481847142239625, 1, 0.102513472612975], 
     Hue[0.6487288669092454, 1, 0.10176003043335265`], 
     Hue[0.6493225788760636, 1, 0.10093796771006586`], 
     Hue[0.6497492556366449, 1, 0.10034718450310709`], 
     Hue[0.6499384202733739, 1, 0.100085264236867], 
     Hue[0.6499907772481441, 1, 0.1000127699641082], 
     Hue[0.6499169408087975, 1, 0.10011500503397273`], 
     Hue[0.6496669893384682, 1, 0.10046109168519789`], 
     Hue[0.6491243836319389, 1, 0.10121239189423845`], 
     Hue[0.6483881105564229, 1, 0.10223184692187601`], 
     Hue[0.6476673319658686, 1, 0.10322984804725902`], 
     Hue[0.6470649192956847, 1, 0.10406395789828284`], 
     Hue[0.646492840332535, 1, 0.10485606723187464`], 
     Hue[0.6459052314226442, 1, 0.10566967956864651`], 
     Hue[0.6453175862656999, 1, 0.10648334209364638`], 
     Hue[0.6448171573227068, 1, 0.10717624370702135`], 
     Hue[0.6445346715615721, 1, 0.10756737783782327`], 
     Hue[0.6445187656805075, 1, 0.10758940136545116`], 
     Hue[0.6446754130693914, 1, 0.10737250498084282`], 
     Hue[0.6448217876435393, 1, 0.10716983249356107`], 
     Hue[0.6448213068073135, 1, 0.10717049826679662`], 
     Hue[0.6446747005057164, 1, 0.1073734916074697], 
     Hue[0.6445188584205228, 1, 0.1075892729561992], 
     Hue[0.6445356096358542, 1, 0.10756607896574033`], 
     Hue[0.6448183521045389, 1, 0.10717458939371549`], 
     Hue[0.6453186380742251, 1, 0.10648188574338074`], 
     Hue[0.6459060748044555, 1, 0.10566851180921547`], 
     Hue[0.646493455942218, 1, 0.10485521484923671`], 
     Hue[0.647065445798343, 1, 0.10406322889460198`], 
     Hue[0.6476782205548365, 1, 0.10321477153945717`], 
     Hue[0.6483883164107922, 1, 0.10223156189274935`], 
     Hue[0.6491243444061467, 1, 0.10121244620687372`], 
     Hue[0.6496669043016357, 1, 0.10046120942850455`], 
     Hue[0.6499169012778275, 1, 0.10011505976916191`], 
     Hue[0.6499872761827474, 1, 0.1000176175931189], 
     Hue[0.6499506956391089, 1, 0.10006826757661845`], 
     Hue[0.6497831131736972, 1, 0.1003003048364193], 
     Hue[0.6493577841898452, 1, 0.10088922189098354`], 
     Hue[0.6486206497020778, 1, 0.1019098696432769], 
     Hue[0.6476640151146004, 1, 0.10323444061055342`], 
     Hue[0.6466285838488163, 1, 0.10466811467086985`], 
     Hue[0.645563391991172, 1, 0.1061429957045311], 
     Hue[0.6443899338329055, 1, 0.10776778392366933`], 
     Hue[0.6427084326690079, 1, 0.11009601630445065`], 
     Hue[0.6393231015822478, 1, 0.11478339780919544`], 
     Hue[0.6320807432698805, 1, 0.1248112785493963], 
     Hue[0.6197500814765424, 1, 0.14188450257094132`], 
     Hue[0.6042150040102856, 1, 0.1633946098319123], 
     Hue[0.595075849977109, 1, 0.1760488231086183], 
     Hue[0.5950760330681816, 1, 0.17604856959790252`], 
     Hue[0.6051860768200773, 1, 0.162050047479893], 
     Hue[0.6197571630575969, 1, 0.14187469730486596`], 
     Hue[0.6320881314564221, 1, 0.12480104875264642`], 
     Hue[0.6393277909144098, 1, 0.11477690488774024`], 
     Hue[0.642710798643102, 1, 0.1100927403403204], 
     Hue[0.6443912491738061, 1, 0.10776596268242239`], 
     Hue[0.6455644065284103, 1, 0.10614159096066272`], 
     Hue[0.6466294094583147, 1, 0.10466697151925652`], 
     Hue[0.64766440059411, 1, 0.10323390686969391`], 
     Hue[0.6486204310728412, 1, 0.10191017236068144`], 
     Hue[0.6493571286681643, 1, 0.10089012953638786`], 
     Hue[0.6497827013349246, 1, 0.10030087507471992`], 
     Hue[0.6499505383206859, 1, 0.10006848540212712`], 
     Hue[0.649992836251731, 1, 0.10000991903606476`], 
     Hue[0.6499987880908246, 1, 0.10000167802808904`], 
     Hue[0.6497848661512465, 1, 0.10029787763673556`], 
     Hue[0.6493623255583317, 1, 0.10088293384231], 
     Hue[0.6485080528944187, 1, 0.10206577291542022`], 
     Hue[0.6471334129224147, 1, 0.1039691205689644], 
     Hue[0.4134396293934205, 1, 0.42754512853218696`], 
     Hue[0.36992357537943527`, 1, 0.48779812639770503`], 
     Hue[0.560364425850268, 1, 0.22411079497655204`], 
     Hue[0.6471333502188614, 1, 0.10396920738926879`], 
     Hue[0.6485074236435838, 1, 0.10206664418580709`], 
     Hue[0.649993719165779, 1, 0.10000869653969073`], 
     Hue[0.6499645347886048, 1, 0.1000491056773164], 
     Hue[0.6498452129760711, 1, 0.10021432049467077`], 
     Hue[0.6494626278600213, 1, 0.10074405373227828`], 
     Hue[0.42072780205667315`, 1, 0.41745381253691416`], 
     Hue[0.2794714163724129, 1, 0.6130395773305052], 
     Hue[0.27950127825763316`, 1, 0.6129982301048157], 
     Hue[0.4207460109307008, 1, 0.4174286002497989], 
     Hue[0.5442403811400227, 1, 0.24643639534458395`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.6498321507756425, 1, 0.10023240661834114`], 
     Hue[0.649132833376689, 1, 0.10120069224766141`], 
     Hue[0.6465876268599643, 1, 0.10472482434774179`], 
     Hue[0.6363436379563803, 1, 0.11890880898347347`], 
     Hue[0.5985789422584301, 1, 0.17119838764217368`], 
     Hue[0.5054107485799124, 1, 0.3002005019662751], 
     Hue[0.35056984491302934`, 1, 0.5145955993511901], 
     Hue[0.1920257274160761, 1, 0.7341182235777408], 
     Hue[0.07116385446886986, 1, 0.9014654322738725], 
     Hue[0.07116385446585693, 1, 0.9014654322780442], 
     Hue[0.19202572741530333`, 1, 0.7341182235788108], 
     Hue[0.35056984491472737`, 1, 0.514595599348839], 
     Hue[0.5054107485816628, 1, 0.3002005019638515], 
     Hue[0.5998737256253059, 1, 0.16940561067265333`], 
     Hue[0.6361358775824969, 1, 0.11919647719346589`], 
     Hue[0.6465876268599808, 1, 0.10472482434771889`], 
     Hue[0.6491923510353136, 1, 0.10111828318187349`], 
     Hue[0.6498321507756426, 1, 0.10023240661834108`], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6498549379809121, 1, 0.10020085510335255`], 
     Hue[0.6494782446417727, 1, 0.1007224304960071], 
     Hue[0.6484645052704198, 1, 0.10212606962557269`], 
     Hue[0.6459417553415037, 1, 0.10561910798868726`], 
     Hue[0.6384789975532839, 1, 0.11595215723391462`], 
     Hue[0.6131190636395967, 1, 0.1510659118836354], 
     Hue[0.5442403811387878, 1, 0.24643639534629383`], 
     Hue[0.4207460109293239, 1, 0.41742860025170536`], 
     Hue[0.27950127825713017`, 1, 0.6129982301055121], 
     Hue[0.1666401527254356, 1, 0.7692674808417046], 
     Hue[0.10995731692870991`, 1, 0.8477514073294786], 
     Hue[0.10993697241483547`, 1, 0.8477795766563816], 
     Hue[0.16660070648733238`, 1, 0.7693220987098475], 
     Hue[0.27947141637245565`, 1, 0.613039577330446], 
     Hue[0.4207278020584586, 1, 0.4174538125344419], 
     Hue[0.5438542150957212, 1, 0.24697108679053995`], 
     Hue[0.6131150084109688, 1, 0.15107152681558167`], 
     Hue[0.63847840811195, 1, 0.11595297338345392`], 
     Hue[0.6459425149453757, 1, 0.10561805622947988`], 
     Hue[0.6484656021364827, 1, 0.10212455088794703`], 
     Hue[0.6494626278600188, 1, 0.10074405373228157`], 
     Hue[0.6498553820677755, 1, 0.1002002402138493], 
     Hue[0.649968486457508, 1, 0.10004363413575816`], 
     Hue[0.6499947516409308, 1, 0.10000726695871127`], 
     Hue[0.6499993476936773, 1, 0.1000009031933699], 
     Hue[0.6499903637000147, 1, 0.10001334256921046`], 
     Hue[0.6499461593618887, 1, 0.1000745485758465], 
     Hue[0.6497870627427598, 1, 0.1002948362023327], 
     Hue[0.6493634059128109, 1, 0.10088143796687715`], 
     Hue[0.648507423643595, 1, 0.10206664418579148`], 
     Hue[0.6471333502188961, 1, 0.10396920738922087`], 
     Hue[0.6452024257204935, 1, 0.1066427951562399], 
     Hue[0.6421328552372216, 1, 0.11089296967153926`], 
     Hue[0.6342357357137098, 1, 0.12182744285794023`], 
     Hue[0.6113350077370074, 1, 0.15353614313337435`], 
     Hue[0.560364425850219, 1, 0.22411079497661998`], 
     Hue[0.48758898573082615`, 1, 0.3248767889880869], 
     Hue[0.4148630973140133, 1, 0.4255741729498278], 
     Hue[0.37117736989834854`, 1, 0.4860621032176713], 
     Hue[0.3699235753804618, 1, 0.4877981263962837], 
     Hue[0.41343962939488754`, 1, 0.4275451285301558], 
     Hue[0.48756298968034234`, 1, 0.324912783519526], 
     Hue[0.5613439013174827, 1, 0.22275459817579318`], 
     Hue[0.6113184040198557, 1, 0.15355913289558448`], 
     Hue[0.6343038838830553, 1, 0.12173308385423123`], 
     Hue[0.642130743574499, 1, 0.11089589351223221`], 
     Hue[0.6452016973298363, 1, 0.10664380369714979`], 
     Hue[0.6471334129224495, 1, 0.10396912056891615`], 
     Hue[0.64850805289443, 1, 0.10206577291540458`], 
     Hue[0.6493623255583336, 1, 0.1008829338423074], 
     Hue[0.6497848661512468, 1, 0.1002978776367353], 
     Hue[0.649946398470897, 1, 0.100074217501835], 
     Hue[0.6499902459174384, 1, 0.10001350565277761`], 
     Hue[0.6499988168962403, 1, 0.10000163814366736`], 
     Hue[0.649992836251731, 1, 0.10000991903606475`], 
     Hue[0.648620431072842, 1, 0.10191017236068038`], 
     Hue[0.6476644005941145, 1, 0.1032339068696878], 
     Hue[0.6466294094583313, 1, 0.10466697151923365`], 
     Hue[0.639183848053694, 1, 0.11497621038719294`], 
     Hue[0.593969696312709, 1, 0.17758042049009526`], 
     Hue[0.6042150040106946, 1, 0.16339460983134596`], 
     Hue[0.6466285838488328, 1, 0.10466811467084695`], 
     Hue[0.6476640151146048, 1, 0.10323444061054728`], 
     Hue[0.6486206497020786, 1, 0.10190986964327584`], 
     Hue[0.6493577841898455, 1, 0.10088922189098325`], 
     Hue[0.649124344406147, 1, 0.1012124462068735], 
     Hue[0.6483883164107923, 1, 0.10223156189274908`], 
     Hue[0.6476782205548369, 1, 0.10321477153945663`], 
     Hue[0.6470654457983444, 1, 0.10406322889460017`], 
     Hue[0.6464934559422207, 1, 0.10485521484923278`], 
     Hue[0.6459060748044588, 1, 0.10566851180921094`], 
     Hue[0.6439828956080353, 1, 0.10833137531195104`], 
     Hue[0.6459052314226476, 1, 0.10566967956864184`], 
     Hue[0.6464928403325377, 1, 0.10485606723187091`], 
     Hue[0.6470649192956857, 1, 0.10406395789828136`], 
     Hue[0.6483881105564231, 1, 0.10223184692187579`], 
     Hue[0.6491243836319391, 1, 0.10121239189423821`], 
     Hue[0.6496669893384683, 1, 0.10046109168519775`], 
     Hue[0.6499907772481441, 1, 0.1000127699641082], 
     Hue[0.6497492556366449, 1, 0.10034718450310712`], 
     Hue[0.6493225788760636, 1, 0.10093796771006587`], 
     Hue[0.6487288669092454, 1, 0.10176003043335262`], 
     Hue[0.6481847142239626, 1, 0.10251347261297492`], 
     Hue[0.6477871153278271, 1, 0.10306399416147023`], 
     Hue[0.6479722666001457, 1, 0.10280763086133675`], 
     Hue[0.6486298611368615, 1, 0.10189711534896101`], 
     Hue[0.64863081307338, 1, 0.10189579728301236`], 
     Hue[0.6479727326168283, 1, 0.10280698560746845`], 
     Hue[0.64744405493571, 1, 0.10353900085824778`], 
     Hue[0.647195477869171, 1, 0.10388318448884022`], 
     Hue[0.647234063588764, 1, 0.10382975810786524`], 
     Hue[0.64778679201793, 1, 0.10306444182132772`], 
     Hue[0.6481845887416956, 1, 0.10251364635765228`], 
     Hue[0.6487286338295367, 1, 0.10176035315910302`], 
     Hue[0.6493221359730589, 1, 0.10093858096038005`], 
     Hue[0.649985101517905, 1, 0.10002062866751625`], 
     Hue[0.6499293875019, 1, 0.1000977711512155], 
     Hue[0.64975855562808, 1, 0.10033430759188924`], 
     Hue[0.6494481187205927, 1, 0.10076414330994854`], 
     Hue[0.6490820712669709, 1, 0.10127097824573265`], 
     Hue[0.6487973060787215, 1, 0.10166526850638562`], 
     Hue[0.6486665440965278, 1, 0.10184632355865385`], 
     Hue[0.6486721421475294, 1, 0.10183857241111316`], 
     Hue[0.648875149937858, 1, 0.10155748470142736`], 
     Hue[0.6492205124027052, 1, 0.10107929051933136`], 
     Hue[0.6495955370911407, 1, 0.10056002556611295`], 
     Hue[0.6498247725796036, 1, 0.10024262258208744`], 
     Hue[0.6499395617051161, 1, 0.10008368379291611`], 
     Hue[0.649939804960482, 1, 0.10008334697779414`], 
     Hue[0.6498036739551808, 1, 0.10027183606205746`], 
     Hue[0.6495635854272817, 1, 0.10060426633145621`], 
     Hue[0.649221128254437, 1, 0.10107843780154885`], 
     Hue[0.6488754715936949, 1, 0.10155703933180717`], 
     Hue[0.6486721458807171, 1, 0.10183856724208408`], 
     Hue[0.6486615686527497, 1, 0.10185321263465427`], 
     Hue[0.6487943291253612, 1, 0.10166939044180771`], 
     Hue[0.6490732055840213, 1, 0.1012832538067398], 
     Hue[0.6494608701931662, 1, 0.10074648742484674`], 
     Hue[0.6497686522347683, 1, 0.10032032767493616`], 
     Hue[0.6499979189376313, 1, 0.1000028814709721], 
     Hue[0.6499989806170189, 1, 0.10000141145335847`], 
     Hue[0.6499936916833658, 1, 0.10000873459226267`], 
     Hue[0.6499720083241632, 1, 0.10003875770500482`], 
     Hue[0.6499210378689576, 1, 0.10010933218144337`], 
     Hue[0.6498289592233316, 1, 0.10023682569077165`], 
     Hue[0.6497500661969323, 1, 0.100346062188863], 
     Hue[0.6497201201157683, 1, 0.10038752599355166`], 
     Hue[0.6497442349944514, 1, 0.10035413616152887`], 
     Hue[0.6498175387315116, 1, 0.10025263867944555`], 
     Hue[0.6499045423782822, 1, 0.10013217209160924`], 
     Hue[0.6499635376940699, 1, 0.10005048626974944`], 
     Hue[0.6499895375823748, 1, 0.10001448642440418`], 
     Hue[0.6499978738704448, 1, 0.10000294387169176`], 
     Hue[0.6499996049868014, 1, 0.10000054694135192`], 
     Hue[0.6499996082984593, 1, 0.1000005423559795], 
     Hue[0.6499977154256198, 1, 0.10000316325683417`], 
     Hue[0.6499887115763905, 1, 0.10001563012499778`], 
     Hue[0.6499637194211009, 1, 0.10005023464770653`], 
     Hue[0.649904864696231, 1, 0.10013172580521862`], 
     Hue[0.6498178986902057, 1, 0.10025214027509985`], 
     Hue[0.6497444578897739, 1, 0.1003538275372362], 
     Hue[0.649720148386843, 1, 0.1003874868489867], 
     Hue[0.6497498661728607, 1, 0.10034633914526989`], 
     Hue[0.6498285638060286, 1, 0.10023737319165268`], 
     Hue[0.649917969520653, 1, 0.10011358066371126`], 
     Hue[0.6499735114284139, 1, 0.10003667648373475`], 
     Hue[0.6499943973499914, 1, 0.10000775751539649`], 
     Hue[0.6499991149582264, 1, 0.10000122544245589`], 
     Hue[0.6499998925666856, 1, 0.1000001487538201], 
     Hue[0.6499993476880973, 1, 0.10000090320109607`], 
     Hue[0.6499796318088381, 1, 0.10002820211083958`], 
     Hue[0.6499326287044422, 1, 0.10009328333231075`], 
     Hue[0.6498492997424695, 1, 0.10020866189504221`], 
     Hue[0.6497585093987792, 1, 0.10033437160169031`], 
     Hue[0.6497220759135403, 1, 0.10038481796586742`], 
     Hue[0.6497395116100092, 1, 0.10036067623229504`], 
     Hue[0.649807523533853, 1, 0.10026650587620367`], 
     Hue[0.6498948423987034, 1, 0.10014560283256452`], 
     Hue[0.6499875975622534, 1, 0.1000171726061106], 
     Hue[0.6499971946455725, 1, 0.10000388433689966`], 
     Hue[0.6499994854782605, 1, 0.10000071241471627`], 
     Hue[0.6499996718109462, 1, 0.10000045441561291`], 
     Hue[0.6499983476490149, 1, 0.10000228787059483`], 
     Hue[0.649992139261425, 1, 0.10001088409956545`], 
     Hue[0.6499711752825617, 1, 0.10003991114722234`], 
     Hue[0.6499202363144329, 1, 0.10011044202616999`], 
     Hue[0.649752335400284, 1, 0.10034292021499139`], 
     Hue[0.6497216053983531, 1, 0.10038546944843423`], 
     Hue[0.6497446269774029, 1, 0.10035359341590382`], 
     Hue[0.6498180333025885, 1, 0.10025195388872375`], 
     Hue[0.6499074536869546, 1, 0.10012814104883222`], 
     Hue[0.6499685517490378, 1, 0.10004354373210154`], 
     Hue[0.6499926102537842, 1, 0.10001023195629886`], 
     Hue[0.6499987684026548, 1, 0.10000170528863186`], 
     Hue[0.6499998525302062, 1, 0.10000020418894534`], 
     Hue[0.6492162512642067, 1, 0.1010851905572524], 
     Hue[0.6488750409140394, 1, 0.10155763565748406`], 
     Hue[0.6486943253197311, 1, 0.10180785724960313`], 
     Hue[0.6486561461999452, 1, 0.10186072064622981`], 
     Hue[0.6488059954277985, 1, 0.10165323709997136`], 
     Hue[0.6491243397305977, 1, 0.10121245268071086`], 
     Hue[0.6497589618188889, 1, 0.10033374517384615`], 
     Hue[0.6493814166270159, 1, 0.10085650005490117`], 
     Hue[0.6487415025304525, 1, 0.10174253495783511`], 
     Hue[0.6487385095926334, 1, 0.10174667902558458`], 
     Hue[0.6489651538469169, 1, 0.10143286390426902`], 
     Hue[0.6493262593973558, 1, 0.10093287160366125`], 
     Hue[0.6496859288220751, 1, 0.10043486778481912`], 
     Hue[0.6498879983365086, 1, 0.10015507922637275`], 
     Hue[0.6499728188455073, 1, 0.10003763544468221`], 
     Hue[0.6484785424654154, 1, 0.10210663350942493`], 
     Hue[0.6472376528774046, 1, 0.10382478832359364`], 
     Hue[0.6483004248350253, 1, 0.10235325792073424`], 
     Hue[0.6485590288669325, 1, 0.10199519079963201`], 
     Hue[0.6499925368181951, 1, 0.1000103336363452], 
     Hue[0.649956754063224, 1, 0.10005987898938219`], 
     Hue[0.6498201909540227, 1, 0.10024896637135326`], 
     Hue[0.6494380510073331, 1, 0.1007780832206157], 
     Hue[0.6486312945647095, 1, 0.10189513060270997`], 
     Hue[0.6472945453822478, 1, 0.10374601408611843`], 
     Hue[0.6454301116847382, 1, 0.10632753766728567`], 
     Hue[0.6425869541066359, 1, 0.11026421739081178`], 
     Hue[0.6355677813921327, 1, 0.11998307191858565`], 
     Hue[0.6150728538407967, 1, 0.14836066391274305`], 
     Hue[0.49721716070329236`, 1, 0.3115454697954414], 
     Hue[0.4218615510022992, 1, 0.41588400630450884`], 
     Hue[0.3732101372974441, 1, 0.48324750220353896`], 
     Hue[0.3699389649357174, 1, 0.48777681778131443`], 
     Hue[0.4092648191988564, 1, 0.43332563495542964`], 
     Hue[0.4799251869009553, 1, 0.3354882027525234], 
     Hue[0.5547703620061858, 1, 0.23185642183758892`], 
     Hue[0.6075419005407393, 1, 0.15878813771282255`], 
     Hue[0.6416071963746115, 1, 0.11162080501976875`], 
     Hue[0.6449363081981523, 1, 0.10701126557178922`], 
     Hue[0.6469167021582444, 1, 0.10426918162704622`], 
     Hue[0.6483449140191484, 1, 0.10229165751194842`], 
     Hue[0.64926118126401, 1, 0.1010229797882938], 
     Hue[0.6497487056715416, 1, 0.10034794599325009`], 
     Hue[0.6499334733653315, 1, 0.10009211380184876`], 
     Hue[0.6499871546152928, 1, 0.10001778591728701`], 
     Hue[0.6499982837325233, 1, 0.10000237637035238`], 
     Hue[0.6499821959348161, 1, 0.10002465178256237`], 
     Hue[0.6499097362338683, 1, 0.10012498059925928`], 
     Hue[0.649644480283586, 1, 0.10049225806888096`], 
     Hue[0.6488721916036004, 1, 0.10156158085655329`], 
     Hue[0.6468897902012477, 1, 0.10430644433673392`], 
     Hue[0.6412672325871528, 1, 0.11209152411009617`], 
     Hue[0.622513680397445, 1, 0.1380579809881531], 
     Hue[0.5682104334557424, 1, 0.2132470921382028], 
     Hue[0.31803818591230487`, 1, 0.5596394348906548], 
     Hue[0.12317793669702404`, 1, 0.8294459338041205], 
     Hue[0.10551553715041861`, 1, 0.8539015639455743], 
     Hue[0.1447215641964955, 1, 0.7996162957279294], 
     Hue[0.23867664284349838`, 1, 0.6695246483705407], 
     Hue[0.3752505842358355, 1, 0.48042226798115084`], 
     Hue[0.5105339839090244, 1, 0.2931067915105816], 
     Hue[0.6333039763672068, 1, 0.12311757118386749`], 
     Hue[0.6492133707832681, 1, 0.10108917891547486`], 
     Hue[0.3180381859125545, 1, 0.5596394348903092], 
     Hue[0.3732101372984604, 1, 0.48324750220213175`], 
     Hue[0.6486312945647198, 1, 0.10189513060269574`], 
     Hue[0.6499544789815872, 1, 0.10006302910241772`], 
     Hue[0.6497967031430824, 1, 0.10028148795573212`], 
     Hue[0.6493843083159343, 1, 0.10085249617793722`], 
     Hue[0.6486670765987007, 1, 0.10184558624795291`], 
     Hue[0.6477258602117323, 1, 0.10314880893760145`], 
     Hue[0.6466982385822283, 1, 0.10457166965537625`], 
     Hue[0.6456433109470764, 1, 0.10603233868866352`], 
     Hue[0.6444863018191712, 1, 0.10763435132730144`], 
     Hue[0.6428823803202537, 1, 0.10985516571041797`], 
     Hue[0.6397468996933413, 1, 0.11419660042460432`], 
     Hue[0.6330024607854741, 1, 0.12353505429703592`], 
     Hue[0.6211966685594903, 1, 0.13988153584070584`], 
     Hue[0.6066857938393038, 1, 0.15997351622250255`], 
     Hue[0.5959049495707341, 1, 0.17490083905590664`], 
     Hue[0.5947857583630093, 1, 0.17645048842044875`], 
     Hue[0.6039331393082432, 1, 0.16378488403474026`], 
     Hue[0.6189100178908061, 1, 0.14304766753580686`], 
     Hue[0.6314113814489777, 1, 0.12573808722449245`], 
     Hue[0.6389584142500591, 1, 0.1152883494999182], 
     Hue[0.6442963774518267, 1, 0.10789732352823997`], 
     Hue[0.6454878932078376, 1, 0.10624753248145569`], 
     Hue[0.6465464412567902, 1, 0.10478185056752126`], 
     Hue[0.6475834488846897, 1, 0.10334599385196813`], 
     Hue[0.6485590288669337, 1, 0.10199519079963026`], 
     Hue[0.6493199214653448, 1, 0.10094164720183028`], 
     Hue[0.6497651749073808, 1, 0.10032514243593434`], 
     Hue[0.6499450533801044, 1, 0.10007607993524002`], 
     Hue[0.6499916808511504, 1, 0.10001151882148406`], 
     Hue[0.6492714389145247, 1, 0.10100877688758128`], 
     Hue[0.6485711159572851, 1, 0.10197845482837452`], 
     Hue[0.6478481526586202, 1, 0.10297948093421831`], 
     Hue[0.6472169204860098, 1, 0.10385349471167885`], 
     Hue[0.646645752668982, 1, 0.10464434245833251`], 
     Hue[0.6460978666860392, 1, 0.10540295381933042`], 
     Hue[0.645489117970712, 1, 0.10624583665593737`], 
     Hue[0.6449758474344328, 1, 0.10695651893693928`], 
     Hue[0.6446057461859066, 1, 0.10746896681951394`], 
     Hue[0.6447269791201302, 1, 0.10730110583366587`], 
     Hue[0.6448143518714197, 1, 0.10718012817803428`], 
     Hue[0.6446386253954922, 1, 0.1074234417600878], 
     Hue[0.6444502281867962, 1, 0.1076842994336668], 
     Hue[0.6444285208655675, 1, 0.10771435572459899`], 
     Hue[0.6457420223619782, 1, 0.10589566134495336`], 
     Hue[0.646907408335789, 1, 0.10428204999659998`], 
     Hue[0.6481847608283471, 1, 0.10251340808382711`], 
     Hue[0.6489306887868329, 1, 0.10148058475669296`], 
     Hue[0.6495445652662334, 1, 0.1006306019390615], 
     Hue[0.6498702683563081, 1, 0.10017962842972729`], 
     Hue[0.6499710158419191, 1, 0.10004013191118907`], 
     Hue[0.6495311358384767, 1, 0.1006491965313401], 
     Hue[0.6483894496489137, 1, 0.10222999279381192`], 
     Hue[0.6479788895815404, 1, 0.10279846057940568`], 
     Hue[0.6475978994814844, 1, 0.10332598533332932`], 
     Hue[0.6473189778091604, 1, 0.10371218457193178`], 
     Hue[0.6471883956275422, 1, 0.10389299066955707`], 
     Hue[0.6473203313841714, 1, 0.10371031039114721`], 
     Hue[0.6484128933058474, 1, 0.10219753234574976`], 
     Hue[0.6490074389437255, 1, 0.1013743153086879], 
     Hue[0.6483004248350057, 1, 0.10235325792076135`], 
     Hue[0.6476512819636975, 1, 0.10325207112718815`], 
     Hue[0.647177909117925, 1, 0.10390751045210388`], 
     Hue[0.6476302589163752, 1, 0.1032811799619421], 
     Hue[0.6484785424654151, 1, 0.10210663350942516`], 
     Hue[0.6490374185577825, 1, 0.10133280507383965`], 
     Hue[0.6495774352447521, 1, 0.10058508966111258`], 
     Hue[0.6487415025304523, 1, 0.10174253495783539`], 
     Hue[0.6497589618188885, 1, 0.10033374517384669`], 
     Hue[0.6494842522907944, 1, 0.10071411221274619`], 
     Hue[0.6488059954277987, 1, 0.10165323709997108`], 
     Hue[0.6486943253197311, 1, 0.10180785724960309`], 
     Hue[0.6498071763115433, 1, 0.10026698664555554`], 
     Hue[0.649995513367399, 1, 0.10000621226052449`], 
     Hue[0.6499724972674363, 1, 0.10003808070662663`], 
     Hue[0.6498868726098938, 1, 0.10015663792476255`], 
     Hue[0.649675283084229, 1, 0.10044960803722157`], 
     Hue[0.6493256084315968, 1, 0.10093377294086604`], 
     Hue[0.6499730201144907, 1, 0.10003735676455142`], 
     Hue[0.6499119335839733, 1, 0.10012193811449863`], 
     Hue[0.6497610653711238, 1, 0.10033083256305937`], 
     Hue[0.64948661714491, 1, 0.10071083779935544`], 
     Hue[0.6499921940479368, 1, 0.10001080824131829`], 
     Hue[0.6499768211371815, 1, 0.10003209381005643`], 
     Hue[0.6499709311885555, 1, 0.1000402491235386], 
     Hue[0.6498762763822666, 1, 0.10017130962455392`], 
     Hue[0.6498541257365453, 1, 0.1002019797493988], 
     Hue[0.6495774352447521, 1, 0.10058508966111254`], 
     Hue[0.6495306842520321, 1, 0.10064982180487864`], 
     Hue[0.6476302589163754, 1, 0.10328117996194178`], 
     Hue[0.6475974574857244, 1, 0.10332659732745854`], 
     Hue[0.6473386224356845, 1, 0.10368498431982145`], 
     Hue[0.6473184531260556, 1, 0.10371291105623075`], 
     Hue[0.6471779091179248, 1, 0.10390751045210418`], 
     Hue[0.6471877544905419, 1, 0.1038938783977113], 
     Hue[0.6495118930856678, 1, 0.1006758403429215], 
     Hue[0.6494787147610555, 1, 0.1007217795616155], 
     Hue[0.6490601902829448, 1, 0.10130127499284564`], 
     Hue[0.6490063830516062, 1, 0.10137577731316069`], 
     Hue[0.6473203313841713, 1, 0.10371031039114739`], 
     Hue[0.6472745253097466, 1, 0.10377373418650476`], 
     Hue[0.6471883956275424, 1, 0.10389299066955672`], 
     Hue[0.6471785610476428, 1, 0.1039066077801869], 
     Hue[0.6499710158419191, 1, 0.10004013191118907`], 
     Hue[0.6499768885403957, 1, 0.10003200048252905`], 
     Hue[0.6472164168884309, 1, 0.10385419200063425`], 
     Hue[0.6469074083357877, 1, 0.10428204999660161`], 
     Hue[0.6466451819682585, 1, 0.10464513265933437`], 
     Hue[0.6460736462773871, 1, 0.10543648976977178`], 
     Hue[0.6457420223619759, 1, 0.10589566134495648`], 
     Hue[0.6454881245503626, 1, 0.10624721216103636`], 
     Hue[0.6449747057502719, 1, 0.10695809973039276`], 
     Hue[0.6446604067397317, 1, 0.10739328297575611`], 
     Hue[0.6444285208656477, 1, 0.10771435572448775`], 
     Hue[0.6446054156460634, 1, 0.10746942449006598`], 
     Hue[0.6444502281869823, 1, 0.10768429943340925`], 
     Hue[0.6444500571988938, 1, 0.10768453618614703`], 
     Hue[0.6446057461857632, 1, 0.10746896681971264`], 
     Hue[0.6444293000046112, 1, 0.10771327691669219`], 
     Hue[0.6446614119197257, 1, 0.10739189118807217`], 
     Hue[0.6499916808511504, 1, 0.10001151882148407`], 
     Hue[0.6465464412567721, 1, 0.10478185056754641`], 
     Hue[0.645642311937682, 1, 0.1060337219324404], 
     Hue[0.6444850252642972, 1, 0.10763611886481932`], 
     Hue[0.6428801433477171, 1, 0.10985826305700704`], 
     Hue[0.6397424833007631, 1, 0.11420271542971269`], 
     Hue[0.6211894469842212, 1, 0.13989153494492462`], 
     Hue[0.6456433109470441, 1, 0.10603233868870826`], 
     Hue[0.6465472957244812, 1, 0.10478066745841058`], 
     Hue[0.6466982385822131, 1, 0.10457166965539727`], 
     Hue[0.6493843083159341, 1, 0.10085249617793748`], 
     Hue[0.6497647458011401, 1, 0.10032573658303683`], 
     Hue[0.6499916431084579, 1, 0.1000115710805968], 
     Hue[0.6416047567879677, 1, 0.11162418290896782`], 
     Hue[0.6075239849977159, 1, 0.15881294384931657`], 
     Hue[0.5547429134967014, 1, 0.23189442746610583`], 
     Hue[0.479900588293155, 1, 0.33552226236332383`], 
     Hue[0.6454307554303194, 1, 0.10632664632725011`], 
     Hue[0.6444510447211244, 1, 0.10768316884767408`], 
     Hue[0.6334576495991543, 1, 0.12290479286270953`], 
     Hue[0.5972152565878802, 1, 0.1730865678013966], 
     Hue[0.510520851349772, 1, 0.2931249750541619], 
     Hue[0.6225162151471804, 1, 0.1380544713346734], 
     Hue[0.6412672295637734, 1, 0.11209152829631382`], 
     Hue[0.6488711177040362, 1, 0.10156306779441146`], 
     Hue[0.6496468100677274, 1, 0.10048903221391596`], 
     Hue[0.6499821551229769, 1, 0.1000247082912629], 
     Hue[0.6499973236426885, 1, 0.10000370572550824`], 
     Hue[0.6499997033584459, 1, 0.10000041073445946`], 
     Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
     Hue[0.6499998652875634, 1, 0.10000018652491231`], 
     Hue[0.6499997033584459, 1, 0.10000041073445946`], 
     Hue[0.6499986685807253, 1, 0.10000184350361113`], 
     Hue[0.6499973236426885, 1, 0.10000370572550824`], 
     Hue[0.6499903486487819, 1, 0.10001336340937898`], 
     Hue[0.6499821551229769, 1, 0.10002470829126286`], 
     Hue[0.6499471992776279, 1, 0.10007310869251526`], 
     Hue[0.649776996090499, 1, 0.10030877464392456`], 
     Hue[0.6496468100677264, 1, 0.10048903221391733`], 
     Hue[0.6488711177040118, 1, 0.10156306779444513`], 
     Hue[0.644379238729608, 1, 0.10778259252823516`], 
     Hue[0.6412672295634195, 1, 0.11209152829680384`], 
     Hue[0.633303976366686, 1, 0.12311757118458871`], 
     Hue[0.6225162151465272, 1, 0.13805447133557772`], 
     Hue[0.45983657272858763`, 1, 0.36330320699118634`], 
     Hue[0.5105208513514405, 1, 0.2931249750518516], 
     Hue[0.5682104334567659, 1, 0.21324709213678578`], 
     Hue[0.597215256588433, 1, 0.17308656780063125`], 
     Hue[0.6225136803974861, 1, 0.13805798098809613`], 
     Hue[0.6334576495989711, 1, 0.12290479286296306`], 
     Hue[0.6412672325869223, 1, 0.11209152411041531`], 
     Hue[0.6444510447209125, 1, 0.10768316884796729`], 
     Hue[0.6469167021582841, 1, 0.1042691816269912], 
     Hue[0.6454307554303608, 1, 0.10632664632719284`], 
     Hue[0.47990058829466425`, 1, 0.33552226236123417`], 
     Hue[0.5547429134976741, 1, 0.23189442746475897`], 
     Hue[0.6075239849981009, 1, 0.15881294384878336`], 
     Hue[0.6416047567879696, 1, 0.11162418290896522`], 
     Hue[0.6497647458011402, 1, 0.10032573658303669`], 
     Hue[0.6465472957244994, 1, 0.10478066745838548`], 
     Hue[0.6211894469844126, 1, 0.1398915349446595], 
     Hue[0.6397424833007785, 1, 0.11420271542969126`], 
     Hue[0.642880143347735, 1, 0.10985826305698225`], 
     Hue[0.6444850252643324, 1, 0.10763611886477051`], 
     Hue[0.6456423119377144, 1, 0.10603372193239556`], 
     Hue[0.644742260288362, 1, 0.10727994729303722`], 
     Hue[0.6444293000047064, 1, 0.10771327691656032`], 
     Hue[0.6444500571991165, 1, 0.10768453618583873`], 
     Hue[0.6446054156459392, 1, 0.10746942449023812`], 
     Hue[0.6446604067396938, 1, 0.10739328297580855`], 
     Hue[0.6449747057502663, 1, 0.10695809973040055`], 
     Hue[0.6454881245503643, 1, 0.10624721216103405`], 
     Hue[0.6460736462773897, 1, 0.10543648976976815`], 
     Hue[0.64664518196826, 1, 0.10464513265933222`], 
     Hue[0.6472164168884312, 1, 0.10385419200063364`], 
     Hue[0.6499768885403957, 1, 0.10003200048252905`], 
     Hue[0.6471785610476426, 1, 0.10390660778018722`], 
     Hue[0.6472745253097466, 1, 0.10377373418650467`], 
     Hue[0.6490063830516288, 1, 0.1013757773131294], 
     Hue[0.6494787147610784, 1, 0.1007217795615837], 
     Hue[0.6471877544905421, 1, 0.103893878397711], 
     Hue[0.6473184531260556, 1, 0.10371291105623072`], 
     Hue[0.6475974574857242, 1, 0.10332659732745883`], 
     Hue[0.6495306842520321, 1, 0.10064982180487868`], 
     Hue[0.6498541257365453, 1, 0.10020197974939882`], 
     Hue[0.6499709311885555, 1, 0.1000402491235386], 
     Hue[0.6499955545015644, 1, 0.10000615530552621`], 
     Hue[0.6499921940479368, 1, 0.10001080824131829`], 
     Hue[0.6493814166270158, 1, 0.10085650005490124`], 
     Hue[0.64948661714491, 1, 0.1007108377993554], 
     Hue[0.6496976408126721, 1, 0.10041865118245408`], 
     Hue[0.649761065371124, 1, 0.10033083256305912`], 
     Hue[0.6498799412726705, 1, 0.10016623516091785`], 
     Hue[0.6499119335839736, 1, 0.10012193811449815`], 
     Hue[0.64996159366688, 1, 0.10005317799970473`], 
     Hue[0.649973020114491, 1, 0.10003735676455103`], 
     Hue[0.6492162512642065, 1, 0.10108519055725261`], 
     Hue[0.6493256084315966, 1, 0.10093377294086624`], 
     Hue[0.6496752830842288, 1, 0.10044960803722168`], 
     Hue[0.6498432245869254, 1, 0.10021707364887249`], 
     Hue[0.6498868726098938, 1, 0.10015663792476259`], 
     Hue[0.64995742655059, 1, 0.10005894785302934`], 
     Hue[0.6499724972674363, 1, 0.10003808070662665`], 
     Hue[0.6499921293089566, 1, 0.10001089787990629`], 
     Hue[0.649995513367399, 1, 0.10000621226052449`], 
     Hue[0.6497523354002839, 1, 0.10034292021499154`], 
     Hue[0.6498071763115432, 1, 0.10026698664555568`], 
     Hue[0.6497585093987792, 1, 0.10033437160169033`], 
     Hue[0.6499996894548788, 1, 0.10000042998555234`], 
     Hue[0.6499976810908947, 1, 0.10000321079722264`], 
     Hue[0.6499735114284139, 1, 0.10003667648373474`], 
     Hue[0.6499875385469106, 1, 0.10001725431966231`], 
     Hue[0.6499179695206531, 1, 0.10011358066371122`], 
     Hue[0.6499510653458983, 1, 0.10006775567491014`], 
     Hue[0.6498285638060287, 1, 0.10023737319165262`], 
     Hue[0.6498754872667991, 1, 0.10017240224597054`], 
     Hue[0.6497844884994874, 1, 0.10029840053917119`], 
     Hue[0.6497525816504375, 1, 0.10034257925324044`], 
     Hue[0.6498178986902056, 1, 0.10025214027509997`], 
     Hue[0.6499979498338926, 1, 0.10000283869153345`], 
     Hue[0.6499990931632785, 1, 0.10000125562007593`], 
     Hue[0.6499895375823748, 1, 0.10001448642440418`], 
     Hue[0.6499952798767935, 1, 0.100006535555209], 
     Hue[0.6499635376940699, 1, 0.10005048626974943`], 
     Hue[0.6499797919710948, 1, 0.1000279803477149], 
     Hue[0.6499045423782823, 1, 0.10013217209160918`], 
     Hue[0.649938736749848, 1, 0.10008482603867201`], 
     Hue[0.6498175387315117, 1, 0.10025263867944541`], 
     Hue[0.6498625824888394, 1, 0.10019027040006855`], 
     Hue[0.6497220805506988, 1, 0.10038481154518639`], 
     Hue[0.6497587426645933, 1, 0.10033404861825541`], 
     Hue[0.6498289592233316, 1, 0.10023682569077172`], 
     Hue[0.6499991804292786, 1, 0.10000113479022964`], 
     Hue[0.6499617603399277, 1, 0.10005294722163856`], 
     Hue[0.6491240599696748, 1, 0.10121284004198873`], 
     Hue[0.6499852101793618, 1, 0.10002047821319134`], 
     Hue[0.6499298416416036, 1, 0.1000971423423951], 
     Hue[0.6499657096233139, 1, 0.10004747898310386`], 
     Hue[0.6497686522347684, 1, 0.10032032767493607`], 
     Hue[0.6498661528906174, 1, 0.10018532676683745`], 
     Hue[0.6494608701931663, 1, 0.10074648742484657`], 
     Hue[0.6496322047027856, 1, 0.1005092550269123], 
     Hue[0.6499817210220851, 1, 0.10002530935403611`], 
     Hue[0.6499395617051158, 1, 0.1000836837929167], 
     Hue[0.6498247725796032, 1, 0.10024262258208783`], 
     Hue[0.6498942532833839, 1, 0.10014641853069925`], 
     Hue[0.6495955370911406, 1, 0.10056002556611304`], 
     Hue[0.6497259877549593, 1, 0.1003794015700564], 
     Hue[0.6486592242610939, 1, 0.10185645871540853`], 
     Hue[0.6486985272829319, 1, 0.10180203914670968`], 
     Hue[0.6488858529817219, 1, 0.10154266510223128`], 
     Hue[0.6492168120882641, 1, 0.10108441403163439`], 
     Hue[0.6498347039214942, 1, 0.10022887149331575`], 
     Hue[0.6499576702370821, 1, 0.10005861044096336`], 
     Hue[0.6499659179555519, 1, 0.100047190523082], 
     Hue[0.6499745865383855, 1, 0.10003518786992782`], 
     Hue[0.6498668777824628, 1, 0.10018432307043619`], 
     Hue[0.6494794345021984, 1, 0.10072078299695619`], 
     Hue[0.64951254449455, 1, 0.1006749383921616], 
     Hue[0.6494921178874883, 1, 0.10070322138655469`], 
     Hue[0.6490365748044895, 1, 0.10133397334762992`], 
     Hue[0.6484128933058365, 1, 0.10219753234576491`], 
     Hue[0.6483395074792844, 1, 0.10229914349022172`], 
     Hue[0.6489814055841804, 1, 0.10141036149882726`], 
     Hue[0.6490500614364055, 1, 0.10131529954959236`], 
     Hue[0.6495311358384767, 1, 0.10064919653134007`], 
     Hue[0.6495778694437395, 1, 0.1005844884625145], 
     Hue[0.6498543989283845, 1, 0.10020160148377538`], 
     Hue[0.6498765165910504, 1, 0.10017097702777641`], 
     Hue[0.6499746602037513, 1, 0.10003508587172912`], 
     Hue[0.6490074389437478, 1, 0.10137431530865688`], 
     Hue[0.6490612179653654, 1, 0.1012998520479556], 
     Hue[0.6496523174518567, 1, 0.1004814066051215], 
     Hue[0.6477602551397625, 1, 0.10310118519109808`], 
     Hue[0.6476889012124347, 1, 0.10319998293662894`], 
     Hue[0.6473189778091605, 1, 0.10371218457193164`], 
     Hue[0.6473382110820157, 1, 0.1036855538864398], 
     Hue[0.6475978994814844, 1, 0.10332598533332936`], 
     Hue[0.6476306747916085, 1, 0.10328060413469597`], 
     Hue[0.6483894496489135, 1, 0.10222999279381198`], 
     Hue[0.648454805069711, 1, 0.10213950067270793`], 
     Hue[0.6472169204860091, 1, 0.10385349471167978`], 
     Hue[0.64784815265862, 1, 0.10297948093421863`], 
     Hue[0.6481850644702216, 1, 0.10251298765661626`], 
     Hue[0.6489327307650269, 1, 0.1014777574022705], 
     Hue[0.649870268356308, 1, 0.10017962842972737`], 
     Hue[0.6497422679611429, 1, 0.10035685974610997`], 
     Hue[0.6495445652662333, 1, 0.10063060193906168`], 
     Hue[0.6492714988092747, 1, 0.1010086939563889], 
     Hue[0.6446378483465082, 1, 0.1074245176740656], 
     Hue[0.6449758474344249, 1, 0.10695651893695021`], 
     Hue[0.6454891179707094, 1, 0.10624583665594087`], 
     Hue[0.6457429134754836, 1, 0.10589442749548424`], 
     Hue[0.6466457526689804, 1, 0.1046443424583349], 
     Hue[0.6469079421014989, 1, 0.10428131093638608`], 
     Hue[0.6499800978129978, 1, 0.10002755687431077`], 
     Hue[0.6498908903541091, 1, 0.10015107489431062`], 
     Hue[0.6497651749073807, 1, 0.10032514243593448`], 
     Hue[0.6493848462505366, 1, 0.10085175134541088`], 
     Hue[0.6450042018600114, 1, 0.10691725896306116`], 
     Hue[0.6436612706901785, 1, 0.10877670212129127`], 
     Hue[0.6413492538797367, 1, 0.11197795616651847`], 
     Hue[0.6363229297017741, 1, 0.11893748195138976`], 
     Hue[0.6264945721377247, 1, 0.13254597704007343`], 
     Hue[0.6123745783731487, 1, 0.15209673763717874`], 
     Hue[0.6444863018191366, 1, 0.10763435132734933`], 
     Hue[0.6460988378740803, 1, 0.10540160909742732`], 
     Hue[0.6471452171056709, 1, 0.10395277631522504`], 
     Hue[0.6477258602117284, 1, 0.10314880893760692`], 
     Hue[0.6485606730077377, 1, 0.1019929142969787], 
     Hue[0.6498906156449326, 1, 0.10015145526086258`], 
     Hue[0.6499800210545625, 1, 0.10002766315522109`], 
     Hue[0.6499272404251578, 1, 0.10010074402670452`], 
     Hue[0.5947858976871175, 1, 0.17645029551014493`], 
     Hue[0.5959049495699404, 1, 0.1749008390570056], 
     Hue[0.6039357705137042, 1, 0.16378124082717888`], 
     Hue[0.6211966685590604, 1, 0.13988153584130092`], 
     Hue[0.6386880733811215, 1, 0.11566266762613948`], 
     Hue[0.6428823803202386, 1, 0.10985516571043896`], 
     Hue[0.6442709715647295, 1, 0.10793250091037464`], 
     Hue[0.647305180926357, 1, 0.10373128794812109`], 
     Hue[0.6493194313649147, 1, 0.10094232580242588`], 
     Hue[0.6499964589486245, 1, 0.1000049029942124], 
     Hue[0.6421307435744927, 1, 0.11089589351224086`], 
     Hue[0.6439216662082725, 1, 0.10841615448085354`], 
     Hue[0.6392482971262327, 1, 0.11488697320983171`], 
     Hue[0.6113184040195201, 1, 0.1535591328960491], 
     Hue[0.6255259248970978, 1, 0.1338871809117108], 
     Hue[0.561343901316591, 1, 0.22275459817702792`], 
     Hue[0.5900825238500264, 1, 0.18296265928457897`], 
     Hue[0.487562989678903, 1, 0.324912783521519], 
     Hue[0.5262450270724396, 1, 0.2713530394381607], 
     Hue[0.3747741167538307, 1, 0.48108199218700365`], 
     Hue[0.49507930341202766`, 1, 0.3145055798910387], 
     Hue[0.6392520089619881, 1, 0.11488183374493961`], 
     Hue[0.643922915936966, 1, 0.1084144240872778], 
     Hue[0.6486346449067806, 1, 0.10189049166753458`], 
     Hue[0.649363405912809, 1, 0.10088143796687978`], 
     Hue[0.6497870627427595, 1, 0.10029483620233297`], 
     Hue[0.6496196896792591, 1, 0.10052658352102598`], 
     Hue[0.6499461593618886, 1, 0.10007454857584652`], 
     Hue[0.6498899253776141, 1, 0.1001524110156112], 
     Hue[0.6499763529684163, 1, 0.10003274204373136`], 
     Hue[0.6499964290356581, 1, 0.10000494441216566`], 
     Hue[0.64999986712212, 1, 0.10000018398475698`], 
     Hue[0.4598523370130971, 1, 0.36328137952032713`], 
     Hue[0.5682182330627773, 1, 0.21323629268230834`], 
     Hue[0.6479045331466449, 1, 0.10290141564310716`], 
     Hue[0.638478408112191, 1, 0.11595297338312012`], 
     Hue[0.6131150084107319, 1, 0.15107152681590974`], 
     Hue[0.5438542150943324, 1, 0.24697108679246285`], 
     Hue[0.23864305325628815`, 1, 0.6695711570297549], 
     Hue[0.14468550878889286`, 1, 0.7996662185999945], 
     Hue[0.12320664814348603`, 1, 0.8294061794936347], 
     Hue[0.1969400522797311, 1, 0.7273137737665262], 
     Hue[0.31924359861640145`, 1, 0.5579704019157519], 
     Hue[0.6468888344263154, 1, 0.10430776771740956`], 
     Hue[0.6484645052704583, 1, 0.10212606962551937`], 
     Hue[0.6494782446417755, 1, 0.10072243049600321`], 
     Hue[0.6490857182415478, 1, 0.1012659285886261], 
     Hue[0.6498549379809119, 1, 0.10020085510335289`], 
     Hue[0.6499692960032009, 1, 0.1000425132263373], 
     Hue[0.6499949427213864, 1, 0.10000700238577273`], 
     Hue[0.6499993787624871, 1, 0.1000008601750178], 
     Hue[0.6499999454587057, 1, 0.10000007551871525`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.6499289484739933, 1, 0.10009837903600931`], 
     Hue[0.6499289484739933, 1, 0.10009837903600931`], 
     Hue[0.6496234965987948, 1, 0.10052131240166877`], 
     Hue[0.6496234965987948, 1, 0.10052131240166878`], 
     Hue[0.26072995684113986`, 1, 0.6389892905276525], 
     Hue[0.26072995684113764`, 1, 0.6389892905276556], 
     Hue[0.12170305563831885`, 1, 0.8314880768084816], 
     Hue[0.12170305563831718`, 1, 0.8314880768084838], 
     Hue[0.033059327874478295`, 1, 0.9542255460199531], 
     Hue[0.03305932787447752, 1, 0.9542255460199542], 
     Hue[0.03305932787175303, 1, 0.9542255460237266], 
     Hue[0.03305932787175392, 1, 0.9542255460237254], 
     Hue[0.1217030556359836, 1, 0.831488076811715], 
     Hue[0.12170305563598527`, 1, 0.8314880768117127], 
     Hue[0.2607299568417166, 1, 0.6389892905268539], 
     Hue[0.26072995684171885`, 1, 0.6389892905268508], 
     Hue[0.4280417126324534, 1, 0.40732685943198765`], 
     Hue[0.4280417126324556, 1, 0.40732685943198454`], 
     Hue[0.559170544826714, 1, 0.22576386100916526`], 
     Hue[0.5591705448267154, 1, 0.22576386100916337`], 
     Hue[0.649623496598795, 1, 0.10052131240166846`], 
     Hue[0.649623496598795, 1, 0.10052131240166845`], 
     Hue[0.6499289484739933, 1, 0.1000983790360093], 
     Hue[0.6499289484739933, 1, 0.1000983790360093], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.5591705448254742, 1, 0.22576386101088186`], 
     Hue[0.5591705448254729, 1, 0.22576386101088372`], 
     Hue[0.42804171263043833`, 1, 0.40732685943477775`], 
     Hue[0.42804171263043606`, 1, 0.40732685943478086`], 
     Hue[0.6490857182415353, 1, 0.10126592858864356`], 
     Hue[0.6432968085982096, 1, 0.10928134194094068`], 
     Hue[0.6294670107067198, 1, 0.12843029286761867`], 
     Hue[0.5972214239233667, 1, 0.17307802841379993`], 
     Hue[0.5682182330616764, 1, 0.21323629268383273`], 
     Hue[0.510533983907657, 1, 0.2931067915124749], 
     Hue[0.45985233701165773`, 1, 0.3632813795223201], 
     Hue[0.3752505842345883, 1, 0.4804222679828778], 
     Hue[0.3192435986155256, 1, 0.5579704019169646], 
     Hue[0.2386766428429961, 1, 0.6695246483712362], 
     Hue[0.14472156419534377`, 1, 0.7996162957295241], 
     Hue[0.12320664814153293`, 1, 0.829406179496339], 
     Hue[0.12317793669330279`, 1, 0.8294459338092731], 
     Hue[0.14468550878552755`, 1, 0.7996662186046541], 
     Hue[0.23864305325551322`, 1, 0.6695711570308279], 
     Hue[0.6499999454587057, 1, 0.10000007551871525`], 
     Hue[0.6479034511561872, 1, 0.10290291378374081`], 
     Hue[0.6468888344261868, 1, 0.10430776771758747`], 
     Hue[0.10550699045016398`, 1, 0.8539133978382344], 
     Hue[0.6468897902011316, 1, 0.10430644433689479`], 
     Hue[0.6479045331465781, 1, 0.1029014156431996], 
     Hue[0.6488721916035768, 1, 0.10156158085658602`], 
     Hue[0.6499997070467911, 1, 0.10000040562752005`], 
     Hue[0.64999986712212, 1, 0.10000018398475698`], 
     Hue[0.6499964290356581, 1, 0.10000494441216566`], 
     Hue[0.6499763529684163, 1, 0.10003274204373135`], 
     Hue[0.6498899253776143, 1, 0.10015241101561112`], 
     Hue[0.6496196896792596, 1, 0.10052658352102511`], 
     Hue[0.6462369452811769, 1, 0.10521038345683198`], 
     Hue[0.6439229159369845, 1, 0.10841442408725223`], 
     Hue[0.6416071963745702, 1, 0.11162080501982595`], 
     Hue[0.6327196532761324, 1, 0.12392663392535516`], 
     Hue[0.5262450270736306, 1, 0.27135303943651146`], 
     Hue[0.5900825238506201, 1, 0.18296265928375688`], 
     Hue[0.6255259248972422, 1, 0.13388718091151078`], 
     Hue[0.6392482971262292, 1, 0.11488697320983655`], 
     Hue[0.6439216662083033, 1, 0.10841615448081084`], 
     Hue[0.6499964589486245, 1, 0.1000049029942124], 
     Hue[0.6492611812640128, 1, 0.1010229797882901], 
     Hue[0.6486346449067905, 1, 0.10189049166752093`], 
     Hue[0.6473051809263888, 1, 0.10373128794807712`], 
     Hue[0.6442709715647609, 1, 0.10793250091033112`], 
     Hue[0.5547703620062218, 1, 0.23185642183753913`], 
     Hue[0.49507930341255957`, 1, 0.31450557989030214`], 
     Hue[0.47992518690165575`, 1, 0.33548820275155355`], 
     Hue[0.4092648191999626, 1, 0.433325634953898], 
     Hue[0.37477411675478794`, 1, 0.48108199218567826`], 
     Hue[0.36993665875162945`, 1, 0.48778001095928225`], 
     Hue[0.6498201909540229, 1, 0.10024896637135305`], 
     Hue[0.6499272404251579, 1, 0.10010074402670448`], 
     Hue[0.6493848462505368, 1, 0.10085175134541062`], 
     Hue[0.6499800210545625, 1, 0.10002766315522107`], 
     Hue[0.6497827013349247, 1, 0.1003008750747198], 
     Hue[0.6498906156449327, 1, 0.10015145526086251`], 
     Hue[0.6493194313649149, 1, 0.10094232580242558`], 
     Hue[0.6485606730077386, 1, 0.10199291429697735`], 
     Hue[0.64714521710568, 1, 0.10395277631521234`], 
     Hue[0.6386880733811489, 1, 0.11566266762610168`], 
     Hue[0.6039357705144809, 1, 0.16378124082610337`], 
     Hue[0.6197500814767566, 1, 0.14188450257064478`], 
     Hue[0.6123745783734561, 1, 0.15209673763675313`], 
     Hue[0.6320807432699584, 1, 0.12481127854928835`], 
     Hue[0.626494572137861, 1, 0.1325459770398848], 
     Hue[0.6393231015822664, 1, 0.11478339780916977`], 
     Hue[0.6363229297018136, 1, 0.1189374819513351], 
     Hue[0.6427084326690243, 1, 0.11009601630442789`], 
     Hue[0.6413492538797488, 1, 0.1119779561665016], 
     Hue[0.64438993383294, 1, 0.10776778392362159`], 
     Hue[0.6436612706902045, 1, 0.10877670212125537`], 
     Hue[0.6450042018600488, 1, 0.10691725896300931`], 
     Hue[0.6499800978129978, 1, 0.10002755687431074`], 
     Hue[0.6481850644702218, 1, 0.10251298765661598`], 
     Hue[0.6469079421015004, 1, 0.10428131093638413`], 
     Hue[0.6492714988092749, 1, 0.10100869395638867`], 
     Hue[0.6497422679611429, 1, 0.10035685974610985`], 
     Hue[0.6499452847292683, 1, 0.10007575960562862`], 
     Hue[0.6499786432660215, 1, 0.10002957086243183`], 
     Hue[0.6489327307650271, 1, 0.10147775740227026`], 
     Hue[0.645742913475486, 1, 0.10589442749548096`], 
     Hue[0.6451848600758786, 1, 0.10666711681801426`], 
     Hue[0.6448183521045512, 1, 0.10717458939369848`], 
     Hue[0.6445356096359176, 1, 0.10756607896565253`], 
     Hue[0.6445188584207069, 1, 0.10758927295594438`], 
     Hue[0.6446378483467755, 1, 0.10742451767369551`], 
     Hue[0.6445187656803508, 1, 0.10758940136566814`], 
     Hue[0.6445346715615177, 1, 0.1075673778378987], 
     Hue[0.6448171573226968, 1, 0.1071762437070351], 
     Hue[0.6453175862657006, 1, 0.10648334209364543`], 
     Hue[0.6499872851621001, 1, 0.10001760516016903`], 
     Hue[0.6498765165910504, 1, 0.10017097702777644`], 
     Hue[0.6495778694437395, 1, 0.10058448846251454`], 
     Hue[0.6490500614364055, 1, 0.10131529954959238`], 
     Hue[0.648454805069711, 1, 0.1021395006727079], 
     Hue[0.6495125444945283, 1, 0.10067493839219152`], 
     Hue[0.6490612179653426, 1, 0.10129985204798726`], 
     Hue[0.6499746602037512, 1, 0.10003508587172912`], 
     Hue[0.6498671323084145, 1, 0.10018397064988765`], 
     Hue[0.6476306747916085, 1, 0.10328060413469592`], 
     Hue[0.6473382110820156, 1, 0.10368555388643992`], 
     Hue[0.6472266389834022, 1, 0.10384003833067391`], 
     Hue[0.6471976417124164, 1, 0.10388018839819263`], 
     Hue[0.6476889012124372, 1, 0.10319998293662551`], 
     Hue[0.6483395074792947, 1, 0.10229914349020733`], 
     Hue[0.6483775520143936, 1, 0.10224646644160888`], 
     Hue[0.6492984661033829, 1, 0.10097135462608528`], 
     Hue[0.6490365748045124, 1, 0.10133397334759822`], 
     Hue[0.6494921178875113, 1, 0.10070322138652285`], 
     Hue[0.6496153109565739, 1, 0.10053264636782082`], 
     Hue[0.6497438699910105, 1, 0.1003546415509085], 
     Hue[0.6499382721143278, 1, 0.10008546938016159`], 
     Hue[0.6498668777824628, 1, 0.10018432307043622`], 
     Hue[0.6499745865383855, 1, 0.10003518786992784`], 
     Hue[0.6499728188455073, 1, 0.10003763544468222`], 
     Hue[0.6499576702370821, 1, 0.10005861044096337`], 
     Hue[0.6498879983365086, 1, 0.10015507922637276`], 
     Hue[0.6498347039214942, 1, 0.10022887149331577`], 
     Hue[0.6494358636771683, 1, 0.10078111183161306`], 
     Hue[0.6497259877549595, 1, 0.10037940157005618`], 
     Hue[0.6498942532833842, 1, 0.10014641853069874`], 
     Hue[0.6499731374090267, 1, 0.10003719435673221`], 
     Hue[0.6499617603399274, 1, 0.10005294722163902`], 
     Hue[0.6496322047027855, 1, 0.10050925502691242`], 
     Hue[0.6498661528906173, 1, 0.1001853267668375], 
     Hue[0.6499657096233139, 1, 0.10004747898310387`], 
     Hue[0.6493262593973559, 1, 0.10093287160366116`], 
     Hue[0.6492168120882642, 1, 0.10108441403163429`], 
     Hue[0.648885852981722, 1, 0.10154266510223121`], 
     Hue[0.6487385095926334, 1, 0.10174667902558462`], 
     Hue[0.6486985272829319, 1, 0.10180203914670978`], 
     Hue[0.648661418574052, 1, 0.10185342043592793`], 
     Hue[0.6486592242610937, 1, 0.10185645871540881`], 
     Hue[0.6490246129733722, 1, 0.10135053588302306`], 
     Hue[0.6491240599696747, 1, 0.1012128400419889], 
     Hue[0.6499852500802348, 1, 0.10002042296582875`], 
     Hue[0.6497760637592552, 1, 0.10031006556410822`], 
     Hue[0.6498625824888393, 1, 0.10019027040006864`], 
     Hue[0.649938736749848, 1, 0.10008482603867204`], 
     Hue[0.6499797919710948, 1, 0.1000279803477149], 
     Hue[0.6499952798767935, 1, 0.100006535555209], 
     Hue[0.6499990931632785, 1, 0.10000125562007593`], 
     Hue[0.6497844884994874, 1, 0.10029840053917125`], 
     Hue[0.649875487266799, 1, 0.10017240224597061`], 
     Hue[0.6499510653458982, 1, 0.10006775567491018`], 
     Hue[0.6499875385469106, 1, 0.10001725431966232`], 
     Hue[0.6499976810908947, 1, 0.10000321079722264`], 
     Hue[0.6499996894548788, 1, 0.10000042998555234`], 
     Hue[0.6499991804292786, 1, 0.10000113479022964`], 
     Hue[0.6499685517490378, 1, 0.10004354373210152`], 
     Hue[0.6497587426645933, 1, 0.1003340486182554], 
     Hue[0.6497446269774028, 1, 0.10035359341590383`], 
     Hue[0.6497220805506987, 1, 0.10038481154518647`], 
     Hue[0.6499875780500365, 1, 0.1000171996230264], 
     Hue[0.6498075235338531, 1, 0.10026650587620353`], 
     Hue[0.6497525816504376, 1, 0.10034257925324029`], 
     Hue[0.6497395116100093, 1, 0.10036067623229489`], 
     Hue[0.6497444578897738, 1, 0.10035382753723637`], 
     Hue[0.649904864696231, 1, 0.10013172580521867`], 
     Hue[0.6499637194211009, 1, 0.10005023464770654`], 
     Hue[0.6497760637592553, 1, 0.10031006556410807`], 
     Hue[0.6497500661969323, 1, 0.100346062188863], 
     Hue[0.6499183291303126, 1, 0.10011308274264415`], 
     Hue[0.6499817845643631, 1, 0.10002522137242048`], 
     Hue[0.6499667588310659, 1, 0.10004602623390876`], 
     Hue[0.6494358636771684, 1, 0.10078111183161303`], 
     Hue[0.6486665440965279, 1, 0.10184632355865368`], 
     Hue[0.6487973060787215, 1, 0.10166526850638564`], 
     Hue[0.6490820712669708, 1, 0.10127097824573278`], 
     Hue[0.6498666614359694, 1, 0.10018462262711927`], 
     Hue[0.6494928049778546, 1, 0.10070227003066289`], 
     Hue[0.648377552014383, 1, 0.10224646644162362`], 
     Hue[0.6490171435581193, 1, 0.10136087815029625`], 
     Hue[0.6495581589251697, 1, 0.1006117799497651], 
     Hue[0.6498671323084145, 1, 0.10018397064988763`], 
     Hue[0.6473537923316887, 1, 0.10366397984843105`], 
     Hue[0.6480091049759611, 1, 0.10275662387943847`], 
     Hue[0.648755138205803, 1, 0.10172365479196505`], 
     Hue[0.6496095597971275, 1, 0.10054060951166957`], 
     Hue[0.6450053143732403, 1, 0.10691571856012894`], 
     Hue[0.6481572782578708, 1, 0.10255146087371726`], 
     Hue[0.6499764872407213, 1, 0.10003255612823204`], 
     Hue[0.3711773698973812, 1, 0.48606210321901067`], 
     Hue[0.41486309731293136`, 1, 0.42557417295132594`], 
     Hue[0.4875889857302076, 1, 0.32487678898894345`], 
     Hue[0.6255368322476673, 1, 0.13387207842630677`], 
     Hue[0.646236945281131, 1, 0.10521038345689565`], 
     Hue[0.64846560213652, 1, 0.10212455088789542`], 
     Hue[0.16660070649009112`, 1, 0.7693220987060277], 
     Hue[0.2153415771899569, 1, 0.7018347392754444], 
     Hue[0.10993697241880118`, 1, 0.8477795766508907], 
     Hue[0.13133504687222974`, 1, 0.8181514735615281], 
     Hue[0.10995731693131072`, 1, 0.8477514073258775], 
     Hue[0.1666401527260788, 1, 0.769267480840814], 
     Hue[0.1313694777282427, 1, 0.818103800068587], 
     Hue[0.2153784744292791, 1, 0.701783650790229], 
     Hue[0.3464112201430799, 1, 0.5203536951865048], 
     Hue[0.4873085045365856, 1, 0.32526514756472774`], 
     Hue[0.585623995432508, 1, 0.18913600632421984`], 
     Hue[0.6294670107072995, 1, 0.12843029286681606`], 
     Hue[0.6432968085985096, 1, 0.10928134194052527`], 
     Hue[0.6496234965987948, 1, 0.10052131240166877`], 
     Hue[0.2607299568411387, 1, 0.6389892905276541], 
     Hue[0.12170305563831796`, 1, 0.8314880768084828], 
     Hue[0.033059327871753474`, 1, 0.954225546023726], 
     Hue[0.12170305563598438`, 1, 0.831488076811714], 
     Hue[0.2607299568417177, 1, 0.6389892905268524], 
     Hue[0.4280417126324546, 1, 0.407326859431986], 
     Hue[0.5591705448267148, 1, 0.22576386100916412`], 
     Hue[0.649623496598795, 1, 0.10052131240166845`], 
     Hue[0.6499289484739933, 1, 0.1000983790360093], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.5856239954315277, 1, 0.18913600632557717`], 
     Hue[0.48730850453512964`, 1, 0.32526514756674363`], 
     Hue[0.3464112201419854, 1, 0.5203536951880203], 
     Hue[0.21537847442891117`, 1, 0.7017836507907383], 
     Hue[0.13136947772675878`, 1, 0.8181038000706417], 
     Hue[0.1313350468685427, 1, 0.8181514735666332], 
     Hue[0.2153415771885579, 1, 0.7018347392773814], 
     Hue[0.6392520089618953, 1, 0.11488183374506818`], 
     Hue[0.6255368322474537, 1, 0.1338720784266026], 
     Hue[0.6499764872407213, 1, 0.10003255612823203`], 
     Hue[0.6493571286681645, 1, 0.1008901295363876], 
     Hue[0.6481572782578727, 1, 0.10255146087371465`], 
     Hue[0.6460988378741058, 1, 0.10540160909739191`], 
     Hue[0.6450053143732773, 1, 0.10691571856007749`], 
     Hue[0.6320881314565716, 1, 0.12480104875243928`], 
     Hue[0.6197571630580532, 1, 0.14187469730423413`], 
     Hue[0.6051860768208408, 1, 0.16205004747883583`], 
     Hue[0.5950760330689806, 1, 0.17604856959679616`], 
     Hue[0.6496095597971278, 1, 0.10054060951166938`], 
     Hue[0.6498908903541091, 1, 0.10015107489431052`], 
     Hue[0.6487551382058032, 1, 0.1017236547919648], 
     Hue[0.6480091049759613, 1, 0.10275662387943818`], 
     Hue[0.6473537923316892, 1, 0.10366397984843027`], 
     Hue[0.6453186380742276, 1, 0.10648188574337719`], 
     Hue[0.6446747005059975, 1, 0.10737349160708046`], 
     Hue[0.6495581589251697, 1, 0.10061177994976514`], 
     Hue[0.6490171435581193, 1, 0.10136087815029626`], 
     Hue[0.6474600972735775, 1, 0.10351678839043126`], 
     Hue[0.6474700106798338, 1, 0.10350306213561476`], 
     Hue[0.6496149480434029, 1, 0.10053314886298056`], 
     Hue[0.6494928049778319, 1, 0.10070227003069426`], 
     Hue[0.6499659179555519, 1, 0.10004719052308203`], 
     Hue[0.6498666614359694, 1, 0.1001846226271193], 
     Hue[0.6499667588310656, 1, 0.10004602623390928`], 
     Hue[0.6499998944694872, 1, 0.10000014611917156`], 
     Hue[0.6495577101050631, 1, 0.10061240139298953`], 
     Hue[0.6499655367985427, 1, 0.10004771827894092`], 
     Hue[0.649965516562715, 1, 0.10004774629777938`], 
     Hue[0.6496090377308189, 1, 0.10054133237271227`], 
     Hue[0.6499997961154858, 1, 0.10000028230163507`], 
     Hue[0.6490867430856564, 1, 0.10126450957370664`], 
     Hue[0.6474954669797973, 1, 0.10346781495104992`], 
     Hue[0.6294650459019475, 1, 0.12843301336653418`], 
     Hue[0.6474944451681277, 1, 0.10346922976720777`], 
     Hue[0.6474944451680357, 1, 0.10346922976733522`], 
     Hue[0.629465045901841, 1, 0.12843301336668167`], 
     Hue[0.6474954669797108, 1, 0.1034678149511697], 
     Hue[0.649086743085644, 1, 0.1012645095737238], 
     Hue[0.6499997961154859, 1, 0.10000028230163507`], 
     Hue[0.6496090377308191, 1, 0.10054133237271208`], 
     Hue[0.649965516562715, 1, 0.10004774629777935`], 
     Hue[0.6499655367985427, 1, 0.1000477182789409], 
     Hue[0.649299395728952, 1, 0.1009700674522203], 
     Hue[0.6495577101050631, 1, 0.10061240139298959`], 
     Hue[0.649999546284906, 1, 0.10000062822089953`], 
     Hue[0.6499968016948423, 1, 0.10000442842252606`], 
     Hue[0.6499837977879257, 1, 0.10002243383210294`], 
     Hue[0.6499427464970976, 1, 0.10007927408094187`], 
     Hue[0.6498634854226076, 1, 0.10018902018408178`], 
     Hue[0.6499987777339871, 1, 0.10000169236832561`], 
     Hue[0.649993865184265, 1, 0.1000084943602484], 
     Hue[0.6499762536549267, 1, 0.10003287955471693`], 
     Hue[0.6499307068090907, 1, 0.1000959444181821], 
     Hue[0.6498518987975389, 1, 0.10020506320340776`], 
     Hue[0.6499921293089566, 1, 0.10001089787990629`], 
     Hue[0.6499882868309909, 1, 0.10001621823401269`], 
     Hue[0.64995742655059, 1, 0.10005894785302931`], 
     Hue[0.6498432245869256, 1, 0.10021707364887242`], 
     Hue[0.6497995501416562, 1, 0.10027754595770674`], 
     Hue[0.649510432152012, 1, 0.1006778631741373], 
     Hue[0.6499615936668796, 1, 0.1000531779997052], 
     Hue[0.6499507438872519, 1, 0.10006820077149742`], 
     Hue[0.6498799412726701, 1, 0.10016623516091826`], 
     Hue[0.6498506186895233, 1, 0.1002068356606601], 
     Hue[0.649697640812672, 1, 0.10041865118245424`], 
     Hue[0.6496397195744827, 1, 0.10049884981994704`], 
     Hue[0.6435492187575874, 1, 0.1089318509510328], 
     Hue[0.638324715551791, 1, 0.1161657784667509], 
     Hue[0.6228816248504861, 1, 0.1375485194377885], 
     Hue[0.584391631122217, 1, 0.1908423569076996], 
     Hue[0.5180120543224829, 1, 0.28275254016886997`], 
     Hue[0.649671307313124, 1, 0.10045511295105926`], 
     Hue[0.6499080428696402, 1, 0.10012732525742125`], 
     Hue[0.6499810990463154, 1, 0.10002617055125558`], 
     Hue[0.6479034511562572, 1, 0.10290291378364377`], 
     Hue[0.6481488635226674, 1, 0.10256311204553752`], 
     Hue[0.6497769960904989, 1, 0.10030877464392474`], 
     Hue[0.6498161665378681, 1, 0.10025453863987495`], 
     Hue[0.6499471992776278, 1, 0.10007310869251541`], 
     Hue[0.6499585389917856, 1, 0.10005740754983537`], 
     Hue[0.6499903486487819, 1, 0.100013363409379], 
     Hue[0.6499928350255395, 1, 0.10000992073386848`], 
     Hue[0.6499986685807253, 1, 0.10000184350361113`], 
     Hue[0.6499990728488086, 1, 0.10000128374780339`], 
     Hue[0.6499998652875634, 1, 0.10000018652491231`], 
     Hue[0.6499999130990606, 1, 0.10000012032437766`], 
     Hue[0.6499773681890932, 1, 0.10003133635356326`], 
     Hue[0.6498799739553269, 1, 0.10016618990800887`], 
     Hue[0.6139219345410782, 1, 0.14995424448158404`], 
     Hue[0.6276537703969349, 1, 0.13094093329655168`], 
     Hue[0.6369354292276365, 1, 0.11808940568481112`], 
     Hue[0.6416037038677826, 1, 0.11162564079845479`], 
     Hue[0.6437749675546234, 1, 0.10861927569359847`], 
     Hue[0.6499786571222672, 1, 0.10002955167686084`], 
     Hue[0.6499786571222672, 1, 0.10002955167686084`], 
     Hue[0.6498762763822666, 1, 0.10017130962455395`], 
     Hue[0.6499312334274999, 1, 0.10009521525423094`], 
     Hue[0.6499312334274999, 1, 0.10009521525423093`], 
     Hue[0.6499546249480828, 1, 0.10006282699496238`], 
     Hue[0.6499774540762749, 1, 0.10003121743285015`], 
     Hue[0.6442963774517934, 1, 0.1078973235282862], 
     Hue[0.6437749675545958, 1, 0.10861927569363655`], 
     Hue[0.6416037038677707, 1, 0.11162564079847141`], 
     Hue[0.6389584142500377, 1, 0.11528834949994783`], 
     Hue[0.6369354292276032, 1, 0.11808940568485717`], 
     Hue[0.6314113814488912, 1, 0.12573808722461224`], 
     Hue[0.6276537703968138, 1, 0.13094093329671944`], 
     Hue[0.6189100178905788, 1, 0.14304766753612178`], 
     Hue[0.6139219345407914, 1, 0.1499542444819813], 
     Hue[0.6498799739553269, 1, 0.10016618990800895`], 
     Hue[0.6499544789815872, 1, 0.10006302910241778`], 
     Hue[0.6499773681890932, 1, 0.10003133635356329`], 
     Hue[0.6355280494073535, 1, 0.12003808543597211`], 
     Hue[0.6499999130990606, 1, 0.10000012032437766`], 
     Hue[0.6499990728488086, 1, 0.10000128374780339`], 
     Hue[0.6499928350255395, 1, 0.10000992073386847`], 
     Hue[0.6499585389917857, 1, 0.10005740754983528`], 
     Hue[0.6498161665378682, 1, 0.1002545386398748], 
     Hue[0.6355280494071409, 1, 0.12003808543626643`], 
     Hue[0.6499871546152928, 1, 0.100017785917287], 
     Hue[0.6499810990463154, 1, 0.10002617055125557`], 
     Hue[0.6499334733653315, 1, 0.10009211380184872`], 
     Hue[0.6499080428696403, 1, 0.1001273252574212], 
     Hue[0.6497487056715419, 1, 0.10034794599324971`], 
     Hue[0.6496713073131244, 1, 0.10045511295105859`], 
     Hue[0.49721716070467614`, 1, 0.31154546979352543`], 
     Hue[0.518012054323759, 1, 0.28275254016710305`], 
     Hue[0.5843916311228773, 1, 0.1908423569067853], 
     Hue[0.615072853841081, 1, 0.14836066391234937`], 
     Hue[0.6228816248506646, 1, 0.13754851943754146`], 
     Hue[0.6355677813921563, 1, 0.11998307191855279`], 
     Hue[0.6383247155517915, 1, 0.11616577846675029`], 
     Hue[0.6425869541066501, 1, 0.11026421739079217`], 
     Hue[0.643549218757615, 1, 0.10893185095099478`], 
     Hue[0.6499546249480828, 1, 0.10006282699496233`], 
     Hue[0.6499774540762749, 1, 0.10003121743285012`], 
     Hue[0.6496397195744829, 1, 0.10049884981994692`], 
     Hue[0.6498506186895235, 1, 0.10020683566065973`], 
     Hue[0.6499507438872523, 1, 0.10006820077149693`], 
     Hue[0.6495104321520119, 1, 0.10067786317413745`], 
     Hue[0.6497995501416562, 1, 0.10027754595770683`], 
     Hue[0.6499882868309909, 1, 0.10001621823401269`], 
     Hue[0.6498383027784683, 1, 0.10022388846058239`], 
     Hue[0.6498518987975388, 1, 0.10020506320340787`], 
     Hue[0.6499202363144327, 1, 0.10011044202617005`], 
     Hue[0.6499307068090907, 1, 0.10009594441818215`], 
     Hue[0.6499711752825617, 1, 0.10003991114722235`], 
     Hue[0.6499762536549267, 1, 0.10003287955471694`], 
     Hue[0.649992139261425, 1, 0.10001088409956545`], 
     Hue[0.649993865184265, 1, 0.1000084943602484], 
     Hue[0.6499983476490149, 1, 0.10000228787059483`], 
     Hue[0.6499987777339871, 1, 0.10000169236832561`], 
     Hue[0.6498492997424695, 1, 0.10020866189504228`], 
     Hue[0.6498634854226075, 1, 0.10018902018408185`], 
     Hue[0.6499326287044422, 1, 0.1000932833323108], 
     Hue[0.6499427464970975, 1, 0.10007927408094192`], 
     Hue[0.6499796318088381, 1, 0.1000282021108396], 
     Hue[0.6499837977879257, 1, 0.10002243383210295`], 
     Hue[0.6499968016948423, 1, 0.10000442842252608`], 
     Hue[0.6499993476880973, 1, 0.10000090320109607`], 
     Hue[0.649999546284906, 1, 0.10000062822089954`], 
     Hue[0.6499786571222672, 1, 0.10002955167686085`], 
     Hue[0.6499786571222672, 1, 0.10002955167686085`], 
     Hue[0.6499872851621001, 1, 0.10001760516016904`], 
     Hue[0.6499786432660215, 1, 0.10002957086243185`], 
     Hue[0.6499786432660215, 1, 0.10002957086243186`], 
     Hue[0.6481499757638406, 1, 0.10256157201929773`], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499999994667391, 1, 0.10000000073836127`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6499999860214585, 1, 0.10000001935490364`], 
     Hue[0.6481488635226095, 1, 0.10256311204561763`], 
     Hue[0.6481499757637851, 1, 0.10256157201937459`], 
     Hue[0.6499786432660215, 1, 0.10002957086243183`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.6499999936474662, 1, 0.10000000879581607`], 
     Hue[0.649744463028524, 1, 0.10035382042204373`], 
     Hue[0.6497201483868429, 1, 0.1003874868489868], 
     Hue[0.6497393167031356, 1, 0.10036094610335085`], 
     Hue[0.6497201201157683, 1, 0.10038752599355157`], 
     Hue[0.6499731374090271, 1, 0.10003719435673182`], 
     Hue[0.649978584567043, 1, 0.10002965213794048`], 
     Hue[0.64932693666548, 1, 0.10093193384779686`], 
     Hue[0.6496050201873916, 1, 0.10054689512515011`], 
     Hue[0.6496046189157265, 1, 0.10054745073207098`], 
     Hue[0.6498226656875891, 1, 0.1002455398171844], 
     Hue[0.6497422006045631, 1, 0.10035695300906647`], 
     Hue[0.6498702084125652, 1, 0.10017971142875598`], 
     Hue[0.6448140890407267, 1, 0.10718049209745545`], 
     Hue[0.6492714389145245, 1, 0.1010087768875815], 
     Hue[0.6495444786347686, 1, 0.10063072189032049`], 
     Hue[0.635809914745834, 1, 0.11964781035192219`], 
     Hue[0.6499450533801044, 1, 0.10007607993524008`], 
     Hue[0.6498987693663225, 1, 0.10014016549278425`], 
     Hue[0.6499448820990992, 1, 0.10007631709355506`], 
     Hue[0.6498985097083886, 1, 0.10014052501915438`], 
     Hue[0.6499999143695201, 1, 0.1000001185652799], 
     Hue[0.6227153440039659, 1, 0.13777875445604731`], 
     Hue[0.6227153440039653, 1, 0.13777875445604798`], 
     Hue[0.00856416289874995, 1, 0.9881419282940385], 
     Hue[0.008564162897155558, 1, 0.9881419282962461], 
     Hue[0.6227153440043187, 1, 0.13777875445555868`], 
     Hue[0.6227153440043193, 1, 0.13777875445555793`], 
     Hue[0.6430994341870176, 1, 0.10955462958720644`], 
     Hue[0.6430994341870178, 1, 0.10955462958720621`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6430994341869646, 1, 0.10955462958727985`], 
     Hue[0.6430994341869645, 1, 0.10955462958728006`], 
     Hue[0.008564162898749617, 1, 0.988141928294039], 
     Hue[0.008564162897156002, 1, 0.9881419282962455], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.6499995584935135, 1, 0.10000061131667352`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499766495074196, 1, 0.10003233145126517`], 
     Hue[0.6499993787624871, 1, 0.1000008601750178], 
     Hue[0.6499949427213864, 1, 0.10000700238577273`], 
     Hue[0.649969296003201, 1, 0.10004251322633723`], 
     Hue[0.6499999143695201, 1, 0.1000001185652799], 
     Hue[0.6499924815348365, 1, 0.10001041018253413`], 
     Hue[0.649995066268984, 1, 0.10000683131986839`], 
     Hue[0.6326369084383063, 1, 0.12404120370080668`], 
     Hue[0.6278460623886941, 1, 0.13067468284642353`], 
     Hue[0.6498702084125652, 1, 0.10017971142875591`], 
     Hue[0.6495444786347687, 1, 0.10063072189032032`], 
     Hue[0.6499872761827475, 1, 0.1000176175931189], 
     Hue[0.649822601052624, 1, 0.1002456293117514], 
     Hue[0.6494794345021757, 1, 0.10072078299698756`], 
     Hue[0.649327839891267, 1, 0.10093068322747661`], 
     Hue[0.6499785002992394, 1, 0.10002976881643783`], 
     Hue[0.6499785845670428, 1, 0.10002965213794081`], 
     Hue[0.6499145448836653, 1, 0.10011832246877123`], 
     Hue[0.6499298416416035, 1, 0.10009714234239513`], 
     Hue[0.6499807313906684, 1, 0.10002667961292078`], 
     Hue[0.6499852101793618, 1, 0.10002047821319135`], 
     Hue[0.6499875143105937, 1, 0.10001728787763953`], 
     Hue[0.6499844331418096, 1, 0.10002155411134056`], 
     Hue[0.649997177936394, 1, 0.10000390747268527`], 
     Hue[0.6499994806519499, 1, 0.10000071909730011`], 
     Hue[0.6499992967751281, 1, 0.10000097369597646`], 
     Hue[0.6499924900042139, 1, 0.10001039845570384`], 
     Hue[0.6499902455567598, 1, 0.10001350615217874`], 
     Hue[0.649998744591033, 1, 0.10000173825856974`], 
     Hue[0.649998257978814, 1, 0.10000241202933446`], 
     Hue[0.6499998499361392, 1, 0.10000020778073027`], 
     Hue[0.6499997756993264, 1, 0.10000031057016343`], 
     Hue[0.6497393167031354, 1, 0.100360946103351], 
     Hue[0.6497220759135403, 1, 0.10038481796586733`], 
     Hue[0.649744463028524, 1, 0.10035382042204372`], 
     Hue[0.6447602379004875, 1, 0.10725505521470961`], 
     Hue[0.6445860308483407, 1, 0.1074962649792206], 
     Hue[0.6499987762295317, 1, 0.10000169445141766`], 
     Hue[0.6499972833772172, 1, 0.1000037614776993], 
     Hue[0.622715344004319, 1, 0.1377787544555582], 
     Hue[0.6430994341870176, 1, 0.1095546295872063], 
     Hue[0.6455633919912057, 1, 0.10614299570448438`], 
     Hue[0.6499169012778275, 1, 0.10011505976916187`], 
     Hue[0.6499452554080252, 1, 0.10007580020427294`], 
     Hue[0.6499452554080252, 1, 0.10007580020427294`], 
     Hue[0.6448213068074805, 1, 0.10717049826656548`], 
     Hue[0.6447602379007439, 1, 0.10725505521435462`], 
     Hue[0.6450472715451144, 1, 0.106857624014457], 
     Hue[0.6473532864649093, 1, 0.10366468027935632`], 
     Hue[0.6474596176061951, 1, 0.10351745254526841`], 
     Hue[0.649990745780477, 1, 0.10001281353472413`], 
     Hue[0.6499768211371815, 1, 0.10003209381005643`], 
     Hue[0.6499892906359471, 1, 0.10001482835022706`], 
     Hue[0.6499848496426992, 1, 0.10002097741780107`], 
     Hue[0.6499997433419163, 1, 0.10000035537273122`], 
     Hue[0.6497498661728607, 1, 0.10034633914526987`], 
     Hue[0.6498629460993739, 1, 0.10018976693932853`], 
     Hue[0.6497442349944516, 1, 0.10035413616152872`], 
     Hue[0.6498758963289264, 1, 0.10017183585225574`], 
     Hue[0.6499979396020884, 1, 0.10000285285864687`], 
     Hue[0.649985101517905, 1, 0.10002062866751625`], 
     Hue[0.6499883785355535, 1, 0.10001609125846449`], 
     Hue[0.649990745780477, 1, 0.10001281353472413`], 
     Hue[0.6499893270949103, 1, 0.10001477786858572`], 
     Hue[0.6450484170872981, 1, 0.1068560378791257], 
     Hue[0.647353286464909, 1, 0.10366468027935681`], 
     Hue[0.645047271545117, 1, 0.10685762401445344`], 
     Hue[0.6451837682394984, 1, 0.10666862859146373`], 
     Hue[0.6451837682394984, 1, 0.10666862859146374`], 
     Hue[0.644586417592649, 1, 0.10749572948710148`], 
     Hue[0.644643854407393, 1, 0.1074162015897635], 
     Hue[0.6265023909903372, 1, 0.13253515093645618`], 
     Hue[0.6499928687028823, 1, 0.10000987410370149`], 
     Hue[0.6498802677343509, 1, 0.10016578313705254`], 
     Hue[0.6499902459174384, 1, 0.10001350565277763`], 
     Hue[0.649998299585341, 1, 0.10000235442029706`], 
     Hue[0.649997307226403, 1, 0.10000372845574963`], 
     Hue[0.6452024257204503, 1, 0.10664279515629968`], 
     Hue[0.6421328552372512, 1, 0.11089296967149839`], 
     Hue[0.6425888456319614, 1, 0.11026159835574584`], 
     Hue[0.6435506515418182, 1, 0.10892986709594407`], 
     Hue[0.6459425149455353, 1, 0.10561805622925885`], 
     Hue[0.6384789975537194, 1, 0.11595215723331168`], 
     Hue[0.6227153440039657, 1, 0.13777875445604756`], 
     Hue[0.6499987762295317, 1, 0.10000169445141764`], 
     Hue[0.6425888456319463, 1, 0.11026159835576668`], 
     Hue[0.6435506515418299, 1, 0.10892986709592786`], 
     Hue[0.649997307226403, 1, 0.10000372845574962`], 
     Hue[0.6455644065284439, 1, 0.10614159096061612`], 
     Hue[0.6497831131736973, 1, 0.10030030483641918`], 
     Hue[0.649880267734351, 1, 0.10016578313705246`], 
     Hue[0.6499928687028823, 1, 0.10000987410370148`], 
     Hue[0.6265023909906217, 1, 0.13253515093606227`], 
     Hue[0.6446438544074229, 1, 0.1074162015897222], 
     Hue[0.6445864175924402, 1, 0.10749572948739058`], 
     Hue[0.645048417087303, 1, 0.10685603787911896`], 
     Hue[0.6499893270949103, 1, 0.10001477786858572`], 
     Hue[0.6499883785355535, 1, 0.10001609125846449`], 
     Hue[0.6499979396020884, 1, 0.10000285285864687`], 
     Hue[0.6498758963289265, 1, 0.10017183585225567`], 
     Hue[0.6498629460993739, 1, 0.10018976693932845`], 
     Hue[0.649998744591033, 1, 0.10000173825856974`], 
     Hue[0.649998257978814, 1, 0.10000241202933446`], 
     Hue[0.6499998499361392, 1, 0.10000020778073027`], 
     Hue[0.6499997756993264, 1, 0.10000031057016343`], 
     Hue[0.6499924900042139, 1, 0.10001039845570384`], 
     Hue[0.6499902455567599, 1, 0.10001350615217873`], 
     Hue[0.6499985526901774, 1, 0.10000200396744671`], 
     Hue[0.6499680543081146, 1, 0.10004423249645675`], 
     Hue[0.6499611431173056, 1, 0.1000538018375769], 
     Hue[0.6499915553675152, 1, 0.10001169256805592`], 
     Hue[0.6499070733798012, 1, 0.10012866762796759`], 
     Hue[0.6498941642091621, 1, 0.10014654186423702`], 
     Hue[0.6499389913540884, 1, 0.10008447350972374`], 
     Hue[0.6499994806519499, 1, 0.10000071909730011`], 
     Hue[0.6499992967751281, 1, 0.10000097369597646`], 
     Hue[0.649997177936394, 1, 0.10000390747268527`], 
     Hue[0.6499994103243372, 1, 0.1000008164739948], 
     Hue[0.6499875143105937, 1, 0.10001728787763953`], 
     Hue[0.6499844331418096, 1, 0.10002155411134056`], 
     Hue[0.6499968070349429, 1, 0.1000044210285406], 
     Hue[0.6499579058346595, 1, 0.10005828422893295`], 
     Hue[0.6499502404150022, 1, 0.10006889788692015`], 
     Hue[0.6499861817897984, 1, 0.1000191329064331], 
     Hue[0.6498945035414182, 1, 0.10014607201957478`], 
     Hue[0.6498817551107648, 1, 0.10016372369278713`], 
     Hue[0.6499513388525884, 1, 0.10006737697333923`], 
     Hue[0.6499990165514296, 1, 0.10000136169802062`], 
     Hue[0.6499997133311914, 1, 0.10000039692604273`], 
     Hue[0.6499807313906684, 1, 0.10002667961292076`], 
     Hue[0.6499971170968787, 1, 0.10000399171201411`], 
     Hue[0.6499145448836653, 1, 0.10011832246877118`], 
     Hue[0.6499785002992391, 1, 0.10002976881643814`], 
     Hue[0.6499763120114476, 1, 0.10003279875338034`], 
     Hue[0.6499569735915823, 1, 0.1000595750270399], 
     Hue[0.6499305639619215, 1, 0.1000961422065702], 
     Hue[0.6499223977301635, 1, 0.1001074492966967], 
     Hue[0.6499682293104805, 1, 0.10004399018548857`], 
     Hue[0.6498038432915924, 1, 0.10027160159625682`], 
     Hue[0.6497842792878259, 1, 0.10029869021685645`], 
     Hue[0.6499293875019, 1, 0.10009777115121549`], 
     Hue[0.6499955545015644, 1, 0.1000061553055262], 
     Hue[0.6499971445555819, 1, 0.10000395369227129`], 
     Hue[0.6499942337059641, 1, 0.10000798409943434`], 
     Hue[0.6499848496426992, 1, 0.10002097741780107`], 
     Hue[0.6499313963608999, 1, 0.10009498965413854`], 
     Hue[0.6499452847292683, 1, 0.10007575960562864`], 
     Hue[0.6499452847292683, 1, 0.10007575960562864`], 
     Hue[0.6450730162623394, 1, 0.10682197748291483`], 
     Hue[0.6450730162623393, 1, 0.10682197748291483`], 
     Hue[0.6451848600758754, 1, 0.10666711681801869`], 
     Hue[0.6451848600758754, 1, 0.10666711681801869`], 
     Hue[0.6363290967524772, 1, 0.11892894295810859`], 
     Hue[0.6454889217763025, 1, 0.10624610830973502`], 
     Hue[0.649946398470897, 1, 0.10007421750183504`], 
     Hue[0.6499872378397605, 1, 0.10001767068340861`], 
     Hue[0.6499812127959619, 1, 0.10002601305174517`], 
     Hue[0.6123798420897374, 1, 0.15208944941420982`], 
     Hue[0.6314188285390657, 1, 0.1257277758689859], 
     Hue[0.6276615081556854, 1, 0.13093021947674333`], 
     Hue[0.6342357357138686, 1, 0.12182744285772036`], 
     Hue[0.6355735873344104, 1, 0.1199750329215857], 
     Hue[0.6383290297329686, 1, 0.11615980498512041`], 
     Hue[0.6499951048581283, 1, 0.10000677788874544`], 
     Hue[0.6326369084382553, 1, 0.12404120370087737`], 
     Hue[0.6278460623885795, 1, 0.1306746828465822], 
     Hue[0.6498198123292013, 1, 0.10024949062110598`], 
     Hue[0.649865897701864, 1, 0.10018568010511139`], 
     Hue[0.6499924815348365, 1, 0.10001041018253413`], 
     Hue[0.649995066268984, 1, 0.10000683131986839`], 
     Hue[0.6499694960336534, 1, 0.10004223626109528`], 
     Hue[0.6131190636403478, 1, 0.15106591188259538`], 
     Hue[0.6459417553416843, 1, 0.10561910798843711`], 
     Hue[0.6495806066420243, 1, 0.10058069849565873`], 
     Hue[0.6499766495074196, 1, 0.10003233145126522`], 
     Hue[0.6498880939419247, 1, 0.10015494684964274`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499969194200786, 1, 0.10000426541835268`], 
     Hue[0.6499870926215222, 1, 0.10001787175481543`], 
     Hue[0.6499995584935135, 1, 0.10000061131667352`], 
     Hue[0.6499989198255313, 1, 0.10000149562618747`], 
     Hue[0.6499996498839958, 1, 0.10000048477600589`], 
     Hue[0.6499981583263428, 1, 0.10000255000967932`], 
     Hue[0.6499998959071556, 1, 0.10000014412855386`], 
     Hue[0.6499998069333369, 1, 0.10000026732307205`], 
     Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.018968293162061722`, 1, 0.9737362094679146], 
     Hue[0.0021628179027943784`, 1, 0.9970053290576693], 
     Hue[0.0021628179019673732`, 1, 0.9970053290588143], 
     Hue[0.01896829315981796, 1, 0.9737362094710212], 
     Hue[0.6499999419197341, 1, 0.1000000804188298], 
     Hue[0.6499998069333369, 1, 0.10000026732307205`], 
     Hue[0.6499981583263428, 1, 0.10000255000967932`], 
     Hue[0.6499870926215222, 1, 0.10001787175481541`], 
     Hue[0.6498880939419249, 1, 0.10015494684964242`], 
     Hue[0.6495806066420229, 1, 0.10058069849566069`], 
     Hue[0.6499996498839958, 1, 0.10000048477600589`], 
     Hue[0.6499989198255313, 1, 0.10000149562618747`], 
     Hue[0.6499998959071556, 1, 0.10000014412855386`], 
     Hue[0.6499969194200786, 1, 0.10000426541835268`], 
     Hue[0.6499982837325233, 1, 0.10000237637035238`], 
     Hue[0.6499972833772172, 1, 0.1000037614776993], 
     Hue[0.6499694960336535, 1, 0.10004223626109526`], 
     Hue[0.6498198123292014, 1, 0.10024949062110579`], 
     Hue[0.6498658977018641, 1, 0.10018568010511128`], 
     Hue[0.6355735873342693, 1, 0.11997503292178105`], 
     Hue[0.6383290297328634, 1, 0.11615980498526599`], 
     Hue[0.6499872378397605, 1, 0.1000176706834086], 
     Hue[0.6499812127959619, 1, 0.10002601305174516`], 
     Hue[0.6499925368181951, 1, 0.10001033363634519`], 
     Hue[0.6499951048581283, 1, 0.10000677788874544`], 
     Hue[0.6443912491738397, 1, 0.10776596268237587`], 
     Hue[0.6450814653729413, 1, 0.10681027871438892`], 
     Hue[0.6499448820990992, 1, 0.10007631709355502`], 
     Hue[0.6498985097083886, 1, 0.1001405250191543], 
     Hue[0.6314188285392321, 1, 0.12572777586875555`], 
     Hue[0.6276615081559497, 1, 0.1309302194763774], 
     Hue[0.6123798420903684, 1, 0.15208944941333602`], 
     Hue[0.635809914745879, 1, 0.11964781035185994`], 
     Hue[0.6344958252613736, 1, 0.12146731886886732`], 
     Hue[0.6498987693663226, 1, 0.10014016549278415`], 
     Hue[0.649950695639109, 1, 0.1000682675766184], 
     Hue[0.6363290967525409, 1, 0.11892894295802031`], 
     Hue[0.6499169408087976, 1, 0.10011500503397268`], 
     Hue[0.6499452847292683, 1, 0.10007575960562862`], 
     Hue[0.6451848600758786, 1, 0.10666711681801425`], 
     Hue[0.6499384202733739, 1, 0.10008526423686702`], 
     Hue[0.6499313963608999, 1, 0.10009498965413856`], 
     Hue[0.644586030848589, 1, 0.10749626497887677`], 
     Hue[0.6493269366655053, 1, 0.10093193384776192`], 
     Hue[0.6496050201873775, 1, 0.10054689512516958`], 
     Hue[0.6499971445555819, 1, 0.1000039536922713], 
     Hue[0.6499942337059641, 1, 0.10000798409943434`], 
     Hue[0.6499682293104808, 1, 0.10004399018548812`], 
     Hue[0.6499971170968787, 1, 0.10000399171201411`], 
     Hue[0.6498038432915926, 1, 0.10027160159625655`], 
     Hue[0.6497842792878261, 1, 0.10029869021685618`], 
     Hue[0.6499305639619218, 1, 0.10009614220656972`], 
     Hue[0.6499223977301639, 1, 0.10010744929669622`], 
     Hue[0.6499569735915827, 1, 0.10005957502703941`], 
     Hue[0.6499764116330907, 1, 0.10003266081572051`], 
     Hue[0.649999101927029, 1, 0.10000124348565209`], 
     Hue[0.649925810454061, 1, 0.10010272398668485`], 
     Hue[0.6499740052775556, 1, 0.10003599269261544`], 
     Hue[0.6499931350584105, 1, 0.10000950530373938`], 
     Hue[0.6499986042640042, 1, 0.10000193255753263`], 
     Hue[0.6499380881968962, 1, 0.10008572403506673`], 
     Hue[0.6499820089674371, 1, 0.10002491066047177`], 
     Hue[0.6499963588136884, 1, 0.10000504164258525`], 
     Hue[0.6499994700011782, 1, 0.10000073384452254`], 
     Hue[0.6499513388525884, 1, 0.10006737697333921`], 
     Hue[0.6499074536869546, 1, 0.10012814104883216`], 
     Hue[0.6498945576128976, 1, 0.10014599715137257`], 
     Hue[0.6498945035414182, 1, 0.10014607201957484`], 
     Hue[0.6498817551107648, 1, 0.10016372369278721`], 
     Hue[0.6499579058346595, 1, 0.10005828422893297`], 
     Hue[0.6499502404150022, 1, 0.10006889788692018`], 
     Hue[0.6499389913540885, 1, 0.10008447350972371`], 
     Hue[0.6498948423987034, 1, 0.10014560283256445`], 
     Hue[0.6498821047507632, 1, 0.10016323957586631`], 
     Hue[0.6499070733798011, 1, 0.10012866762796764`], 
     Hue[0.6498941642091621, 1, 0.10014654186423709`], 
     Hue[0.6499680543081146, 1, 0.10004423249645678`], 
     Hue[0.6499611431173056, 1, 0.10005380183757692`], 
     Hue[0.6498821047507631, 1, 0.1001632395758664], 
     Hue[0.6499504648283491, 1, 0.10006858716074746`], 
     Hue[0.6498945576128976, 1, 0.10014599715137261`], 
     Hue[0.6499836181429697, 1, 0.10002268257127285`], 
     Hue[0.6499764116330911, 1, 0.10003266081572015`], 
     Hue[0.649327839891292, 1, 0.100930683227442], 
     Hue[0.6499696557470173, 1, 0.10004201511951463`], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499998973914634, 1, 0.10000014207335849`], 
     Hue[0.6499696557470173, 1, 0.1000420151195146], 
     Hue[0.6495118930856898, 1, 0.10067584034289113`], 
     Hue[0.649604618915741, 1, 0.10054745073205101`], 
     Hue[0.6499763120114478, 1, 0.10003279875337998`], 
     Hue[0.6499996718109462, 1, 0.10000045441561291`], 
     Hue[0.6499997221218345, 1, 0.10000038475438296`], 
     Hue[0.6499996739625998, 1, 0.1000004514364003], 
     Hue[0.6499997231111884, 1, 0.10000038338450845`], 
     Hue[0.6499994854782605, 1, 0.10000071241471627`], 
     Hue[0.6499993034614677, 1, 0.10000096443796776`], 
     Hue[0.6499581095157081, 1, 0.10005800220901964`], 
     Hue[0.6499504648283491, 1, 0.10006858716074744`], 
     Hue[0.6499994700011782, 1, 0.10000073384452254`], 
     Hue[0.6499963588136884, 1, 0.10000504164258524`], 
     Hue[0.6499820089674371, 1, 0.10002491066047176`], 
     Hue[0.6499380881968964, 1, 0.10008572403506669`], 
     Hue[0.6499986042640042, 1, 0.10000193255753263`], 
     Hue[0.6499931350584105, 1, 0.10000950530373937`], 
     Hue[0.6499740052775556, 1, 0.10003599269261543`], 
     Hue[0.6499258104540611, 1, 0.1001027239866848], 
     Hue[0.6496495783709015, 1, 0.10048519917875173`], 
     Hue[0.649621458422506, 1, 0.10052413449191479`], 
     Hue[0.649615310956587, 1, 0.10053264636780261`], 
     Hue[0.6496211353704806, 1, 0.10052458179471914`], 
     Hue[0.6496149480433895, 1, 0.10053314886299929`], 
     Hue[0.6498226010526239, 1, 0.1002456293117515], 
     Hue[0.6344958252613189, 1, 0.12146731886894314`], 
     Hue[0.6499979068548963, 1, 0.10000289820091286`], 
     Hue[0.6499999463041645, 1, 0.10000007434808002`], 
     Hue[0.6499997881961503, 1, 0.10000029326686882`], 
     Hue[0.6499998875844862, 1, 0.10000015565224989`], 
     Hue[0.6499961977161761, 1, 0.1000052647006792], 
     Hue[0.6499715658257951, 1, 0.10003937039505302`], 
     Hue[0.10275085520088534`, 1, 0.8577295851064664], 
     Hue[0.07116385446585627, 1, 0.9014654322780451], 
     Hue[0.6498321507756426, 1, 0.10023240661834108`], 
     Hue[0.6499999706508989, 1, 0.1000000406372169], 
     Hue[0.008564162898749839, 1, 0.9881419282940387], 
     Hue[0.00856416289715578, 1, 0.9881419282962458], 
     Hue[0.6499999463041645, 1, 0.10000007434808002`], 
     Hue[0.6499979259072688, 1, 0.10000287182070478`], 
     Hue[0.6498226656875892, 1, 0.1002455398171843], 
     Hue[0.6499835735373029, 1, 0.10002274433296532`], 
     Hue[0.6499817210220853, 1, 0.10002530935403585`], 
     Hue[0.6499836181429695, 1, 0.10002268257127303`], 
     Hue[0.6499817845643628, 1, 0.10002522137242074`], 
     Hue[0.6499861817897984, 1, 0.1000191329064331], 
     Hue[0.6499968070349429, 1, 0.1000044210285406], 
     Hue[0.6499994103243372, 1, 0.1000008164739948], 
     Hue[0.6499915553675152, 1, 0.10001169256805592`], 
     Hue[0.6499985526901774, 1, 0.10000200396744673`], 
     Hue[0.6499998221998805, 1, 0.10000024618478089`], 
     Hue[0.6499906782378703, 1, 0.10001290705525656`], 
     Hue[0.6446386253957014, 1, 0.10742344175979816`], 
     Hue[0.6447609920664576, 1, 0.10725401098490486`], 
     Hue[0.649998345225296, 1, 0.1000022912265133], 
     Hue[0.6499993476936773, 1, 0.1000009031933699], 
     Hue[0.6499997070467911, 1, 0.10000040562752005`], 
     Hue[0.6499995636115868, 1, 0.10000060423011056`], 
     Hue[0.6483242391402418, 1, 0.10232028426735747`], 
     Hue[0.6483242391402418, 1, 0.10232028426735751`], 
     Hue[0.6483242391402418, 1, 0.10232028426735748`], 
     Hue[0.6483242391402463, 1, 0.1023202842673513], 
     Hue[0.6483242391402464, 1, 0.10232028426735125`], 
     Hue[0.6483242391402463, 1, 0.10232028426735128`], 
     Hue[0.6469166687904662, 1, 0.10426922782858529`], 
     Hue[0.6450730162625556, 1, 0.10682197748261522`], 
     Hue[0.6450730162625556, 1, 0.10682197748261522`], 
     Hue[0.6446427123917254, 1, 0.10741778284222633`], 
     Hue[0.6451837682394976, 1, 0.10666862859146478`], 
     Hue[0.6451837682394977, 1, 0.10666862859146477`], 
     Hue[0.647847739448394, 1, 0.10298005307145448`], 
     Hue[0.6476673319658687, 1, 0.1032298480472588], 
     Hue[0.6475036441269619, 1, 0.1034564927472835], 
     Hue[0.6475036441269619, 1, 0.10345649274728348`], 
     Hue[0.6473254666988637, 1, 0.10370319995541953`], 
     Hue[0.6499997114379519, 1, 0.10000039954745131`], 
     Hue[0.649838667427071, 1, 0.10022338356251717`], 
     Hue[0.6498522655918395, 1, 0.10020455533437608`], 
     Hue[0.649849705083499, 1, 0.1002081006536168], 
     Hue[0.6498638958591648, 1, 0.10018845188731024`], 
     Hue[0.6499964999597848, 1, 0.10000484620952874`], 
     Hue[0.6499892906359471, 1, 0.10001482835022706`], 
     Hue[0.6473254666988637, 1, 0.10370319995541954`], 
     Hue[0.648184760828347, 1, 0.10251340808382732`], 
     Hue[0.6478477394483939, 1, 0.10298005307145464`], 
     Hue[0.6475036441269618, 1, 0.10345649274728375`], 
     Hue[0.6475036441269617, 1, 0.10345649274728376`], 
     Hue[0.644642712391751, 1, 0.10741778284219103`], 
     Hue[0.6447410918958458, 1, 0.1072815650672905], 
     Hue[0.6447410918958458, 1, 0.1072815650672905], 
     Hue[0.644822685525103, 1, 0.1071685892729343], 
     Hue[0.644822685525103, 1, 0.10716858927293431`], 
     Hue[0.6447422602883427, 1, 0.10727994729306398`], 
     Hue[0.6447422602883427, 1, 0.10727994729306398`], 
     Hue[0.6039331393078194, 1, 0.16378488403532698`], 
     Hue[0.599124239982273, 1, 0.17044336002454505`], 
     Hue[0.6450803703104249, 1, 0.10681179495479633`], 
     Hue[0.6469166687904262, 1, 0.10426922782864076`], 
     Hue[0.6452016973297894, 1, 0.10664380369721467`], 
     Hue[0.6432970668472778, 1, 0.10928098436530766`], 
     Hue[0.6432970668470466, 1, 0.10928098436562779`], 
     Hue[0.6450761923626182, 1, 0.10681757980560565`], 
     Hue[0.5959045810185231, 1, 0.17490134935896817`], 
     Hue[0.5991242399827877, 1, 0.17044336002383234`], 
     Hue[0.6448438343094479, 1, 0.10713930634076449`], 
     Hue[0.644742260288362, 1, 0.1072799472930372], 
     Hue[0.6446754130691614, 1, 0.1073725049811612], 
     Hue[0.6448226855248731, 1, 0.1071685892732527], 
     Hue[0.649849705083499, 1, 0.10020810065361674`], 
     Hue[0.6498638958591649, 1, 0.10018845188731017`], 
     Hue[0.6498386674270711, 1, 0.10022338356251706`], 
     Hue[0.6498522655918396, 1, 0.10020455533437599`], 
     Hue[0.6499766758185227, 1, 0.10003229502050702`], 
     Hue[0.6499991149582264, 1, 0.10000122544245589`], 
     Hue[0.6499998221998805, 1, 0.10000024618478089`], 
     Hue[0.6499943973499914, 1, 0.10000775751539649`], 
     Hue[0.6499205322569598, 1, 0.10011003225959411`], 
     Hue[0.6499309840236278, 1, 0.10009556058266922`], 
     Hue[0.649979910447695, 1, 0.1000278163031916], 
     Hue[0.6499993034614677, 1, 0.10000096443796776`], 
     Hue[0.6499996739625998, 1, 0.1000004514364003], 
     Hue[0.6499997231111884, 1, 0.10000038338450845`], 
     Hue[0.6499996082984593, 1, 0.1000005423559795], 
     Hue[0.6499997221218345, 1, 0.10000038475438296`], 
     Hue[0.6499996049868014, 1, 0.10000054694135192`], 
     Hue[0.6499978738704448, 1, 0.10000294387169176`], 
     Hue[0.6499329557399242, 1, 0.10009283051395126`], 
     Hue[0.6499430494131798, 1, 0.10007885465867405`], 
     Hue[0.6499941827230284, 1, 0.1000080546911914], 
     Hue[0.6499852320800056, 1, 0.10002044788922305`], 
     Hue[0.6499835735373027, 1, 0.1000227443329655], 
     Hue[0.6499452554080251, 1, 0.10007580020427298`], 
     Hue[0.6499452554080251, 1, 0.10007580020427298`], 
     Hue[0.6397468996933219, 1, 0.1141966004246313], 
     Hue[0.6413526165411418, 1, 0.1119733001738037], 
     Hue[0.6189168169696497, 1, 0.14303825342663892`], 
     Hue[0.6139274757408153, 1, 0.14994657205117884`], 
     Hue[0.5666286137183364, 1, 0.21543730408230344`], 
     Hue[0.6499979259072688, 1, 0.10000287182070478`], 
     Hue[0.634303883883022, 1, 0.12173308385427735`], 
     Hue[0.6113350077372445, 1, 0.15353614313304617`], 
     Hue[0.615088110609863, 1, 0.14833953915557424`], 
     Hue[0.6228939004999126, 1, 0.13753152238473657`], 
     Hue[0.6499903637000147, 1, 0.10001334256921046`], 
     Hue[0.6499998973914634, 1, 0.10000014207335849`], 
     Hue[0.6497210465128499, 1, 0.10038624328990012`], 
     Hue[0.6499317360308978, 1, 0.10009451934183383`], 
     Hue[0.649988567829675, 1, 0.10001582915891158`], 
     Hue[0.649986680500004, 1, 0.1000184423846099], 
     Hue[0.6499987371330672, 1, 0.10000174858498384`], 
     Hue[0.6499992903837791, 1, 0.10000098254553669`], 
     Hue[0.6499892775816672, 1, 0.10001484642538383`], 
     Hue[0.6499935635661466, 1, 0.10000891198533556`], 
     Hue[0.6499547241190271, 1, 0.10006268968134718`], 
     Hue[0.6499821959348161, 1, 0.10002465178256234`], 
     Hue[0.6499904136321839, 1, 0.10001327343236079`], 
     Hue[0.649986680500004, 1, 0.10001844238460987`], 
     Hue[0.6499317360308979, 1, 0.10009451934183364`], 
     Hue[0.6497210465128498, 1, 0.1003862432899004], 
     Hue[0.10275085519733629`, 1, 0.8577295851113805], 
     Hue[0.6499973394962008, 1, 0.10000368377449126`], 
     Hue[0.649998345225296, 1, 0.1000022912265133], 
     Hue[0.6499995636115868, 1, 0.10000060423011056`], 
     Hue[0.6499979068548963, 1, 0.10000289820091286`], 
     Hue[0.6150881106096312, 1, 0.14833953915589532`], 
     Hue[0.6228939004996968, 1, 0.1375315223850352], 
     Hue[0.6424451989541747, 1, 0.11046049375575805`], 
     Hue[0.6427107986431146, 1, 0.1100927403403028], 
     Hue[0.649950538320686, 1, 0.10006848540212708`], 
     Hue[0.6189168169701293, 1, 0.1430382534259747], 
     Hue[0.6139274757414217, 1, 0.14994657205033926`], 
     Hue[0.6413526165411501, 1, 0.11197330017379226`], 
     Hue[0.6447609920662616, 1, 0.10725401098517635`], 
     Hue[0.6496495783709018, 1, 0.10048519917875146`], 
     Hue[0.649652358023095, 1, 0.10048135042956088`], 
     Hue[0.649621458422494, 1, 0.10052413449193147`], 
     Hue[0.6499941827230284, 1, 0.1000080546911914], 
     Hue[0.6499329557399242, 1, 0.10009283051395124`], 
     Hue[0.6499430494131799, 1, 0.10007885465867403`], 
     Hue[0.649979910447695, 1, 0.10002781630319159`], 
     Hue[0.6499713297183559, 1, 0.10003969731304567`], 
     Hue[0.649976389667182, 1, 0.10003269123005579`], 
     Hue[0.6499205322569599, 1, 0.10011003225959407`], 
     Hue[0.6499309840236278, 1, 0.10009556058266918`], 
     Hue[0.6499926102537842, 1, 0.10001023195629886`], 
     Hue[0.6499766758185227, 1, 0.100032295020507], 
     Hue[0.6499906782378703, 1, 0.10001290705525656`], 
     Hue[0.6499713297183559, 1, 0.10003969731304568`], 
     Hue[0.649976389667182, 1, 0.10003269123005579`], 
     Hue[0.6499996709568588, 1, 0.10000045559819547`], 
     Hue[0.649999779338247, 1, 0.10000030553165791`], 
     Hue[0.6498321507756425, 1, 0.10023240661834114`], 
     Hue[0.07116385446886919, 1, 0.9014654322738734], 
     Hue[0.649621135370493, 1, 0.10052458179470194`], 
     Hue[0.6499996709568588, 1, 0.10000045559819547`], 
     Hue[0.6499998525302062, 1, 0.10000020418894534`], 
     Hue[0.649999779338247, 1, 0.10000030553165791`], 
     Hue[0.6499997881961503, 1, 0.10000029326686882`], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.649940220239339, 1, 0.1000827719762999], 
     Hue[0.6499302912297338, 1, 0.10009651983575332`], 
     Hue[0.6497575876165925, 1, 0.10033564791548731`], 
     Hue[0.649717658604433, 1, 0.10039093424001597`], 
     Hue[0.5985789422584306, 1, 0.17119838764217316`], 
     Hue[0.6361358775824967, 1, 0.11919647719346611`], 
     Hue[0.6465876268599808, 1, 0.10472482434771894`], 
     Hue[0.6499984458205482, 1, 0.1000021519407794], 
     Hue[0.6499984458205482, 1, 0.1000021519407794], 
     Hue[0.6496628369321749, 1, 0.10046684117083483`], 
     Hue[0.5991253617568926, 1, 0.17044180679814872`], 
     Hue[0.5936528925800798, 1, 0.17801907181219717`], 
     Hue[0.6499122626117608, 1, 0.10012148253756195`], 
     Hue[0.6498691588927481, 1, 0.10018116461004108`], 
     Hue[0.6499509547899046, 1, 0.10006790875243984`], 
     Hue[0.6449129383762623, 1, 0.10704362378671385`], 
     Hue[0.6447410918958291, 1, 0.10728156506731357`], 
     Hue[0.6447410918958292, 1, 0.10728156506731355`], 
     Hue[0.6474431293251607, 1, 0.10354028247285443`], 
     Hue[0.6499917352412674, 1, 0.10001144351209136`], 
     Hue[0.6499817734807857, 1, 0.10002523671891218`], 
     Hue[0.6416068802400537, 1, 0.11162124274454101`], 
     Hue[0.6499940613673298, 1, 0.10000822272215877`], 
     Hue[0.6498321507756425, 1, 0.10023240661834114`], 
     Hue[0.6496444802835842, 1, 0.10049225806888334`], 
     Hue[0.6497775656083637, 1, 0.10030798608072715`], 
     Hue[0.6497176586044328, 1, 0.10039093424001616`], 
     Hue[0.649947428513126, 1, 0.10007279128951778`], 
     Hue[0.6499302912297339, 1, 0.10009651983575313`], 
     Hue[0.6499999025254264, 1, 0.10000013496479421`], 
     Hue[0.6498691588927484, 1, 0.10018116461004063`], 
     Hue[0.6499398049604824, 1, 0.10008334697779356`], 
     Hue[0.6499509547899049, 1, 0.10006790875243936`], 
     Hue[0.03305932787447796, 1, 0.9542255460199536], 
     Hue[0.05053038130973697, 1, 0.9300348566480564], 
     Hue[0.6499983626934944, 1, 0.10000226703977699`], 
     Hue[0.6499987893805093, 1, 0.10000167624237187`], 
     Hue[0.6499977154256198, 1, 0.10000316325683417`], 
     Hue[0.6450736851083142, 1, 0.10682105138848805`], 
     Hue[0.6450736851083142, 1, 0.10682105138848805`], 
     Hue[0.6465876268599643, 1, 0.10472482434774175`], 
     Hue[0.6491923510353136, 1, 0.1011182831818735], 
     Hue[0.646236624228737, 1, 0.10521082799097971`], 
     Hue[0.6454530964615557, 1, 0.10629571259169222`], 
     Hue[0.6459907714908584, 1, 0.10555123947419615`], 
     Hue[0.6448435305234965, 1, 0.10713972696746633`], 
     Hue[0.5961398668207601, 1, 0.1745755690174091], 
     Hue[0.5988995745045004, 1, 0.170754435301461], 
     Hue[0.5856170866541521, 1, 0.18914557232502022`], 
     Hue[0.6499896086305067, 1, 0.10001438805006765`], 
     Hue[0.6499845305213169, 1, 0.10002141927817668`], 
     Hue[0.6498891968769868, 1, 0.10015341970878756`], 
     Hue[0.6499289484739933, 1, 0.10009837903600931`], 
     Hue[0.6499928871566862, 1, 0.10000984855228068`], 
     Hue[0.5901051118871274, 1, 0.1829313835409005], 
     Hue[0.6072701026756729, 1, 0.159164473218299], 
     Hue[0.595645576906745, 1, 0.17525997043681454`], 
     Hue[0.6444958224282412, 1, 0.1076211689455122], 
     Hue[0.6490376229975539, 1, 0.10133252200338695`], 
     Hue[0.6498946193265016, 1, 0.10014591170176697`], 
     Hue[0.6499308362608209, 1, 0.1000957651773249], 
     Hue[0.6499948524777456, 1, 0.10000712733850615`], 
     Hue[0.649994143903924, 1, 0.10000810844072064`], 
     Hue[0.6498166833888368, 1, 0.1002538230000721], 
     Hue[0.6499587350003936, 1, 0.10005713615330115`], 
     Hue[0.6499998252030462, 1, 0.10000024202655138`], 
     Hue[0.6476127536334878, 1, 0.10330541804594007`], 
     Hue[0.6499581095157081, 1, 0.10005800220901967`], 
     Hue[0.6498383027784684, 1, 0.10022388846058226`], 
     Hue[0.6494842522907945, 1, 0.10071411221274607`], 
     Hue[0.6499119444868923, 1, 0.10012192301814919`], 
     Hue[0.6490246129733724, 1, 0.10135053588302283`], 
     Hue[0.6486614185740522, 1, 0.1018534204359277], 
     Hue[0.6490374185577825, 1, 0.10133280507383957`], 
     Hue[0.6476512819637038, 1, 0.10325207112717934`], 
     Hue[0.6479788895815403, 1, 0.10279846057940577`], 
     Hue[0.6489306887868327, 1, 0.1014805847566932], 
     Hue[0.6460978666860362, 1, 0.10540295381933454`], 
     Hue[0.6493199214653446, 1, 0.10094164720183067`], 
     Hue[0.6475834488846838, 1, 0.10334599385197639`], 
     Hue[0.6327196532763, 1, 0.12392663392512315`], 
     Hue[0.6499973394962008, 1, 0.10000368377449126`], 
     Hue[0.45983657272680345`, 1, 0.3633032069936568], 
     Hue[0.5972214239242457, 1, 0.1730780284125829], 
     Hue[0.6443792387298601, 1, 0.10778259252788604`], 
     Hue[0.6472945453822796, 1, 0.10374601408607448`], 
     Hue[0.6494380510073349, 1, 0.10077808322061334`], 
     Hue[0.6497422006045632, 1, 0.10035695300906636`], 
     Hue[0.6446614119197689, 1, 0.1073918911880123], 
     Hue[0.6498543989283845, 1, 0.1002016014837754], 
     Hue[0.6489814055841804, 1, 0.10141036149882726`], 
     Hue[0.6477602551397652, 1, 0.10310118519109432`], 
     Hue[0.6490601902829679, 1, 0.10130127499281374`], 
     Hue[0.6472376528774036, 1, 0.10382478832359494`], 
     Hue[0.6496859288220751, 1, 0.10043486778481911`], 
     Hue[0.6491243397305978, 1, 0.1012124526807107], 
     Hue[0.6486561461999454, 1, 0.10186072064622959`], 
     Hue[0.6488750409140392, 1, 0.1015576356574842], 
     Hue[0.6499987823857478, 1, 0.1000016859274261], 
     Hue[0.6498176582689631, 1, 0.10025247316605117`], 
     Hue[0.6447269791198692, 1, 0.10730110583402737`], 
     Hue[0.6066823642767425, 1, 0.15997826484758743`], 
     Hue[0.6475890729501602, 1, 0.1033382066843936], 
     Hue[0.6449354756217119, 1, 0.1070124183699374], 
     Hue[0.6494383119686701, 1, 0.10077772188953373`], 
     Hue[0.6499098804701534, 1, 0.10012478088747992`], 
     Hue[0.6499098804701535, 1, 0.1001247808874797], 
     Hue[0.6492133707832605, 1, 0.10108917891548559`], 
     Hue[0.6494383119686716, 1, 0.10077772188953155`], 
     Hue[0.6449363081981928, 1, 0.10701126557173313`], 
     Hue[0.42186155100379946`, 1, 0.4158840063024316], 
     Hue[0.6475890729501655, 1, 0.10333820668438627`], 
     Hue[0.6066823642771308, 1, 0.1599782648470497], 
     Hue[0.6448226855248731, 1, 0.1071685892732527], 
     Hue[0.649817658268963, 1, 0.10025247316605124`], 
     Hue[0.6497216634938592, 1, 0.10038538900850273`], 
     Hue[0.6499852500802349, 1, 0.10002042296582866`], 
     Hue[0.649652358023096, 1, 0.1004813504295595], 
     Hue[0.6475004150899573, 1, 0.1034609637215976], 
     Hue[0.6485711159572849, 1, 0.10197845482837478`], 
     Hue[0.5947857583623852, 1, 0.17645048842131275`], 
     Hue[0.6066857938385622, 1, 0.15997351622352923`], 
     Hue[0.6330024607853376, 1, 0.12353505429722485`], 
     Hue[0.6486670765987, 1, 0.10184558624795385`], 
     Hue[0.369936658750547, 1, 0.48778001096078116`], 
     Hue[0.4218763261831908, 1, 0.4158635483617358], 
     Hue[0.6492143200935557, 1, 0.10108786448584597`], 
     Hue[0.10550699045395528`, 1, 0.853913397832985], 
     Hue[0.19694005227927658`, 1, 0.7273137737671554], 
     Hue[0.10551553714730144`, 1, 0.8539015639498903], 
     Hue[0.6492143200935481, 1, 0.10108786448585651`], 
     Hue[0.6483449140191628, 1, 0.10229165751192848`], 
     Hue[0.42187632618421733`, 1, 0.41586354836031447`], 
     Hue[0.3699389649367029, 1, 0.48777681777994986`], 
     Hue[0.594785897687917, 1, 0.176450295509038], 
     Hue[0.6475004150899578, 1, 0.10346096372159692`], 
     Hue[0.6496523174518581, 1, 0.10048140660511957`], 
     Hue[0.6489651538469169, 1, 0.10143286390426892`], 
     Hue[0.6499852320800057, 1, 0.10002044788922296`], 
     Hue[0.6498180333025885, 1, 0.1002519538887237], 
     Hue[0.6497216634938593, 1, 0.10038538900850262`], 
     Hue[0.649941550412067, 1, 0.10008093019867641`], 
     Hue[0.6497967031430822, 1, 0.10028148795573225`], 
     Hue[0.649941550412067, 1, 0.10008093019867643`], 
     Hue[0.6448143518714418, 1, 0.10718012817800371`], 
     Hue[0.6329576816102662, 1, 0.12359705623193912`], 
     Hue[0.6448140890408159, 1, 0.10718049209733183`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.649721605398353, 1, 0.10038546944843434`], 
     Hue[0.6450803703104622, 1, 0.10681179495474478`], 
     Hue[0.6497970985365656, 1, 0.10028094048783229`], 
     Hue[0.6497970985365656, 1, 0.10028094048783216`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499418600005051, 1, 0.1000805015377621], 
     Hue[0.6450814653729043, 1, 0.10681027871444017`], 
     Hue[0.6499565454836217, 1, 0.10006016779190843`], 
     Hue[0.6499565454836217, 1, 0.1000601677919084], 
     Hue[0.6454889217763369, 1, 0.1062461083096875], 
     Hue[0.6329576816103337, 1, 0.12359705623184569`], 
     Hue[0.6499418600005051, 1, 0.10008050153776213`], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499996087792145, 1, 0.10000054169031844`], 
     Hue[0.6499567540632241, 1, 0.10005987898938218`], 
     Hue[0.6474431293251608, 1, 0.10354028247285428`], 
     Hue[0.6454878932078032, 1, 0.10624753248150337`], 
     Hue[0.6450761923628122, 1, 0.10681757980533695`], 
     Hue[0.5666286137182623, 1, 0.21543730408240602`], 
     Hue[0.6499971946455725, 1, 0.10000388433689966`], 
     Hue[0.6442370654339595, 1, 0.10797944786067142`], 
     Hue[0.6473386224356845, 1, 0.10368498431982147`], 
     Hue[0.6425433794512151, 1, 0.1103245515290868], 
     Hue[0.6499097362338684, 1, 0.10012498059925916`], 
     Hue[0.6497911224533827, 1, 0.10028921506454719`], 
     Hue[0.6497234483054741, 1, 0.10038291773088195`], 
     Hue[0.649995891364032, 1, 0.10000568888057104`], 
     Hue[0.6499997133311914, 1, 0.10000039692604273`], 
     Hue[0.6497233765288313, 1, 0.10038301711392589`], 
     Hue[0.6497943170473904, 1, 0.10028479178053641`], 
     Hue[0.6499458125596493, 1, 0.10007502876356245`], 
     Hue[0.6489344903150339, 1, 0.10147532110226072`], 
     Hue[0.6486593996716279, 1, 0.10185621583928456`], 
     Hue[0.6489003584073849, 1, 0.10152258066669777`], 
     Hue[0.6499848496426992, 1, 0.10002097741780107`], 
     Hue[0.648945328630618, 1, 0.10146031420375959`], 
     Hue[0.6495908047814821, 1, 0.10056657799487091`], 
     Hue[0.6472015028703471, 1, 0.10387484217951948`], 
     Hue[0.6495371410484513, 1, 0.10064088162522138`], 
     Hue[0.6479012991383333, 1, 0.10290589350076933`], 
     Hue[0.6445975391505655, 1, 0.10748033040690941`], 
     Hue[0.4363713103250134, 1, 0.39579357031921225`], 
     Hue[0.3699378118431322, 1, 0.48777841437104774`], 
     Hue[0.4363885413626311, 1, 0.3957697119594339], 
     Hue[0.6479116918971519, 1, 0.10289150352702038`], 
     Hue[0.649559230442396, 1, 0.10061029631052858`], 
     Hue[0.6491292687549561, 1, 0.10120562787775308`], 
     Hue[0.10275085520088556`, 1, 0.8577295851064661], 
     Hue[0.6489000604437772, 1, 0.10152299323169314`], 
     Hue[0.6472086250834637, 1, 0.10386498065366576`], 
     Hue[0.5936528925800799, 1, 0.17801907181219712`], 
     Hue[0.6099350580464594, 1, 0.1554745350125947], 
     Hue[0.647201502870347, 1, 0.10387484217951967`], 
     Hue[0.648900358407385, 1, 0.10152258066669763`], 
     Hue[0.6473904480212564, 1, 0.10361322581672193`], 
     Hue[0.6463615928568269, 1, 0.105037794505932], 
     Hue[0.6448435305234965, 1, 0.10713972696746633`], 
     Hue[0.6447636185417649, 1, 0.10725037432678715`], 
     Hue[0.648659399671628, 1, 0.10185621583928438`], 
     Hue[0.6480246283909675, 1, 0.10273512992019884`], 
     Hue[0.6496495783709018, 1, 0.10048519917875146`], 
     Hue[0.6479012991383548, 1, 0.1029058935007395], 
     Hue[0.6489344903150339, 1, 0.10147532110226079`], 
     Hue[0.6495371410484526, 1, 0.10064088162521953`], 
     Hue[0.6495371410484527, 1, 0.10064088162521938`], 
     Hue[0.648934490315034, 1, 0.10147532110226068`], 
     Hue[0.647901299138362, 1, 0.10290589350072946`], 
     Hue[0.6480246283909674, 1, 0.10273512992019894`], 
     Hue[0.6486593996716278, 1, 0.1018562158392846], 
     Hue[0.6447636185419895, 1, 0.1072503743264761], 
     Hue[0.6448142204560843, 1, 0.10718031013772958`], 
     Hue[0.646361592856824, 1, 0.10503779450593599`], 
     Hue[0.6473904480212559, 1, 0.1036132258167227], 
     Hue[0.6489003584073845, 1, 0.1015225806666984], 
     Hue[0.6472015028703367, 1, 0.10387484217953377`], 
     Hue[0.6099350580461176, 1, 0.15547453501306802`], 
     Hue[0.5947858280247514, 1, 0.17645039196572884`], 
     Hue[0.647208625083455, 1, 0.1038649806536777], 
     Hue[0.6489000604437767, 1, 0.10152299323169388`], 
     Hue[0.19694005227927797`, 1, 0.7273137737671536], 
     Hue[0.6491292687549454, 1, 0.10120562787776805`], 
     Hue[0.649559230442397, 1, 0.10061029631052726`], 
     Hue[0.6479116918971736, 1, 0.1028915035269904], 
     Hue[0.5666286137182632, 1, 0.2154373040824048], 
     Hue[0.43638854136357774`, 1, 0.39576971195812316`], 
     Hue[0.36993781184416613`, 1, 0.4877784143696161], 
     Hue[0.4363713103265153, 1, 0.3957935703171326], 
     Hue[0.6479012991383548, 1, 0.10290589350073955`], 
     Hue[0.6495371410484525, 1, 0.10064088162521961`], 
     Hue[0.6472015028703471, 1, 0.10387484217951946`], 
     Hue[0.6495908047814821, 1, 0.10056657799487088`], 
     Hue[0.6489453286306182, 1, 0.10146031420375949`], 
     Hue[0.6489003584073851, 1, 0.10152258066669752`], 
     Hue[0.648659399671628, 1, 0.10185621583928439`], 
     Hue[0.6489344903150338, 1, 0.10147532110226089`], 
     Hue[0.6499948664608386, 1, 0.10000710797730039`], 
     Hue[0.6499458125596493, 1, 0.10007502876356242`], 
     Hue[0.6497943170473904, 1, 0.10028479178053637`], 
     Hue[0.6497233765288313, 1, 0.100383017113926], 
     Hue[0.649995891364032, 1, 0.10000568888057104`], 
     Hue[0.6497234483054742, 1, 0.10038291773088184`], 
     Hue[0.6497911224533826, 1, 0.10028921506454724`], 
     Hue[0.6499455194466978, 1, 0.10007543461226463`], 
     Hue[0.6473908758804227, 1, 0.10361263339633786`], 
     Hue[0.649128269088777, 1, 0.1012070120309243], 
     Hue[0.64459851077779, 1, 0.10747898507690626`], 
     Hue[0.4363713103247258, 1, 0.3957935703196105], 
     Hue[0.6446917420522249, 1, 0.10734989561999628`], 
     Hue[0.6446917420519871, 1, 0.10734989562032558`], 
     Hue[0.4363713103265097, 1, 0.39579357031714046`], 
     Hue[0.6445985107778432, 1, 0.10747898507683241`], 
     Hue[0.6491282690888007, 1, 0.10120701203089132`], 
     Hue[0.6473908758804227, 1, 0.10361263339633796`], 
     Hue[0.6499455194466978, 1, 0.10007543461226466`], 
     Hue[0.649824821602494, 1, 0.10024255470423904`], 
     Hue[0.6499597831211297, 1, 0.1000556849092051], 
     Hue[0.6489000604437772, 1, 0.10152299323169305`], 
     Hue[0.649559230442397, 1, 0.10061029631052716`], 
     Hue[0.6486631270815442, 1, 0.10185105481016969`], 
     Hue[0.6489453286306182, 1, 0.10146031420375946`], 
     Hue[0.6497943170473904, 1, 0.10028479178053637`], 
     Hue[0.6497911224533827, 1, 0.10028921506454717`], 
     Hue[0.6479116918971737, 1, 0.10289150352699036`], 
     Hue[0.6472086250834638, 1, 0.10386498065366556`], 
     Hue[0.6497234483054741, 1, 0.10038291773088194`], 
     Hue[0.6445975391506519, 1, 0.10748033040678968`], 
     Hue[0.645284131759114, 1, 0.10652966371814983`], 
     Hue[0.6498244600804971, 1, 0.10024305527315781`], 
     Hue[0.6334776944950843, 1, 0.12287703839142183`], 
     Hue[0.6445985107777569, 1, 0.1074789850769521], 
     Hue[0.4363885413636581, 1, 0.3957697119580119], 
     Hue[0.6099395356971271, 1, 0.15546833518859332`], 
     Hue[0.609935058046162, 1, 0.15547453501300657`], 
     Hue[0.649128269088788, 1, 0.10120701203090902`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6496495783709008, 1, 0.10048519917875282`], 
     Hue[0.10275085519718585`, 1, 0.8577295851115888], 
     Hue[0.3699378118441581, 1, 0.4877784143696273], 
     Hue[0.5947858280254814, 1, 0.17645039196471807`], 
     Hue[0.6499848496426992, 1, 0.10002097741780114`], 
     Hue[0.6499997133311914, 1, 0.10000039692604273`], 
     Hue[0.5936528925793111, 1, 0.17801907181326163`], 
     Hue[0.3699378118423824, 1, 0.4877784143720859], 
     Hue[0.649128269088777, 1, 0.10120701203092423`], 
     Hue[0.609939535696351, 1, 0.155468335189668], 
     Hue[0.4363885413622587, 1, 0.3957697119599496], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6099350580464612, 1, 0.15547453501259223`], 
     Hue[0.6445985107777901, 1, 0.10747898507690615`], 
     Hue[0.6334776944949212, 1, 0.12287703839164765`], 
     Hue[0.6498244600804972, 1, 0.1002430552731577], 
     Hue[0.6452841317591499, 1, 0.10652966371810024`], 
     Hue[0.6497234483054742, 1, 0.10038291773088183`], 
     Hue[0.6445975391506057, 1, 0.10748033040685363`], 
     Hue[0.6497943170473904, 1, 0.10028479178053638`], 
     Hue[0.6489453286306182, 1, 0.10146031420375946`], 
     Hue[0.6472086250834637, 1, 0.10386498065366578`], 
     Hue[0.6479116918971799, 1, 0.10289150352698177`], 
     Hue[0.6497911224533826, 1, 0.10028921506454722`], 
     Hue[0.6486631270815439, 1, 0.10185105481016991`], 
     Hue[0.6489000604437771, 1, 0.10152299323169331`], 
     Hue[0.6495592304423972, 1, 0.10061029631052709`], 
     Hue[0.6499597831211297, 1, 0.10005568490920513`], 
     Hue[0.6473904480212564, 1, 0.10361322581672185`], 
     Hue[0.6486631270815439, 1, 0.10185105481016993`], 
     Hue[0.6452851935746376, 1, 0.10652819351204024`], 
     Hue[0.6499599794841723, 1, 0.10005541302191531`], 
     Hue[0.19694005227972972`, 1, 0.7273137737665281], 
     Hue[0.6499599794841723, 1, 0.10005541302191528`], 
     Hue[0.6486631270815442, 1, 0.10185105481016965`], 
     Hue[0.6452851935746403, 1, 0.10652819351203645`], 
     Hue[0.6473904480212564, 1, 0.10361322581672192`], 
     Hue[0.6498248216024941, 1, 0.10024255470423891`], 
     Hue[0.6491292687549689, 1, 0.10120562787773542`], 
     Hue[0.6491292687549453, 1, 0.10120562787776811`], 
     Hue[0.6499455194466978, 1, 0.10007543461226463`], 
     Hue[0.6498244600804972, 1, 0.10024305527315769`], 
     Hue[0.6498244600804971, 1, 0.10024305527315783`], 
     Hue[0.6499455194466978, 1, 0.10007543461226467`], 
     Hue[0.6497233765288313, 1, 0.100383017113926], 
     Hue[0.6334703961606172, 1, 0.12288714377760701`], 
     Hue[0.6448435305234644, 1, 0.1071397269675108], 
     Hue[0.6334703961606807, 1, 0.12288714377751916`], 
     Hue[0.6497223596864661, 1, 0.10038442504950848`], 
     Hue[0.6446917420519871, 1, 0.10734989562032567`], 
     Hue[0.6452841317591496, 1, 0.10652966371810071`], 
     Hue[0.6498248216024941, 1, 0.10024255470423904`], 
     Hue[0.6498248216024941, 1, 0.10024255470423893`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499171656570684, 1, 0.10011469370559767`], 
     Hue[0.6499458125596493, 1, 0.10007502876356242`], 
     Hue[0.633477694494929, 1, 0.12287703839163683`], 
     Hue[0.6452851935746035, 1, 0.1065281935120876], 
     Hue[0.6099395356963766, 1, 0.15546833518963252`], 
     Hue[0.6499597831211297, 1, 0.10005568490920515`], 
     Hue[0.6499597831211297, 1, 0.10005568490920512`], 
     Hue[0.6452851935746391, 1, 0.1065281935120382], 
     Hue[0.6099395356970551, 1, 0.15546833518869302`], 
     Hue[0.6334703961606802, 1, 0.1228871437775197], 
     Hue[0.6334776944950551, 1, 0.12287703839146225`], 
     Hue[0.6446917420522449, 1, 0.10734989561996859`], 
     Hue[0.6499458125596493, 1, 0.10007502876356243`], 
     Hue[0.6499171656570687, 1, 0.1001146937055972], 
     Hue[0.6499599794841723, 1, 0.1000554130219153], 
     Hue[0.6499599794841723, 1, 0.10005541302191527`], 
     Hue[0.6496495783709015, 1, 0.10048519917875173`], 
     Hue[0.6499997433419163, 1, 0.10000035537273123`], 
     Hue[0.6499848496426992, 1, 0.10002097741780114`], 
     Hue[0.649649578370901, 1, 0.10048519917875254`], 
     Hue[0.6499848496426992, 1, 0.10002097741780107`], 
     Hue[0.6499962816736484, 1, 0.10000514845187147`], 
     Hue[0.6499997433419163, 1, 0.10000035537273122`], 
     Hue[0.649995891364032, 1, 0.10000568888057104`], 
     Hue[0.6452841317591498, 1, 0.10652966371810027`], 
     Hue[0.6473908758804225, 1, 0.10361263339633812`], 
     Hue[0.6473908758804222, 1, 0.10361263339633854`], 
     Hue[0.6447636185419683, 1, 0.10725037432650547`], 
     Hue[0.6447636185417653, 1, 0.10725037432678652`], 
     Hue[0.5666286137183357, 1, 0.21543730408230438`], 
     Hue[0.6334703961606387, 1, 0.12288714377757717`], 
     Hue[0.6499171656570683, 1, 0.10011469370559789`], 
     Hue[0.6499171656570684, 1, 0.10011469370559768`], 
     Hue[0.10275085519733629`, 1, 0.8577295851113804], 
     Hue[0.6499963043540927, 1, 0.10000511704817927`], 
     Hue[0.6424451989541748, 1, 0.11046049375575796`], 
     Hue[0.10275085519977556`, 1, 0.857729585108003], 
     Hue[0.6499165878991569, 1, 0.10011549367809063`], 
     Hue[0.6448435305234992, 1, 0.10713972696746267`], 
     Hue[0.6499169060240259, 1, 0.10011505319750269`], 
     Hue[0.6445750019051109, 1, 0.10751153582369267`], 
     Hue[0.6425433794512151, 1, 0.11032455152908685`], 
     Hue[0.6499165878991569, 1, 0.10011549367809049`], 
     Hue[0.6499165878991573, 1, 0.10011549367808992`], 
     Hue[0.6499948524777456, 1, 0.10000712733850615`]},
   VertexNormals->CompressedData["
1:eJw8XHc8le//lhFlyx4hq6JBkpFzkyIqK1JShIQyiqhEkUoUH0KkpGWGJC3q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    "]],
  Axes->True,
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Lighting->"Neutral",
  Method->{"RotationControl" -> "Globe"},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangePadding->{Automatic, Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563367593993874*^9, 3.5660870479853783`*^9, 
  3.566101829378634*^9, 3.5661392752617826`*^9, 3.614707872656658*^9},
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"9e219fa5-0d2f-4a98-8336-e967b4266678"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
   "IntensityFunction", 
    "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
   RowBox[{"OutputGraphics", "\[Rule]", 
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxcnWWY1UqzRnF3d3d3h71hcHd3dxjk4M7gLoMc3N3d3Qd35+A+yOByuXmz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      "], {{
        {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxEnXm8VdP//88dz3Dne8+58znn3tskKg1CCA1UVCikIlTIkIyhIlOojBmT
KZRoEhokJWMoogghNBlLJJTq93x9Xvv3+P6xHuu9136v915r7bX3Gt6v93vV
Dx7R59LMUCh0TLNQKIt4cSwU2hsNhb7MDoUe4/p6wg2EnXHHW8pCodtLQ6HP
4OseIS4IhS7LCYUuJQwnLEPIGPi+qwiFBnN9W3kodElNKDSJtBm1odAO5FwF
/QNyjiP/ufBcwfUHyBkKPRL6krxQ6HLo5ch6izCRtOcJu8h7C/FP5N2A/HPg
GYf8v5O+fz3POZjQlfutiJ8i7SbCzYQnCGMJNxJqS5z+JOEZwq2EcYS/4ub9
kfz35YdC5yP/Gt2rCoUuhh7PsxZTzguhX6dcPSn/NdB3w7OR8lwrGp7epF8H
fS/pbSjbI8SXUp4Xie8LuS0mI/8RwjvIGQ3v/aTNI7yP/IdIP4+0B4kfILwN
TzvkLEpQv0ahUHvoR+G9DJmhVCj0MM8cQvrZ5LmTpBcIw2nDK7l+k7z3IuMe
whLoI5Nul5HkPSzpdrkKem/c73sHdf+Buowk713I3Rc3/x+kd0i6za6G/2fi
DwkrCffC+xHxr4TnaNtzqP9k0n5Bzjqe+Q7lfor0JwnL4VlL2lLirwlPk/ZZ
MW0M/9OUcQ33Xif9M+JlxN8QvqVNDuDeg/C05dknUpbWxJ0ozxJkt6HuXaBn
6f2S/gl5X4P+knACvIuIPyfkJEzvJq0NZSxHHt0+1IG2KoN+gnxnU+fHiafD
25f0PoSm8NzO828jPMm9C2vczs/Sn78gflXfDeFT7i0h/orQi/J8iIx2lC0r
5XdyA/mupL6N+b4yeV4O6VN5Xn949sD/Ejy3wfM19b2f+5+ojxI/QPgUugc8
69XeaoOk2+8+fVvcXw29jfAI9OeUY4XuQX9M/BuhJc8cz/W70A8TP0R4D7pn
0m08CTndky77PdAt4L8Dnne4bl/Jdwf9CGWNptyPb4Xn36T77DjoZ6nXGt7j
2/qXkD6DeAzpc+vdRndBH5/0O7kb+nvq+B3hKeSWpPx+JpIehp6jbxb6yTDv
gv/Qr/ygItTpJ+KfCXfQrj8Sz6FvXgvPWug/CBnICxEeJs9u3u/dxK+Tvp/3
1pfwENdn8i1nwzOA+CDCJNLaUK8etZZZSxkn0m/vIb016d1J30J6Dem386wH
SP+I6xspwwfET1OGm6BXQj8D3YZ/43PQ7xDaQbclXEm+g4mPo00vhz6ZstyB
nBfgOY++OJTwI233L2Uexf3FpO8TD/SD8O3k+jPC54TrSbuLtCXQXSjbN8QV
lO0I3tFw7t1E2fcg5154lnOvG8+8gvS3oBP05dn8t0u53wn+JPEn8D9VFAqd
BF+a60+5/pS8J1D3O0mPUI5i0qtoq0LiD7g/gfRc0ou4Pot69SfkQt9DPQbS
D67lfgp5nyBnEO/tOa6L4W+AZzHPrSVejZxW3CsiFBO6UpcfKGMldbkh4fZ7
kvY8AP6llP8F+O9F/hDkT0beRTxzGKESWQ9z/RChGrqaOuYT4tC9KMMqytAf
+eOQcQvhTeRewfs/DJ4i+t5ByNhO24/g3gR4Z2X6vY7jWVNIm0wYR3k2kjaT
8mTCm0HIQvaDup/td5CR5fKL7wtkriPcxv3PS52uwTWaZoyB7kNdI2m/11Og
M5F1H7xfcT2JeD3xv+rrhfR5wsOk/Up5pxI/wfMeJ36M+Bd4nipzv81FfjZh
c6b76+n6V8GzTX0p5e/jJJ6Vwfc4F1mH1lE+6rWJ9FnUqxff2x/U69rqUGhB
0t/bEPhbUv5tpD8L30LSo6QPJf1o0jsSnqUsYeTtor2vhr4WmXPgfSju72Qu
4UXCN9RjK3zzoMfAN5rwGvRo/ZOJJ8N/dK2/5eKkv6fZmZZ1bK37fgnp65Bz
J/V6Rd+1vnHkrFP70ob3QH8BXZR2+51OvoMb3PYDoe9M+D0t5FkF8PwNz6mk
z0HuYfT3fvyHD6Z9/uYZrYgzkHkvMr+E7yyuf6H8vWm3NtD/wdOaOA85u7jf
Fzm7abtsyvQefXUIfSzMtxbVv5s+XEA8iGcsp/9+RXuW5/I/QV4r4gr9U2j/
CRmMGcgZR3oL0stJPx3eYp7Vlvc5lW/wA+JexOPhaQ1PJTyjyXcm4SxCFN5G
pA+Cbsh1+ijCFp59ANebifOJB5N2I+EO+sZc4m94/oXQM6G/hD4POkQ9xtEm
7/PMFYQyntWB+s+GZz08h5DWlLQ7uL6TvvApdXuA+h+I/ATpQ0l/j7Q+xJcR
akgvJv006CroIuhToSugC6H7Qt9NvXpyXc/1ao2zpK1S21LuOtJ28A5foP5p
6N+hD6S+EzVOk+devR/iBu7dD30ydCPoNch5BDnr1L+gJ0N/Af0Z9KOqL/R0
ZJYg61nij6nXR4QUeVvxjH7wtKbPlGabvprwNeUp4fon7t9Enet51kC1KXQd
9ADosdBp6P7QPYi757rND1Yfpnyncv0xZZhI2krKcDFtPg96A2nDoXNp/4dp
/720+VN638TtCb/TnyaT3jXX5V9EOJTyHs/1Y9AtKNPJxK0o86XEJ2X4ukuu
676QUE89u3H9L/XolOv2WUC4AvpywhPQPfXv4bmjuT4Imb1Ja4nMbfTt4dRt
JX36TMr6HP+gU4ivh3cMIQTfj/BsJSyE51VCjLQDVCb6w1zK+ivf4WHU4xfi
zzWWwvM+IQOe6cjLJW5MmAfvJTxrG3xtyPshPL9BH0fZJvGsayjbBO4fTXwd
/C+QdjV0c97NxcTHEh4m/ZqU22mT5uHU/QzS91H3X/hGzyBcz3UPZD5I/uug
r0y5PX6A/+qU22wj9H7a/xl42hCPJr2Ed3Qb76KU6x+QU0TcgXLel+HvqkPC
dBfabQhy78/wO84h35Fcb6cMTyDvCerQkevhfO8XEl+gd0va2cR3wf8m39cj
Gm+53k3egcT7yXskzzqC0Iz6HkX8NfnvUf+G/hb6XH1z8B+geQRlGY+Mo0i7
Vn2GuJr0y6Hfh38Vbd2etDa8lwy9W+Rn5XiuSlLoLK4fou2fQc5YeBtpDOT6
FcbeTOp+ELLnQb9IOBC6NZl+03dNvhb0hYMIG7huR9yW8D30NdSrhGcvJM9A
+B5A3tPIP4n7vQm74bme93UyZbie+32I58MzSPNprhdAz4N/EO+mn9ZVfEcX
kX4gfBcSn4aMUwn/IWcFZXyH8Af0SuJswl/QPbjflXfwj/45lPkb4t7kvUD/
E+S8zDM2kjaemOYJvUG+euq+hbQJtMN4wnTufUveM8nzDXE34sbkfVZrCuSP
gyesuTn3mhIPQ/7V1Ksd7bSO93M5fb5a8xHkj6I9KqErVGfap5DntYVvInKO
R24D6TdBd4ZOQR9C3Vfxrgcz/vxImbZm/284DOUi5yfoiZRhBPLDXHfQeh26
CHog9CjN3ZBRq3k+z2gOfajWzdy/nvu1WmNDH8OzklrPk3YcdB30ZdSpjgdN
QP55eqekx0i/D/ldKE9P6FdIPxa5J0AP5P5xxPO0nqUdXiJ+UfMFePpzrxP3
nofuB30M9ADiLsQvwtcBGYdDH0/ZpsJzBNcduB7MdRdCV8LhpB1G2nF6R/Sn
ZYQjSbuK8lxJGEM9XqaN7iJ+ifhwXmYt7XMl/f8w6BroK6BvJc8hXI+Avh36
COhroP/iPXWA3sa7G4i8AYS11HMS8qZRpqN59knMJTbw/Af0X+cZGyj7Sup4
v+acyGqpdb3GSUJ/+M6ucTyFF/AgPD01J9C6HXoIdH/oocQD9R9VO0OfBb1Y
62N4zoA+nfBz3G2xnjKdW+O9mseR+RPp52hNSvqJOf5Grg55n0X0GcpDvXpw
bxT1epM2W0t/60RZfyHvUK3TyTs7y+18LuFkytAW/hdI+5L32Fp7P+RtQl+Y
RVpn7XdwPRN6JnXvTBsdAE8frUMp27HIa0F8E31vIn3oUP2/Cd3hORWeadx/
lnAVbVTDP7aUtp8Bf5z6RuB7h/d0NnlP5HlRrisowyWkVfDMZqRv1L+Uedu3
tP8xxJdQvxORdSz0pfAdTnwx8QDmbWOpa3uuL9RcmbL8RrgI+jzynEecQGYb
7p8PfTL8LaGH6v+gNSDhXMJgQqOw6bGEKsozAp5q8jYnfTB0T9Kb8z6GEf9G
fBDpQ0jvxXUD9DnENxCG0F5niqbt60gfpPky4S3GpuGqN3SHsHlGEZryD7mA
9HKedRByLyNtJ/E5yOmj+TVy5tB2lbThBMp1G+/u+Jjnl//ov0abH6Y5A+38
o/4/xBla00C3J302eSs0L2We+zrPOERzH2TvIu+GgOdm3sO3+m9AN+F5R2jc
hOdF8lZDrybvbvi3wNOB6we5LoZ+m2/lXPhOVR3J9xp1/IX2r6B+eZTxh2zv
xeQQbw7yzkNmDfGnmuNnOf1wzRXijr9H3jjKsyngX0J9Dkd+PW0yE/lbkP+v
5sHEmwhnIvtuytFWa3x4OtR6zZFH2uXIuhf6LmQfWet1TAHpfSnfFOhXtZak
j92KjGa0zR763mn0s1MIA+C5XnNjeAZC36DxA7p9rddSOUmv8yXnMe1f0GeH
ab9D60PiRzO9LkryzsaQt17zBJ7VT2ss+mZ3yn5Ntt/3Rt7pD3nuW0O5/wjx
Au0XUN/PCGeT9rT+x+TpD72atF7E98MziLi39jWgzyQeqzENOov4+6BvjOJ5
N3LdhDIcpnbk/mW0TRPos6B/IG5M3b+iDk2QEdcYpz5Nvq9JawbdQ3sYms8g
52jo+ZShmvSzuP6MPlwLPRD+i6njQNKKedYU1leHqA2Qv570L8lfhuwDub6Q
9G3EBxCGQP9I3Id/xvHUsZP2WPS90w8uQ9ahtd5ridLmYc3zud+fZ9VR5rTG
P65/Jt9PhHPhf5WyLSLkkN601t/gRuJmtf7+NhEfXuu9ghgyM7P9Laj/Lyt3
/A3tM5e+WgX9EX21I+FTeJrQH4/LMH088bW8tzXQeVqLsVbdQL4s5pMfau+J
tMcobwZl+RueHlzforV2QGu8qs71mNUl5vWV1lbb+S4+gacp9FE892PoBp5b
h+wupDWnP19GW35FeiuuT6Nv3IDcLzTn0HslLQXP67THlwHPgoBuCf078j/T
vyLD8/vVOc7TJuq6HJjheG1AFwXl1DzzzwI/RzInRV1mjb9aI2mtdAbxeN5J
ijrfQBlvTXutfD994d6o14qS8wbv94xgbXyEdAqqN2U/BnpshteGIwOZGrvb
aJ1GfCz3V1KXZqTfwPXhtHk+Mn6s85o6rrk36UuRfw/PK+O6K22bJD49w2u+
VFBmzR1qA/q+qNe0eheaU1cG5fyy3GvfrTz/VuQfG7PM13nu07zba3nXnWKu
l9a/68st40f4H6c/X5Hpf9AO2nxd0OZLyt2u6+H5j/b8mfRjtMaB/0XK/QvX
r1HH7Tl+35Fs0121jqUf/Ap9MPFI2vc36E4ZppXeGfoPZG4L6J5VptVnroHn
90DOTdRlZ4776O3U/a+gT94G/WeQflSGx5SO6rekfxf8T3YQ/0Hopu+Fb6Q5
8dl8R2/UuF4v0jY3Ir9DzHL3ZvlZ4r+tzvVtSfmPSbn8b9a6fdQnC1Q2nvV1
MDZdTpnXq77Q88s9Dq6l3W6A580cf58tY6b3SH9A+rs5HmOuos+NphwH8MxW
8LxN+n/w/CSdRpD3FHiu1fyFfrqFdltFejbpB8csZy/8P8P/Xo7HQq1jtYbN
VLtRz2+1J0Uf+I28vxZ4Dayg9XA6w+vjFUF5Uhm+p/QZvOtZJX7eIq3T9A/g
XW0v8Lq8IcPrZD2rTt94g9vhJdqqVnWkT5zE/RP4x10NLSVgZ+jLoS+Cjjd4
f3YY/Ofy7/1Le6f8M5+GriJ/K/7DCXiOgmekeGijztL9QQ9gDtmf8A95ziYe
RNgNfSpl7kvYpv1oZL3OszprH0XfsfbENH/k2z9Z+7rQjWnTY5E5CpnbqNu7
5JtDvre1H6z5Hvd66D1yXQ59Cvn+gN5BiCFvO++ukPtxnl9GWEF6NfE20j/Q
PA56P/R/0LPgL+D6TL6bAug9pCfI20tlh/4ZnjTlacNzLqY8H+p74Zst0LxO
44DmDIQvyf8FoQflm8x/5RHCSvh6Uu6eWpdR3+1cnwBdAv9KfYPa/9J4pj0x
zTG1V5swPYTvLk/7JNzrhox+vPOLtSet/5Dmc8QHIrOesrWlbJdQtlfh+xae
RcRnwF9GPeZr7sg7agfPcHiW8b0dAn0pdHe9K+r4I3m6wHsJ8VSefTTpHQmb
uN5D+28hfh2ZBfC8AV1G/uUa77P87L81NqndoJvznl+hHT/i/r5s7xO041vo
X+B9A+0vXFbl9f0Ayj+b58Rpt8a0Rz94Tg/W7DnIiVGHI7mOQtcj89gCr3O1
rpX+blSl17mnIOcE7nUv8Fr+fb7BnGC9P5K+MaLE+xJjeVZPypAHna/9Wu73
QdY58NzIvQLSLoOeCl0PPZO4VPsd0CO01wEdgm7QnjP5WnDZhHq/G+yBHKf9
hALvLTQQ1xdYn76OfJ8TukMvhXcf+ddr7sj9JgXed2iN/L+Q9ZX0WoQXSWvK
M5K83xbE52vvnfrO1TxK6wv492rs1jxO8xl4OmpPjet5kq31GOmdCK+QdqzG
1ix/t0U8/2PS6qAPROZq6Jd5vyXS3UA3kP58tfc6DuZ+e8p4SLBv04q4ZbCf
c1iB9wG0H3JSufcDntSeDHV9S7qkLP8bGhEaE/LhXYb8UuiLKH8GfPu4rqce
C2iXprThFvp7Ln2wMWEzdI7WWIT3uNcNmdnQ9/D//4V/207GjZvpzzuh90Lf
Cp0lnR7/1cnSfZC+h/QbSf9ZcxDox7Te0ViktTLpP2ncgz6f7/UTyjOZZ+6l
LOcSXofeSbyE+CHtlZJ3B/y74X8Iejv0P9KfaM5J3ue0z4uc54k/5N4A6GnQ
7TS31N6C+qbKBP+rpC8i/In814gf1FxH4xr3dyGzA+9jHmktiR8n/XfS/yV9
CDIHa39W+57EC2i7Z6DDjEfvQXfkWx9DvbZqLgT/Lsr1F+E6nn1JwmvN2/m3
/Ep5Tg17LducvnE69GmEVfpvEQ7V2jjhecit8B/C9VXSUxG6Ql+hfVbo46Gv
lGzodrVe0+wn/pdnniF9D/fa1nq9s4/4LsrWWmtl6InQraAroA+hnkfA+x/P
vEjPls6Le21qvSbaK51Ordc4e4hbEyZD/0f8KeU9geedRJ4Idf5Yc3vt2dJ3
l6v9kX0Z4Sr9O+kfV8I/X3o17u2C50niJtxfTDu3QGYCmcWkR5DXl/QFKf/r
S0kvR3aC8DN5XiX9II2ZpL8E3aCxAPrllPtsPvRzPGs/vH14diEy+xLn6VtJ
uo8XwPM9Zf+OcBr3nod/hvR/2osnXqt9RekSeL/rtC/G+/0Pei/vN5e8nSjf
8fpfIvNB+L+H9zh9J/xjN2gfnPsrGK8PkB4N/r9I68X9uOaW0CdCl0IfqvdA
qCT8TZ8cSHiM+3P5987RvrzGZkIFoRqeVfwfjpZOlrgL7+wzzYmkB+d5D0iP
Q3x/rtP/1Pxbe4mE9vp/S/+R4b4+hfydSH+UeCbpKzP8rd4BvSrD3/kb1Hs+
1/cRWiD3Tu3fES8h/SXouwlfQ+8hPhn5H1P3vdC94fmGdv1He3yU+Wvo9eon
8DxLm/yL7Eza5A7eRTbtdw//jWXIeUU6JcIkwtoM/0fuhOdgtQ/8fRNupwvi
1nc1h29Ihud9mvNp7vcKz2mR7/npU/TFX0jLo1+UkbcM3kry/kVaPMPX08lb
orYS9iPA2cTgL4Y/THoc/idI/4n0ctKblXgPcp/2P6WroNyb6F+zc7z3qDLM
hP42y3PXn/lX/0RYnGMcifAkJ1CnswPMztaQ8TuPQv8IvRHeHwjPam+W8E2W
58mzqNNMwkaup5YY3yOMyNQa44Ama31TY+xJU/rqSMr1Yo51Q/No4+/I9xF1
aq69WNK/5/ox5E0hvAtdQ/qNpL8HvZ86v0HWfWXGHgmDdIQwUAE+ShiqEwMs
1kzuHVVlDNURVcZoCZclbJAwTcLhCLvTnDFohNYO0B2lV0XGqwnjoIQd2sOz
7qYvvqw5M+WdQXnOR9YrXF9APJ84h7o8Q/pBUeOXhG/6NuSyCnsl7JpwMDdB
r5DeGfq/uPFCwiBdSV0ehz40aSyV3rXea12JcTzCTk0vN57n7YQxPMLtbAr2
vAcH+7HP8X6mB/vPLxDPKPD++YvEcwu8r9620nu4s5HzYb33fqUzOSTHe7Zn
qz+pLlw/x/UXfDMtoC/h+V9BHwV9NfS6pPdoD2Q+cg/8d2tuxr3PtS9Gei3v
ugn0KdBria/i+VcWGGtxS5X3868p93689uEvCHkv/wjSzwt5j/584u7Bfr72
/IdAf1nh/f4ryHs2fesk9QO+014B1m62eJL/t6eu/emZgZ5I+Cj1Q2Gh7uCd
fqH1WMI4JOGRuiWNeRL2aUXCeDZ9p6v0biqNm3pc+1E5fkfCvF1QbbzT+cTT
S4x/El7qTuSs4/4c2ngOeb7mWR8gMz/h77yQ9/99hfGSE6VPo20eKPCe/+PE
Uwq8n/6l9kkKjIOcQ1/ejJwE/W0C8j9DTnHK+KlntJbm+psC48aEFXs6x7iq
HVLhU66HSb8r37jEUTnGVwlfKOyWcIfCJArTNVf8RV5nzcr2fF5rK60ZNOfX
XF/rH+FxWgW4nZIir8dmat+QOpaQtoQ6dqz0Gu0o6hjm+XfCU8i9rYxNd4WN
+ykkb14wF2xe6TXFLNqmnPREsF5rFMwdO2U5j57bMstz1E/DXh/Or/Bc91jN
/6OeM3fJ8hy5czDnrEFeVZHXfU8zds3j3aW47gbdmLhRkTFdwpgJV9akyPNj
zYmf0zxKe5707RlJ42561hqTJQzPn4QNhcaVCY9WX2ms0V2U6yfe0zjiofTV
mNYwwrxlG2sjvI6wOsKzhaEXx43JyYJeFDeWRzy6fiZpnJEwXzuQ+bXW69BT
k8anbBNeIMC/PaL5A+ntaI9Tee51YeN/hK3J4n5mgJF7AZ7fSPuHvNOSfl43
ZD6tMU66VvL+njIe6Tq+97EJ8wgvND3psgsfd53qTSihT22s9hrjB+LiYB1x
DOWfyL2PsoxLnILsVdCvJYwR1D9yV9I4QvXJ3dB3wv8xPO9zfUuN+2aEsvSj
D9+l/RHproT/yfG/Myvh7zWLsn1FWVZnGT8pTKnwphrnhM/U967/e+MS4x6F
Md3C+7kVOY9SrutqjAnen/R/WthFfc/CnApLqm9PWNQRfBtroW8j38os4x6F
LxVvDmX4knnToIgxq114VudgzqM1mtZeWoP9R9q/JZ7/30Xeeq2nybuPvrSH
MDdsDJOwTLMpTzP61TzSplHeptAzoJ+E3g/vbOhntL9Av30N+nnof0mfqf6e
bazWUaVeQ95PPSYRntBeS637b5j32wSZ06WDQGaYd/dcsMYv1b9Renrie7Q/
TNpblPPuhL/PN6V7rHUfnk85f+U//yp5ZyBnob6fYB2qtY7mhP/wHwtTziht
+DL3p8M3HZ4jaP9i2iObNntY84oy49tytDYvN/Z2Bs88X1jxAuuar+Y7GonM
9chcQRm/4/pL6Pfof4NJz64wnkm4pgf5Jx9Pm3QtNG5E80fNPTUHreY5f5V4
Hjkh1/NNzTs1R/2V+CPtSwZzzG3QHZC5kPL/S5t9Tr7DkXkYIZP02+GpqDCm
ShiQ8fTbb4U7gb4Iep0wG/B2KDSOSniqVvxbNtJnbtI+s+as0tEQxmruCf+h
0O21HoCnf8yYnFsLPUfVfLhBe8nEZcJVVnjOWkf8apXxLHGte+C/otDrnWsL
vV7UmrRphdeke6SrJb1ToTE0F/Mup2geTtm20Xbj1SaUty91+JP3cRb/h1NT
xg4JY3Up+S4p9DrqIuILC7122EN5zyQ8keu1gObRmk9rvaA1+xlxz/1Ff57h
tbPWAFqTN67yOvqACq+dtbbWmvYP+s9RfIejuD5IaxDtz8D7F8/ZRngk11gf
YX6upYyboV+Fbktd3qWfTNeeCdfnSM8M71cZ3jNfTNijMazG+pNBtMHSGmOX
Hmfe0RxZvbSvX+d98h0F1q/8EexTa4/6dfibZVjX83iV98M/0H6Eypdl/enM
Go/npyN/Ybn3ar8gvW2AcdI+sdYR2v/V3q/wVquCfV3hrYSRapThPWmtNbS3
rD1s7U1rX7p11BirWuhF1QGGqsIYLe0hay+5a5XxWj/Rh/+lHkvyrRM6MWVc
mfBxy0hbqv0u+sdLlG1eifUE3ZA5nHbLR+Z99cYATiL+hXAXMlvSPpW8x4pC
4xQHEZ+psT/X+DZhoC7hOT2oxyO8j0mlxloJc3UV6edKb0m4B/6jSN+qubp0
IxHrFKRb2K7xFfpt0udQrqsi1g38XmEdyLukj0T+TO3LZFj/IJ23dBBLZTeS
ZT2ddAXSZ0tf8FKN2+zVeuuQpbeWHvmHHOubpWOWPk56if3ab00ac3cf9Z1T
ZczhXuGO9O61bq2zXcwbWbbZuDXk8eXpkO1URI/THFT2MIR+ObY1kR3NZNJ3
0i5/Eu7nHXwa2J4s5d5PSdudXKw1ouav0AenbSMj2X8ia33Sax3ZK8i2ZWrI
dhzvUaa3kPUu8UMlxqMIqzOTOi8ifTnprcj7Cm1zEN9406jxGyNCtpt5KuQ1
mGyDZDMyJWT7IK1lZD8iOxvZlej6l6TtYFqnveYQ7kT4k1+Tnne2SRsfcj59
5jKu11faLmMIbfhB0liepvDcXG1M1FDS76CMtxcYg1RV57XQSOJ+NcYz/QHv
H8Q7So27uhjeCwj58F9H2rWEgzUXrjKW6nxk3sv9ewqM2bqZ+MYCY6tupm3G
lhgHtY60zwN7J+GYhF+6lGffTbv1IO4rvRWyx5Ya1zW6xLitKulv6ox/uZZ4
LDJuKDCeaiV1PEHvn7y/JT0fH65/KfcvKTBu+OsKY3fGlBsnI6yObKb2Vhgn
GBGWsNC4QeEdYxXGdP4F/wb+k1fmGg8p/Ke+L/2vN/OP7EPop32iXP8n9c0L
/yms4JIM40n1z9QYsJNyN+cZfxBfSDm30TeOoG9clDS+8ST6ex/CQ9A9eF/D
k8aQnk7annJjcv8UbqTC+MMdpJ3CvQfgOQ7+k1PGRn5K3RsajIUWJrpxg/Gx
wsk+1WA8sHDB6zXm5hurKtzQ5SGvP7eWGgsrbKvwlfrPSO6xDf7OhpH3A+rw
nnRtxL/G/U3Kpmyp9j+yjHd5m3tvwPMW8YFJ9/XvNQevMN7qRsp/TIBru5J7
zZO2e9ug74Z7P2ZZz3hRtTGZFxJ3LDFGU1jNLTFjpYXjFEZUc4MTA4yo6EmE
Q2jvdoQBpLUtNN5auNWt5H0owII+Um286cPCR5QYMyrM554KY0czNQ+hD5yX
a3xpd/r8QmGFq7zWEc5f87atVba3ebTCNiuyY3mb+61LbQMgu5Vrqm0LMJK4
a9Q2E2/Ac2SlbVxuIe+GKu8p15L2sGzNtN+WMpZpdKbxIsvrjVURHmpDxHim
6zKt15I+SzY70kPJnmUZ9JaU1y6yD7ixwrqv5rTxt4W2K5DdwZ8R662WSl8A
/xrijrW2tRkP/4pM23e8n2n8imxubuf63Uzb4rxH/DzhhBLjw4Qn+1069Hxj
xYTLUvlv09w+ZZzOIcjvFeDKhPf6uNDYs6O5fpC6j4BnGP2nB+Fh6IPog931
z4W+sM7769qPFw5nU8S4lVuhv0h5f1v73A8krZv9SN8H9HDpDKEnJb3X/kHK
uDPt3wt79nahsWLClPUsMf5NmLcbA5ybsG39qoyzOo34dfJfSb5WPGtSg3E1
wtfcl7Qe+F2t/6qMVxtaYXsO2XWsIkzMtq2McDCy1ZDNxoeZtgHRfdlDrRVu
hH6X4PodYU6gyzO936p91yN45jOF3qPWfnVfvs8076aZcIKECH3vE+0Jk7aF
+lRJ1yBbQmGbkP14offFu5J3erDvrX3wjbnWE9XDH620DqkL5V9VZf3syVXW
MWl/XrqlrwLdnPS20uVqn1975Z/D0znYJ5cOVunS834Q6H8P1P5+pXW4PSqs
z5UeV/qDPMoeJazn+tOU9RTSVzQJsFLCSG1NeR/hGOkxaPPp2ksg7clq48ca
0c/fqjdmTNixR5LWzX4Dz2NJ99kfNF+THgHek/gnT5H9Henfk35gqbFlFwaY
NWHOhFv7lntPE1/Nv/dAtYXspogfTxorJcyUsGODw7a1WZvyuz9Cuv6wMWUv
ZxpvNj/T/Vu4tYWZrucpYWPQ1I+fSPqbE3bsyaT7i/BTU+vdb54mTtCGB5Bn
MG24JuWySl/0fIP1PtL/SPd0X6b7a/+ksRzCNg5Ies4rvNUo6pqTa8zJaOhc
6KO1xkj6vy48o/aztW+tfTPtt+8MGWPamG9yO/Sz8HzD93JRxPvkH9TYtuYN
7XWQlp3r+eeKGuOVXiP9RNourH4n2zXZ7ApHwPUy3uMi+uvrxHt57pv5xqxM
gT+itR3vrJy+/ZrsIgj7coy90xz1Y+5lZxvTmJlrHKTmotId7Az2EheW2C7j
kmD+/2OwP6+xbAv0v9ALyr0u+Ix8bwRj3G7SEynv8T8ujGfKe5vSOfSjrcqR
Nwv65XzjaoT5ahMzdusPrTEStukojxvnJbxXPtcPVHl//Dfe44HBnvkP8PfV
/hLyH9XaqM62qs/UeG9zE/f/DnmP85+Qn12Q8p6tdAj5KesUpFt4pMF7s9Kl
NEHOD9APQ5fCsxH6EehTkt4jn1xjvYr2XXeFjMVYRTs20/9H6xKenZ9tTJ0w
WXnQ55K3hdqyxnq9qHAUKdtByPZB2PgC3lcZdTuL93lO0pglYZeaprxO1Hqx
bcq4JuGbhKNbEqyhxuZ57bAPWd0D7M3ETONwRkLfmWlc512ZHj+E87yW67sz
jQe7h/jyTOtk9S0Im9qh0rid2nJjQYV5vE3/sCrjQmNV1s9eFWA7L62wrjZZ
bsyPdLjCqZ6V9JpXa9//coxrFJZxMvn/1p4h8ds17m/CEe3OMVZY66b2tMch
JcYHN9Y6lrgRZdtDvquDdZkwYyWan5JnZY11Ze8gp5C0glzjIYuIo9leR39Y
Yzu1t+FplfLadxFpjWq8Dl3CNzU7WPdpHXhgyuvaV7h/QpXX5YvLjatsFqzL
hbmqDdZ5A5NeWwtTvLXSa7w3yo2Rk+3R4hrjooW3mg99Ee1/IeFgntmIOrYm
vUH6u0LbZsreUrgd6bJHkH4H6bcRllKnMbzH0fm2bxnA3GZ/tukbSLs+3/iY
/qTv1XwA+lnmbM8E+JPp/MMPFwaF+3UFttWVjW47ynSedNC0Q0a1MVMtte9O
2pvM004lzyjp/PMt8xLaJFd7R/D8LrtXwk3cO1D70qR/qzIxHhRqrS19juwL
kLmH9PXU5zC68KoybXC6vIdA3pjv70L2QT1luwH/v/AfIFtSYZQJM3jOMq7z
i40V0/5nA8/pI4xNzJitf9RXiZfQN+PI+D5sfNpBCP4O+jXS7+bZ/bV3JowO
z8pG9gKeNZDrXZr7QZ9FO2QJQ468pOx3Arvmc+A5K8ChPcQ7OhHZq6jTBbXW
J5Q1GOsm/UKKshVJZ5VvjFrfUmPe/iTv25RjGWld6SdvU59CeM7W/kvUGDnZ
O/cWvqjImLHjAvzUIuWB7lJkHFUP6R6KjLlqo71M2uE7vXuenUf7Lqf9PyLt
dOTu0jxAtg9cfwW9s8p4n4WU5aAiY31eIv2XQtskPwq9LbAbngLdBp6Di4wp
ujzfuCnZB22jXr8RrtA+WoHTD9B/ONsYnibaJ6+0DfQjFbZ13p1p3cP9Ye9L
Szcg+2bZ1crOVrbSmVm2sZWdsuz3ZTNcVGNb6ELiw4kjebavzghsn2WL26jS
9s8PVti2V/a8spduqLQd7v3ChlDOX/SfROaxpFdoX4z0l6hfk3zjsQo0lnI9
UvZJ3F+j/y7pH9J+WYSdXL9FnEHYrrUEMk+Juv8Phm4m/I++TfrSIOkvae+4
9umReasw4vrv633wns4kvjnf+9U1WudBDyO0Jr1P1O+0MfR+YVKhT5VtQrZt
yfI0P+feVSoneTvpXwk9XDaP+ea5WPYohDug07TZwpgxckuIT466P7wK/R/0
F9BX0LYzKOd07a9rvanyk7+cvAV5tv0vI54Ts13/UNngwDue0E94QWQU0beL
aO/+2bZzEV5+gP5t0Gtoi1nCSBGXhY3Vl11Mf/nLyLS9yUbq8gPhFK4HkH5a
pu076vi+DoN+jX/q1nzbYsj+4l/K8A/hR67fDOwCBpF+X4Ox98Lg38P3MBB6
GXmXp2z/cgHfyroq4/ZPJc4jX79s29q8EqyLyplbZiDnC97lQ8yN307ZXkB2
A+8W2qZANgvCwAifKUzSmymvU2XfIJym/ufFmcZjSV/wAPcX5xqrpTVM2wrj
whoR76PN95YEWDHkv6N9CM0Dq4wpawzPXaSPJ7zB9d/Ue1epMWd3Fxqn1EH/
Aa3jco2Faq89E+J9tOVyyvt+rtcsTZDZMVsTJt6L9gcJR2utS/pN5H+3ytg4
6TLupcx/1ViXMQn6I2S8rP1b5HyqfaMA/7Nae0S5xqMeJf0NdGviCN/ax6oL
9DvkP5/7w2n/taR1Im8Z1/cmbR8hO4nyWuNY79U7pH5n0SYj6WNzoHO0HlHf
5vrCImP/riJ+Tt8n99rynz8b/lFFxirLxmu4dIGVtvk6RustynAHZTmXd7qi
wnjmbrKpLDLuUHb4FQXGeQrf+b7wT8TdNaeuNub3XdmbUJ4P6av3ku9uwtyY
fUdcSvp52hsNfFnIV8YYyjCsxP4r5NviFu7dHOBFB8N/O/Q42RxS/gvgmwL9
a8r+CTqpL1UYZxWhDC8UGuslfJewYsKMTWsw9koYrPaZxlvNLrMNzJ+5xmu1
yTR2q3e2bZaEQdI3dSXf1+fVxmatJf4235gnYZxKaK+YcH0Vxm2JX+toYbna
ZXpt3k22kVqHk+elQmOoTiHv6ipj3I4nb1+N0dw/hfgj6pwh3W6mcXBx+TdR
X4p4ztwd+pOIsXPdoBcUGosl/JtwcMK/yQ5IWDSts+enjJPTeny8xr4cz8Fk
B/5Nue1D2sTtH+Ag8t/M9YAC2yZrTq44K6CLhBMqsV3rGMo1mtBa74x32ypi
Xs19pGekKv+bvyiv5jCFwhuX+b/fin7Rsthy8knLK/P//k3i5YR5hF55Hru1
T7uq3vvMz7EuGcnzPyn2eHKNbG2j1ld+GrNfCI0da2Ie07UvPYt3diY8x1OI
k/Js/ybMzAt11nVOI26LvN55np+9RRsdK30CbTa7znvFzxN/TL6WEeOrv0JW
KfGRyH4H/k7SNcCfH7Ounk/nf5igRI730N9L2nbzNvmgaLCu9SPigpj9IzUO
2d5Z8z/N/YQbiuc4z+By+0kaXOW5hGyXhc3WmFyTY4y09vOVPkH4+aRteUX3
pN3GkOfFOo+F2i9vzr0lwRguu+h2xbY7ld3gp/A/Df9S+G+kbW8I9udPpazX
q925f2Ke57Rq8zbFtqvVvKpdsM7SntqJwfpLa67lCfuk2ss7nZZv/1PCB8gn
0pdZxgjNzjetNarwBMIVfE38fL4xWlug30rYr1Io7jWvcG195E8lYWxdLG6M
kbBGudCjeedzcozPu7XOmL2TtX9D2vpgnX5Lnct0E/Er1K2J9NT19gElHuH3
rkPOCznGG42SHUWOsXqFCWMDS+O2TdZzehO/mG8MnuxQdhdY/yg7kVuF4yux
bkK2MO8F+kXZyMwK9Iuv5Xj/pFh7FAmv6zvz3l/I91pf9i9TAx5hkFYnvP4u
ilvnqXW+1vifJtyWxaSPk4178D5alLitxbcs2MfQ3s2MYO9CexrXC48UXMvW
Zm6gK5WdzpygzLLxeSvYE5mR73chO5lEwmvAGp67LmGfE8dR/hYxt6H4W5ZY
f6q2+0v/j+B6bNS2P2qHLrTbkfSrbZS5rsZzuQuqbK+vOar6cEvZ/sGf5N2N
Q8458B/F91lCPysucz9W3xf+rZvascz3leeSqPVM0jHdqz2kAuPwhoSMixsq
fRLf3XDim3nuxrixc9/If12J8wgTeDT9vzJm+thi25N3hq6OGRvYmzwzAwzh
sVzXxvzck0m/OGrMnp7Rqdj25125vh/ZF0aNMxxMWlXMtPCGun+JPgHtk5TZ
Z94xxbZnl/xh8iUQs2+F44rtn64X9Gjqcjr5RlOXrXHrVb4vs26ne6Dz6ij8
f9Amui/9i/wJXl7u/0kH8t6Z7/TT9C+jnOdErcs7Pmg36RS3If8u4l/KjGeU
fOmPbi61LlQ4wtd4x8cHz1rAP/RS2QPpn1pmPelJ3EvF7JviLO1Ppe2fQjqg
TfCM1v+Z8jxMGboWu47Styq+hnsLte6AHgX9RNrt8TV50/BMDXBLF0X9jtSe
I/Lth4Lh739rNdnAaB23nDI0j9jvw0qe0zjfthjLSD8gYlr3xK9/snxg7IAu
VnsU+J7StabXv112Okfnea0k25l0sX3kad1ycrnHAdl3yCee1opaJ74H72lR
819K+RuC9cwlJfrp+XsYVuVv5VSNFXnmb0H53ozZf4jWYqqXbHm0Ds2mDbPK
vObLJc4s83rmDMLJBd4rubHKfXlkufdPZDPUlrx9CmwHpL2LJsX2laF19KrA
Jkh0pzzvh8hO53P+p8/Av4zvtGmwdyEbIvkF+VtzY2ReUeL9DaWfJv9hMf8n
D9VeS57HoA8CvyJaY15e4vW75F9U5X2R/pSzotr8X9OXDiq2rxDVRXtEKj9d
M9SC9O553ieSLdT+oF7aL5I9Fc0falZsXxySq30a2VK1If2Iau/7tOeZBxbb
Z4ja4Yhi++BokuP/4bbg/78L+X8V2L63ccx9Xn1/S9I+J6bRNxvF/F3L78SP
ScfPkd4qbV75QryKMlyUY9+YC5A3v8B9/WPijwjDoK/mHVbJ7oXrT4TTC9Kn
kNYk5u+hKXHfHGMgxuYY3/0K9boG+Vfl2KflSPm1y7GP0Ktls5ZjXMSBwt3l
GHu9Ctkr9U/m+pSI/Wi+rHaLWrbwGCdEzCv/ob8njT1vrVjYW/gG6HsuMBZR
mMNetOHj+cal35g2rvuQpL/XD7M8h9iZNCbwKOIdSfO2Tdrf5vtZxnvPL3Ne
+aOUT07lFaZd2ETxLCE+LWI570Av5oU/R3wn/ef1hP1NCqN+esRYyndD9ocp
jOWxxBkJYycz4vaNqfJ3Jt6XNDayK/EBUdd3AXzP5ttvpvCRerawkirLWRHz
y/9kM33jOcay/Bk37uN3ynBAzO2kd7Ep4X3cg4Q3Yc7/kvZVhLWDnkBYBn1C
wmuO8+CZkPb6cZxstvjILpSdLTyT4B0mu1zoZ6Ff1l6K8AjaDwvWQougdwbr
9nnQ64K16LJ66+xuly6e9B8C3eKlMfMor2wvtbbXuv7DXOv9wlqnwP97ru8N
h/+zQP5C/dtyvX7LoZwXyb5XGDniFYGu8RLoNQHPz2mXcw7rmtn1ti84XDqQ
tOXP1HpH+M5gv2JD2vV7lvQa5C/Wv0zr83q33zOkn5Lweu1y2m2Jfvxhr6de
g94XrNe+T7u+0+RHU342pBuFPjpmG2rtvT9Ge04hfM29ucRzCLuhN8K/iXg6
/FvSru8s6BHS+wRrztd5VmGwz7IMujTYJ/ox7XcxG/6lpBeHvZd0WsJrxKsp
83PcOzXb67vssOnO3Ps4YpunLtCz+dbqY54nLEu4L/5X5j022SVoD7oy4f38
tLC+CeudNguHmWM9lWzkpcPamWV83cFR29/INrwyZf3VaaS3zLdNve4dyH9/
idaD3H+Xdcc7RfaR0C7DcqTXeK3e89HalG3M5SNFeD7ZtstXhvBkK9OelyZT
9osivxDClt0ata8V4c9kiy+MoezoP0l7jl2Xst8S+TMRzmxN2nbf9dJpJOxT
Rb5VdhbYh4L+1avSnt+mZGeWsswzqddLwb+9njy3pI1LlH29bPPVB3S9Nu32
aka+56H3QLeHfrnE9vzyMfEK9MH59j3xedptdQA8P9BW/2ieAH1oidtBeqAj
Yq6v9EYv6LkaG+E5Mub2kV7zqJjbQXrNWfBkaI9L3wh0lvSq0DOh98NzOHTH
mNtEuk/5j8nNtg5UPgmkb5WPArWnfBzI10F9wv41DqStGpP/vyxjOBfl2C9G
RGuWtOfw6ZT/d/rXaT32cNrr2RX6TyeNN76dca0k5vHzGY0ZGgvh+YT7HYO9
6Kc0TyzwfEDzihPpJ3dI90E7XcoYXEz69dpHJ2+9xkPylsY85ss/2JS0x+Q1
pE9Gznmyt+W6LOZxfxo8j8HTjLTPkp6jyd+Y5mnN06YfEBal3nPf63juBcho
l2MfTZcjMx7zvsGT0Odzrw30RRp7C7wufgQ5afUp5HdJuz2ld7uG+4mY193C
QS3Msl+pQ3O8/j9H+wAJ7wGcW+71guYJ8tlVE3O95O+rIua2VZ5ZBV476Bsf
V+C1iZ6tua7mcnOzvDZpFMjROuj4QI7WJmoHYe/SwrTk2Afco7J7KHC7TaZP
Do96fv6txgDuP0mdNseNYdzA/+TOEq9B2gRzeLWV/Mr9kLS83ryvupjrqTp/
l/T9p+SPJOZ9FdkXCV+if7/27y4Q/gL51/HO15bZBkr+zVZAf8S8oUI6T+Zm
q7UGI36K93U58cRG9H/K9ifptfB8G7c/N/l1uz1hWxH5Z53TYDuY0bR/bsI2
DBPIPx85B0AvIJ5HGC8fZ8i8hHgTeYdr7VJtH8MjiNMJY2KlP11Tb3zjWuKV
DcYUv1pj3Jr8B1YJw97gNc43astq+y6bL7yZ+jn0V/XGockP4THwb4rbtku+
1kYR9iNnNPGkav8v7ice32C/oK+Tt2mA+RH2J4+wlvEvXzpo+F6B3quy8z7m
B/RjmvzCn4anRnvapW63ZI31WSnipRX8c2Sjq/JDf6c9SuhH5ZcHeg9yXqAM
jykvcTvSX9MkH55bqu0j/lbi2wgp/ROJ7yG007qauA/vOgI9E/o54VegZ9Tb
b+og/mN/QEeR9SkyY8RR+sSagM6D/iyo4yb4FiPjXt7X/ZTjdOS8S9pxCdvV
yr62a8L4eNnIbqRffxa2jdODCds5rZRuhfHqB+6tkn6T/vki8Wx4FgS8stn4
ifs/cf2qxmvorYFesoTvprjAtvrHU6/e8O6Sn2xkPoysl+DbpPlV2HZWk0lb
HOgcd/M9vA8dJy5JWx+7lH5yDHXIQ+bT/Is2hp0uHwv/aLyTXQnxVo130mNy
ryXP2sz1l1znQT8qe3voXfpXE5cSh5H1NXStvkHabmOpv6nh8P8unbr0m9A7
5F9CGBTpogO9cEXautw3KFs+/8id0jWrvpSzkHI+g+xQndu2Mm1/htqzfZQy
v0m7x2WPTZucTxgevPf3yTsA+gPivdon15qEfrov7fdQTtyX8vxC+m9cnwnv
NdLjI/s/7n1IWoL4CtLOpkyZlHk/ddqnfgvPaNLzC+zvbhrPu07+uIXBlE4+
bD10dp3brBo5F3B/uzAEXOeQvp64hvRK2mhzqb/lL6vt86oL9OkJ79uvUf+j
Dp/znfZoMJZGtrqD6+zjfYzmBipnjdcds2qNsdH+4RB4xhKe0R5onf3YX69x
P23f8tqP1L7luDrvky6q9/kFK4L1k/C445D5TK2x7MK0T4MupUyPUJ/mpK3h
+52l90pag/ZXpReC/jtuDL3OfJDd1nLyzqm1/3mtif5K+vwFrXG0ttP5BZqH
az6uMyOuppyHUIabhIETpoIyPkT9lyO/d7391ctW9MY6Y1DPFwY2bXvA+2n7
oQ22g5MP+Wn19mEuzGxV0naC8hU/Cf4Tao2LTCbtj0I6tSGk/1fjdcjXtfbt
IP3a7nr7l5AObnDaNnryW7+btHNqbQvVOGm/1dKZ1yVtDziWsv2Rsp2gfNfv
TBkHe572u9PGBMqH26V1xhnKH93ABuPx5L9uRJ19ZEuHX0/aoFrbHTaCHlLj
czOeJO28Gp+RMRW6nbAMUfez6oTnzDW8lynydQV9ncY2ntHAt7MN+W/zjYyV
TpS4d61tQZdz/32ux0F/oD1M+MLQm4h3I2cg9BLS93G9WHsxpN1JnjHyz0Zb
/U56Y+jtxDGts+A5GvorYYZJb0zaF+RfIl0v8b0J28F9R9nKCVeVul9tq7bO
b7vwI/I1D/0X9J/V1h/tJF4pvD30r9D5lOEE6ALin6qNwxEe5xfo8wOeNOET
6TeJSzUGQTfILo0yPMW31g/6gnrrfb6mLx/H9YXar5EvBMJQ7VsRd+feuQF9
JfxXUcdGqi/XN8iGVs8nvVzzCuJw8K/QP6Mz152EOyE+kjCN/+p8/lFhynNR
8Kzuagd9+9qX0twB+jTim6U7IG9r6DLqtiEYQ8/memmxx9ZW0HuELyFuQdgF
3VJYd0JveI4mPoUwDrqP0ghjoU8ibkzYLNyGZMS9t3JUteezTYN9yAnSgZI+
RfNlnv9fqf+J/6Z8NsK79O3jo/5GPs7096bvLp00Tlm0sMhty31dRB/ogIzP
yPM0/XYt8VMBTiWXvDOIF5P3FP5V92UbF56Ttg3joqS/eX37OidC2GfRwpSv
Qc4TYfvl7x61PNkJf6oxJMDh6B+hf8WHyGhf7rMs5lLvTcKNEybq/xK2/e6n
mf7mVa8reNcjw7bZ/USYG2QuCttmMjvtuINszaMel1XWUNp2n3Mp5+fSB5E+
lev9KceyJz2CduhHPZ8RDidt+9F5SdsCq+4682Kd9FNhy9oQ9dgtW++/Uj5j
YiB12kLZNwflz5FdMyFH+yiy34q5/kfKhinmZ91JPCHAy3Ul/Zuox/pvox7r
ZTd+ZLl9ej1NP82njwwQFot7WdBfRj0n0TkF07Jtc/pV1HMdXU9E/viwz0qY
AH1r0P7joW8O8FH7i9y39zLm3ldgf9HSHR9ebF/EWqetTno+P4l/1Rl5XgfK
5uiLpHULD9d6TaC1g/wMaI0jfwrSs2qNIB8Ex4Zs098u0BF8lLS+5T7ynp7n
taF0E6/U2SbopTrrteWHuX3IfhVEPyT8c8R2WFpXaB0jWjZTWifKbkn7w58m
rbe5X1ibYvtS1tpqcZ1tphYQdyi2b2Wtr4ZFXWb5f3ii3v4/2zZ4bdM+qNeX
Zb4vP9sTAn8CWmfJP7biM3Wv2uvKE/i3DMrzelM+DeQvSnoDprehCxLGtU6M
GwclXUZj0m8MG1smXNlqfcvB9fgSr4Ulp6rBuplK4ovpG4frXVV5PXloUP6F
Aa016Yhy+4T+pMxr4bZBXb4o83sYQ94nCux7QWvA1+vs70L+w4X/kp/mI+E7
O8/rX/lk0P6T/GNoD0pjp8bQiPZVpC8L+/rxOuP2w/qH0L9mSvfBvULaZyfl
GCksBjJnxTwnvAOeITzvA/I8LTudfOPVNGcWbuUU7b+Tfr70QVxX8+4OzTNW
rbbY+DD54DoRnhdint9r7B1M+vukz4h5ji3sy99h40bPQea8mOfGela6wHgW
4Vs+QOZ95K8mrVbjLWUulw2b1ukFPk/lJu6fm2+Zz8e8jtCzKoVthr9M/bTA
fs9UzjOKLP8s5FcFGDn5Oju4wH7PhJF7LWZ/aMKzLYr5DDLh2RpJdwHdDJlF
8v8T89y+TZ4xdfKr9g8yz8l3e11YYlyc0r+Lem0iXxblBcYICUf0POW5QDp+
zYegX4l57TBH+FDyNEH+oQX2byYfxMlinxejcg6D5+WY59jC6ckXGl0i1Ddq
Wv38uWrjCTvzriuL7Rdd9Xo9wOnJ51uvcp+39nGlcYJ6h3Sp0KHCqeZ7nfNY
kdcpqzXXLPF8uJYyDU/Yruo+7Rnk27fWzVxvjdieSL58Dwubvhr6b+E79d4y
bYtxS7b91sqHr+wyHpBNU6HPFdKZLJeF/W+XbdewhDHnd8bta1jYdOHSt2i+
kO9rxZKpb/sO6tgj7Lnm7dDdwv6naN6ptCfrbbdyU7b98QqDIVoYeNmLqS5Z
2rvNt9/jW0hvoK1uF96MseCcsM9/ke3JYNrkAc05hbFJeI6t85h+TpmnSHP8
hMfwp+K2a5Gtl2xmdhR7jNd173zbgslm5oGYx0qNcWsq/f4P530+GPM4qL50
vuzseG6S52aUeS8iJRxnwvZnj/Gsf/Jty/aksIbl9mHWn39Oq3Kf3TRFuvoy
z72F7ZcfD7V/Qusn5HxL2gs6vyPs+bzs4OSXQ2dalROPTHjeMTVuexrZtuld
vh/QmpuclG8bLd1/IOpzWYSbyi23b71DhYmLWPfRNNNz8MUBpvGIqP1SyFeD
4lcD+oGAlr18qsw+63ZDP0J7rs7z9X6tj6PGvU8m/ZM84yH/E74ian969WVO
20Pe34r8XPlw+DLtfMdqPV5qnKR0RpnQs6PGRN4b4OqlG9KZLy2JbyHv+rTv
d66zDzTpkTKpVzZ550SNxXy02L7UJPPugCdDa7C072+rMfby3SDvh1WmB9HO
49PGXk6hf22HbwvPvKvBOE/pgLKCvUDR8k/YhfbvGHUe+QWVnikStLvaX7hN
+YT8INe6pzUBj+jDKswbpg++H7EPUdmtvBWxDUs0034A5Q/wYcrzd439UjwY
rCNXBxjOuZqzBeXRmvKTXPsVlZ9E+Vu4hb7UK2EM3iVx+zSUb8ODef4x2caG
Chf6Rdp41UeFHeV7mIXc/pTtq7Qxq51o87Pibsss2mxCjn2+yN+Lzr17IWS9
pM6PuyfHvlz6R0x/xL2xNfbdJR2l/LnIr8vKkM/Ik7+XbOLMhO9lxn1OnHhy
Azny2bSKe4MDWvZC12ruEA18IpX7OT9RryERn40n+6KBEfuHkm8oXYuWbVLf
Yp/BJ3uwTSH73dqs+UPMelP5dWme730D0dKT6jnyOfNewC+d7G6+hX8CHy9K
eziQI/9MwkgJHxVN2O9XXtwYMflhk12WMGXyAyZc2bqAVnseTps/lmO/cA9G
7ctf/T+WsG1UftwYP827dKbhc1X+Rn4sty5b8qUbLoE/KjyUbIiQ+XiOfdOp
XCqf7OO+irkddQ5htM711X7J//y+BTxfw7M+Zr9TQyP2Faf0CyOWKTuxhjr7
qipEfl7C/u0KdKZSwv7uKuLuc+p7uZX2TzKdMm+Wrof2ez5qH5rfyL4pZnyq
9LnCxQp7LB2t9I/Cb59YYR99wtk24T/TuMz+5ldH7Ou9S6DnlR9e8cn3u/SR
0kX2qXBcVGn9746g/0sfLL2tsODSBe8InlUd6GpVnsqwzxboR3qjMuNppcO9
ud7nDTxUZ1yudK0dMq2Hlo5YmN7L4o5zq6zjFsZX+F7pXkXL/lT6UpWzE/QA
ZK6iPufzLi5K21f9Fuau66qtDz630jaoskUVDlt+96UvFuZWPiqF3Z2Xsm5W
9LHE++QnIsO6+MeK7SdROuIv86yLl51tAfX9Is/p+aW2cRUtfK/kd0ROlHLU
Ef+Qtp5aeF899x14wgEeuF/CGOFr4varqXRhgM/R+B/U8ZQKl+vkCqdlBukR
5KeJv0sbqyzd91FcXxX389dWGf+vd70V3mfLfT7mz8jpVWG/lcOEX6Dsu4vc
ju9r34Gynk67/ROzv5rHkXt/sf2pit4tnEPMfmzeJ21QzL5uPoQ+O2a/OiMC
vzdPQT9Q7P0o0b/Qh5+LmufqwE/O09APwrMyz/Sv0iFE7ZdH+17q7yt4H6MC
vz3Pcv1mlePTKP8NwTeiceiFXPvJkc+cHcj5vcS+clYh+5yYZXbifR4edfpb
yJmhMaXCe3KL8pxfOv6/g77XvMI+cuV7R3YCsheQv+s3aa/ZwRh0YIX9dObQ
bn8K15Nn3z2zch3r3tm8p7m5tjsYBD0n1/YI3RK2tT4nbszEmuBb61jhfdHM
8v+TpXqJV3Jkf/1jkf0xrSa9e8LlOxc5txTah5N88j4k/9OBb9Bz0y6/xse/
KeeuEvtOehiejwNfn+ek7WtX9h3yqSRfo/ofaR9WY6fG2cJgHNUYWlhqfIu+
iyfKjSH6i+/+vIjtivWPk+8T+SeUf5aTIj7rdx70v3H7LPy7zOOefFfO0ngR
t6+zf8o8fmiPWuPJ7EDOHO0dVBkHJSyQ9q/FI/9pJxYbiyP/JP/ELXdXmbGy
svuVvbTOCwjn2ia6Y8q20kvlO7fcNtPN4t6DV3mEjzw6ZX7ZPo8Rtj/XZwse
TJtfT3x03BhcYR6E0W1G+tnEh8Tt41BlmY6cUyP2t/lWyNgt+TUUnmlaiXFO
8p1YX2d/aldIrxKx3kHjsnyzKf3tkPFQt+cYEyUQ3JtE+6ljn4j9j0oHMKLG
vnOEy9L5yDfn2J+byiA/ncoTJu93xBHKeUaZnyH5wo/Jd+eEkH29XBGUv3nM
ZR4fMg5NPPJb15M2vzTPfPeW+2znbcjbVGp9ip6nfdBLAzmTyu1rcVOFz1WM
qd/RXu21x0v8c8JYHdnBygZ2AvPLzaRtbLDNsrAYJ4iP7+0Y+O6r9DmSpfCf
T/rNEZ//OCbD2AmBReWz6KNyn7X4RJXPYBS+QmeFdEj5XIsmCWMzZH8u2/ON
5T5Xcifl7E0fa5zrcxK/L7ctfLu4z0lsmutzNI6LeX2hMx/lC1c2Gjpv48OA
R33l0IR9yRyn71R2V0E5N5T77MS2ccc6S1HnJ14b0DrXbzU8RxI3heeBcp+V
vFnjfNzl1zmMR6Z8PuNiytk26nMudd6i8GiyLxYupHPKZXwXnuNSbrMV0NdH
zK93oO9A34Vs/DulnFf8OpdTeKrzSO+Scvxerc+FFHZFz5Ze+zut3xp8pqVw
NTrX4w76w/tFPitC56EIG6P3cVjK7+HVWvsNEK6mJ9eb6+17ayLfxCL600LZ
mghLzfcyPmr7bOFtZIMt++tDUn7OwlpjZOQvQDgZzW+lj9P4J52caPlXPJP0
G4L5qmwIhK0Xrv7i4N8lfwhKfy7HNgj319i3rWwHtgb8ShdWXph5+RyQDcLz
Aa3zpGU/8TL1mFtuXvlBlU3CrICnJG6fxPJLoLMvpHMUFl82EfJfvDfkc9Q2
hGwTIdsFYfv/58c4oMUzvtL4f9k4yOZf83XZXEjevECm/AJsJP023stazWPz
rd+UDlP+h4WDle3F3ECmbAXk+1f2AovI043v5rJGrF3L7PtXdknSe8ofcBlt
X5SwP+CyuP0qiCeesl+FBTn21aw5u3BIwiANizj9/9M6R0f+nXWWjuimwbxc
8/MvE55L6xxNXY8IaPkakH9m4dZkizEmaqybfFbIP7PsNIpIP1K6b+jqlM9D
ES3b9ZfLbYexBvkb6r1Wujlte4ulwf98a0Crb2hcm5Zj3xM6s1u0/NB+wf/t
oHz7ye0WsW9Z+bF6p8A+lIQN7Q7PJXmmhbcVRnciPLeUO/5Wtnjcb4j5zLvN
Zfa5NJ+yPZt22ibhWOvsf+nreuNzTs3x3q/8OQ0K/tvb4x5vf0VGD+FfkHum
1k5p+5S+VL6k8o0tFq740YAWNli6YvEIE9su7THrD+lz0z53byv09LTP49uc
NC5atPD5d1T5OTfJFoFnd47Yn9u6Yvc3jXHdio1v1Ll9b/E/6BHwyIZhSI5t
GrYj93zomfJJjqwHSJuI7AfzjWV+MGT/aeKfoX8d5RkK/UKt/auJlo+1k4N3
oX/l7eW+t1G+P/ONuZYc+ZQTdvoRPbfM4+aihLHY8jUn2wThfuXDTv6tZINx
bo5tMp4oMeZbfJMDmQ+F7K9OOPCHQ8ZZK6+w1sJ1y7ed7CLks05yplPmb+rd
HhtJ+zHX52M00Rqs1H5+hH+Vnx/hY1PayyL9CZ47nfrNol1ORe5j/AO+pz2f
1PyW9BNz7cdMPsj6cr9Xrn2gnVHoufqtXI8s9Jxcc+/t8lUS83x6eZXn4WfI
zlQ6iJjn3IdG7btL56ueIsxY1Ocf90HOWdItwXNZodcRmvOfXug1wi1a40E/
TvppWkNCny6Me64xbLIZkW7iANJPEwZe83bq0p42nSR8OvVdne9naz9H+0uy
Kf6uxHP7cVzvT3iurjl7EjknS/+U6/22owiHwn+x/PkE65qJhd6j0z5YS/np
jLo8mo/onGfN4apJP0kYOa2Doj73Sudf6TwsjXca94bBc4HwxBpvovZxu4u8
y/NMr8vw/pbslLWvdVfKNspjk97rEq19rgcKvb+n/bhroIfG/F7uK/Rek/b6
tAeg9yOfpVq7yGepfIFeDs+QmNv8X+JpUddxI234FPQM2vCPYO12o+b1VcYS
7OH9bqANn4naz+pPpfZ/J993xyLzsKj9y70G71xkDIOeA90vZv+rm4S5KrL8
Y3g/CyP2R/qj1oJR8+ys9Lt+QntlPOvpPPvpu5T/wNSA7s53d7/6uvZO8nxu
8XzK0J/v+rJc+y89OuG27CMMY7HPIL6Iey9XOY7y3jsmvB46GZ6jC/0s3ZPf
N/l/k6+9U5F5fq59b24tsv79+YjPj8sI3q++G7WDvp1d6vtRv199y32D/8DT
af975RNvYNo+eMcI60s7zI/4+rUC8+t7P0hrXOS8IF8wPHOpzgOQbVKR20pl
+C7mttU38k2Jv2X56Z2Z529cPmm/LvG3L/rbEr9f+bf9OWb5Ose5Bfy/xvys
jpRnQcS+cc9MO76Bcs7K87cm+c/n2Ufi69R3Rp7/F7oekLZv2FFaM1LOt7m3
KOKz5tT3dQ540+B70Rz4zRLvx2mv7e6091y+F3643PsY2s9YSnoyzLiIzKR8
Uca8f3FdzPsnyiPfccOyfY7nwgbbrK7WOgaeFmH76/k17XX6XNJfh64Rzg06
Ue/9pRehl8n3DKGKe2+lbV/5Mek3ICcR9rmhb5LeGnoV6dcLoxv2WadllPlE
ynw6Zb4w7XMRN8v/Hn21u9bO8k8Q7NfoPETtS4lH+zM15fYjN6TCZ5CqLvIF
sZv69imxf6IVtFOXsP0WqT3kb0/nsR4Ttb+9a6F7lLheuk5Tr29p+8soy/cR
n4V6faZxNDvynb+y3P4izuK5L0ZtuyG/Bm9EXS/5sFguvwtBm3ySsj+83ZT/
j3z7yRtK/lukuw7bR9LrhcYOaW/v/aj1vGr/D6PWc8mn0q0xt6HoD6LWeSnv
n4FM6bDeK7SPwPOgz0vYz9942eQG7SF/iAUVPmd8P/GYmG0rdAbtMuHTpA+W
XUbCuNmV5T4PUecMap2Ri/ysQq8fzmOOlNB/Bf6V9NsPi3yWYjP9p6MeX3QG
rNaMFdk+CzEd9OHDEvZbezxlm1/i8wq15pybNv/xKa87ZR8gf1n/f70nX07S
MWndp+s84ni217atEz6TUWcz6sxHnZmoNWjnmNehol9M++zFbimfh6j1kdZJ
OldRZ0eKPhmeFPFXvK/RMduY6CzenjE/t17vhTJPjnq8zyj3mTPyL90jZjk6
M/P2tONP5Lct5vLUBvtP0nloD2p52n3gw5TPk1I/kq5kVMz2Lzq79420v8f3
ZfNS73MfVyPzt4TPfNTZj7W0ebt8j8X6V6j8Wguvkg6Rcp5EWjk8vZF7sMa0
hH1/6rx4jbfJbJ8v2afBZfxU/rLg7xZze1XJz0/UY/Qo+Q+W3SD33kb+Q1HL
LC21HdT3wRj3fbHHtZci9uEsX9x3UJfu0POId8Q8JmqsfIR/3hnBP/ke6F7Q
PXM95zgn1/uTo3nuF/SxycibErHfUflb3xTzPEk+ZttH7ZdUZ9lvoQwbin1d
V+h39STpr6Qtu7/23/LcJr0lq8rt9B/teSb5JuX5+oU8532KvAvS5h2gPYCU
5a2vdd84Idd7ETsqPS/sJry09Na53h+Qf1j5XVW735Zrv/E6n6tP2vQw5PUW
3inDfaav5tu59uX+QYn3GtR2L6UtUz5ve6U8T1R/WAFP+1yfJ35b2vTHpHdP
+2zxtbXun4fm+szQ12mfJaX2DVsnPKVszCn7GuSsoZ0fpI2Xc/+NUvuA/UqY
qKD9P4Pnc+G2ZVNF255a6PnnBHiH0HYvIWs19z8m3A/PWmGt8yzzkxL7mpWf
91M0hyz0nHYQ+R7O8/xwicZ94rOoX+tC+wRW32hRaBymeJbSVz+S3/lGtsOT
7Zj0F7L3k91fTGu+tP2CPpGyLZ36pvStx1VYFx2r9B6r9Bfacx2atq+U51PW
44juGuhQ1gXyOwW09EH7azwPlQ3gXWn74JxK3k+rbUt4FvLX59neUL5HT0zY
98r5lPHOtP2UPgV/A307XOqy6h+gMUX/h6FxP0fnOcr28POgDDeV2V+KfKHI
J7J8I+ub7Z2wr9Dhce+hy3eo9qyb0mb1hf4nL+a5fTRPId87eT57TvOun0o8
p5Uv/V8rPSefQnwW7+XBPOddlLbv8YHkbU7a9zGvHR7K81pAct/N8zpFcqSX
lv9T+RHammta55B1rXAcLnd5VU6dbda9wuUeHDev8shXi+wf5WtVuu/5UdOy
ielcYZ3z2dpPbvBZZ+FG9tEqG0Pph+T3VbaK0uW0T3h+2jXuf97huf7vjaNe
h0B/RBtuKvFcXD7k/670Gq4v77N/oc9T0D9pQBDrvyQdgebtOrOhiveytcTn
5f0e81kL+r81rzZuIaPKmIS6Mvty6lfoMx30jJuLfU6cvqO+hT6LQfTMiM96
0DkRSyI+K0L+oeZEfLaEzpUopx3mEJ8Q93rltuDfsqLadIL7hXU+9+E23t1J
hT73Qd/dDTz3lTzTwloky+xzqnPCuv5+sgcsMr5Caw/pPpYG9X05z2e3qY5p
+VSFP0tn7ER8NoTOYHg54vMY9P8/rM5roBsYx/IqvP7YR9yP9r801z75T4O+
BPoy6ImUbV7E18si1pdIVyJdyrzguqbMepad0oEXGRus+bPWE49y/zv4i+t8
VsNRxNuKjAXR+uGViLEmwpmorCqnxvLNJV476FyAI+sc30iZm1Vb1yOHPkML
PVeXXNVR5df5c7ODd6SzPDol7AvrdPnLj9g3uuZez0B3zbU/9Nsi9iGu8UFn
SOtfrTOl7wr45Ud9F/16MvG/0i3SPp1J/4K+egTyXyK9p/aiIvaxLv/qP8N/
a4ZtSfrThhPzPHbXFPqsBM0TBpB+Z55pnYPdjvhC8vxC3kuJO+g/WuixXXr/
Xyo9H3iI+K1g3G+lf36e5wI6f+GdEs8TRN+f57wqx5EJ+3jvhcwj6vxtjaU9
74vYh7rONrg3Yl/w2rv/scTna+i/pPYcGvTzxyIeQ+Vv/Y9y79l3FDYp4vNU
9I0sjvg8P/kjm0AfGp/rs1GOSvidnAR/ZYXP/sugLj1pz2PgWVfrtfLEiP3b
n0j60cSfk76TZz0M/z/kmxqx33v5uJfuQu9iVIbX1E8Fee+IeD2sf83oevui
/6zW5ZVM6RyezPNaXHy/l/vdHyV/JMIB5rstdO6n9InSK2q/Vuefa//2lwL7
V9ceaw5ysvPsL3lznn0py/f3FYnAZzIyt6ndwvaxLOzcmWH7aBUm7qywcXHt
Gpwuf86S1ylq/8vv8OxBxBsDvNs5gZwdyLwgbF/MN1T4LM574/bFLH/N8tW8
PWJaPpplHyI7keKk/VErbwn0dQn7UX+WvL9HbP+yIMgrftVhVML+q6fFjXGT
n2n5Rlf5VB7h9BSfHZRNOEPxCAP3tf51+fYj/3uxcYcjgiBa+EPhEEUvzzSe
Tj7ihamTD2z5excOclyQLr/x65H5VaF9xy8NeISdO5M2vAq6knodwnjeOWq/
8R9FbT8geif1uoL4Tfhvpt2mEZ/Bd/odbfJcprG+4pEv/Le4boWcFoFv/NFp
5+3JN3Rrhe+nK13Xi4L6/hWxn3zZCO3NN6ZfeH6tEeVDXutErXW15tVaWL4O
5fPwO+HP9X/JtG9GrXm09pFvRvlf1FpePhhHxb3OLi/3uarCp2xN+1xV4VY2
pb2e17q+EJ7B2fZBIP8D8kOQF9BLeG552H4atRcQD+SvpfwVYftzVJnlW17r
5Sl19qH4M8/ZEvGZsfJpX1NrHMEvPPe6uP1HJsrtL6A0KP+AQL7uaZ1eFjxr
A/18ZMy+J+VzoCDs+j8ed79oXe4zOIXfmVrp9VhhwLMt3+v7M6Cvj7sNK+D/
IWK/+Dr7dpCwpMSllfZFKX7hdup5n8uj9kE5NuZ1v9K1P1Mb4Fu0Z6P7wpys
C2TK7+EAnQ1B/GmV9yfqg/QRabfbP7VuQ7Wt+PoFZVabN/DcxmHPG+X3spTy
biX+POKzE+SP8ruAHpPp/aR02PidYWnTG2vte6EoaFt9A5cG/V8Y9QFh+3ke
EfQ37UVIzymf5tJ1Hpu2/lV4gGPS1sG+Dt0J+kzoZbXWB+vf+gPlixVajysd
rvTDNwe0/rP6V+u/rP/xnRGPlS3iPjtpabXt86WPfa/c5wqN1L87w/remyL+
H9dpbI/4n7xQ76XE+xj1QbrKJ5yB9qqfqjJOQT7fhW2Qr3XJlH8A+QC4JmJ/
C7I5lT/evlkeM1RGnWUl3a90wPI3LUyD1ujTqjwXuDvisVu4QuELhbH7tcIY
w2fIu6DGvtNapuznWv6uj8mwr/Lnub+PeEqNcXzSFeocyXMj9rcuXav0atKp
CR8n/Jywcwtr7L/hMfJ2o/0fzPA6UfNjjV3byz1ejQ/a54S066IxUXMRzUk2
lfssFp3JojHuiTyPf5KlM1ckR/NuzWvGRTy36Zr2Gl3zba1Tb4143ar5juY9
kquzpIUvH0n/+YD52nv5fi8ZtcYIa920WX6N8n2mhfb6Ogd9TzYS2kMbn+m9
suOD8e6TUvPKr+i0Su8NCu+tPU/l1VkUVwR5JUc2Fl0CWvtvkqPzMEZUWLZ8
m8uX3InBGCoMerfgWfI1J9/rOktjQtz3m5R7/65HwKO88sku34CXV/i86+pK
j8snBumbqXPPsP2wjwz45VdQ+4RdgzqmNZ+KeA6hMxTEX5D0GQ8660F2Ivdq
70LjAnFGnvdAdYb1PWnHF/F/vbrC5yDU6Kz7iM9X0Hj+c8TnLkwOxn3RizJt
CyEbEtlcX5nwXOCRuM8J0XnfOitE55iIzkgaa39GMAZdU2G+b2QjU+fzwDPh
WZ/y2Cta9gQ6K1w2BcLs9wv/nw1C7+D/r/ffP+y9zuF1ph+r99kVGr+F87+F
616kFyatT9a3INzU+RU+Z7yc+n4o29BCn1+isyR1pqTO/bw/4esP4j6rXuk6
Q/H3tM9DPEPnpyTsM+FDzX9472tJb5rls0HXhH0+6AN8Y515/zWNbF8vnq7y
EaN9Euijs2wHJ5lVWbbJuyNse8M/hfGkzLdx/aV8ikZNy7ZNNm7bNI5rXku+
36o8RxgXzDHeS1uOzt/8m/Brpu0W76kwrfM7f82zLZvO6ZxHeho5b2hvlu/r
P+59pP6tdRbXDUW2zZc/cJ23eJf8XBA2hG3f/w3xCaR3pM2/DdvP+VFF9q8u
X+tjiux3/eQs2+v/EPSfNO3zLHVLEtenzVNHfBCyDyQcWWSfAyuC9pGvAJXh
OOg7eNY/0rXw/o/X3mPUZ7D+m2ffAqJri3zeq+zhZWeaR13aMEZMIO8e7T/W
2YeBbPPl70D1HEjfWsl1usjnusreXmebygZxu+ZqAf17pn2Iy5f4LuJJtOEX
xM/pPwr9FfQM6Kekfyu13aLq+mzYZ2VGqOe0sM/HlL21fJX/k2lba9lcVyRt
qyYbNp3POiZhO7bn4x53xaN56K5C2z7mZ/m8ANF50H/m2Q5VtOwyZXtSkWUb
yBcCekeebVRj0NvTPtOzH307L+0zOmNpn7urcpZm2bZ1aiDztzzbW+p6SoVl
bKEffi99eqFtI++inTNpz0F1nm/fFPYca2OV7SVlh3J92uf27tU+KHI+5/70
uNtPbaIzaDOKLW8D9PiEz+t9Le5YeXVe8Ji0zwLek/J70HuRf+RYg7+LXaRH
Gnx+bpT49gqfWfNo3D6fR5Mep83/ifhcW50LJbuZMWHbLm1PuUyyo9kX8Xm8
Ovv274DWeuaWhM88nRf3ubkqu2TKV/Mo9cGknylaZ+XcWeH1xxPwty+yL33Z
Z91Ju2XIhznt1r3U/ivkl19nNWkc+KPWOrWDw57f6twmjTln8/wUeVfQ/kni
m+JOT5VbH3ZgMN6tgP9i4t+R04K2aEb6r9orzjTdPRgTpYMQn86C0hi4o9b6
o5bBPHBmhfvF6zznPp59MPQ7mn/JLoZ3VlBkXx06h7l1lnlFq09p7ac2G1hl
nVarYJzNKPD6RXbKXxTabln0uRUu37Xkex76AGT8IvuDBp/v81utdSjNw573
Hh31+V+ao08tNj0Keg0yOwbjy0eFPlNLftul59P5XAOC8VdnAmlsvjhIl97w
5rht1NK05zcBj84MGprwGHUH9y+ibIOhv672eUNHwbO/1uN+22Acl560Tdjr
EZ2DpXeyvdY4dq13js/0mkJ5pYscVuG5eaXOQ6OfH0n6vlrP248I+/ywK9Km
99b6vK24zuZpsE5S45vWGjNph7/ybBMdz/K52zqH98+0z9MdWuv/4YJgLJPt
8/yA/iNtegg8e/NsD653UMI7mER95lC25yrMq/N25c9lUTBeyH781YB/WiBf
fmNkb74w4Nld6HOFZQvXosjnT8j/SKLKPlvmIf+PKvuKWcBzJtK/9wv3xTfS
Ft4DiuwvIpRvm36dSSE7TY0dhyG/sshnkMtus0ep/UuIpxnjTFNCRDLKfM6x
7MGnlnocjMGXS1pOkc8Uns2zD8ny+eOyK9cZ5e25fivsM811T7Gudb75zrTP
Te5bZ1s/nYGuMbu0yGecy+69TfAu2mbZNl35E1m2GXw7+FevoG8dqnbSWfeB
bbvklhW5zTQ+HiMbiqjPd96RdtxfvjeKfJazfPcUVznuT/+cQX/Ynmebd9n2
Lw7ehep6Rr7PhM4s8pnR4jmpzm1we73t51XWqRW2t9Hcana5bYDOidjOSPho
4aeXQ79VaVqYauH55F/y3ZD9R+rs7Q+EFy2wP82XA0x6r4jxdsLjCmt2ZJXT
dd688OrXCtMaMa58VJAuXPyNNca8y7brmoBnVoDxFib87ZD98urMS+HOxHNi
xLj0rRXGgOsMcWH0hO1+M2S6b8Q48xH1pi+rN/ZOMpXn6RLzvxXgsIXHvq/c
WDlh5oTP/39MnXWcVdXXxmeYYG7XxL0TzL2DjWIXFopgd2MXiGJhd3d3IjbY
gYKK2N3xswPF7kTFwPf58iw+vn/MnHX32WefffbeZ5+913rWs9aJ+24uuZq2
3zFxN/7HnkT1a1O/VMM3eQHarmwu2zd0fkDKfsTkh/uKGCTHhM818s44/hbs
7018n9nK25twnJr5lH+1VPDils3l/ibYHqU9gZ1bvwfmzTu9iOQJKuOqnK+F
1wxegMPazekLJ7CKrZtPeR9Jmgu4L+UYIvhTr6r8q5Qc12RyzjFUKP+gouOn
UP6wwDGerHL21LVvJP0bvCa4TWLEjlB9HtKYWF3p3RVzjExR3UflHHMHX+kn
lSefNm8RPsw/6bgd/Vw0ZxHxGF5rddus227upj+Utot+H9Xtdd+/vY7Lgx87
Puz9Ol3ek6rL5kXzIhHf5+hur9/r9R5Mg4sibR/19YvmwCLmzv7dnm/+UplZ
zb8/9ndMInhUWPevqeNTuraYdv23yznOED7z18SRuh3T7XVug+41X69jBA3E
LynpviXPod3eQwyv2ReePMQJIiYu7wEYSOL/ggW9Xr/3S1m+oc5YWThqJwXu
cs0WYy/htx7aYtzojpKHtTjW74Cq+2HRXuchRilcFevi9woncotxp2tH+bso
z/B4v75NOI4SfZDRc9+ZtP/5NXGkvy5rc7yjV9VX43OOi8GzcBzQYg4BYvqe
p/ImdhujOqLFuNZnM8YHg2el/3+OMvdXv/QrmOegt2J//Ol8Q9lPFeyvPytt
vQM6B3A1s8Pv/WqNgT/T1tMuXbTMvhrfd66Z5wvPtaSBuWE/Wmv3OoD1wPhO
x+7ET571Bn7a6LI/rFg3/G/aez44Wuoy3lOgb/87bf02e7g5ae8HqRf1Yx+9
ler+V9p75qt7fA2+6V+mnB/+GrheKJO102Zp3+uVfo4r+muUw758dsjE9KR8
6o3/P/rvRdqN8/o0bZ3nM2n7loC9AdvzQtpYnHM1Ns6uN/bgvKptO2BpOPdM
5Af/ybVg2kqRDi6I4wshk/5c2no3cJ3EnQHb+XOX/bTAdpL2eqQ/GfhV7KDE
EPlE8qYV874iw/0KNgZ/EvAxL6Utc6/e+I0MzpQ4OTPqHUsH+Z96x9Wl/Nsk
b16w7z1tPiLn+Fu8++sVjPFC50m8IHw+8fMc1GvO+UvReeodPIH4KNh+9L5c
D78/37aCOfn3qDNPzLIt5oohlsWSLeZOX7DX/P1ndDt+BXGfF65z7OrhOp6m
9J3V7/9LuqwTIxYA5d+vOu6YcYySxfOOO0J8auKUEK+EuCRwTvRJ3rXB3Jfw
4O+j9BWVZwj2mDpz26/Y4rgAQyKdOi0veYWW/+IGIFMn4msQp3oRyZdUrQ8H
47dIr797cM6gn2a9zlr9rqz9WOfGbGp2/CbWqxy/CJlYU3C0Y4p9Sc/4YtHX
gEX8Iq7t67b/a2vNOELiPq3UzxhC+gUc4aVV63/QmROv9lulb1lxfF7wfvPw
gcTn3aafcVBw9JV17XVl2wGwmXyXtj2A9+LyqucP8H7gAEkH/3dSq+MP9++y
7o24v+wnKBv5kH7m2oF/Z1P8BWLtxFpov26v92arzYaqPVfLmW8Fv31wzU9X
HLuJuE1gLVqrln/ERy1rX0r8KPGJfDxk/CHxdVyhw76c97cYM/BHl/0ar+sz
LoV4usTSxQ75RIvxGacGLgF76+VwmIXNHcwvuISXw86KvbWrw/Zb7Lj8Bp/A
vcBUgyEGS9ytPKdrPD4ceN3LVOalReMqTlX6g4GNnl7x+X5l+2+DBajq2hOz
xgfAU4AdeFqL7b+1TmPF/u6wjRxbeXOHMWHEsEYHXS4Z03RzvW3L2JiJjX12
0fGzwTgN6/RxTR3fyBkrRWxs8FEciR0ONurSKOfKlGXiiJ9TdCxt7gEuAAzH
PEwAx0Ed9mvFh7XSYVwF+AqwF9eqDxbj/EBjPaa3GPuxY9T/lrBhY8vu6LCt
+9bolzOizemLb3n3s8ZMnKn2fCTwE2A1wGykdW0N33jsCRX7/eD/A//1Uklz
VA8OuzO+PeR7r8kyPj5fSB7XYvvOlV3mF8Av6Ut8TVrs60ZsS2JcXtHnOJrE
08SGQiwX4rcSzwUOeDgO8BeDOwH/THwz8SfbNmT2FDu2mFsAngX4Fi5oN6cC
eeb5YHO8qN18CZQJtzy8CjtIvrfOvAvbxb2I5UlMz0Gq845qn5mBayI+1D4t
jhH1guS9Wxwf9HzlGZX1mD9H8i9J40n+LhtTsmWn8SDgQsC9LNRpfHgj/svq
i59zxtKcR7ySrGXwMndH/nOV/mvS11wQ5YAtASdO+eBVwL5zT/hM8PHCvwts
wJcZy/h8wYuATxf+XPeHDE8CPlzEHc7W2zaEPx78CGAOwGHwzcZ/EizGH+3m
+R7bYlvRi9EO9NdCGkebRluB5QXTOxsOjJxjyYP9W1nv1wol8wzBz0RcMzia
hihtxZI5buCUyip9c6V3pRwfDT6oZ/PmhCJW2tNquzYdn1ffltPmvMrpdzFl
ziviDA5SPy5XMp9nTm1eoQ+V/wLd45ycf99ZNDdvF743RceJI07nATlz1BIb
bnbe/FPEXINfEq6rNPyErPuSjiU3pugyy8qzLPHTSua02rtovqBOvoVwCefN
v5VPOfYc/KuVtLm5qHNrynxWxEyE++p79uOqz4t63pTOPaXjbwk/+w/oXGrW
TyyjY3+Vc3XSMUAf1H2a0+bm2qBonljSj41vBbbIdXOODUqetrz5t9iTJFjX
JM0V1qr0pH536PqutOtA3TpSjucI71Yl5TrRL2NV3q45c1ttWTRHLu2zac7x
SSlzo5zjkMJR1lnxcQe15456hqXhaR7o2JAF1vCq577d1qP8ru9dG74VSfNx
ZVPm3a2TfLjquV7WfjF75c0zeZXki1WHNSN9SsV+WixuFtG124S/xiXKs3bW
/iBH6Lo7UpbBJ4FTynXYP+WGFvvprNdpeX0dZ+TsE4Yfx6G6dljWv0dJ3j1v
jOtrgXe9kDm/aF5NODrPkrxM1nnA33L+9Hrjv8a3GNd0GDbNrOt9l8r4Lur8
fs6YIZ4RnNf1LcaPPa38rWm3/4fKs1LWOKQPcsYX8c37RW3Wo79Ui3nM0jru
12Bez6NyTodjjfHOOFlSY3mJkvk9twMjrL9mvgFKW6xkfuH9co6rSL9wfmS8
S8RRTLaYAw1bD7+x+ywNh27JfMP/hg/C7+3G/4EDnCV5HJjxvOuPLRjM3JSw
icO/w1x/Tsjw8MBh3MIYRCeZ8H2533Fd5jKAt2cs5QXWivX/87HvuLrDNpZ7
wBR12G4zWfKLWfuAwGmGThfdLmvEfTQWR/ezbvz+Pq8T9x/o+KDECcUHB9wE
elh0sENCPjL06O+1WJeO7nlGi3XRxLbEFv1Nt/W55K2oHVq7jYed2Gds8gst
xidnlGcFHd9gLuo2dpa44dOyxnyA9wDTDLb5hYpxtc+1GAP8bto8XPg8kv58
i+/xXZQPj8sCqtu7LeZOGdvrfczX8VxgRPB7uTJtbiK+ofAizp8wFyJ88/Ml
zCdJzNs+yWxl8eciFg4+n3Bpk75onde6CyTMM0kMqWpirmvS3NhStYTj/BEr
amDCcQCJOYis5pkbY5F7dXCt2uhN4gEONEYGrAx7jAGS32gxJwx6dGKwokvf
q9d4oq/0XAOV/naLY7h+mLT/AGvCGVnbdX5SenPG/J3sx4k5+XqLbQ9FXb+w
jlMDx0T7g1mCY+bVaENs+dgNRnfY/gxu6YLQG3wRMrZ6bAzkAysH7g3M2xNZ
6/3R+WOHBxsHLu7QXtu0sB8d1uvYyHC1LRPlgBMA4/Bpi8cW9o1PWqxzAAtI
2UeqPgfp2mvZD/UYZ/dDlA9+ELwgODps6d+1WJdxTqvt/wd22E5CmdhKsMPz
LOhAwBV82eK9DFg9MHsnd5gTkRirzAlHK/+fLcbRbYftlblcdbmz1e39ccU2
jY/j2bF70A7gqZYoGhuHXbtaNEYffD48SnN5lVi7Zr3nh3+J+KevhJzsNmYc
PiLs45QDfu7JsjFz4OjA8f3SYn0Hdjzsedj+Zob9/SPJbxctf9zPuL7fWqxL
AfdHOeDu9kDv1GJb4ZiQwSuCmwA/AU5idMjgKMBMkHYUsVPzji/L+uTwbmMQ
5u/1vEYbMpdeBydM3jbsRN6c/Fn9PaIyM4n/bAjI2HTAF+QS1g++EnI1sAz5
hPEMd4Xv5GP1/ibiL/lovfMUEq7HayGDgzgG27yOA/T+5WLN0K5zE4vmom9j
jdltW99tfbb1pRP+fYvyPI7eM+91CDHlt20w73Ip4dgAS3V6DbIo6yCVnU75
N9x3T7c4FgaYgtZok/c1nyyddByct5u8b2HP8liT40oSS/GpJsdxJIbjrZEO
R8QpZXNHwCFxR+SBnwHuB2I9wgXxRMhwQhA3Z3nJr+k4U+nLJR1PB74WuF3Q
p+LvPihpn3c4AZCJzwWPxBLgJ+C5LZsv5952x/Sh/s/3Ol4PZb6i40fogpKO
6UNMGeSXdPwh/Ke21Py9RMJlzkH/2Wuehhu7HGOIdvhF126mtvpG7XYFc2C3
xwj4CvollbAd9p60uR3YF+Bzju/5qWCt1H/fqo6f9nnvuUzMk19nnJ+YR+8k
zdv2uurwQcY8Dz/UmZtmUMJ2k431vi/MuFbdzkq5/FPq7deEfxN+UsS/5Hl4
FuLD812Yv857B2Iko/sdrGsLKa9pFueYsm1jrn44YV3xhxl/p+BYeB0dmuSF
643B4174Ch7WbWwPunT4ExZNmL/jJvye9DubN5/eYgnbp95KOg/2nbP7O378
PNwH8lshYxBhPdGQdwx68DrElicOPfgOgiLC2d2QMK6BdPABaxRtY+xpcHq/
hNco7wfm51/msYzxIxnlac6bpzrBdxTcpM7foj7atNv1SoatoDPaBOxGc8K2
91UDh5KVfCO6pJgrTqy5vJPYZzC/hN0TDEhLwrZiuDhok0+xbTX5XfizwfMb
WDEwZAf2Wr8N7gsuMDjB0Plcr/qtBjflQMckhzcA/epbKctz6u03iF88vuGj
k/b5x89qWMEy/HEo/+APnccXulLIfxec/nu9OTHxQUIn9mbWmPaLYw0GJoB1
22tZ6+PQ9cGjC69vVcX3Cwz8Rf3si0Q58GniXzw0Ya5Y9HZcy/fu1azx3nf1
83dkWMLYnP4pp9/dz7hx0sGlPZD0vU5qsD4eGwDfkQ+zltHzg11fM+HvNPjv
4Ql/szZQBddi7PQ6XirxkIidCh88vPDguohlREwj9LfDQ74r7MnrJGybxr6/
bsL2d2x8GyZsd2EtTQz0fRq8dyC++b4N5mnegOdtMPaPdLijiVdA+tx9a8J1
BtuDzXEj/R3dYE5oZGxqfyR8r6MkL5Axj/HJjCt9B2vYo0rmGt814dhVe9cs
wze+aMZcxqc0mDMZWUOqbpjm0lOVtnPFnN9wf5/G9ylv3uSB2Fszjq15XoPj
jZJnvjrH7iSG5uLM1UnHDP1RZXyT9DdxsUbHweTaJeoc75JYmMTBfLfVMQSe
V523yDg+6AUNjrmJDF/6qJrjvJyg+m+U8bXn81wZx2W4osGxGVZjHa1yxil9
e6VfqfQ9apaJwf1C0vU8V+mVZvst47OMPZc6D9b1Y5R/h4RjcJ+scnZm/Cj/
jFavtYkZdVHE/5rUYG51ZPjV96w5ju25unavmq+FQ/64jNOv4bum9F0S5qs/
I2OZmGVXRsyvmyTfnnGcLWJsEQsYGe4a+NHhSSde2NIhw0lC3O8dE+YRndlq
7nQ41NcrmyN+H3jvIp7X7Q2OFcyYJ24XMX9J36vOsdUoh9jia+na8Tq/I7FQ
m+3Hng0f8HMkP6s8pWbL+JjDIbFvwrwTxNhFJg4XsYWJ8wVHzZet5pkg7i6x
u4jhdbTKf7LqOJ7X9ZqDCPm0OsfBIx7e2vXmrIK7ilg1cPuMSzjmKdxByKfX
mf/ngIRjnsL5BofdRKX/3Or9E9w58ODAh0P805ujTNYwrD3gjCNuKd9e+FR/
rDNfEWViRz8w8kyqM9cqedCPEjeP+IJwsu0Z5bNuIc4e8QWXq3f8PeIRwgMG
Dx98f6xdHgl5bozshHWLrB/g1oJjCz4t4gcSJ7uCrqNgjptzY21GOvxebxe8
/8J2uG7SefBtvj3KYT2GzpLy4Z5q1fqpU+c78eVsM//cfPi9tnm9Bu/XR/Fc
xEz8JfqCuITE+iMOItxln4Y8O9aHxCNnjfd0yF31Xlvy7MRh/DDahHXmTZp4
xoCj7TNvH/1FfNJZTY5vOKfBMQfPTJgvjpiDpyfMwwYHHjLxComNeGrCvGpw
qpGfWIRw3cF3ANcB3Hlw0MFF91uUv069eXnhA2lvNF8bvG3zYiMi39dtnr+z
JCcazWFAmXB0d8YcMq7eHA+8I/iGdzWbQwHOhMXazEUypNUcBqTjM0vcT8qE
m66A/0LCcT/hcECG7w79GDwqD9U79jTv0fhe+/vDU3R9vf2+4QW6rt6+7Zcm
zA+A3yK+hCfV288Qf0N4JBYPGb9C1gjkZ52Ajz6cDPP89OE9uLfX3HW0LbEj
8f0nz+Re+yhSPrY8/P3Jf029fZzhr5jaa44V2hb/x+FZc8Us0mheGJ4Lrif0
daQ/rDzrZ71vWrTR+kl4Yx6ptw81ZV6LLq7q572fdz/rPIOU/7eq22Rar9dh
rLdYa8FRAVcFvHvnlj2XPN/u2ATEL2A5ObHNcSR3UvoNeeO+OhuMBQNTDh5s
iZTjArB0qgWm6C3dd2Da8onKc3/SZbImeSjp/MjEnyS+9pkN9qGH54FYtzuo
PiN0XL3DPMfwHc/jMEbGbwoOY7iM4V6dGdfil31V1rymwxrt145/+zzfemT8
3Ndvs9/2mFbzc5Efbq6lU47joKaq68s4RgPrh2VSlmmTlVPWQ6GDOrzs+h+m
Y0/a6xjWMIeUvWdYvey9BGsd1jmjVGYi6e/yPpKTSX+L95LcknS8toUiD2vF
AWmvaVjPsA6ifGJYoLNHT34w80DOeK038dlKWz5B6Q8m/Sy0M3sY1kyslzYK
GcxVd9o2goOU3hm6d2wBnWnbPg5UelvYEV5g7dNmHzK4iuFFhh+ZGL5wVMMj
jU/ZOm3mFoBjAL83/N/wFcOvC/8u4uriO/BywvGP8A9Axkdgr7Lj+HyltdYp
wfG1vH6fEzxaK0j+J2leMDjBWNcjs7a/qL/jr4BnZ52LDoV1L3oUZHwkz2gz
LhKfhj+yHsPEBgLDDu4czHm/2EMRc2ePsuPtfFpxXBfK/6uffVdfSNjnhTU4
MuvwUWX7rQ0pm6uf+jNoFo++Zg06os088/DNw/cPb9iKvAf93Z7oFeG8hysN
nrSh8Kfq+TbHhzdrzrclG829Ddc2Poo/x7uAz+TGbf9xcsPrTb9s3GgebvLD
OQFvM+V8qnL3zprzbYlG80XD1TCz3lxlcJbBz/xE1BOOi5F6tiHKu0yHOZ7J
A6fZVkpfSsdHKuZ/wE8eH/nfky5z8Ub79aNbeKLePvTkObrZnHA8L5wLxC5J
Jb32RqfLu3aO+uXASGftlclbFzSt0fYpcHFbKH3tnGViRF7SZrvfy2qH6Xnb
rbZsMP/3U4x99j6q8wN831Tno9WXV7I37jW+G9wIfpmr5ux3R5xH7F3I2DLW
yDkOJTEosZVgn9pd6VPzxv2uJXnPnNMfbfS+h/0P+jZsT9ibRinPvjnLjzXa
XsZzbYXOp+yYj4+rnUfmjCkkFuTP6q+f4EJSXXbLGX/4iNKvp01Sjlf1S5xH
r0gMqUv6OyYH7wbj+E/J3yrPN/q7tL9jS/H+4APyasL5/+7n+GIT+tvv4ves
r2X849txU39jhtkb4t+RkHxvq8teHp6ANsukXaDzF4ID6+dYY+Mj/yUd9reY
0al7h46CPriM+BE6v1y7yyc/8ch47i3URpfFu3hR1CeTsb8Ye8YvK36mKbrv
D+Bksm6TUW32lcNnDvwj7Qm+EWwn2EuwSQfhr6X7ZVSfp9UmTUnvfV4Kmf3R
MLVxc3IuBHbuPpW5HTtXMvSlt+v6/qE/uZ51S94YcfCa+5Qd1/QH1fF5ldEY
Za6eskyZz+rYEOnEFeK7wPeIeAjERWC/eVjGMvuaneHEBgcied2U5QHKc3Wb
96N7VYy/7ZecC9GuezxpmXdqaMr3yoOryLmexIjZMec2IUbnnXn7Pa2g/FPy
9hMZ0WBcOPhwYs6B+UdeuMEYfLD4EwObD/4evPcDkQ4+f4mc35HJ4HxzLpN4
rGBWGc+7KU9H2u8LuoKpUQ6x4iZF23Y12FcA/wHw/vhs4buFT8BbIYNtxR8O
v7h5PljI4GvPbzP2Ccx7Puf4cLeE3wBl4mMALh78Pf5MT4aM/Xhy9PWKDeYX
g2eMNfM18R25Kt5HviP/9DNHJlyZ7OuWDZn9KXGJid9MHDbieRHTmf3yLRFH
fs86xwSDK3bHOnMWIhMrrKfZXJbz+JuRWcfDBwQvEOuoDZtcJjGkH40y72sw
ty1c66fWmdMUblPsaehziFF9d+yjqRt7ZjhQ4VF9pMHxseGNZd+9RaSzt70r
Y/5b9st3w8uhvKdVzC9P/IU1Gx37Bplv4sk9XpedrsHdUjMH5kE9jkGAzDco
UTPn5wFgMoNTiG8KMQXgNeX7RTwC+Db5RhLPBfmQHvPqwC/6dL3XisTDIM4G
nJ+Uw/qBWAmU/3G94+9Q5mE95kkiP1xJxM+B44lv3xPRtny/P4501qkTyub8
h/sfDiF4hbAn8A2Fl5U4IMToQT68x9878sA7tFm0P/v/TZrMXYtO4JmM2/kB
teOJZevhDm13/Hm4ztlTzwmZePRnl72ffrjdexP4tdmv7RC2A/QAJ0S88vUl
T2nznv78ivUnxPxDJ0Kcc2IBrh77dMphb/6m6r+i5Dd6vQ9F/pfry+YCfyn0
Iewp0B2hA+G9SDd63wdHJ/yc9SHDG87+Eb549nfsneF8Z78N7zsye1V0HeSB
T74Y9RxaZw7JQ5LmZ1gm6ozdeHLGsdvRSRJ/nviC6MrOzVgmHv3RZevY9tez
n5pxbER0TWdlHNse3eCC8S5srHzHlR1LkRjpY6KPHlKet+I9Ym++aZSDHu8Y
ybmk9VrrZRwnER3g2RnHht9Q8p0ho2s6TXJF8gbYhtqs3zpOdRufcfw+9FoH
hYwu76Y2694OUZ59M45XuKrSLw4ZXdnE6Gv0Wl/3mo/iq16vww9Kmsfiy17L
8Gx8lTR/KTrJ8WXvKe8AQ5411yh7yQVCZj8Lfxr52V+/mPTz8q1cN2vOWPaq
4IizSWOJ2eshX91gflJ4Stnnzmrz3ncqGMzg62P/DpcUfF9PxB6c/PDiwZFL
fBPWk/tkzVHMenizkJ9E1xTXsqaFl3XreC64bcHqYH8cFLgd0vGTezphvhC4
dreN8uFRfDJhn0T8HvFzxN8RzlJ4NmZ0m0sDeftGc4HAA4LPXSlkOELw74cv
4IBYK7GuYk2Vjf3RXG6Q/l4bEYP1qpBZI+Vj34Qv5NZt9sWEj4Q16uMJ86DA
MQBPAf6Xa8W94AGAN5XnwpcT7gF8+/HrXzNk/C+HxbVwEcDVSZn4CQ5S+hOJ
/7gikfHlxC+TNoHHZUI8C2s0eMngKH683lxt20bffaxr90863g37EeIfbaL8
M3otf9jrOEjEQ2Jvwr5ynOTN2Os1+1r2mJ/0Op24PAdmzYPNfoPYMMzz7EHg
6iPmEHv8WSETE+Yz9J9Jc8i8FfcqRR8xh8BDA1cL7wj9BactPCnsZ+FNgT9l
XgwiZPbA8M1QJntbOFzQSRC7ifHAtTso/Zs268++0LzxV7QP4wquR/ghBzaa
3xGeR/g/4VCESxF+z3LW/FcVyR0ly6Prg8c06fgNnZEf3Rqc22Amsa9+ljR3
JfIzKb8vfOO2inZ7KvR7lIPu66KyY0m8rXru0fMfz+hlgcO8gf1a2boxOMAW
j/qjv5o/a06/+Rptd+W+2F4HZc3dNz97sbJ1ge+1W0/I88Jp2RV50MX9rLbq
U96/2m1bxtaOfRlfDbBVcJrUddv+Bu8i7y7vMzzVcEiChYZPEowc+OpJ2P5C
houS/F/F+47tBc5lMAnMDd9EOnWn7eD83CryU/6mkU57vhH3uqneNhP2BqzV
10kZPwR2CN+3V5in2u0DB8YIfBE6vC9j/gFnRH78JFjjv570Oh9/NPwsxqBa
qtru3VL1uv61pNf21PPTaGf4TuED3DLq/FE8CzZAbIHEEkXfhg4OXdA/IROf
9J/IQzp1YL/xblz7YKTjdweOCvMz5RAHlK5At/RQ5EGeFvXHRxBfQWKz8k3g
2/Bbo9uZusG3uf4A87PAJ4puckbM+QsF9yPjLVu1vMMA8wt+EnML+7CXoswj
A1N9o9J3HOA26Kgaz0Wb1ze5nV+JfsF3hbZdpck+ZfgDnlJnPgPiO6P/OT72
w+yF8Vk+L+nY2cSoZv9xY4f3BfjNsl/A95ZrH+wx/wHp7IvZexI/mn30UjXL
k3s8/1Mmc/ttZX8H4DbANxnfXfRT+Nzje8/3CK4p/OGZ/xcLGV5leLPw8eZb
s2TIcGJ/12uMYbVm3jV42Yhdin82nFD4ucALjTym0XwjZycdO3tO9DtjAP0A
6eyv4VtAj4AOASwGmAziBqaqtgXd0KX3O+V0xiv4CDDxYPmIq0d8vavDLkRM
Pq5JVJ3O2MYnk77YKjAdbyaN68CfF/lStf2V7fbpXa5srP3bUQd4SuCIQH94
c9k2ajhILop+RH8H78RZSccTR4eBjG7imrh2QswJzANwsOMvyRjGl/CBsn0J
7y9bL0I7XBHvDrF+0QkPDL9U9N4DQkYHC54c7DS6KWIcIxMreVy399P/9NrP
fU7K3Av4euHvSTxisNwtaeus/kwZkw3uuhCYqG8lz6k4zzrt3l9TFvtoykNm
r83Y/DXlsX1/j/flxITfpOq9+sZVn/8l8vycMmcH43Jaj/f3xJYvVmw3eEhr
D/zf8fFnv5/KWWYvj/85eoFNq8Z9o8/aKvaMu6e8l0G/RTr47b277b/+kO6z
ZtU6+P5Ku1bj7f2U9Zb8Jp11QmPOvuToWNiHwYHLXmxE1bEHxw70dcRZZK2B
r9VHKWMw4Gf4OGVfKfAzP9Lu6PxrltH7ba9y1mYO6PYz8Zz474Nlbkhbv8Sx
MeTBOfMDoH/bpmq9yLHd5gbgWtpn+Zz5SdDvLZMz5wb6wG2r1hEeh89dxf1e
rngNybvPOg9Mxe8p++mDmYEroJv9e9J4ArAE2OeRf260LufZkJti7mVNjvx0
pKNnei5pXVNT5Of7xbXPhwxOFp9rIO7gpJj/P4/vCHM+MaDBaeNXjs5zvXbH
927ttN80/n7o04h5PSXei11y9itG5zYp8hDD+sGy9T1NurY35TLJ3xf4fHSk
t+bsV4uNg28ueIVZkms5c+xMi+d6IepPmzwdz7551bo3fKa/T5m7B96eLat+
B3kXwbXC9wQeFV4f8mDn+i3l9meM/ljxe7i6nnW+nPviHl23VdV6oAO6HWOH
cc5enbg6u6VCT9Luvnoe37JG9x+/8Vt/iu+18rxQtrwl/rBlt/2TJX9/H4n2
R2/3WNJ6vFVTLgfdHeno9X5otL4cGf1eY/Tpr0rv7LZdgD0gOKPjksYawb8C
Txn8ILdpz7hryjqirXTcRX+r6TmGsy/TX7XJ3098QVmfEPOI/Oh82HfukPI+
lL0s17KfXRg/qZTx2+unnGcwe2u122ZKuyh8S3eKMh/JhW+p8uyv+myY8n6W
GOYb6S/XZFvKBinbU9gTE+eeffGMsvO/reNJGT8D+1/231umvAenbO7HWoD1
F+s2/FRr4P9T3nuvHjL7dPb0PPtcfE7G8eux34EtWTFlnM9bZae/quPyGsfL
phwbvaA8K6Sss6XuPAN2jSUzlrH9YVfE5sp3ZL2U461j+xuYsXx5rK+wTfLe
kR975PuN1tdtm7KOYqDkkSnrE4aFjM5iJQ2QBfBd1e/5Iz+6EdaT6IsTrJEy
rjO2TtbJ+LSwRkV/snbKOpM9M+4/sD3Ui7omm2yrXC/qTN+uH2MAO0VLzLFg
DJHhFvsqZewa9jL2JeyL2BNhRyMdO92nKePkwMi9NeA/PjkwcWDBwcWBB0fm
HFjrZskndJhjtimuxS7XEPdi78UeFU5pbFCsm7eMdeVPkY6danbUh/x/xpoT
bpZEzL1g9xqjfLhxkXcMDB11AEeHfhE75XKxTqB/WYdjqySOOPZKZPIQT5x1
8hYpz1drpDxWB6httyIGhK67vdPv01bxTsGxQf4ecDfql41T1hGhB9skZd0d
trKNYryh3yMPerN79SybpzzndKrT1tTxVL2D75Z97S3Y/AeYMx6ee/CV/yaN
sURXOifpvSS+wKQTT5x1Omt3/PVYf9OurNuXxXcDf3mdq1R95F6s2ReO/CNj
DBCXlu8LeAL2JoxDdDT4KLE2Q2Zfk0x5bYE9upSyvxsyvmD47rHWOiNkbDlD
NElcnzTHRXfKPoDY0PHvw+8MG3c5ZMqpRB5s6/iaUT5rsK7wZWM9wwQMZ1wl
7Brw1mHjWC04ie7tMKcN3xK+I29GHtZm8P+wPmBtsEjOvEOsnYa1297yRId5
LK5N2t53Z9nrOPioTgmfRtaQXVE+a6F1Ix17J7wB+Fxho4QLCr5I9FbEeIFr
Ev6rNWLOR/9zY9n8W+9XzB/JfgHd0aSydUVwUq4d5cAvhR4JPlb0RSNDPjp0
XJQPDyV8G6yZX2k0FxH7GuxKO+XcF6yX7i17vTRL9909Z94V1kUr1+wL2az+
2itnmbVTe9p+jqN1TXu0P7a0cTmnPy55atmcf7NV5gnRDqyl4eTke9cNviXn
9r+HPZHuNT5pf8BHdRySMu/MBhl/89CxriV5zZRtaSMyfj/R6/bpnRqRsh4Z
TOlaKeuZ/2m0jA6Z93iN+O781ej86Jn/p/r8rt9H4FOVd/nFOn9nhse3Bv+8
RWP8l6u2k584wLGhFol08Ong1MGHvFS2reyZsn0aFkvZr+HNsufwN8q2IfLN
wm74etnfphvbbM/EBsma8O6yMbxwUDVG+qxYV4B9YY2xQs3+oexflpc8IWku
GrhpaU9s4ssp/aqkuQVWlHxd0pw2fCgY2/DhbJhzOazf4FOBqwVOlXm8LQ8q
fc2cy8Gmv07O98JmTxvQFnynWP9g44T/5/tG8wupq+oOLlr+rtH8Q+Rh7cS6
ifUT6+EpOc+nzLOlqsuknRsiD+sr5trVYn4mHbspa6pP4pvCN+J8uLtTtnNh
4yLuOB91dJPEscYO9VXOPP+vSu5R+56rPp2vy/GbiT1A3AF86pFfq7cOFV0q
MS9+zDnWw/v1/r5gD+Pb0dfhmA9L6Tin4HgKxIn4U/34HPrysv3KiSkA98jv
6u/BquND2BdSjnn9fL1jVSO/EOWD4cDWtn3WcSuIH4cf6HTJ99SbP2FaPMvF
waWADJ8CMnwD+KRTnw/AzqXcDuhrD+0x5qWxZt9MOO7x1Ryl9r+B90jH0fq7
UfIyOp5fdV0HVx1fjvzwNK+mZ3lH123W6ph9XPt2veOgTUzZXnBI3jHS8Ksl
TvjUeF7ihd8Xcr+KY53PUVsd2GPMUb+adaXER0df+mbKsc6xOb6eclx1bJTb
Rx+h62Y9g76Vb9nBPcYrNdQcf4NyiJ+OjYL469gpVsk6lt/kueA5ty3xKXbK
Ok4E/QR/xUMxHhrxfVPWW+GY0gA/ijGm9C9U7yMkf46vZ8rp8A4swrzBnFa1
PhUZneog/R6k849q7E2GWyhlX5sPVLfDU8bDHqPjsSnb+vbV8QD9/a/Oca73
l7yynu/zVvM5faRv2h5KG52y/RpdDnxb6NYuzzh9coOP5Jtnl94j8m+kZx/D
eqbq68bEtRz5jX7oM+Y11XFm2bagSdG/+OAcmvK5j3Xue9ZHncYWMYaJ9fCA
/h5LmdOAMcJYIR7hNzlzg/AewrFAnlqH54DHU55bds/63Tmy2fHWH46+IOYH
MTqWqzrWOtwXcF7Af/FIvMtDC74XY/IStfVM1e115T9IaQdH391T9G/kQ1J+
llS9j4fEcy1YtbyAjkP19xD2UR3rO+w39ZeOe+TNH4Jemv48MPqU94C2wuZG
DCl+/6r3ZlyPx9cfVfsu4bdE/OhB2Ll0XEF9e5/qP1V/e+n3hWDT9fdE6OOf
C39neJWeCY4mONUTWcdZ36je8T4oa6Fm+2DBT36VFqTb6Phsl2O4w4MOX/vu
PY5BTRzsXXtsHya+9Gq6/6oF++kQzx0udzjdd+kxdpXY0ed1GodL7OoHNZY2
UfrTKv8n/IF079eJO9BjfAQxwydUjGl+UekLNxsHjT3iQWL06K8FXFvF+OCv
2m2/wY7zrcr/QuP5hwbHOIb7Ai4TeDAqbfYDq6rdprHfV5732jw+SadPu/V7
aR0H8h4r/acGv4ddYPZ07FP6FLXlvWBfAuMBvgOc9OA2c5yv1GpebuSt680l
D6c8POq/6Hn7JH/U7naC654YIj93mI/+Q6U/XTAnOm20aJtlYrJgo8c+Dwb7
3XZjtL9ss00fez42JuK2YDfCZjR3359ybOPrKsZqv9VuPvWn9Jdh71N2DKBZ
Ov6hv1tVxjqtjolJ/DMw1T+XzYmQ7/C+DIwgezG4Poj3hW7/76rlnQY4Xi1l
Ytvl+zg55t59B/gbNazP/P3EXIE7nhil18T3Apm4oqObHYf02viWnZZ3TNK5
37UWc80TPwX+B2Q45/k2jo/v4ynh+8+8DQ/AhJDhUJgQ12Kz5hmxcaezxkOA
hTgx72/BvfE95LvI2mBUj9+/M6uO205Mwhe67NuPfzi+4cQxI4YrNqnH0SnC
UaYylxzgd+t55f9X43OO/r5DP581xgJ8xRvtxul/1mY7EeVgu2eeuyPmOuJx
3ZZyTFL2XPjuss5kLYqMvYy4wNR9ybDpYLNHZ37CAM+RW9cc444YpcQnBS+A
DGaA9qDvwbkTE/WWGAPTKm6H2cQhr3gd1VAJPFHK+qWN8+YWvEHyMPjP0vab
48hvfPL2qJo79xe4BSr2uRzfbh+7YZF/SNpxXuG5IbbnmmnHHXld8/CItLkY
FqzYlrJAxbEASD9J6VvUfP3XaufddK89VPfnsIkrbVH+6n3kN+/2W01xjm+3
rllR8obwIek4WH/r1hs/tnjIpCGDq1lCxyXTHjMH1SxzL/bjq6cdL3lo2jJ+
kByHRjp71krYDtChgjdFj7pPzpwe6FHRQ8M7A6cK+yf2V3DUYKPAbgEHDnvo
ctgv9siZTxKdLbg88HnwYqC/Ro/Nfg2uUcpHJwymlfvC4wGXEW3O2pWYtiun
vSbcsmb5my4fOUeMW3iKVok8xCZeVX8fMlb7LH/b5SPniFkM39FqkWduvEr9
nUz5ef/Ghj4yZNKJTb1M2nPLPT3GaS5as//j1ynHwcEXHxl//ImBrQXLB14d
XnswfvDcolNeJbju4SufZ1NCxiaFLpk86AFI+zbS8bPHlgGOcZ2qbRN/dRuD
xlqTdSZYtjdSxratUTVefDUdr8jbrxU90rUDHB+QOIH/S3nfAeZuzzbHSjob
vGvOuGfyXZm3DP4ZfRv6ODDyvWn3L7p4+B3hecRXlOMXIcPjRAwpuGx2LDmm
1HL6vXWz2xOfbo60L7Zy+nxI9PsXRY//B/g2F10O8peSD1Q5K6Qdt5ojfE/w
ZS0bfUQsL+4DfxR7W/z2t2YfrWtn6vfJ/Xz8JGRi0iITl3bdqnWF7VW3BW1y
BHzC4I3A1HTankaZ7Jc5JqP8jTTePlc5TRojOeV/SfmzFdt40F2gw8D+U0ib
A/aVVnNQYSskNhrxC4ldCMYBGZwD8+4lMfdi+8ZnaV5cddLBTZ2dcrxS4oky
x5IH+/h3ZWMZ/uwwJgF8BliF43U8LmUfHvAVXA+eZB04RNAb9Po8+fhOn6jj
CSljVsGAnJwyngT/L9LxW+RIvnk4vhMjP3lPivz5ZsusjThyjvUBnEXwFIHB
OFXHU1LGl5xZdDpxOvnO8L0BZzYSP+KUcXT4G+6dMl5xu5DBKa7SY27lX3Uc
n/aeBB/8xjbvidgbYX/GDo19+Jce8ykvDW6oyXuWG+u852HNBY4RbCHtwvdx
YNbfLbBoxG89N2V8C75ayGBTiD13YcqxKoklSx/h78b5uTFfAxdzXlxLXq4B
N0OcXGQwP3wPz49v4kJZtwP4uv2jHU6rM86HdmOtRcxSYuoxd71Qsi3lg7Jt
PPOnzXvzstr8qIx/b5Oxzh9+m9eUfoF+L4g9Un8Lpb2PQ5eJThMOroXiHPZ0
7PsLR56fir5uJck3at24SNp7mJ6KObUOVh121nuVVfpO7IfaPP55D9Jp8/Ci
y4HjeW6eBh9zIcN/DK8ytkPs2Hyz4C47stuxTR7pMW8oebAn0ufUlX6nbRhb
rNHRK6NnXqDOPmf4nsERfVrKcQTxyePIbzBUxCBGxkcPXNXpkc47eka8p51Z
y+Ca6Oezo697su4LcE3b5s03AQ4HzDJ6AXQCzMHMxeh/zsxaxh8NPyp8ruA6
w5cLnzH46PhGY++EixteNPoFPfOAinmJDy17bmaOHtjibyzfWji6sZdW45uL
7xc+YPMrffmM22R+VeP5ZvPZrtroNTYcH8TLJNYk8RDRC51VNYfuY2r7FuV7
hHVVvY+Phrx+xfIn6uezIz/XsSd8Un/r6/evzH+MvXrH7ubcnuz3Ql4/1ris
dR/v9vqVdSyxriZ2mS+wE/sDOkil/676fyL5FtZUdT7eyhhSvmGqTwN10Bz+
WeT/AxsHXHysoyR/qvTbJbexNitYpsxZkadH6U3wfKaZRDQWVLf1qJvqMktt
+JDSF9PvJ1XOpZLvQf+itcIVko+qmkv+EslP6PyFvEP81Vm+PG2eea67TH8X
S341Y5ny5l1Dnlcycb3kFzMuh/Pwul+cNjf9yhXfC476B3ScFv1yq+raruNT
+l5N63I8x+307vzQ5Dx/qZzTqm77O9Xmv6n86fG830u+OW3exXeV/8G0+W04
Tg95WpPbnH4YrnvXK+0l9qxqzzuV3q/ePI53pd0fWzJ+08bVnASPn+Rx4Joq
5odbm1j3Stsxbb19VXXYLW3/xBIYAslLKO+Nuna05OOwZbf4GmIAgS3bPW1e
+mfyLmcPyR3wCaTta3m8rt1F8v6S96JP045FBR5k3bQxIYfwjZR8Vj/b9cgD
j8cbGhvrp73mH1+zPBadGRyY6bnNNvf5eE5i4nxWsV/SohXXZYeoz/3Kf4Hk
w5T/PtVz+7TxJbMk35N3/AN82+HHYb+A3gZ9HLqDpdS2d6cdmw1dAenoc9bW
Pe6TvJaOv2asL0BXcErV78QWYHbS7gv4NdElTIkxzN6Ee+FH35z1O8s+/Xgd
z9DfROUfyfdDf4s0GBe3VTzj1xXXd7GKz5PvpkbHYBkZ+Xm+7eIZ68BmSb6R
vUDFMY8G06dqz7yu2VnHW6NNsMUsrno/iB2D74ie62ylb6ti9pB8luRV6swp
8H7G3Koc4QOCCwheAmTOXxB5SD9P93tb8tQ24/TB6+/X5O8s6RPRVer4esa+
MG9mnId1yFVq/9cy5iv4R3U7WtcsrzXDKV1+X9fssX8GfhrbxjsKRzz88Iv1
GOv0ZY/fad5t3neOr4bMHIC8R5N9MFjjUM+FsR1kXEfu+W48b2en63lOxTz0
3Iu5AT4o6ok/wnp5Pw/Pcki7cQDHl821f0/GXOFnpi3Dr393xv4S4AHAaN2R
MX4AXg24NsBBrB7pY+uM67g5Y0wI+AjygJc4T2Xem3H/jYhyKfNg1WEN1pRl
15267dPkPqCtWY+NC5k2X1TtNVltcMBAPYOe8/GMf59QcZnHV6KOUc+5/hNR
z0kZ+yChKzi93ff5WOvkE+IdP1vv8jNVY1vg03gkYz8o2mrhgt8Z5jHem0kx
j12j9ImSZ9QZ0whH4VO6/sxOp7donVNVnuvSjo+YbDVH8QWq5+vKd63S39Pv
3oLl6ZJXZUzq+BDx3yS/L/kxyUNDJu0c5T2XOYpvQdW/D6+63+g/+nFKxnlo
c9qePjhE6UdU/Q25hTUU+gvJT7T5e0X9wWQe0+RvE+PwWcY65dRZ3/JExjq9
2VpnTlXakhrvT/Y5z4Fdfj+55ws6nq+0l2MM88f45t7IL2X8vTsTX0fJZ+i4
q/4WUtrNar/nq35Xbu72u0lfsA+gX54KmWenHO71QsbfRb6J32ucjNL5H3R8
Xr+vibb9X8gP1ZnzeULa/MzDe/x7jo4p9cVKzCn6nSyY7x35rIrrc2q7v73c
a7Tu8bneqbVj/HQVvPdg/Yl/DmP/jjZ/X/imjNHxAmJHKe8gsN8Z+zODwegP
f1TGXAf4wiDjF9NQcn2Q91YZy0r+uNG22mUy5hriuGzI8+u4hP4+ajQOCiwR
OCL4ikiHv+h79tpxr34lyyxHF9axljHOh3LwS6/VuZ6DM+Y5oszFo/x28EsZ
xwgAB8iakvUk60pkMGm7VLzuntRpzAnPO7PR+KYloxyeZ6nM3E9C3U4Vy+PV
bvOzL8iYP5A4iHCmXdPp/QGxUtgj4NeLfy8x/RIZ85TBUXYrWGqlDdIDLFLz
uWvU/p9mHUvvkkZzLTZmHANshZzjCK7TYPwmZYLhHAIHs+QNGszxRBtQN7id
lo6++Dj6QtPS3PbrizYcU/DvKkv9jO9L/L6mvOtJ/bI5xycjbllrxveCh5C+
mj/6C+zVAlHmhsT90nVraM7cs+A89NGbqvNbacekgG8V3tV1lG+87nW7nvm9
tP/eT1u3w7k3I/9zzb527Ub/kQ5fK8d3Qyb/22lzvF6ZdTkbKe3Cqs9n9Z5u
rt8z0+bE/EDHD9OOhXCB8vTgE6OKZpRvPjDYGvRXZJ2vS7//zFkm/x1ZX0v5
lEv5N2nNf7rS31D6v/WOq/FR2hyb7F/eiefdDqxsxjHdqC/pxCognlt99Dtt
tmC07Zi0ZdqUvloo+gvcGvKHjcazgbcD9w6+jv4Fr4VPBOmXRx+Bk3s/8swX
/cV7B3fYjEb/LRbv+8yQGU/cC+wguMHuvNeRrCGpK+OGONrUbeGoD7xlC0f5
4AoXifS7ir4Xz7VX2u/sjEjvinIBPtAOxGQhrh1tNS9OC5yz8M1u0O0jcQyv
oY5px9rYSvKRki9U+Svi+8c8p/fxZKWdkva7f1ra6zp0C4dWHVPiwm7jDE+L
9EX1op9IX6Nv0fxzUto6hJ0ylvXq1h2sa4exj+82TuzkKH8/HfdJ29+EOY85
kXlvbNpyU8xF+0Weq9rM57iR3ptNlP/wtHnSPmt0neGvof8ZB7TbEWk/IzD2
cRXXcwUd90y7TWmqqRqrJzBuJR+l49H6023qllHHbip5P9X9VPpJ8tNqx4tU
2G34Z6gOP8H1p/Rn9PtXsAd57w3wU9g87ZiqFzS6nGclH1B17Jz9q5bJM07H
0xpdzs3Kc17cizKXa/FafYWo2zHp//iMkfEz4nhUyEep/45lvq74uuPj2nzB
8vJ13tPQPg0xP9MWS7JmV7sdJ1lF1M1pdDtwr0Hw8km+rp/HIO3GOKff6Bf6
4wq14QD6A9uB7tUr+YgG88+w32OvtyOx1nQsdJqjHk5+9K6b5/wbGaweMhyA
zcpXlPxSq/d57PfgC2ReL8TcflnOMbrAEZ0L363kQxscd4tvCpwa/+b8LvBe
NKp/+mfMV/l4lMUek/0o9YRfcIeKeWRpiLNzrif1guMervuROndxzjL5iE9L
Pddv+G/sagqrOzDnenIf+MVb41uwjMrXa1L3HBzorPvSxoMtV/G4u1b/Nsz4
HPk2l3xYjOGlK3NdDep2J75MxtfCAdisNt8/PZeeaO73f1zaa4Chkg9OO24O
644D0157PF1y2oHs0fSc7Tq3fcUcF7Qze2q+XdT5SdX/cD1LG33PWjBnuy97
SWy/yGPQNSj9oLSxWJ1Nvu8g1jxZ50PPcrDylJRhT5Vz0gDj3MC7wb0HNx97
DXgL4EQYKvnGjH2bwXVfp+MN+lu5yXwFV2SMg1017/T1da9bM76G/MxzzHfE
HTqv4PQ9WaNKvjpjngTiDpGH+ZDyxkeZD6ue10per85lXxfl36m2Op+xrbZa
r8nyVkq/mH1RxrGWbut0/qNZM3Y6/UW19xkF3wOOBfa8YGXAyRzY7md6V/uX
Ue3GGh4DB4DkJfBdC5w73Ihg48HAU0/O3VV1vd7St/hE7pkxXnG50A8vVme8
MT7q4IfRF5PeBY4mY24R8IHwiyCDYWddB/8O2Pvbq8YXPwknA36pkg9o9zg6
IuP4UWfo+sMzXjceVXHbHlkx5geeiyWV58KMZfA/yBMiHa7HCfFcZ2bskw+W
8vCCy2T/cFDF92Ks3lI1rvnxHvv34+cPHvOcjOUbYp+I7z0Y+WlV4+Vf6zGP
Jtyafzf6b8uMMZy8W7xjfEd4n3iv/mh02haRDs5z45A5bhIyHJxwcf6p8/tV
fG7fisvnet5Z8myW8Xs6st15l1WeTMHv59kNfm9Wz/jdvluTQS3v32BF4RsF
j7p2xnWjnH+j/hdGOnwE4EjxX0AGf0r6ZiHDObp+lHNAxv0Lt9I2qs9snT+q
bCwqWFh+w+V5Wcb4/0syluH4PL3gsYuuBnzX5ZFejnTG82kF9zF9Td9eGP27
ctgmVq6znQF5sSaXfUncC78SeA3wGcG34KJIXzjvOZH5cLLaZ6H4jbxRtAnv
CD4k2SZznY6LMQwvAnPIqk1+rouifOp1cdQNndMl8VxrZszjAI6Xdw0uhnyU
eXDG+y/w9YdEOjYIuPDQ5+N7umDK/qfY7MDJ49+Kj9ICKfsBof8nP35P6PPx
g0K3TznE6YRDD0w6MWzApWM7AMvONwh7KNxt8LaBcZ0/ZRwsPkPEzsSPCGw7
GPdS2Atyca8pIdcHn1wlyudeyMRhwWeJOuKXhF8jMTjxbZxrZ4lySEdeMMrp
jGvBFRCfZnSUSZ2xd8zl1E6Zgw6fCzjCwLiCn4STBf+CXUIe32ycD3nwy/g+
57hIF0U6fA3ghS7NOx1b829J2zX4loyMPFxL+bOjTM6TD3zgZXnHRQJvgA1l
QDwjzzUg+mJq9AvPi+0MPwR8GG8NGd8B+KvwE4HD6qecy7w47jUr6gMu8beQ
N4x2AL/dv+R3n28w2Ali0oDZID5RBttoh99HuHfBpcOhi4xP1r1V+yq91GOM
Ofy54MzxF8EPqrfJPLvw7eJXAm8IZdzcZt+o4yMdrPpx8b2Af5dy+Pbcp/IP
0zULawP8co99pR7o87flmMj/RI/H/k1VvyOHxHdzctU+K2/re7R7u689tux5
6dSo/6HY1DOuD891ejzjKRnn4Vl4Z0+IZ3m2bJ52sO6knxTfd57xxKgPekf8
7+AhgoOR/PB08S7g+5EPW1t7yjZQ4iXRznAhPtLh9+m5smNF8Y6xFgVTn453
rZT39djpKJM4RviSYOMrx3jgevLSd4yZtki/Nm9/Q+wLhzZav7RfP1/bGnVg
XJWinreHzLXwMhb/373aov7UvTXkF3vcTndXvca5JdY577R6fLHWW1HrkFUz
XjeulbRNFHsodlHkVjBdKqsoef5mc8aWsraBPqz5PJM1TgCsJ5jPHeqNAyT9
Wh2P1LUtgQUdGHmOrPcxGfKjnS4TXOU1Fee/WsfLK47p9nabbRTYKv5oMqYN
bNvqOndjxXW7oWK8Tz5rPBY4qVzWuKm1tZ5s072/rDo2ZyFrHokp+kZslfc1
PGMy6vlZ1biGYQOijChnkp7384xtZF9lHJ8AWwy2G2R4g6emHceOGHZvVK0D
3lbvy6tV29JP6zLm91PlubPJ/vAfSf45zpEnq/te32XbxYc15/tWecAGg+f9
Ku77jOaW2Rnb66YXjPMDw/BF1Xbsr3XtRKXPyDjOI3HbiN82tcnYVTCsxHHj
+GXIJY2NJh237XI+zoFx/ajqWKkzdDxY5fyTcT9gs0XGbtsf/LTk1SRX1KfT
JZ9c8bod3rGtm4wXfSxj/fugHh/Rx1+hej6Ysf1ioR5zoX2k40kVp58Inx84
5Ix5sRbs8Tr9wx7rv9GDb6DyxxesO0afvxY47Rjz1OG2uC91QGYfwf7i1pg3
eEdujXTKQp+OLp0j5aPvprzpUeYxmse2VL4POpzGOX4v0OP1zns120pnZhwz
o1iyLRA74OVgjDPm+2rM2vaM0mHpAR7jZ1S9P2LMs5+aWXU+7LZg8euzxuGM
r9TNJaG9UsfJBcvwQn9QdTy9qerH2wvuF+IhfqL0q5T3vIG27TbGfacUfD/2
YmAriG+BfhueqweizSsFy3CDYwchD1gR4qozxp6t836uIep8T8H1nIdj7Jc1
vvHegmXeqV+LbhPKvL7JbcW78L+q3xFw8g8q/ZOMz8Nnv1/GOrTHerymu6Hq
9eH+sWZD3jfWe5Oq9gl+SX0xOmOOXfR46PSQ0+wlq7Yrbt/ltSU+rqkmc+rv
nrF/69iMuXpZ47HWGxvyj0XrRy6RnNNzbRcyOhVkdCzXV+0L+0LNOsbdow7o
n9C1sSdAv7d3PNcOGlcZ3XNE2Xp47stv9Iejoj7Jku+LTma3jNO59tCCbaU8
z7iC1/qs/1nvrx3rYdb87B3Yy/Ctx58NHhX2FPi54ZM2RmNkDcmbtdt3aljG
/lOJgr8X2ErgZSUPQwjfseEZ+4jtX/BamXXy3hXL12gOf7TH7Tqx6jrSzqzh
O6LOyLT5mGgfeNnwq2PfxJ6GtmJfA5cl+xXKZA87Ir712BrGRb9Qxuh5fa3y
V4s644c+MuP9OBxvW2e8h3tH6b9kjHMg9ujvMYdfpnv9kXHcUuKU/hHz7duR
H5v7TxxjDvy+yfLLTY5j+X18L8BWIBPn8x3WQtgYuz2vfxdzOzgLMBnU5dmY
88FYEAeVb8r0eD8+ifnk3aqxHGA6wKhwbV08C7+x9YNbmRXp1PfXqDNYgF/j
XvgJUQfueUDB7QO27KJKzCEaZA90OU5p3wBjyXbJeL+G//iuGfOOHlywjC85
x10i/Xr106U6HoNtSON2+3gvju20fEOb9Zbg1dAbg1lDhreHd323GNvcC57T
Ftq4aD3yZbG+vSnm8ItV5x8lPwAWt8l9Q78cW7FtGDvdBQXL2IgpY+coB500
MazRSx9ZtNxfZSyRdz7S364aVwO+5sgex0U+Y4DxjvhFgPfD7wleIeLTf6dn
vChn3SY6SGJ3ouscVXD6y2AetIZ+V/fbXsdLcs7zktIf7rG9qwDXYn/HqifO
zu34+eaM3ybmPPgYsDFg6sDYEWMFvAzp4LSJTT8xZwzdtVXboZ7RXNQQ8eq5
tlX3eFb32ELni73mOV1deXbGjqPz8/U49in6TXSbU3vMg9SovDsXXG/qjPxc
3vlK8M6pnGEqZ8dux/UayP4AXZnOv6jvZo/yfKA8PXr27ZSnV3lqPY59SlzV
jhZznpMfTvWZepbn846FCh6Q5wI3yLNOiue9Oud2wG64n/JfmzNWaJucOZTx
p95C92rX+Sqdiu1e6cfqd33B+ZHhB74mrp2jPj4LThbVtwAGPmcOWJ6P33BA
rVUzp+zRxETImU+W9CciD/lv77Av9N6a22stLh8uFOpLvdkLr6frv9Y+oEd1
a1J9blL68cpzS84yz3hkp8dAW6c5VCZF/w7XtZ/o2kqP2+aGaB84V67P+Z7w
s5C2frvvOyHGDPvQCVEH9PNXRxsupjLHqczfuo3Loq24lnFKvxOLtr5kXT++
3p/2GDvwlMbShb3+Zo+u+X0iTjxNfkDRzwOOsaBnvC/nOQLd8B0564cv7fVe
jrgxl/V6T0jcmFOI75YzT9TFGjfHqi5v67iOynoC3/I685M8ljPH11HK/0DO
nJMnS340Z79C8lPODZIH5q2nZqq8vNf7XmLRpFW3apzr05rpX80fR/VYPwDn
PjoB8tyVs77uHvyVcsbk8hykLwJPVa91GXDZvtNrnCh8t2A4b4t3+YpexyEi
HhHX3RFl0s+88+A5ue/tkf/1DrffdI2lzjZ/r4izPUD1fEC/V+1xTDTa5GfJ
iyj9e50fo7Yqdvo9xqZxUa91WMQC2h19XcxLuxYcPxmZGMvYVLCnYN/g/cPe
sVvB6eT5sdNz1Ktwfff6W05sop6My8EGBA74yihnxRgzpI8uOJ3xA8b1lhjn
PPut8bwbqKzpjBONw1Xy1sWjh/+g1fpn9NCFktPhjYHjBR6ZlVqc9kik/9Rr
Hjb42I7WeJiWs756vZrHyRkq/0SlP5QzFw17GeSDNM6OK7oOYOSOlfxg7j+b
BjL76gFV+6ziz/q8nrctZ46CZ9AX5MwXAcc2XNukraZy/sraNwRfEPit7lb6
7Kz54OCCw4YI7zk8KlsNMF/kt7rPyurT29WHP1RdRkNcCydEv5BJ4xz+LXBm
8xt5MnZhxmjk577wSKRV76u5V833/Dnuu80A+yJ8XzWPy8/BL/8FGETJn+u4
QtG883C8bDDAXJZv4ftfdB78ZZav2o8Pfz78a8gPRz198kPwtK+o51pOY/ig
Pt+DesD3jv/Nj5EHX525z9Hj33C8w8nGkXLg3ANjyTPC2UKcB+I93Nbf+rn+
OevoON8ceYbnzJ0Bb8Z3XY5PUKiaQ4J0uNn+SDnGAFwE6xcdexrfKGIIbh3f
6I1zToejAF8qeN+Ii018bHg64OggRgHlfKn0EXreRfQ+nz3A160T18LnsW5c
u6DG9sCc+aaGKX87XCDK/7uesU/pQxocs68+Z38iuDEgOrizv3GbpN+ga/7t
ckyUD3o9LhgnjL278VXXGD92oPnz/876N/Fe/pF8R3+33b9Zj+E7QyZWx3q6
ZrjKvnmA0+pinFP+nBh7tDntzLjDT4F5cjFlvSXGOuN8NZWTUTkHDzBedAD1
73AcUmQ4tiq95nZft+Z3qz3er3Kvud3Xrvm94hycX229fg/v1VjK6m8j9Vm+
z+3THu9ghe9ezlxg11WNR3quZn73arwXa+r3Fnz7dW1Cx7T+pvc31jWTM/b1
Q5V9W96/v694HfBdxWsuMEDEw4QfMhdrA+YD5gF4UW6P+QGZmJnkBy/Ui76V
OBbw4xEfIWc+PvC21AH8LTx1cPA92N9cMsjwyXA+EXm+rfjabyp+Xp7rxf6+
L+1PDJSFSx5LL/Q3JwfcavBy/Jb32GOMrar6pNQn4wY4rSXSN1f7vC35Vx2H
FX1f+G020+83Jf+i4xClz8oaE56v2scevg24YZjrqAu+c+SBh/DOHtcLUtHp
PX6OFPgLlfW6yvyp5jgK9D/+d8Qo6MyZ222lqrkUAE4xv3VFeoeO5Zx5/xkj
3TFO4BTpiffu+l7HWXuy6nVxR/TLZz3G+T5b9TquI8qhPbtinNCulZC7VNcL
iBmv44ii0xlji6oNf9B3a0+lt/e6H7auug7rxJwwUHnq+eaAiQ6OVOI4parm
aEhXzSMB5/UJ6GnVR8frb/PgKoCzAG6C4wbYP3Krmv1z8fOtl7xxydfCQbF8
1tdt12y+i62z5lXGxxpf6+Obza0KZ1Oxahs9/sDMjVy3RVy7XMjUZ6+B9vde
oWrOjEMYY8320cZv+p+q+Qfwuf636lg0B2ftUzw2a05/fB6pD1zP8Gb8obYZ
xbeg2XkOjjLh2YC7I6nn+lZriUOz5tuHWwSOEWIBwOkBX0f/mrlHqBN+lPDz
kx/u6E1K5keG6wP/5i3jWWjnLaNuQ7KOK4C/9i467pq1zyn8HHB2nKP8lZLP
/U39ddxZf2OjbSn/xLAH7RZ9RH8h44MDJ8tcTga986MGOrbiKI2TzwouC96J
X3O+LxwvcE3sGOVvkDVnOr7wcJJsFH23C3gk6t1snzh8qKtV56F/8aPHt24f
7HFVc38BFGmrmnsNHjZ8Jyl/kyhzzEBzbQysuuxNonzybBgyaRuEjF8jMczw
bYQDGRkf9hkF56HO+LoeFH1KDCHGIP7gg6rmIllUx0m69rCsOWRYRxMr4mrJ
oweat2hWr3ldjlX6V/X2PYezfhOlrZ01Nz11+KlqPzxisdG/8MhPUJ75O3zc
UmWNUdp+UT7jbZ8YA4yNA0ImD3WYGy8p4fy0Z03HBeO+yNQBX79/2u07eIXK
n09pi+lvM/oFjmO99wvVzJ0/OOo5q2r/M2K60YaDI//+PfY/+13nX1YbLpy1
P+lmaocj2af02b8Qn8aNGGOdvt9t6LJ6XCZl0z74H+J7iA/iQlHnb1TmuKx9
kD9CLxTvCO/Z/tEmzA97x/PCOXwsNlf443WPo5T+l+pxpurxN3oX9h8FpxNP
irKPYG2gcl5N+72eEekHxvxzRI/jX82u2Y8VP7tv2NNUzGsEvxH5D4964jd9
eJQJv/SH+p2pOs4IsX5Z8zDPHBDzCfcfF/canXVcEPj6fi/6NzJzxl5Z24uZ
b8ZGv39dsMwc9WXB+ak/vEmUg035q4LHB2OD457RVrx3yNi74VonJiXrZPiG
4B0i1gnjaEzkhz8IHiFioxBvi754pt68UsxFJyntE91r20jHvg83KzZ97MjE
l6oLWzz4M7Bn2+fM04pPJfF2RufMycZx+5DhrOVauNfG5FwmPobg1w7IGWvH
HhZOgX/7O8/+/++++8e1lEe5/8BhUXNMnmPAEhd9jjrAtQznMnqXXXPmg4ML
bm4soJx9q5/q8HFK2XqPUVEm/te7RZ3hloNj7s/+LnunSCeW0Y6Rvm3O94Lb
mRhQ6IX+6G/OvW0jfXbI6It2yPlauPloQ/jm+ukZ9865rtRzPo3vvTXOD+8z
Ty1twr6VdS56AfAYNeVZHg6XPqdPjjUw3GXkQW8A/+vkyI98b+R5Q8++qNLe
17NXVc4yxM5UOQ/0OuYjsR/BsaJLAXMLVxm8ZlxTLBjPio5l8bxlcK27FIyP
RHc3pmgZnGSlxTo45C2L7lf6nb35HtHmPOPY6HfaYO+QiXW2d7QJfUT+uXrI
nMthPMA7sWfkmV/PcpSe5eg+n98r8sD5hww3BbzAcBI0dLr8PSMdP7txMZ6H
VM2jNUfHJzvsVzxNbdVP1+ysPGsSs0Df5UNzxvmDzTwkZ3zmJbF/ZM+4o573
SKVvrPQd1T5H5Ix1JO7bsewXGA8FYxafYGwXXA7yv0VjIsm/XdF5wDT27/T5
6+Ck6nQdhrcbS3lE1Gcn5T8uyv8zbxm/xUyL78uedAFdu13WawN42eFnJ84Z
HGxwtJ0FL4DOLaMyFlAbfFpwfjjZ8E/8jvxKf1LlPZUzDxjYzmNy9oP4uL+f
faMG812TDl4i0en26Kg47ajIn4x0zi9R8rODBeVdos3Rbc7O2w+TZ+EIJyN8
jKfreGrOPJbsc+G1zGKjBmtOeod9Rk+KPHBjnxzXcjwxZM6fEnnwuTwoZ7/L
ufePOtxZdDr+o190erwylp7Vu7Ok7v1cr+c05kb4T65os6/qG8RPzPse/J6T
d50PkLxr0c8ARwqx4uAZhYP9tJy5R/kNTuPMnPEb8KicEfnRJ9AO9C35z8rZ
l37Pot879N7/5H2Oe3H+tCgTfcLp8bzgqcAigwEDj4wM5gqf1+OjfTbW+3WY
nueIPusv0HHAzQifIryKnyvtS00GD2qMHK5v5jHKPxMfb+X/CNuH+vXdevN8
wPcBX8fFmsM/0O9Laub0IB1ujqN17T66V6O+U81K30XpS+udOgs8nuRlNP6O
Up7tleerbu8/2IewbzhC6Tso/RulX1bzvS/XcRWdX1V/i9MvytOpuj6nul0q
eWnlfwFOb+UdrTzX616Tu+zPfbnyrC95lNLPVD9+pTy7S/5Sx91Klicp/4bK
t6vkDXQcrzIX0DUvSj6o0+UeouMneeeZqePifNPx1+Ieyp9X/sHKf0qjy6XM
efd4qp/nY56BORk958ol6zrRqSJ36bnW0HF1+PPqfOQ3uut5+dCXrlSyzpT8
6FOR0Z0uoDp0qQ7Pqw4XldzOE+vNh7Gu5DfrzNm2Qck++Eth5y7Zpw8/NuS5
PBo63lvyNfgloztDJ3ZuyXXgvuiHly9ZRzyoy/IiXebRXiPqf6Lq06s2e6zP
un36jjY4tOh2oB9PVZ7WinUyq+lvpK67Uv34nfrpZMlfx7OuFDpibD7Llqx3
xraELQq7A3mGRN3QVyPTNrTzSpF+tu51MbEc+4yzYjzgx3ePfqfh7kEXVPI4
ZC/crjokdbxF7/IZXW6/fZSnovRWpb8KXk5lnq7jsUq/ucvp+0vOKf0YpR+D
TCxtXfs0+VvNSfCs5PHK/yV2beXZR/lfVNrJkg8eaPvlg5IPHGifyWmMQ8lP
EvsC/ZXkkcp/KO+yynkGzCv8NJKfgqdD8jjJV6r8f3TP/dBhSt6LNXjJ/p33
g6/Te36f8leVPkvpN9FvcIPpmo8lj1J7LdDqMf4Y/HjK95LyL6Lj4nxfJS8g
+X2V/0TIS1fN6UMdJim9qGv3k9zd6vfxK9bqqv/BFeMG7wsuwdka5w/qeI3+
vsBvTmPuasnNfJdL3pOzH39VZW9aMk8/e2jSV9BxmZp1UCP6zNFFHvi71tLv
dfUsZzE/6JrNSvYfKeKLU3Lau5K3k/yOjgfhv6Tzz+q6C1XPIXDR9Tnv5pF/
eJ/zkBes/JYl865w3CrktfvchherDV7Hvx++RP1eTr8fx74E74HKH8yaALun
5L424wF27/Q1o3UcqfSblfcy5Vm2y+Xvgu0OX/uSeS14p7eL95r7cd+7lX8n
9AZq5/mwu0nei7j13Z6zty9573SI0h9X+Vf0mZNjwyhn+VZzPe6he3UozwPg
Fvvs//6evjGvVO3//m7I4IIOYt5Re2zO+GO+1b0O0PFA/a1TZ/zbx8r/WtU4
qIMCC3Wfyuljf6l6btbnvFx7MD4w+vsG/1/Vef+SbYKkcW5ovdO4F/aXIwu+
3+g6c2HBi7UN3w7VvwFeTKWtLrko+WjJb2osXcp83s96s0tijB2T91zAPMB8
gHwUtvwuc4Cd1OFxR/7j4L5VW+Ww56itVlL5K6id31P9z4r68DxHFdwO1HFF
eDSZx1T+sqrDSSXbNcDz7FcypgeOFHg26RO4b/cumTv0o6p5/T7WcQBrRaUP
72dfBvwcHtRxbZV/rNL/Bm9ZsnxP1vhbsLVTq/YNAbN7j46H6vxhJeNRTtDx
RP3diG+p+uJ1PVNCz7RU0elL6jhS6cfwHvX5N9dMVP62otNbdVxdbbWm0kZ0
GJMMfvcBHdeIdM6DleJ5m5rsm7xvyf5J8HzuUzLXJ3y+8Ppe1uk22CfaAdwL
uMf3qvan5tqvG415+0vpH1ZtM6JtsSvBXcpzblhvToan0e0rz50FjyfG0mdV
4yc/13FV1e9cpa2i4yH6u0Z9OJZ3kDmZOECSd8v7W8t3lrlrWslzFvuLc0pe
368S5XyvMTFcaSNKtllv3Of5kHUK6WuVbLM+i+9Syb7IHPk9Q89xvo4XkEfy
NgWfI31d1Sfdbh/bbQu+b//4Dp4b3z5s3GvFfeHPpQ58XzkOD7mN747qeKLK
aZV8DlwL6KUlf6a2z0guY2/SfDKFdZf6eJ2SeTYLSr9S/XxLn3W6ayt9AvtN
pZ+lco4D29LjtcxiWmP/3upn/bVkjk7K2EfvY0X5v+r03FuSfLauPb7P6w6e
BRvzMtSt0/w2VxXdLoP07g0DD1LyGoI57ML4pozX8Sr6Q2NguK79R2WeFWvC
K5W+YLvPk+9c5fk27/RzQp7A/JP331WRh7UV/b5TpE2I/Mur/IXazGW0Lvyb
SsvqmOnyXJPrMoaCe+2v45nqv5NL9jecUHT/8kxrsnZFvwIvrn6fovSVi7bL
nFGybebMGBvsGUd02c/w/g6Xd0qUub7qs63q85HqM1TXn6r0AUq/PtqNsYSd
6vSSbVjEI0CGEx9bD/d6Sekfd/r6T3Q8vuh2Xr/JHO/DY0+6el+sWaOvh4UM
pz/8eL/A96C8S+vvvf6O+Yw8Ofb4y8d+f3HWdfp7X3m6e33coeqYAMuErgCe
GPLAFbOcnnFB9mm6V1evy94OPTFzoP66m1zmsjlzU75RM17g7G77uh1X8Df8
/rx5AdBlPaVyV4797z9Fv4v3Nvo9WJF9favLXDLqgN1tiXiWwarPhRpTf8OJ
3elyftOzP9Tf1w5ucL8Nif3+0JoxQft229+UOnwQ7/hKcd/VapZXrblvuC+x
qPBZBjsHhm7PwFiCtbyIvYzq8LKO76keazUZ7/G+7rubnn1cu/lV8If4XMev
9LdTk+1QgyVPU/pg2pK1hvLvp/xDdW4o73uf43MRW2u4jjP5vivPkcozSuNw
d/Y3yvMJ32jJ96pur+j3h61eg73aZx/I/+lZ3uUdUp7b1H9vSd5a8kZglSU/
or/b9Peu5oaHdWzX+zJdx4dKxqbfreNj+rur5LUk3zV8Rx6N2EnEULqx5Gua
0YU2WebaiVEO58H74ZcOxo+ykPFPfzjqwH0fjXuRZ5Seo0Npm6ueUzpsg76H
eAqdHt+Mc8b1QjEeFtBxwZwxYfXKs6VkALuboXPK2a76r65ZRefvVnm5vH2e
8THhPPnwLcLvmXTWn/g0U85PkjfFfyHn+AjkJ04JXK+bFY1DgIMP/5FNo5wR
NecfXnP8tc2iDl9IXjXnd3qDosuiHHQy64WeAdwCugIwD5OUPjRnfdjaGvP/
qg1W1Xj4Ho4Y9VkTNlnJT0turjkOB/E4fq/4mtV07VSVs4bO/QmflMrYvWqf
DThup3dYJ7Ff2UfuPRcvETJ1WF3HNUKPQX03jGdp1Di7hbGrsfa1nmuDnOPl
YcveMGT6Z5HoI2LOE3ueuHuLqR7nayz/ofegU+/AO0obqXpN7fD5u1SfdYp+
/5lPiK3HtcRzOULPe0qTbWc/V9z3Q9uNI4Df5JX+jkG/QIyHXMLpcJ4QQ4xY
Ysy3zG2Lx9yCHpvYcuiumTOXiHcffAj4km/AolTcnrQt+qVNQkdEHmLhgEsh
faPIv4Se8SrVq5++uavk3O/0BXZ86gC2ZJCOi+X8/G/Gb/T1pA2K5+W4aKTT
hotF+t8V28+Jj7aK+uDW6Av2dg/GGmlayOz1ftS5/TUHpNXmP0k+QnJR8h+S
/231uus3/X3b6rnlF/0drTydyjNL8pnEi5Wc0XNtI/kQvkFd3uOsiz5Z57pV
n00lr6wyDqk3//nEin2O8D1q1Ln51a9NOq6iPIfVmzv9V/0+TmUO6PEccHfM
A98pfSwO+Ur/mr2W5FlwGMIlWLLeazn93VnyGv939t6t3oOzJr0z1qWfs/fT
tTN17Raq8xD2kTpeF3MbcxH3nBz3/Ub5d1b+35X/Z9X7cDBVOm7V5XxcO1N5
FsZfSnn+1bvUDoFAn7/b98Qa6bya97sHsMZjPa88HTqO1pgosw5nrau/P3gO
HaeorVZXWw3s9N52W+VZR8fJSl9Z6ffAOaDnu13tdonyLCh5FclPQDwh+Wkd
JkgeqTq9pzKX0LUNfN9Dblaed5XnEdZ8fAMk793nvTb7bvb1b7P/Krhut+h+
fbrv453mkYdPfkynYwq8qvt8hC4CDl6lP6D0gn5vUjRuZ5DSRyj9WeXL6ffG
gQWa0Of4AB/ruKf6tafRtpXNiD2ALVH1vUhj7BWV9xdzVMV6dfTxL+hvFhw9
quO6yj8fPp3E1oTfX/fKav6oqKwTdK9dWbsOtJ6L7+kzDda5wbG1na5/oGTf
K8YQ38Jl+nlO+0vlzNJ9e0ue3ypKn6HrF1CbTdP5Bv3dpPSdlfaO/n5U+RO7
vdfYU+mb9Pl95PpVdRxY728gmH6+dQ/HN5dv48T4VqITRve7Xp/1sTuH/Jb+
vlH516r8N5lnJV8NnrrN5fa0/veef6l6vs/9dG6y8vyvz1wJ76q81yR/1OrY
f69L/hheZnQUkudT/nvRx0juZg3MekZ/c+BYUfobkr+SfFW3z/Ps5X5uhz/r
rb99V38/wcMV5dwc7XN/vF+8Z+g6af/72Dvoea+VfKjqt2Ofz1+haxdpsz4E
vUij+u4ZjZPxOt9P8qPt1jP/qb90m/WElDcl+nQ2Y73N45m9CTovdDZpXZvR
tef22aeQfn8RjgWlb67xMlHpLZI3knxDn8fCHbEm2SbmCuaM9eJePMdffeak
m6K2/Zt1WNm6oN/0+yid30ry9TreUPL1BxUsH6jjTn1eg13e7TEwPdZIm6ru
y+qe4/AL1LkjoxzGzO1Rn3/0O99mfSbkWMS3QBf6b59jWqADnBrPzr4M28EO
MT/zXbg2vgX4/eET91jV+IdFA+ewico8XOUc2We9wJoRB2Smzl2nPMP1rq6o
b9AwpS/b6L81Co7twpH0WfVOXy2uRSeCrmR7MFrYpCVvozpMUPqIgnl65y85
D7qUyUpfq+BYtFeHPEPrlVf0t4rkBZV+ZafrNlJtNbzNMcqR0VtwX3QXWT17
VfdJEC9AaYP1963mgB72K/qbUGedPBxzTyv9BHh7lPZFyeWgB6ENHqjZDnG/
jl+pfpOy1q1wn6FxryH1zoMOl/gzQ6N91mxze2yjupXwDdG1m2KbBC/R7LU9
zzJc+RuZw/O2G8J7DyaY54fji7a6JutrSCNeL+3zfJN5S+EsfU39cn3e+FzS
4YqFX3EI9SpYP/J40b/5flwIt46OF+m4XMJ5aNvRrMl0fEj3Pb/TvMLTVbe7
E64D/UU7LkE71puPlnt91+DzEyLPygX31231Lpff59Sbm/mqyAP3GPnhMjs9
xgNp7+edn2uvBw+SdZyvbNEy8YnhauXZ4VydrrpuqrxTul1PyoeTn9g0yxSc
znMgEw/mJL5h6OGxf4ZM2h3KX6N9dMwXPeZ7da+b8DVV+ge613x8f5B1zT01
p09mHZ722N5L9eyv/v5Q559X/6+A/qhg/tvmNqdz/qwu81LeqWvvxQYn+SKl
LZW0vRgfOH6Tfo7O36W/gQXnf0rlvK26nNrpmMuUPxbMiuq8b8H62z614T6M
+UbH8MVXcPE671+R8R9cRfLYgvkR4R3cS/IXjeaLhPflsLJ9GPFvxLcRH8T9
CvZDJM47Pmz4r6GbQY+DfmZUxX6L+LsfoL8TVd64TvOpUB84VV7Ku574OX6n
sbU8fBJl9/vyMU7gjYY/Gp5p3l3eYfTwN+n5t9DxbY3T1pJ14ujDC3r2G7BV
gIVIeNwwZibWzKm20EDzi+ADif/jnrqmU/IlKutT3f9Gxp/yX9pkjlH4ReGd
Js8SPeYThVcUzstjmzxv4Ld7TaTDh7lHlA+XCTp36oa/Lbws8LPAsYt/4iDJ
M5X+csV1fqnicddXsB2rWHR9mL9ui3aAQ/vuJnOn8l7DmYr8scqZWnN9r+jy
+8Gzf9RsnlSe5S3lmVXne1A+PNyDoz3P7nR9zgp7B+08p852vBUKnh/GlqxL
R6fOfHx1zD/w38GDN4/PDBnON9Lh3YMrD76+nrx5KfEbRebzBYcZeZQ899pK
3nxor2jc35z1XDu76O8H3w44+jrz5uUjjuKAvPkhHy+Zr5FYwCt0mgdwzbLH
/Pz5//xtifuIHy5+weW8OQlfKdlnmfjFfGP49qykNr9T8/Ofuv/FyvS88ixd
53iOzehWsdXW2X95ybz9jeEsony2ANgC7oly8GXEpxE/ykOKxgNhkz1M8uD8
f+UhgxHiuHjI3cozReWsonJGwnmYN+fQ5pJ78+YrxV8Yfyp8qb7QvPEGNlvs
sEXjwIkH0QkeX+WsrHLOKRo3Tsyyz8HBSb5E+S/T3zuSb2Y+V9679Lddo9Pe
Rb+htrhQ187IOb4S+HLK303tVFObvye5X4frQH7Ku7TF6ZR5aZRPOWDWqcMo
XfuXjn/rb3az/aPpL+Yo1gL3Rr/jD8Yz4tsFh898eeOswFwhD67znMJ8B3cT
cwxzDfMePE74lOHbtZ3u+4/K2rZm7qCl8+ax2rvga8kPH0wt8nNfroUXihie
tPl8zD+dnifhXyXu6KC8Oazgilkw73ly0bJjmzyl464120F34ZtSM99nTgPo
NtWtPW/90q2S2/Lmt1u203oq9FWP5X0t+ihipLRST8kNKrue90tlpfPmRoEX
5dqi/TeyCWNwOvLG5+BbkYx0fMq4Fz5plFmQ3K70R/OWv417oSNDP3Zz0TJ5
Ppb8MOXkHaPmOh3v6mduFThWtgEnVvP5HUL3lZHclnDceGR0R9zrobx5yXeq
2afhQL7RnX6eh1mXFy3zXB9JvktySn8n9vez43/EewcPFb72pPWLdNZCrKVY
R22c8PsO1+gcjbO74xtBOYwH2hDuWDhkmxL23cG3J5EwVyHp8MrCIbZI3lxe
8JjR7/iz832k3+HsgguIPEvWmRuLusEh2Fn0fXkHSYdLCw6yprgHdgT8xbgv
/kRdRc9FzLFzcuZPvDSei2ek/+FqZZ6ErxVuRfL8o/fieK0NfmIOa7XvWEPe
PmU/hkxscPgXG+O58INjbOBDQR36x7MzZhhLK4berCX/H98SMngV1qp1UZ/P
0547mDfA2oALwS6G7zU+2Pgm3ph3bCf6hXtNyttvbttO+w3tW/be9+O8MVLb
ddo/Br+kL5V/Wt64Kuo8KdrqpJrru6Hm6m067Ss1VuW8V3A50+rty3Z93Pf6
DvvhLUiMvIKxT2CuwFdhs7+oZmzeA3nj7cAsga1av894sAfz1vXt0Gk937iy
bSXEG3g/bC5T87aREMvgC8lX1mxzwP5RTDj2yvS8db/4plEmOld4ieC/nhcn
ARn8zFi9G0s12CZ4XbwLvMsvt1pfW6445tUNefuX3Zw3Dyr9nu/18x6o9tm1
077+S5Ztl8E3DLzr5yrzw7z1O3AJwDswjx8OGf4B0l8NmbUbazjWmWBrKQde
Q9YOrCFYV4CjIM8zartza05nHQvOjDa/NPamM+K+N8XcwlxxUNXxC4hZAOYC
7Ah4CXw578jbTwifLGIhYFPDBwwZv7BTavZ7O7nmMX9ztMNnRa8tWWMOD98x
rqXviIuAbxl2H9LRCf9Y8HgAv4Gv2a35/+xQt+Ttb/VBwjK+YMyBxK6DY2qf
Ttvq9+v0ezQ5b78j5q+7Y9zCWwInLBwm6ZLt9Njosc1ja4dLHOwweGK4cZHB
eIEr/jRvnBxx9Bp1TVbp0NOAachFmfiv49MOPwGctOS5rs0cpXCVwhnJtdQB
Tlrsndgj5/qdlXwv1ip8E+FJnOcvjsz3EZ4PuN3h+lgpZDgpu7uNQwTjt1bR
ZaJvby6Z/x38APmTcS17BbhODkibGz4R6Xx703EvfLSR+SbXuswzsmm7r22J
/I0ltxvlg+cF17sza239vS35U8Zw0RhTsK/kAS8LVvZCjZX3JF9Qs8x4O79m
Hg3aG94MuArgL4CvABn+AmKijMW/W/fcq9NYvnvjedHVT8lbt898dff/FXXe
YVIUXRffXdgwGyfs7ISNs2AEQUFFQQUxoShmRQUDIKKoiAEkCAIiCAaCEQMG
zFlRQZCkooiIoIKYc46gYADf7/w85fP9MU/duX0rdHV1d3XVveeEe5Zn6TPh
+XlwGDP4WX0cd36edxyfG2xGZo2JuzZlPADaALYAeANgUoApUQ5eStTYvPjq
bo3aL5XxgR/lMQXG78UGPhiuNbGs3GP42OL/iu/rgLhl/GbR44OLX/C3LT1m
CHO9MO56wUC4WHLLmGPjGW/I4CfQNjAvBgbfWPoZ/9s+YU2ONfEO6tOrdG/t
r2fYLhFfo6tYs9K31kjWePQM2KL8x8b8/28wfCRPlDyTdU5d/5+VvqzrdC/v
QOX7RWX8rN/SAnPSHRMzP90dWZdze9Y+i7yPiKP/O26bSQV+T50Z9EOS5hSA
W6CbrkdPrrX+D0q4fHCYi1nrjrleyjg61HUU36P6nS25J+97yYcVOK6a2HKw
qQcX+1xmS78sZ5ufdN/8pmNHSB7S0vUiT5DNxnK34fyWLps6OD/WUTepzEdp
Z8R66t2Er2mw71pseXyB8V2Gx4xr9Irq3ZXvYNV7p+TvVM7snL/l8bfAFwN/
KnypiPlfnbIfKD6oc3L+3r9b6cA82+APtjpnHN8dGu2HRX78ssC5Ya2goNC4
6+D4g/deV2KsanCqwUxinYFvNLCr0RPnDbY8uPzgyTOXI29TWFNlPRVfX/wL
xsTsY/BWzr4H+CCAjQNWzn/vLmQwc8CH4rttgs79rpzPtaze3+/gOoGdtDLn
8lmnxZ/2klAX67jIrOuuzble/BzAygUzNwXeaaFl1lDArxoRM64U2Fh8b35Q
bZ9o/KTxYcbvlvkSmAz434D1wP4zuNCn881d47k582bmzKNU3/4tzAF3UZ3n
aMy3FwUb5vDMt5eE9yl72nxL8B1BbM7LUcdsEO+zPOoYE/BewJMhPgW8F2yI
FcIXGJ/gdIn9gbHhG4L4lZXB/uG4y+cbAQx1MNnBa2dsbtTvK53jF7J5J2q/
yZMSll/MM6751+Ge2hDzfODhfHPfrY+aU/Ye6ddFvRbWNmL95ELjCeA7DU8S
3w+8u/79zqLs0J6cfq9HzZ3BfGRVmLecnnU/8a1xQbGfHTw3OD+wdTgveDfI
C98G8S9wXxGLxDXqH54V+EH3D3NdYjKIYyEmpV3C8SpFJY5NIY4F3O0VOXNu
9Gtl3+4BoRzma7+FuQpY5Vz3c1u4n4kdAtOoY8Ll43t2fdDTTrBhaDPXp03C
fi34reH/gox/ywVhTtK6xpia4GwSv1Ap+0SYexBf9kr0/+OPGBvEAhEHhJ6Y
I/zLq8M8hGch/Tak2HE5fWL/H3tDStzNbgn7zBWHfugbbCYl7X88v9pY+4wZ
8PaJraBtfHvC49mm0pyeN2j8fKL8i/LNrc5axAuME+k3yGYBYwweZ7Xle+IX
W1q/UPoPWTuvNKfq7nH/57v14Ij1l+CfrDzHK71D99RpSt9hv1U22+XM7VCl
58NOyvuW9OMKXM/6YNMv2P/LZaZ0XZDhOEOmPL6XPwxtOFD6Dyrdb3Avz5C8
DMD6Yq/5sEcA5yEcunBQ3gRml+TdisyRiAxn4j/q048rzbuCP2yT8v2lPq9X
O5+T/lT8SZT3fcnn0caM9W8rncG+otoyLuV7kPbw/71K299VYC4Xyud7sqvK
WSv5SJXzufJ/iz84exay+bzS3BpTiy3DdfGN+vNC/R+ld8EUXcdPK/3N/Uml
5Y9k00nt/KzSe/Tk/bLSfC6U8UUocwm+A8RztjTfC3psa9gnle1X7GPimyR5
cMq8QLST9XZ4aijz4Xrz1vC9i1yicr4K5RCP9m1ozxdgobb0efWq83lv03ls
bbAf4ehGx+t8wzkonQMmJt8EOr5G/fNdpcsrbrK/3T6q8wbGo/R/059N9jXp
nHMsGXrqK2yy712XnHU/BHvwUntHjbMKlzLjoQOxsbLrqHQX5VsSM7YquKv4
S+Ivi88k8T+kHZX+j7g8yT10zZ9Uu/eQ7nml1yq9Xr+XlHd/2azGl0bpoxHr
iecfpHZNC+Ozo/p3qdKT0ralzJkl5piFg/YGyVdW2h4uzv4Nxir4Re2dyp58
sL805zj1f/nl+Y6JmpvsU85BeQvYo8SPlvlqnnFEu0aNIwfGcLeo+dEGq537
R82lBr4oNmCKwhcAJwF44//inUvuBNZW1Lzm4FBdoDYcW+LYfDCNsT9c+jkV
xjxiDgGWETK4RsUp89hvw8eg2OPyxALz1f/LW0+MqtKz9bsx3/y3x4TzWq58
M2Xfmb0Q1Xul2jWUuQBxT8wpNN7y1RdXSH8+3x28s5X35ULzJcObfKHqLYi7
HPpnlmz6RB1vDqcqYwDebeLK+0bN80tMOjbEwt8asZ54c8YSXN3g+HJ9Z4S9
kqfZI4cHCT+xqK8pa8hc0+lhDByY9ZrxT2ljVMAbDWf0XfgA6Dy+ZE4um7Ok
B4SddFDUa87wS2M/o8SYwCeENt9Xa5zFnZocI3h81LiPxNqeGvXeNPH4yMTd
PxJxe4jT/lplLq70NVlUaZk1qH8a7Yu2V864F115hoBr0WTMhy3E7TeYl/4U
2X6Ov1ilY/M/jFlezDp5lbEMwAfoFDFnNnzZH8Tsq8P76ETVs2uleaX/49Ue
WmQ/Hmw2gykjm+68a6R/LmPeY/Rcr0NDvXdGLI+QzfKs650n2/fVzhN0fi/l
7AOEL1BJyj7S/93rR2SNDcF9/XaVdfA+R1I+77/Txi2gnfQh53dwqPdutWG/
So/vsQ3mhO/TaLwCbIYXeSwdVOl2z45YRl+dcnvvSLs+njd81y1X/zRUmg+b
9zg8vmAoVHOtKv0u472GDA72kaXmAAYrIYWu0mODsY0Mp3BdpY+hH1JvTIlf
WferM2bSrjm/H3cO5fSuM45SO+kfz/ieAJNhqsboJvX9jFZ+z7YPbYNLGt5o
yj1Bx+7UuVU2mkcafXtifhsdz7mnynw9ZrwJ7q/XJDdKHpvvNtJWntWvVbkf
4Gc5v9484T/kfA/WhXM5sslrVR3Z28RvUPWWgw0Zc1m86zmvbOg3dLVBT9/W
hro4l/ogwynJcxJc9m7h2V6fNYYF57pA5a/Tte6l/pkmeazeDQOYK8mmWLqX
GR/6/7bu1QX0u3Qv8q7Q7zLp3wUrlr0ptfUjMNCl31M2I1T264zzApf9puSZ
BdatCnq+61dL3o/5Qoll5lSt4673EMnfl7te6liPryPzKqVFzEErve6dVn+d
rLSFrmdzaN9prHmUuJ3o9gjPauYPP5V7LsGzIl9j4+US466c19J5Oa//niO9
C1zP/FDX6hLLhTq+UOkLXFPlG1tqOS39F+XOy/OnOec5ZiVciOr7DpTJ81N9
fUWJsTLA8FhZ6TZ+UOX7+mld0zt1vIvkbjyvwCOS3R4qb2ujcYs65YxDAT7O
6UXOt2/I+17MeefmGx+IeF/ewdz7u4VnFPFUYAmBRbR7udvGM5w4LGKwyAPu
E/OEnPp270rXBQ7PxKj/I4M3RRnr9Py+HOwcnW9W74D3dZ1elf49pdmcx9Vg
tb0p5+v/J/ijkl+rtMz5vxb6c4LOb4Xkdly3ZpcxupVjwWg3cYhg+pCeWmQs
LNqznrWQmLFoVuabe3tcpbnqGJevh3GYzHmfojpn/jR41ProvjlFv85Rc9X8
WGXeCzgvVkv/Q5Wxf54v8jH0+CR+W+V4/2dKrH+f+5TnX6WxRTqr/J+rzJGx
pMh6uPa66B6L677skTaeEOWDNbQYzBXJT6i8grRTFnbBO/quyu+toyXvHjUn
0BMq8xvpry0y1tTX7O2WGPOH9xbvLN4hXwU9fB2cF+29kbl3ld9xO2bdzoTu
5VviLvNN6Xurj0ar7PH4WspmiXRbssa3Aufq8gb77OC7gz8P7xTeow+ArSr5
iyDzXkPfJnxTwz+3XZ7fV2Oixjg6Kmu5kPhq4uCixthCJm6QmEHGLLoJYQxP
COOYscB/xuLKMufF/lnJV0Y9VnlnjZB8P/gAEV+nTuGdOzLqdk5lvqnfW/l5
/27mTwnXa2iDMZ+Ob/R5YU9f0BbqAqPo2KzH5TFZYy6O/m9epPJHRd3/xDgS
98g91iu8r3lvc7+h437jOmK/VHnH5MwbX6VnxWtx5yVeknOaGM7r6Kzvg6cy
jpWkT+gL+vNypb/DqVFmmbxwQsITCRfk5irjfIHx9TtrwvrNKzFGFjLX/pUq
8x+Axb2fzv/SEscDxnPmlmzGH5U97PCsZj//4Urv6RMfRowlvojkQz48zANX
Sd6+pf0Q1kq+vsQ8ZnCbjQnfFGuDDwM8Ptgzb+RZ9UaV+xZ73q+8W3nHvhby
rqxyOWDjzy7zs5VnI89JZObqxM59yPwefKgy+04wRwXH7qMqP4PPLLLNU/l+
pqKfG8bSp1WeCz0Xd33sTxFHujLUC14euHn9GjwXY07G9xE8nPBx4l8CVgM2
xDYyRx0SdfnzwrfSGtbgs04blLbNGv/sj6y5Rx8L15Fr9Xu4XnDgwIXzrOpq
k7V+Z6Wz+UaJOs+qEvODcv0YC7eFcsCF+iOMAfhI/+UlVZnvqm1/Sr+8xOOH
vH8U+ZnxS3i+tUy7znzmp7LZWGV+n+dKLPO8eAv8QJW5NuPryHuR78GcxtBe
BY7RZp6CnnfllLivNTYDG93uRM7v2kfDGDsh5+cYzyLq2RTq5TwfD+cFfhs4
brRlTZll8NyQNwU9441rxBz27nAtmDfzPcd3HXNj0vP5xivyuDo36nF0TtTf
gDfkOzYTPeNtX/XDtKj7pavk6VHXxXP4uqj77XPmwWpfiwJzZ8ClcU6eMRF7
RM3LDN8Feng9VmdtX6j37Kv4KFUat6tl3DLldCl3+TznGQ+0gT6hH2gDY+g4
lXOx8h+GH6h010T9/mL8XxXG4ULJk6N+x12eM97ebrr3T2CvC38cpcvKnJ+8
jJ8ZUWNzHVdtvK5/0n6eoGdcgfE1M2qcrtfx+1OeHQrMS4Ue7K9FOt+Do8YE
Lo97jMJpC9Y0+v1LHIt6YNQxkiu4fpUu72SVvzffxXnmTN8raq6mgWVeTzhG
8pllXjc4T/ItNf7u/krvvlWZUA6+N6zzhjJbxL0ugf8zGPidouZYOq7MPH/s
oV8Z3mvHlHlvHT1xkeD8Hc57J8+823DGT84zNzsy3OwX8t3HPAQugzLLU9g7
KPMYuAr/onC+cJST8h/ulFWhDyPqn32zXtuYWuM1lV5h/eHtCuPkT5I8LOL2
wANPvltCXso8IJT/d3XwqU+Y8+WgoN8+zJfgDmB9iPUj1oiYt0yJeg7DOLok
jAe+0Vk74Dudd+4kyYtYr8B3Smku4+OTg823tV7THd3g+4z7jbWUBWEcPq5r
8maZuce4d8bmjMO0a5PLnyX94vAMhGNsYbjHbwnjn/f51WGugh8y8uIwL7sm
zAfy4z6v/ALj7IDFc7BshtJn3FO808vcPto2p8x63hedgj24PcOUDo/6fO5Q
2y7lWpS4rqmh3p5Z28U09g6p9PyE+djhXEeeE7p3Dqh0XtYZeG5w7guKPCek
z5kjMke9KfT/G5JvDPcsz3ue+50LjNc1KTyX/hdzv7NGt0XyFZJ/Yf5ZYnk6
5UueIPnnfOP43RA1ViS4i9dHjUnIXIk5E3OjFbqW1/N80LksoW/DPOrqYINM
yn/m0q/KfjzfERk/q2kr70TuO/SPhvfObVG/g/59H0XNtT0u53fRAU0ee5z7
3CJfU8YA57W33hF3SR4h+dMyyyMlHx581fDTeD3u/rk9/GaH9+NTRT535tVg
l3LuYB72S7q8idV+NtLP2HIPjkn4OUaMSM8QkwI/0Tzdew+rvdPAnFabpjPH
1u8O5ky6vlclvbb8Cf0n/QzJraSfIXma5GbJV4DpKPnGlLk94U+Fu3ODyj1B
9bTRu7GN/k8KvhzwfmIDb9P9yjNPeR9PGz/gPsnbpc2Liv3ZelbclDI2Ruu0
+VHhSYXb9Nlqr1OfLf1fsn8M/wmlXfW/p8ZBWdZ8jvBN/scrigy3I1gmnxDT
KNuWWeOAgQe2GQy9UmOHXq/3/QFq42XEkjJuZL+T7K+WPEFyTvLaanMJXyz5
lqT5Oc7I2pcbLkz4Iq/I2bfsEZU3Pek48B3Tjle+MmauvYnspeu3Sff4jfjI
xPz8/EDXqJfSJRpLN8R8DC6qfcGE1XXdnLUtet411yq9Lmb8JXin4J+6HW4N
OAAKHVNzfcxlUQ55kE+SPD/j7zHW9hgXt8Tsu/6i2r2ddN31nftExmtorNXc
HM4Rfk+ezzeFNmyt8brvbWnzzrJufV2dsUauiJlndl3O54ue99T4mN9Hj2Xd
B71rHP9Uqr6K4eev8y2RHE2bO5D32zS44kvNGQZfWDTh8wfr54tq98FHCfvi
Tgx9S50TQxvOi5hLbKTsRsDxpvq6tTJvFTxY8G89Kd3qYsdlfx/278BPG6//
F0nuovZM4L7DpwvfPeV7KmZOuvm1joNrr3yTIublgpML3jRs4KWZp/N9KGZu
Hbiw4MTaIj1BDNhvlnyFyr1Y5e+jutqXm08LLq3biSmS/izpJ8lmlOQmyWPA
uZE8VumH6qvbZP8B/a2y7pS8VMUPT3k/sS5t3V3syeb52GzJS/IcCzI76C+R
/bGyH8Z563yPZsynfPzOYAMf3YMx898RywZP3lzmD0nvQY5KGX/oKMkXSX6n
wfsGvdTn3Up97nCBwRU2N/RDTcL4LGCzECPboLx9lOeznOOKnoWfTtdjR43L
I1p5TWawnnOvquxlGvfLwfoEG441OPA+WpkDDS6071T+b7K7rqUxJy8usR5+
tJlJx2rvrP65XvJayXNV728Bw4JY/wLdS/eo3XvzLVXhfmbuNDDlNZ2zUuas
Y3weXei4vkdixjkakPT64rmyaUx6vOyo6zlSv6T056n8+Vlz6C3I+oe8XPfF
F6rvca6jxv+nkh+OGTepWG37CP9XeCAqPK7gmTpHdexb7P3HM/TbUXIybYy9
7SVXp43D11pyAj18IpJPYxzp14VnLNx26qOBasNB6rO5WccJgtkA5920mL8L
WstmsZ7D2zUbExdsXDCUm/V/gfStmo2zC6YwuLu8u5F5f4FhC74w2MLEtX4l
OVvgNSgwr5nfH626OzNHA0MmZxviYbPNjgsmPvgY2ezH/KXR8xDyMvcAQxcc
XrB2f1KeNyX/nDNeL7i94PT2AH9L6d4pr9usi3n9gvXF9TGvZx6R9Dt1L9nc
rXp/Yt1J9bbX/+dY70wZxxo8a9ZHTq32Htsp6ttt0n0dcxwvsZjIYIODAU4b
+DbhW4N28g3CusNa1rDyXTfnCK7vQPaJ2T/XOR6l891bxw5uNB4wfcj6K3uz
7L+y94rP4NKY1wHgsVyEv4f0hzSY2/NbjeXrIubyhMfzRskvsb4v+aq487JX
gv5F5mQqZy84HsCAUd5+ak+BbPeUbgB8RfhZS3611vGHCzVWu+p/aZFxq04M
bWMPuVPK3zFHady+LPvdZD+3zue9Jpz7ccrbnb7XOXaTXCb5OpWzRvYX6/hb
de6bz0L/vJq13FJld280/+i3Oes+DzY7NZjj7fhm10N9fF8/qDITOv64ykyC
pyPdwozn+eCoMndlfRWZ+T0xwWBLnas0LfvJ0mWUbsx57BCHwh4z69yst4Bb
DjY9uPSdNZa6SF8o+1/geeedznNG8v6SSyVvlnyg5C1KN9Y4Dn2L9A9mvF+1
DF9v6XeX/gel3ZmzSW6bso85vubs9+0v/RSltdLvkfSY+V3yFLUpq/RAPRu/
Uf5dpL8lbTww8LI4t91kv6P0X+n4jJjvdzjpP4aPXvpNKce8f6H/e6mcLmBd
sT9ALH2NOV8/Uzox7vkJ/DuUMT08Nz7UsSbZbExZTx37hX1zeNrYW4erDblr
2EOfEdoAX+f0YN9d+b9UOZG018TYb2A95Jxqx9Gdlvb6CXrWEPArfzfmWFNw
/lbLpkQ2e0SsP0P/Z5XY9wu/rzUZryW2V5+3ltwNXzSlV4Oj0dKcUKyXvh3z
9Waf+q2Y19YamT9L107p4ox5AXZROcdXG6e8t+qdrnLa8L3Vyut47PXyzbU5
bYz1bWmvY6Nnf3NRs2NAS+r8Hce+L99iPZPGzelKbELcY4BYg5YZ+/QUZuzL
tiGcYy/wVpWWqfweyvOj5HLJ90T8HAOTn7Xoj2JeW2bfmLrYLz4m5X2n4zKO
Uy+QfBTYLfhZ6rl2l8o5IuU1ubeZa6uPWrL/AIegrt0dMfOLLuS9rrxPM98D
u0a/ni2c8h98ZnChwaEG83lD2pzuH6eNcwIHD3wZg8E2UnnvqrzqZudNKM1E
jIkDHs64Gq9nXKm8X6v/D5X8vuzvKjWeDlg6YOQgb1SZE2R/WqGxMTeA5yH5
cOUdQnxoofGRhuq3N989fAcp335x42uBPQ6+OXjjd8tmumzuUTpHv5mF9q8g
zoL2E7uBDyT2+DcWgFUmm29UZkzybZIfrLHPG/2ALxx+ksfH7Qv3uc6ls2wu
qjH2Qz/Jn6SMA8S5b1IbJoHTJP2UjHn2esWNCTZK+p58c6SMpQMGEDg575V4
75N9T3Bwd8GfUvIU9ekAjYXuuo7tk+ZMPiJjvDLOnbihtSqzSPpfVeYjGg9T
iXuU7WzZFWsMLeH7JWOezbqsffbaxO1vWaVyH1H+DuBtKG1ZZFwP/MGwwT8N
TiJ4s4grKVW5t6r9D8jmBb5hNK561xr3A3ydS+uMo3lHoTFd40lzyT5aY8yJ
nZkr1QS8oLjjX77UtT5e+iPT5guir4h/A1vlF/yUa4wD8WuhsUTwUcmqT56o
NSbE19LvU2t8zW8l/5wyZzH8xXzTgecKtuUvKeOQUPZwtbO96mkbt+94RHXN
ks39sh2Ss5/QTbIdVu098Pd0rrtk7Ge6G+vwGftxnyy5XcZ+9B2zXmv6J+Z1
p5fAEWBvFf8NHWsVdznNccvMBcEBIkaCeIH17L/LfpRsDm7yPPMQpTeD2UNs
bcYxBT3ixnpjvYt1HNY67gATItTFug561tl6qcy9iUsnjirh9bsBWa9Bsb/F
3tYOynNQuef3U4KetanOxCqonHmS/4xZBmeBmKm/g565FufLWjrzrG1BvkH1
HolPbtZ9sS3Mx8ABZtyd22R+Hnh64AmCSwgZvh7iRegTcJLAduspeYGu3f5K
u8eN2fcX83hdr+vAAE/4GPrtgwxu7DQdGyWb6Ur/lP2lkj/nGSl5mOTPUuZN
gj9pAT57SX+/7aFxmAc+juTdJd8V6gWv6XeNq1UtzPdH7A95iQOCe4t7BB+U
RMRt7tXCvORfahyuU1qRsQ9oZcZcpefJ5mfiHZvNPXV2nWPHwL0C86o+5bW8
HRgzKa977pQ1NmQL9W3frPGrsAerirgl4pqIhXpSZc6X7ugmtxMuK3is4KRC
Jl6pp459ojJHNDt2irzEQ8VV/mbpExl/b90evrmqkv7W/JG5k55Xu8p+qOxL
m43BFGk23hK4S2AxrVD6K/6b6sPuEfvdPhl8cZHxuf2L+ybu7/z2aftqL1Z6
FH5kyjta8r2qf07MuL5/Zl32x1nrOIYf+B85+9aNqDe/EHM/OGsoF0zVl1Rv
O5V5LXNttX8YsSeS2+Lnqf/bZHuG6jqJd4Dy9EsbM+YE2VQqPV72xyKnjQN6
PPvw6p+jpe9Fv9b43OkHfFkPUzk/q8w708ZzpQ1gvR4u/SbpTyeWXHl6KG9x
jY93DDbdZPOxbPqmjU/MeX6WZ/93/OAnMp8u8bnTJ28yl2JPgliBEvPQvyb9
wTXGWHxV5d2gdj4ueT/mbNI/JHnftLnEsb+FZ2vKcUTzpG8TcV342x8n3d2h
3s/rvQf1osbOxRHPK26WTbu03/08o+4v91oH9xI+/uTFz7+D6r1B9V7LPFbt
6Y7fk+wHlngdA+7mPcDe5htH6Y1wBRHvkXMf3Bf6YW3aHN7rlfaTXQ3zCskT
Nf666/grauPHOa+TfKR0uOqaqjJ3qXFMwX1hzMxibUXX+uG075fHlO6g9+BG
1TuNNQfZ35MyZ945OvZmyvEqjXrXnJyxb/SuPP/jfl+Dh7+fbN7Wtesj+816
t05kPTPn47uGd/rRtcZ9Okbp9tLtEPfawbwaryX8hD8VeBVx+2Kl1P43pJ+v
4+v0i6r868O4AhMYbODjM/aX2sA9q/YPiJjH6sykY4kyxKNzvdX+E1VmusY+
Txmlb1S6LtZKmpLm0z4sY78s2ta/wO1vF+53fOrxuT9b8kERv0d5h7YNNnOC
3D7YbyyxPf75+M7jQ8+6GP6MyPh9Uc/2oa4PiI3Av0zpKp3L7roWU9L2C2OO
tF2xceSIxzq30Tis+4a50Jnqu/Y6PkD2MZ3b6TrHuNKEfv3wPVR6omwqmCcy
By43Tx4ceXBjwqkJnvEI2Zyi9EHZXJI030CbGvPhwYu3sN4Yt3BS75Hy84Xr
8HKBY64pB15O2gZWLLiy02S/i9r4UrXnrLS5Le879m+ZjxWbz2G0yqxP+1nS
KTxP3omY1xNOz2a14zL8GtQ/F6juHsp3puzPUt5hxE7p+Pl8a0p/v/QDJLeR
PEdyLXNo2eyddgzXjzxTlO5Y47i6y1kHBSNfcoNsRup/X+UdmjWnKG24W/9P
4V5Q2j9t/sDOof0X8N5U3u1V3qCkOQCauO/V/mWsb+j/d6wH6V5foffdYPVj
g3RH6TpOp4/ixosYzBqHxvmxjY45BdeGmB34vuEkBmOZGORhcWPIwC2MHh5w
+DrgCyF+Ea4SYj6J9ySukfhGuD2IAUUP1wg8IeiJeYQP5QzJ5Vnb9w96/FYm
x+3H0ldt/lvXrRVc5I3ei+6V8/oN6zj4n+CLgsx6ziXsZSo9sdG+LmBz4NOC
fwf+Dfg2zI+5fHxk4NLlG57vd7hw4cfF//wilXMe/g6N5ryFX5n9XL71sd8n
5MWeffPhsh/CN6/sv88aj/87pQP5pombU5h+OCP+//Gw8OIQp0l8K3ze//Fm
I8PNDc81HOfEd76eMndKN42Bmqz5g+HKhpt4iGzWpBwnij2xovBmXxhkOIfh
pSZmtKLB3wudG22PDRzj4/W/XcTci7vrHhoU2kw6MMhgkNCf+KMTV3Rq3PFW
7E3BLUT8Puu3rAl30r3bllikuHmCSPsE+fJw7vABwclD3ojKqVXbXlDbusDb
HHeewhLX0yfUlZbNgkLz2mQkL5Q8ucm2fYMNvBUdwnrXSUFPOZRBWcRFETtL
nxBLC44KWC34I4FjCJ4hnB3EaRGvdWqFMSmrEsaQAdMePTFcO4C5X2j+PmLB
iS3vU+G8FcGGPRz2chhjd1dYZk+HNp3M+CG2kGec0gmN5rxgT3v3Jsc+VgVc
u47ErRD7obQs4fL7hvJioXxiKJCpJ5EwZhN7Xs+H/+wNtVL5yYT3Dzg3zieb
5/LKQpvZS0qEvOAqUQ5lcLw82LCnBufBiDzzHsSDPfsb7HOwpj9SaSrhNdsF
Qc/eB/icPfDR0PmOqjBfNVzV8FTDa96BWLlSy/Cbg9UDjg8x8merz/uxTqO8
a3UOM8N66QrJJ4W1WfqMa0a/EYvCNd0lPMd4vu0cfJCujntNGt9+/MPwDWPd
FD1rp/hD8dzAx5D4m6nhGdI/yPiKEa9K2xgb+JdRDutjXLtLgx7soGGh3u1Z
J5Ju30ZzbsO9vWeJ8Urh3ob3Yb3u546M96zxTcE5Bad8arnt4emGlxt77OCg
H828p8RYAsNDX4FvhAyewaassZRWJ4y9Oipu/FXS0UGGx4Y2E3sL/wAcBsT4
94r4OXOa6m3NfFTnc5Hu9a1q562q5/esfbPghMV/D37YGbxPa+0vhv8rPp+s
9SGzBrgl+LgScwGPLHnBzL9W98LJqvOxBq/LEYu4KPh1gIsEJlJNneO9P4ST
gnmydI/A7Zm2z2mzyv4Sv7O4fUEb2ZeV/UdKM8w74vZvA/MfH1z8bx8P/8Hu
/yP4/uHLR6wtMbdgA4GxND28Nzm/m0NefHgphzJuzRkHAAyT23mWxI1785D+
X8M6erN9+mgDa4gj4atWvrpm+4jOitt3i5hLzhc/FrBzbg/lXK3zPREfnwZj
7IOvX8Fztd5+2Nc0GHefY8x9ZsKNy1pxo9exWMsDC2d2kLEBJ4Fvb767+f5G
Bn8G7BNwjsBSuE3lrMB/R+WMqff6MOvEkWADjzW4C/cE+yeDDA7Hv9j8cfMa
gIcEBlNaNo0653vJ22w8EnBJwDN6VOX+VuQ1GY7fFzeWCxhHYBWBU/RiuC7E
HZP3gbjjr8F+wR7MeXT3Bz0p/8E54po+FPJe12D/l76Nxl5CTwz3ktAe8v7X
X/QzZd8byv8p6zh94vV5jrzAe0tl5WvcL5L8vxrHXRF/xd4Q/v34HcMh1a7B
a2XrdY5bs8Zx+SJtHKOn48ZZGq3rMldyXr73mCiHGBb8XvGFZf4DDtyTcWPB
MS9Cz74YmB5gcoHXdWSFy+wVMLfQg/XxTdp1HJjxuwWuJTA2wQzjnQi2GHMA
+NuYf8Dhhkx8OvOCQUE/OG6exXSwQYZjkZj1wUHfG2xr6ep03idJ3sy6i+Qr
m4wvCb8J+bAnDnuGfudKHt7C8des4YyQ/IHs/iIOlm+9tMfRnlnjx4PzBcYX
71b8Z1hvP1l1bVHaoLpuLzOv0+v55nvi/wyl86V7Pjz/z2y0jyPAeeCgguMJ
hucDyv8N622yn6Iyj2OOxr68ji/R72rePXGPAfb4GAP8717tmFDKx6/4/Hzv
KZ+X731l5FV6Lg1Qva/y/M4ZV47xMzXfZVMHeG7olwYZzDH4/2p1/qeoPX+C
46L2NDY4lnFHtXNW0vOLt9SGthUeJ+AFgrMKpij4yeX0i+z3Zv4fd5nwCYIj
tyycFzim9APYomBLc/+Cn8b7bn7oN7i3iDMl3pQ2Lw3tB2eG94i6Oq+z5BaS
d8ozDkO+5IYK4/D8JPsLy82nM176A9hrrTX/XRelP1Nn3Hg748r9Hxye+lpj
pSyX3Y9xlwOeD3uF38aNbcV6DpgIn8put2Zj5oCdk671Xhn4rBcW2Z69RfaX
2GcivhBevu+4f3Uvd1Te7yV3aDaeBDKYEqtkt0J5Lsh3+mqQSfm/h8p8JeiH
5Bt7Gexg1vPBPQa7+eRaz1fZH2JvCA4UOFEOqbWOY4xruLTAdOhUa+6t3kHe
JWEb8sK3AjfKQbVeF+LcWVOC9+SqoGevECwq9ss+DjLYUPtoPG2OmyMY/mLk
bflOtwQ9GCzguYDDgr8BemzBYNwYNwfFr3HLt6g9y+sdg/NIk8fd73FzBW1S
+lvcuJ1ghG4K8sxyyzflGRvr11AO671b48ZYgLsKrqtDa803ip514P/qBmce
zKWfw5iB/whsza615nWE35F59sVRX2v2E1m/R4+/LDyJg8LYA+uJsce4q6n1
d/CuaffDX3Fj2oBDCYbmN+XGmQd3uXWd8ebRg68Ibgz24MkcH/qQvGCE0idg
/TJGXgnjh9hD4hKJx/ya/fd8+8n01L22nXRHMgfGh0T34oWSS8I8mzn2uw32
TRoq/TchL2VM17Xor/pX6HhDnXGwmRf9rfPaKJsPJC/NGScHvJyk/rcNc61k
pf0oiM1c1GCMabD0VzY4hqxe9jfXe11lB/xZ9DuOOR5lwIupcjYrvVb98ILK
KZXdBY2OabxFY+NglRMvMl/VCw2Ogxyi44uz/m5fpHSGyj9T+VYxz5E8UPLq
Bn/TY8O6QY+w3s66O/v+7J3BBbZGdp2KzeV9PdzZyvsm8UaSG1lnJg5X/3uo
DZMln1dvnIfe0i3Rr155MzqnJmKfKLPIXEi3hHHYp8H4GRub7IuDT87KOvtS
IONbAY/SLPxWa82xeWuQwZl/IKxVsqZBTC+4Ax0ijncl1hXccvDs4Woh/hU9
bSXGlVjXp/GfqTUeOs8TcJoZS0fnO74bPnXikS8FE173x2PgzCvvK5XmiXhZ
7d9B59hW8jLeJZIHqczr1A+nsZ7c6Nj2N2KO7/1ReZulfwZ9k7GTaqU7mVhX
tetH9tYajFV5nuRzZPeurnVKNtNU5hnKe3aj4+uJ7yW296UG79flco5ZZvwT
ewvGL88Kng3MK8DQAY8F3BU4jXgGgH0CBsqIKnOWgeECFgp7VTskPL/lGJy+
8PmS7hZsWNMAR2Z4ON4hYYwZnqvoWVuASwpOKfZuwIbpEPKy/sB6B9/zw0Me
nsM8j3cJeeExax/sR4X2wZdEGbsG/YZ6f6em1f+t4VlTHzbgWyj9DoXmwtus
emsTPsaeVTZhv2i4BOAM6NxsPh9kuAPwX29IOI4SH41MwvuGcEvSL+zfgQEL
Ljw4sNjVS/4z39wCyHAPsH/HubMHx34h/UkZYKfB4wWWGvxayOyxgjlXGL4f
wYoDM65zmH9GEsaAhSuvNKwnFCes7xbmCC1D3uXqh6OCDxXltQj6M+rtN7oj
330JzyXAdLotaYyrdZrz/BM3dzUYQVxL5GRFwLWT/VkZn19DOMc+YY1jrzzX
Q33g57FfyL4hfFXbqd772DPXuN05YQygf3nr4v6PDA4Qejiu2Kulz/GLg4sE
v7cTmt0O2gfuEPOjonBeL+b8XgXzjD5EzxxqhK791Rr7D+XcT8WhD0lLgvyW
2rYd+xf4khGzj1+55B1rfX6tNJaG8szR+T3CHihxWHFjqRHLSPzn+OCbj78+
sQxXBD0xnmUZ59k5Y+wm7kG4a8FrBLeR/dBHgwx+I7woH+p3m/rkR7VngNrT
odHflujZR+6n9pyBb26d4yaJvSR2knEFTh9+AOfIZohs7pVNS8krmAvq/Vsi
+U3JxbWOO1gdd8zAWbXGSrunzrypcKzCnQp+O/a8Gx5Q//bDnwi/D9n3l/1d
sv+MWEi+bQrMRcu8APzML4mjjDvuHN5Y+qaV7CMZ59lJaVmtYx1KM46tJcb2
yGyIcYkbz2VRylhYYGLBF0PfjGn03n1Obb1R6XBds8mq5wHV+4Tk0br+b+bM
xdOcMD9FU8L27PXDR9QUZOLssdlQZFxbMLLBx35efd46Yd4H7nNkMHJJtwt6
eDVbBZm9/e3DM3NNzvhy8Ok8nvK9Dl4s2Fn/hPsLrNsNcXME8j5cHze3KLr1
Qc81fz9c91fBlNd4eFznd2qz9XDp8G6EWxCAcvK9G8rZWmKZvZ6+sn8vbn7q
1+uNRbeoyXNe9A0h74Zgv5NsnpXus3rPE7eFOSS4JMTqPJOxLww+MfvIrmPE
GJWT1Z8HKc+duhZjVP4kPVPGFNiXeKPyHlFq38Ln0uYPYz93sq777GC/ED83
6Rsz9q+GV21QK73v4XiQfoH+P0r8ieSYbH4P2CWPSL49bb6Q3ygbn/hS75E9
pN/UUu+lsm/K/imxLZPrvc+7WNeqq/Q3lzoO5Qn9ZklOEgea9foH2M9D0/YN
2ib9RZJ/iDju45K0+d0riRGXHFfesUofU9syki+XPFy/P4izUroMzADmIln7
+z2Gj7DG84Oyj8r+fB1/Jm3MpTrJ56ftgwL+8Ky0sUh+UHoTcS6l5ia4U3mL
JJ/LHrfkilL7J3yPH2ap92Rn63duqff94fyA+6NFjf3z8NNjzxGf/CPwd1Of
PKtjL2mcHCN9pcr5WNd5qtq8l/7vrvb8zDnCoSWb/VXvLSpzXoFjBG6v914b
e275zeapLVI6S/qx0t/BPBfOIpWzPmuOymUR79mdAt80cziVOThtHy8wk+HH
/kRteFJ1Xt3K/A3sD/ZkjETsjzeOfUSdy3iedUlzC3yfMqZhH9k8gr9Z0njN
8Mo9KP0HBY5dui9tfAf2Je/Rb1Sp9yXHq81dwWtQOoN+UN7zpL9W4/PFcvsh
s1D8tuQlas8U/V8MdmrOfgLgKJyp9h6g9NiI8f/fqzZu/kGSPwObgvU/te1V
/DZbmB/8CZ3nw+rbo+mDanMM3E9cvo7Ni9hP4yl4z9TOCbQH/wn2ZvC5wOe5
0Bx2YJiCefOPyjtJbfuf7t+patspkvPVzqsld8HvSDY/sf7GehFxttLvVe11
F0D/F6isTeBG6Xg36cdJ/6vqb0+/qJzR0p9eax6Jpfh4NxnncQrXWvIfxElK
/lp9fYKeTS+pnZ1YGy00V2Zf2RQo7zWymQ8PnOyP4hlQb4zsvtKPanBc8Ml8
azQ4Buo4ycP1G1hsbqCeatsT+fZp3lv5n2PPW+keTeZRPqvJ8T4XKO9JyrdZ
z8CHdYoLk/Y/PzLfHFV82/CNM6zZ7z7eh+c3Ok6DeI238VPQdT0naT+l+/Tb
WTYJ5X2l1t8QcFftozznl5jPfUvauA8L8HlUvY/yDlU5Z6jMcuU9RG1+VuXt
VGrf1En6tZU8Weki/ZaW2gdpTpPxUh9S+kjAjLtT8hU61lo2E5UeUW9OmKfU
byszjssmPht/BfwWpuK/SuwNsY7KO03/u0r/HXnrjMNOmTPwkZJ+ptIb9DtE
8vdKt6rckrh50OBD3kv6a/jGrzbn0izVVS25ON/+IderrE/LvR74T8IxRlNk
Mz7n+Eo45fk+5zv9EskFyrsyz36P+ZJXSH4Zvwa1bavKmd3kmAf82PFnv5M9
waAH74t490N0/IEm45w+qvTQet9f3Gf36f9Z0q/KmfftFNl3a7Tf6T0ak806
3kL1rsqzT2n3sF4Az+ypOs9nIvYn762yFkfsl0WsETFH+Hi8pjybCt0ns6vt
fzGEPRzpP5P+2LQx+sAc3DFnTELwBvHJeQAuPNm3l+0i/T4q9PX6RTZjNM4v
azY+0hrmK7KfK/s/ZH+Dxs/TkjdLnpkyPiQ4kNvnjD/5bpC/bXBMWZ9mYwG9
Gco5VGNhPrgAauf9KuddlTNZ5aR1Xj+r3zYkjQVH/DYYcQPr7CcCZ/QqtXNr
oZ8/q8Fe5N5Mew4Gj12SOXMrx7TjvzodfznNkWYqXVHt76rPGJ+tjL8ML+F7
+NlKvwAfNtal8b1XveNk8yE4tbJ5pdr48/gELq82bvAjxCvV239lF9kfDLYk
39oq/ynZ/FbgWFe4d+G/3J/1ANW1VXk/VrpUNjnJT8vmfck3Su6rNpyi3z8t
/dweUGMs3QHEYWT8zPyF+ADWHPhOlc2Lyrsd30GyreIdX2zMrmXSt2rhmDJi
2R6NeX0erpyd8V9VulA2Mdk8hJ+L+rmphTkun9LvHuLkVM5jku+S/D9dkwrG
erGxueADLJL+s6Rxj0fFPB8Gv/q4mLHaDtHvJJ17D6UP1tv/7U+Vc6jqek39
c7nyHix5ueSxvMP1/y+14SOle6pt/XW/fKnzOpS1MpVzmNJsxvwB/4CFlTX/
+ZyscbBZv1ueM7Zzb9Z2lQ5S/u3Vh4eqr46uMZZ3g56dj6u+I6Sr03VeVe19
iVfUD4+xzqI0K/0ZaltRC3OUn8Z3TgtzhdNXBS3MOb5YbX2rhTklT0w79mZp
xj7o+KIzPgdVO85sjdq5VPp3ZL9Mabek48lX4F9NjDN+9rIfLPtm2R+QMt9T
TczfmP2lr5J+V+nH61z6Fvo5XK+8V0R8v18l/WDpj5L8gvRrVNeipNcIWSsk
3uqsaq9D7MCak67lBcrbS/bVSWMvMh/jP3r80gelje9JHPRa2XzF/gXnp9+6
iP0DB0peGbEv1jfEjUp+Fn8b5lURx5AenjQ31VrpD2X+EbGv4JuSv1CZa5Ru
VN5LIm5/hf6PjHh+wn7xnmrzperzg5PGQHxD5cyS/fMFjkU9mflixHFwL9I2
9gbVHwdkjcMILmM/2VfIvovsz5fcRvKhzN9kV1/k/v9KeSvVT18rfUE2cZVz
e8p4nsTbjMiZg71YNj11rdcnzf/2XI35JsAyhn9hV+mr8fnCh66VuTeI0T4S
XlXGf7OxlcBWGC37RaqrWuXMThkLAhyJy6T/MWlOul6q69Na4w5g/63qa8ce
lNq8SXmXKO8z9CWxErJ/R8fHtzKnzgDZv6z6Jkmuly4fv0rZ34mvqX7jiCPI
mo8G/Oj7lHZWfTfqXrtW6VzZLCn0PIG164Uxx7vV15k7FD7cJDE+KrOTbO6o
Np70MJV5a7VxiHdSGev1i6nN0/lmUf5+qqtJeb+UzVN850l/KfEysj9e/fCe
7DNFnhtMJs5Z8iSlo/TunB7mhKxXjM0zRydctOAQROv8PcB3wTd1/o/+pGbv
ZY1L+FhBs/0tv9bxC/SMag0WRJNxgsERhjNnaL3x436TfmyN8VkmqU++07Gk
bA4q8Fr60ALz85ax7hI3bkM7/b+owFy64Dmgf7/ImC7lwQYsR3AUWZu9uMYY
rGOJZcg49pW6xuh3T9Bfo9/rFb4uj6svtqiM13Qel6jfuhY4fhkcZTi08O0+
DT5R6f/R9UlJl44bb6hTgf8jsy4B7w7rDFNqjJkyTeVfWup+AEt5GfvlcXNq
vZWwz9RTur7DVX4PlXF6yliEYBJ+DMadbJvi5ouE1wwZ/MLquONA6LfrMo5t
pi4wtcDOAuOIPqR/wL2B0xDuQ3gP50bMDwc33AWl5r2Dz2gCc+9yzzPhLYS/
ED/yw9SOb8O7Zk6DeeEqcsb5BHPkryZzzVEm+Lv7gWuscq7Keh0N3zt87cDX
A2dvZM54f2Ct8Rxgvx0b9tPPw/cpzzywb1cb77wk6+N7BJs3eJ5UeA8RPEz2
LX5oMg9kVdxckCckHXdD/E1nsD0LzFs9T30b0zvxfuXdxpoj/VnnOXIk9BXj
qyyMsQ3V5ilpCval0t/F86bUfJzgbLO3WBr2E1k/Z32etfCJTeboOw7fn2bj
e/Rudj1loa57G8yNWpUz7x7XCN7JcQ3GifubOX+T92JfaTb/14OV3k/PhrFH
HPa6rH2A3mHuqjFUpvtkVdr8M/DQrFDbxoDFgh88ezkx6+Gmma8+/VXy/dLf
xvOl1N99xE1uDDbY/hrKeVDn+5PkryRfVmn5XvxDVO9tZV5zgMeWuG/iv1kX
Zn0YvjZ08NLSdvirRyXsj3FijTEmUmr/nznjUY1Uv/2YNrZak/R/xRxHtCHf
e1/sgRH3Cq4S+EpgUINfBY4V3PZgUIN3DNZxG5W1RNfxJfZrdH6FcXM1wsvE
vJfn7/wixyXB5UQ91EeMEr5++PyBI/uY8l9a4fU9fFfQ4wfIumRxmD/foPM9
UGM42+R3Ke0BU+tf3GXJL7Lv2eQY771ke3ap2w82FP28MVyLrkl/C7dgL73M
2JTgUsItTF2slx6uvlpQ5Tk2fNesx/dh7hzzngqYPOyjwHkNDs8bCXMBXZQx
BzZ69mJ21z1we0HevzzprKnCN8Y6KvioPLPYH5yTtG/lGNUzFf7RAvtpz2MN
v8Lr8/h/MQ7xAYOvjHL+LjKG5/JK76NRPs9JuMng2IXTlvG/u9o0En/6rPmQ
L2FNoNZcT3+E6w5/N+e2Mutr9Ue4XmB20j8PF5mnGjzOj1gfqve4L1L5G1lL
KjMmEhhF4BaB+fNVtbG9Pkm77+jD1ikfow+nhXRL6M8J1X5P4Zd+peRRBcbK
aEmshMrZVW1ezJiX/qYmt/Gv0H64PuAaAUflU12Li9TlV6qclbJ7TX24QPl+
UP79yn3vd6w3t/CvSlvo/pmifAVKv1PeK5W3Hb4Qko/Nc/vnK//Fqvdm5X1Y
v4sq7J/wXa2xRP9s8hrIsWpvqeYw6xLmQh1JTBJriaWOt7pe5/VwgeOb8B3i
Pf1Qgzl14NIZqTIO15j5XjYN9d5rGJdnbvGLWIeSvI1xqPLnSL5J5fwoeXqe
Y+6qsvaFihIXX2u8P94jw+m7PPOG46eOv/qFDfZBxxd9GOtJspmQZ05zsGPA
kGnLXkejsR3AeACXG9wrzndQxryzZ2f8rfSF2pxlvUp5r1HeazhH/KrL/R2K
zxy+c9fiqyn9etnHWQOQ/VDZTyQOTOefk74U/hfWPSTvJn3/jDlx+d68TfpF
0k9hb0R5r1Pea2XzfzQzHZQ=
            "]], Polygon3DBox[CompressedData["
1:eJw0nQV0XUXXhm/SSNO0Sdv4zb1RoLhDW9ytuLu7FfdSoLi7u7trcXeHIsWK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            "]], Polygon3DBox[CompressedData["
1:eJwt13mcz3UeB/APg5zDMKZdzSRXKq2OYaNtI61jG2WZ6KKiVM6UK0fO5GhM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            
            "]]}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl1F9MlmUYx/FLkBJC/INKCi8KmqYCvUXLzWi1eZK0TspVWpiaf4gIBRIF
I0WbdVId9MfClavVUSetcssDW8NipkUJaE7dtMWBtam5lW6OUZ+7tvd9r+/v
uq/7d1/v81zPU7Fu8yMt4yJii5/sLRGJDxdEnB0fUUvPpofowryIhtKI++jX
CiOeFF8X18h14jfxPrF7TsR+fBCvnhDRxmMIF8if4/MRn6v0p2omOewV+YO4
Gn8tHuH3EO7Hz4q1N0V0VDhvslp6hMfjcu/x/YTeWx7RQx/BN6x9gI9a+5Ue
o3utfyP3D32SZyZHr848j+/FF8V5ZREr8RW8LeX0Xa9mhM/bdJ649uaIL/Co
mjr1J3DORHvED9Xm44m5zp8asVjc6cJNzY84pO/ldPukiFy+M+zfRE/mmUMf
td5Il4il6oem+d/0Kj5VxRFNuJj3sPxzeDpuFhtm8sLP4wI+JXxb8MCtETW8
M7w202vkt4h3qF+LbzinlV6HR/FJvm30M/QY3Y6n8MuonyX3QuqNX7FcGb2V
Pl6iD7oDl1qbkerTtaOb9T1gfabc9rSux07xaX4Z3IXLxVPO3YFn4xdTTn25
mnI+3anfNHv+w0t4vdwv6nfiDXjclIhdOKt+I51L99CbcB7ejYf1cBvPCrk9
dCW/BfRc+mV6Dj2frqQ30kV00Lvd2wfpp+QXiSvFDXKF+DF82f1udb8fxT/j
a/b8bu/nOFf8zbytNitv0X+r6RB71V/CT+AR8UfXaC7PpfQP+H3X/ax8Gd3P
r8e875cbM7OjZviw+R3kfYHuxZc8I334D2vd9GfWPqbP0w3OXyG3l76LZ6O4
3vlZXI9rxD77q3AVLhKbnNmVnif5P12GM3wOeE4H8QE1r8p/id/F74hd/N7A
2/Eyfa4S76/0Na9LeNXJ1cmdEPP51PPWVgzynUBn5TP0Ic9EVv1P9rkcUZ2e
AXEP7wG5WbgHu82xxM8ubLyjxp7lPN3iWCCeAtXp2UrvHzXTxXvU78DGJjrF
Y/x8Yht2yeO699sws2X2G5k4pre/5B6gtRFX8fc2aDH6rF2h66wVpXelDSsc
dlnO+MZWnj5R68x2kEapTey339ZoxUY5FupxqcXviv8btZiHbwfGJVrUfCvv
1kVzmmPxTn5N2DHRmOZcfNi55yTuTu8P+isHnB7//7v7X0Xlrsw=
          "],
          VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwV0slOVFEUheHtOxgUwSAaAfUhHDpAJ8JUMRKwQTRxYDM0CkprA0WfOFGR
AhR7BcXYgoJAUTRCeBi+M1hZe69/73PuvVWlZ6+cvLwjIrJ0qiji2b6If6UR
w/zb3oiukoh6/e3iiHn+RJ6lp/Qd78bPybd2Rizw5/JxGqGfeAY/L79j/4d+
VD5Gv9V1ByJ68At4E/5L9gJ7SbPqXqxZPqNu2u98+qO+K7tmppDuqffwDLZI
Lfoye3/NtarneIV7htOz0XWzlbwNKze3qF6iCflxXueMW+YrsAL1LsrJq3m7
nSremXZ4h/4Yn3fHtP1leadsledphXL4V2xNfR9b56/0b+l1+tZ2+9x1Uf4A
/8/fyD/QVc8xmd7LTL+ZBuyhmQX9O3yS3lNOP4Bfwh/hS/pDdj9inyivH8Qb
8S58WT8l/0yr6qH0G7un3s6K/mDal3WbvWGmKL0bntEXp3fBe9SHzayr81hv
enb1iDuydNPcCd4nP2JuQ72ZvonZL1i//LT/25xsQH1G/tj9NXxQX4NtOG+3
vpBqaUh+lG8DTsJ6nA==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lSk1EUhuHjLqwiUcAqkZAAsgJ0AaHKFUhskoDNQEfikDU4S59AJAMW
4ETBlnaETRr7Duxmjn0cvPU1597/nn8kd/PCjWMRsYyLQxGPhiM6IxGnkxE9
WjoZUUZffmg2Rt+iokucilgfjRjIG2Zn6HtUzWp4x4/jI7LHI+q6D3wKpUTE
vPcO3C/zOb5CL9GXuip/ma/RK/SVrs5f5fP8X+T5hq5AZ+XC/2/Z6Rw9j653
Mt5M2m3Ov5ygaTnL3zN/jX1dXx7gk/Ob8mNM8M9pw/kntEk/657yz3DLO2n5
K1pmK/jCvzDbQob/jlV9G9/4CXcm6aTctHfR3j25aI+U2YLc0i/SQ/2CPq2f
cv5IXjGb5n/wb8xW5bPyT7nNX3Ovq7/PX+d/6WfM1+RtOz0wu+17v/V/0NEv
6e9iSt6jO9jFHfwDG3JeOg==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DdSA1EQhOHBQ06GkQQx3nufU2SkEAIS3hvhuQGXAG5BFSE5l8B79yn4
q3t6+82+3dRUZiKdFxFrOKuI2E1GjFVF/GIUp7Jb2Q/fkYj4pvW1ESfyL75d
9kmPzR+0zfxO63SOZGXVEaU4zD2viZjDAV8iK8Y+P6lbxBciax5xfhh7fJNn
Q/wgds0FOvlolO+Y3+St3vlKt80D9AX9qNbZkiXcv8/8jF6kzIupiAXk2ZWm
h7rn7pbh55HUedJtsfuRjss27ZrWC2f+ZBvmq8qIdfru7CzW+EvZHb/K9+h1
Y4Xvopf2dNIqe651luUduf+IJf6n3N3ohR0Lue/TmcE836aTdZ9WmjE32NHC
P6AZN56lc/+Mv0cjLrxvx7f8A5qSRd0=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Us3lWEYxvG7WTYR2gysCMU8E3wAIqc2I2aMmuw98AFCZS2HnU2O5UzT
ytlHMHVqWN8DtfoZ/Nd1vf/nuZ/nffeuHsyk0g8iYgTfKiLyn0UUYKwq4k91
xG/s8s+5Yb1Wvq2N2OHq9Tps648qI5rN9FtbqYnY4gq4Ji5fbnpe5v+hkUtw
G1y5LMO6/tdaBmt6knuCVX3Amdfu+YV3KOW/8ife5xQfub6nEVX2feF79RRW
9DdyyHra2rizl7kS84PcFS6xxL2Qd9b3sej5lWxDzvkzWOCO5DFu+Q/29zh7
nu+WXfisN7inU9+37xAHmOM7uFEz7+9/W2Tsm+Vf8+3I6W3yLOm++/v1VnzS
W+SImayZPef9RJb/Ib9jWr/xTmlM6cW+7zEm9ZdmivQa84VygjvXLzDqf8iT
D5HAfwywS64=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lOlFEUxfELugikqoCqUkQ6jdEwQPcAJIAgYjNkYJOgLoBEKrIDLae0
ShWgdIUIDExAlEYRBkpsFqI/Bif3nf85973vS9970HG/LCJGaCMRcTcVUVcV
8b064oDWsYaaiEY6j3/DrmYjipmINdkd/SHstvmBv6xzWv5KvsrX8tfl58z3
fA4/JT/L99tZwW6ZWb7PLPFH3nqis6J7zW5GtoxfMi/SkvO2LK/TYv5OR/yi
RbxZfmj/sSwvW8B+8sf0jJrk89gf/b/0A3uq+1L3Hd4ob6C3zvVmueyFbI5v
M9tp2d4SzWLDfJlOWverb92nGfymf6nB9vhdKmJzugO6g3brvFst35F9oYK8
104V9pl/XhExjfVgKWwb+0RvsBtYEiu554r7Prr3Nd6Nd9GUc+CP8EnnQjJi
wvzHP6Rx54T9VvdVmmP84klmJ+e7zmD15gUalW3qbVEF3un+Yfw/u4BYAQ==

          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0cdOlGEUBuDjRbgSCxgXLg0ygwpTGNoWE3euKC41ITHhFoam3oCuRenN
NhY66A1gY2AKM16Fz79487Zzvu/L/7cOP7n/+EJEFGH7UsTktYhaa8QUbr8S
cYaXWvT4J/yCzNWIITMPr0cs645lN80+aItY4Xec85tepXfpNbyH/8jW6X36
k/0NuoSL8r/Q4YzXzt6U36aHL0ek8Jzsnaxu9oU7K+6rQqfuje69Lk2PmL+L
38puXIy4Q4/KuvC87IO5e/SY7MR9H/mD5C34EL+UlaHEZ813m/1M5+hX8lP4
wuf5jO4rfWTvuTdVve0bf44b0IQec+N2UvoT7y3DKWTtbpmdoWfhGeRkaXPb
8mn+kTcW7O/w391xK/kXztrlf/B5fo/uwZPyCvTSC3b25QW65pw69NOL8gN5
H10yO+Gupm6AX9Id6v5583nyXfUNPJh8K/xUfqQfpf8DuVxj8g==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0FtTjmEUxvHVF5CYhqlJvZnBkSRUkm1HnL0VwqSiknZk00YlVDaHZggf
wofgO9hvEkVkJpsZsonfc3DN/76ute617udJNXWnuzIi4j59zo3IKogYWxWx
EkdxOS6lbbSFMlIRV+QH8TLuXh3xsDBizt3f6pdkB9RGcD9+kv+SX+SP5EcM
4y53atU+qi2oDckOqw3irGxIbVzPBf6QfAA/yPfZc1ftHt2h97J1SaZ3szmt
tIlm5GvlJc4ttJGmZTv19ZtVZ2YfvpP1Jt/Cn8cd6m9l55JvkJ3FKf5M8i18
D27X80Y2aP9pvlZ+CoOvsGcEi/Ef9eRF/MQf2RGLuDX5D+ob8C91u7fHO7uw
CnNp0uwJOzplNWZ34GtZO1bzJ/EVX6XnhvN1eslfw6vJPPkLfo1ZRXbcpPX0
XFaOZdSu5xm/V89t75mgW/RU1mZG2p4TWKkvR8+T5C62Jv8BW/C7/hp6rDaA
Y3qb5V+dj+M3rKZH6v14TDaPTfgF05Qy6wGNutvLFzg3qvc5N+Afby2lYT4T
l9FR+QqsxyU4jv8B8RVrbg==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0blOlGEUh/FDxTIMO8gOAxV03ANLIktBhRQUBKkIlmprx06i0FARVmWH
oLKEioJwDyAogoLXoP6meHLOef7n+973m0kNvuodzYiIKTRWRzQ1RDTjXSpi
vj5itzaiVF+CBnmRWozhuoh+daAx4tx+SnZq9wT1+jz+DV+nv0Ytktxrrka/
4NkufQ+6Uc21qAt2LtUd7/njjCdUyaZrIra5R/NvVHIjdtvdsQNbsl/8Aypk
U/Y3uXvzYnlEOTfJbXA/uTs84ya4XO+ZdWaZ+QqlOLaX4Nf4EvOR+SuK9atc
juyLucj8WT1Eof5Cli3rU/vxAgX8P98b+pfO/WS3004+X8AXYoj/yOdxH3zP
HNbNz+3NeC7Jj7vrGjeWvrP5QJ8lX5EnzPvmPeSkfy8uU7Zq/uHd35Gd/l+c
lY8V/pa7QRZ/Zv+t/aRsWfaNv0amrNVd2rDE58r/IoH33H86oE+T
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lSk2EUheEbUHYgKpAOBAGJM12FTtyAVUwMgkGmNjuwUHqbDbgAqywH
gTTYK+AKVFRiEhN7QUc+DE7dc9/znfsn2fHpc4VERNygY30Rp/ojTtNqKqKY
jniLddqPZCOOUglfxc8MRLyTrdlvJiNmsff2C2YZ29HZtg9SxZ7HP/BDNCer
URX/aD9Ot9yY8OYTv5JxV37FNw775kV8B+/mH+jU+A75sjxhdtFnbJjW5Vnv
rsvq9kndHnsv3XO3gU1hB3QOUh9+1dsmfgl/rD+Gf7EX7Pf3b1OOWtgIlXUq
1OZHaV5Wp6e6azpfsSf8nP/03Cxh37Bn+967a76X0k/SS6ws/y5/wc/rvDYr
2PlDEa/4BWzTrGI/vNvgF7Et86F7Z937ief9vyX8F3+CGrLf5hj9oRw1sV3z
JBX1p93c42/rPpLNuHWHv4yn/b6/sozZsrfpjc4/7K43/wEnRWS/
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Mky3HEUxfFrl9iImILWhhTFPkvzPFYZsmNDWZNQZZ5egReQoEk8CAuv
YZ7nIat8LE6d7z331P3/uktHxvvH0iJilqoTEeslEb+KIs6TERm8vDSigg7N
FzRfFtH7NaJG98g8VRzxSa/WfGyeNi/o9OnUyU5kmfb1+E7+GTfgS3kWntEf
1r0yZ5uv+W+eQze4324D59Ks7q1s0Z0BeeP7TfM95dk3mTf5o3lJp1znAVd6
/5b8CQ/iIZpzK6GzS/f0gT5SOj3rVemcvv9evW7/SQ+t4lE3z+RDel/cbPbN
fN7CH2QFuBUv4wzdNpySFVI73uYptw/sK+y/8R9u78hHcYJ36K3kRHTyInMX
f7RL4m78h695SzF/8Zbv7vzFb3hPvk+veFf2j0+4P0k/6T/hLEnj
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0UtTkmEYxvGbslIpI3VamQE600wH0Fr1IQKCgLKgpNrWpmUHyrDv4KrW
kEaZdrBFnyjtsCrTH4tr/tf9v5/3eV+GTOth+UEiIjpyfyriQibi26mIZDZi
C3+fjqikI8ry1XzY/AXPzET0nbnKl+Qzd8juE/7Ce+7a1If0yycjfuJdboP7
KC190h1L7ljUZ7k7OMG94G7rM1wTx7nnXEPPcn/0W3pGv4n5wU5ysuJsExf4
OTzovU/lgFzy24q+9RUuS4p7NJg903P2JdeRAtfAdfefxw94EXecvzG4V5+X
tufe2yX4Pm7jdfucXV7eccGt4Q+s29U9s2rem454izXuuN2Y1Oyq5jR/DY9x
R6XKV8xJfVTK+gie4LuD/8A8bD4iJT3Ft/mi/t97nvC7WDB/55/Z/zM/5v/i
Ff6139zz3nO+u4tn8Q23Dw9lSHI=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0slSU1EUheENKE5EpQkkQAgBfQN7sUPBZkghAjaQ2CA2IGjsAaUcAOrM
J9AqqxjgDIfqzOZ9FERFvzv4a+211tnnpG4lXxzvGSuLiEXMNkdcaI14lY+4
SJtzEZtoB19Jn+nP0Zf8edqk30gP8MvpiKf6Af4FP0gb9Rvofr6CzuhPmU8j
o7vWHlEu38eX0Wn9CfNJpPUh+0en5K/bvOd8A/85G/FEVtAP47H5vb5Rv0P/
iN9O2/HQXJR/c+d3vHW+m3bhga7aXg2O81dwGbPO39dtlW/DFrS5654sZc4k
99ES30W7sdPeJRRxVz5M36GAkjfn7Qwl3xV39GdlC+Z+Wu/udezl/9JJfV+y
w8/ZW3Z/Sv4He2S/6YQzvc7M8WdonWwNu/lf9La+324nfwy1slXsMq/Qcf0R
81HU8D/xAyN2xnSffONq/iO9xQ95I6374Lfc5PO6Vtww52iDbkl3nf/izq94
Y+cwPYRR+WZ9FeqdPShrSf4D8jpZLUaS76t7br5qzuqz5hxaMMP/BwoFVVs=

          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0TlP1GEUxeHrB7CkcoEBLClNRCgFYWbYRkRQaWgAQcCINLRswcSIUljC
RxBXxNhasO+LrTRsgystzxQn5z2/e+77/ieTaOvN9FyIiElqvRrxNT/if0HE
HD/jT65E/OW/6aH5F/yP8yz/x/vMT3mWyosiHuh8NvtEv7Be82N+H/+IfaDj
RMQr3eeFESdmLWbv8Xd0ZNZj5wi/h/+4HFGm2+z8GG/iM3pvaYzuyoe6CZ0B
9zVg3XoT2J7derlLPpBLdZ7p1GEpe5uXInZ1auWkfMN8A9vBarBGbF3eltPy
HblVJ+m8haV4Bqvmm/Kgb993/zTdxjawKt6gU8Gv50VU8np5zb3r5qu8wJ39
dh75zrrcDM/InfJNs1psFRu124Ft8xpsBfvmzXbshd53Oy/9zmV8RCetc1G+
5byEDfOfOlO04t1F7JpzMS3LC/Ib9xTJhbSEzWNZb5zQojxu/tRsIvcf0iS9
piF3V+f+C+cSbw7wczKLZ3U=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Us71GEYx/GbYaS1rhZSDi/AXohcpK2Ny8Jp7LWoRCWmFGXG5FgUOb0P
vYH2Hd9CJ+dT+Vjc1/f5fe/7OfxnKlJ32vrzImJBLV2N+Hwtorgi4m5ZRD7e
wyKsK49oUF/0L8j3+QQO4EWs12utimjEr2Ye8AX8IN7gbqpv/JB8wM+azVRG
FFr/LI34rvdQ71B+hEn8xWfNNJud9LbH/G+uxFnv5Jf2vMc/XKWZYf2M/AT/
ciOYlUdxW24xMyV32pfDHe41dsnTeEt/l5ux7uZmcU+ewx65UH/de/a5ea6X
W8ADeYOf0z/y7mXukHuDKTNv8UiuvhzRJy/Kx+fffCXiBKvsS3vjU3UqP8Mx
dZv/Jz+3fmXfC/yB/7lx6y13TWDO3EfrcN6KsyfNfMBLfqc8btU6wyXNbXpn
PleDteq66lUJ7hMum6nHOpVSBfyus/fVnmo//8+4eXPH8olKyqe45p6se9ax
Q25yfxrPALr5Yhg=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LlO1XEQxfFhRxA6qNgxsbCQXdEXYEkgoaWA0CmbgBZQkBBLSSAxQZZ7
QYWGnjdgeQD2XZYWlx63zy2+mTNn5szvf29l33DXUFpETOG2LGK7PGILszjU
V1dGVKGwNOK9esDrqI54WRJRwNvXv6Af0r+qIprpfPqL3a9YwyqmZYYrIlbM
ntvJU5fxjH5TFJGkm+gHagI37n6Q+Sy7giHZJf41v947dVjmL/I67V3xc+lu
/oL6TZ+jJuV+8j5ix/42svk5+k260ZtZqRv6H9jAgEzSLIFB+tKtd/6PTHuT
3nrMn6cv+BnqJ5zTj8wm5BMyc7wte2f89NRv5Z2mdni99t66l8Y/4TX4hqC/
y9bT/7DHr1P/Yszundk6avV/MMrbtVND/0aPmyO8Y95T/T1avflEZtBsXG3X
t+AV+vEaMzJHMsV0G/4DjmBQtw==
          "],
          VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwVz7sv5GEUh/GDLagEi5mlcVkiRDGJhIKCoJxZvSxbrUioUPAHUEh2S4lL
NyRmG6VbQ8ZUG1tsI9luQ4REJCjc4qP45nnOec/vvO+v4dv0yFRRRMzJcVVE
KhmxXh2RronYwAwuJCI2+Rjfwt+NEeM8x1POfuGZby8/Rvx1ds7v+C2+4BMe
mDmUPvuXPkUsN0Xk1Yv8BMvNneIfSfJwXs+beDP+s7eTd/AevHL/tfzX7/aG
GymqdZcUS4O9z3iPJdhr3wn/wAtYjfve8mhfy/t3eKRu5YNmX9Rd/BW/uq+f
l7ljACfVpWbSPCNfpMJbKuXCe0bVCZ6UhG++qyfk2lmdeobPyoo98/bf6mf5
D72fssMr7F/ln82v4YHeNrapc5hX15rZ5e16e3juvx78w5B7C+phzOqN6r0B
K1VJdg==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzss3XEYxvHXQlwSQuuco5FwqlKTpZEYxGKpQeJgRDDRpswdKoIek9uh
Q4caMZs6uAwEiRAkRCpNp0qa2FUkfAzfPM//eW//X+3gaOZTXkRMYK8iYisZ
sY1GrFdFrGEwhcqIX7IhepKOONU7yo895/y/FxEX8ht+0swUpvEVWVS/jmix
5+fLiAc923QH+eYO6CHK+DN6jg1735mZMzuP92av5ZvyRd85LOCP7Le7R/K/
/A2u+FvaYWbWjm/6lrGE5KuIFEb44ee9bt551wd9zfL//D12ze6hDm8TEQ14
tDOt740s3GiS5dMCtPHtaiV8p3oXMii1K6PWzV/iAp/1lcv75P3I+oePdt96
xzz/RTaO73yW1ugdMDPDr8oWaVqWoxu+f9Ae9XrZCr8lK3enAvt8Uq2S7/Xe
BC2kRShGq5lDHOAYTwn7TrY=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwVzztIFXAUx/GjEIJrpd6yoFy0IUfpcTOTJGopB8FNLBAMvOQiOpWLWVSU
TxDsMUVQQSo6SGqDpXTFQair9+p6QXIQpBqMPg5ffr/zO+f8H6daU40dBRHx
BIuHI04cjziJWyURPWUR3Xh3LOJ2IuLOAfJedWVFxAN6TnZPlimN6KRZZ2wf
ifhxOiLP7/G79B/dkO3zC0cjvqDW7mWknFVHP9hfln+kfe59iEl+TTZFH6kf
4zOfk83Rp+pnSPMvnTHvTc+dN86vyF7oDWCdz9vZoCPqUfziz5vdkSf9+RJq
MeqMEVz35hL/qjdTKC/lC+yV0QQO8Wdog/6i+77hK4rkNfKbfBrfUSy7Krth
dlXdwNc58wrqkXHfsN5PmkW7/l3kzHbRcvtbfIuZTdqMSu+/r1dFx7z1LO1X
N5qp5t/KBtUVdofopPoVbdJ/Td/ggrmk/kX6Xv2Jb9OfoLPqP+75jb+Yls1g
SX7NfLXsP/ENWkc=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j1I1WEUx/GTS13vXUKvrxXYi5JooIWGVlNGrlEZEVQXrM2WrCYLgiQr
chC0hqYcNaEaNW0o6hrUEERoJWmYQ5RDL6Tg5z98+T7nd849z8O9typ34UjX
uogYxauiiMmyiGMlEXk+ztM8hfelETNcWhHRIR/lE/xua8SIc095xFVclH00
283l8huy3qSnnpVf4w8+U6F3V96PPtmc3i3eLz+A69si7qm/ye9zU2VEMzr1
zuMcUsURK3Z99a69evO8Il/FovNBu7/zJnMF9k3Zs8/cc66WvU3ejy92NKhn
nZfd9ymZU//k3+pfvGCmzd5DWC9bxQY8ccdjpJz/u+up859sxAT/5Wrz484F
esE16s1mt3vHFt7B07I8BryxJdlrtpVz3nCYM+p27lKnzRx13pj8TnxFdpaz
6hwvemfKzkKk3LcThUirM0g71yKDH2ZbZK3odv9lXMIDO2/bVWXnHV4290/+
GYPJ2+VDvGBHHU7Ke73roaxGb5iX5PVo0CuyvxiP5KfUY8l3qrcLu9U3ffY0
Z81M6J1xfsZ7uBF1dr7AG0zKXyf/SX7JeV4DHNVnig==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T9I1HEYx/HnnFpS+mdZRNS1XBIEdSGBCN6Wg+jS0VAQodtdDVIXoXR6
Q1Di0ur1Ry7FyUO4q5ZAa2i5vURIXTuFOqPJXje8+Xyez/N8n+/3x+/8vfxo
LhERz/HtWMS1nogbpyPS9HZ3xAOax0NMnoqYwpj8iTqVjCjQcfUzeRGP+GlZ
EY/5GVmp3eN7za+eiNg8aabdQ8ud8/SKXpnG8Yg1MxV+nQ7a06Dn9KuyWW97
iYy8rm7aVVfX8Eo2Ye6LfE/+lX6Sf8Cc/CO9av9P+Rb+mNmmfXo79J96n/7F
AX8YA3qddMS5jHdkaUI/Ke+g/Xpl3/caN/lDsiH6Rv0Wt/guWZa+Uy/gPv/D
W7/jqT0btCJ/j5zeWfN5uqheQoEfNnex/T98Qw55lL1l0pt+X4hY5kt8jb6g
LdlnfsXZKg7ckXamaM91etneBA3c0TtKU2f8I1xCw5mmbBe/cAR3zf0H+LhV
Vw==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzFI1GEYx/HnxNmhO8/Mpf4HlUQQQVEuFbbp5G231WJiGOoSeFhBjUGe
EgS5dKXgHVyDnoNTWFBLU0aIk52YKFGXtdTQ54aH7/f5Pf/3fZ//iZt3hsZS
EfFIfUxHTHZHTB+LeNkZcQ9f4X2ckF9So9mIL10Rt/FTEvHabEo+pd+SF3Hb
PT8zEZvm3/kT2YxqmJfwbC5iFvf0L7CsDnhBvsQrKut8t7ePY7v8veyDOqNv
yDf4Dn71xmc+dzRiX7/bugvf2GvRXt/0z8yasr/8F5bct25eMf8ne25e5b/N
VvEP5szrPMwSfsR+15xLZGl+WtZultL38kR2XuVas56Ied+exLw6pYbtnXfv
JHaYFXiR38B9//CQj/DHOI4/ZE/5XV7GB3goq/ELdr7Y+i9vVe1wmS/wPlzE
muwKX+FXsWnHOl+W3/J2v+yt/jq22f0dXzMb0Gf0g5jGc879Bwp3VJ4=
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0EtI1GEYxeFXyqVJ5ExlQYRGkGZgtNGgcN+F8JZIixZZm8Jo0cJ9UWoF
TQsvBV1Ai9GCvERKEOGiFmWaWq26mDS6KUdqI/jM4sc57znv933/mZ2nL5w4
nxcRabzfFLFcHJHFXzRsi6hHHU6iCcdxryTiGJ21/9zeEH7wV5IR17ZGXNK3
0+u4KuugnajCQVRjfnPEbV2F3RTNmB/SRzjkvm9bIs7pvtN5fElEvNR9pWP0
QO4NeQfemnvd2YN3/E1ZBrcwa34gv4/LzsyZU/JF3MFvc7/utTf7aMbcJV9C
N1bNA7nvdvaNnTQ/iF5dFndR5NtfyCb0o/QfLcUu1DhXIivj9+A/yrEXr+Sl
zjYXRXwwp+we9r9O8mdlR3TT/Aw+ocBbp+xU8Psw6fwUPqLJ7hz9jDo0oB6t
9pPOndG3oJhvpUflF2lj7l57G1CISr+3U16r38/f4B878wRd/IKdX+jm07KN
/ADdbb9PtmReRD//VJ7gn9ERc5b/6b1luoIh+XY6TCf063ULWId8jMl36Mfp
lP6PLIk2JDAtWwOXhnO9
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j9IlWEUx/FTXSuIlspuqRUWLRFk18Gl4epgl0i7iPTvapAuJlghLqIS
RA42RJNWc9BioIMSRTYURENqVniDoJKGtiAoqEj7PMOXc87ve57nva+vtV1X
2i6vi4gZvN0Rca8y4m9VxB+8zEa8lo3LKg9EvNDf1n/mnujHUr874hq3on7B
lPy6vM7OeXMHSrgvH5QX7Q67d8Lcbx7S39L36vu4jdURm7EJo/Iu+Rl3ZXdh
Z8SI7KS9krxbVnL+vfvfYYBrly/bv8i1cgvyeQw6cymd5Zf4Tj7PZ7gKbEAn
38zP8+f4en5NLTi7nl/Vt9vJ23ll57T5oJ1f6j/8RFFe4befUlvRgsfOTuOG
e/aZV7EXayi4r0ltRB57MJWe5V0buZxn3XSuR95gPmQ+6/6n5meYw2F5h539
XI15wvm7uINarkpeLW82F3AcV+1nuW3cQ8/aqt+iz8knzRlzJn1Hz8rhKH5v
978hP+aucTtH7D6y813+Q170/mPy0fSu+Cr/Jp9Nfweuxv5I+obcMMr8Cj/N
n+D7uA/qJ5SxyH/kJ9NvN1/gl9RlvMFzvsw/4JvS9+YX1Qbzgtpi/g9jFmq6

          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D9I1GEYB/DnhuuCJIIrO7tF7xYhHMIGwanOUkiUOzkUEy+VFgUdzpYg
l9DARaLFxamuoaYTgqIGFW4xqCGXolU3I2g4EkE/N3z5/nuf3/u8v67ZpdJi
IiJewMHViIs3ImqQgtdwrz3iDb4A3/SD2Yj78Ol6xEdoz0cc6hq6l9ciujMR
7+Rf+HX+ir5OP6fX5DX6KV2UP+M3+Sq/TG/QFfkCX+XX+Dl6BR/lIqboKfkT
vkxfdtcl+6XMzLdm+Wm440xS/t1eXztkuofySbitOzX7ysy+fk9f1k/odulx
vIP/O/MZN/kx50pQhG3ZqtnwnQZfgAH441wnPsYnujP3J/ynu7696Xyv7wXf
x9+ke/Bvb8rTOTqLz/gMnW69DbfhE1mSTrZ02u50U/aX/kd/kB/So+4dgRX3
1mU/ZcP8A1iUvZf9ovvtOIQf22kQV3RvdT/ovtZbcAFmvHNL/gjfgnOcyU44

          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T1IlWEYxvHbpRBsEDWPiuFXiyINCqm0iIKDiHgyawlErED8CDpJgRKC
g+ikgw5+LE4iiIttoluRg1BIaB0hglLoYwgkDMzfGW6u6/pfz/2+78Nb3jeS
HM6KiBlzkB+xWBDxsjgix5yYd4URRUURCbOvX9A/TURs4/+wB5UR5/Stbk43
pNvQ/cJ+mh18Bh/AV/H7zt++HrGFT+Lz2Bo/xt/VTctLckq+Yafa2Vl5SK7S
v9Cv+K5lM4X344PYsZw2r7Bx5x7iefY/YUdmFO/BPvDZ+kG5Q26w28u38W14
jdwjN8slfCd/h2/VFcvtcqPcQutpGf6bNsm19J53fvbNp/wt7CbtxvaxL5k7
YKWZu2K72Hf6zQxknq/L1yXl17oDPhe7RruwTazOuT35Kn6FTrvPRV7Ef/lv
RcQf/ow/pT/oGZbmv/LP7L/n0/yE5yTsfnSn5/5TyrzRHerKSiKeyOU0aWfd
ucdyI31E68wlBVlUAQ==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D1Im2EUxfEbCtW6BPyqH9SgIoqFilQCUggd6hAwUDMZIrQELR1KTYcO
cRGXDha76CA1QyKtk4PgouLSwaVdHNTBRRA6BR1LR38Oh3vP/9z7PM/79pcW
8x8TEfGNLtojqh0Rqd6I08cRR10Rh3SKb+K93RHP+O2eiNJgRF39LVuXjeL7
dn7xa3yr/ED/Rb+rLqtJrKb/rH/aaU+/qP+Kf3LWkv0hfBV/hy84s4z1YSvY
G2weW8A6sAo2i5WwAtbkfc30wXkP1bL8tfytfFr+yM48lsXmsAyWNfsAL+Cv
8C3v+E55PsO/lCfN5fgX/H+zU/q0flL2wz079JMy+Bie09epRhPYMJY2u8Wf
2R/BUtixewb96wGqyp/gnXien6E5KlIbnsRvvGPDGUWz62oL3ow38BM1wSfU
mjvGzRzr/7V5M35tZg1v8Lf8qLzCX/F/+ef+x575M/7q/v/Ls9h7MxfqOf2R
Xcqm9EV8+/67vOMOr1lNVw==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0L0rxmEUxvGjpwyiyDsDD4MogwWlkEVhEkpSMggDhRJSSj0ZlMk/wMLC
bjWIWCiSwUuhlPI2IMnHcHWu63uf+9zn90sOT3ZPpEXEHF3kRSyURMzTaWFE
R4GKzRRFTNM+1oaVVkYc4+v5Ec14M7Yvr8l5zvb4FX5HXVI31Fm1Vt/6/zzz
V/VNq1NUhXeVYs5G9ZXLy/xTRcSQvMD3q1nuTPHdfI/+Eb6Tb7FXurMB+ag4
4pDqsCT92K/PG73UQx2U0pvjrJPvonc9b5SNfZj3yreb1aSvUf62z6vaitWp
D/I91ct3dqzGDuQaOclfU8LdMrmIv6R8Pkfd1vfrTqacIW/JCT7Bf+Gfud77
/5f4M3+Jvcg3dktht9ijfCXPy+fymZ5bbFweo13fdIJfYYPyptmLWIP/8geU
DEob
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0UtLVWEUh/HlwJQkkTzejimo6EjtDI6YioMiKEEkNBAJwgt5IT2iYA1C
sVmioyB0Yh+gYYFfwEmDBoLg8AjqwAQvgy4Drz8Hf9Z6nrX2++7Nrhme7s3k
RMQXeVkaMV4RMSF9+lR5RGllRJn8LI5oUYeTEWk1m4jYqo3Y5r9zP+SAy+JG
8yb5WhdxzB1xzfih/Md/8KrzR8zT7oiSiGtuU7/Gt6h5XL7dFeeeu+cXXtYX
qvf5JTs7+la1RK3kcpyX1VdLPd5TG2TX8yncrO9QT9zxt8w9+Ck+xbm4HXfj
O/pVZ/1zXyf3gnvANcoT3I9zzZtwmzznhrhn+gLv04On8F07fVwR18+95wZx
Ar/GH8wXuaT7K7g33BKuwVU4gxfsfOY+3r4fNypjss6l7C3z9Xbm7X7j9v27
NH+gjtubkA3+ED/iF+3+1r/lJ2XANxbhTrNTNcNNyyv+k90EdyaPzS/UGbNL
dfb2G+wk9VfSZX4Pz/GF6ju1ir8BRpFOzA==
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T1I1XEYxfEnggbzqpXmK2Y6uJUUCKJFQ1LpEDSEDS1pi28XFFQQ4fpK
gYstgSnm4FBDUkEXakyHIB0qyC2tQSxB0kQn6XOHw/ec5zm/3/93uecfJO90
H4uIp7RaGJFbEpFHK/y1oojPuC3/od90uTRiC4urIj7lR/zkf9EGNdpdp1N0
mqZ18rCZmiiHcilBt+gmjbu/Ta/Bt8b4c7hMo3w9jmBLccRz9+9URlSdjZjj
K7HLbkGnjK/DUmw129LL58/QXTkHE5TtO0lvvl2ghzV2DXSRTjhfgRcyb6Dj
cjbe8K2rzp3kj2jfPVn4Dw9xD+/bH/C7/BX3ruOe/AMvyRve85X/a/YFq82W
cEf+iP3OT/uNa96Vlr9jo7yKr+UV7NapMJuVa71tBpdw0x0f7J/J5Trv+Ul+
SjfNP8F3OKE7bP5Ifiv36j7m3/Cjdn12KXlRHsZXmDJ/aN6j22c2QC/N+/FF
5k04pHNPp53vonnzjsz/hZ04aP+N/gOkmlqQ
          "],
          VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DtInFEQhuHx0mgawWt2RV2FVdFCC7FcUkS8i1opNt6w8JpGJWVISBEw
jQiLNlaBQLo0Wm6rFgraqQuCiAjaiYXgY/Ex77xn5uyePzWzOrZSEBHf5aI6
IlcTMVUV0anOJiLm5Lg84lJ/JfmKiLPGiHMur7/V5/EPO9f225siHrkHbou7
4V70z/p9/YTzO66wUvg/XAn+gF/dW4Yr8AFfjevwup2djxGHXL/awLfyg/gG
D6gtare5Lv4ed0gGP6l/naecdeMe7sU9Ka7X2/pkmCtOmvWerLkinDE7zmed
n8hn/aR+Dxfb/21uxB39/Dxfyo3iL3jXWcIdZdyi+SVZlq/Oqri0veb3/yxD
Zr/x9fyC/V84jdfwNm7H63gfd+I2O2k7SffXyj9+WN10/5D60+wBV25mC+fw
f997Gx/hBJ/TT5vPcqfv3wifcp+8f0M2pc7vvAHnKUnq
          "],
          VertexColors->None]}, {}, {}}},
      VertexColors->{
        Hue[0.6499999999669532, 1, 0.10000000004575714`], 
        Hue[0.6499999852880078, 1, 0.10000002037045079`], 
        Hue[0.6499998575374961, 1, 0.1000001972557747], 
        Hue[0.6499991538514573, 1, 0.1000011715902899], 
        Hue[0.6499968622093047, 1, 0.10000434463327044`], 
        Hue[0.6499926810152515, 1, 0.10001013397888259`], 
        Hue[0.6499886753209286, 1, 0.1000156803248681], 
        Hue[0.6499871827318621, 1, 0.10001774698665249`], 
        Hue[0.6499886974241673, 1, 0.10001564972038382`], 
        Hue[0.6499925949688808, 1, 0.10001025312001116`], 
        Hue[0.6499966840514407, 1, 0.10000459131338975`], 
        Hue[0.6499990174111819, 1, 0.10000136050759434`], 
        Hue[0.6499998034253445, 1, 0.10000027218029237`], 
        Hue[0.6499999729662879, 1, 0.10000003743129375`], 
        Hue[0.6499999980637757, 1, 0.10000000268092593`], 
        Hue[0.6499999980108732, 1, 0.10000000275417563`], 
        Hue[0.649999972502692, 1, 0.10000003807319564`], 
        Hue[0.6499998007707878, 1, 0.10000027585583228`], 
        Hue[0.6499990071984714, 1, 0.10000137464827052`], 
        Hue[0.6499966598024274, 1, 0.10000462488894667`], 
        Hue[0.6499925622199799, 1, 0.1000102984646433], 
        Hue[0.6499886739785015, 1, 0.10001568218361344`], 
        Hue[0.6499871792649814, 1, 0.10001775178694884`], 
        Hue[0.649988696060685, 1, 0.10001565160828231`], 
        Hue[0.6499927167322246, 1, 0.10001008452461209`], 
        Hue[0.6499968893754299, 1, 0.10000430701863561`], 
        Hue[0.6499991646891583, 1, 0.10000115658424233`], 
        Hue[0.6499998599977125, 1, 0.1000001938493212], 
        Hue[0.6499999856334239, 1, 0.10000001989218238`], 
        Hue[0.65, 1, 0.1], 
        Hue[0.6499999852880078, 1, 0.10000002037045079`], 
        Hue[0.6499998368066057, 1, 0.10000022596008445`], 
        Hue[0.6499987662030103, 1, 0.10000170833429345`], 
        Hue[0.6499935549624519, 1, 0.10000892389814346`], 
        Hue[0.6499778300417067, 1, 0.10003069686532913`], 
        Hue[0.6499505462683586, 1, 0.10006847439765738`], 
        Hue[0.6499252913219769, 1, 0.10010344278495513`], 
        Hue[0.6499158508823386, 1, 0.10011651416291577`], 
        Hue[0.6499247160158207, 1, 0.10010423936270982`], 
        Hue[0.6499489183734026, 1, 0.10007072840605798`], 
        Hue[0.6499755737898713, 1, 0.1000338209063321], 
        Hue[0.6499918966134397, 1, 0.10001122007369896`], 
        Hue[0.6499980735657545, 1, 0.10000266737049385`], 
        Hue[0.6499996593138839, 1, 0.1000004717192377], 
        Hue[0.6499999506826558, 1, 0.10000006828555356`], 
        Hue[0.6499999500906315, 1, 0.10000006910527945`], 
        Hue[0.649999655185399, 1, 0.10000047743560135`], 
        Hue[0.6499980549290366, 1, 0.10000269317518012`], 
        Hue[0.6499918370195641, 1, 0.10001130258829587`], 
        Hue[0.6499754483540974, 1, 0.10003399458663449`], 
        Hue[0.6499487609293296, 1, 0.10007094640554366`], 
        Hue[0.6499246089762626, 1, 0.1001043875713287], 
        Hue[0.6499158353957267, 1, 0.10011653560591685`], 
        Hue[0.6499253861002506, 1, 0.10010331155349914`], 
        Hue[0.6499507186578939, 1, 0.10006823570445467`], 
        Hue[0.6499779704371008, 1, 0.10003050247170654`], 
        Hue[0.6499936165544795, 1, 0.1000088386168745], 
        Hue[0.6499987823857478, 1, 0.1000016859274261], 
        Hue[0.6499998396191935, 1, 0.1000002220657321], 
        Hue[0.6499999856334239, 1, 0.10000001989218238`], 
        Hue[0.6499998575374961, 1, 0.1000001972557747], 
        Hue[0.6499987662030103, 1, 0.10000170833429345`], 
        Hue[0.6499924447114087, 1, 0.10001046116881876`], 
        Hue[0.649966803005242, 1, 0.10004596506966493`], 
        Hue[0.6498986870713849, 1, 0.10014027943962096`], 
        Hue[0.6497903076682764, 1, 0.10029034322854044`], 
        Hue[0.6496956694759822, 1, 0.10042138072556306`], 
        Hue[0.6496598500920082, 1, 0.10047097679568098`], 
        Hue[0.6496884070778483, 1, 0.10043143635374868`], 
        Hue[0.6497763140913129, 1, 0.10030971895048985`], 
        Hue[0.6498816573421481, 1, 0.100163859064718], 
        Hue[0.6499540431582559, 1, 0.10006363255010721`], 
        Hue[0.6499865511173065, 1, 0.1000186215298833], 
        Hue[0.64999697736963, 1, 0.10000418518051227`], 
        Hue[0.6499994121848602, 1, 0.10000081389788582`], 
        Hue[0.6499994075356613, 1, 0.10000082033523827`], 
        Hue[0.6499969516884851, 1, 0.10000422073902053`], 
        Hue[0.6499864629461425, 1, 0.1000187436130335], 
        Hue[0.6499538247815461, 1, 0.10006393491785928`], 
        Hue[0.6498812811242848, 1, 0.10016437998175962`], 
        Hue[0.6497759033253894, 1, 0.10031028770330704`], 
        Hue[0.6496881578673747, 1, 0.10043178141440438`], 
        Hue[0.6496598197797228, 1, 0.10047101876653777`], 
        Hue[0.6496958940624493, 1, 0.10042106975968566`], 
        Hue[0.6497907590832415, 1, 0.10028971819243498`], 
        Hue[0.6498991064821327, 1, 0.10013969871704716`], 
        Hue[0.6499670218094749, 1, 0.100045662109958], 
        Hue[0.6499925169058931, 1, 0.10001036120722495`], 
        Hue[0.6499987823857478, 1, 0.1000016859274261], 
        Hue[0.6499998599977125, 1, 0.1000001938493212], 
        Hue[0.6499991538514573, 1, 0.1000011715902899], 
        Hue[0.6499935549624519, 1, 0.10000892389814346`], 
        Hue[0.649966803005242, 1, 0.10004596506966493`], 
        Hue[0.649879101783133, 1, 0.10016739753104668`], 
        Hue[0.6496852145273001, 1, 0.10043585680835372`], 
        Hue[0.6494162997265167, 1, 0.10080820037866924`], 
        Hue[0.6492010682900416, 1, 0.1011062131368654], 
        Hue[0.6491137171780911, 1, 0.10122716083033544`], 
        Hue[0.6491563829934823, 1, 0.10116808508594756`], 
        Hue[0.6493416527692054, 1, 0.10091155770417709`], 
        Hue[0.6495997554994432, 1, 0.10055418469307868`], 
        Hue[0.6498113105300759, 1, 0.10026126234297193`], 
        Hue[0.6499305428935218, 1, 0.1000961713782006], 
        Hue[0.6499799856500064, 1, 0.10002771217691427`], 
        Hue[0.6499948089502459, 1, 0.10000718760735187`], 
        Hue[0.6499947831523833, 1, 0.1000072233274692], 
        Hue[0.6499798727551617, 1, 0.1000278684928531], 
        Hue[0.6499302554975778, 1, 0.10009656931104621`], 
        Hue[0.6498107930448382, 1, 0.1002619788609932], 
        Hue[0.6495991042255871, 1, 0.10055508645687941`], 
        Hue[0.6493411176280112, 1, 0.10091229866890762`], 
        Hue[0.6491561566068836, 1, 0.10116839854431495`], 
        Hue[0.6491137403392346, 1, 0.10122712876105974`], 
        Hue[0.6492013214066819, 1, 0.10110586266767127`], 
        Hue[0.649416890241138, 1, 0.10080738274303964`], 
        Hue[0.6496859288220751, 1, 0.10043486778481918`], 
        Hue[0.6498796003047549, 1, 0.10016670727033943`], 
        Hue[0.6499670218094749, 1, 0.10004566210995798`], 
        Hue[0.6499936165544795, 1, 0.1000088386168745], 
        Hue[0.6499991646891583, 1, 0.10000115658424232`], 
        Hue[0.6499968622093047, 1, 0.10000434463327044`], 
        Hue[0.6499778300417067, 1, 0.10003069686532913`], 
        Hue[0.6498986870713849, 1, 0.10014027943962096`], 
        Hue[0.6496852145273001, 1, 0.10043585680835371`], 
        Hue[0.6493047777680848, 1, 0.10096261539803639`], 
        Hue[0.6488673490985243, 1, 0.10156828586358183`], 
        Hue[0.6485502856265529, 1, 0.10200729682477297`], 
        Hue[0.6483902795375447, 1, 0.10222884371724578`], 
        Hue[0.6483816036130576, 1, 0.10224085653576644`], 
        Hue[0.6485957628883882, 1, 0.10194432830838562`], 
        Hue[0.6489939519074331, 1, 0.10139298966663111`], 
        Hue[0.6494149503656054, 1, 0.1008100687245465], 
        Hue[0.6497275525921767, 1, 0.10037723487237067`], 
        Hue[0.6498986949687521, 1, 0.10014026850480488`], 
        Hue[0.6499645086924556, 1, 0.10004914181044619`], 
        Hue[0.6499644084648013, 1, 0.10004928058719827`], 
        Hue[0.6498983451179355, 1, 0.10014075291362773`], 
        Hue[0.6497269063824568, 1, 0.10037812962429069`], 
        Hue[0.6494141593805527, 1, 0.10081116393461945`], 
        Hue[0.6489933573089761, 1, 0.10139381295680236`], 
        Hue[0.6485955693237665, 1, 0.10194459632093877`], 
        Hue[0.6483817334719172, 1, 0.10224067673119161`], 
        Hue[0.6483905107237508, 1, 0.10222852361326827`], 
        Hue[0.6485504399625566, 1, 0.10200708312876784`], 
        Hue[0.6488676434233365, 1, 0.10156787833691877`], 
        Hue[0.6493054326597033, 1, 0.10096170862502624`], 
        Hue[0.6496859288220751, 1, 0.1004348677848191], 
        Hue[0.6498991064821327, 1, 0.10013969871704712`], 
        Hue[0.6499779704371008, 1, 0.10003050247170653`], 
        Hue[0.6499968893754299, 1, 0.10000430701863561`], 
        Hue[0.6499926810152515, 1, 0.10001013397888259`], 
        Hue[0.6499505462683586, 1, 0.10006847439765738`], 
        Hue[0.6497903076682764, 1, 0.10029034322854043`], 
        Hue[0.6494162997265167, 1, 0.1008082003786692], 
        Hue[0.6488673490985243, 1, 0.10156828586358178`], 
        Hue[0.6483447647008006, 1, 0.10229186426042995`], 
        Hue[0.6479786482228467, 1, 0.10279879476836613`], 
        Hue[0.6477162367776388, 1, 0.10316213369250021`], 
        Hue[0.647562318571634, 1, 0.10337525120850674`], 
        Hue[0.6476410815525707, 1, 0.10326619477336373`], 
        Hue[0.6480080185451157, 1, 0.10275812816830143`], 
        Hue[0.648579486372906, 1, 0.10196686502213027`], 
        Hue[0.6491668432411315, 1, 0.10115360166612573`], 
        Hue[0.6495970754140722, 1, 0.10055789558051553`], 
        Hue[0.6498068783412693, 1, 0.10026739921978108`], 
        Hue[0.6498066105961633, 1, 0.10026776994377398`], 
        Hue[0.6495963220340493, 1, 0.10055893872208573`], 
        Hue[0.64916586418334, 1, 0.10115495728460613`], 
        Hue[0.648578777570923, 1, 0.10196784644026052`], 
        Hue[0.6480079461523003, 1, 0.10275822840450731`], 
        Hue[0.6476414975569021, 1, 0.10326561876736627`], 
        Hue[0.6475628209177057, 1, 0.10337455565240761`], 
        Hue[0.6477166871005474, 1, 0.10316151016847287`], 
        Hue[0.6479788895815403, 1, 0.10279846057940578`], 
        Hue[0.6483448000569576, 1, 0.10229181530575106`], 
        Hue[0.6488676434233366, 1, 0.10156787833691866`], 
        Hue[0.6494168902411381, 1, 0.10080738274303949`], 
        Hue[0.6497907590832415, 1, 0.1002897181924349], 
        Hue[0.6499507186578939, 1, 0.10006823570445465`], 
        Hue[0.6499927167322246, 1, 0.10001008452461209`], 
        Hue[0.6499886753209286, 1, 0.1000156803248681], 
        Hue[0.6499252913219769, 1, 0.10010344278495513`], 
        Hue[0.6496956694759822, 1, 0.10042138072556304`], 
        Hue[0.6492010682900418, 1, 0.10110621313686535`], 
        Hue[0.6485502856265529, 1, 0.10200729682477291`], 
        Hue[0.6479786482228467, 1, 0.10279879476836615`], 
        Hue[0.6475401197544662, 1, 0.10340598803227762`], 
        Hue[0.6471492185716042, 1, 0.10394723582393262`], 
        Hue[0.6468120214679307, 1, 0.10441412412132671`], 
        Hue[0.6466225588476567, 1, 0.1046764569801677], 
        Hue[0.6467189588664768, 1, 0.10454298003103212`], 
        Hue[0.6471926206447458, 1, 0.10388714064573666`], 
        Hue[0.6479416314291787, 1, 0.10285004879036792`], 
        Hue[0.6486847327742014, 1, 0.10182113923572118`], 
        Hue[0.6491330712110971, 1, 0.101200362938481], 
        Hue[0.6491325955422843, 1, 0.10120102155683719`], 
        Hue[0.648683647156053, 1, 0.10182264239931124`], 
        Hue[0.6479407143627663, 1, 0.10285131857463126`], 
        Hue[0.6471924667805575, 1, 0.10388735368845883`], 
        Hue[0.6467195342872655, 1, 0.10454218329455547`], 
        Hue[0.6466234011364024, 1, 0.10467529073421211`], 
        Hue[0.6468126895154238, 1, 0.1044131991324902], 
        Hue[0.6471496978926512, 1, 0.1039465721486368], 
        Hue[0.6475405484301956, 1, 0.10340539448126762`], 
        Hue[0.6479788895815403, 1, 0.10279846057940577`], 
        Hue[0.6485504399625567, 1, 0.10200708312876777`], 
        Hue[0.649201321406682, 1, 0.1011058626676712], 
        Hue[0.6496958940624493, 1, 0.10042106975968564`], 
        Hue[0.6499253861002506, 1, 0.10010331155349914`], 
        Hue[0.649988696060685, 1, 0.10001565160828231`], 
        Hue[0.6499871827318621, 1, 0.10001774698665249`], 
        Hue[0.6499158508823386, 1, 0.10011651416291577`], 
        Hue[0.6496598500920082, 1, 0.10047097679568097`], 
        Hue[0.6491137171780911, 1, 0.10122716083033541`], 
        Hue[0.6483902795375447, 1, 0.10222884371724579`], 
        Hue[0.6477162367776386, 1, 0.10316213369250041`], 
        Hue[0.6471492185716038, 1, 0.10394723582393323`], 
        Hue[0.6466247658365454, 1, 0.10467340114939871`], 
        Hue[0.6460970638205105, 1, 0.10540406547929318`], 
        Hue[0.645589268197284, 1, 0.10610716711145293`], 
        Hue[0.6452371269589686, 1, 0.10659474728758193`], 
        Hue[0.6452105445038666, 1, 0.106631553763877], 
        Hue[0.645564334064698, 1, 0.10614169129503348`], 
        Hue[0.6461188517281143, 1, 0.1053738976072263], 
        Hue[0.6465292695559217, 1, 0.10480562676872378`], 
        Hue[0.6465287438944914, 1, 0.10480635460762724`], 
        Hue[0.646117940680914, 1, 0.10537515905719602`], 
        Hue[0.6455640968389634, 1, 0.10614201976143531`], 
        Hue[0.6452112044766596, 1, 0.1066306399553944], 
        Hue[0.6452381831863726, 1, 0.10659328481886882`], 
        Hue[0.6455902756764894, 1, 0.10610577214024544`], 
        Hue[0.6460978666860379, 1, 0.10540295381933218`], 
        Hue[0.6466253190276136, 1, 0.10467263519253509`], 
        Hue[0.6471496978926508, 1, 0.10394657214863749`], 
        Hue[0.6477166871005472, 1, 0.10316151016847318`], 
        Hue[0.6483905107237506, 1, 0.10222852361326844`], 
        Hue[0.6491137403392345, 1, 0.1012271287610599], 
        Hue[0.6496598197797226, 1, 0.10047101876653787`], 
        Hue[0.6499158353957267, 1, 0.10011653560591688`], 
        Hue[0.6499871792649814, 1, 0.10001775178694884`], 
        Hue[0.6499886974241673, 1, 0.10001564972038382`], 
        Hue[0.6499247160158207, 1, 0.10010423936270982`], 
        Hue[0.6496884070778483, 1, 0.10043143635374868`], 
        Hue[0.6491563829934823, 1, 0.10116808508594757`], 
        Hue[0.6483816036130574, 1, 0.10224085653576663`], 
        Hue[0.6475623185716332, 1, 0.10337525120850805`], 
        Hue[0.6468120214679272, 1, 0.10441412412133169`], 
        Hue[0.6460970638205038, 1, 0.10540406547930246`], 
        Hue[0.6453297342290453, 1, 0.10646652183670652`], 
        Hue[0.6444525596532943, 1, 0.10768107124928494`], 
        Hue[0.6433834721860854, 1, 0.10916134620388175`], 
        Hue[0.6419342693173481, 1, 0.11116793479136415`], 
        Hue[0.6399724772615234, 1, 0.11388426225327539`], 
        Hue[0.6378190830503149, 1, 0.11686588500725631`], 
        Hue[0.6363437737647057, 1, 0.11890862094117663`], 
        Hue[0.6363435021480464, 1, 0.11890899702578202`], 
        Hue[0.6378192495710805, 1, 0.11686565444004243`], 
        Hue[0.6399739959560372, 1, 0.11388215944548692`], 
        Hue[0.6419364029752823, 1, 0.11116498049576298`], 
        Hue[0.6433852867591608, 1, 0.10915883371808509`], 
        Hue[0.6444538432672651, 1, 0.107679293937633], 
        Hue[0.6453306991597083, 1, 0.10646518577886538`], 
        Hue[0.6460978666860311, 1, 0.10540295381934163`], 
        Hue[0.6468126895154199, 1, 0.10441319913249546`], 
        Hue[0.6475628209177045, 1, 0.10337455565240919`], 
        Hue[0.6483817334719169, 1, 0.1022406767311921], 
        Hue[0.6491561566068834, 1, 0.10116839854431524`], 
        Hue[0.6496881578673745, 1, 0.10043178141440455`], 
        Hue[0.6499246089762626, 1, 0.10010438757132877`], 
        Hue[0.6499886739785015, 1, 0.10001568218361344`], 
        Hue[0.6499925949688808, 1, 0.10001025312001116`], 
        Hue[0.6499489183734026, 1, 0.10007072840605798`], 
        Hue[0.6497763140913129, 1, 0.10030971895048985`], 
        Hue[0.6493416527692054, 1, 0.10091155770417717`], 
        Hue[0.6485957628883876, 1, 0.10194432830838648`], 
        Hue[0.6476410815525666, 1, 0.1032661947733693], 
        Hue[0.6466225588476413, 1, 0.10467645698018899`], 
        Hue[0.6455892681972526, 1, 0.10610716711149638`], 
        Hue[0.6444525596532654, 1, 0.10768107124932486`], 
        Hue[0.6428646294941891, 1, 0.10987974377727662`], 
        Hue[0.6397787456596381, 1, 0.11415250600973181`], 
        Hue[0.6332784547823019, 1, 0.12315290876296653`], 
        Hue[0.622205306537433, 1, 0.13848496017893902`], 
        Hue[0.6090491411989667, 1, 0.1567011891091231], 
        Hue[0.5998736460104983, 1, 0.1694057209085409], 
        Hue[0.5998738052387638, 1, 0.16940550043863484`], 
        Hue[0.6090518863173507, 1, 0.15669738817597592`], 
        Hue[0.6222118250047584, 1, 0.1384759346087962], 
        Hue[0.6332852682945339, 1, 0.12314347466910694`], 
        Hue[0.639783111261144, 1, 0.1141464613307238], 
        Hue[0.6428668818449628, 1, 0.10987662513774389`], 
        Hue[0.6444538432672381, 1, 0.10767929393767041`], 
        Hue[0.6455902756764588, 1, 0.10610577214028791`], 
        Hue[0.6466234011363869, 1, 0.10467529073423344`], 
        Hue[0.6476414975568979, 1, 0.10326561876737213`], 
        Hue[0.6485955693237656, 1, 0.1019445963209399], 
        Hue[0.6493411176280109, 1, 0.10091229866890794`], 
        Hue[0.6497759033253893, 1, 0.10031028770330719`], 
        Hue[0.6499487609293295, 1, 0.10007094640554372`], 
        Hue[0.6499925622199799, 1, 0.10001029846464331`], 
        Hue[0.6499966840514407, 1, 0.10000459131338975`], 
        Hue[0.6499755737898713, 1, 0.1000338209063321], 
        Hue[0.6498816573421481, 1, 0.10016385906471802`], 
        Hue[0.649599755499443, 1, 0.1005541846930789], 
        Hue[0.6489939519074316, 1, 0.10139298966663324`], 
        Hue[0.6480080185451057, 1, 0.10275812816831516`], 
        Hue[0.6467189588664403, 1, 0.10454298003108281`], 
        Hue[0.6452371269588972, 1, 0.10659474728768085`], 
        Hue[0.6433834721860215, 1, 0.10916134620397015`], 
        Hue[0.6397787456596258, 1, 0.11415250600974894`], 
        Hue[0.6301844468266199, 1, 0.1274369197785264], 
        Hue[0.6080792206635541, 1, 0.15804415600430965`], 
        Hue[0.5717905289829107, 1, 0.20829003679289282`], 
        Hue[0.5317029461800612, 1, 0.26379592067376145`], 
        Hue[0.5054104508359922, 1, 0.3002009142270876], 
        Hue[0.5054110463243464, 1, 0.3002000897047511], 
        Hue[0.5317100440196496, 1, 0.2637860928958698], 
        Hue[0.5718071228013197, 1, 0.20826706073663426`], 
        Hue[0.6080965938095235, 1, 0.15802010087912133`], 
        Hue[0.6301948999416345, 1, 0.12742244623466004`], 
        Hue[0.6397831112611579, 1, 0.11414646133070443`], 
        Hue[0.6433852867591167, 1, 0.10915883371814625`], 
        Hue[0.6452381831863105, 1, 0.1065932848189547], 
        Hue[0.6467195342872314, 1, 0.10454218329460267`], 
        Hue[0.6480079461522906, 1, 0.10275822840452063`], 
        Hue[0.6489933573089745, 1, 0.10139381295680457`], 
        Hue[0.6495991042255869, 1, 0.10055508645687973`], 
        Hue[0.6498812811242847, 1, 0.1001643799817597], 
        Hue[0.6499754483540974, 1, 0.1000339945866345], 
        Hue[0.6499966598024274, 1, 0.10000462488894668`], 
        Hue[0.6499990174111819, 1, 0.10000136050759434`], 
        Hue[0.6499918966134397, 1, 0.10001122007369898`], 
        Hue[0.6499540431582559, 1, 0.10006363255010724`], 
        Hue[0.6498113105300757, 1, 0.10026126234297222`], 
        Hue[0.6494149503656031, 1, 0.10081006872454952`], 
        Hue[0.6485794863728921, 1, 0.10196686502214951`], 
        Hue[0.6471926206446967, 1, 0.10388714064580462`], 
        Hue[0.6452105445037793, 1, 0.10663155376399788`], 
        Hue[0.6419342693172904, 1, 0.11116793479144421`], 
        Hue[0.6332784547823264, 1, 0.12315290876293279`], 
        Hue[0.6080792206635947, 1, 0.15804415600425353`], 
        Hue[0.5535172220443463, 1, 0.23359153870782828`], 
        Hue[0.47393025290694657`, 1, 0.3437888805903817], 
        Hue[0.3965448698524707, 1, 0.4509378725119636], 
        Hue[0.3505683074570688, 1, 0.5145977281363663], 
        Hue[0.35057138237062935`, 1, 0.514593470563744], 
        Hue[0.3965589856306645, 1, 0.45091832758831074`], 
        Hue[0.47395746658768534`, 1, 0.34375120010935883`], 
        Hue[0.553545544713231, 1, 0.23355232270475706`], 
        Hue[0.6080965938097692, 1, 0.15802010087878113`], 
        Hue[0.6332852682947127, 1, 0.12314347466885944`], 
        Hue[0.6419364029753274, 1, 0.11116498049570052`], 
        Hue[0.6452112044766228, 1, 0.10663063995544537`], 
        Hue[0.6471924667805229, 1, 0.10388735368850681`], 
        Hue[0.6485787775709114, 1, 0.10196784644027657`], 
        Hue[0.6494141593805507, 1, 0.1008111639346222], 
        Hue[0.649810793044838, 1, 0.1002619788609935], 
        Hue[0.6499538247815461, 1, 0.10006393491785932`], 
        Hue[0.6499918370195641, 1, 0.10001130258829588`], 
        Hue[0.6499990071984714, 1, 0.10000137464827052`], 
        Hue[0.6499998034253445, 1, 0.10000027218029237`], 
        Hue[0.6499980735657545, 1, 0.10000266737049385`], 
        Hue[0.6499865511173065, 1, 0.10001862152988332`], 
        Hue[0.6499305428935217, 1, 0.10009617137820083`], 
        Hue[0.649727552592175, 1, 0.10037723487237314`], 
        Hue[0.6491668432411204, 1, 0.10115360166614108`], 
        Hue[0.647941631429142, 1, 0.10285004879041884`], 
        Hue[0.6455643340646423, 1, 0.1061416912951107], 
        Hue[0.639972477261512, 1, 0.1138842622532912], 
        Hue[0.6222053065374926, 1, 0.13848496017885642`], 
        Hue[0.5717905289829407, 1, 0.20829003679285135`], 
        Hue[0.47393025290686036`, 1, 0.34378888059050106`], 
        Hue[0.350516590379209, 1, 0.5146693363980183], 
        Hue[0.24717815546080268`, 1, 0.6577533232081193], 
        Hue[0.192019443012804, 1, 0.7341269250591944], 
        Hue[0.19203201182186103`, 1, 0.7341095220928078], 
        Hue[0.2472070239801022, 1, 0.6577133514121661], 
        Hue[0.35054863766858774`, 1, 0.5146249632281092], 
        Hue[0.47395746658837945`, 1, 0.3437512001083977], 
        Hue[0.571807122802092, 1, 0.2082670607355649], 
        Hue[0.6222118250052738, 1, 0.13847593460808238`], 
        Hue[0.6399739959563222, 1, 0.11388215944509239`], 
        Hue[0.6455640968390548, 1, 0.10614201976130883`], 
        Hue[0.647940714362772, 1, 0.10285131857462335`], 
        Hue[0.6491658641833358, 1, 0.10115495728461198`], 
        Hue[0.6497269063824556, 1, 0.10037812962429228`], 
        Hue[0.6499302554975777, 1, 0.10009656931104641`], 
        Hue[0.6499864629461425, 1, 0.10001874361303353`], 
        Hue[0.6499980549290366, 1, 0.10000269317518012`], 
        Hue[0.6499998007707878, 1, 0.10000027585583228`], 
        Hue[0.6499999729662879, 1, 0.10000003743129375`], 
        Hue[0.6499996593138839, 1, 0.1000004717192377], 
        Hue[0.64999697736963, 1, 0.10000418518051228`], 
        Hue[0.6499799856500063, 1, 0.10002771217691438`], 
        Hue[0.6498986949687512, 1, 0.10014026850480605`], 
        Hue[0.6495970754140672, 1, 0.10055789558052244`], 
        Hue[0.6486847327741864, 1, 0.10182113923574201`], 
        Hue[0.646118851728098, 1, 0.1053738976072489], 
        Hue[0.6378190830503302, 1, 0.11686588500723522`], 
        Hue[0.609049141199, 1, 0.1567011891090769], 
        Hue[0.5317029461799629, 1, 0.26379592067389745`], 
        Hue[0.3965448698520418, 1, 0.45093787251255757`], 
        Hue[0.24717815546023186`, 1, 0.6577533232089097], 
        Hue[0.13586707405626453`, 1, 0.8118763589990183], 
        Hue[0.07851354847794556, 1, 0.8912889328766908], 
        Hue[0.07853633966851448, 1, 0.8912573758435953], 
        Hue[0.13590944914320868`, 1, 0.8118176858017111], 
        Hue[0.24720702397992556`, 1, 0.6577133514124108], 
        Hue[0.3965589856317552, 1, 0.4509183275868006], 
        Hue[0.5317100440208999, 1, 0.2637860928941386], 
        Hue[0.6090518863181518, 1, 0.15669738817486675`], 
        Hue[0.6378192495715569, 1, 0.11686565443938277`], 
        Hue[0.6461179406811218, 1, 0.10537515905690827`], 
        Hue[0.6486836471561027, 1, 0.10182264239924246`], 
        Hue[0.6495963220340547, 1, 0.10055893872207818`], 
        Hue[0.6498983451179356, 1, 0.10014075291362756`], 
        Hue[0.6499798727551617, 1, 0.10002786849285314`], 
        Hue[0.6499969516884851, 1, 0.10000422073902054`], 
        Hue[0.649999655185399, 1, 0.10000047743560135`], 
        Hue[0.649999972502692, 1, 0.10000003807319564`], 
        Hue[0.6499999980637757, 1, 0.10000000268092593`], 
        Hue[0.6499999506826558, 1, 0.10000006828555356`], 
        Hue[0.6499994121848602, 1, 0.10000081389788582`], 
        Hue[0.6499948089502459, 1, 0.1000071876073519], 
        Hue[0.6499645086924554, 1, 0.1000491418104465], 
        Hue[0.649806878341268, 1, 0.1002673992197828], 
        Hue[0.649133071211094, 1, 0.10120036293848536`], 
        Hue[0.6465292695559209, 1, 0.10480562676872485`], 
        Hue[0.6363437737647146, 1, 0.11890862094116436`], 
        Hue[0.5998736460104778, 1, 0.16940572090856923`], 
        Hue[0.5054104508357453, 1, 0.3002009142274296], 
        Hue[0.35056830745625983`, 1, 0.5145977281374865], 
        Hue[0.1920194430115696, 1, 0.7341269250609037], 
        Hue[0.07851354847718961, 1, 0.8912889328777374], 
        Hue[0.016906005021812276`, 1, 0.9765916853544138], 
        Hue[0.016918907565830477`, 1, 0.9765738202934655], 
        Hue[0.07853633966586049, 1, 0.8912573758472702], 
        Hue[0.1920320118201158, 1, 0.7341095220952243], 
        Hue[0.35057138237145397`, 1, 0.5145934705626022], 
        Hue[0.5054110463257803, 1, 0.30020008970276585`], 
        Hue[0.5998738052395493, 1, 0.16940550043754726`], 
        Hue[0.6363435021483804, 1, 0.11890899702531947`], 
        Hue[0.6465287438946181, 1, 0.10480635460745186`], 
        Hue[0.649132595542316, 1, 0.10120102155679332`], 
        Hue[0.6498066105961676, 1, 0.10026776994376801`], 
        Hue[0.6499644084648015, 1, 0.10004928058719788`], 
        Hue[0.6499947831523833, 1, 0.10000722332746918`], 
        Hue[0.6499994075356613, 1, 0.10000082033523827`], 
        Hue[0.6499999500906315, 1, 0.10000006910527945`], 
        Hue[0.6499999980108732, 1, 0.10000000275417563`], 
        Hue[0.6499999980108732, 1, 0.10000000275417563`], 
        Hue[0.6499999500906315, 1, 0.10000006910527945`], 
        Hue[0.6499994075356613, 1, 0.10000082033523827`], 
        Hue[0.6499947831523833, 1, 0.1000072233274692], 
        Hue[0.6499644084648013, 1, 0.10004928058719831`], 
        Hue[0.6498066105961631, 1, 0.10026776994377418`], 
        Hue[0.6491325955422841, 1, 0.10120102155683748`], 
        Hue[0.6465287438944921, 1, 0.1048063546076263], 
        Hue[0.6363435021480459, 1, 0.11890899702578257`], 
        Hue[0.5998738052387229, 1, 0.16940550043869146`], 
        Hue[0.5054110463240795, 1, 0.3002000897051206], 
        Hue[0.3505713823697989, 1, 0.5145934705648939], 
        Hue[0.19203201182058266`, 1, 0.7341095220945779], 
        Hue[0.07853633966768225, 1, 0.8912573758447476], 
        Hue[0.016918907565741215`, 1, 0.9765738202935891], 
        Hue[0.016906005018723635`, 1, 0.9765916853586903], 
        Hue[0.07851354847341785, 1, 0.89128893288296], 
        Hue[0.19201944301049073`, 1, 0.7341269250623975], 
        Hue[0.35056830745800077`, 1, 0.5145977281350759], 
        Hue[0.5054104508375454, 1, 0.3002009142249371], 
        Hue[0.5998736460110626, 1, 0.1694057209077594], 
        Hue[0.6363437737646683, 1, 0.11890862094122849`], 
        Hue[0.6465292695558271, 1, 0.1048056267688548], 
        Hue[0.6491330712110641, 1, 0.10120036293852665`], 
        Hue[0.6498068783412636, 1, 0.10026739921978885`], 
        Hue[0.649964508692455, 1, 0.10004914181044693`], 
        Hue[0.6499948089502459, 1, 0.10000718760735192`], 
        Hue[0.6499994121848602, 1, 0.10000081389788582`], 
        Hue[0.6499999506826558, 1, 0.10000006828555356`], 
        Hue[0.6499999980637757, 1, 0.10000000268092593`], 
        Hue[0.649999972502692, 1, 0.10000003807319564`], 
        Hue[0.649999655185399, 1, 0.10000047743560135`], 
        Hue[0.6499969516884851, 1, 0.10000422073902053`], 
        Hue[0.6499798727551617, 1, 0.10002786849285311`], 
        Hue[0.6498983451179355, 1, 0.10014075291362773`], 
        Hue[0.6495963220340493, 1, 0.1005589387220857], 
        Hue[0.6486836471560531, 1, 0.10182264239931109`], 
        Hue[0.6461179406809142, 1, 0.10537515905719567`], 
        Hue[0.6378192495710786, 1, 0.11686565444004504`], 
        Hue[0.6090518863173231, 1, 0.1566973881760142], 
        Hue[0.5317100440194852, 1, 0.2637860928960975], 
        Hue[0.3965589856301587, 1, 0.45091832758901107`], 
        Hue[0.24720702397933064`, 1, 0.6577133514132345], 
        Hue[0.13590944914274938`, 1, 0.811817685802347], 
        Hue[0.07853633966592277, 1, 0.8912573758471839], 
        Hue[0.07851354847355607, 1, 0.8912889328827686], 
        Hue[0.13586707405281984`, 1, 0.8118763590037879], 
        Hue[0.24717815545988908`, 1, 0.6577533232093843], 
        Hue[0.3965448698539299, 1, 0.4509378725099432], 
        Hue[0.5317029461815325, 1, 0.26379592067172436`], 
        Hue[0.6090491411993084, 1, 0.15670118910864986`], 
        Hue[0.6378190830500777, 1, 0.11686588500758477`], 
        Hue[0.6461188517279151, 1, 0.10537389760750222`], 
        Hue[0.6486847327741383, 1, 0.10182113923580859`], 
        Hue[0.6495970754140618, 1, 0.10055789558052991`], 
        Hue[0.6498986949687511, 1, 0.10014026850480622`], 
        Hue[0.6499799856500064, 1, 0.10002771217691435`], 
        Hue[0.64999697736963, 1, 0.10000418518051228`], 
        Hue[0.6499996593138839, 1, 0.1000004717192377], 
        Hue[0.6499999729662879, 1, 0.10000003743129375`], 
        Hue[0.6499998007707878, 1, 0.10000027585583228`], 
        Hue[0.6499980549290366, 1, 0.10000269317518012`], 
        Hue[0.6499864629461425, 1, 0.10001874361303352`], 
        Hue[0.6499302554975778, 1, 0.10009656931104624`], 
        Hue[0.6497269063824568, 1, 0.10037812962429073`], 
        Hue[0.64916586418334, 1, 0.10115495728460613`], 
        Hue[0.6479407143627665, 1, 0.10285131857463113`], 
        Hue[0.6455640968389635, 1, 0.10614201976143513`], 
        Hue[0.6399739959560363, 1, 0.11388215944548823`], 
        Hue[0.6222118250047468, 1, 0.13847593460881222`], 
        Hue[0.5718071228012546, 1, 0.20826706073672444`], 
        Hue[0.47395746658748916`, 1, 0.34375120010963045`], 
        Hue[0.35054863766829164`, 1, 0.5146249632285194], 
        Hue[0.24720702397975558`, 1, 0.6577133514126461], 
        Hue[0.19203201182016771`, 1, 0.7341095220951525], 
        Hue[0.19201944301058688`, 1, 0.7341269250622643], 
        Hue[0.2471781554599206, 1, 0.6577533232093407], 
        Hue[0.3505165903801044, 1, 0.5146693363967786], 
        Hue[0.47393025290842367`, 1, 0.34378888058833645`], 
        Hue[0.5717905289838813, 1, 0.20829003679154906`], 
        Hue[0.6222053065376022, 1, 0.13848496017870468`], 
        Hue[0.6399724772613484, 1, 0.11388426225351767`], 
        Hue[0.645564334064564, 1, 0.10614169129521904`], 
        Hue[0.6479416314291371, 1, 0.10285004879042564`], 
        Hue[0.6491668432411246, 1, 0.10115360166613523`], 
        Hue[0.6497275525921761, 1, 0.10037723487237159`], 
        Hue[0.6499305428935218, 1, 0.10009617137820066`], 
        Hue[0.6499865511173065, 1, 0.1000186215298833], 
        Hue[0.6499980735657545, 1, 0.10000266737049385`], 
        Hue[0.6499998034253445, 1, 0.10000027218029237`], 
        Hue[0.6499990071984714, 1, 0.10000137464827052`], 
        Hue[0.6499918370195641, 1, 0.10001130258829587`], 
        Hue[0.6499538247815461, 1, 0.1000639349178593], 
        Hue[0.6498107930448382, 1, 0.10026197886099324`], 
        Hue[0.6494141593805526, 1, 0.10081116393461954`], 
        Hue[0.6485787775709229, 1, 0.10196784644026062`], 
        Hue[0.6471924667805575, 1, 0.10388735368845878`], 
        Hue[0.6452112044766597, 1, 0.10663063995539425`], 
        Hue[0.6419364029752817, 1, 0.11116498049576384`], 
        Hue[0.633285268294527, 1, 0.12314347466911642`], 
        Hue[0.6080965938094919, 1, 0.15802010087916515`], 
        Hue[0.5535455447131511, 1, 0.2335523227048677], 
        Hue[0.4739574665882697, 1, 0.34375120010854965`], 
        Hue[0.3965589856316865, 1, 0.45091832758689565`], 
        Hue[0.35057138237145447`, 1, 0.5145934705626015], 
        Hue[0.3505683074580232, 1, 0.5145977281350448], 
        Hue[0.3965448698539395, 1, 0.45093787250993], 
        Hue[0.4739302529084245, 1, 0.34378888058833534`], 
        Hue[0.5535172220453116, 1, 0.2335915387064916], 
        Hue[0.608079220663972, 1, 0.15804415600373106`], 
        Hue[0.633278454782362, 1, 0.12315290876288346`], 
        Hue[0.6419342693172857, 1, 0.11116793479145054`], 
        Hue[0.6452105445038205, 1, 0.10663155376394089`], 
        Hue[0.6471926206447316, 1, 0.10388714064575626`], 
        Hue[0.6485794863729036, 1, 0.10196686502213353`], 
        Hue[0.649414950365605, 1, 0.10081006872454687`], 
        Hue[0.6498113105300758, 1, 0.10026126234297196`], 
        Hue[0.6499540431582559, 1, 0.10006363255010721`], 
        Hue[0.6499918966134397, 1, 0.10001122007369896`], 
        Hue[0.6499990174111819, 1, 0.10000136050759434`], 
        Hue[0.6499966598024274, 1, 0.10000462488894667`], 
        Hue[0.6499754483540974, 1, 0.10003399458663449`], 
        Hue[0.6498812811242848, 1, 0.10016437998175964`], 
        Hue[0.6495991042255871, 1, 0.10055508645687948`], 
        Hue[0.648993357308976, 1, 0.10139381295680251`], 
        Hue[0.6480079461523002, 1, 0.10275822840450749`], 
        Hue[0.6467195342872655, 1, 0.1045421832945555], 
        Hue[0.6452381831863728, 1, 0.1065932848188684], 
        Hue[0.6433852867591614, 1, 0.10915883371808421`], 
        Hue[0.6397831112611403, 1, 0.11414646133072888`], 
        Hue[0.6301948999416069, 1, 0.12742244623469806`], 
        Hue[0.6080965938096965, 1, 0.15802010087888185`], 
        Hue[0.5718071228019954, 1, 0.20826706073569862`], 
        Hue[0.5317100440208316, 1, 0.2637860928942333], 
        Hue[0.5054110463257548, 1, 0.300200089702801], 
        Hue[0.5054104508375404, 1, 0.30020091422494405`], 
        Hue[0.5317029461815312, 1, 0.2637959206717261], 
        Hue[0.5717905289838803, 1, 0.2082900367915504], 
        Hue[0.6080792206639716, 1, 0.1580441560037317], 
        Hue[0.6301844468267296, 1, 0.1274369197783744], 
        Hue[0.6397787456596526, 1, 0.1141525060097118], 
        Hue[0.6433834721860744, 1, 0.10916134620389706`], 
        Hue[0.6452371269589603, 1, 0.10659474728759341`], 
        Hue[0.6467189588664743, 1, 0.1045429800310355], 
        Hue[0.6480080185451152, 1, 0.10275812816830196`], 
        Hue[0.648993951907433, 1, 0.10139298966663116`], 
        Hue[0.6495997554994433, 1, 0.10055418469307864`], 
        Hue[0.6498816573421482, 1, 0.10016385906471795`], 
        Hue[0.6499755737898713, 1, 0.10003382090633207`], 
        Hue[0.6499966840514407, 1, 0.10000459131338975`], 
        Hue[0.6499925622199799, 1, 0.1000102984646433], 
        Hue[0.6499487609293296, 1, 0.10007094640554366`], 
        Hue[0.6497759033253894, 1, 0.10031028770330705`], 
        Hue[0.6493411176280112, 1, 0.10091229866890768`], 
        Hue[0.6485955693237664, 1, 0.10194459632093891`], 
        Hue[0.647641497556902, 1, 0.10326561876736648`], 
        Hue[0.6466234011364024, 1, 0.1046752907342122], 
        Hue[0.6455902756764903, 1, 0.10610577214024428`], 
        Hue[0.6444538432672702, 1, 0.10767929393762596`], 
        Hue[0.6428668818449762, 1, 0.10987662513772525`], 
        Hue[0.6397831112611666, 1, 0.11414646133069248`], 
        Hue[0.633285268294681, 1, 0.1231434746689032], 
        Hue[0.6222118250052016, 1, 0.13847593460818255`], 
        Hue[0.6090518863180883, 1, 0.1566973881749547], 
        Hue[0.5998738052395204, 1, 0.16940550043758723`], 
        Hue[0.5998736460110543, 1, 0.16940572090777092`], 
        Hue[0.6090491411993062, 1, 0.15670118910865305`], 
        Hue[0.6222053065376013, 1, 0.13848496017870593`], 
        Hue[0.6332784547823616, 1, 0.12315290876288401`], 
        Hue[0.6397787456596524, 1, 0.11415250600971207`], 
        Hue[0.6428646294942048, 1, 0.109879743777255], 
        Hue[0.6444525596532982, 1, 0.10768107124927954`], 
        Hue[0.6455892681972842, 1, 0.10610716711145265`], 
        Hue[0.6466225588476566, 1, 0.10467645698016773`], 
        Hue[0.6476410815525707, 1, 0.10326619477336363`], 
        Hue[0.6485957628883883, 1, 0.10194432830838548`], 
        Hue[0.6493416527692056, 1, 0.1009115577041769], 
        Hue[0.649776314091313, 1, 0.1003097189504897], 
        Hue[0.6499489183734026, 1, 0.10007072840605792`], 
        Hue[0.6499925949688808, 1, 0.10001025312001115`], 
        Hue[0.6499886739785015, 1, 0.10001568218361342`], 
        Hue[0.6499246089762626, 1, 0.1001043875713287], 
        Hue[0.6496881578673747, 1, 0.10043178141440437`], 
        Hue[0.6491561566068836, 1, 0.10116839854431495`], 
        Hue[0.6483817334719172, 1, 0.10224067673119168`], 
        Hue[0.6475628209177056, 1, 0.10337455565240777`], 
        Hue[0.6468126895154237, 1, 0.10441319913249028`], 
        Hue[0.6460978666860392, 1, 0.10540295381933039`], 
        Hue[0.6453306991597177, 1, 0.10646518577885243`], 
        Hue[0.644453843267272, 1, 0.10767929393762347`], 
        Hue[0.643385286759181, 1, 0.10915883371805703`], 
        Hue[0.6419364029753845, 1, 0.11116498049562153`], 
        Hue[0.6399739959563322, 1, 0.11388215944507858`], 
        Hue[0.6378192495715385, 1, 0.1168656544394084], 
        Hue[0.6363435021483664, 1, 0.11890899702533884`], 
        Hue[0.6363437737646637, 1, 0.11890862094123503`], 
        Hue[0.6378190830500764, 1, 0.1168658850075865], 
        Hue[0.6399724772613479, 1, 0.11388426225351829`], 
        Hue[0.6419342693172855, 1, 0.11116793479145093`], 
        Hue[0.6433834721860742, 1, 0.10916134620389735`], 
        Hue[0.6444525596532981, 1, 0.10768107124927964`], 
        Hue[0.6453297342290546, 1, 0.1064665218366937], 
        Hue[0.6460970638205118, 1, 0.10540406547929135`], 
        Hue[0.6468120214679307, 1, 0.10441412412132668`], 
        Hue[0.647562318571634, 1, 0.10337525120850674`], 
        Hue[0.6483816036130577, 1, 0.10224085653576623`], 
        Hue[0.6491563829934826, 1, 0.10116808508594727`], 
        Hue[0.6496884070778484, 1, 0.10043143635374849`], 
        Hue[0.6499247160158208, 1, 0.10010423936270975`], 
        Hue[0.6499886974241673, 1, 0.10001564972038382`], 
        Hue[0.6499871792649814, 1, 0.10001775178694883`], 
        Hue[0.6499158353957267, 1, 0.10011653560591685`], 
        Hue[0.6496598197797228, 1, 0.10047101876653775`], 
        Hue[0.6491137403392347, 1, 0.10122712876105969`], 
        Hue[0.6483905107237508, 1, 0.10222852361326822`], 
        Hue[0.6477166871005474, 1, 0.10316151016847291`], 
        Hue[0.6471496978926512, 1, 0.10394657214863678`], 
        Hue[0.6466253190276147, 1, 0.10467263519253359`], 
        Hue[0.6460978666860392, 1, 0.10540295381933043`], 
        Hue[0.645590275676491, 1, 0.10610577214024328`], 
        Hue[0.6452381831863822, 1, 0.10659328481885547`], 
        Hue[0.6452112044767101, 1, 0.10663063995532446`], 
        Hue[0.6455640968391104, 1, 0.10614201976123169`], 
        Hue[0.6461179406811379, 1, 0.10537515905688595`], 
        Hue[0.6465287438946186, 1, 0.1048063546074513], 
        Hue[0.6465292695558261, 1, 0.10480562676885623`], 
        Hue[0.6461188517279146, 1, 0.10537389760750286`], 
        Hue[0.6455643340645638, 1, 0.10614169129521937`], 
        Hue[0.6452105445038203, 1, 0.10663155376394112`], 
        Hue[0.6452371269589602, 1, 0.10659474728759356`], 
        Hue[0.6455892681972842, 1, 0.10610716711145261`], 
        Hue[0.6460970638205119, 1, 0.10540406547929121`], 
        Hue[0.6466247658365464, 1, 0.10467340114939741`], 
        Hue[0.647149218571604, 1, 0.10394723582393292`], 
        Hue[0.6477162367776387, 1, 0.1031621336925004], 
        Hue[0.6483902795375448, 1, 0.10222884371724564`], 
        Hue[0.6491137171780913, 1, 0.10122716083033519`], 
        Hue[0.6496598500920083, 1, 0.10047097679568083`], 
        Hue[0.6499158508823387, 1, 0.10011651416291573`], 
        Hue[0.6499871827318622, 1, 0.10001774698665247`], 
        Hue[0.649988696060685, 1, 0.10001565160828231`], 
        Hue[0.6499253861002506, 1, 0.10010331155349914`], 
        Hue[0.6496958940624493, 1, 0.10042106975968562`], 
        Hue[0.649201321406682, 1, 0.10110586266767116`], 
        Hue[0.6485504399625567, 1, 0.1020070831287677], 
        Hue[0.6479788895815404, 1, 0.10279846057940567`], 
        Hue[0.6475405484301957, 1, 0.1034053944812675], 
        Hue[0.6471496978926513, 1, 0.10394657214863673`], 
        Hue[0.6468126895154237, 1, 0.10441319913249034`], 
        Hue[0.6466234011364024, 1, 0.1046752907342121], 
        Hue[0.646719534287268, 1, 0.10454218329455199`], 
        Hue[0.647192466780572, 1, 0.10388735368843882`], 
        Hue[0.6479407143628089, 1, 0.10285131857457236`], 
        Hue[0.6486836471561178, 1, 0.10182264239922159`], 
        Hue[0.6491325955423191, 1, 0.10120102155678898`], 
        Hue[0.6491330712110643, 1, 0.10120036293852638`], 
        Hue[0.6486847327741382, 1, 0.10182113923580877`], 
        Hue[0.647941631429137, 1, 0.10285004879042578`], 
        Hue[0.6471926206447316, 1, 0.1038871406457563], 
        Hue[0.6467189588664745, 1, 0.10454298003103545`], 
        Hue[0.6466225588476568, 1, 0.10467645698016752`], 
        Hue[0.6468120214679309, 1, 0.10441412412132642`], 
        Hue[0.6471492185716041, 1, 0.10394723582393277`], 
        Hue[0.6475401197544659, 1, 0.10340598803227799`], 
        Hue[0.6479786482228466, 1, 0.10279879476836637`], 
        Hue[0.6485502856265529, 1, 0.10200729682477296`], 
        Hue[0.6492010682900418, 1, 0.10110621313686532`], 
        Hue[0.6496956694759822, 1, 0.10042138072556303`], 
        Hue[0.6499252913219769, 1, 0.10010344278495513`], 
        Hue[0.6499886753209286, 1, 0.1000156803248681], 
        Hue[0.6499927167322246, 1, 0.10001008452461209`], 
        Hue[0.6499507186578939, 1, 0.10006823570445467`], 
        Hue[0.6497907590832415, 1, 0.10028971819243494`], 
        Hue[0.6494168902411381, 1, 0.10080738274303955`], 
        Hue[0.6488676434233366, 1, 0.10156787833691865`], 
        Hue[0.6483448000569576, 1, 0.10229181530575097`], 
        Hue[0.6479788895815404, 1, 0.10279846057940568`], 
        Hue[0.6477166871005474, 1, 0.10316151016847291`], 
        Hue[0.6475628209177055, 1, 0.10337455565240786`], 
        Hue[0.6476414975569019, 1, 0.10326561876736656`], 
        Hue[0.6480079461523006, 1, 0.10275822840450693`], 
        Hue[0.6485787775709253, 1, 0.10196784644025733`], 
        Hue[0.6491658641833469, 1, 0.1011549572845966], 
        Hue[0.6495963220340597, 1, 0.10055893872207124`], 
        Hue[0.6498066105961688, 1, 0.10026776994376628`], 
        Hue[0.6498068783412638, 1, 0.10026739921978865`], 
        Hue[0.6495970754140618, 1, 0.10055789558052994`], 
        Hue[0.6491668432411246, 1, 0.10115360166613523`], 
        Hue[0.6485794863729036, 1, 0.10196686502213344`], 
        Hue[0.6480080185451154, 1, 0.1027581281683018], 
        Hue[0.6476410815525709, 1, 0.1032661947733634], 
        Hue[0.6475623185716342, 1, 0.10337525120850653`], 
        Hue[0.6477162367776387, 1, 0.1031621336925003], 
        Hue[0.6479786482228466, 1, 0.1027987947683664], 
        Hue[0.6483447647008004, 1, 0.10229186426043022`], 
        Hue[0.6488673490985242, 1, 0.10156828586358195`], 
        Hue[0.6494162997265166, 1, 0.10080820037866929`], 
        Hue[0.6497903076682764, 1, 0.10029034322854048`], 
        Hue[0.6499505462683586, 1, 0.1000684743976574], 
        Hue[0.6499926810152515, 1, 0.10001013397888259`], 
        Hue[0.6499968893754299, 1, 0.10000430701863561`], 
        Hue[0.6499779704371008, 1, 0.10003050247170653`], 
        Hue[0.6498991064821327, 1, 0.10013969871704714`], 
        Hue[0.6496859288220751, 1, 0.10043486778481912`], 
        Hue[0.6493054326597033, 1, 0.1009617086250262], 
        Hue[0.6488676434233366, 1, 0.10156787833691865`], 
        Hue[0.6485504399625566, 1, 0.10200708312876779`], 
        Hue[0.6483905107237506, 1, 0.1022285236132684], 
        Hue[0.648381733471917, 1, 0.10224067673119189`], 
        Hue[0.6485955693237663, 1, 0.10194459632093905`], 
        Hue[0.648993357308976, 1, 0.10139381295680246`], 
        Hue[0.6494141593805528, 1, 0.10081116393461917`], 
        Hue[0.6497269063824574, 1, 0.1003781296242898], 
        Hue[0.6498983451179365, 1, 0.1001407529136264], 
        Hue[0.6499644084648017, 1, 0.10004928058719757`], 
        Hue[0.649964508692455, 1, 0.10004914181044688`], 
        Hue[0.6498986949687511, 1, 0.1001402685048062], 
        Hue[0.6497275525921762, 1, 0.10037723487237155`], 
        Hue[0.6494149503656051, 1, 0.10081006872454676`], 
        Hue[0.6489939519074331, 1, 0.101392989666631], 
        Hue[0.6485957628883884, 1, 0.10194432830838535`], 
        Hue[0.6483816036130579, 1, 0.10224085653576616`], 
        Hue[0.6483902795375448, 1, 0.10222884371724568`], 
        Hue[0.6485502856265528, 1, 0.10200729682477307`], 
        Hue[0.6488673490985241, 1, 0.10156828586358203`], 
        Hue[0.6493047777680847, 1, 0.10096261539803657`], 
        Hue[0.6496852145273001, 1, 0.1004358568083538], 
        Hue[0.6498986870713849, 1, 0.100140279439621], 
        Hue[0.6499778300417067, 1, 0.10003069686532914`], 
        Hue[0.6499968622093047, 1, 0.10000434463327044`], 
        Hue[0.6499991646891583, 1, 0.10000115658424233`], 
        Hue[0.6499936165544795, 1, 0.1000088386168745], 
        Hue[0.6499670218094749, 1, 0.100045662109958], 
        Hue[0.6498796003047549, 1, 0.10016670727033941`], 
        Hue[0.6496859288220751, 1, 0.1004348677848191], 
        Hue[0.6494168902411381, 1, 0.1008073827430395], 
        Hue[0.649201321406682, 1, 0.10110586266767124`], 
        Hue[0.6491137403392345, 1, 0.10122712876105991`], 
        Hue[0.6491561566068835, 1, 0.10116839854431522`], 
        Hue[0.649341117628011, 1, 0.10091229866890786`], 
        Hue[0.6495991042255871, 1, 0.10055508645687952`], 
        Hue[0.6498107930448382, 1, 0.10026197886099321`], 
        Hue[0.6499302554975778, 1, 0.10009656931104617`], 
        Hue[0.6499798727551618, 1, 0.10002786849285303`], 
        Hue[0.6499947831523835, 1, 0.10000722332746916`], 
        Hue[0.6499948089502459, 1, 0.10000718760735192`], 
        Hue[0.6499799856500064, 1, 0.10002771217691434`], 
        Hue[0.6499305428935218, 1, 0.10009617137820065`], 
        Hue[0.6498113105300759, 1, 0.10026126234297192`], 
        Hue[0.6495997554994433, 1, 0.10055418469307857`], 
        Hue[0.6493416527692056, 1, 0.10091155770417684`], 
        Hue[0.6491563829934826, 1, 0.10116808508594727`], 
        Hue[0.6491137171780912, 1, 0.10122716083033526`], 
        Hue[0.6492010682900416, 1, 0.10110621313686542`], 
        Hue[0.6494162997265166, 1, 0.10080820037866937`], 
        Hue[0.6496852145273, 1, 0.10043585680835385`], 
        Hue[0.6498791017831329, 1, 0.10016739753104674`], 
        Hue[0.649966803005242, 1, 0.10004596506966494`], 
        Hue[0.6499935549624519, 1, 0.10000892389814348`], 
        Hue[0.6499991538514573, 1, 0.1000011715902899], 
        Hue[0.6499998599977125, 1, 0.1000001938493212], 
        Hue[0.6499987823857478, 1, 0.1000016859274261], 
        Hue[0.6499925169058931, 1, 0.10001036120722495`], 
        Hue[0.6499670218094749, 1, 0.10004566210995798`], 
        Hue[0.6498991064821327, 1, 0.10013969871704712`], 
        Hue[0.6497907590832415, 1, 0.10028971819243492`], 
        Hue[0.6496958940624493, 1, 0.10042106975968565`], 
        Hue[0.6496598197797226, 1, 0.10047101876653788`], 
        Hue[0.6496881578673745, 1, 0.10043178141440456`], 
        Hue[0.6497759033253893, 1, 0.10031028770330719`], 
        Hue[0.6498812811242847, 1, 0.10016437998175969`], 
        Hue[0.6499538247815461, 1, 0.1000639349178593], 
        Hue[0.6499864629461425, 1, 0.1000187436130335], 
        Hue[0.6499969516884851, 1, 0.10000422073902053`], 
        Hue[0.6499994075356613, 1, 0.10000082033523827`], 
        Hue[0.6499994121848602, 1, 0.10000081389788582`], 
        Hue[0.64999697736963, 1, 0.10000418518051227`], 
        Hue[0.6499865511173065, 1, 0.1000186215298833], 
        Hue[0.6499540431582559, 1, 0.1000636325501072], 
        Hue[0.6498816573421482, 1, 0.10016385906471793`], 
        Hue[0.649776314091313, 1, 0.10030971895048969`], 
        Hue[0.6496884070778484, 1, 0.1004314363537485], 
        Hue[0.6496598500920083, 1, 0.10047097679568086`], 
        Hue[0.6496956694759822, 1, 0.10042138072556307`], 
        Hue[0.6497903076682763, 1, 0.10029034322854052`], 
        Hue[0.6498986870713849, 1, 0.10014027943962103`], 
        Hue[0.649966803005242, 1, 0.10004596506966494`], 
        Hue[0.6499924447114087, 1, 0.10001046116881876`], 
        Hue[0.6499987662030103, 1, 0.10000170833429346`], 
        Hue[0.6499998575374961, 1, 0.1000001972557747], 
        Hue[0.6499999856334239, 1, 0.10000001989218238`], 
        Hue[0.6499998396191935, 1, 0.1000002220657321], 
        Hue[0.6499987823857478, 1, 0.1000016859274261], 
        Hue[0.6499936165544795, 1, 0.10000883861687448`], 
        Hue[0.6499779704371008, 1, 0.10003050247170653`], 
        Hue[0.6499507186578939, 1, 0.10006823570445465`], 
        Hue[0.6499253861002506, 1, 0.10010331155349914`], 
        Hue[0.6499158353957267, 1, 0.10011653560591689`], 
        Hue[0.6499246089762626, 1, 0.10010438757132877`], 
        Hue[0.6499487609293295, 1, 0.10007094640554372`], 
        Hue[0.6499754483540974, 1, 0.1000339945866345], 
        Hue[0.6499918370195641, 1, 0.10001130258829588`], 
        Hue[0.6499980549290366, 1, 0.10000269317518012`], 
        Hue[0.649999655185399, 1, 0.10000047743560135`], 
        Hue[0.6499999500906315, 1, 0.10000006910527945`], 
        Hue[0.6499999506826558, 1, 0.10000006828555356`], 
        Hue[0.6499996593138839, 1, 0.1000004717192377], 
        Hue[0.6499980735657545, 1, 0.10000266737049385`], 
        Hue[0.6499918966134397, 1, 0.10001122007369896`], 
        Hue[0.6499755737898713, 1, 0.10003382090633207`], 
        Hue[0.6499489183734026, 1, 0.10007072840605792`], 
        Hue[0.6499247160158208, 1, 0.10010423936270976`], 
        Hue[0.6499158508823387, 1, 0.10011651416291573`], 
        Hue[0.6499252913219769, 1, 0.10010344278495513`], 
        Hue[0.6499505462683586, 1, 0.10006847439765741`], 
        Hue[0.6499778300417067, 1, 0.10003069686532914`], 
        Hue[0.6499935549624519, 1, 0.10000892389814348`], 
        Hue[0.6499987662030103, 1, 0.10000170833429346`], 
        Hue[0.6499998368066057, 1, 0.10000022596008445`], 
        Hue[0.6499999852880078, 1, 0.10000002037045079`], 
        Hue[0.65, 1, 0.1], 
        Hue[0.6499999856334239, 1, 0.10000001989218238`], 
        Hue[0.6499998599977125, 1, 0.1000001938493212], 
        Hue[0.6499991646891583, 1, 0.10000115658424232`], 
        Hue[0.6499968893754299, 1, 0.10000430701863561`], 
        Hue[0.6499927167322246, 1, 0.10001008452461209`], 
        Hue[0.649988696060685, 1, 0.10001565160828231`], 
        Hue[0.6499871792649814, 1, 0.10001775178694884`], 
        Hue[0.6499886739785015, 1, 0.10001568218361344`], 
        Hue[0.6499925622199799, 1, 0.10001029846464331`], 
        Hue[0.6499966598024274, 1, 0.10000462488894668`], 
        Hue[0.6499990071984713, 1, 0.10000137464827052`], 
        Hue[0.6499998007707878, 1, 0.10000027585583228`], 
        Hue[0.649999972502692, 1, 0.10000003807319564`], 
        Hue[0.6499999980108732, 1, 0.10000000275417563`], 
        Hue[0.6499999980637757, 1, 0.10000000268092593`], 
        Hue[0.6499999729662879, 1, 0.10000003743129375`], 
        Hue[0.6499998034253445, 1, 0.10000027218029237`], 
        Hue[0.6499990174111819, 1, 0.10000136050759434`], 
        Hue[0.6499966840514407, 1, 0.10000459131338975`], 
        Hue[0.6499925949688808, 1, 0.10001025312001115`], 
        Hue[0.6499886974241673, 1, 0.10001564972038382`], 
        Hue[0.6499871827318622, 1, 0.10001774698665247`], 
        Hue[0.6499886753209286, 1, 0.1000156803248681], 
        Hue[0.6499926810152515, 1, 0.10001013397888259`], 
        Hue[0.6499968622093047, 1, 0.10000434463327044`], 
        Hue[0.6499991538514573, 1, 0.1000011715902899], 
        Hue[0.6499998575374961, 1, 0.1000001972557747], 
        Hue[0.6499999852880078, 1, 0.10000002037045079`], 
        Hue[0.6499999999669532, 1, 0.10000000004575714`], 
        Hue[0.6499999849238686, 1, 0.10000002087464362`], 
        Hue[0.6499998410900942, 1, 0.10000022002910035`], 
        Hue[0.6499989027437987, 1, 0.1000015192778172], 
        Hue[0.6499950637214474, 1, 0.10000683484722672`], 
        Hue[0.6499858880248885, 1, 0.10001953965784668`], 
        Hue[0.6499738433200122, 1, 0.10003621694152162`], 
        Hue[0.6499736137013089, 1, 0.10003653487511074`], 
        Hue[0.6499852820270374, 1, 0.10002037873179444`], 
        Hue[0.6499944257549256, 1, 0.10000771818548765`], 
        Hue[0.6499985573975376, 1, 0.10000199744956326`], 
        Hue[0.6499999644133952, 1, 0.10000004927376044`], 
        Hue[0.649999963849577, 1, 0.10000005005443176`], 
        Hue[0.6499997310457263, 1, 0.1000003723982252], 
        Hue[0.6499985427449788, 1, 0.10000201773772166`], 
        Hue[0.6499943838807886, 1, 0.10000777616506201`], 
        Hue[0.6499852093278041, 1, 0.10002047939227127`], 
        Hue[0.6499735432029402, 1, 0.10003663248823666`], 
        Hue[0.6499739154396369, 1, 0.1000361170835797], 
        Hue[0.6499859694850614, 1, 0.1000194268668381], 
        Hue[0.6499951095696064, 1, 0.10000677136516045`], 
        Hue[0.6499999852765213, 1, 0.10000002038635529`], 
        Hue[0.6499998410900942, 1, 0.10000022002910035`], 
        Hue[0.6499987284592187, 1, 0.10000176059492807`], 
        Hue[0.6499926958443384, 1, 0.10001011344630079`], 
        Hue[0.6499709105190519, 1, 0.10004027774285126`], 
        Hue[0.6499228820634163, 1, 0.10010677868142358`], 
        Hue[0.6498632426034409, 1, 0.10018935639523571`], 
        Hue[0.6499166783476851, 1, 0.10011536844166691`], 
        Hue[0.6499995658652175, 1, 0.10000060110969894`], 
        Hue[0.6499975345136633, 1, 0.1000034137503124], 
        Hue[0.6499892148045759, 1, 0.10001493334751028`], 
        Hue[0.6499646928280673, 1, 0.10004888685344525`], 
        Hue[0.6499164076341196, 1, 0.10011574327583442`], 
        Hue[0.649859297955133, 1, 0.10019481821596973`], 
        Hue[0.6499231865672959, 1, 0.10010635706066737`], 
        Hue[0.6499989027437987, 1, 0.1000015192778172], 
        Hue[0.6499926958443384, 1, 0.10001011344630079`], 
        Hue[0.6499655474797963, 1, 0.1000477034895128], 
        Hue[0.649883813694463, 1, 0.10016087334612819`], 
        Hue[0.6497258842286484, 1, 0.10037954491417912`], 
        Hue[0.6495470248985343, 1, 0.10062719629433715`], 
        Hue[0.6499962208090388, 1, 0.10000523272594622`], 
        Hue[0.6499834211304725, 1, 0.10002295535780738`], 
        Hue[0.6499425936539298, 1, 0.10007948570994332`], 
        Hue[0.6498463773044624, 1, 0.10021270834766752`], 
        Hue[0.6496866431313959, 1, 0.10043387874114412`], 
        Hue[0.6499950637214474, 1, 0.10000683484722672`], 
        Hue[0.6499709105190519, 1, 0.10004027774285126`], 
        Hue[0.649883813694463, 1, 0.10016087334612818`], 
        Hue[0.6496719726032052, 1, 0.10045419178017752`], 
        Hue[0.6493325519861007, 1, 0.10092415878847594`], 
        Hue[0.6499750001267646, 1, 0.10003461520909523`], 
        Hue[0.6499160398116125, 1, 0.10011625256853653`], 
        Hue[0.6497718388043817, 1, 0.1003159155016253], 
        Hue[0.6495107697330291, 1, 0.10067739575426744`], 
        Hue[0.6499951095696064, 1, 0.10000677136516044`], 
        Hue[0.6499858880248885, 1, 0.10001953965784668`], 
        Hue[0.6499228820634163, 1, 0.10010677868142358`], 
        Hue[0.6497258842286484, 1, 0.10037954491417911`], 
        Hue[0.6493325519861007, 1, 0.10092415878847591`], 
        Hue[0.6498706375066201, 1, 0.10017911729852608`], 
        Hue[0.6496722119092209, 1, 0.1004538604333865], 
        Hue[0.6493021059490827, 1, 0.10096631483973172`], 
        Hue[0.6499231865672959, 1, 0.10010635706066733`], 
        Hue[0.6499859694850614, 1, 0.10001942686683808`], 
        Hue[0.6499738433200122, 1, 0.10003621694152162`], 
        Hue[0.6498632426034409, 1, 0.10018935639523571`], 
        Hue[0.6495470248985343, 1, 0.10062719629433713`], 
        Hue[0.647580489015451, 1, 0.1033500921324526], 
        Hue[0.6472836152052587, 1, 0.10376114817733419`], 
        Hue[0.6471229934816806, 1, 0.10398354748690382`], 
        Hue[0.6494582860502159, 1, 0.10075006546893182`], 
        Hue[0.6489836000327871, 1, 0.10140732303152564`], 
        Hue[0.6472221007030101, 1, 0.10384632210352455`], 
        Hue[0.6471236667804909, 1, 0.10398261522701252`], 
        Hue[0.6499739154396369, 1, 0.1000361170835797], 
        Hue[0.6475804890154508, 1, 0.10335009213245272`], 
        Hue[0.6471111373540478, 1, 0.10399996366362618`], 
        Hue[0.6466655980999736, 1, 0.10461686416926731`], 
        Hue[0.6462649933797092, 1, 0.10517154762809496`], 
        Hue[0.6460136181207266, 1, 0.10551960567899407`], 
        Hue[0.6460894082914638, 1, 0.10541466544258865`], 
        Hue[0.6460145578411789, 1, 0.1055183045275985], 
        Hue[0.6472836152052579, 1, 0.10376114817733527`], 
        Hue[0.6466655980999717, 1, 0.10461686416927002`], 
        Hue[0.6460502287342637, 1, 0.10546891406025037`], 
        Hue[0.6453869809034413, 1, 0.10638725721061978`], 
        Hue[0.6447122845415751, 1, 0.10732145217320362`], 
        Hue[0.6441102689755968, 1, 0.10815501218763528`], 
        Hue[0.6436464972274288, 1, 0.10879715768509854`], 
        Hue[0.6433361223092663, 1, 0.1092269075717851], 
        Hue[0.6433360175588242, 1, 0.1092270526108588], 
        Hue[0.6436473955325628, 1, 0.10879591387799005`], 
        Hue[0.6441116193627917, 1, 0.10815314242074998`], 
        Hue[0.6499736137013089, 1, 0.10003653487511074`], 
        Hue[0.6471229934816762, 1, 0.1039835474869099], 
        Hue[0.6462649933796968, 1, 0.10517154762811219`], 
        Hue[0.6453869809034246, 1, 0.10638725721064288`], 
        Hue[0.6443765815752575, 1, 0.1077862716650282], 
        Hue[0.6429887403224448, 1, 0.10970789801507655`], 
        Hue[0.6406162192000339, 1, 0.11299292726149159`], 
        Hue[0.6364545540009836, 1, 0.1187552329217151], 
        Hue[0.6305924039164738, 1, 0.12687205611565178`], 
        Hue[0.625034954606874, 1, 0.1345669859289438], 
        Hue[0.630594812444056, 1, 0.12686872123130705`], 
        Hue[0.6364584596844344, 1, 0.11874982505232165`], 
        Hue[0.6471236667804864, 1, 0.10398261522701893`], 
        Hue[0.649859297955133, 1, 0.10019481821596983`], 
        Hue[0.6499735432029402, 1, 0.10003663248823669`], 
        Hue[0.6499852820270374, 1, 0.10002037873179444`], 
        Hue[0.6499166783476851, 1, 0.10011536844166691`], 
        Hue[0.6460136181206872, 1, 0.10551960567904847`], 
        Hue[0.6447122845415196, 1, 0.10732145217328057`], 
        Hue[0.6429887403224135, 1, 0.10970789801511988`], 
        Hue[0.6394886467886375, 1, 0.11455418136957889`], 
        Hue[0.6310134115394466, 1, 0.12628912248384325`], 
        Hue[0.6140784301117376, 1, 0.14973755830682497`], 
        Hue[0.5901149258211708, 1, 0.18291779501684047`], 
        Hue[0.6460145578411413, 1, 0.10551830452765065`], 
        Hue[0.647222100702996, 1, 0.10384632210354394`], 
        Hue[0.6496866431313958, 1, 0.1004338787411443], 
        Hue[0.6499164076341196, 1, 0.10011574327583449`], 
        Hue[0.6499852093278041, 1, 0.10002047939227128`], 
        Hue[0.6499944257549256, 1, 0.10000771818548765`], 
        Hue[0.6441102689755097, 1, 0.10815501218775583`], 
        Hue[0.6406162192, 1, 0.1129929272615385], 
        Hue[0.6310134115394676, 1, 0.1262891224838142], 
        Hue[0.6058582780000794, 1, 0.1611193073845055], 
        Hue[0.5584199878537663, 1, 0.22680309374093893`], 
        Hue[0.4978115944517789, 1, 0.3107224076821523], 
        Hue[0.6441116193627406, 1, 0.1081531424208207], 
        Hue[0.646089408291409, 1, 0.10541466544266438`], 
        Hue[0.6495107697330285, 1, 0.10067739575426836`], 
        Hue[0.6498463773044623, 1, 0.10021270834766764`], 
        Hue[0.6499646928280673, 1, 0.10004888685344528`], 
        Hue[0.6499943838807886, 1, 0.10000777616506201`], 
        Hue[0.6499985573975376, 1, 0.10000199744956326`], 
        Hue[0.6436464972273616, 1, 0.10879715768519174`], 
        Hue[0.636454554000992, 1, 0.11875523292170333`], 
        Hue[0.6140784301118009, 1, 0.1497375583067373], 
        Hue[0.558419987853781, 1, 0.2268030937409187], 
        Hue[0.4653501926787307, 1, 0.35566896398329606`], 
        Hue[0.6364584596846764, 1, 0.11874982505198657`], 
        Hue[0.6436473955326357, 1, 0.10879591387788896`], 
        Hue[0.6493021059490783, 1, 0.10096631483973767`], 
        Hue[0.6497718388043812, 1, 0.10031591550162612`], 
        Hue[0.6499425936539298, 1, 0.10007948570994339`], 
        Hue[0.6499892148045759, 1, 0.1000149333475103], 
        Hue[0.6499985427449788, 1, 0.10000201773772166`], 
        Hue[0.6433361223092463, 1, 0.10922690757181291`], 
        Hue[0.6305924039165115, 1, 0.12687205611559949`], 
        Hue[0.5901149258212088, 1, 0.18291779501678784`], 
        Hue[0.49781159445165823`, 1, 0.31072240768231946`], 
        Hue[0.6305948124445969, 1, 0.1268687212305581], 
        Hue[0.6433360175591031, 1, 0.10922705261047262`], 
        Hue[0.6489836000327963, 1, 0.10140732303151286`], 
        Hue[0.6496722119092204, 1, 0.10045386043338717`], 
        Hue[0.6499160398116123, 1, 0.10011625256853683`], 
        Hue[0.6499834211304725, 1, 0.10002295535780742`], 
        Hue[0.6499975345136633, 1, 0.1000034137503124], 
        Hue[0.6499997310457263, 1, 0.1000003723982252], 
        Hue[0.6499999644133952, 1, 0.10000004927376044`], 
        Hue[0.6250349546068943, 1, 0.13456698592891564`], 
        Hue[0.6494582860502358, 1, 0.10075006546890423`], 
        Hue[0.6498706375066219, 1, 0.10017911729852358`], 
        Hue[0.6499750001267647, 1, 0.10003461520909515`], 
        Hue[0.6499962208090388, 1, 0.10000523272594623`], 
        Hue[0.6499995658652175, 1, 0.10000060110969894`], 
        Hue[0.649999963849577, 1, 0.10000005005443176`], 
        Hue[0., 1, 1.], 
        Hue[0.649999963849577, 1, 0.10000005005443176`], 
        Hue[0.6499995658652175, 1, 0.10000060110969894`], 
        Hue[0.6499962208090388, 1, 0.10000523272594622`], 
        Hue[0.6499750001267646, 1, 0.10003461520909523`], 
        Hue[0.6498706375066201, 1, 0.10017911729852609`], 
        Hue[0.6494582860502159, 1, 0.10075006546893184`], 
        Hue[0.6250349546069032, 1, 0.1345669859289033], 
        Hue[0.6499999644133952, 1, 0.10000004927376044`], 
        Hue[0.6499997310457263, 1, 0.1000003723982252], 
        Hue[0.6499975345136633, 1, 0.1000034137503124], 
        Hue[0.6499834211304725, 1, 0.10002295535780739`], 
        Hue[0.6499160398116125, 1, 0.10011625256853654`], 
        Hue[0.6496722119092209, 1, 0.1004538604333865], 
        Hue[0.6489836000327871, 1, 0.10140732303152555`], 
        Hue[0.6433360175588241, 1, 0.10922705261085894`], 
        Hue[0.6305948124440502, 1, 0.12686872123131515`], 
        Hue[0.49781159445338463`, 1, 0.310722407679929], 
        Hue[0.5901149258219073, 1, 0.18291779501582073`], 
        Hue[0.6305924039163933, 1, 0.12687205611576322`], 
        Hue[0.6433361223090291, 1, 0.10922690757211345`], 
        Hue[0.6499985427449788, 1, 0.10000201773772166`], 
        Hue[0.6499892148045759, 1, 0.10001493334751028`], 
        Hue[0.6499425936539298, 1, 0.10007948570994334`], 
        Hue[0.6497718388043817, 1, 0.10031591550162536`], 
        Hue[0.6493021059490827, 1, 0.1009663148397318], 
        Hue[0.6436473955325627, 1, 0.10879591387799013`], 
        Hue[0.6364584596844316, 1, 0.11874982505232544`], 
        Hue[0.46535019268013794`, 1, 0.3556689639813475], 
        Hue[0.5584199878547623, 1, 0.22680309373955995`], 
        Hue[0.6140784301120935, 1, 0.14973755830633206`], 
        Hue[0.6364545540009346, 1, 0.11875523292178278`], 
        Hue[0.6436464972273148, 1, 0.10879715768525641`], 
        Hue[0.6499985573975376, 1, 0.10000199744956326`], 
        Hue[0.6499943838807886, 1, 0.10000777616506201`], 
        Hue[0.6499646928280673, 1, 0.10004888685344525`], 
        Hue[0.6498463773044624, 1, 0.10021270834766756`], 
        Hue[0.649510769733029, 1, 0.10067739575426754`], 
        Hue[0.6460894082914639, 1, 0.10541466544258854`], 
        Hue[0.6441116193627918, 1, 0.10815314242074982`], 
        Hue[0.49781159445338496`, 1, 0.3107224076799285], 
        Hue[0.5584199878547618, 1, 0.22680309373956073`], 
        Hue[0.6058582780004875, 1, 0.16111930738394037`], 
        Hue[0.6310134115395549, 1, 0.12628912248369326`], 
        Hue[0.6406162192000211, 1, 0.11299292726150936`], 
        Hue[0.6441102689755677, 1, 0.10815501218767563`], 
        Hue[0.6499944257549256, 1, 0.10000771818548763`], 
        Hue[0.6499852093278041, 1, 0.10002047939227127`], 
        Hue[0.6499164076341196, 1, 0.10011574327583443`], 
        Hue[0.6496866431313959, 1, 0.10043387874114416`], 
        Hue[0.6472221007030099, 1, 0.10384632210352472`], 
        Hue[0.646014557841179, 1, 0.10551830452759829`], 
        Hue[0.5901149258219057, 1, 0.1829177950158229], 
        Hue[0.6140784301120928, 1, 0.14973755830633298`], 
        Hue[0.6310134115395546, 1, 0.12628912248369367`], 
        Hue[0.6394886467886615, 1, 0.11455418136954568`], 
        Hue[0.6429887403224473, 1, 0.109707898015073], 
        Hue[0.6447122845415725, 1, 0.10732145217320734`], 
        Hue[0.6460136181207251, 1, 0.10551960567899599`], 
        Hue[0.6499166783476851, 1, 0.10011536844166684`], 
        Hue[0.6499852820270374, 1, 0.10002037873179442`], 
        Hue[0.6499735432029402, 1, 0.10003663248823666`], 
        Hue[0.649859297955133, 1, 0.10019481821596973`], 
        Hue[0.6471236667804908, 1, 0.10398261522701273`], 
        Hue[0.6364584596846646, 1, 0.11874982505200281`], 
        Hue[0.6305948124445522, 1, 0.12686872123062018`], 
        Hue[0.6250349546068997, 1, 0.1345669859289081], 
        Hue[0.6305924039163923, 1, 0.12687205611576466`], 
        Hue[0.6364545540009342, 1, 0.1187552329217834], 
        Hue[0.6406162192000208, 1, 0.11299292726150978`], 
        Hue[0.6429887403224471, 1, 0.10970789801507319`], 
        Hue[0.6443765815752722, 1, 0.10778627166500773`], 
        Hue[0.6453869809034444, 1, 0.10638725721061551`], 
        Hue[0.6462649933797096, 1, 0.10517154762809447`], 
        Hue[0.6471229934816807, 1, 0.10398354748690375`], 
        Hue[0.6499736137013089, 1, 0.10003653487511072`], 
        Hue[0.6441116193628278, 1, 0.1081531424207001], 
        Hue[0.6436473955327029, 1, 0.10879591387779611`], 
        Hue[0.6433360175591226, 1, 0.10922705261044566`], 
        Hue[0.6433361223090287, 1, 0.10922690757211413`], 
        Hue[0.6436464972273146, 1, 0.10879715768525677`], 
        Hue[0.6441102689755674, 1, 0.10815501218767593`], 
        Hue[0.6447122845415724, 1, 0.10732145217320749`], 
        Hue[0.6453869809034444, 1, 0.10638725721061548`], 
        Hue[0.6460502287342674, 1, 0.10546891406024508`], 
        Hue[0.6466655980999738, 1, 0.10461686416926702`], 
        Hue[0.6472836152052586, 1, 0.10376114817733438`], 
        Hue[0.6460145578411807, 1, 0.10551830452759606`], 
        Hue[0.6460894082914773, 1, 0.10541466544256996`], 
        Hue[0.6460136181207252, 1, 0.10551960567899595`], 
        Hue[0.6462649933797097, 1, 0.10517154762809428`], 
        Hue[0.6466655980999739, 1, 0.10461686416926684`], 
        Hue[0.6471111373540477, 1, 0.10399996366362627`], 
        Hue[0.6475804890154506, 1, 0.10335009213245296`], 
        Hue[0.6499739154396369, 1, 0.1000361170835797], 
        Hue[0.6471236667804907, 1, 0.10398261522701283`], 
        Hue[0.6472221007030102, 1, 0.10384632210352437`], 
        Hue[0.648983600032812, 1, 0.10140732303149122`], 
        Hue[0.6494582860502409, 1, 0.10075006546889727`], 
        Hue[0.6471229934816808, 1, 0.10398354748690349`], 
        Hue[0.6472836152052587, 1, 0.10376114817733417`], 
        Hue[0.6475804890154507, 1, 0.1033500921324529], 
        Hue[0.6495470248985343, 1, 0.10062719629433717`], 
        Hue[0.6498632426034409, 1, 0.10018935639523573`], 
        Hue[0.6499738433200122, 1, 0.10003621694152162`], 
        Hue[0.6499859694850614, 1, 0.1000194268668381], 
        Hue[0.6499231865672959, 1, 0.10010635706066735`], 
        Hue[0.6493021059490841, 1, 0.10096631483972977`], 
        Hue[0.6496722119092239, 1, 0.10045386043338231`], 
        Hue[0.6498706375066231, 1, 0.1001791172985219], 
        Hue[0.6493325519861006, 1, 0.10092415878847606`], 
        Hue[0.6497258842286484, 1, 0.10037954491417919`], 
        Hue[0.6499228820634163, 1, 0.1001067786814236], 
        Hue[0.6499858880248885, 1, 0.10001953965784668`], 
        Hue[0.6499951095696064, 1, 0.10000677136516045`], 
        Hue[0.6495107697330291, 1, 0.10067739575426747`], 
        Hue[0.6497718388043818, 1, 0.10031591550162516`], 
        Hue[0.6499160398116127, 1, 0.10011625256853622`], 
        Hue[0.6499750001267648, 1, 0.10003461520909494`], 
        Hue[0.6493325519861006, 1, 0.10092415878847612`], 
        Hue[0.6496719726032051, 1, 0.10045419178017764`], 
        Hue[0.649883813694463, 1, 0.10016087334612823`], 
        Hue[0.6499709105190519, 1, 0.10004027774285129`], 
        Hue[0.6499950637214474, 1, 0.10000683484722674`], 
        Hue[0.6496866431313958, 1, 0.10043387874114428`], 
        Hue[0.6498463773044624, 1, 0.10021270834766757`], 
        Hue[0.6499425936539298, 1, 0.10007948570994332`], 
        Hue[0.6499834211304725, 1, 0.10002295535780736`], 
        Hue[0.6499962208090388, 1, 0.1000052327259462], 
        Hue[0.6495470248985342, 1, 0.10062719629433724`], 
        Hue[0.6497258842286484, 1, 0.10037954491417923`], 
        Hue[0.6498838136944629, 1, 0.10016087334612825`], 
        Hue[0.6499655474797963, 1, 0.10004770348951282`], 
        Hue[0.6499926958443384, 1, 0.10001011344630079`], 
        Hue[0.6499989027437987, 1, 0.1000015192778172], 
        Hue[0.6499231865672959, 1, 0.10010635706066733`], 
        Hue[0.6498592979551329, 1, 0.10019481821596984`], 
        Hue[0.6499164076341195, 1, 0.10011574327583449`], 
        Hue[0.6499646928280673, 1, 0.10004888685344526`], 
        Hue[0.6499892148045759, 1, 0.1000149333475103], 
        Hue[0.6499975345136633, 1, 0.1000034137503124], 
        Hue[0.6499995658652175, 1, 0.10000060110969894`], 
        Hue[0.6499166783476851, 1, 0.10011536844166684`], 
        Hue[0.6498632426034409, 1, 0.10018935639523575`], 
        Hue[0.6499228820634163, 1, 0.10010677868142362`], 
        Hue[0.6499709105190519, 1, 0.10004027774285129`], 
        Hue[0.6499926958443384, 1, 0.1000101134463008], 
        Hue[0.6499987284592187, 1, 0.10000176059492807`], 
        Hue[0.6499998410900942, 1, 0.10000022002910035`], 
        Hue[0.6499999852765213, 1, 0.10000002038635529`], 
        Hue[0.6499951095696064, 1, 0.10000677136516044`], 
        Hue[0.6499859694850614, 1, 0.10001942686683808`], 
        Hue[0.6499739154396369, 1, 0.1000361170835797], 
        Hue[0.6499735432029402, 1, 0.10003663248823669`], 
        Hue[0.6499852093278041, 1, 0.10002047939227128`], 
        Hue[0.6499943838807886, 1, 0.10000777616506201`], 
        Hue[0.6499985427449788, 1, 0.10000201773772166`], 
        Hue[0.6499997310457263, 1, 0.1000003723982252], 
        Hue[0.649999963849577, 1, 0.10000005005443176`], 
        Hue[0.6499999644133952, 1, 0.10000004927376044`], 
        Hue[0.6499985573975376, 1, 0.10000199744956326`], 
        Hue[0.6499944257549256, 1, 0.10000771818548763`], 
        Hue[0.6499852820270374, 1, 0.10002037873179442`], 
        Hue[0.6499736137013089, 1, 0.10003653487511072`], 
        Hue[0.6499738433200122, 1, 0.10003621694152164`], 
        Hue[0.6499858880248885, 1, 0.10001953965784668`], 
        Hue[0.6499950637214474, 1, 0.10000683484722674`], 
        Hue[0.6499989027437987, 1, 0.1000015192778172], 
        Hue[0.6499998410900942, 1, 0.10000022002910035`], 
        Hue[0.6499999849238686, 1, 0.10000002087464362`], 
        Hue[0.6499999965856617, 1, 0.10000000472754546`], 
        Hue[0.6499999480469419, 1, 0.10000007193500345`], 
        Hue[0.6499999480469419, 1, 0.10000007193500345`], 
        Hue[0.6499999965856617, 1, 0.10000000472754546`], 
        Hue[0.6499999509486679, 1, 0.10000006791722911`], 
        Hue[0.6499995605902448, 1, 0.10000060841350733`], 
        Hue[0.6499995314220489, 1, 0.10000064880024004`], 
        Hue[0.6499975387906934, 1, 0.10000340782827066`], 
        Hue[0.6499970370468677, 1, 0.10000410255049084`], 
        Hue[0.649991166860452, 1, 0.10001223050091258`], 
        Hue[0.6499873787655159, 1, 0.10001747555543954`], 
        Hue[0.6499797890669986, 1, 0.10002798436877125`], 
        Hue[0.6499650867010297, 1, 0.10004834149088197`], 
        Hue[0.6499365186637519, 1, 0.10008789723480505`], 
        Hue[0.6499660419264217, 1, 0.10004701887110848`], 
        Hue[0.6499660352996491, 1, 0.10004702804663976`], 
        Hue[0.6499689720806963, 1, 0.10004296173442062`], 
        Hue[0.6499793572109922, 1, 0.10002858232324167`], 
        Hue[0.6499904847358855, 1, 0.10001317498108164`], 
        Hue[0.6499630030101804, 1, 0.10005122660128868`], 
        Hue[0.649997032693306, 1, 0.10000410857849946`], 
        Hue[0.6499997344623704, 1, 0.10000036766748721`], 
        Hue[0.6499999234519708, 1, 0.10000010598957898`], 
        Hue[0.6499999917956835, 1, 0.10000001135982291`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499999878784672, 1, 0.1000000167836607], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499999916279817, 1, 0.10000001159202533`], 
        Hue[0.6499998974223291, 1, 0.10000014203062124`], 
        Hue[0.6499998686930739, 1, 0.10000018180959001`], 
        Hue[0.6499999222917153, 1, 0.10000010759608655`], 
        Hue[0.6499993483460993, 1, 0.10000090229001642`], 
        Hue[0.6499991515859967, 1, 0.10000117472708145`], 
        Hue[0.6499970064878591, 1, 0.10000414486296436`], 
        Hue[0.6499958569645508, 1, 0.10000573651062201`], 
        Hue[0.6499904256749581, 1, 0.10001325675775032`], 
        Hue[0.6499852021769049, 1, 0.10002048929351634`], 
        Hue[0.6499792798726709, 1, 0.10002868940707105`], 
        Hue[0.6499628521968075, 1, 0.10005143541980506`], 
        Hue[0.6499353113077606, 1, 0.1000895689584853], 
        Hue[0.6499660027761931, 1, 0.10004707307911731`], 
        Hue[0.6499660613044453, 1, 0.10004699203999874`], 
        Hue[0.6499690957937134, 1, 0.10004279043947381`], 
        Hue[0.6499798735525514, 1, 0.100027867388775], 
        Hue[0.6499912329900899, 1, 0.10001213893679865`], 
        Hue[0.6499989171085051, 1, 0.10000149938822367`], 
        Hue[0.6499998438351633, 1, 0.10000021622823552`], 
        Hue[0.6499999966971565, 1, 0.10000000457316796`], 
        Hue[0.6499999966971565, 1, 0.10000000457316796`], 
        Hue[0.6499995314220489, 1, 0.10000064880024004`], 
        Hue[0.6499995605902448, 1, 0.10000060841350733`], 
        Hue[0.6499999509486679, 1, 0.10000006791722911`], 
        Hue[0.6499968197541345, 1, 0.10000440341735237`], 
        Hue[0.6499968197541345, 1, 0.10000440341735237`], 
        Hue[0.6499846921337001, 1, 0.10002119550718443`], 
        Hue[0.6499834669215924, 1, 0.10002289195471835`], 
        Hue[0.6499501069361, 1, 0.10006908270386163`], 
        Hue[0.6499391582420061, 1, 0.10008424243414546`], 
        Hue[0.6498923240356159, 1, 0.10014908979683958`], 
        Hue[0.6498470503888287, 1, 0.10021177638469872`], 
        Hue[0.6497372360371154, 1, 0.10036382702553248`], 
        Hue[0.6498246858302774, 1, 0.10024274269653898`], 
        Hue[0.6498595392714196, 1, 0.10019448408572672`], 
        Hue[0.6498872063550267, 1, 0.10015617581611685`], 
        Hue[0.6499648695962024, 1, 0.10004864209756598`], 
        Hue[0.6499892896045865, 1, 0.10001482977826487`], 
        Hue[0.6499995706076633, 1, 0.10000059454323541`], 
        Hue[0.6499998222703252, 1, 0.1000002460872421], 
        Hue[0.6499998205406813, 1, 0.10000024848213372`], 
        Hue[0.6499989347644688, 1, 0.1000014749415048], 
        Hue[0.649998672028374, 1, 0.10000183872994367`], 
        Hue[0.6499946619760952, 1, 0.10000739111002195`], 
        Hue[0.6499933666375028, 1, 0.10000918465576535`], 
        Hue[0.6499797258816096, 1, 0.100028071856233], 
        Hue[0.6499741382710061, 1, 0.10003580854783767`], 
        Hue[0.6499433111349449, 1, 0.10007849227469179`], 
        Hue[0.6499231631029164, 1, 0.10010638954980806`], 
        Hue[0.6498869310750488, 1, 0.10015655697300938`], 
        Hue[0.6498302874016713, 1, 0.10023498667460903`], 
        Hue[0.6495193091275062, 1, 0.10066557197729911`], 
        Hue[0.6498258485023254, 1, 0.10024113284293408`], 
        Hue[0.6498634903348335, 1, 0.10018901338253836`], 
        Hue[0.6498926261234818, 1, 0.10014867152133293`], 
        Hue[0.6499711016483095, 1, 0.10004001310234079`], 
        Hue[0.6499998438351633, 1, 0.10000021622823552`], 
        Hue[0.6499970370468677, 1, 0.10000410255049084`], 
        Hue[0.6499975387906934, 1, 0.10000340782827066`], 
        Hue[0.6499834669215924, 1, 0.10002289195471835`], 
        Hue[0.6499846921337001, 1, 0.10002119550718443`], 
        Hue[0.6499339441898728, 1, 0.10009146189094531`], 
        Hue[0.6499339441898728, 1, 0.10009146189094531`], 
        Hue[0.6498131704790807, 1, 0.10025868702896522`], 
        Hue[0.6497964648039245, 1, 0.10028181796379686`], 
        Hue[0.6495530687696348, 1, 0.10061882785742883`], 
        Hue[0.6494292804404583, 1, 0.1007902270824424], 
        Hue[0.6495197235700737, 1, 0.10066499813374416`], 
        Hue[0.6496872006198551, 1, 0.10043310683404684`], 
        Hue[0.6498468322258638, 1, 0.10021207845649631`], 
        Hue[0.6499962490896035, 1, 0.10000519356824138`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499751193911049, 1, 0.10003445007385486`], 
        Hue[0.6499981815209614, 1, 0.10000251789405334`], 
        Hue[0.649991888260414, 1, 0.10001123163942685`], 
        Hue[0.6499899581044661, 1, 0.10001390416304694`], 
        Hue[0.649968151589994, 1, 0.10004409779846983`], 
        Hue[0.6499613986682437, 1, 0.10005344799781657`], 
        Hue[0.6499029637901637, 1, 0.1001343578290042], 
        Hue[0.6498815309986415, 1, 0.100164034001881], 
        Hue[0.6497727314760293, 1, 0.10031467949472868`], 
        Hue[0.6497158718365242, 1, 0.10039340822635104`], 
        Hue[0.6491676275232411, 1, 0.10115251573705085`], 
        Hue[0.6494394618677293, 1, 0.10077612972160567`], 
        Hue[0.6495474566380963, 1, 0.1006265985010974], 
        Hue[0.6497265096835253, 1, 0.1003786788997342], 
        Hue[0.6498842956213006, 1, 0.10016020606281466`], 
        Hue[0.6499989171085051, 1, 0.10000149938822367`], 
        Hue[0.6499975662514333, 1, 0.10000336980570772`], 
        Hue[0.6499873787655159, 1, 0.10001747555543954`], 
        Hue[0.649991166860452, 1, 0.10001223050091258`], 
        Hue[0.6499391582420061, 1, 0.10008424243414546`], 
        Hue[0.6499501069361, 1, 0.10006908270386163`], 
        Hue[0.6497964648039245, 1, 0.10028181796379684`], 
        Hue[0.6498131704790807, 1, 0.10025868702896522`], 
        Hue[0.6495129010015269, 1, 0.10067444476711664`], 
        Hue[0.6495129010015269, 1, 0.10067444476711662`], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6498709896006915, 1, 0.100178629783658], 
        Hue[0.6499859604962616, 1, 0.1000194393128687], 
        Hue[0.6499533005675091, 1, 0.10006466075267968`], 
        Hue[0.649941462651146, 1, 0.1000810517137978], 
        Hue[0.6498573946453188, 1, 0.1001974535680202], 
        Hue[0.649828893698698, 1, 0.10023691641718743`], 
        Hue[0.6496559963280033, 1, 0.1004763127766109], 
        Hue[0.6495884346066919, 1, 0.10056985977534973`], 
        Hue[0.6488022469143933, 1, 0.10165842734930168`], 
        Hue[0.6487517211908194, 1, 0.10172838604348085`], 
        Hue[0.6488011994693257, 1, 0.10165987765785683`], 
        Hue[0.6489976573214437, 1, 0.10138785909338578`], 
        Hue[0.6493332016432399, 1, 0.10092325926320626`], 
        Hue[0.6498842956213006, 1, 0.10016020606281463`], 
        Hue[0.6497265096835254, 1, 0.10037867889973409`], 
        Hue[0.6499711016483095, 1, 0.10004001310234076`], 
        Hue[0.6499503668772793, 1, 0.10006872278530574`], 
        Hue[0.6499912329900899, 1, 0.10001213893679864`], 
        Hue[0.6499650867010297, 1, 0.10004834149088197`], 
        Hue[0.6499797890669986, 1, 0.10002798436877125`], 
        Hue[0.6498470503888287, 1, 0.10021177638469872`], 
        Hue[0.6498923240356159, 1, 0.10014908979683958`], 
        Hue[0.6495530687696348, 1, 0.10061882785742882`], 
        Hue[0.6499289484739935, 1, 0.10009837903600899`], 
        Hue[0.6494589962075535, 1, 0.10074908217415667`], 
        Hue[0.6499147887623509, 1, 0.10011798479059121`], 
        Hue[0.6497916794686949, 1, 0.10028844381257641`], 
        Hue[0.6497289407483949, 1, 0.1003753128099147], 
        Hue[0.6495085615470422, 1, 0.10068045324255707`], 
        Hue[0.6494073982064067, 1, 0.10082052556035999`], 
        Hue[0.6483053260376217, 1, 0.10234647164021618`], 
        Hue[0.6483163987955445, 1, 0.1023311401292462], 
        Hue[0.6480161564309219, 1, 0.10274686032641583`], 
        Hue[0.6479796182166929, 1, 0.10279745169996367`], 
        Hue[0.6481284893528518, 1, 0.10259132243451285`], 
        Hue[0.6483958281620501, 1, 0.1022211610063922], 
        Hue[0.64933320164324, 1, 0.10092325926320615`], 
        Hue[0.6489976573214438, 1, 0.10138785909338563`], 
        Hue[0.6495474566380964, 1, 0.1006265985010973], 
        Hue[0.6498634903348335, 1, 0.1001890133825383], 
        Hue[0.6499798735525514, 1, 0.10002786738877499`], 
        Hue[0.6499365186637519, 1, 0.10008789723480505`], 
        Hue[0.6497372360371154, 1, 0.10036382702553247`], 
        Hue[0.6489846669012644, 1, 0.10140584582901847`], 
        Hue[0.6473523532851713, 1, 0.10366597237437833`], 
        Hue[0.6496234965987956, 1, 0.10052131240166763`], 
        Hue[0.6480476331533843, 1, 0.1027032771722371], 
        Hue[0.6495819204902942, 1, 0.10057887932113115`], 
        Hue[0.6492559152561154, 1, 0.10103027118384031`], 
        Hue[0.6480467041527054, 1, 0.10270456348086947`], 
        Hue[0.6473513706733502, 1, 0.10366733291382275`], 
        Hue[0.6476433233638824, 1, 0.10326309072693203`], 
        Hue[0.6473931627551948, 1, 0.10360946695434578`], 
        Hue[0.647134233734633, 1, 0.10396798405973895`], 
        Hue[0.6472841430793683, 1, 0.10376041727472078`], 
        Hue[0.6475809298216182, 1, 0.10334948178545172`], 
        Hue[0.6483958281620502, 1, 0.10222116100639211`], 
        Hue[0.6481284893528518, 1, 0.10259132243451291`], 
        Hue[0.6488011994693256, 1, 0.10165987765785686`], 
        Hue[0.6494394618677293, 1, 0.10077612972160571`], 
        Hue[0.6498258485023254, 1, 0.10024113284293411`], 
        Hue[0.6499660613044453, 1, 0.10004699203999876`], 
        Hue[0.6499660419264217, 1, 0.10004701887110848`], 
        Hue[0.6465822717265688, 1, 0.1047322391478279], 
        Hue[0.6462861242777479, 1, 0.10514228946157993`], 
        Hue[0.6460011934807784, 1, 0.10553680902661455`], 
        Hue[0.6462658582790937, 1, 0.10517035007510118`], 
        Hue[0.6466661863103492, 1, 0.10461604972413183`], 
        Hue[0.6475809298216181, 1, 0.10334948178545186`], 
        Hue[0.6472841430793674, 1, 0.10376041727472206`], 
        Hue[0.6479796182166926, 1, 0.1027974516999641], 
        Hue[0.6487517211908193, 1, 0.10172838604348111`], 
        Hue[0.6499875583936996, 1, 0.10001722683949292`], 
        Hue[0.6499660352996491, 1, 0.10004702804663974`], 
        Hue[0.6499689720806963, 1, 0.10004296173442062`], 
        Hue[0.6499875752276579, 1, 0.10001720353093523`], 
        Hue[0.6498246858302774, 1, 0.10024274269653896`], 
        Hue[0.6498595392714196, 1, 0.1001944840857267], 
        Hue[0.6494292804404583, 1, 0.10079022708244238`], 
        Hue[0.6495197235700737, 1, 0.10066499813374416`], 
        Hue[0.6450459043341157, 1, 0.10685951707583985`], 
        Hue[0.6449078143256106, 1, 0.10705071862607762`], 
        Hue[0.644397187686445, 1, 0.1077577401264608], 
        Hue[0.6439515530904346, 1, 0.10837477264401368`], 
        Hue[0.6438587986192775, 1, 0.10850320191176961`], 
        Hue[0.6427201663461681, 1, 0.1100797696745365], 
        Hue[0.6434731972963169, 1, 0.10903711143586889`], 
        Hue[0.6410125786951648, 1, 0.11244412180669497`], 
        Hue[0.6388740031493004, 1, 0.11540522640866098`], 
        Hue[0.6431577560121023, 1, 0.10947387629093527`], 
        Hue[0.6432314603305186, 1, 0.10937182415774348`], 
        Hue[0.6434736200020822, 1, 0.10903652615096315`], 
        Hue[0.6438600147950488, 1, 0.10850151797608631`], 
        Hue[0.6447135116824771, 1, 0.10731975305503161`], 
        Hue[0.6453879602649294, 1, 0.10638590117163631`], 
        Hue[0.6466661863103472, 1, 0.1046160497241347], 
        Hue[0.646265858279081, 1, 0.10517035007511863`], 
        Hue[0.6471786129927855, 1, 0.10390653585614328`], 
        Hue[0.6480161564309208, 1, 0.10274686032641733`], 
        Hue[0.6499660027761931, 1, 0.10004707307911734`], 
        Hue[0.6499793572109922, 1, 0.10002858232324166`], 
        Hue[0.6498872063550267, 1, 0.10015617581611685`], 
        Hue[0.6496872006198551, 1, 0.10043310683404687`], 
        Hue[0.6449078143255991, 1, 0.10705071862609364`], 
        Hue[0.6450459043340817, 1, 0.10685951707588696`], 
        Hue[0.6437573464570181, 1, 0.10864367413643647`], 
        Hue[0.6437573464570021, 1, 0.10864367413645863`], 
        Hue[0.6419793946935759, 1, 0.11110545350120263`], 
        Hue[0.6416150548927508, 1, 0.11160992399465273`], 
        Hue[0.6387923231016593, 1, 0.11551832185924087`], 
        Hue[0.6370814322963922, 1, 0.1178872475896108], 
        Hue[0.6336566410847779, 1, 0.12262926619030753`], 
        Hue[0.6282683067128656, 1, 0.13009003685910922`], 
        Hue[0.6155545287377167, 1, 0.14769372944008474`], 
        Hue[0.6250352667022192, 1, 0.13456655379692734`], 
        Hue[0.6275873411445113, 1, 0.1310329122614459], 
        Hue[0.6336600539028828, 1, 0.1226245407498546], 
        Hue[0.6406195765724375, 1, 0.11298827859200967`], 
        Hue[0.6429908696471925, 1, 0.10970494971927194`], 
        Hue[0.6453879602649129, 1, 0.10638590117165914`], 
        Hue[0.6447135116824265, 1, 0.10731975305510176`], 
        Hue[0.6461108778787858, 1, 0.10538493832168114`], 
        Hue[0.6471342337346244, 1, 0.1039679840597509], 
        Hue[0.6483163987955415, 1, 0.10233114012925029`], 
        Hue[0.6495193091275061, 1, 0.10066557197729935`], 
        Hue[0.6497261232417286, 1, 0.10037921397299124`], 
        Hue[0.6499353113077606, 1, 0.10008956895848536`], 
        Hue[0.6498869310750488, 1, 0.10015655697300946`], 
        Hue[0.6499792798726709, 1, 0.10002868940707106`], 
        Hue[0.6499630030101804, 1, 0.10005122660128868`], 
        Hue[0.6499904847358855, 1, 0.10001317498108164`], 
        Hue[0.6499648695962024, 1, 0.10004864209756599`], 
        Hue[0.6498468322258637, 1, 0.10021207845649638`], 
        Hue[0.6439515530903862, 1, 0.1083747726440807], 
        Hue[0.6443971876863692, 1, 0.10775774012656568`], 
        Hue[0.6416150548927391, 1, 0.11160992399466907`], 
        Hue[0.6419793946935369, 1, 0.11110545350125665`], 
        Hue[0.6361335930405146, 1, 0.11919964040544136`], 
        Hue[0.6361335930405176, 1, 0.1191996404054371], 
        Hue[0.623696762682929, 1, 0.1364198670544061], 
        Hue[0.621035954087277, 1, 0.14010406357146268`], 
        Hue[0.6025635060503066, 1, 0.1656812993149601], 
        Hue[0.591356231466683, 1, 0.18119906412305425`], 
        Hue[0.5511449764429753, 1, 0.23687618646357272`], 
        Hue[0.55917054482559, 1, 0.22576386101072146`], 
        Hue[0.568122959888174, 1, 0.21336820938560533`], 
        Hue[0.5901231464870408, 1, 0.18290641255640516`], 
        Hue[0.6140905734391747, 1, 0.14972074446883504`], 
        Hue[0.6310228082209636, 1, 0.12627611169405048`], 
        Hue[0.6429908696471691, 1, 0.1097049497193044], 
        Hue[0.6406195765724637, 1, 0.11298827859197333`], 
        Hue[0.6443985210226438, 1, 0.10775589396864699`], 
        Hue[0.6460011934807279, 1, 0.10553680902668437`], 
        Hue[0.6476433233638594, 1, 0.10326309072696392`], 
        Hue[0.6491676275232406, 1, 0.10115251573705152`], 
        Hue[0.6494692059492381, 1, 0.1007349456087473], 
        Hue[0.6498302874016711, 1, 0.10023498667460914`], 
        Hue[0.6497727314760292, 1, 0.10031467949472883`], 
        Hue[0.6499628521968075, 1, 0.1000514354198051], 
        Hue[0.6499433111349449, 1, 0.10007849227469183`], 
        Hue[0.6499904256749581, 1, 0.10001325675775032`], 
        Hue[0.649997032693306, 1, 0.10000410857849946`], 
        Hue[0.6499892896045865, 1, 0.10001482977826487`], 
        Hue[0.6427201663461, 1, 0.11007976967463086`], 
        Hue[0.6438587986191934, 1, 0.1085032019118861], 
        Hue[0.6370814322963932, 1, 0.11788724758960933`], 
        Hue[0.6387923231016436, 1, 0.11551832185926283`], 
        Hue[0.6210359540872956, 1, 0.14010406357143684`], 
        Hue[0.6236967626829744, 1, 0.1364198670543432], 
        Hue[0.5848239391333233, 1, 0.19024377658462932`], 
        Hue[0.5848239391333415, 1, 0.19024377658460404`], 
        Hue[0.5284611999947693, 1, 0.2682844923149349], 
        Hue[0.5155200401453298, 1, 0.2862030213372357], 
        Hue[0.4280417126309771, 1, 0.4073268594340317], 
        Hue[0.44738231990342936`, 1, 0.3805475570567901], 
        Hue[0.49782834784076413`, 1, 0.31069921068201894`], 
        Hue[0.5584448138850497, 1, 0.22676871923608494`], 
        Hue[0.631022808221062, 1, 0.12627611169391412`], 
        Hue[0.6140905734395959, 1, 0.14972074446825182`], 
        Hue[0.6387961530918295, 1, 0.11551301879592843`], 
        Hue[0.6438600147950412, 1, 0.10850151797609685`], 
        Hue[0.646582271726557, 1, 0.1047322391478442], 
        Hue[0.6488022469143883, 1, 0.10165842734930862`], 
        Hue[0.6492111455095844, 1, 0.10109226006365249`], 
        Hue[0.649715871836524, 1, 0.10039340822635136`], 
        Hue[0.6496559963280025, 1, 0.10047631277661184`], 
        Hue[0.6499231631029164, 1, 0.10010638954980812`], 
        Hue[0.6499029637901635, 1, 0.10013435782900432`], 
        Hue[0.6499852021769049, 1, 0.10002048929351635`], 
        Hue[0.6499797258816095, 1, 0.10002807185623301`], 
        Hue[0.6499970064878591, 1, 0.10000414486296437`], 
        Hue[0.6499997344623704, 1, 0.10000036766748721`], 
        Hue[0.6410125786951287, 1, 0.11244412180674491`], 
        Hue[0.6434731972962738, 1, 0.10903711143592851`], 
        Hue[0.6282683067129132, 1, 0.13009003685904325`], 
        Hue[0.633656641084807, 1, 0.12262926619026732`], 
        Hue[0.591356231466732, 1, 0.18119906412298648`], 
        Hue[0.6025635060503691, 1, 0.16568129931487363`], 
        Hue[0.5155200401453158, 1, 0.28620302133725506`], 
        Hue[0.5284611999947402, 1, 0.26828449231497525`], 
        Hue[0.28735888634961493`, 1, 0.6021184650543793], 
        Hue[0.26072995684233446`, 1, 0.6389892905259984], 
        Hue[0.2873725448605462, 1, 0.602099553270013], 
        Hue[0.3624655433976934, 1, 0.4981246322185784], 
        Hue[0.5584448138855233, 1, 0.22676871923542932`], 
        Hue[0.4978283478418999, 1, 0.3106992106804463], 
        Hue[0.5901231464879024, 1, 0.18290641255521203`], 
        Hue[0.6336600539032805, 1, 0.12262454074930401`], 
        Hue[0.6434736200022606, 1, 0.10903652615071605`], 
        Hue[0.6483053260376065, 1, 0.10234647164023727`], 
        Hue[0.6488831338517029, 1, 0.10154643005148822`], 
        Hue[0.6495884346066901, 1, 0.1005698597753521], 
        Hue[0.6495085615470396, 1, 0.10068045324256061`], 
        Hue[0.6498815309986413, 1, 0.10016403400188124`], 
        Hue[0.6498573946453183, 1, 0.10019745356802079`], 
        Hue[0.6499741382710061, 1, 0.1000358085478377], 
        Hue[0.649968151589994, 1, 0.10004409779846989`], 
        Hue[0.6499958569645508, 1, 0.10000573651062203`], 
        Hue[0.6499946619760952, 1, 0.10000739111002195`], 
        Hue[0.6499993483460993, 1, 0.10000090229001643`], 
        Hue[0.6499999234519708, 1, 0.10000010598957898`], 
        Hue[0.6489846669012489, 1, 0.10140584582904005`], 
        Hue[0.6473523532851375, 1, 0.10366597237442497`], 
        Hue[0.6388740031493075, 1, 0.1154052264086511], 
        Hue[0.6155545287377708, 1, 0.14769372944000964`], 
        Hue[0.5511449764429537, 1, 0.2368761864636027], 
        Hue[0.2335219919339223, 1, 0.6766618573222615], 
        Hue[0.1499765696284696, 1, 0.7923401343605806], 
        Hue[0.14997656962768036`, 1, 0.7923401343616734], 
        Hue[0.12170305563956019`, 1, 0.8314880768067628], 
        Hue[0.06372301272420777, 1, 0.91176813622802], 
        Hue[0.15000883322846736`, 1, 0.7922954616836606], 
        Hue[0.2335584141616424, 1, 0.6766114265454182], 
        Hue[0.06375799796092974, 1, 0.9117196951310205], 
        Hue[0.1500088332269906, 1, 0.7922954616857053], 
        Hue[0.36246554339828446`, 1, 0.49812463221775993`], 
        Hue[0.28737254486065156`, 1, 0.6020995532698671], 
        Hue[0.44738231990483157`, 1, 0.38054755705484866`], 
        Hue[0.5681229598892839, 1, 0.21336820938406859`], 
        Hue[0.6250352667028372, 1, 0.13456655379607163`], 
        Hue[0.6431577560124171, 1, 0.10947387629049946`], 
        Hue[0.6473513706734314, 1, 0.10366733291371037`], 
        Hue[0.6483330201390716, 1, 0.10230812596128551`], 
        Hue[0.649407398206408, 1, 0.10082052556035821`], 
        Hue[0.6492559152561338, 1, 0.1010302711838148], 
        Hue[0.6498288936986976, 1, 0.10023691641718807`], 
        Hue[0.649791679468696, 1, 0.1002884438125748], 
        Hue[0.6499613986682435, 1, 0.10005344799781668`], 
        Hue[0.6499533005675091, 1, 0.10006466075267974`], 
        Hue[0.6499933666375028, 1, 0.10000918465576536`], 
        Hue[0.649991888260414, 1, 0.10001123163942686`], 
        Hue[0.6499991515859967, 1, 0.10000117472708145`], 
        Hue[0.6499989347644688, 1, 0.10000147494150481`], 
        Hue[0.6499999222917153, 1, 0.10000010759608655`], 
        Hue[0.6499998974223291, 1, 0.10000014203062124`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999917956835, 1, 0.10000001135982291`], 
        Hue[0.6499995706076633, 1, 0.10000059454323541`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499962490896035, 1, 0.10000519356824139`], 
        Hue[0.6499751193911047, 1, 0.10003445007385507`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6498709896006902, 1, 0.10017862978365968`], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.6494589962075485, 1, 0.10074908217416359`], 
        Hue[0.6499289484739933, 1, 0.10009837903600931`], 
        Hue[0.6480476331533758, 1, 0.10270327717224897`], 
        Hue[0.6496234965987948, 1, 0.10052131240166877`], 
        Hue[0.28735888634874723`, 1, 0.6021184650555808], 
        Hue[0.2607299568411386, 1, 0.6389892905276543], 
        Hue[0.10026584227806645`, 1, 0.8611703722303696], 
        Hue[0.12170305563831785`, 1, 0.8314880768084829], 
        Hue[0.03305932787493082, 1, 0.9542255460193266], 
        Hue[0.03305932787447774, 1, 0.9542255460199538], 
        Hue[0.04091504616611452, 1, 0.9433483976161491], 
        Hue[0.008564162898874406, 1, 0.9881419282938663], 
        Hue[0.1003038852266922, 1, 0.8611176973784263], 
        Hue[0.03305932787175336, 1, 0.9542255460237261], 
        Hue[0.12170305563598427`, 1, 0.831488076811714], 
        Hue[0.26072995684171757`, 1, 0.6389892905268526], 
        Hue[0.4280417126324545, 1, 0.4073268594319861], 
        Hue[0.5591705448267148, 1, 0.2257638610091642], 
        Hue[0.6480467041528128, 1, 0.10270456348072075`], 
        Hue[0.6489583372556369, 1, 0.10144230226142584`], 
        Hue[0.6497289407484016, 1, 0.10037531280990554`], 
        Hue[0.649623496598795, 1, 0.10052131240166845`], 
        Hue[0.6499414626511464, 1, 0.10008105171379728`], 
        Hue[0.6499289484739933, 1, 0.1000983790360093], 
        Hue[0.6499899581044661, 1, 0.10001390416304694`], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.649998672028374, 1, 0.10000183872994367`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499998686930739, 1, 0.10000018180959001`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499999916279817, 1, 0.10000001159202533`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499999878784672, 1, 0.1000000167836607], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499998205406813, 1, 0.10000024848213372`], 
        Hue[0.6499981815209614, 1, 0.10000251789405334`], 
        Hue[0.6499859604962616, 1, 0.10001943931286872`], 
        Hue[0.6499147887623508, 1, 0.10011798479059132`], 
        Hue[0.649581920490294, 1, 0.10057887932113145`], 
        Hue[0.5591705448254737, 1, 0.22576386101088267`], 
        Hue[0.568122959888075, 1, 0.21336820938574236`], 
        Hue[0.4280417126304372, 1, 0.4073268594347793], 
        Hue[0.44738231990300226`, 1, 0.3805475570573815], 
        Hue[0.2873725448596086, 1, 0.6020995532713111], 
        Hue[0.15000883322750808`, 1, 0.7922954616849889], 
        Hue[0.008564162898749728, 1, 0.9881419282940389], 
        Hue[0.0637579979606423, 1, 0.9117196951314183], 
        Hue[0.00856416289715567, 1, 0.988141928296246], 
        Hue[0.0330593278718706, 1, 0.9542255460235638], 
        Hue[0.0637230127197419, 1, 0.9117681362342035], 
        Hue[0.14997656962507233`, 1, 0.7923401343652845], 
        Hue[0.28735888634955103`, 1, 0.6021184650544679], 
        Hue[0.649458996207529, 1, 0.10074908217419068`], 
        Hue[0.6498709896006885, 1, 0.10017862978366218`], 
        Hue[0.6499751193911046, 1, 0.10003445007385516`], 
        Hue[0.6499962490896035, 1, 0.10000519356824138`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499995706076633, 1, 0.10000059454323541`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499999880630696, 1, 0.10000001652805754`], 
        Hue[0.6499998686930739, 1, 0.10000018180959001`], 
        Hue[0.6499998974223291, 1, 0.10000014203062124`], 
        Hue[0.6499999916279817, 1, 0.10000001159202533`], 
        Hue[0.649998672028374, 1, 0.10000183872994367`], 
        Hue[0.6499989347644688, 1, 0.1000014749415048], 
        Hue[0.6499899581044661, 1, 0.10001390416304694`], 
        Hue[0.649991888260414, 1, 0.10001123163942685`], 
        Hue[0.649941462651146, 1, 0.10008105171379782`], 
        Hue[0.6499533005675091, 1, 0.10006466075267968`], 
        Hue[0.6497289407483949, 1, 0.10037531280991473`], 
        Hue[0.6497916794686949, 1, 0.10028844381257641`], 
        Hue[0.6480467041527056, 1, 0.10270456348086918`], 
        Hue[0.6492559152561154, 1, 0.10103027118384024`], 
        Hue[0.6431577560121026, 1, 0.10947387629093487`], 
        Hue[0.6432314603305186, 1, 0.10937182415774356`], 
        Hue[0.6250352667022085, 1, 0.13456655379694196`], 
        Hue[0.6275873411445028, 1, 0.1310329122614577], 
        Hue[0.5901231464869925, 1, 0.18290641255647203`], 
        Hue[0.4978283478405595, 1, 0.3106992106823023], 
        Hue[0.3624655433972453, 1, 0.4981246322191988], 
        Hue[0.1003038852272069, 1, 0.8611176973777135], 
        Hue[0.23355841416119505`, 1, 0.6766114265460376], 
        Hue[0.040915046164483715`, 1, 0.9433483976184072], 
        Hue[0.15000883322690067`, 1, 0.7922954616858299], 
        Hue[0.040893852336497005`, 1, 0.9433777429186965], 
        Hue[0.10026584227413049`, 1, 0.8611703722358194], 
        Hue[0.14997656962515238`, 1, 0.7923401343651736], 
        Hue[0.23352199193288742`, 1, 0.6766618573236943], 
        Hue[0.6480476331532764, 1, 0.10270327717238656`], 
        Hue[0.6489591993613006, 1, 0.10144110857666067`], 
        Hue[0.6497294663699528, 1, 0.10037458502621935`], 
        Hue[0.6499416771509483, 1, 0.10008075471407167`], 
        Hue[0.6499900187740281, 1, 0.10001382015903812`], 
        Hue[0.6499999917956835, 1, 0.10000001135982291`], 
        Hue[0.6499991515859967, 1, 0.10000117472708145`], 
        Hue[0.6499993483460993, 1, 0.10000090229001642`], 
        Hue[0.6499999222917153, 1, 0.10000010759608655`], 
        Hue[0.6499933666375028, 1, 0.10000918465576535`], 
        Hue[0.6499946619760952, 1, 0.10000739111002195`], 
        Hue[0.6499613986682437, 1, 0.10005344799781657`], 
        Hue[0.649968151589994, 1, 0.10004409779846984`], 
        Hue[0.649828893698698, 1, 0.10023691641718745`], 
        Hue[0.6498573946453188, 1, 0.10019745356802023`], 
        Hue[0.6494073982064067, 1, 0.10082052556035996`], 
        Hue[0.6495085615470421, 1, 0.1006804532425571], 
        Hue[0.6473513706733505, 1, 0.1036673329138225], 
        Hue[0.6434736200020821, 1, 0.10903652615096326`], 
        Hue[0.633660053902879, 1, 0.12262454074985986`], 
        Hue[0.6140905734391554, 1, 0.14972074446886185`], 
        Hue[0.5584448138849759, 1, 0.2267687192361872], 
        Hue[0.18507857487504847`, 1, 0.7437373578653175], 
        Hue[0.12170305563612982`, 1, 0.8314880768115126], 
        Hue[0.1287910267796043, 1, 0.821673962920548], 
        Hue[0.18504088594804108`, 1, 0.7437895425334816], 
        Hue[0.5511449764442349, 1, 0.23687618646182867`], 
        Hue[0.5284611999960993, 1, 0.26828449231309326`], 
        Hue[0.6155545287379652, 1, 0.14769372943974055`], 
        Hue[0.6025635060508471, 1, 0.16568129931421172`], 
        Hue[0.6388740031490734, 1, 0.1154052264089754], 
        Hue[0.6336566410847063, 1, 0.12262926619040662`], 
        Hue[0.6434731972961383, 1, 0.10903711143611633`], 
        Hue[0.6473523532850615, 1, 0.10366597237453028`], 
        Hue[0.6489846669012399, 1, 0.10140584582905249`], 
        Hue[0.6499997344623704, 1, 0.10000036766748721`], 
        Hue[0.6499993557516623, 1, 0.10000089203615993`], 
        Hue[0.6499958569645508, 1, 0.10000573651062201`], 
        Hue[0.6499970064878591, 1, 0.10000414486296436`], 
        Hue[0.6499741382710061, 1, 0.10003580854783768`], 
        Hue[0.6499797258816096, 1, 0.100028071856233], 
        Hue[0.6498815309986415, 1, 0.10016403400188102`], 
        Hue[0.6499029637901637, 1, 0.10013435782900423`], 
        Hue[0.6495884346066918, 1, 0.1005698597753498], 
        Hue[0.6496559963280032, 1, 0.10047631277661098`], 
        Hue[0.6483053260376217, 1, 0.10234647164021617`], 
        Hue[0.6465822717265689, 1, 0.10473223914782774`], 
        Hue[0.6462861242777479, 1, 0.1051422894615798], 
        Hue[0.6438600147950487, 1, 0.10850151797608636`], 
        Hue[0.6406195765724355, 1, 0.1129882785920124], 
        Hue[0.6310228082209484, 1, 0.12627611169407155`], 
        Hue[0.3624655433981332, 1, 0.49812463221796943`], 
        Hue[0.2873725448606186, 1, 0.6020995532699127], 
        Hue[0.26072995684176997`, 1, 0.6389892905267801], 
        Hue[0.2873588863495887, 1, 0.6021184650544156], 
        Hue[0.5155200401465881, 1, 0.28620302133549336`], 
        Hue[0.5155200401465878, 1, 0.2862030213354939], 
        Hue[0.5913562314673553, 1, 0.1811990641221235], 
        Hue[0.584823939133998, 1, 0.19024377658369515`], 
        Hue[0.6282683067129716, 1, 0.1300900368589624], 
        Hue[0.6236967626831381, 1, 0.13641986705411643`], 
        Hue[0.6410125786950517, 1, 0.11244412180685161`], 
        Hue[0.6387923231016319, 1, 0.1155183218592789], 
        Hue[0.6438587986192152, 1, 0.1085032019118559], 
        Hue[0.6499892896045865, 1, 0.10001482977826487`], 
        Hue[0.6499648695962024, 1, 0.10004864209756596`], 
        Hue[0.649997032693306, 1, 0.10000410857849946`], 
        Hue[0.6499852021769049, 1, 0.10002048929351634`], 
        Hue[0.6499904256749581, 1, 0.10001325675775032`], 
        Hue[0.6499231631029164, 1, 0.10010638954980809`], 
        Hue[0.6499433111349449, 1, 0.10007849227469179`], 
        Hue[0.6497158718365242, 1, 0.1003934082263511], 
        Hue[0.6497727314760293, 1, 0.10031467949472872`], 
        Hue[0.6488022469143931, 1, 0.10165842734930183`], 
        Hue[0.6476433233638824, 1, 0.10326309072693211`], 
        Hue[0.6473931627551947, 1, 0.1036094669543459], 
        Hue[0.6460011934807786, 1, 0.10553680902661441`], 
        Hue[0.6447135116824785, 1, 0.1073197530550298], 
        Hue[0.6429908696471961, 1, 0.10970494971926699`], 
        Hue[0.5584448138854339, 1, 0.22676871923555317`], 
        Hue[0.4978283478418154, 1, 0.3106992106805634], 
        Hue[0.4473823199047938, 1, 0.38054755705490095`], 
        Hue[0.4280417126324526, 1, 0.40732685943198865`], 
        Hue[0.528461199996099, 1, 0.26828449231309376`], 
        Hue[0.5511449764442337, 1, 0.2368761864618304], 
        Hue[0.5848239391339978, 1, 0.1902437765836954], 
        Hue[0.5913562314673545, 1, 0.18119906412212453`], 
        Hue[0.6210359540875073, 1, 0.1401040635711437], 
        Hue[0.6210359540875072, 1, 0.1401040635711439], 
        Hue[0.6370814322964223, 1, 0.11788724758956906`], 
        Hue[0.636133593040564, 1, 0.11919964040537295`], 
        Hue[0.6427201663461387, 1, 0.11007976967457717`], 
        Hue[0.641979394693572, 1, 0.11110545350120805`], 
        Hue[0.6443971876864337, 1, 0.10775774012647635`], 
        Hue[0.6498468322258638, 1, 0.10021207845649628`], 
        Hue[0.6496872006198552, 1, 0.10043310683404671`], 
        Hue[0.6499435436197024, 1, 0.10007817037271977`], 
        Hue[0.6499904847358855, 1, 0.10001317498108163`], 
        Hue[0.6499628521968075, 1, 0.10005143541980507`], 
        Hue[0.6499792798726709, 1, 0.10002868940707105`], 
        Hue[0.6498302874016713, 1, 0.10023498667460905`], 
        Hue[0.6498869310750488, 1, 0.10015655697300938`], 
        Hue[0.649167627523241, 1, 0.10115251573705095`], 
        Hue[0.6483163987955443, 1, 0.10233114012924638`], 
        Hue[0.6480161564309218, 1, 0.10274686032641599`], 
        Hue[0.6471342337346329, 1, 0.10396798405973914`], 
        Hue[0.6462658582790939, 1, 0.10517035007510085`], 
        Hue[0.6453879602649326, 1, 0.10638590117163177`], 
        Hue[0.6310228082210256, 1, 0.12627611169396455`], 
        Hue[0.6140905734395123, 1, 0.14972074446836753`], 
        Hue[0.5901231464878142, 1, 0.18290641255533424`], 
        Hue[0.5681229598892343, 1, 0.21336820938413703`], 
        Hue[0.5591705448266987, 1, 0.22576386100918644`], 
        Hue[0.602563506050846, 1, 0.1656812993142133], 
        Hue[0.6155545287379638, 1, 0.14769372943974254`], 
        Hue[0.6236967626831377, 1, 0.13641986705411707`], 
        Hue[0.628268306712971, 1, 0.13009003685896328`], 
        Hue[0.6361335930405639, 1, 0.11919964040537312`], 
        Hue[0.6370814322964221, 1, 0.11788724758956945`], 
        Hue[0.6416150548927615, 1, 0.11160992399463798`], 
        Hue[0.6416150548927614, 1, 0.11160992399463811`], 
        Hue[0.6439515530904331, 1, 0.10837477264401578`], 
        Hue[0.643757346457027, 1, 0.10864367413642426`], 
        Hue[0.6450459043341169, 1, 0.10685951707583816`], 
        Hue[0.6495197235700738, 1, 0.10066499813374392`], 
        Hue[0.6499630030101804, 1, 0.10005122660128865`], 
        Hue[0.6498595392714197, 1, 0.10019448408572659`], 
        Hue[0.6499793572109922, 1, 0.10002858232324165`], 
        Hue[0.6499353113077606, 1, 0.1000895689584853], 
        Hue[0.6495193091275062, 1, 0.10066557197729913`], 
        Hue[0.6479796182166929, 1, 0.10279745169996372`], 
        Hue[0.6472841430793682, 1, 0.10376041727472092`], 
        Hue[0.6466661863103496, 1, 0.10461604972413144`], 
        Hue[0.6429908696472039, 1, 0.10970494971925615`], 
        Hue[0.6406195765724956, 1, 0.11298827859192927`], 
        Hue[0.6387961530918427, 1, 0.11551301879591018`], 
        Hue[0.6336600539032469, 1, 0.12262454074935054`], 
        Hue[0.6250352667028026, 1, 0.13456655379611943`], 
        Hue[0.6336566410847058, 1, 0.12262926619040751`], 
        Hue[0.6388740031490726, 1, 0.11540522640897635`], 
        Hue[0.6387923231016316, 1, 0.11551832185927938`], 
        Hue[0.6410125786950513, 1, 0.11244412180685208`], 
        Hue[0.6419793946935718, 1, 0.11110545350120836`], 
        Hue[0.6427201663461385, 1, 0.1100797696745775], 
        Hue[0.6437573464570269, 1, 0.10864367413642435`], 
        Hue[0.643951553090433, 1, 0.10837477264401599`], 
        Hue[0.644907814325618, 1, 0.10705071862606744`], 
        Hue[0.644907814325618, 1, 0.10705071862606746`], 
        Hue[0.6494292804404584, 1, 0.10079022708244216`], 
        Hue[0.6498246858302775, 1, 0.10024274269653886`], 
        Hue[0.6499660352996491, 1, 0.10004702804663972`], 
        Hue[0.6499660027761931, 1, 0.10004707307911731`], 
        Hue[0.6487517211908195, 1, 0.10172838604348083`], 
        Hue[0.6488011994693257, 1, 0.10165987765785672`], 
        Hue[0.6481284893528519, 1, 0.10259132243451279`], 
        Hue[0.6475809298216183, 1, 0.10334948178545168`], 
        Hue[0.6453879602649328, 1, 0.10638590117163146`], 
        Hue[0.6447135116824834, 1, 0.10731975305502306`], 
        Hue[0.6443985210227201, 1, 0.10775589396854145`], 
        Hue[0.6438600147951252, 1, 0.10850151797598054`], 
        Hue[0.6434736200023033, 1, 0.10903652615065697`], 
        Hue[0.6431577560124131, 1, 0.10947387629050494`], 
        Hue[0.6434731972961379, 1, 0.10903711143611679`], 
        Hue[0.643858798619215, 1, 0.10850320191185622`], 
        Hue[0.6443971876864336, 1, 0.1077577401264766], 
        Hue[0.6450459043341169, 1, 0.10685951707583821`], 
        Hue[0.6499875752276579, 1, 0.10001720353093521`], 
        Hue[0.6499660613044453, 1, 0.10004699203999874`], 
        Hue[0.6499690957937134, 1, 0.1000427904394738], 
        Hue[0.6499875583936996, 1, 0.10001722683949292`], 
        Hue[0.6498258485023254, 1, 0.10024113284293407`], 
        Hue[0.6498634903348335, 1, 0.10018901338253833`], 
        Hue[0.6494394618677293, 1, 0.1007761297216056], 
        Hue[0.6495474566380964, 1, 0.10062659850109733`], 
        Hue[0.6489976573214438, 1, 0.10138785909338563`], 
        Hue[0.6483958281620502, 1, 0.10222116100639206`], 
        Hue[0.6466661863103496, 1, 0.10461604972413144`], 
        Hue[0.6462658582790938, 1, 0.1051703500751009], 
        Hue[0.64611087787881, 1, 0.1053849383216477], 
        Hue[0.6460011934807838, 1, 0.10553680902660717`], 
        Hue[0.6465822717266224, 1, 0.10473223914775362`], 
        Hue[0.6473513706734652, 1, 0.1036673329136637], 
        Hue[0.6483330201390971, 1, 0.10230812596125023`], 
        Hue[0.6480467041528214, 1, 0.10270456348070894`], 
        Hue[0.6489583372556444, 1, 0.10144230226141537`], 
        Hue[0.6480476331532762, 1, 0.10270327717238693`], 
        Hue[0.649458996207529, 1, 0.10074908217419068`], 
        Hue[0.6473523532850612, 1, 0.10366597237453057`], 
        Hue[0.6489846669012398, 1, 0.10140584582905257`], 
        Hue[0.6499660419264217, 1, 0.10004701887110846`], 
        Hue[0.6499798735525514, 1, 0.100027867388775], 
        Hue[0.6498926261234819, 1, 0.10014867152133292`], 
        Hue[0.6497265096835254, 1, 0.10037867889973415`], 
        Hue[0.64933320164324, 1, 0.10092325926320618`], 
        Hue[0.6475809298216183, 1, 0.10334948178545166`], 
        Hue[0.6472841430793682, 1, 0.1037604172747209], 
        Hue[0.6471786129927874, 1, 0.10390653585614049`], 
        Hue[0.6471342337346329, 1, 0.1039679840597392], 
        Hue[0.6476433233638853, 1, 0.10326309072692814`], 
        Hue[0.6483053260376332, 1, 0.10234647164020018`], 
        Hue[0.6488831338517164, 1, 0.10154643005146977`], 
        Hue[0.6492559152561433, 1, 0.10103027118380156`], 
        Hue[0.649407398206416, 1, 0.10082052556034711`], 
        Hue[0.6496234965987958, 1, 0.10052131240166731`], 
        Hue[0.6497289407484043, 1, 0.10037531280990179`], 
        Hue[0.6495822971313279, 1, 0.10057835781816142`], 
        Hue[0.6498709896006885, 1, 0.10017862978366215`], 
        Hue[0.6497372360371154, 1, 0.1003638270255325], 
        Hue[0.6499365186637519, 1, 0.10008789723480506`], 
        Hue[0.6498923240356159, 1, 0.1001490897968396], 
        Hue[0.6499797890669986, 1, 0.10002798436877125`], 
        Hue[0.6499912329900899, 1, 0.10001213893679865`], 
        Hue[0.6499711016483095, 1, 0.10004001310234077`], 
        Hue[0.6498842956213006, 1, 0.10016020606281464`], 
        Hue[0.6483958281620502, 1, 0.10222116100639209`], 
        Hue[0.6481284893528518, 1, 0.10259132243451285`], 
        Hue[0.6479796182166928, 1, 0.10279745169996383`], 
        Hue[0.6480161564309217, 1, 0.10274686032641614`], 
        Hue[0.6483163987955443, 1, 0.10233114012924639`], 
        Hue[0.6488022469143936, 1, 0.10165842734930128`], 
        Hue[0.6492111455095863, 1, 0.10109226006364978`], 
        Hue[0.6495085615470444, 1, 0.10068045324255397`], 
        Hue[0.6495884346066922, 1, 0.10056985977534917`], 
        Hue[0.6497916794686982, 1, 0.10028844381257172`], 
        Hue[0.6498288936986989, 1, 0.10023691641718625`], 
        Hue[0.6499289484739935, 1, 0.10009837903600897`], 
        Hue[0.6499414626511469, 1, 0.10008105171379662`], 
        Hue[0.6499149607103801, 1, 0.10011774670870442`], 
        Hue[0.6499751193911046, 1, 0.10003445007385514`], 
        Hue[0.6495530687696347, 1, 0.10061882785742893`], 
        Hue[0.6495129010015268, 1, 0.10067444476711676`], 
        Hue[0.6498470503888287, 1, 0.10021177638469878`], 
        Hue[0.6498131704790806, 1, 0.10025868702896529`], 
        Hue[0.6499650867010297, 1, 0.10004834149088199`], 
        Hue[0.6499501069360999, 1, 0.10006908270386165`], 
        Hue[0.649991166860452, 1, 0.10001223050091258`], 
        Hue[0.6499989171085051, 1, 0.10000149938822367`], 
        Hue[0.64933320164324, 1, 0.10092325926320615`], 
        Hue[0.6489976573214437, 1, 0.10138785909338567`], 
        Hue[0.6488011994693256, 1, 0.10165987765785689`], 
        Hue[0.6487517211908193, 1, 0.1017283860434811], 
        Hue[0.649167627523241, 1, 0.10115251573705104`], 
        Hue[0.6494692059492382, 1, 0.10073494560874716`], 
        Hue[0.6496559963280033, 1, 0.10047631277661086`], 
        Hue[0.6497158718365242, 1, 0.1003934082263511], 
        Hue[0.6498573946453189, 1, 0.10019745356801998`], 
        Hue[0.6498815309986415, 1, 0.10016403400188097`], 
        Hue[0.6499533005675093, 1, 0.10006466075267935`], 
        Hue[0.6499613986682437, 1, 0.1000534479978165], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6499899581044661, 1, 0.10001390416304687`], 
        Hue[0.6499860137071367, 1, 0.10001936563627234`], 
        Hue[0.6499962490896035, 1, 0.10000519356824138`], 
        Hue[0.6495129010015268, 1, 0.10067444476711679`], 
        Hue[0.6495530687696347, 1, 0.10061882785742898`], 
        Hue[0.6497964648039245, 1, 0.10028181796379694`], 
        Hue[0.6497964648039245, 1, 0.10028181796379694`], 
        Hue[0.6499391582420061, 1, 0.10008424243414549`], 
        Hue[0.6499339441898728, 1, 0.10009146189094534`], 
        Hue[0.6499873787655159, 1, 0.10001747555543954`], 
        Hue[0.6499846921337001, 1, 0.10002119550718444`], 
        Hue[0.6499975387906934, 1, 0.10000340782827066`], 
        Hue[0.6498842956213006, 1, 0.10016020606281462`], 
        Hue[0.6497265096835254, 1, 0.1003786788997341], 
        Hue[0.6495474566380964, 1, 0.10062659850109733`], 
        Hue[0.6494394618677292, 1, 0.10077612972160574`], 
        Hue[0.6495193091275061, 1, 0.10066557197729935`], 
        Hue[0.6497261232417286, 1, 0.10037921397299124`], 
        Hue[0.6497727314760292, 1, 0.10031467949472878`], 
        Hue[0.6498302874016713, 1, 0.10023498667460914`], 
        Hue[0.6499029637901637, 1, 0.10013435782900423`], 
        Hue[0.6499231631029164, 1, 0.1001063895498081], 
        Hue[0.649968151589994, 1, 0.10004409779846982`], 
        Hue[0.6499741382710061, 1, 0.10003580854783767`], 
        Hue[0.649991888260414, 1, 0.10001123163942684`], 
        Hue[0.6499933666375028, 1, 0.10000918465576535`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.649998672028374, 1, 0.10000183872994367`], 
        Hue[0.6499981929645616, 1, 0.10000250204906862`], 
        Hue[0.6498468322258638, 1, 0.10021207845649625`], 
        Hue[0.6496872006198552, 1, 0.10043310683404669`], 
        Hue[0.6495197235700738, 1, 0.10066499813374391`], 
        Hue[0.6494292804404584, 1, 0.10079022708244217`], 
        Hue[0.6497372360371154, 1, 0.10036382702553254`], 
        Hue[0.6498131704790806, 1, 0.10025868702896532`], 
        Hue[0.6498470503888286, 1, 0.1002117763846988], 
        Hue[0.6499339441898728, 1, 0.10009146189094535`], 
        Hue[0.6499391582420061, 1, 0.1000842424341455], 
        Hue[0.6499834669215924, 1, 0.10002289195471836`], 
        Hue[0.6499834669215924, 1, 0.10002289195471836`], 
        Hue[0.6499970370468677, 1, 0.10000410255049084`], 
        Hue[0.6499968197541345, 1, 0.10000440341735237`], 
        Hue[0.6499995605902448, 1, 0.10000060841350733`], 
        Hue[0.6499998438351633, 1, 0.10000021622823552`], 
        Hue[0.6499711016483095, 1, 0.10004001310234076`], 
        Hue[0.6499503668772793, 1, 0.10006872278530574`], 
        Hue[0.6498634903348335, 1, 0.10018901338253831`], 
        Hue[0.6498258485023254, 1, 0.10024113284293411`], 
        Hue[0.6498869310750488, 1, 0.10015655697300946`], 
        Hue[0.6499353113077606, 1, 0.10008956895848536`], 
        Hue[0.6499433111349449, 1, 0.10007849227469183`], 
        Hue[0.6499628521968075, 1, 0.1000514354198051], 
        Hue[0.6499797258816096, 1, 0.10002807185623301`], 
        Hue[0.6499852021769049, 1, 0.10002048929351635`], 
        Hue[0.6499946619760952, 1, 0.10000739111002195`], 
        Hue[0.6499958569645508, 1, 0.10000573651062203`], 
        Hue[0.6499989347644688, 1, 0.1000014749415048], 
        Hue[0.6499991515859967, 1, 0.10000117472708145`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499998686930739, 1, 0.10000018180959001`], 
        Hue[0.6499995706076633, 1, 0.10000059454323541`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499892896045865, 1, 0.10001482977826487`], 
        Hue[0.6499648695962024, 1, 0.10004864209756596`], 
        Hue[0.6499435436197024, 1, 0.10007817037271975`], 
        Hue[0.6498595392714197, 1, 0.10019448408572659`], 
        Hue[0.6499630030101805, 1, 0.10005122660128864`], 
        Hue[0.6498246858302775, 1, 0.10024274269653886`], 
        Hue[0.6498923240356158, 1, 0.10014908979683962`], 
        Hue[0.6499365186637519, 1, 0.10008789723480506`], 
        Hue[0.6499501069360999, 1, 0.10006908270386165`], 
        Hue[0.6499650867010297, 1, 0.10004834149088199`], 
        Hue[0.6499846921337001, 1, 0.10002119550718444`], 
        Hue[0.6499873787655159, 1, 0.10001747555543954`], 
        Hue[0.6499968197541345, 1, 0.10000440341735237`], 
        Hue[0.6499970370468677, 1, 0.10000410255049084`], 
        Hue[0.6499995314220489, 1, 0.10000064880024004`], 
        Hue[0.6499995314220489, 1, 0.10000064880024004`], 
        Hue[0.6499999509486679, 1, 0.10000006791722911`], 
        Hue[0.6499999480469419, 1, 0.10000007193500345`], 
        Hue[0.6499999966971565, 1, 0.10000000457316796`], 
        Hue[0.6499999966971565, 1, 0.10000000457316796`], 
        Hue[0.6499998438351633, 1, 0.10000021622823552`], 
        Hue[0.6499989171085051, 1, 0.10000149938822367`], 
        Hue[0.6499975662514333, 1, 0.10000336980570772`], 
        Hue[0.6499912329900899, 1, 0.10001213893679864`], 
        Hue[0.6499798735525514, 1, 0.10002786738877499`], 
        Hue[0.6499660613044453, 1, 0.10004699203999876`], 
        Hue[0.6499875583936996, 1, 0.10001722683949292`], 
        Hue[0.6499660027761931, 1, 0.10004707307911734`], 
        Hue[0.6499792798726709, 1, 0.10002868940707108`], 
        Hue[0.6499904256749581, 1, 0.10001325675775033`], 
        Hue[0.6499970064878591, 1, 0.10000414486296437`], 
        Hue[0.6499993483460993, 1, 0.10000090229001643`], 
        Hue[0.6499998974223291, 1, 0.10000014203062124`], 
        Hue[0.6499999222917153, 1, 0.10000010759608655`], 
        Hue[0.6499999878784672, 1, 0.1000000167836607], 
        Hue[0.6499999916279817, 1, 0.10000001159202533`], 
        Hue[0.6499999880630696, 1, 0.10000001652805754`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499999917956835, 1, 0.10000001135982291`], 
        Hue[0.6499997344623704, 1, 0.10000036766748721`], 
        Hue[0.6499993557516623, 1, 0.10000089203615993`], 
        Hue[0.6499999234519708, 1, 0.10000010598957898`], 
        Hue[0.649997032693306, 1, 0.10000410857849946`], 
        Hue[0.6499904847358855, 1, 0.10001317498108163`], 
        Hue[0.6499793572109922, 1, 0.10002858232324165`], 
        Hue[0.6499660352996491, 1, 0.10004702804663973`], 
        Hue[0.6499875752276579, 1, 0.10001720353093521`], 
        Hue[0.6499660419264217, 1, 0.10004701887110846`], 
        Hue[0.6499797890669986, 1, 0.10002798436877126`], 
        Hue[0.649991166860452, 1, 0.1000122305009126], 
        Hue[0.6499975387906934, 1, 0.10000340782827066`], 
        Hue[0.6499995605902448, 1, 0.10000060841350733`], 
        Hue[0.6499999480469419, 1, 0.10000007193500345`], 
        Hue[0.6499999509486679, 1, 0.10000006791722911`], 
        Hue[0.6499999965856617, 1, 0.10000000472754546`], 
        Hue[0.6499999965856617, 1, 0.10000000472754546`], 
        Hue[0.6499875499410278, 1, 0.10001723854319232`], 
        Hue[0.6499875752276579, 1, 0.10001720353093523`], 
        Hue[0.6499993557516623, 1, 0.10000089203615993`], 
        Hue[0.6499999880630696, 1, 0.10000001652805754`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499875610519944, 1, 0.10001722315877695`], 
        Hue[0.6499875583936996, 1, 0.10001722683949292`], 
        Hue[0.6499975662514333, 1, 0.10000336980570773`], 
        Hue[0.6499999519224451, 1, 0.10000006656892216`], 
        Hue[0.6498378759096497, 1, 0.10022447950971584`], 
        Hue[0.6499435436197024, 1, 0.10007817037271981`], 
        Hue[0.6499798465258424, 1, 0.10002790481037209`], 
        Hue[0.6497261232417287, 1, 0.10037921397299106`], 
        Hue[0.6498403530877374, 1, 0.10022104957082523`], 
        Hue[0.6499503668772791, 1, 0.10006872278530578`], 
        Hue[0.6499999519224451, 1, 0.10000006656892216`], 
        Hue[0.6494616792468534, 1, 0.10074536719666463`], 
        Hue[0.6495984682510236, 1, 0.10055596703704421`], 
        Hue[0.6497732626026613, 1, 0.1003139440886228], 
        Hue[0.6499981929645616, 1, 0.10000250204906862`], 
        Hue[0.6499900187740281, 1, 0.10001382015903805`], 
        Hue[0.6494692059492383, 1, 0.10073494560874698`], 
        Hue[0.6494812112006415, 1, 0.10071832295295798`], 
        Hue[0.6496330749346824, 1, 0.10050805009043988`], 
        Hue[0.649813758879976, 1, 0.10025787232003332`], 
        Hue[0.6499860137071368, 1, 0.10001936563627217`], 
        Hue[0.6499416771509491, 1, 0.10008075471407049`], 
        Hue[0.6492111455095863, 1, 0.10109226006364984`], 
        Hue[0.648758555220787, 1, 0.10171892354044881`], 
        Hue[0.6488795947841098, 1, 0.10155133029892492`], 
        Hue[0.6491535472148489, 1, 0.10117201154867078`], 
        Hue[0.6498137588799761, 1, 0.10025787232003325`], 
        Hue[0.6499149607103819, 1, 0.10011774670870197`], 
        Hue[0.649729466369962, 1, 0.10037458502620653`], 
        Hue[0.648883133851712, 1, 0.10154643005147576`], 
        Hue[0.6481345467524913, 1, 0.10258293526578137`], 
        Hue[0.647966797245455, 1, 0.10281520381398546`], 
        Hue[0.6480385917352298, 1, 0.10271579605891265`], 
        Hue[0.6482450581235273, 1, 0.10242991952126995`], 
        Hue[0.649153547214849, 1, 0.10117201154867062`], 
        Hue[0.6496330749346825, 1, 0.10050805009043975`], 
        Hue[0.6498926261234819, 1, 0.10014867152133289`], 
        Hue[0.6483341237539456, 1, 0.10230659787915224`], 
        Hue[0.6495822971313424, 1, 0.10057835781814135`], 
        Hue[0.6489591993613566, 1, 0.10144110857658323`], 
        Hue[0.6489583372555867, 1, 0.10144230226149542`], 
        Hue[0.6483330201390396, 1, 0.10230812596132983`], 
        Hue[0.6471786129927877, 1, 0.10390653585614024`], 
        Hue[0.6474234415840103, 1, 0.10356754242213957`], 
        Hue[0.6482450581235273, 1, 0.10242991952126992`], 
        Hue[0.6488795947841098, 1, 0.10155133029892484`], 
        Hue[0.6494812112006415, 1, 0.10071832295295793`], 
        Hue[0.6498403530877374, 1, 0.10022104957082521`], 
        Hue[0.6499690957937134, 1, 0.1000427904394738], 
        Hue[0.6499875499410278, 1, 0.10001723854319232`], 
        Hue[0.6461108778788095, 1, 0.10538493832164841`], 
        Hue[0.6464564564606159, 1, 0.10490644490068565`], 
        Hue[0.64742344158401, 1, 0.10356754242214004`], 
        Hue[0.6480385917352296, 1, 0.10271579605891286`], 
        Hue[0.6487585552207868, 1, 0.10171892354044898`], 
        Hue[0.6498378759096497, 1, 0.10022447950971583`], 
        Hue[0.6494616792468534, 1, 0.10074536719666462`], 
        Hue[0.6443985210227051, 1, 0.1077558939685622], 
        Hue[0.6450470004719606, 1, 0.10685799934651607`], 
        Hue[0.6464564564606102, 1, 0.10490644490069351`], 
        Hue[0.6479667972454544, 1, 0.10281520381398628`], 
        Hue[0.6499875610519944, 1, 0.10001722315877697`], 
        Hue[0.6495984682510236, 1, 0.10055596703704424`], 
        Hue[0.6387961530917176, 1, 0.11551301879608337`], 
        Hue[0.6419821243866809, 1, 0.11110167392613411`], 
        Hue[0.6450470004719279, 1, 0.1068579993465614], 
        Hue[0.6481345467524894, 1, 0.10258293526578396`], 
        Hue[0.6499435436197024, 1, 0.10007817037271981`], 
        Hue[0.6497732626026613, 1, 0.10031394408862286`], 
        Hue[0.5614916278741021, 1, 0.22255005371278172`], 
        Hue[0.57812541033916, 1, 0.19951866260731693`], 
        Hue[0.6025745294274645, 1, 0.1656660361773569], 
        Hue[0.6237081735896381, 1, 0.13640406733742408`], 
        Hue[0.6419821243866659, 1, 0.11110167392615486`], 
        Hue[0.6473931627551752, 1, 0.10360946695437283`], 
        Hue[0.6499798465258424, 1, 0.1000279048103721], 
        Hue[0.43299533247763233`, 1, 0.40046800118481685`], 
        Hue[0.4697754323597277, 1, 0.34954170904037707`], 
        Hue[0.5284835431577712, 1, 0.2682535556277013], 
        Hue[0.623708173589869, 1, 0.1364040673371045], 
        Hue[0.6462861242777049, 1, 0.10514228946163941`], 
        Hue[0.6499993557516623, 1, 0.10000089203615993`], 
        Hue[0.2674438253340051, 1, 0.6296931649221468], 
        Hue[0.267450645458638, 1, 0.6296837216726551], 
        Hue[0.3196540147172407, 1, 0.5574021334684359], 
        Hue[0.5284835431585925, 1, 0.2682535556265643], 
        Hue[0.6025745294281106, 1, 0.1656660361764622], 
        Hue[0.6483341237539202, 1, 0.10230659787918744`], 
        Hue[0.18504088595038598`, 1, 0.7437895425302348], 
        Hue[0.18504088595001256`, 1, 0.7437895425307519], 
        Hue[0.12879102678331356`, 1, 0.8216739629154121], 
        Hue[0.10026584227849467`, 1, 0.8611703722297765], 
        Hue[0.12880990328898734`, 1, 0.8216478262152483], 
        Hue[0.18507857487579976`, 1, 0.7437373578642772], 
        Hue[0.10030388522786648`, 1, 0.8611176973768003], 
        Hue[0.1850785748753384, 1, 0.743737357864916], 
        Hue[0.31965401471773736`, 1, 0.5574021334677483], 
        Hue[0.46977543236106056`, 1, 0.34954170903853155`], 
        Hue[0.5781254103401833, 1, 0.1995186626059001], 
        Hue[0.627587341145137, 1, 0.13103291226057956`], 
        Hue[0.6432314603308535, 1, 0.10937182415727968`], 
        Hue[0.6499999880630696, 1, 0.10000001652805754`], 
        Hue[0.6499998222703252, 1, 0.1000002460872421], 
        Hue[0.6499900187740281, 1, 0.1000138201590381], 
        Hue[0.6499981929645616, 1, 0.10000250204906863`], 
        Hue[0.6499416771509486, 1, 0.10008075471407114`], 
        Hue[0.6499860137071367, 1, 0.10001936563627227`], 
        Hue[0.6497294663699593, 1, 0.10037458502621026`], 
        Hue[0.6499149607103814, 1, 0.10011774670870276`], 
        Hue[0.648959199361349, 1, 0.10144110857659368`], 
        Hue[0.6495822971313402, 1, 0.10057835781814445`], 
        Hue[0.267443825332904, 1, 0.6296931649236714], 
        Hue[0.12879102678220322`, 1, 0.8216739629169494], 
        Hue[0.04089385234061427, 1, 0.9433777429129957], 
        Hue[0.04089385234029075, 1, 0.9433777429134436], 
        Hue[0.040915046164482605`, 1, 0.9433483976184087], 
        Hue[0.12880990328631003`, 1, 0.8216478262189554], 
        Hue[0.26745064545827635`, 1, 0.6296837216731559], 
        Hue[0.432995332479051, 1, 0.40046800118285253`], 
        Hue[0.5614916278752367, 1, 0.22255005371121075`], 
        Hue[0.6495819204903069, 1, 0.10057887932111356`], 
        Hue[0.6499147887623521, 1, 0.10011798479058953`], 
        Hue[0.6499859604962616, 1, 0.10001943931286864`], 
        Hue[0.6499981815209614, 1, 0.10000251789405334`], 
        Hue[0.6499998205406813, 1, 0.10000024848213372`], 
        Hue[0.6499999878784672, 1, 0.1000000167836607], 
        Hue[0.5614916278739857, 1, 0.22255005371294295`], 
        Hue[0.43299533247711963`, 1, 0.4004680011855267], 
        Hue[0.26745064545750746`, 1, 0.6296837216742204], 
        Hue[0.12880990328781605`, 1, 0.8216478262168702], 
        Hue[0.04091504616570485, 1, 0.9433483976167164], 
        Hue[0.008564162897190197, 1, 0.9881419282961982], 
        Hue[0.0408938523364103, 1, 0.9433777429188165], 
        Hue[0.12879102677946985`, 1, 0.821673962920734], 
        Hue[0.26744382533350425`, 1, 0.6296931649228403], 
        Hue[0.6495822971313276, 1, 0.10057835781816173`], 
        Hue[0.6499149607103801, 1, 0.10011774670870452`], 
        Hue[0.6499860137071367, 1, 0.10001936563627235`], 
        Hue[0.6499981929645616, 1, 0.10000250204906863`], 
        Hue[0.6499998222703252, 1, 0.1000002460872421], 
        Hue[0.6489583372555867, 1, 0.10144230226149535`], 
        Hue[0.5781254103390867, 1, 0.19951866260741846`], 
        Hue[0.4697754323594143, 1, 0.34954170904081094`], 
        Hue[0.3196540147165537, 1, 0.5574021334693872], 
        Hue[0.18507857487510665`, 1, 0.743737357865237], 
        Hue[0.10030388522652434`, 1, 0.8611176973786585], 
        Hue[0.10026584227419488`, 1, 0.8611703722357301], 
        Hue[0.1850408859480107, 1, 0.7437895425335237], 
        Hue[0.6483330201390397, 1, 0.10230812596132967`], 
        Hue[0.6025745294274348, 1, 0.16566603617739795`], 
        Hue[0.5284835431576489, 1, 0.2682535556278708], 
        Hue[0.1288099032863832, 1, 0.821647826218854], 
        Hue[0.6483341237538894, 1, 0.1023065978792301], 
        Hue[0.6499999234519708, 1, 0.10000010598957898`], 
        Hue[0.6488831338517119, 1, 0.1015464300514758], 
        Hue[0.6387961530917151, 1, 0.11551301879608673`], 
        Hue[0.6237081735896223, 1, 0.1364040673374461], 
        Hue[0.319654014717638, 1, 0.5574021334678859], 
        Hue[0.2674506454582996, 1, 0.6296837216731236], 
        Hue[0.26744382533355726`, 1, 0.6296931649227668], 
        Hue[0.6499798465258424, 1, 0.10002790481037209`], 
        Hue[0.6492111455095861, 1, 0.10109226006364998`], 
        Hue[0.6443985210227057, 1, 0.10775589396856143`], 
        Hue[0.6419821243866807, 1, 0.11110167392613443`], 
        Hue[0.5284835431584985, 1, 0.2682535556266944], 
        Hue[0.46977543236099784`, 1, 0.3495417090386184], 
        Hue[0.43299533247903554`, 1, 0.40046800118287396`], 
        Hue[0.6497732626026613, 1, 0.10031394408862274`], 
        Hue[0.6494692059492383, 1, 0.10073494560874705`], 
        Hue[0.6481345467524912, 1, 0.10258293526578155`], 
        Hue[0.6461108778788097, 1, 0.10538493832164814`], 
        Hue[0.645047000471963, 1, 0.10685799934651287`], 
        Hue[0.6237081735898071, 1, 0.1364040673371902], 
        Hue[0.602574529428017, 1, 0.1656660361765918], 
        Hue[0.5781254103401121, 1, 0.1995186626059986], 
        Hue[0.5614916278752068, 1, 0.2225500537112522], 
        Hue[0.6495984682510237, 1, 0.10055596703704404`], 
        Hue[0.6498872063550268, 1, 0.10015617581611677`], 
        Hue[0.6497261232417287, 1, 0.10037921397299107`], 
        Hue[0.6479667972454549, 1, 0.10281520381398558`], 
        Hue[0.6471786129927874, 1, 0.10390653585614043`], 
        Hue[0.6464564564606162, 1, 0.10490644490068528`], 
        Hue[0.6419821243867047, 1, 0.11110167392610121`], 
        Hue[0.6275873411450932, 1, 0.13103291226064023`], 
        Hue[0.6494616792468535, 1, 0.10074536719666437`], 
        Hue[0.6498378759096498, 1, 0.10022447950971572`], 
        Hue[0.6499689720806963, 1, 0.1000429617344206], 
        Hue[0.6499875610519944, 1, 0.10001722315877695`], 
        Hue[0.6487585552207871, 1, 0.10171892354044876`], 
        Hue[0.6480385917352298, 1, 0.10271579605891265`], 
        Hue[0.6474234415840103, 1, 0.10356754242213963`], 
        Hue[0.6450470004719643, 1, 0.10685799934651109`], 
        Hue[0.6432314603308571, 1, 0.10937182415727481`], 
        Hue[0.6498403530877374, 1, 0.10022104957082521`], 
        Hue[0.6494812112006415, 1, 0.1007183229529579], 
        Hue[0.64887959478411, 1, 0.10155133029892478`], 
        Hue[0.6482450581235274, 1, 0.10242991952126983`], 
        Hue[0.6464564564606162, 1, 0.10490644490068533`], 
        Hue[0.6462861242777769, 1, 0.10514228946153971`], 
        Hue[0.6489591993613006, 1, 0.10144110857666075`], 
        Hue[0.6483341237538893, 1, 0.10230659787923027`], 
        Hue[0.6499875499410278, 1, 0.1000172385431923], 
        Hue[0.6496330749346824, 1, 0.10050805009043981`], 
        Hue[0.649153547214849, 1, 0.10117201154867066`], 
        Hue[0.6474234415840103, 1, 0.10356754242213959`], 
        Hue[0.6473931627551958, 1, 0.10360946695434443`], 
        Hue[0.6495819204903092, 1, 0.10057887932111045`], 
        Hue[0.6497294663699528, 1, 0.10037458502621932`], 
        Hue[0.6499503668772793, 1, 0.10006872278530576`], 
        Hue[0.649813758879976, 1, 0.10025787232003329`], 
        Hue[0.6482450581235273, 1, 0.10242991952126988`], 
        Hue[0.6480385917352297, 1, 0.10271579605891275`], 
        Hue[0.6479667972454548, 1, 0.10281520381398572`], 
        Hue[0.648134546752491, 1, 0.10258293526578166`], 
        Hue[0.6499147887623526, 1, 0.10011798479058873`], 
        Hue[0.6499416771509483, 1, 0.10008075471407167`], 
        Hue[0.6499975662514333, 1, 0.10000336980570773`], 
        Hue[0.649153547214849, 1, 0.10117201154867064`], 
        Hue[0.6488795947841098, 1, 0.10155133029892488`], 
        Hue[0.6487585552207868, 1, 0.10171892354044898`], 
        Hue[0.6499859604962617, 1, 0.10001943931286852`], 
        Hue[0.6499900187740281, 1, 0.1000138201590381], 
        Hue[0.6498137588799761, 1, 0.10025787232003325`], 
        Hue[0.6496330749346824, 1, 0.10050805009043978`], 
        Hue[0.6494812112006415, 1, 0.10071832295295796`], 
        Hue[0.6499981815209614, 1, 0.10000251789405334`], 
        Hue[0.6497732626026614, 1, 0.1003139440886227], 
        Hue[0.6495984682510237, 1, 0.10055596703704402`], 
        Hue[0.6494616792468535, 1, 0.10074536719666437`], 
        Hue[0.6499999519224451, 1, 0.10000006656892216`], 
        Hue[0.6498926261234819, 1, 0.10014867152133289`], 
        Hue[0.6498403530877374, 1, 0.10022104957082523`], 
        Hue[0.6499998205406813, 1, 0.10000024848213372`], 
        Hue[0.6499998222703252, 1, 0.1000002460872421], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499798465258424, 1, 0.10002790481037208`], 
        Hue[0.6498872063550268, 1, 0.10015617581611676`], 
        Hue[0.6498378759096498, 1, 0.10022447950971572`], 
        Hue[0.6499999519224451, 1, 0.10000006656892216`], 
        Hue[0.6499690957937134, 1, 0.10004279043947381`], 
        Hue[0.6499875610519944, 1, 0.10001722315877697`], 
        Hue[0.6499689720806963, 1, 0.1000429617344206], 
        Hue[0.6499875499410278, 1, 0.1000172385431923], 
        Hue[0.6499690478431731, 1, 0.10004285683252959`], 
        Hue[0.6499650382974362, 1, 0.10004840851124211`], 
        Hue[0.6499998988706782, 1, 0.10000014002521485`], 
        Hue[0.6499689178987232, 1, 0.10004303675561406`], 
        Hue[0.6499650303492368, 1, 0.10004841951644139`], 
        Hue[0.6496325065507648, 1, 0.10050883708355646`], 
        Hue[0.6495979512450224, 1, 0.10055668289150747`], 
        Hue[0.6496325065507649, 1, 0.10050883708355643`], 
        Hue[0.6499690478431731, 1, 0.10004285683252959`], 
        Hue[0.6492568700596784, 1, 0.10102894914813774`], 
        Hue[0.6499650382974362, 1, 0.1000484085112421], 
        Hue[0.647733989804249, 1, 0.1031375525787322], 
        Hue[0.6477329026591776, 1, 0.10313905785652336`], 
        Hue[0.6469512230735474, 1, 0.10422138343662676`], 
        Hue[0.6499650303492368, 1, 0.10004841951644142`], 
        Hue[0.6499689178987231, 1, 0.10004303675561409`], 
        Hue[0.6275861158776409, 1, 0.13103460878480497`], 
        Hue[0.6495979512450223, 1, 0.1005566828915077], 
        Hue[0.6469512230735815, 1, 0.10422138343657948`], 
        Hue[0.6499998988706782, 1, 0.10000014002521485`], 
        Hue[0.6492568700596688, 1, 0.10102894914815094`], 
        Hue[0.6477339898042302, 1, 0.10313755257875815`], 
        Hue[0.6275861158776742, 1, 0.13103460878475878`], 
        Hue[0.6477329026592883, 1, 0.10313905785637009`], 
        Hue[0.6477329026591778, 1, 0.10313905785652307`], 
        Hue[0.6275861158775875, 1, 0.1310346087848789], 
        Hue[0.6477339898041263, 1, 0.1031375525789021], 
        Hue[0.6492568700596507, 1, 0.10102894914817598`], 
        Hue[0.6499998988706782, 1, 0.10000014002521485`], 
        Hue[0.6469512230735475, 1, 0.10422138343662657`], 
        Hue[0.6495979512450224, 1, 0.1005566828915075], 
        Hue[0.6499689178987232, 1, 0.10004303675561406`], 
        Hue[0.6275861158775856, 1, 0.13103460878488143`], 
        Hue[0.6499650303492368, 1, 0.10004841951644139`], 
        Hue[0.6499650382974363, 1, 0.10004840851124208`], 
        Hue[0.6469512230736324, 1, 0.10422138343650898`], 
        Hue[0.647732902659307, 1, 0.10313905785634415`], 
        Hue[0.647733989804126, 1, 0.10313755257890245`], 
        Hue[0.6499690478431731, 1, 0.10004285683252957`], 
        Hue[0.6492568700596506, 1, 0.10102894914817606`], 
        Hue[0.6496325065507648, 1, 0.10050883708355651`], 
        Hue[0.6495979512450223, 1, 0.10055668289150767`], 
        Hue[0.6496325065507648, 1, 0.10050883708355657`], 
        Hue[0.6499650303492368, 1, 0.10004841951644142`], 
        Hue[0.6499689178987231, 1, 0.10004303675561409`], 
        Hue[0.6499998988706782, 1, 0.10000014002521485`], 
        Hue[0.6499650382974363, 1, 0.10004840851124208`], 
        Hue[0.6499690478431731, 1, 0.10004285683252959`], 
        Hue[0.6499999477487557, 1, 0.10000007234787675`], 
        Hue[0.6499995415164597, 1, 0.1000006348233636], 
        Hue[0.6499972508920432, 1, 0.10000380645717097`], 
        Hue[0.6499891948964658, 1, 0.10001496091258584`], 
        Hue[0.6499727635994403, 1, 0.10003771193923645`], 
        Hue[0.6499999833152275, 1, 0.10000002310199285`], 
        Hue[0.6499998838143439, 1, 0.10000016087244698`], 
        Hue[0.6499992517330715, 1, 0.10000103606190107`], 
        Hue[0.6499964365371523, 1, 0.10000493402548141`], 
        Hue[0.6499878785449099, 1, 0.10001678355320162`], 
        Hue[0.64997163313836, 1, 0.10003927719303991`], 
        Hue[0.6499995415164597, 1, 0.1000006348233636], 
        Hue[0.6499967956750783, 1, 0.10000443675758397`], 
        Hue[0.6499839080767035, 1, 0.10002228112456447`], 
        Hue[0.6499439425821281, 1, 0.10007761796320734`], 
        Hue[0.6498689637672006, 1, 0.10018143478387614`], 
        Hue[0.6499988129691915, 1, 0.10000164358111958`], 
        Hue[0.6499940313665191, 1, 0.10000826426174277`], 
        Hue[0.6499769587829002, 1, 0.10003190322367668`], 
        Hue[0.6499332213778155, 1, 0.10009246270764012`], 
        Hue[0.6498591025961614, 1, 0.10019508871300734`], 
        Hue[0.6499972508920432, 1, 0.10000380645717097`], 
        Hue[0.6499839080767035, 1, 0.10002228112456447`], 
        Hue[0.6499333273424222, 1, 0.1000923159874155], 
        Hue[0.649802635479388, 1, 0.10027327395161664`], 
        Hue[0.6499910204721564, 1, 0.10001243319239884`], 
        Hue[0.6499648950093987, 1, 0.10004860691006341`], 
        Hue[0.6498924977752071, 1, 0.10014884923432864`], 
        Hue[0.6497443765290007, 1, 0.10035394019061437`], 
        Hue[0.6499891948964658, 1, 0.10001496091258584`], 
        Hue[0.6499439425821281, 1, 0.10007761796320734`], 
        Hue[0.649802635479388, 1, 0.10027327395161664`], 
        Hue[0.649507963302497, 1, 0.10068128158115795`], 
        Hue[0.6499481872069947, 1, 0.10007174079031515`], 
        Hue[0.6498438427337278, 1, 0.1002162177533], 
        Hue[0.6496234428209622, 1, 0.10052138686328319`], 
        Hue[0.6499727635994403, 1, 0.10003771193923645`], 
        Hue[0.6498689637672006, 1, 0.10018143478387613`], 
        Hue[0.6497656401713836, 1, 0.10032449822423818`], 
        Hue[0.6494616592083259, 1, 0.10074539494231807`], 
        Hue[0.649978647617328, 1, 0.10002956483754584`], 
        Hue[0.6441375780758971, 1, 0.10811719958721938`], 
        Hue[0.6432396388960604, 1, 0.1093604999900703], 
        Hue[0.642231751769465, 1, 0.11075603601151002`], 
        Hue[0.6499798790222463, 1, 0.10002785981535132`], 
        Hue[0.6437344762513189, 1, 0.10867534057509703`], 
        Hue[0.6417513908539809, 1, 0.11142115112525726`], 
        Hue[0.6378571080019445, 1, 0.11681323507423075`], 
        Hue[0.6309283188212801, 1, 0.12640694317053525`], 
        Hue[0.6441375780758337, 1, 0.10811719958730724`], 
        Hue[0.6417513908539563, 1, 0.11142115112529143`], 
        Hue[0.6360099177032927, 1, 0.11937088318005631`], 
        Hue[0.6220664870179633, 1, 0.13867717182128156`], 
        Hue[0.5965457485369448, 1, 0.17401357894884573`], 
        Hue[0.6498013526819988, 1, 0.10027505013261706`], 
        Hue[0.6499532866781321, 1, 0.10006467998412484`], 
        Hue[0.6432396388959816, 1, 0.10936049999017944`], 
        Hue[0.6378571080019386, 1, 0.11681323507423888`], 
        Hue[0.6220664870179979, 1, 0.13867717182123368`], 
        Hue[0.5839593231110924, 1, 0.19144093723079508`], 
        Hue[0.5205040684996355, 1, 0.2793020590005047], 
        Hue[0.6496866182982453, 1, 0.10043391312550666`], 
        Hue[0.6499131219491169, 1, 0.10012029268583819`], 
        Hue[0.6499824722110213, 1, 0.10002426924627814`], 
        Hue[0.6422317517694232, 1, 0.11075603601156796`], 
        Hue[0.63092831882132, 1, 0.1264069431704799], 
        Hue[0.5965457485370032, 1, 0.1740135789487649], 
        Hue[0.520504068499611, 1, 0.2793020590005387], 
        Hue[0.6495503990542772, 1, 0.10062252438638544`], 
        Hue[0.6498698870997501, 1, 0.10018015632342288`], 
        Hue[0.6499712182270595, 1, 0.10003985168560998`], 
        Hue[0.6499952676247932, 1, 0.10000655251951718`], 
        Hue[0.6480874779838659, 1, 0.10264810740695487`], 
        Hue[0.6498119241509249, 1, 0.10026041271410392`], 
        Hue[0.6499575857662996, 1, 0.10005872740050828`], 
        Hue[0.6499926578215517, 1, 0.1000101660932362], 
        Hue[0.6499990466030793, 1, 0.10000132008804404`], 
        Hue[0.6499999100348424, 1, 0.10000012456714136`], 
        Hue[0.6499314498889781, 1, 0.10009491553833798`], 
        Hue[0.6499884615950133, 1, 0.10001597625305847`], 
        Hue[0.6499984854790767, 1, 0.10000209702897084`], 
        Hue[0.6499998499633765, 1, 0.10000020774301727`], 
        Hue[0.6499999901267185, 1, 0.10000001367069754`], 
        Hue[0.6499999833152275, 1, 0.10000002310199285`], 
        Hue[0.649999996933637, 1, 0.1000000042457334], 
        Hue[0.6499998838143439, 1, 0.10000016087244698`], 
        Hue[0.6499988129691915, 1, 0.10000164358111958`], 
        Hue[0.6499910204721564, 1, 0.10001243319239884`], 
        Hue[0.6499481872069947, 1, 0.10007174079031517`], 
        Hue[0.6497656401713836, 1, 0.10032449822423817`], 
        Hue[0.6499999689061249, 1, 0.10000004305305792`], 
        Hue[0.6499992517330715, 1, 0.10000103606190107`], 
        Hue[0.6499940313665191, 1, 0.10000826426174277`], 
        Hue[0.6499648950093987, 1, 0.10004860691006343`], 
        Hue[0.6498438427337278, 1, 0.10021621775330003`], 
        Hue[0.6494616592083259, 1, 0.10074539494231807`], 
        Hue[0.6090241519504237, 1, 0.15673578960710566`], 
        Hue[0.6363371711390605, 1, 0.11891776303822395`], 
        Hue[0.6499964365371523, 1, 0.10000493402548141`], 
        Hue[0.6499769587829002, 1, 0.1000319032236767], 
        Hue[0.6498924977752071, 1, 0.10014884923432867`], 
        Hue[0.6496234428209621, 1, 0.10052138686328327`], 
        Hue[0.5138230752066207, 1, 0.2885526650985252], 
        Hue[0.5873524065680152, 1, 0.1867428216750559], 
        Hue[0.6258101614488276, 1, 0.1334936226093157], 
        Hue[0.6398547950462351, 1, 0.11404720685905909`], 
        Hue[0.6499878785449099, 1, 0.10001678355320162`], 
        Hue[0.6499332213778155, 1, 0.10009246270764013`], 
        Hue[0.6497443765290007, 1, 0.10035394019061443`], 
        Hue[0.5873524065680147, 1, 0.18674282167505662`], 
        Hue[0.6206832762213136, 1, 0.14059238677048885`], 
        Hue[0.6364974200212797, 1, 0.11869587997053574`], 
        Hue[0.6423011565880341, 1, 0.11065993703195276`], 
        Hue[0.64997163313836, 1, 0.10003927719303991`], 
        Hue[0.6498591025961614, 1, 0.10019508871300735`], 
        Hue[0.6090241519504225, 1, 0.1567357896071074], 
        Hue[0.625810161448827, 1, 0.1334936226093165], 
        Hue[0.6364974200212795, 1, 0.11869587997053603`], 
        Hue[0.6415696507928466, 1, 0.11167279120990485`], 
        Hue[0.6438278308474126, 1, 0.10854608036512113`], 
        Hue[0.6363371711390599, 1, 0.11891776303822488`], 
        Hue[0.6398547950462348, 1, 0.11404720685905957`], 
        Hue[0.6423011565880339, 1, 0.11065993703195309`], 
        Hue[0.6438278308474125, 1, 0.1085460803651213], 
        Hue[0.6499786571222672, 1, 0.10002955167686084`], 
        Hue[0.6480874779838893, 1, 0.10264810740692248`], 
        Hue[0.6499798927908357, 1, 0.10002784075115065`], 
        Hue[0.6499153777187439, 1, 0.10011716931250861`], 
        Hue[0.6495503990542805, 1, 0.10062252438638086`], 
        Hue[0.6498119241509267, 1, 0.10026041271410145`], 
        Hue[0.6499314498889787, 1, 0.10009491553833723`], 
        Hue[0.6495278596636377, 1, 0.10065373277342475`], 
        Hue[0.6498281137840707, 1, 0.1002379962989791], 
        Hue[0.6499573290700602, 1, 0.10005908282607058`], 
        Hue[0.6496866182982456, 1, 0.10043391312550613`], 
        Hue[0.6498698870997506, 1, 0.10018015632342239`], 
        Hue[0.6499575857662998, 1, 0.100058727400508], 
        Hue[0.6499884615950134, 1, 0.10001597625305839`], 
        Hue[0.6495278596636377, 1, 0.1006537327734248], 
        Hue[0.6497944442738895, 1, 0.10028461562076833`], 
        Hue[0.649935848726795, 1, 0.10008882483982239`], 
        Hue[0.649985852682855, 1, 0.10001958859296996`], 
        Hue[0.6498013526819988, 1, 0.10027505013261703`], 
        Hue[0.6499131219491169, 1, 0.10012029268583815`], 
        Hue[0.6499712182270595, 1, 0.10003985168560994`], 
        Hue[0.6499926578215517, 1, 0.10001016609323618`], 
        Hue[0.6499984854790767, 1, 0.10000209702897084`], 
        Hue[0.6498281137840707, 1, 0.10023799629897913`], 
        Hue[0.649935848726795, 1, 0.10008882483982239`], 
        Hue[0.6499833260191297, 1, 0.10002308705043594`], 
        Hue[0.6499968965922412, 1, 0.10000429702612754`], 
        Hue[0.6499532866781321, 1, 0.10006467998412485`], 
        Hue[0.6499824722110213, 1, 0.10002426924627814`], 
        Hue[0.6499952676247932, 1, 0.10000655251951718`], 
        Hue[0.6499990466030794, 1, 0.10000132008804404`], 
        Hue[0.6499998499633765, 1, 0.10000020774301727`], 
        Hue[0.6499153777187437, 1, 0.10011716931250862`], 
        Hue[0.6499573290700602, 1, 0.10005908282607058`], 
        Hue[0.649985852682855, 1, 0.10001958859296996`], 
        Hue[0.6499968965922412, 1, 0.10000429702612754`], 
        Hue[0.6499995283469943, 1, 0.10000065305800795`], 
        Hue[0.6499999489931797, 1, 0.1000000706248282], 
        Hue[0.649978647617328, 1, 0.10002956483754584`], 
        Hue[0.6499798790222463, 1, 0.10002785981535132`], 
        Hue[0.6499999100348424, 1, 0.10000012456714136`], 
        Hue[0.6499999901267185, 1, 0.10000001367069754`], 
        Hue[0.649999996933637, 1, 0.1000000042457334], 
        Hue[0.6499999689061249, 1, 0.10000004305305792`], 
        Hue[0.6499786571222672, 1, 0.10002955167686084`], 
        Hue[0.6499798927908357, 1, 0.10002784075115065`], 
        Hue[0.6499999489931797, 1, 0.1000000706248282], 
        Hue[0.6499999965648129, 1, 0.100000004756413], 
        Hue[0.6499999965648129, 1, 0.100000004756413], 
        Hue[0.6499999850058028, 1, 0.10000002076119612`], 
        Hue[0.6499999850058028, 1, 0.10000002076119612`], 
        Hue[0.6499999489931797, 1, 0.1000000706248282], 
        Hue[0.6499717446721232, 1, 0.1000391227616756], 
        Hue[0.6499999689061249, 1, 0.10000004305305792`], 
        Hue[0.6499999903087575, 1, 0.10000001341864341`], 
        Hue[0.6499999901267185, 1, 0.10000001367069754`], 
        Hue[0.6499999683904712, 1, 0.1000000437670398], 
        Hue[0.6499999583631957, 1, 0.10000005765095982`], 
        Hue[0.6499999100348424, 1, 0.10000012456714136`], 
        Hue[0.649999996676745, 1, 0.10000000460143], 
        Hue[0.6499999489931797, 1, 0.1000000706248282], 
        Hue[0.6499995283469943, 1, 0.10000065305800795`], 
        Hue[0.6499968965922412, 1, 0.10000429702612754`], 
        Hue[0.649985852682855, 1, 0.10001958859296996`], 
        Hue[0.6499573290700602, 1, 0.10005908282607055`], 
        Hue[0.6499153777187439, 1, 0.1001171693125086], 
        Hue[0.6499534788862268, 1, 0.10006441384983993`], 
        Hue[0.6499998499633765, 1, 0.10000020774301727`], 
        Hue[0.6499990466030794, 1, 0.10000132008804404`], 
        Hue[0.6499952676247932, 1, 0.10000655251951718`], 
        Hue[0.6499824722110213, 1, 0.10002426924627812`], 
        Hue[0.6499532866781321, 1, 0.10006467998412481`], 
        Hue[0.6499968965922412, 1, 0.10000429702612754`], 
        Hue[0.6499833260191297, 1, 0.10002308705043593`], 
        Hue[0.649935848726795, 1, 0.10008882483982234`], 
        Hue[0.6498281137840707, 1, 0.10023799629897905`], 
        Hue[0.6499984854790767, 1, 0.10000209702897084`], 
        Hue[0.6499926578215517, 1, 0.10001016609323618`], 
        Hue[0.6499712182270595, 1, 0.10003985168560994`], 
        Hue[0.6499131219491169, 1, 0.10012029268583812`], 
        Hue[0.6498013526819989, 1, 0.10027505013261694`], 
        Hue[0.649985852682855, 1, 0.10001958859296996`], 
        Hue[0.649935848726795, 1, 0.10008882483982234`], 
        Hue[0.6497944442738897, 1, 0.10028461562076825`], 
        Hue[0.6495278596636378, 1, 0.10065373277342464`], 
        Hue[0.6499884615950133, 1, 0.1000159762530585], 
        Hue[0.6499575857662997, 1, 0.10005872740050815`], 
        Hue[0.6498698870997505, 1, 0.10018015632342248`], 
        Hue[0.6496866182982456, 1, 0.10043391312550612`], 
        Hue[0.6499573290700602, 1, 0.10005908282607055`], 
        Hue[0.6498281137840707, 1, 0.10023799629897903`], 
        Hue[0.6495278596636378, 1, 0.10065373277342463`], 
        Hue[0.6499314498889773, 1, 0.1000949155383391], 
        Hue[0.6498119241509249, 1, 0.10026041271410391`], 
        Hue[0.6495503990542795, 1, 0.10062252438638224`], 
        Hue[0.6499153777187439, 1, 0.10011716931250858`], 
        Hue[0.6438278308474092, 1, 0.10854608036512567`], 
        Hue[0.6423011565880492, 1, 0.11065993703193187`], 
        Hue[0.6398547950463043, 1, 0.11404720685896333`], 
        Hue[0.6363371711392205, 1, 0.11891776303800249`], 
        Hue[0.634412731493343, 1, 0.12158237177844815`], 
        Hue[0.6499717446721232, 1, 0.1000391227616756], 
        Hue[0.6499534788862268, 1, 0.10006441384983993`], 
        Hue[0.643827830847377, 1, 0.1085460803651703], 
        Hue[0.6415696507928302, 1, 0.11167279120992746`], 
        Hue[0.636497420021236, 1, 0.11869587997059636`], 
        Hue[0.625810161448658, 1, 0.13349362260955047`], 
        Hue[0.6090241519500147, 1, 0.15673578960767195`], 
        Hue[0.6498591025961613, 1, 0.10019508871300743`], 
        Hue[0.64997163313836, 1, 0.10003927719303994`], 
        Hue[0.6423011565879951, 1, 0.1106599370320068], 
        Hue[0.63649742002124, 1, 0.11869587997059089`], 
        Hue[0.6206832762210897, 1, 0.14059238677079894`], 
        Hue[0.587352406567333, 1, 0.18674282167600043`], 
        Hue[0.6497443765290006, 1, 0.10035394019061458`], 
        Hue[0.6499332213778155, 1, 0.10009246270764016`], 
        Hue[0.6499878785449099, 1, 0.10001678355320164`], 
        Hue[0.6398547950462775, 1, 0.11404720685900034`], 
        Hue[0.6258101614487078, 1, 0.13349362260948144`], 
        Hue[0.587352406567368, 1, 0.18674282167595202`], 
        Hue[0.5138230752053732, 1, 0.28855266510025257`], 
        Hue[0.6496234428209611, 1, 0.10052138686328474`], 
        Hue[0.649892497775207, 1, 0.10014884923432879`], 
        Hue[0.6499769587829002, 1, 0.10003190322367671`], 
        Hue[0.6499964365371523, 1, 0.10000493402548143`], 
        Hue[0.6363371711392378, 1, 0.11891776303797848`], 
        Hue[0.6344127314933686, 1, 0.12158237177841268`], 
        Hue[0.6090241519500755, 1, 0.15673578960758772`], 
        Hue[0.6494616592083241, 1, 0.10074539494232045`], 
        Hue[0.6498438427337273, 1, 0.10021621775330074`], 
        Hue[0.6499648950093986, 1, 0.1000486069100635], 
        Hue[0.6499940313665191, 1, 0.10000826426174277`], 
        Hue[0.6499992517330715, 1, 0.10000103606190107`], 
        Hue[0.6499999689061249, 1, 0.10000004305305792`], 
        Hue[0.6499999903087575, 1, 0.10000001341864341`], 
        Hue[0.6497656401713869, 1, 0.10032449822423352`], 
        Hue[0.6499481872069948, 1, 0.10007174079031503`], 
        Hue[0.6499910204721564, 1, 0.10001243319239886`], 
        Hue[0.6499988129691915, 1, 0.10000164358111958`], 
        Hue[0.6499998838143439, 1, 0.10000016087244698`], 
        Hue[0.6499999683904712, 1, 0.1000000437670398], 
        Hue[0.6499999583631957, 1, 0.10000005765095982`], 
        Hue[0.6499999901267185, 1, 0.10000001367069754`], 
        Hue[0.6499999583631957, 1, 0.10000005765095982`], 
        Hue[0.6499999683904712, 1, 0.1000000437670398], 
        Hue[0.6499998499633765, 1, 0.10000020774301727`], 
        Hue[0.6499984854790767, 1, 0.10000209702897084`], 
        Hue[0.6499884615950133, 1, 0.1000159762530585], 
        Hue[0.6499314498889773, 1, 0.10009491553833913`], 
        Hue[0.6499999903087575, 1, 0.10000001341864341`], 
        Hue[0.6499999100348424, 1, 0.10000012456714136`], 
        Hue[0.6499990466030794, 1, 0.10000132008804404`], 
        Hue[0.6499926578215517, 1, 0.10001016609323618`], 
        Hue[0.6499575857662997, 1, 0.10005872740050817`], 
        Hue[0.6498119241509249, 1, 0.10026041271410392`], 
        Hue[0.6344127314931636, 1, 0.12158237177869655`], 
        Hue[0.6499952676247932, 1, 0.10000655251951718`], 
        Hue[0.6499712182270595, 1, 0.10003985168560996`], 
        Hue[0.6498698870997505, 1, 0.1001801563234225], 
        Hue[0.6495503990542795, 1, 0.10062252438638229`], 
        Hue[0.5205040685009305, 1, 0.2793020589987117], 
        Hue[0.5965457485375734, 1, 0.1740135789479753], 
        Hue[0.6309283188213023, 1, 0.12640694317050455`], 
        Hue[0.642231751769313, 1, 0.11075603601172052`], 
        Hue[0.6499824722110213, 1, 0.10002426924627812`], 
        Hue[0.6499131219491169, 1, 0.10012029268583815`], 
        Hue[0.6496866182982456, 1, 0.10043391312550619`], 
        Hue[0.5205040685009303, 1, 0.2793020589987119], 
        Hue[0.5839593231117566, 1, 0.19144093722987549`], 
        Hue[0.6220664870181908, 1, 0.13867717182096656`], 
        Hue[0.637857108001951, 1, 0.11681323507422176`], 
        Hue[0.6432396388960145, 1, 0.1093604999901337], 
        Hue[0.6499532866781321, 1, 0.10006467998412481`], 
        Hue[0.6498013526819989, 1, 0.10027505013261696`], 
        Hue[0.5965457485375725, 1, 0.1740135789479767], 
        Hue[0.6220664870181905, 1, 0.13867717182096712`], 
        Hue[0.6360099177033423, 1, 0.11937088317998765`], 
        Hue[0.6417513908539852, 1, 0.11142115112525128`], 
        Hue[0.6441375780758909, 1, 0.10811719958722801`], 
        Hue[0.6499534788862268, 1, 0.1000644138498399], 
        Hue[0.6499717446721233, 1, 0.10003912276167556`], 
        Hue[0.6344127314931625, 1, 0.12158237177869816`], 
        Hue[0.6309283188213016, 1, 0.12640694317050544`], 
        Hue[0.6378571080019506, 1, 0.11681323507422223`], 
        Hue[0.641751390853985, 1, 0.11142115112525151`], 
        Hue[0.6437344762513346, 1, 0.10867534057507511`], 
        Hue[0.6422317517693127, 1, 0.11075603601172099`], 
        Hue[0.6432396388960143, 1, 0.10936049999013404`], 
        Hue[0.6441375780758908, 1, 0.10811719958722825`], 
        Hue[0.6494616592083307, 1, 0.10074539494231151`], 
        Hue[0.6497656401713895, 1, 0.10032449822422998`], 
        Hue[0.6498689637672006, 1, 0.10018143478387617`], 
        Hue[0.6499727635994403, 1, 0.10003771193923647`], 
        Hue[0.6496234428209623, 1, 0.10052138686328298`], 
        Hue[0.6498438427337282, 1, 0.10021621775329947`], 
        Hue[0.6499481872069951, 1, 0.10007174079031451`], 
        Hue[0.6495079633024969, 1, 0.1006812815811581], 
        Hue[0.649802635479388, 1, 0.10027327395161673`], 
        Hue[0.6499439425821281, 1, 0.10007761796320737`], 
        Hue[0.6499891948964658, 1, 0.10001496091258584`], 
        Hue[0.6497443765290007, 1, 0.10035394019061446`], 
        Hue[0.6498924977752071, 1, 0.10014884923432864`], 
        Hue[0.6499648950093987, 1, 0.10004860691006338`], 
        Hue[0.6499910204721564, 1, 0.1000124331923988], 
        Hue[0.6498026354793879, 1, 0.10027327395161674`], 
        Hue[0.6499333273424222, 1, 0.10009231598741554`], 
        Hue[0.6499839080767035, 1, 0.10002228112456447`], 
        Hue[0.6499972508920432, 1, 0.10000380645717097`], 
        Hue[0.6498591025961613, 1, 0.10019508871300745`], 
        Hue[0.6499332213778155, 1, 0.10009246270764016`], 
        Hue[0.6499769587829002, 1, 0.1000319032236767], 
        Hue[0.6499940313665191, 1, 0.10000826426174277`], 
        Hue[0.6499988129691915, 1, 0.10000164358111958`], 
        Hue[0.6499534788862268, 1, 0.10006441384983988`], 
        Hue[0.6498689637672006, 1, 0.1001814347838762], 
        Hue[0.6499439425821281, 1, 0.10007761796320738`], 
        Hue[0.6499839080767035, 1, 0.10002228112456449`], 
        Hue[0.6499967956750783, 1, 0.10000443675758397`], 
        Hue[0.6499995415164597, 1, 0.1000006348233636], 
        Hue[0.649999996676745, 1, 0.10000000460143], 
        Hue[0.64997163313836, 1, 0.10003927719303995`], 
        Hue[0.6499878785449099, 1, 0.10001678355320164`], 
        Hue[0.6499964365371523, 1, 0.10000493402548143`], 
        Hue[0.6499992517330715, 1, 0.10000103606190107`], 
        Hue[0.6499998838143439, 1, 0.10000016087244698`], 
        Hue[0.6499999583631957, 1, 0.10000005765095982`], 
        Hue[0.6499999683904712, 1, 0.1000000437670398], 
        Hue[0.6499999903087575, 1, 0.10000001341864341`], 
        Hue[0.6499717446721233, 1, 0.10003912276167556`], 
        Hue[0.6499727635994403, 1, 0.10003771193923647`], 
        Hue[0.6499891948964658, 1, 0.10001496091258585`], 
        Hue[0.6499972508920432, 1, 0.10000380645717098`], 
        Hue[0.6499995415164597, 1, 0.1000006348233636], 
        Hue[0.6499999477487557, 1, 0.10000007234787675`], 
        Hue[0.6499999850058028, 1, 0.10000002076119612`], 
        Hue[0.6499999850058028, 1, 0.10000002076119612`], 
        Hue[0.6499999925396918, 1, 0.10000001032965763`], 
        Hue[0.6499999924509668, 1, 0.1000000104525075], 
        Hue[0.6499999714959052, 1, 0.10000003946720826`], 
        Hue[0.6499999718281185, 1, 0.1000000390072206], 
        Hue[0.6499999714959052, 1, 0.10000003946720826`], 
        Hue[0.6499999987909204, 1, 0.1000000016741103], 
        Hue[0.6499999924509668, 1, 0.1000000104525075], 
        Hue[0.6499798927908357, 1, 0.10002784075115066`], 
        Hue[0.6499786439810903, 1, 0.10002956987233663`], 
        Hue[0.6499786571222672, 1, 0.10002955167686085`], 
        Hue[0.6499999958851704, 1, 0.10000000569745643`], 
        Hue[0.6499999823388529, 1, 0.10000002445389598`], 
        Hue[0.649999996933637, 1, 0.1000000042457334], 
        Hue[0.6499999968907343, 1, 0.1000000043051372], 
        Hue[0.6499999834633291, 1, 0.10000002289692897`], 
        Hue[0.6499999747414913, 1, 0.10000003497331982`], 
        Hue[0.6499999923535981, 1, 0.10000001058732584`], 
        Hue[0.6499999790874041, 1, 0.10000002895590207`], 
        Hue[0.6499999843722919, 1, 0.10000002163836517`], 
        Hue[0.6499999820241611, 1, 0.10000002488962312`], 
        Hue[0.6499999385497581, 1, 0.10000008508495034`], 
        Hue[0.6499999199446159, 1, 0.10000011084591645`], 
        Hue[0.649999930191259, 1, 0.10000009665825685`], 
        Hue[0.6499798790222463, 1, 0.1000278598153513], 
        Hue[0.6499786432660215, 1, 0.10002957086243183`], 
        Hue[0.649978647617328, 1, 0.10002956483754584`], 
        Hue[0.6499999988522372, 1, 0.10000000158920994`], 
        Hue[0.6499999726116505, 1, 0.10000003792233012`], 
        Hue[0.6499885213023262, 1, 0.10001589358139451`], 
        Hue[0.6499316532667695, 1, 0.10009463393831913`], 
        Hue[0.648088593100504, 1, 0.10264656339930217`], 
        Hue[0.6480874779837993, 1, 0.10264810740704716`], 
        Hue[0.6499798927908357, 1, 0.10002784075115066`], 
        Hue[0.6499786439810903, 1, 0.10002956987233663`], 
        Hue[0.6499872728813456, 1, 0.10001762216429065`], 
        Hue[0.6499786571222672, 1, 0.10002955167686085`], 
        Hue[0.6499872851621001, 1, 0.10001760516016904`], 
        Hue[0.6499786432660215, 1, 0.10002957086243185`], 
        Hue[0.6480885931004806, 1, 0.10264656339933452`], 
        Hue[0.6499999531810358, 1, 0.10000006482625813`], 
        Hue[0.6499999385497581, 1, 0.10000008508495034`], 
        Hue[0.649999996933637, 1, 0.1000000042457334], 
        Hue[0.6499999834633291, 1, 0.10000002289692897`], 
        Hue[0.6499999968907343, 1, 0.1000000043051372], 
        Hue[0.6499999846564967, 1, 0.10000002124485077`], 
        Hue[0.6499999823388529, 1, 0.10000002445389598`], 
        Hue[0.6499885213023262, 1, 0.1000158935813946], 
        Hue[0.649931653266769, 1, 0.10009463393831988`], 
        Hue[0.6499999199446159, 1, 0.10000011084591645`], 
        Hue[0.649999930191259, 1, 0.10000009665825685`], 
        Hue[0.6499999957862591, 1, 0.10000000583441045`], 
        Hue[0.6499999820241611, 1, 0.10000002488962312`], 
        Hue[0.6499999833152275, 1, 0.10000002310199285`], 
        Hue[0.6499999968907343, 1, 0.1000000043051372], 
        Hue[0.6499999834633291, 1, 0.10000002289692897`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499999946476501, 1, 0.10000000741094602`], 
        Hue[0.6499999923535981, 1, 0.10000001058732584`], 
        Hue[0.6499999790874041, 1, 0.10000002895590207`], 
        Hue[0.6499316532667682, 1, 0.10009463393832103`], 
        Hue[0.6499885213023261, 1, 0.10001589358139462`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499999924343713, 1, 0.10000001047548586`], 
        Hue[0.649999930191259, 1, 0.10000009665825685`], 
        Hue[0.6499999459827224, 1, 0.1000000747931536], 
        Hue[0.6499999385497581, 1, 0.10000008508495034`], 
        Hue[0.6499999957862591, 1, 0.10000000583441045`], 
        Hue[0.6499999820241611, 1, 0.10000002488962312`], 
        Hue[0.6499999846564967, 1, 0.10000002124485077`], 
        Hue[0.6499999823388529, 1, 0.10000002445389598`], 
        Hue[0.6499999531810358, 1, 0.10000006482625813`], 
        Hue[0.6480874779837994, 1, 0.10264810740704695`], 
        Hue[0.6480885931004169, 1, 0.10264656339942274`], 
        Hue[0.6499798790222463, 1, 0.1000278598153513], 
        Hue[0.6499786432660215, 1, 0.10002957086243183`], 
        Hue[0.6499872851621001, 1, 0.10001760516016903`], 
        Hue[0.649978647617328, 1, 0.10002956483754584`], 
        Hue[0.6499872728813457, 1, 0.10001762216429065`], 
        Hue[0.6480885931004168, 1, 0.10264656339942299`], 
        Hue[0.6499786439810903, 1, 0.10002956987233662`], 
        Hue[0.6499316532667682, 1, 0.100094633938321], 
        Hue[0.6499885213023261, 1, 0.10001589358139462`], 
        Hue[0.649999930191259, 1, 0.10000009665825685`], 
        Hue[0.6499999833152275, 1, 0.10000002310199285`], 
        Hue[0.6499999834633291, 1, 0.10000002289692897`], 
        Hue[0.6499999968907343, 1, 0.1000000043051372], 
        Hue[0.6499999726116505, 1, 0.10000003792233012`], 
        Hue[0.6499999714959052, 1, 0.10000003946720826`], 
        Hue[0.6499999988522372, 1, 0.10000000158920994`], 
        Hue[0.6499786432660215, 1, 0.10002957086243186`], 
        Hue[0.6499999459827224, 1, 0.1000000747931536], 
        Hue[0.6499999385497581, 1, 0.10000008508495034`], 
        Hue[0.6499999946476501, 1, 0.10000000741094602`], 
        Hue[0.6499999790874041, 1, 0.10000002895590207`], 
        Hue[0.6499999923535981, 1, 0.10000001058732584`], 
        Hue[0.6499999843722919, 1, 0.10000002163836517`], 
        Hue[0.6499999820241611, 1, 0.10000002488962312`], 
        Hue[0.6499999947460028, 1, 0.10000000727476545`], 
        Hue[0.6499999924343713, 1, 0.10000001047548586`], 
        Hue[0.6499999958851704, 1, 0.10000000569745643`], 
        Hue[0.6499999823388529, 1, 0.10000002445389598`], 
        Hue[0.6499786439810903, 1, 0.10002956987233662`], 
        Hue[0.6499999718281185, 1, 0.1000000390072206], 
        Hue[0.6499999714959052, 1, 0.10000003946720826`], 
        Hue[0.6499999987909204, 1, 0.1000000016741103], 
        Hue[0.6499999924509668, 1, 0.1000000104525075], 
        Hue[0.6499999925396918, 1, 0.10000001032965763`], 
        Hue[0.6499999924509668, 1, 0.1000000104525075], 
        Hue[0.6499872705232843, 1, 0.10001762542929866`], 
        Hue[0.6499999924343713, 1, 0.10000001047548586`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499872761827475, 1, 0.1000176175931189], 
        Hue[0.6499999947460028, 1, 0.10000000727476545`], 
        Hue[0.6499999924343713, 1, 0.10000001047548586`], 
        Hue[0.6499999747414913, 1, 0.10000003497331982`], 
        Hue[0.6499999790874041, 1, 0.10000002895590207`], 
        Hue[0.6499999923535981, 1, 0.10000001058732584`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499872761827474, 1, 0.1000176175931189], 
        Hue[0.6499872705232843, 1, 0.10001762542929865`], 
        Hue[0.6499999987909204, 1, 0.1000000016741103], 
        Hue[0.6499999718281185, 1, 0.1000000390072206], 
        Hue[0.6499998378409675, 1, 0.10000022452789123`], 
        Hue[0.6499999925396918, 1, 0.10000001032965763`], 
        Hue[0.6499999726116505, 1, 0.10000003792233012`], 
        Hue[0.6499998474023537, 1, 0.10000021128904879`], 
        Hue[0.6499987373870405, 1, 0.1000017482333285], 
        Hue[0.6499930394481843, 1, 0.10000963768712945`], 
        Hue[0.6499740840158208, 1, 0.10003588367040199`], 
        Hue[0.6499368000496959, 1, 0.10008750762349808`], 
        Hue[0.6499872851621001, 1, 0.10001760516016904`], 
        Hue[0.6499997694648034, 1, 0.10000031920257986`], 
        Hue[0.6499999846564967, 1, 0.10000002124485077`], 
        Hue[0.6499999947460028, 1, 0.10000000727476545`], 
        Hue[0.6499999946476501, 1, 0.10000000741094602`], 
        Hue[0.6499999328468428, 1, 0.1000000929812946], 
        Hue[0.6499999957862591, 1, 0.10000000583441045`], 
        Hue[0.6499999459827224, 1, 0.1000000747931536], 
        Hue[0.6499996132007059, 1, 0.10000053556825345`], 
        Hue[0.6499999531810358, 1, 0.10000006482625813`], 
        Hue[0.6499997664208694, 1, 0.1000003234172578], 
        Hue[0.6499978004542722, 1, 0.1000030455248539], 
        Hue[0.649990533972543, 1, 0.1000131068072481], 
        Hue[0.6499701121736939, 1, 0.10004138314411615`], 
        Hue[0.6499332456084079, 1, 0.10009242915758908`], 
        Hue[0.6499872728813457, 1, 0.10001762216429065`], 
        Hue[0.6499999988522372, 1, 0.10000000158920994`], 
        Hue[0.6499997205474622, 1, 0.10000038693428308`], 
        Hue[0.6499988198134662, 1, 0.1000016341044314], 
        Hue[0.649997998599588, 1, 0.10000277116980137`], 
        Hue[0.6499925051018157, 1, 0.10001037755133219`], 
        Hue[0.6499899497720244, 1, 0.10001391570027392`], 
        Hue[0.6499658530333119, 1, 0.10004728041541434`], 
        Hue[0.6498899315253245, 1, 0.10015240250339691`], 
        Hue[0.6498257856160936, 1, 0.10024121991617815`], 
        Hue[0.6498206455449007, 1, 0.10024833693782984`], 
        Hue[0.6499999333097417, 1, 0.10000009234035774`], 
        Hue[0.6499999042768432, 1, 0.1000001325397556], 
        Hue[0.6499993878957052, 1, 0.10000084752902356`], 
        Hue[0.6499966175523572, 1, 0.10000468338904392`], 
        Hue[0.6499967448026513, 1, 0.10000450719632889`], 
        Hue[0.6499849888742334, 1, 0.1000207846356768], 
        Hue[0.6499482995199596, 1, 0.10007158528005594`], 
        Hue[0.6498637789166501, 1, 0.10018861380771515`], 
        Hue[0.6498245814294037, 1, 0.10024288725159497`], 
        Hue[0.6498206206758443, 1, 0.10024837137190787`], 
        Hue[0.6499980650680817, 1, 0.10000267913650228`], 
        Hue[0.6499887061646138, 1, 0.10001563761822711`], 
        Hue[0.6499957081322433, 1, 0.10000594258612468`], 
        Hue[0.6499929243432877, 1, 0.10000979706314017`], 
        Hue[0.6499949826603763, 1, 0.10000694708563292`], 
        Hue[0.6499777227220929, 1, 0.10003084546171759`], 
        Hue[0.6499234404741348, 1, 0.1001060054973519], 
        Hue[0.6497919036628964, 1, 0.1002881333898358], 
        Hue[0.6494291374898146, 1, 0.1007904250141029], 
        Hue[0.6499942406207414, 1, 0.10000797452512729`], 
        Hue[0.6499908589738949, 1, 0.10001265680537647`], 
        Hue[0.6499711554269493, 1, 0.10003993863960878`], 
        Hue[0.6499552803098146, 1, 0.10006191957102599`], 
        Hue[0.6499690892099143, 1, 0.10004279955550338`], 
        Hue[0.649886621235013, 1, 0.10015698598228986`], 
        Hue[0.6497011754290651, 1, 0.1004137570982175], 
        Hue[0.6495400008935742, 1, 0.10063692183966653`], 
        Hue[0.6498257856160936, 1, 0.10024121991617815`], 
        Hue[0.6496731893555393, 1, 0.10045250704617642`], 
        Hue[0.6496727141920235, 1, 0.10045316496489053`], 
        Hue[0.6499872705232843, 1, 0.10001762542929866`], 
        Hue[0.6498206455449007, 1, 0.10024833693782982`], 
        Hue[0.6498245814294036, 1, 0.10024288725159507`], 
        Hue[0.6430994341869618, 1, 0.10955462958728375`], 
        Hue[0.6431138697201356, 1, 0.10953464192596608`], 
        Hue[0.6494291374898145, 1, 0.10079042501410311`], 
        Hue[0.649461400807902, 1, 0.10074575272752026`], 
        Hue[0.6498376968729129, 1, 0.10022472740673605`], 
        Hue[0.6499872761827474, 1, 0.1000176175931189], 
        Hue[0.6319953620941587, 1, 0.12492949863885709`], 
        Hue[0.6227153440039706, 1, 0.13777875445604082`], 
        Hue[0.6233200715729882, 1, 0.1369414393604779], 
        Hue[0.6499334584002099, 1, 0.10009213452278638`], 
        Hue[0.6499332456084078, 1, 0.10009242915758913`], 
        Hue[0.6499558704947553, 1, 0.10006110239187734`], 
        Hue[0.6498637789166501, 1, 0.10018861380771525`], 
        Hue[0.6499035776827975, 1, 0.1001335078238189], 
        Hue[0.6499701121736939, 1, 0.10004138314411617`], 
        Hue[0.6499807215560938, 1, 0.10002669323002401`], 
        Hue[0.649791903662896, 1, 0.10028813338983632`], 
        Hue[0.6498491275148004, 1, 0.10020890036412251`], 
        Hue[0.6499482995199596, 1, 0.100071585280056], 
        Hue[0.6499651447615216, 1, 0.10004826109943168`], 
        Hue[0.649990533972543, 1, 0.10001310680724812`], 
        Hue[0.6499941257642842, 1, 0.10000813355714501`], 
        Hue[0.6499978004542722, 1, 0.10000304552485391`], 
        Hue[0.6499997664208694, 1, 0.1000003234172578], 
        Hue[0.6499999113420365, 1, 0.10000012275718022`], 
        Hue[0.649701175429064, 1, 0.10041375709821909`], 
        Hue[0.6497822958439443, 1, 0.10030143652376938`], 
        Hue[0.6499234404741345, 1, 0.10010600549735216`], 
        Hue[0.6499477127625017, 1, 0.10007239771345909`], 
        Hue[0.6499777227220929, 1, 0.1000308454617176], 
        Hue[0.6499849888742334, 1, 0.10002078463567683`], 
        Hue[0.6499904461340845, 1, 0.10001322842972922`], 
        Hue[0.6499966175523572, 1, 0.10000468338904392`], 
        Hue[0.6499987037961257, 1, 0.1000017947438261], 
        Hue[0.6499996132007059, 1, 0.10000053556825345`], 
        Hue[0.6499999459827224, 1, 0.1000000747931536], 
        Hue[0.6499999958851704, 1, 0.10000000569745643`], 
        Hue[0.6499957081322433, 1, 0.1000059425861247], 
        Hue[0.649971155426949, 1, 0.10003993863960904`], 
        Hue[0.6495407493861274, 1, 0.10063588546536209`], 
        Hue[0.6227153440039657, 1, 0.1377787544560476], 
        Hue[0.06744763098817208, 1, 0.9066109724779156], 
        Hue[0.03698777989743762, 1, 0.9487861509112402], 
        Hue[0.02100855953590086, 1, 0.9709112252579835], 
        Hue[0.06747929559368648, 1, 0.9065671291779726], 
        Hue[0.021017919604245705`, 1, 0.9708982651633521], 
        Hue[0.004312626695720967, 1, 0.9940286707290017], 
        Hue[0.06747929559223431, 1, 0.9065671291799833], 
        Hue[0.622715344004319, 1, 0.13777875445555823`], 
        Hue[0.6430994341870176, 1, 0.1095546295872063], 
        Hue[0.649540000893586, 1, 0.10063692183965024`], 
        Hue[0.6496696618168508, 1, 0.10045739133051425`], 
        Hue[0.6496727141920339, 1, 0.10045316496487627`], 
        Hue[0.6498866212350136, 1, 0.10015698598228884`], 
        Hue[0.6499227855829618, 1, 0.10010691226974526`], 
        Hue[0.6499857386104357, 1, 0.10001974653939676`], 
        Hue[0.6499979781484426, 1, 0.10000279948677178`], 
        Hue[0.6499997857288967, 1, 0.10000029668306615`], 
        Hue[0.6499999328468428, 1, 0.1000000929812946], 
        Hue[0.6499999843722919, 1, 0.10000002163836517`], 
        Hue[0.6499999946476501, 1, 0.10000000741094602`], 
        Hue[0.6499999333097417, 1, 0.10000009234035774`], 
        Hue[0.6499999747414913, 1, 0.10000003497331982`], 
        Hue[0.6499995050240461, 1, 0.10000068535132074`], 
        Hue[0.6499956798469451, 1, 0.10000598175038378`], 
        Hue[0.6499710401022167, 1, 0.10004009832000761`], 
        Hue[0.6430994341869646, 1, 0.10955462958727992`], 
        Hue[0.6431138697201368, 1, 0.1095346419259644], 
        Hue[0.6233200715729781, 1, 0.13694143936049186`], 
        Hue[0.004309068890287815, 1, 0.9940335969211399], 
        Hue[0.02101791960398325, 1, 0.9708982651637156], 
        Hue[0.03701244893325295, 1, 0.9487519937847267], 
        Hue[0.021017919602528856`, 1, 0.9708982651657293], 
        Hue[0.004309068888626699, 1, 0.99403359692344], 
        Hue[0.02100855953301084, 1, 0.9709112252619849], 
        Hue[0.06744763098356343, 1, 0.9066109724842968], 
        Hue[0.6233201302809892, 1, 0.13694135807247645`], 
        Hue[0.6496731893555265, 1, 0.10045250704619413`], 
        Hue[0.6499999658355468, 1, 0.10000004730462761`], 
        Hue[0.6499999333097417, 1, 0.10000009234035774`], 
        Hue[0.6499999947460028, 1, 0.10000000727476545`], 
        Hue[0.6499999199446159, 1, 0.10000011084591645`], 
        Hue[0.6499996941293525, 1, 0.10000042351320422`], 
        Hue[0.6499999843722919, 1, 0.10000002163836517`], 
        Hue[0.6499991262252099, 1, 0.10000120984201699`], 
        Hue[0.6499972533523636, 1, 0.1000038030505735], 
        Hue[0.6499928827959313, 1, 0.10000985459024907`], 
        Hue[0.6499817331204784, 1, 0.10002529260241469`], 
        Hue[0.6499551253828276, 1, 0.1000621340853157], 
        Hue[0.021017919602568935`, 1, 0.9708982651656738], 
        Hue[0.03698777989336832, 1, 0.9487861509168746], 
        Hue[0.6499711554269488, 1, 0.10003993863960928`], 
        Hue[0.6499957081322433, 1, 0.1000059425861247], 
        Hue[0.6499999958851704, 1, 0.10000000569745643`], 
        Hue[0.649999454487984, 1, 0.10000075532432992`], 
        Hue[0.6499983016594818, 1, 0.10000235154840982`], 
        Hue[0.6499954680826809, 1, 0.10000627496244185`], 
        Hue[0.6499719284481866, 1, 0.10003886830251078`], 
        Hue[0.6499999113420365, 1, 0.10000012275718022`], 
        Hue[0.6499997694648034, 1, 0.10000031920257986`], 
        Hue[0.6499971342997227, 1, 0.10000396789269159`], 
        Hue[0.6499878647654108, 1, 0.1000168026325082], 
        Hue[0.649981132862961, 1, 0.10002612372820785`], 
        Hue[0.6499931260501088, 1, 0.1000095177767724], 
        Hue[0.6499888903804653, 1, 0.10001538255012504`], 
        Hue[0.6319953620942506, 1, 0.12492949863873], 
        Hue[0.6353293129837486, 1, 0.12031325894557884`], 
        Hue[0.6498245814294037, 1, 0.10024288725159497`], 
        Hue[0.6494291374898146, 1, 0.10079042501410287`], 
        Hue[0.622715344004306, 1, 0.13777875445557644`], 
        Hue[0.6233201302809824, 1, 0.13694135807248597`], 
        Hue[0.6499872761827475, 1, 0.1000176175931189], 
        Hue[0.6498206206758443, 1, 0.10024837137190785`], 
        Hue[0.6430994341870134, 1, 0.10955462958721218`], 
        Hue[0.6498257856160936, 1, 0.1002412199161781], 
        Hue[0.6498401940009914, 1, 0.1002212698447812], 
        Hue[0.6499872705232843, 1, 0.10001762542929865`], 
        Hue[0.6495407493861158, 1, 0.10063588546537817`], 
        Hue[0.6499710401022171, 1, 0.10004009832000711`], 
        Hue[0.6499368000496959, 1, 0.1000875076234981], 
        Hue[0.6499579090308498, 1, 0.10005827980343877`], 
        Hue[0.6499817331204784, 1, 0.10002529260241466`], 
        Hue[0.6499956798469451, 1, 0.10000598175038375`], 
        Hue[0.6499711554269488, 1, 0.10003993863960926`], 
        Hue[0.6498899315253245, 1, 0.10015240250339695`], 
        Hue[0.649920525041201, 1, 0.10011004225064477`], 
        Hue[0.6499740840158208, 1, 0.10003588367040202`], 
        Hue[0.6499830415932077, 1, 0.10002348087094316`], 
        Hue[0.6499930394481843, 1, 0.10000963768712946`], 
        Hue[0.6494291374898145, 1, 0.10079042501410312`], 
        Hue[0.649461400807902, 1, 0.10074575272752026`], 
        Hue[0.6499878647654108, 1, 0.1000168026325082], 
        Hue[0.6499871127135868, 1, 0.10001784393503366`], 
        Hue[0.6499972533523636, 1, 0.1000038030505735], 
        Hue[0.6499995050240461, 1, 0.10000068535132073`], 
        Hue[0.6499957081322433, 1, 0.1000059425861247], 
        Hue[0.6499658530333119, 1, 0.10004728041541437`], 
        Hue[0.649976311639638, 1, 0.10003279926819361`], 
        Hue[0.6499925051018156, 1, 0.1000103775513322], 
        Hue[0.6499955738243941, 1, 0.1000061285508389], 
        Hue[0.6499987373870405, 1, 0.1000017482333285], 
        Hue[0.6499998474023537, 1, 0.10000021128904879`], 
        Hue[0.6498245814294036, 1, 0.10024288725159508`], 
        Hue[0.6498376968729129, 1, 0.10022472740673605`], 
        Hue[0.6499931260501088, 1, 0.1000095177767724], 
        Hue[0.6499983016594818, 1, 0.10000235154840982`], 
        Hue[0.6499981812644314, 1, 0.10000251824924883`], 
        Hue[0.6499996941293525, 1, 0.10000042351320422`], 
        Hue[0.6499999199446159, 1, 0.10000011084591645`], 
        Hue[0.6499999333097417, 1, 0.10000009234035774`], 
        Hue[0.6499999661022928, 1, 0.10000004693528683`], 
        Hue[0.6499334584002099, 1, 0.10009213452278633`], 
        Hue[0.6499560274362279, 1, 0.10006088508829983`], 
        Hue[0.6498257856160936, 1, 0.10024121991617813`], 
        Hue[0.6498401940009914, 1, 0.10022126984478122`], 
        Hue[0.6499942406207414, 1, 0.10000797452512729`], 
        Hue[0.649995048229519, 1, 0.10000685629758907`], 
        Hue[0.6499988198134662, 1, 0.1000016341044314], 
        Hue[0.649999231209965, 1, 0.10000106447851004`], 
        Hue[0.6499998378409675, 1, 0.10000022452789123`], 
        Hue[0.6499999718281185, 1, 0.1000000390072206], 
        Hue[0.6499999988522372, 1, 0.10000000158920994`], 
        Hue[0.6499872728813456, 1, 0.10001762216429065`], 
        Hue[0.649998861931212, 1, 0.10000157578755257`], 
        Hue[0.6499998099007703, 1, 0.10000026321431808`], 
        Hue[0.6499999531810358, 1, 0.10000006482625813`], 
        Hue[0.6499999747414913, 1, 0.10000003497331982`], 
        Hue[0.6499999957862591, 1, 0.10000000583441045`], 
        Hue[0.6499999846564967, 1, 0.10000002124485076`], 
        Hue[0.6499872851621001, 1, 0.10001760516016903`], 
        Hue[0.6499992554553338, 1, 0.10000103090799936`], 
        Hue[0.6499999068044836, 1, 0.10000012903994587`], 
        Hue[0.6499999726116505, 1, 0.10000003792233012`], 
        Hue[0.6499999925396918, 1, 0.10000001032965763`], 
        Hue[0.6499999987909204, 1, 0.1000000016741103], 
        Hue[0.6499182640119672, 1, 0.10011317290650702`], 
        Hue[0.6499998703971854, 1, 0.100000179450051], 
        Hue[0.6499179671599283, 1, 0.10011358393240688`], 
        Hue[0.6499999490745912, 1, 0.10000007051210441`], 
        Hue[0.6499182640119672, 1, 0.10011317290650702`], 
        Hue[0.6499453175635969, 1, 0.10007571414271206`], 
        Hue[0.6463627197888726, 1, 0.10503623413848405`], 
        Hue[0.6458360441378571, 1, 0.10576547734758247`], 
        Hue[0.6499904192577803, 1, 0.1000132656430734], 
        Hue[0.6499855624175456, 1, 0.10001999049878305`], 
        Hue[0.6499947544739892, 1, 0.100007263036015], 
        Hue[0.6499927474735677, 1, 0.10001004195967546`], 
        Hue[0.6499980833227129, 1, 0.10000265386085902`], 
        Hue[0.6499975602665753, 1, 0.10000337809243423`], 
        Hue[0.6499995339718821, 1, 0.10000064526970168`], 
        Hue[0.649999442352031, 1, 0.10000077212795708`], 
        Hue[0.6499998703971854, 1, 0.100000179450051], 
        Hue[0.6499999589602237, 1, 0.1000000568243058], 
        Hue[0.6369343337826544, 1, 0.11809092245478625`], 
        Hue[0.6233200715735031, 1, 0.13694143935976502`], 
        Hue[0.6463627197890695, 1, 0.10503623413821153`], 
        Hue[0.6431138697203481, 1, 0.10953464192567193`], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.649952257675664, 1, 0.100066104756773], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499930428076302, 1, 0.10000963303558903`], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499992118878316, 1, 0.10000109123223314`], 
        Hue[0.646362719788873, 1, 0.10503623413848345`], 
        Hue[0.647195627881372, 1, 0.10388297677963883`], 
        Hue[0.6458360441378573, 1, 0.10576547734758222`], 
        Hue[0.6464975004715674, 1, 0.10484961473167599`], 
        Hue[0.6453822585486565, 1, 0.10639379585570642`], 
        Hue[0.6451837682394977, 1, 0.10666862859146468`], 
        Hue[0.6233200715734802, 1, 0.1369414393597967], 
        Hue[0.6369343337826358, 1, 0.11809092245481205`], 
        Hue[0.6466909526577987, 1, 0.10458175785843253`], 
        Hue[0.6464557249198083, 1, 0.10490745780334242`], 
        Hue[0.6499179671599284, 1, 0.10011358393240688`], 
        Hue[0.6499452554080252, 1, 0.10007580020427294`], 
        Hue[0.6431138697203426, 1, 0.10953464192567951`], 
        Hue[0.6463627197890748, 1, 0.10503623413820415`], 
        Hue[0.6453822585486565, 1, 0.10639379585570649`], 
        Hue[0.6474229577245602, 1, 0.10356821238137827`], 
        Hue[0.6464557249198084, 1, 0.10490745780334221`], 
        Hue[0.646690952657799, 1, 0.10458175785843228`], 
        Hue[0.6474229577245603, 1, 0.10356821238137813`], 
        Hue[0.6499904693183663, 1, 0.1000131963284158], 
        Hue[0.6499857545886895, 1, 0.10001972441566084`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6499949320825263, 1, 0.10000701711650203`], 
        Hue[0.6499931307624713, 1, 0.10000951125196281`], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499982711804069, 1, 0.10000239375020598`], 
        Hue[0.6499978877143096, 1, 0.10000292470326372`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499996319583529, 1, 0.1000005095961268], 
        Hue[0.649999590533435, 1, 0.1000005669537054], 
        Hue[0.6499999490745912, 1, 0.10000007051210441`], 
        Hue[0.6499999853568917, 1, 0.10000002027507307`], 
        Hue[0.6499904192577803, 1, 0.1000132656430734], 
        Hue[0.6499947544739892, 1, 0.100007263036015], 
        Hue[0.6499980833227129, 1, 0.10000265386085902`], 
        Hue[0.6499995339718821, 1, 0.10000064526970168`], 
        Hue[0.6499904693183663, 1, 0.1000131963284158], 
        Hue[0.6499949320825263, 1, 0.10000701711650203`], 
        Hue[0.6499982711804069, 1, 0.10000239375020598`], 
        Hue[0.6499996319583529, 1, 0.1000005095961268], 
        Hue[0.6499996319583529, 1, 0.1000005095961268], 
        Hue[0.649999590533435, 1, 0.1000005669537054], 
        Hue[0.6499982711804069, 1, 0.10000239375020598`], 
        Hue[0.6499978877143096, 1, 0.10000292470326372`], 
        Hue[0.6499949320825263, 1, 0.10000701711650203`], 
        Hue[0.6499931307624713, 1, 0.1000095112519628], 
        Hue[0.6499904693183663, 1, 0.10001319632841578`], 
        Hue[0.6499857545886895, 1, 0.10001972441566084`], 
        Hue[0.649982351773809, 1, 0.10002443600549525`], 
        Hue[0.6499904494586252, 1, 0.10001322382651898`], 
        Hue[0.6499947848408922, 1, 0.10000722098953381`], 
        Hue[0.6499981001297528, 1, 0.10000263058957315`], 
        Hue[0.6499852938294347, 1, 0.10002036239001359`], 
        Hue[0.6499995394710767, 1, 0.10000063765543235`], 
        Hue[0.6499958918832327, 1, 0.10000568816167785`], 
        Hue[0.6499995339718821, 1, 0.10000064526970168`], 
        Hue[0.649999442352031, 1, 0.10000077212795708`], 
        Hue[0.6499980833227129, 1, 0.100002653860859], 
        Hue[0.6499975602665753, 1, 0.10000337809243423`], 
        Hue[0.6499947544739892, 1, 0.100007263036015], 
        Hue[0.6499927474735677, 1, 0.10001004195967544`], 
        Hue[0.6499904192577803, 1, 0.10001326564307339`], 
        Hue[0.6499855624175456, 1, 0.10001999049878303`], 
        Hue[0.649982271892414, 1, 0.10002454661050371`], 
        Hue[0.6499905001789897, 1, 0.10001315359832193`], 
        Hue[0.649994966060422, 1, 0.10000697007018497`], 
        Hue[0.6499652560339055, 1, 0.10004810702997693`], 
        Hue[0.6499982896776413, 1, 0.10000236813865063`], 
        Hue[0.6499874785448396, 1, 0.10001733739945283`], 
        Hue[0.6499999490745912, 1, 0.10000007051210441`], 
        Hue[0.6498401940009914, 1, 0.10022126984478122`], 
        Hue[0.6498965941389109, 1, 0.10014317734612337`], 
        Hue[0.6498307067503871, 1, 0.10023440603792551`], 
        Hue[0.6498376968729129, 1, 0.10022472740673594`], 
        Hue[0.6498948240795815, 1, 0.10014562819750247`], 
        Hue[0.6499575453317327, 1, 0.10005878338683179`], 
        Hue[0.6498475221859048, 1, 0.10021112312720874`], 
        Hue[0.6499996319583529, 1, 0.1000005095961268], 
        Hue[0.6499982711804069, 1, 0.10000239375020598`], 
        Hue[0.6499982896776413, 1, 0.10000236813865063`], 
        Hue[0.64999791089883, 1, 0.10000289260162012`], 
        Hue[0.6499874785448396, 1, 0.10001733739945283`], 
        Hue[0.6499892785262673, 1, 0.10001484511747614`], 
        Hue[0.6499949320825263, 1, 0.10000701711650203`], 
        Hue[0.6499652560339055, 1, 0.10004810702997692`], 
        Hue[0.6499575453317327, 1, 0.10005878338683176`], 
        Hue[0.6498475221859049, 1, 0.10021112312720867`], 
        Hue[0.6498693537502516, 1, 0.10018089480734399`], 
        Hue[0.649994966060422, 1, 0.10000697007018497`], 
        Hue[0.6499931798173987, 1, 0.10000944332975563`], 
        Hue[0.6499728876119557, 1, 0.10003754022959982`], 
        Hue[0.6499904693183663, 1, 0.10001319632841578`], 
        Hue[0.649982351773809, 1, 0.10002443600549525`], 
        Hue[0.6498401940009914, 1, 0.1002212698447812], 
        Hue[0.6474229577245604, 1, 0.10356821238137796`], 
        Hue[0.6499905001789897, 1, 0.10001315359832193`], 
        Hue[0.6499858078426721, 1, 0.10001965067937708`], 
        Hue[0.6466909526577986, 1, 0.10458175785843268`], 
        Hue[0.646455724919808, 1, 0.1049074578033429], 
        Hue[0.645383322492119, 1, 0.1063923227032198], 
        Hue[0.6474229577245602, 1, 0.10356821238137834`], 
        Hue[0.6453822585486587, 1, 0.10639379585570329`], 
        Hue[0.6451837682394984, 1, 0.10666862859146374`], 
        Hue[0.6458367128760315, 1, 0.10576455140241796`], 
        Hue[0.6410145533798334, 1, 0.11244138762792309`], 
        Hue[0.6451760894519943, 1, 0.10667926075877707`], 
        Hue[0.6427222120230419, 1, 0.11007693719886505`], 
        Hue[0.6499904494586252, 1, 0.10001322382651898`], 
        Hue[0.6499856125038711, 1, 0.10001992114848617`], 
        Hue[0.6464557249198024, 1, 0.10490745780335048`], 
        Hue[0.6466909526577906, 1, 0.10458175785844377`], 
        Hue[0.6233201302808182, 1, 0.13694135807271327`], 
        Hue[0.6388748463426085, 1, 0.11540405891023438`], 
        Hue[0.6398576691566518, 1, 0.11404322732155919`], 
        Hue[0.6282755077833603, 1, 0.1300800661461166], 
        Hue[0.6498948240795815, 1, 0.10014562819750256`], 
        Hue[0.649982271892414, 1, 0.10002454661050372`], 
        Hue[0.6499947848408922, 1, 0.10000722098953381`], 
        Hue[0.6499927911642357, 1, 0.10000998146490438`], 
        Hue[0.6498307067503871, 1, 0.10023440603792552`], 
        Hue[0.6498594518723236, 1, 0.10019460509985961`], 
        Hue[0.6453822585486075, 1, 0.10639379585577424`], 
        Hue[0.6453833224920709, 1, 0.1063923227032865], 
        Hue[0.6456533105267098, 1, 0.10601849311686341`], 
        Hue[0.6499852938294347, 1, 0.10002036239001359`], 
        Hue[0.6499879539739198, 1, 0.10001667911303415`], 
        Hue[0.6499981001297528, 1, 0.10000263058957315`], 
        Hue[0.6499975817595002, 1, 0.10000334833299979`], 
        Hue[0.6451760894519326, 1, 0.10667926075886258`], 
        Hue[0.6447422602882784, 1, 0.10727994729315303`], 
        Hue[0.6427222120230224, 1, 0.11007693719889208`], 
        Hue[0.6432412882885953, 1, 0.10935821621579125`], 
        Hue[0.6499958918832327, 1, 0.10000568816167785`], 
        Hue[0.6499964672535286, 1, 0.10000489149511434`], 
        Hue[0.6499995394710767, 1, 0.10000063765543235`], 
        Hue[0.6499994488275219, 1, 0.10000076316189273`], 
        Hue[0.6410145533799854, 1, 0.11244138762771266`], 
        Hue[0.6398576691567839, 1, 0.11404322732137623`], 
        Hue[0.6282755077836939, 1, 0.13008006614565468`], 
        Hue[0.6309334967136163, 1, 0.12639977378114664`], 
        Hue[0.6422329045977426, 1, 0.11075443978774097`], 
        Hue[0.6458367128759976, 1, 0.1057645514024648], 
        Hue[0.6388748463430168, 1, 0.11540405890966907`], 
        Hue[0.6363391370261278, 1, 0.11891504104074618`], 
        Hue[0.6233201302808241, 1, 0.13694135807270516`], 
        Hue[0.6499998703971854, 1, 0.100000179450051], 
        Hue[0.6388748463426072, 1, 0.11540405891023633`], 
        Hue[0.6363391370257134, 1, 0.11891504104131992`], 
        Hue[0.645836712875852, 1, 0.10576455140266648`], 
        Hue[0.6499995339718821, 1, 0.10000064526970168`], 
        Hue[0.6410145533798326, 1, 0.11244138762792409`], 
        Hue[0.6422329045975737, 1, 0.11075443978797506`], 
        Hue[0.6282755077833523, 1, 0.13008006614612758`], 
        Hue[0.6309334967132403, 1, 0.12639977378166728`], 
        Hue[0.6398576691566503, 1, 0.1140432273215611], 
        Hue[0.6499995394710767, 1, 0.10000063765543235`], 
        Hue[0.6499994488275219, 1, 0.10000076316189273`], 
        Hue[0.6499958918832327, 1, 0.10000568816167785`], 
        Hue[0.6499964672535286, 1, 0.10000489149511434`], 
        Hue[0.6499980833227129, 1, 0.100002653860859], 
        Hue[0.6427222120230416, 1, 0.1100769371988655], 
        Hue[0.643241288288611, 1, 0.10935821621576942`], 
        Hue[0.6451760894519946, 1, 0.10667926075877684`], 
        Hue[0.644742260288343, 1, 0.1072799472930636], 
        Hue[0.6499981001297528, 1, 0.10000263058957315`], 
        Hue[0.6499975817595002, 1, 0.10000334833299979`], 
        Hue[0.6499852938294347, 1, 0.10002036239001358`], 
        Hue[0.6499879539739198, 1, 0.10001667911303413`], 
        Hue[0.6499947544739892, 1, 0.100007263036015], 
        Hue[0.6453833224921196, 1, 0.10639232270321906`], 
        Hue[0.6456533105267612, 1, 0.10601849311679216`], 
        Hue[0.6498307067503872, 1, 0.10023440603792542`], 
        Hue[0.6498594518723237, 1, 0.10019460509985952`], 
        Hue[0.6499947848408922, 1, 0.1000072209895338], 
        Hue[0.6499927911642358, 1, 0.10000998146490438`], 
        Hue[0.6499904192577803, 1, 0.10001326564307339`], 
        Hue[0.649982271892414, 1, 0.10002454661050371`], 
        Hue[0.6498376968729129, 1, 0.10022472740673594`], 
        Hue[0.6282755077836376, 1, 0.13008006614573261`], 
        Hue[0.6410145533800203, 1, 0.11244138762766413`], 
        Hue[0.6388748463430075, 1, 0.115404058909682], 
        Hue[0.6499904494586252, 1, 0.10001322382651896`], 
        Hue[0.6499856125038711, 1, 0.10001992114848615`], 
        Hue[0.6427222120230901, 1, 0.1100769371987983], 
        Hue[0.6451760894520181, 1, 0.10667926075874427`], 
        Hue[0.6422329045977838, 1, 0.11075443978768394`], 
        Hue[0.6458367128758516, 1, 0.10576455140266693`], 
        Hue[0.6453833224921226, 1, 0.10639232270321484`], 
        Hue[0.6499905001789897, 1, 0.10001315359832193`], 
        Hue[0.6499858078426721, 1, 0.1000196506793771], 
        Hue[0.6498965941389109, 1, 0.10014317734612337`], 
        Hue[0.649982351773809, 1, 0.10002443600549525`], 
        Hue[0.6499652560339055, 1, 0.10004810702997693`], 
        Hue[0.6499728876119557, 1, 0.10003754022959983`], 
        Hue[0.649994966060422, 1, 0.10000697007018497`], 
        Hue[0.6499931798173987, 1, 0.10000944332975564`], 
        Hue[0.6498475221859048, 1, 0.10021112312720871`], 
        Hue[0.6498693537502516, 1, 0.10018089480734403`], 
        Hue[0.6499575453317327, 1, 0.10005878338683179`], 
        Hue[0.6499874785448396, 1, 0.10001733739945283`], 
        Hue[0.6499892785262672, 1, 0.10001484511747614`], 
        Hue[0.6499982896776413, 1, 0.10000236813865063`], 
        Hue[0.64999791089883, 1, 0.10000289260162012`], 
        Hue[0.6498475221859049, 1, 0.10021112312720867`], 
        Hue[0.6499652560339055, 1, 0.10004810702997692`], 
        Hue[0.6498948240795815, 1, 0.10014562819750256`], 
        Hue[0.6498307067503872, 1, 0.1002344060379254], 
        Hue[0.6498965941389109, 1, 0.10014317734612338`], 
        Hue[0.6499999490745912, 1, 0.10000007051210441`], 
        Hue[0.6499999853568917, 1, 0.10000002027507307`], 
        Hue[0.6499874785448396, 1, 0.10001733739945283`], 
        Hue[0.6499982896776413, 1, 0.10000236813865063`], 
        Hue[0.6499728876119557, 1, 0.10003754022959982`], 
        Hue[0.649994966060422, 1, 0.10000697007018497`], 
        Hue[0.6499905001789897, 1, 0.10001315359832193`], 
        Hue[0.649982271892414, 1, 0.10002454661050372`], 
        Hue[0.6499998703971854, 1, 0.100000179450051], 
        Hue[0.6499999589602237, 1, 0.1000000568243058], 
        Hue[0.6499958918832327, 1, 0.10000568816167785`], 
        Hue[0.6499995394710767, 1, 0.10000063765543235`], 
        Hue[0.6499852938294347, 1, 0.10002036239001358`], 
        Hue[0.6499981001297528, 1, 0.10000263058957315`], 
        Hue[0.6499947848408922, 1, 0.1000072209895338], 
        Hue[0.6499904494586252, 1, 0.10001322382651896`], 
        Hue[0.649982351773809, 1, 0.10002443600549525`], 
        Hue[0.6499998378409675, 1, 0.10000022452789123`], 
        Hue[0.6499999079226575, 1, 0.10000012749170509`], 
        Hue[0.6499999079226575, 1, 0.10000012749170509`], 
        Hue[0.6499999105318043, 1, 0.10000012387904018`], 
        Hue[0.6499988198134662, 1, 0.1000016341044314], 
        Hue[0.649999732409757, 1, 0.10000037050956732`], 
        Hue[0.6499992964406758, 1, 0.10000097415906437`], 
        Hue[0.6499997205474622, 1, 0.10000038693428308`], 
        Hue[0.6499997241332024, 1, 0.10000038196941208`], 
        Hue[0.6499992203039526, 1, 0.10000107957914259`], 
        Hue[0.649999015708746, 1, 0.10000136286481327`], 
        Hue[0.649998333888502, 1, 0.10000230692361262`], 
        Hue[0.6499942406207414, 1, 0.10000797452512729`], 
        Hue[0.6499964646335001, 1, 0.10000489512284605`], 
        Hue[0.6499980650680817, 1, 0.10000267913650228`], 
        Hue[0.6499981753461317, 1, 0.10000252644381777`], 
        Hue[0.6499952966832021, 1, 0.10000651228479705`], 
        Hue[0.6499959630133506, 1, 0.10000558967382225`], 
        Hue[0.6499933017246096, 1, 0.10000927453515605`], 
        Hue[0.6499818743816113, 1, 0.10002509701007671`], 
        Hue[0.6499886776939561, 1, 0.10001567703913772`], 
        Hue[0.6499908589738949, 1, 0.10001265680537647`], 
        Hue[0.6499484530937932, 1, 0.10007137263936332`], 
        Hue[0.6499180307352563, 1, 0.10011349590502969`], 
        Hue[0.6499927911642357, 1, 0.10000998146490438`], 
        Hue[0.6499806446197294, 1, 0.10002679975729786`], 
        Hue[0.6499879539739198, 1, 0.10001667911303415`], 
        Hue[0.6499956092416016, 1, 0.10000607951162864`], 
        Hue[0.6499334584002099, 1, 0.10009213452278638`], 
        Hue[0.6499975817595002, 1, 0.1000033483329998], 
        Hue[0.6499931770229507, 1, 0.10000944719899144`], 
        Hue[0.6499964672535286, 1, 0.10000489149511434`], 
        Hue[0.6499987913150758, 1, 0.10000167356374128`], 
        Hue[0.6499999113420365, 1, 0.10000012275718022`], 
        Hue[0.6499998555397438, 1, 0.10000020002189328`], 
        Hue[0.6499996941293525, 1, 0.10000042351320422`], 
        Hue[0.6499998322292071, 1, 0.10000023229802099`], 
        Hue[0.6499997586209825, 1, 0.10000033421710122`], 
        Hue[0.6499998535240952, 1, 0.10000020281279137`], 
        Hue[0.6499983016594818, 1, 0.10000235154840982`], 
        Hue[0.6499995771839885, 1, 0.10000058543755444`], 
        Hue[0.6499990154332835, 1, 0.10000136324622286`], 
        Hue[0.649999454487984, 1, 0.10000075532432992`], 
        Hue[0.6499995171479255, 1, 0.10000066856441088`], 
        Hue[0.6499985394928872, 1, 0.10000202224061779`], 
        Hue[0.6499987788443321, 1, 0.10000169083092485`], 
        Hue[0.6499978883756586, 1, 0.10000292378754969`], 
        Hue[0.6499931260501088, 1, 0.1000095177767724], 
        Hue[0.6499958515834572, 1, 0.10000574396136695`], 
        Hue[0.6499971342997227, 1, 0.10000396789269159`], 
        Hue[0.6499975148056737, 1, 0.100003441038298], 
        Hue[0.6499955764751569, 1, 0.1000061248805519], 
        Hue[0.6499925770634212, 1, 0.10001027791218614`], 
        Hue[0.6499805463167408, 1, 0.10002693586912803`], 
        Hue[0.6499879519206576, 1, 0.1000166819560126], 
        Hue[0.6499888903804653, 1, 0.10001538255012504`], 
        Hue[0.6499482456526285, 1, 0.10007165986559136`], 
        Hue[0.6499183018776694, 1, 0.10011312047707317`], 
        Hue[0.6499931798173987, 1, 0.10000944332975564`], 
        Hue[0.6499819848662312, 1, 0.10002494403137233`], 
        Hue[0.6499892785262672, 1, 0.10001484511747614`], 
        Hue[0.6499959994335225, 1, 0.10000553924589196`], 
        Hue[0.6499999500040863, 1, 0.10000006922511127`], 
        Hue[0.6499999853568917, 1, 0.10000002027507307`], 
        Hue[0.6499999926512596, 1, 0.10000001017517901`], 
        Hue[0.6499999853568917, 1, 0.10000002027507307`], 
        Hue[0.6499999926512596, 1, 0.10000001017517901`], 
        Hue[0.6499987373870405, 1, 0.1000017482333285], 
        Hue[0.6499997241332024, 1, 0.10000038196941208`], 
        Hue[0.6499992203039526, 1, 0.10000107957914259`], 
        Hue[0.6499998474023537, 1, 0.10000021128904879`], 
        Hue[0.649999590533435, 1, 0.1000005669537054], 
        Hue[0.649999732409757, 1, 0.10000037050956732`], 
        Hue[0.6499992964406758, 1, 0.10000097415906437`], 
        Hue[0.6499999105318043, 1, 0.10000012387904018`], 
        Hue[0.6499925051018157, 1, 0.10001037755133219`], 
        Hue[0.6499979682031483, 1, 0.10000281325717941`], 
        Hue[0.6499951269450512, 1, 0.10000674730685209`], 
        Hue[0.649997998599588, 1, 0.10000277116980137`], 
        Hue[0.6499979682031483, 1, 0.10000281325717941`], 
        Hue[0.6499951269450512, 1, 0.10000674730685209`], 
        Hue[0.6499892997103437, 1, 0.10001481578567803`], 
        Hue[0.6499684714090721, 1, 0.10004365497205403`], 
        Hue[0.6499786307209967, 1, 0.10002958823246613`], 
        Hue[0.6499887061646138, 1, 0.10001563761822711`], 
        Hue[0.64998889575535, 1, 0.10001537510797696`], 
        Hue[0.6499758863201647, 1, 0.1000333881720797], 
        Hue[0.64990986881594, 1, 0.10012479702408313`], 
        Hue[0.6499371615166366, 1, 0.10008700713081094`], 
        Hue[0.6499354525471791, 1, 0.10008937339621354`], 
        Hue[0.6499825790660813, 1, 0.10002412129311823`], 
        Hue[0.6499234644088201, 1, 0.1001059723570184], 
        Hue[0.6499998517472398, 1, 0.1000002052730525], 
        Hue[0.6499995050240461, 1, 0.10000068535132073`], 
        Hue[0.649999724803093, 1, 0.10000038104187135`], 
        Hue[0.6499972533523636, 1, 0.1000038030505735], 
        Hue[0.6499993159067812, 1, 0.10000094720599527`], 
        Hue[0.6499983662639025, 1, 0.10000226209613496`], 
        Hue[0.6499991262252099, 1, 0.10000120984201699`], 
        Hue[0.6499992335415801, 1, 0.10000106125012002`], 
        Hue[0.6499977398917669, 1, 0.10000312938063041`], 
        Hue[0.6499963413007848, 1, 0.1000050658912211], 
        Hue[0.6499878647654108, 1, 0.10001680263250819`], 
        Hue[0.6499923453330904, 1, 0.10001059876956729`], 
        Hue[0.6499954680826809, 1, 0.10000627496244185`], 
        Hue[0.6499959176232237, 1, 0.1000056525216902], 
        Hue[0.6499850753312237, 1, 0.1000206649259979], 
        Hue[0.6499592661856974, 1, 0.1000564006659575], 
        Hue[0.6499729800552231, 1, 0.10003741223122968`], 
        Hue[0.649981132862961, 1, 0.10002612372820784`], 
        Hue[0.649898911013796, 1, 0.10013996936551317`], 
        Hue[0.649930414075084, 1, 0.10009634974219148`], 
        Hue[0.6499366633612995, 1, 0.10008769688435451`], 
        Hue[0.6499394811751557, 1, 0.1000837952959383], 
        Hue[0.6499999500040863, 1, 0.10000006922511127`], 
        Hue[0.6499930394481843, 1, 0.10000963768712945`], 
        Hue[0.6499981753461317, 1, 0.10000252644381777`], 
        Hue[0.6499952966832021, 1, 0.10000651228479705`], 
        Hue[0.649999015708746, 1, 0.10000136286481327`], 
        Hue[0.6499978877143096, 1, 0.10000292470326372`], 
        Hue[0.649998333888502, 1, 0.10000230692361262`], 
        Hue[0.6499964646335001, 1, 0.10000489512284605`], 
        Hue[0.6499658530333119, 1, 0.10004728041541434`], 
        Hue[0.64998889575535, 1, 0.10001537510797696`], 
        Hue[0.6499758863201647, 1, 0.1000333881720797], 
        Hue[0.6499899497720244, 1, 0.10001391570027392`], 
        Hue[0.6499892997103437, 1, 0.10001481578567803`], 
        Hue[0.6499684714090721, 1, 0.10004365497205403`], 
        Hue[0.6498018332354732, 1, 0.10027438475088327`], 
        Hue[0.6499986841176894, 1, 0.10000182199089175`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499992118878316, 1, 0.10000109123223312`], 
        Hue[0.6499992084380691, 1, 0.10000109600882744`], 
        Hue[0.6499956798469451, 1, 0.10000598175038376`], 
        Hue[0.6499974203571485, 1, 0.10000357181317905`], 
        Hue[0.6499817331204784, 1, 0.10002529260241469`], 
        Hue[0.6499944407952419, 1, 0.10000769736043427`], 
        Hue[0.6499883164518722, 1, 0.10001617722048475`], 
        Hue[0.6499928827959313, 1, 0.10000985459024905`], 
        Hue[0.6499937882615862, 1, 0.10000860086857298`], 
        Hue[0.649984029121582, 1, 0.10002211352396337`], 
        Hue[0.6499768388087087, 1, 0.10003206934178795`], 
        Hue[0.6499366088679227, 1, 0.10008777233672245`], 
        Hue[0.6499568986091695, 1, 0.10005967884884229`], 
        Hue[0.6499719284481867, 1, 0.10003886830251077`], 
        Hue[0.6498288316135646, 1, 0.1002370023812183], 
        Hue[0.6498768869650648, 1, 0.10017046420221798`], 
        Hue[0.6498286531654709, 1, 0.10023724946319418`], 
        Hue[0.6499942951189157, 1, 0.10000789906611669`], 
        Hue[0.6499965007467773, 1, 0.10000484511984688`], 
        Hue[0.6499740840158208, 1, 0.10003588367040199`], 
        Hue[0.6499959630133506, 1, 0.10000558967382225`], 
        Hue[0.6499931307624713, 1, 0.1000095112519628], 
        Hue[0.6499818743816113, 1, 0.10002509701007671`], 
        Hue[0.6498899315253245, 1, 0.10015240250339691`], 
        Hue[0.64990986881594, 1, 0.10012479702408313`], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499930428076303, 1, 0.10000963303558898`], 
        Hue[0.649993024783002, 1, 0.10000965799276645`], 
        Hue[0.6499710401022167, 1, 0.1000400983200076], 
        Hue[0.6499815839206784, 1, 0.10002549918675308`], 
        Hue[0.64996575997617, 1, 0.10004740926376463`], 
        Hue[0.6499078273563339, 1, 0.10012762366046074`], 
        Hue[0.6499369681039932, 1, 0.10008727493293267`], 
        Hue[0.6499551253828276, 1, 0.10006213408531567`], 
        Hue[0.6499614584941964, 1, 0.1000533651618819], 
        Hue[0.6497502919378658, 1, 0.10034574962449345`], 
        Hue[0.649818266637786, 1, 0.10025163080921945`], 
        Hue[0.649828653165471, 1, 0.10023724946319411`], 
        Hue[0.6499394811751558, 1, 0.10008379529593828`], 
        Hue[0.6499442388258546, 1, 0.10007720777958594`], 
        Hue[0.6499102360885619, 1, 0.10012428849276052`], 
        Hue[0.6499374484373719, 1, 0.10008660985594665`], 
        Hue[0.6499959994335225, 1, 0.10000553924589196`], 
        Hue[0.6499933578423218, 1, 0.10000919683370825`], 
        Hue[0.6499819848662312, 1, 0.10002494403137231`], 
        Hue[0.649988752611403, 1, 0.10001557330728819`], 
        Hue[0.6499368000496959, 1, 0.10008750762349808`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6499522576756646, 1, 0.10006610475677218`], 
        Hue[0.6499521921357778, 1, 0.10006619550430762`], 
        Hue[0.6498464094443002, 1, 0.10021266384635359`], 
        Hue[0.6498967127539552, 1, 0.10014301310990814`], 
        Hue[0.6496383427872282, 1, 0.10050075614076096`], 
        Hue[0.6497373247140593, 1, 0.10036370424207171`], 
        Hue[0.6499366633612995, 1, 0.10008769688435448`], 
        Hue[0.6499155953597011, 1, 0.10011686796349073`], 
        Hue[0.6499183018776694, 1, 0.10011312047707317`], 
        Hue[0.6499453252164491, 1, 0.10007570354645513`], 
        Hue[0.6499484530937932, 1, 0.10007137263936332`], 
        Hue[0.6466917429014707, 1, 0.10458066367488676`], 
        Hue[0.6499180307352563, 1, 0.10011349590502969`], 
        Hue[0.6499452847292683, 1, 0.10007575960562864`], 
        Hue[0.6499354525471791, 1, 0.10008937339621354`], 
        Hue[0.6499128808040171, 1, 0.10012062657905335`], 
        Hue[0.6450730162623393, 1, 0.10682197748291487`], 
        Hue[0.6451848600758754, 1, 0.10666711681801869`], 
        Hue[0.6439530905198237, 1, 0.10837264389562865`], 
        Hue[0.6466917429014625, 1, 0.10458066367489817`], 
        Hue[0.6465519871630898, 1, 0.1047741716203372], 
        Hue[0.6499179671599283, 1, 0.10011358393240694`], 
        Hue[0.6499482456526284, 1, 0.1000716598655914], 
        Hue[0.6498018332354732, 1, 0.1002743847508833], 
        Hue[0.6369343337822009, 1, 0.11809092245541414`], 
        Hue[0.6313031433718986, 1, 0.12588795533121733`], 
        Hue[0.6423035647750807, 1, 0.11065660261911912`], 
        Hue[0.6370871379712647, 1, 0.11787934742440272`], 
        Hue[0.6451848600758338, 1, 0.10666711681807642`], 
        Hue[0.6439530905197821, 1, 0.10837264389568639`], 
        Hue[0.6441390283451809, 1, 0.10811519152205727`], 
        Hue[0.6499806446197294, 1, 0.10002679975729786`], 
        Hue[0.649988018614091, 1, 0.10001658961125877`], 
        Hue[0.6499956092416016, 1, 0.10000607951162864`], 
        Hue[0.6499926276132632, 1, 0.10001020792009714`], 
        Hue[0.6499234644088201, 1, 0.10010597235701842`], 
        Hue[0.6499334905618971, 1, 0.10009208999121949`], 
        Hue[0.6499825790660813, 1, 0.10002412129311823`], 
        Hue[0.6155593700329793, 1, 0.14768702610818243`], 
        Hue[0.6258195092726606, 1, 0.1334806794686238], 
        Hue[0.5913746289044831, 1, 0.18117359074763875`], 
        Hue[0.6423035647750619, 1, 0.11065660261914508`], 
        Hue[0.6370871379713364, 1, 0.11787934742430345`], 
        Hue[0.6378619063741078, 1, 0.11680659117431233`], 
        Hue[0.649898911013796, 1, 0.10013996936551324`], 
        Hue[0.6499805463167408, 1, 0.10002693586912804`], 
        Hue[0.6499955764751569, 1, 0.10000612488055191`], 
        Hue[0.6499987913150758, 1, 0.10000167356374128`], 
        Hue[0.6499931770229507, 1, 0.10000944719899144`], 
        Hue[0.6499958852039428, 1, 0.10000569740992535`], 
        Hue[0.6499979082329089, 1, 0.10000289629289531`], 
        Hue[0.6319953620941843, 1, 0.12492949863882186`], 
        Hue[0.625819509272948, 1, 0.13348067946822578`], 
        Hue[0.5913746289049686, 1, 0.1811735907469666], 
        Hue[0.5965604897306293, 1, 0.17399316806528264`], 
        Hue[0.6498288316135644, 1, 0.10023700238121848`], 
        Hue[0.6499931260501088, 1, 0.1000095177767724], 
        Hue[0.6499592661856973, 1, 0.10005640066595754`], 
        Hue[0.6499850753312237, 1, 0.10002066492599791`], 
        Hue[0.6499958515834572, 1, 0.10000574396136695`], 
        Hue[0.6499987788443321, 1, 0.10000169083092485`], 
        Hue[0.6155593700336652, 1, 0.14768702610723275`], 
        Hue[0.6090317928650011, 1, 0.15672520987922933`], 
        Hue[0.6497502919378649, 1, 0.10034574962449469`], 
        Hue[0.6499878647654108, 1, 0.1000168026325082], 
        Hue[0.6499366088679226, 1, 0.10008777233672257`], 
        Hue[0.6499768388087087, 1, 0.10003206934178799`], 
        Hue[0.6499983016594818, 1, 0.10000235154840982`], 
        Hue[0.6499975148056737, 1, 0.100003441038298], 
        Hue[0.6499923453330904, 1, 0.10001059876956729`], 
        Hue[0.6499963413007848, 1, 0.10000506589122111`], 
        Hue[0.649998861931212, 1, 0.10000157578755257`], 
        Hue[0.6499990154332835, 1, 0.10000136324622286`], 
        Hue[0.6499995771839885, 1, 0.10000058543755444`], 
        Hue[0.6499997694648034, 1, 0.10000031920257986`], 
        Hue[0.6458360441380219, 1, 0.10576547734735442`], 
        Hue[0.6496383427872298, 1, 0.10050075614075889`], 
        Hue[0.6499817331204782, 1, 0.10002529260241473`], 
        Hue[0.6499078273563338, 1, 0.10012762366046096`], 
        Hue[0.64996575997617, 1, 0.1000474092637646], 
        Hue[0.6499972533523636, 1, 0.1000038030505735], 
        Hue[0.6499959176232237, 1, 0.10000565252169022`], 
        Hue[0.6499871127135868, 1, 0.10001784393503371`], 
        Hue[0.6499883164518722, 1, 0.10001617722048477`], 
        Hue[0.6499944407952419, 1, 0.10000769736043427`], 
        Hue[0.6499996941293525, 1, 0.10000042351320422`], 
        Hue[0.6499985394928872, 1, 0.10000202224061779`], 
        Hue[0.6499995171479255, 1, 0.10000066856441088`], 
        Hue[0.6499981812644314, 1, 0.10000251824924884`], 
        Hue[0.6499983662639025, 1, 0.10000226209613496`], 
        Hue[0.6499993159067812, 1, 0.10000094720599527`], 
        Hue[0.6499998535240952, 1, 0.10000020281279137`], 
        Hue[0.6499998099007703, 1, 0.10000026321431808`], 
        Hue[0.6499998322292071, 1, 0.10000023229802099`], 
        Hue[0.6499998517472398, 1, 0.1000002052730525], 
        Hue[0.6499986841176894, 1, 0.10000182199089175`], 
        Hue[0.6499984977543622, 1, 0.1000020800324216], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499992084380691, 1, 0.10000109600882745`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.649993024783002, 1, 0.10000965799276647`], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.6499521921357778, 1, 0.10006619550430775`], 
        Hue[0.03701244893343003, 1, 0.9487519937844815], 
        Hue[0.021008559536129012`, 1, 0.9709112252576675], 
        Hue[0.010667080107161664`, 1, 0.9852301967746991], 
        Hue[0.018968293162326844`, 1, 0.9737362094675474], 
        Hue[0.0021628179028305716`, 1, 0.9970053290576192], 
        Hue[0.6471956278815293, 1, 0.10388297677942109`], 
        Hue[0.649971040102217, 1, 0.10004009832000738`], 
        Hue[0.6499614584941966, 1, 0.1000533651618817], 
        Hue[0.6499521921357782, 1, 0.10006619550430726`], 
        Hue[0.6499956798469451, 1, 0.10000598175038376`], 
        Hue[0.649984029121582, 1, 0.10002211352396334`], 
        Hue[0.6499937882615862, 1, 0.10000860086857298`], 
        Hue[0.649993024783002, 1, 0.10000965799276644`], 
        Hue[0.6499995050240461, 1, 0.10000068535132073`], 
        Hue[0.6499977398917669, 1, 0.10000312938063043`], 
        Hue[0.64999923354158, 1, 0.10000106125012002`], 
        Hue[0.6499992084380691, 1, 0.10000109600882745`], 
        Hue[0.6499997586209825, 1, 0.10000033421710122`], 
        Hue[0.6499999328468428, 1, 0.1000000929812946], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.6499999042768432, 1, 0.1000001325397556], 
        Hue[0.6499997599027079, 1, 0.10000033244240446`], 
        Hue[0.6499998715320819, 1, 0.10000017787865574`], 
        Hue[0.649999724803093, 1, 0.10000038104187135`], 
        Hue[0.6499989528715463, 1, 0.10000144987016665`], 
        Hue[0.6499975708283137, 1, 0.10000336346848884`], 
        Hue[0.6499986013933341, 1, 0.10000193653230671`], 
        Hue[0.6499974203571485, 1, 0.10000357181317905`], 
        Hue[0.6499913752726683, 1, 0.10001194193015173`], 
        Hue[0.6499815839206784, 1, 0.10002549918675308`], 
        Hue[0.6499445462876953, 1, 0.10007678206319122`], 
        Hue[0.6498464094443002, 1, 0.10021266384635365`], 
        Hue[0.6496727141920234, 1, 0.10045316496489064`], 
        Hue[0.004312626695688215, 1, 0.9940286707290471], 
        Hue[0.01896829316206161, 1, 0.9737362094679147], 
        Hue[0.0021628179027942673`, 1, 0.9970053290576695], 
        Hue[0.02100855953293701, 1, 0.9709112252620872], 
        Hue[0.0021628179019673732`, 1, 0.9970053290588144], 
        Hue[0.01896829315981796, 1, 0.9737362094710214], 
        Hue[0.6499986841176894, 1, 0.10000182199089175`], 
        Hue[0.6499984977543622, 1, 0.1000020800324216], 
        Hue[0.6499999661022928, 1, 0.10000004693528683`], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.6499998517472398, 1, 0.1000002052730525], 
        Hue[0.6499999589602237, 1, 0.1000000568243058], 
        Hue[0.6499999794211159, 1, 0.10000002849383967`], 
        Hue[0.6499996132007059, 1, 0.10000053556825345`], 
        Hue[0.6499997586209825, 1, 0.10000033421710122`], 
        Hue[0.6499998322292071, 1, 0.10000023229802099`], 
        Hue[0.6499966175523572, 1, 0.10000468338904392`], 
        Hue[0.6499992335415801, 1, 0.10000106125012002`], 
        Hue[0.6499977398917669, 1, 0.10000312938063041`], 
        Hue[0.6499993878957052, 1, 0.10000084752902356`], 
        Hue[0.6499993159067812, 1, 0.10000094720599527`], 
        Hue[0.6499983662639025, 1, 0.10000226209613496`], 
        Hue[0.6499777227220929, 1, 0.1000308454617176], 
        Hue[0.6499937882615862, 1, 0.10000860086857298`], 
        Hue[0.649984029121582, 1, 0.10002211352396337`], 
        Hue[0.6499949826603763, 1, 0.10000694708563292`], 
        Hue[0.6499944407952419, 1, 0.10000769736043427`], 
        Hue[0.6499883164518722, 1, 0.10001617722048475`], 
        Hue[0.649886621235013, 1, 0.10015698598228986`], 
        Hue[0.6499614584941964, 1, 0.10005336516188192`], 
        Hue[0.6499690892099143, 1, 0.10004279955550338`], 
        Hue[0.64996575997617, 1, 0.10004740926376463`], 
        Hue[0.6499078273563339, 1, 0.10012762366046075`], 
        Hue[0.6495400008935742, 1, 0.10063692183966651`], 
        Hue[0.6496383427872282, 1, 0.10050075614076094`], 
        Hue[0.64507301626234, 1, 0.10682197748291387`], 
        Hue[0.6369343337821991, 1, 0.11809092245541672`], 
        Hue[0.6155593700329609, 1, 0.14768702610820794`], 
        Hue[0.6090317928642983, 1, 0.15672520988020228`], 
        Hue[0.06747929559215904, 1, 0.9065671291800874], 
        Hue[0.06744763098364448, 1, 0.9066109724841845], 
        Hue[0.6495407493861158, 1, 0.10063588546537816`], 
        Hue[0.6499978004542722, 1, 0.10000304552485391`], 
        Hue[0.6499995171479255, 1, 0.10000066856441088`], 
        Hue[0.6499985394928872, 1, 0.10000202224061779`], 
        Hue[0.6499997664208694, 1, 0.1000003234172578], 
        Hue[0.649999442352031, 1, 0.10000077212795708`], 
        Hue[0.6499995771839885, 1, 0.10000058543755444`], 
        Hue[0.6499990154332835, 1, 0.10000136324622286`], 
        Hue[0.6499998535240952, 1, 0.10000020281279137`], 
        Hue[0.6499849888742334, 1, 0.10002078463567682`], 
        Hue[0.6499959176232237, 1, 0.1000056525216902], 
        Hue[0.6499967448026513, 1, 0.10000450719632889`], 
        Hue[0.6499963413007848, 1, 0.10000506589122111`], 
        Hue[0.6499923453330904, 1, 0.10001059876956729`], 
        Hue[0.6499234404741348, 1, 0.10010600549735192`], 
        Hue[0.6499768388087087, 1, 0.10003206934178796`], 
        Hue[0.6499366088679227, 1, 0.10008777233672247`], 
        Hue[0.6497011754290651, 1, 0.10041375709821751`], 
        Hue[0.6497502919378658, 1, 0.10034574962449351`], 
        Hue[0.5913746289044425, 1, 0.18117359074769507`], 
        Hue[0.5965604897300106, 1, 0.17399316806613918`], 
        Hue[0.6258195092726493, 1, 0.1334806794686394], 
        Hue[0.6499983183666825, 1, 0.1000023284153627], 
        Hue[0.6499990259760979, 1, 0.1000013486484798], 
        Hue[0.649990533972543, 1, 0.1000131068072481], 
        Hue[0.6499975148056737, 1, 0.100003441038298], 
        Hue[0.6499987788443321, 1, 0.10000169083092485`], 
        Hue[0.6499975602665753, 1, 0.10000337809243423`], 
        Hue[0.6499978883756586, 1, 0.10000292378754969`], 
        Hue[0.6499958515834572, 1, 0.10000574396136695`], 
        Hue[0.6499482995199596, 1, 0.10007158528005596`], 
        Hue[0.6499850753312237, 1, 0.1000206649259979], 
        Hue[0.6499592661856973, 1, 0.10005640066595752`], 
        Hue[0.6497919036628963, 1, 0.10028813338983586`], 
        Hue[0.6498288316135645, 1, 0.10023700238121833`], 
        Hue[0.6370871379712585, 1, 0.11787934742441139`], 
        Hue[0.6378619063740117, 1, 0.11680659117444533`], 
        Hue[0.6423035647750802, 1, 0.11065660261911969`], 
        Hue[0.6499825790660813, 1, 0.10002412129311823`], 
        Hue[0.6499234644088201, 1, 0.10010597235701837`], 
        Hue[0.6499334905618971, 1, 0.10009208999121945`], 
        Hue[0.6499987913150758, 1, 0.10000167356374128`], 
        Hue[0.6499979082329089, 1, 0.10000289629289531`], 
        Hue[0.6499931770229507, 1, 0.10000944719899142`], 
        Hue[0.6499958852039428, 1, 0.10000569740992533`], 
        Hue[0.6499701121736939, 1, 0.10004138314411615`], 
        Hue[0.6499955764751569, 1, 0.1000061248805519], 
        Hue[0.6499927474735677, 1, 0.10001004195967544`], 
        Hue[0.6499805463167408, 1, 0.10002693586912803`], 
        Hue[0.6498637789166501, 1, 0.10018861380771518`], 
        Hue[0.649898911013796, 1, 0.10013996936551318`], 
        Hue[0.6439530905198263, 1, 0.1083726438956252], 
        Hue[0.6441390283452353, 1, 0.10811519152198196`], 
        Hue[0.6451848600758766, 1, 0.1066671168180171], 
        Hue[0.6498018332354732, 1, 0.10027438475088318`], 
        Hue[0.6498992374175553, 1, 0.10013951742184662`], 
        Hue[0.6499306690177541, 1, 0.10009599674464822`], 
        Hue[0.6499956092416016, 1, 0.10000607951162864`], 
        Hue[0.6499926276132632, 1, 0.10001020792009714`], 
        Hue[0.6499806446197294, 1, 0.10002679975729785`], 
        Hue[0.649988018614091, 1, 0.10001658961125875`], 
        Hue[0.6499332456084079, 1, 0.10009242915758908`], 
        Hue[0.6466917429014706, 1, 0.10458066367488687`], 
        Hue[0.646551987163097, 1, 0.1047741716203272], 
        Hue[0.5913746289048778, 1, 0.18117359074709227`], 
        Hue[0.6258195092728863, 1, 0.1334806794683113], 
        Hue[0.615559370033591, 1, 0.14768702610733564`], 
        Hue[0.6319953620942502, 1, 0.12492949863873053`], 
        Hue[0.6353293129837483, 1, 0.1203132589455794], 
        Hue[0.6499334584002099, 1, 0.10009213452278633`], 
        Hue[0.6499560274362279, 1, 0.10006088508829984`], 
        Hue[0.6499354525471792, 1, 0.10008937339621347`], 
        Hue[0.6499128808040171, 1, 0.10012062657905328`], 
        Hue[0.6370871379713289, 1, 0.11787934742431384`], 
        Hue[0.6423035647751155, 1, 0.11065660261907082`], 
        Hue[0.6499180307352564, 1, 0.10011349590502963`], 
        Hue[0.6499452847292683, 1, 0.10007575960562862`], 
        Hue[0.6499482456526285, 1, 0.10007165986559136`], 
        Hue[0.643953090519833, 1, 0.10837264389561596`], 
        Hue[0.6451848600758786, 1, 0.10666711681801425`], 
        Hue[0.6499183018776694, 1, 0.10011312047707316`], 
        Hue[0.6499453252164491, 1, 0.10007570354645512`], 
        Hue[0.6499366633612995, 1, 0.1000876968843545], 
        Hue[0.6499155953597011, 1, 0.10011686796349076`], 
        Hue[0.6466917429014706, 1, 0.10458066367488697`], 
        Hue[0.6458360441380555, 1, 0.10576547734730775`], 
        Hue[0.6464975004717023, 1, 0.10484961473148917`], 
        Hue[0.6471956278815415, 1, 0.10388297677940406`], 
        Hue[0.6499182640119672, 1, 0.100113172906507], 
        Hue[0.6499484530937932, 1, 0.1000713726393633], 
        Hue[0.6498286531654709, 1, 0.10023724946319415`], 
        Hue[0.6495400008935912, 1, 0.10063692183964294`], 
        Hue[0.6496696618168546, 1, 0.10045739133050904`], 
        Hue[0.6496731893555265, 1, 0.10045250704619402`], 
        Hue[0.6499819848662312, 1, 0.10002494403137233`], 
        Hue[0.649988752611403, 1, 0.10001557330728819`], 
        Hue[0.6499959994335225, 1, 0.10000553924589196`], 
        Hue[0.6499933578423218, 1, 0.10000919683370825`], 
        Hue[0.6499394811751557, 1, 0.10008379529593829`], 
        Hue[0.6499442388258546, 1, 0.10007720777958597`], 
        Hue[0.6496383427872341, 1, 0.10050075614075284`], 
        Hue[0.6497373247140626, 1, 0.10036370424206716`], 
        Hue[0.6497011754290666, 1, 0.1004137570982155], 
        Hue[0.649782295843946, 1, 0.10030143652376722`], 
        Hue[0.6499521921357784, 1, 0.10006619550430693`], 
        Hue[0.6498866212350147, 1, 0.10015698598228738`], 
        Hue[0.6499227855829625, 1, 0.10010691226974439`], 
        Hue[0.6499614584941968, 1, 0.10005336516188132`], 
        Hue[0.6499522576756641, 1, 0.10006610475677287`], 
        Hue[0.6499446791317119, 1, 0.100076598125322], 
        Hue[0.6498467359396378, 1, 0.10021221177588613`], 
        Hue[0.6499098688159399, 1, 0.10012479702408315`], 
        Hue[0.6499818743816113, 1, 0.10002509701007672`], 
        Hue[0.6499959630133506, 1, 0.10000558967382225`], 
        Hue[0.6497502919378662, 1, 0.1003457496244931], 
        Hue[0.6498182666377861, 1, 0.10025163080921927`], 
        Hue[0.6497919036628964, 1, 0.10028813338983578`], 
        Hue[0.6498491275148006, 1, 0.10020890036412222`], 
        Hue[0.649977722722093, 1, 0.10003084546171745`], 
        Hue[0.6499078273563345, 1, 0.10012762366046009`], 
        Hue[0.6499369681039934, 1, 0.10008727493293235`], 
        Hue[0.6499657599761702, 1, 0.1000474092637643], 
        Hue[0.6499234404741349, 1, 0.10010600549735177`], 
        Hue[0.649947712762502, 1, 0.10007239771345888`], 
        Hue[0.649993024783002, 1, 0.10000965799276641`], 
        Hue[0.6499857386104357, 1, 0.10001974653939667`], 
        Hue[0.6499840291215822, 1, 0.10002211352396323`], 
        Hue[0.6499937882615863, 1, 0.10000860086857295`], 
        Hue[0.6499930428076302, 1, 0.10000963303558902`], 
        Hue[0.6499914127424962, 1, 0.10001189004885144`], 
        Hue[0.6499816678392326, 1, 0.10002538299183177`], 
        Hue[0.6499986841176894, 1, 0.10000182199089175`], 
        Hue[0.6499942406207414, 1, 0.10000797452512729`], 
        Hue[0.6499684714090721, 1, 0.10004365497205404`], 
        Hue[0.6499892997103437, 1, 0.10001481578567803`], 
        Hue[0.6499964646335001, 1, 0.10000489512284606`], 
        Hue[0.649999015708746, 1, 0.10000136286481327`], 
        Hue[0.6498286531654709, 1, 0.10023724946319411`], 
        Hue[0.6498288316135645, 1, 0.10023700238121833`], 
        Hue[0.6498768869650648, 1, 0.10017046420221802`], 
        Hue[0.6498637789166501, 1, 0.10018861380771522`], 
        Hue[0.6499035776827975, 1, 0.10013350782381888`], 
        Hue[0.6499366088679227, 1, 0.10008777233672243`], 
        Hue[0.6499568986091695, 1, 0.10005967884884229`], 
        Hue[0.6499849888742334, 1, 0.1000207846356768], 
        Hue[0.6499768388087087, 1, 0.10003206934178793`], 
        Hue[0.6499482995199596, 1, 0.10007158528005596`], 
        Hue[0.6499651447615216, 1, 0.10004826109943166`], 
        Hue[0.6499966175523572, 1, 0.10000468338904392`], 
        Hue[0.6499883164518722, 1, 0.10001617722048474`], 
        Hue[0.6499944407952419, 1, 0.10000769736043426`], 
        Hue[0.6499904461340845, 1, 0.1000132284297292], 
        Hue[0.6499959176232237, 1, 0.1000056525216902], 
        Hue[0.6499992084380691, 1, 0.10000109600882744`], 
        Hue[0.6499979781484426, 1, 0.10000279948677177`], 
        Hue[0.6499977398917669, 1, 0.10000312938063041`], 
        Hue[0.6499992335415801, 1, 0.10000106125012001`], 
        Hue[0.6499992118878316, 1, 0.10000109123223312`], 
        Hue[0.6499984977543622, 1, 0.1000020800324216], 
        Hue[0.6499974391975304, 1, 0.10000354572649647`], 
        Hue[0.6498018332354732, 1, 0.10027438475088317`], 
        Hue[0.6498899315253245, 1, 0.10015240250339698`], 
        Hue[0.649920525041201, 1, 0.10011004225064478`], 
        Hue[0.6499925051018156, 1, 0.1000103775513322], 
        Hue[0.6499758863201647, 1, 0.10003338817207973`], 
        Hue[0.64998889575535, 1, 0.10001537510797698`], 
        Hue[0.6499658530333119, 1, 0.10004728041541437`], 
        Hue[0.649976311639638, 1, 0.10003279926819361`], 
        Hue[0.6499758863201647, 1, 0.10003338817207973`], 
        Hue[0.64998889575535, 1, 0.10001537510797698`], 
        Hue[0.6499988198134662, 1, 0.1000016341044314], 
        Hue[0.6499952966832021, 1, 0.10000651228479705`], 
        Hue[0.6499981753461317, 1, 0.10000252644381777`], 
        Hue[0.649995048229519, 1, 0.10000685629758907`], 
        Hue[0.6499951269450512, 1, 0.1000067473068521], 
        Hue[0.6499979682031483, 1, 0.10000281325717941`], 
        Hue[0.6499992554553338, 1, 0.10000103090799936`], 
        Hue[0.6499992964406758, 1, 0.10000097415906437`], 
        Hue[0.649999732409757, 1, 0.10000037050956732`], 
        Hue[0.6499999500040863, 1, 0.10000006922511127`], 
        Hue[0.6499394811751558, 1, 0.10008379529593828`], 
        Hue[0.6499575453317327, 1, 0.10005878338683176`], 
        Hue[0.6499102360885619, 1, 0.10012428849276052`], 
        Hue[0.6499366633612995, 1, 0.10008769688435448`], 
        Hue[0.649898911013796, 1, 0.10013996936551324`], 
        Hue[0.6499304140750839, 1, 0.10009634974219153`], 
        Hue[0.6499332456084078, 1, 0.10009242915758913`], 
        Hue[0.6499558704947553, 1, 0.10006110239187734`], 
        Hue[0.6499592661856973, 1, 0.10005640066595753`], 
        Hue[0.649972980055223, 1, 0.10003741223122971`], 
        Hue[0.649990533972543, 1, 0.10001310680724812`], 
        Hue[0.6499850753312237, 1, 0.1000206649259979], 
        Hue[0.6499701121736939, 1, 0.10004138314411617`], 
        Hue[0.6499807215560938, 1, 0.10002669323002401`], 
        Hue[0.6499978004542722, 1, 0.1000030455248539], 
        Hue[0.6499923453330904, 1, 0.10001059876956729`], 
        Hue[0.6499963413007848, 1, 0.1000050658912211], 
        Hue[0.6499941257642842, 1, 0.10000813355714501`], 
        Hue[0.6499975148056737, 1, 0.100003441038298], 
        Hue[0.6499996132007059, 1, 0.10000053556825345`], 
        Hue[0.6499983662639025, 1, 0.10000226209613496`], 
        Hue[0.6499993159067812, 1, 0.10000094720599527`], 
        Hue[0.6499987037961257, 1, 0.1000017947438261], 
        Hue[0.6499985394928872, 1, 0.10000202224061779`], 
        Hue[0.6499995171479255, 1, 0.10000066856441088`], 
        Hue[0.6499997857288967, 1, 0.10000029668306613`], 
        Hue[0.6499997586209825, 1, 0.10000033421710122`], 
        Hue[0.6499998517472398, 1, 0.1000002052730525], 
        Hue[0.6499234644088201, 1, 0.10010597235701836`], 
        Hue[0.6499825790660813, 1, 0.10002412129311822`], 
        Hue[0.6498992374175553, 1, 0.10013951742184661`], 
        Hue[0.6499354525471792, 1, 0.10008937339621347`], 
        Hue[0.6499098688159399, 1, 0.10012479702408318`], 
        Hue[0.6499371615166365, 1, 0.10008700713081096`], 
        Hue[0.6499368000496958, 1, 0.10008750762349812`], 
        Hue[0.6499579090308498, 1, 0.10005827980343879`], 
        Hue[0.6499930394481843, 1, 0.10000963768712946`], 
        Hue[0.6499684714090721, 1, 0.10004365497205406`], 
        Hue[0.6499786307209967, 1, 0.10002958823246615`], 
        Hue[0.6499892997103437, 1, 0.10001481578567803`], 
        Hue[0.6499740840158208, 1, 0.10003588367040202`], 
        Hue[0.6499830415932077, 1, 0.10002348087094316`], 
        Hue[0.6499987373870405, 1, 0.1000017482333285], 
        Hue[0.6499951269450512, 1, 0.1000067473068521], 
        Hue[0.6499979682031483, 1, 0.10000281325717941`], 
        Hue[0.6499955738243941, 1, 0.1000061285508389], 
        Hue[0.6499952966832021, 1, 0.10000651228479705`], 
        Hue[0.6499981753461317, 1, 0.10000252644381777`], 
        Hue[0.6499998378409675, 1, 0.10000022452789123`], 
        Hue[0.6499992203039526, 1, 0.10000107957914259`], 
        Hue[0.6499997241332024, 1, 0.10000038196941208`], 
        Hue[0.649999231209965, 1, 0.10000106447851004`], 
        Hue[0.6499992203039526, 1, 0.10000107957914259`], 
        Hue[0.6499997241332024, 1, 0.10000038196941208`], 
        Hue[0.6499999105318043, 1, 0.10000012387904018`], 
        Hue[0.6499999068044836, 1, 0.10000012903994587`], 
        Hue[0.6499999079226575, 1, 0.10000012749170509`], 
        Hue[0.6499999926512596, 1, 0.10000001017517901`], 
        Hue[0.6499999927381648, 1, 0.10000001005484888`], 
        Hue[0.6499999926512596, 1, 0.10000001017517901`], 
        Hue[0.6499999500040863, 1, 0.10000006922511127`], 
        Hue[0.64999791089883, 1, 0.10000289260162012`], 
        Hue[0.6499942951189157, 1, 0.10000789906611669`], 
        Hue[0.6499892785262673, 1, 0.10001484511747614`], 
        Hue[0.6499959994335225, 1, 0.10000553924589196`], 
        Hue[0.6499931798173987, 1, 0.10000944332975563`], 
        Hue[0.6499819848662312, 1, 0.10002494403137231`], 
        Hue[0.6499183018776694, 1, 0.10011312047707319`], 
        Hue[0.6499179671599283, 1, 0.10011358393240694`], 
        Hue[0.6499452554080251, 1, 0.10007580020427298`], 
        Hue[0.6499482456526284, 1, 0.10007165986559141`], 
        Hue[0.6499805463167408, 1, 0.10002693586912804`], 
        Hue[0.6499927474735677, 1, 0.10001004195967546`], 
        Hue[0.6499955764751569, 1, 0.10000612488055191`], 
        Hue[0.6499925770634212, 1, 0.10001027791218615`], 
        Hue[0.6499975602665753, 1, 0.10000337809243423`], 
        Hue[0.6499987788443321, 1, 0.10000169083092485`], 
        Hue[0.6499958515834572, 1, 0.10000574396136695`], 
        Hue[0.6499978883756586, 1, 0.10000292378754969`], 
        Hue[0.649999442352031, 1, 0.10000077212795708`], 
        Hue[0.6499997664208694, 1, 0.1000003234172578], 
        Hue[0.6499990154332835, 1, 0.10000136324622286`], 
        Hue[0.6499995771839885, 1, 0.10000058543755444`], 
        Hue[0.6499998322292071, 1, 0.10000023229802099`], 
        Hue[0.6499998535240952, 1, 0.10000020281279137`], 
        Hue[0.6499999794211159, 1, 0.10000002849383967`], 
        Hue[0.6499997694648034, 1, 0.10000031920257986`], 
        Hue[0.6499994488275219, 1, 0.10000076316189273`], 
        Hue[0.6499983183666825, 1, 0.1000023284153627], 
        Hue[0.6499999113420365, 1, 0.10000012275718022`], 
        Hue[0.6499998555397438, 1, 0.10000020002189328`], 
        Hue[0.6499987913150758, 1, 0.10000167356374128`], 
        Hue[0.6499975817595002, 1, 0.10000334833299979`], 
        Hue[0.6499964672535286, 1, 0.10000489149511434`], 
        Hue[0.6499979082329089, 1, 0.10000289629289531`], 
        Hue[0.6499931770229507, 1, 0.10000944719899142`], 
        Hue[0.6499879539739198, 1, 0.10001667911303413`], 
        Hue[0.6499956092416016, 1, 0.10000607951162864`], 
        Hue[0.6499927911642358, 1, 0.10000998146490438`], 
        Hue[0.6499806446197294, 1, 0.10002679975729785`], 
        Hue[0.6499180307352564, 1, 0.10011349590502963`], 
        Hue[0.6499182640119672, 1, 0.10011317290650701`], 
        Hue[0.6499453175635969, 1, 0.10007571414271205`], 
        Hue[0.6499484530937932, 1, 0.1000713726393633], 
        Hue[0.6499818743816113, 1, 0.10002509701007672`], 
        Hue[0.6499931307624713, 1, 0.10000951125196281`], 
        Hue[0.6499959630133506, 1, 0.10000558967382225`], 
        Hue[0.6499933017246096, 1, 0.10000927453515607`], 
        Hue[0.6499978877143096, 1, 0.10000292470326372`], 
        Hue[0.649999015708746, 1, 0.10000136286481327`], 
        Hue[0.6499964646335001, 1, 0.10000489512284606`], 
        Hue[0.649998333888502, 1, 0.10000230692361262`], 
        Hue[0.649999590533435, 1, 0.1000005669537054], 
        Hue[0.6499998474023537, 1, 0.10000021128904879`], 
        Hue[0.6499992964406758, 1, 0.10000097415906437`], 
        Hue[0.649999732409757, 1, 0.10000037050956732`], 
        Hue[0.6499999079226575, 1, 0.10000012749170509`], 
        Hue[0.6499999105318043, 1, 0.10000012387904018`], 
        Hue[0.6499983183666825, 1, 0.1000023284153627], 
        Hue[0.6499994488275219, 1, 0.10000076316189273`], 
        Hue[0.6499990259760979, 1, 0.1000013486484798], 
        Hue[0.6499999589602237, 1, 0.1000000568243058], 
        Hue[0.6499999750758687, 1, 0.10000003451033561`], 
        Hue[0.6499999794211159, 1, 0.10000002849383967`], 
        Hue[0.6499999661022928, 1, 0.10000004693528683`], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.64999791089883, 1, 0.10000289260162012`], 
        Hue[0.6499942951189157, 1, 0.10000789906611669`], 
        Hue[0.6499999731984859, 1, 0.10000003710978886`], 
        Hue[0.6498992374175552, 1, 0.10013951742184668`], 
        Hue[0.6499594649681921, 1, 0.10005612542865715`], 
        Hue[0.6499906014956968, 1, 0.10001301331365066`], 
        Hue[0.6499102360885618, 1, 0.10012428849276057`], 
        Hue[0.6499975790673054, 1, 0.10000335206065415`], 
        Hue[0.6499984977543622, 1, 0.1000020800324216], 
        Hue[0.6499974391975304, 1, 0.10000354572649646`], 
        Hue[0.6499812225788024, 1, 0.10002599950627353`], 
        Hue[0.6499816678392328, 1, 0.10002538299183153`], 
        Hue[0.6498467359396423, 1, 0.10021221177587998`], 
        Hue[0.6495407493861327, 1, 0.10063588546535482`], 
        Hue[0.6498992374175552, 1, 0.1001395174218467], 
        Hue[0.6499306690177541, 1, 0.10009599674464828`], 
        Hue[0.6499594649681921, 1, 0.10005612542865716`], 
        Hue[0.6499731279556002, 1, 0.100037207446092], 
        Hue[0.6499906014956968, 1, 0.10001301331365066`], 
        Hue[0.6499996397889839, 1, 0.10000049875371464`], 
        Hue[0.6499983183666825, 1, 0.1000023284153627], 
        Hue[0.6499990259760979, 1, 0.1000013486484798], 
        Hue[0.6499999794211159, 1, 0.10000002849383967`], 
        Hue[0.6499999053015012, 1, 0.10000013112099838`], 
        Hue[0.6499995099093939, 1, 0.10000067858699309`], 
        Hue[0.6499997277891764, 1, 0.10000037690729435`], 
        Hue[0.6499997612218463, 1, 0.10000033061590513`], 
        Hue[0.6499929243432877, 1, 0.10000979706314021`], 
        Hue[0.6499992118878316, 1, 0.10000109123223312`], 
        Hue[0.6499974391975304, 1, 0.10000354572649647`], 
        Hue[0.6499552803098143, 1, 0.10006191957102643`], 
        Hue[0.6499930428076302, 1, 0.10000963303558902`], 
        Hue[0.6499816678392327, 1, 0.10002538299183167`], 
        Hue[0.6499522576756643, 1, 0.10006610475677251`], 
        Hue[0.6498467359396409, 1, 0.10021221177588176`], 
        Hue[0.6498969735437096, 1, 0.10014265201640213`], 
        Hue[0.6496731893555366, 1, 0.10045250704618], 
        Hue[0.0270736379763451, 1, 0.9625134243404452], 
        Hue[0.06744763098777695, 1, 0.9066109724784627], 
        Hue[0.027091472129359362`, 1, 0.9624887308978102], 
        Hue[0.6498464094443034, 1, 0.10021266384634916`], 
        Hue[0.6499811865783439, 1, 0.10002604935306224`], 
        Hue[0.6499815839206784, 1, 0.10002549918675299`], 
        Hue[0.6499975708283137, 1, 0.10000336346848884`], 
        Hue[0.6499974203571485, 1, 0.10000357181317905`], 
        Hue[0.6499986013933341, 1, 0.10000193653230671`], 
        Hue[0.6499997599027079, 1, 0.10000033244240446`], 
        Hue[0.649999724803093, 1, 0.10000038104187135`], 
        Hue[0.6499998715320819, 1, 0.10000017787865574`], 
        Hue[0.06747929559313426, 1, 0.9065671291787372], 
        Hue[0.0106738546460583, 1, 0.9852208166439193], 
        Hue[0.0021628179019727023`, 1, 0.997005329058807], 
        Hue[0.018968293159893457`, 1, 0.9737362094709168], 
        Hue[0.02707363797262352, 1, 0.9625134243455983], 
        Hue[0.6498467359396378, 1, 0.1002122117758862], 
        Hue[0.6498969735437079, 1, 0.10014265201640445`], 
        Hue[0.6499812225788023, 1, 0.10002599950627376`], 
        Hue[0.649977555421589, 1, 0.10003107710856916`], 
        Hue[0.6499816678392326, 1, 0.10002538299183177`], 
        Hue[0.6499975790673054, 1, 0.10000335206065417`], 
        Hue[0.6499969119221585, 1, 0.10000427580008835`], 
        Hue[0.6499974391975304, 1, 0.10000354572649647`], 
        Hue[0.6499997612218463, 1, 0.10000033061590513`], 
        Hue[0.6499995099093939, 1, 0.10000067858699309`], 
        Hue[0.6499998723238989, 1, 0.10000017678229389`], 
        Hue[0.6499997277891764, 1, 0.10000037690729435`], 
        Hue[0.6499998555397438, 1, 0.10000020002189328`], 
        Hue[0.6499906014956968, 1, 0.10001301331365064`], 
        Hue[0.6499594649681921, 1, 0.10005612542865713`], 
        Hue[0.6499731279556002, 1, 0.10003720744609199`], 
        Hue[0.6496727141920364, 1, 0.10045316496487267`], 
        Hue[0.6499102360885618, 1, 0.10012428849276055`], 
        Hue[0.6499374484373719, 1, 0.10008660985594668`], 
        Hue[0.6499445462876963, 1, 0.10007678206318982`], 
        Hue[0.6498464094443047, 1, 0.10021266384634737`], 
        Hue[0.6498967127539578, 1, 0.10014301310990469`], 
        Hue[0.6499552803098139, 1, 0.10006191957102695`], 
        Hue[0.6499942951189157, 1, 0.10000789906611669`], 
        Hue[0.6499965007467773, 1, 0.10000484511984688`], 
        Hue[0.6499913752726683, 1, 0.10001194193015163`], 
        Hue[0.6499815839206785, 1, 0.10002549918675284`], 
        Hue[0.6499929243432876, 1, 0.10000979706314021`], 
        Hue[0.6499989528715463, 1, 0.10000144987016665`], 
        Hue[0.6499974203571485, 1, 0.10000357181317905`], 
        Hue[0.6499975708283137, 1, 0.10000336346848883`], 
        Hue[0.6499999328468428, 1, 0.1000000929812946], 
        Hue[0.649999724803093, 1, 0.10000038104187135`], 
        Hue[0.6499997599027079, 1, 0.10000033244240446`], 
        Hue[0.6499999053015012, 1, 0.10000013112099838`], 
        Hue[0.6499997612218463, 1, 0.10000033061590513`], 
        Hue[0.6499998723238989, 1, 0.10000017678229389`], 
        Hue[0.6499995099093939, 1, 0.10000067858699309`], 
        Hue[0.6499999658355468, 1, 0.10000004730462761`], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.6499906014956968, 1, 0.10001301331365064`], 
        Hue[0.6499594649681921, 1, 0.10005612542865713`], 
        Hue[0.6499999731984859, 1, 0.10000003710978886`], 
        Hue[0.6499999068044836, 1, 0.10000012903994587`], 
        Hue[0.649999746592461, 1, 0.10000035087197716`], 
        Hue[0.649999231209965, 1, 0.10000106447851004`], 
        Hue[0.6499993562029576, 1, 0.1000008914112895], 
        Hue[0.6499985371764694, 1, 0.10000202544796548`], 
        Hue[0.6499955738243941, 1, 0.1000061285508389], 
        Hue[0.6499830415932077, 1, 0.10002348087094315`], 
        Hue[0.6499579090308498, 1, 0.10005827980343876`], 
        Hue[0.6499991746468223, 1, 0.10000114279670756`], 
        Hue[0.6499979082329089, 1, 0.10000289629289531`], 
        Hue[0.6499982700550374, 1, 0.10000239530840976`], 
        Hue[0.6499996397889839, 1, 0.10000049875371464`], 
        Hue[0.6499999658355468, 1, 0.10000004730462761`], 
        Hue[0.6499997857288967, 1, 0.10000029668306613`], 
        Hue[0.6499996352970167, 1, 0.10000050497336162`], 
        Hue[0.6499987037961257, 1, 0.1000017947438261], 
        Hue[0.6499991655407161, 1, 0.1000011554051624], 
        Hue[0.6499982534432173, 1, 0.1000024183093915], 
        Hue[0.6499941257642842, 1, 0.100008133557145], 
        Hue[0.6499807215560938, 1, 0.100026693230024], 
        Hue[0.6499558704947553, 1, 0.1000611023918773], 
        Hue[0.649999637473088, 1, 0.10000050196033976`], 
        Hue[0.6499990284977293, 1, 0.10000134515699023`], 
        Hue[0.6499985546968547, 1, 0.10000200118897033`], 
        Hue[0.6499999927381648, 1, 0.10000001005484888`], 
        Hue[0.6499992554553338, 1, 0.10000103090799936`], 
        Hue[0.649995048229519, 1, 0.10000685629758907`], 
        Hue[0.649976311639638, 1, 0.1000327992681936], 
        Hue[0.649920525041201, 1, 0.10011004225064472`], 
        Hue[0.6498831635659211, 1, 0.10016177352410921`], 
        Hue[0.6499999053015012, 1, 0.10000013112099838`], 
        Hue[0.6499979781484426, 1, 0.10000279948677177`], 
        Hue[0.6499904461340845, 1, 0.1000132284297292], 
        Hue[0.6499651447615216, 1, 0.10004826109943166`], 
        Hue[0.6499035776827975, 1, 0.10013350782381883`], 
        Hue[0.6498822003220268, 1, 0.1001631072464244], 
        Hue[0.6499999731984859, 1, 0.10000003710978886`], 
        Hue[0.6499989602457273, 1, 0.10000143965976213`], 
        Hue[0.6499989528715463, 1, 0.10000144987016665`], 
        Hue[0.6499857386104357, 1, 0.10001974653939674`], 
        Hue[0.6499477127625019, 1, 0.10007239771345894`], 
        Hue[0.6498491275148006, 1, 0.10020890036412224`], 
        Hue[0.6494614008079023, 1, 0.10074575272752002`], 
        Hue[0.649999637473088, 1, 0.10000050196033976`], 
        Hue[0.6499990284977293, 1, 0.10000134515699023`], 
        Hue[0.6499985546968547, 1, 0.10000200118897033`], 
        Hue[0.6499914127424963, 1, 0.10001189004885136`], 
        Hue[0.6499913752726683, 1, 0.10001194193015171`], 
        Hue[0.6499227855829615, 1, 0.10010691226974568`], 
        Hue[0.6497822958439452, 1, 0.10030143652376827`], 
        Hue[0.6499446791317128, 1, 0.10007659812532067`], 
        Hue[0.6499445462876953, 1, 0.10007678206319116`], 
        Hue[0.6496696618168444, 1, 0.1004573913305232], 
        Hue[0.6497907013374782, 1, 0.10028979814810711`], 
        Hue[0.649832150775643, 1, 0.10023240661834047`], 
        Hue[0.6497389422959969, 1, 0.10036146451323512`], 
        Hue[0.649714352432321, 1, 0.10039551201678641`], 
        Hue[0.64973878001104, 1, 0.10036168921548312`], 
        Hue[0.6497140307026751, 1, 0.10039595748860371`], 
        Hue[0.6498206206758443, 1, 0.10024837137190792`], 
        Hue[0.6353293129837054, 1, 0.12031325894563866`], 
        Hue[0.6499560274362279, 1, 0.10006088508829988`], 
        Hue[0.6499991655407161, 1, 0.1000011554051624], 
        Hue[0.6499978883756586, 1, 0.10000292378754969`], 
        Hue[0.6499982534432173, 1, 0.1000024183093915], 
        Hue[0.6499967448026513, 1, 0.10000450719632889`], 
        Hue[0.6499996352970167, 1, 0.10000050497336162`], 
        Hue[0.6499999539215624, 1, 0.1000000638009137], 
        Hue[0.6499690892099143, 1, 0.10004279955550344`], 
        Hue[0.6499949826603763, 1, 0.10000694708563293`], 
        Hue[0.6499993878957052, 1, 0.10000084752902356`], 
        Hue[0.6499999750758687, 1, 0.10000003451033561`], 
        Hue[0.6499991340538082, 1, 0.10000119900241951`], 
        Hue[0.6499996736696589, 1, 0.10000045184201072`], 
        Hue[0.6499997881961503, 1, 0.10000029326686882`], 
        Hue[0.6499998723238989, 1, 0.10000017678229389`], 
        Hue[0.6499994682338144, 1, 0.1000007362916416], 
        Hue[0.6499975790673054, 1, 0.10000335206065417`], 
        Hue[0.6499969119221585, 1, 0.10000427580008835`], 
        Hue[0.6499812225788024, 1, 0.10002599950627365`], 
        Hue[0.6499775554215891, 1, 0.10003107710856897`], 
        Hue[0.07116385446975881, 1, 0.9014654322726416], 
        Hue[0.052429459858746585`, 1, 0.9274053632725047], 
        Hue[0.058101599627731315`, 1, 0.9195516312846796], 
        Hue[0.02707363797620488, 1, 0.9625134243406394], 
        Hue[0.05244141947382608, 1, 0.9273888038054716], 
        Hue[0.05812442404677254, 1, 0.9195200282429303], 
        Hue[0.010673854646939596`, 1, 0.985220816642699], 
        Hue[0.07116385446585682, 1, 0.9014654322780444], 
        Hue[0.05244141947081893, 1, 0.9273888038096353], 
        Hue[0.05812442404452234, 1, 0.9195200282460461], 
        Hue[0.6313031433723827, 1, 0.12588795533054703`], 
        Hue[0.6450730162625566, 1, 0.10682197748261388`], 
        Hue[0.6498321507756426, 1, 0.10023240661834108`], 
        Hue[0.6497387800110438, 1, 0.10036168921547785`], 
        Hue[0.6497140307026826, 1, 0.10039595748859324`], 
        Hue[0.6499445462876959, 1, 0.10007678206319033`], 
        Hue[0.6499913752726683, 1, 0.10001194193015168`], 
        Hue[0.6499989528715463, 1, 0.10000144987016665`], 
        Hue[0.6499999042768432, 1, 0.1000001325397556], 
        Hue[0.6499999661022928, 1, 0.10000004693528683`], 
        Hue[0.6499995599269037, 1, 0.10000060933197948`], 
        Hue[0.6499996708038481, 1, 0.10000045581005648`], 
        Hue[0.6499996266415422, 1, 0.1000005169578647], 
        Hue[0.6499994633943222, 1, 0.10000074299247697`], 
        Hue[0.6499958503661866, 1, 0.10000574564681872`], 
        Hue[0.6499968945489246, 1, 0.1000042998553351], 
        Hue[0.6499964690986961, 1, 0.10000488894026689`], 
        Hue[0.6499952978986884, 1, 0.1000065106018162], 
        Hue[0.6499811865783439, 1, 0.10002604935306235`], 
        Hue[0.6499774815479086, 1, 0.10003117939520355`], 
        Hue[0.010667080107075066`, 1, 0.9852301967748192], 
        Hue[0.027091472129990746`, 1, 0.9624887308969359], 
        Hue[0.010673854646060521`, 1, 0.9852208166439161], 
        Hue[0.010667080104723725`, 1, 0.9852301967780749], 
        Hue[0.05242945985458425, 1, 0.927405363278268], 
        Hue[0.05810159962324535, 1, 0.919551631290891], 
        Hue[0.6497389422959918, 1, 0.10036146451324211`], 
        Hue[0.6497143524323117, 1, 0.10039551201679923`], 
        Hue[0.6499446791317118, 1, 0.10007659812532207`], 
        Hue[0.6499914127424962, 1, 0.10001189004885144`], 
        Hue[0.6499989602457273, 1, 0.10000143965976215`], 
        Hue[0.6499999053015012, 1, 0.10000013112099838`], 
        Hue[0.6499998099007703, 1, 0.10000026321431808`], 
        Hue[0.6499981812644314, 1, 0.10000251824924884`], 
        Hue[0.6499871127135868, 1, 0.10001784393503368`], 
        Hue[0.02709147212931462, 1, 0.9624887308978721], 
        Hue[0.02707363797266582, 1, 0.9625134243455397], 
        Hue[0.6499552803098139, 1, 0.10006191957102697`], 
        Hue[0.6499929243432876, 1, 0.10000979706314023`], 
        Hue[0.649998861931212, 1, 0.10000157578755257`], 
        Hue[0.6499999539215624, 1, 0.1000000638009137], 
        Hue[0.6499996397889839, 1, 0.10000049875371464`], 
        Hue[0.6499993192256, 1, 0.10000094261070784`], 
        Hue[0.6499982700550374, 1, 0.10000239530840976`], 
        Hue[0.6499989057002725, 1, 0.10000151518423804`], 
        Hue[0.6497851328324681, 1, 0.10029750838581342`], 
        Hue[0.6494614008079023, 1, 0.10074575272752002`], 
        Hue[0.6404078578025607, 1, 0.11328142765799296`], 
        Hue[0.6498206455449007, 1, 0.10024833693782975`], 
        Hue[0.6499551253828283, 1, 0.1000621340853147], 
        Hue[0.6499719284481867, 1, 0.1000388683025107], 
        Hue[0.649981186578344, 1, 0.10002604935306213`], 
        Hue[0.6499774815479088, 1, 0.10003117939520317`], 
        Hue[0.6499928827959313, 1, 0.10000985459024901`], 
        Hue[0.6499812225788023, 1, 0.10002599950627371`], 
        Hue[0.649977555421589, 1, 0.10003107710856914`], 
        Hue[0.6499899497720244, 1, 0.10001391570027393`], 
        Hue[0.6499993562029576, 1, 0.1000008914112895], 
        Hue[0.649998333888502, 1, 0.10000230692361262`], 
        Hue[0.6499985371764694, 1, 0.10000202544796548`], 
        Hue[0.649981132862961, 1, 0.10002612372820784`], 
        Hue[0.6499954680826809, 1, 0.10000627496244185`], 
        Hue[0.6499986013933341, 1, 0.1000019365323067], 
        Hue[0.6499968945489247, 1, 0.10000429985533509`], 
        Hue[0.6499991262252099, 1, 0.10000120984201698`], 
        Hue[0.6499975790673054, 1, 0.10000335206065417`], 
        Hue[0.6499969119221585, 1, 0.10000427580008835`], 
        Hue[0.6499887061646138, 1, 0.10001563761822713`], 
        Hue[0.649997998599588, 1, 0.10000277116980137`], 
        Hue[0.649999746592461, 1, 0.10000035087197716`], 
        Hue[0.6499999731984859, 1, 0.10000003710978886`], 
        Hue[0.6498206206758443, 1, 0.10024837137190794`], 
        Hue[0.6499888903804653, 1, 0.10001538255012506`], 
        Hue[0.6499971342997227, 1, 0.10000396789269159`], 
        Hue[0.649999454487984, 1, 0.10000075532432992`], 
        Hue[0.6499997881961503, 1, 0.10000029326686882`], 
        Hue[0.6499998715320819, 1, 0.10000017787865574`], 
        Hue[0.6499996708038481, 1, 0.10000045581005648`], 
        Hue[0.6499998405135435, 1, 0.10000022082740136`], 
        Hue[0.6499997277891764, 1, 0.10000037690729435`], 
        Hue[0.6499996736696589, 1, 0.10000045184201072`], 
        Hue[0.6498206455449007, 1, 0.10024833693782977`], 
        Hue[0.6499908589738947, 1, 0.10001265680537647`], 
        Hue[0.6499980650680817, 1, 0.10000267913650228`], 
        Hue[0.6499997205474622, 1, 0.10000038693428308`], 
        Hue[0.6499999927381648, 1, 0.10000001005484888`], 
        Hue[0.6499999750758687, 1, 0.10000003451033561`], 
        Hue[0.649997537735836, 1, 0.10000340928884255`], 
        Hue[0.6499990259760979, 1, 0.1000013486484798], 
        Hue[0.6499453175635969, 1, 0.10007571414271207`], 
        Hue[0.6499975567721432, 1, 0.10000338293087865`], 
        Hue[0.6499991607215534, 1, 0.10000116207784923`], 
        Hue[0.6499999209879762, 1, 0.10000010940126382`], 
        Hue[0.6499452554080252, 1, 0.10007580020427294`], 
        Hue[0.6499999927381648, 1, 0.10000001005484888`], 
        Hue[0.6499999724303417, 1, 0.10000003817337312`], 
        Hue[0.6483242391402425, 1, 0.10232028426735651`], 
        Hue[0.6431583990632883, 1, 0.1094729859123701], 
        Hue[0.6482530143242407, 1, 0.10241890324335912`], 
        Hue[0.6463635850696269, 1, 0.10503503605743975`], 
        Hue[0.6471956278813717, 1, 0.10388297677963922`], 
        Hue[0.6464975004715672, 1, 0.10484961473167623`], 
        Hue[0.6499975567721432, 1, 0.10000338293087865`], 
        Hue[0.6499991607215534, 1, 0.10000116207784923`], 
        Hue[0.6499996979082646, 1, 0.10000041828086434`], 
        Hue[0.6431583990632911, 1, 0.10947298591236626`], 
        Hue[0.6483242391402418, 1, 0.10232028426735748`], 
        Hue[0.6463635850696212, 1, 0.10503503605744753`], 
        Hue[0.6482530143242377, 1, 0.10241890324336335`], 
        Hue[0.6483242391402463, 1, 0.10232028426735128`], 
        Hue[0.6482524798771888, 1, 0.10241964324696944`], 
        Hue[0.6460888132276699, 1, 0.10541548937707247`], 
        Hue[0.6451751558078836, 1, 0.10668055349677649`], 
        Hue[0.6447410918958293, 1, 0.1072815650673133], 
        Hue[0.6313031433723599, 1, 0.12588795533057862`], 
        Hue[0.6465512173141803, 1, 0.10477523756498112`], 
        Hue[0.6450730162625558, 1, 0.10682197748261514`], 
        Hue[0.6460888132276699, 1, 0.10541548937707258`], 
        Hue[0.6451751558078835, 1, 0.1066805534967767], 
        Hue[0.6451837682394977, 1, 0.10666862859146475`], 
        Hue[0.6479792421191494, 1, 0.10279797245040857`], 
        Hue[0.6476184271540987, 1, 0.10329756240201719`], 
        Hue[0.6475036441269619, 1, 0.10345649274728348`], 
        Hue[0.648324239140247, 1, 0.10232028426735042`], 
        Hue[0.6482524798771917, 1, 0.10241964324696531`], 
        Hue[0.648682976894605, 1, 0.10182357045362386`], 
        Hue[0.6465512173141805, 1, 0.10477523756498087`], 
        Hue[0.6479792421191495, 1, 0.10279797245040849`], 
        Hue[0.6476184271540988, 1, 0.10329756240201703`], 
        Hue[0.6499698377498546, 1, 0.10004176311558596`], 
        Hue[0.6499958626928356, 1, 0.10000572857915081`], 
        Hue[0.6499989602457273, 1, 0.10000143965976215`], 
        Hue[0.6499995620862684, 1, 0.10000060634208989`], 
        Hue[0.6499855624175456, 1, 0.10001999049878305`], 
        Hue[0.6499942635068771, 1, 0.10000794283663174`], 
        Hue[0.6499957594867645, 1, 0.10000587147986459`], 
        Hue[0.6499982534432173, 1, 0.1000024183093915], 
        Hue[0.6499986030712614, 1, 0.10000193420902256`], 
        Hue[0.6499996352970167, 1, 0.10000050497336162`], 
        Hue[0.6499996918089019, 1, 0.10000042672613585`], 
        Hue[0.6499857545886895, 1, 0.10001972441566084`], 
        Hue[0.649994657510819, 1, 0.1000073972927123], 
        Hue[0.6499959545446957, 1, 0.10000560139965206`], 
        Hue[0.6499985371764694, 1, 0.10000202544796548`], 
        Hue[0.6499987724866683, 1, 0.10000169963384406`], 
        Hue[0.649999746592461, 1, 0.10000035087197716`], 
        Hue[0.64999976764185, 1, 0.10000032172666927`], 
        Hue[0.6499856125038711, 1, 0.10001992114848618`], 
        Hue[0.649988018614091, 1, 0.10001658961125877`], 
        Hue[0.6499958852039428, 1, 0.10000569740992535`], 
        Hue[0.6499967008729203, 1, 0.1000045680221105], 
        Hue[0.6499926276132632, 1, 0.10001020792009714`], 
        Hue[0.6499908288660274, 1, 0.10001269849319286`], 
        Hue[0.6499991007478049, 1, 0.10000124511842408`], 
        Hue[0.649997537735836, 1, 0.10000340928884255`], 
        Hue[0.6499858078426721, 1, 0.1000196506793771], 
        Hue[0.649988752611403, 1, 0.1000155733072882], 
        Hue[0.6499728876119557, 1, 0.10003754022959983`], 
        Hue[0.6499965007467773, 1, 0.10000484511984689`], 
        Hue[0.6499970665105199, 1, 0.1000040617546648], 
        Hue[0.6499933578423218, 1, 0.10000919683370825`], 
        Hue[0.6499920691746767, 1, 0.10001098114275549`], 
        Hue[0.6498594518723236, 1, 0.10019460509985961`], 
        Hue[0.6498693537502516, 1, 0.10018089480734406`], 
        Hue[0.6499993562029576, 1, 0.1000008914112895], 
        Hue[0.649997036906219, 1, 0.10000410274523522`], 
        Hue[0.6499886776939561, 1, 0.10001567703913772`], 
        Hue[0.6499857545886895, 1, 0.10001972441566084`], 
        Hue[0.6498965941389109, 1, 0.10014317734612337`], 
        Hue[0.6479792421191494, 1, 0.10279797245040863`], 
        Hue[0.6476184271540988, 1, 0.1032975624020171], 
        Hue[0.6475036441269622, 1, 0.10345649274728327`], 
        Hue[0.6465512173141802, 1, 0.10477523756498137`], 
        Hue[0.645653310526761, 1, 0.1060184931167925], 
        Hue[0.6479792421191491, 1, 0.10279797245040885`], 
        Hue[0.6476184271540985, 1, 0.10329756240201762`], 
        Hue[0.6475036441269617, 1, 0.10345649274728375`], 
        Hue[0.6460888132276827, 1, 0.10541548937705467`], 
        Hue[0.6451751558079051, 1, 0.10668055349674681`], 
        Hue[0.6447410918958457, 1, 0.10728156506729052`], 
        Hue[0.6432319744106683, 1, 0.10937111235445943`], 
        Hue[0.644822685525103, 1, 0.10716858927293434`], 
        Hue[0.642232904597574, 1, 0.1107544397879746], 
        Hue[0.6447422602883427, 1, 0.10727994729306399`], 
        Hue[0.6432412882886112, 1, 0.1093582162157692], 
        Hue[0.6465512173141732, 1, 0.10477523756499099`], 
        Hue[0.6369345841081043, 1, 0.11809057585031717`], 
        Hue[0.6313032801501992, 1, 0.12588776594587803`], 
        Hue[0.5681211260697845, 1, 0.21337074851875992`], 
        Hue[0.6035532562554852, 1, 0.16431087595394364`], 
        Hue[0.6363391370257159, 1, 0.11891504104131655`], 
        Hue[0.6309334967132458, 1, 0.1263997737816596], 
        Hue[0.6451837682394547, 1, 0.10666862859152436`], 
        Hue[0.6460888132276146, 1, 0.10541548937714908`], 
        Hue[0.6451751558078197, 1, 0.10668055349686502`], 
        Hue[0.6447410918957623, 1, 0.10728156506740609`], 
        Hue[0.6432319744106638, 1, 0.10937111235446557`], 
        Hue[0.6448226855250837, 1, 0.10716858927296105`], 
        Hue[0.5681211260697305, 1, 0.21337074851883464`], 
        Hue[0.6035532562554903, 1, 0.16431087595393662`], 
        Hue[0.6175668224059234, 1, 0.1449074766687214], 
        Hue[0.6369345841081185, 1, 0.11809057585029736`], 
        Hue[0.6313032801502132, 1, 0.12588776594585865`], 
        Hue[0.6431583990630713, 1, 0.10947298591267063`], 
        Hue[0.636934584107928, 1, 0.11809057585056115`], 
        Hue[0.6313032801501643, 1, 0.1258877659459263], 
        Hue[0.5681211260708114, 1, 0.21337074851733795`], 
        Hue[0.6035532562559326, 1, 0.16431087595332416`], 
        Hue[0.6175668224060558, 1, 0.14490747666853818`], 
        Hue[0.643231974410409, 1, 0.10937111235481833`], 
        Hue[0.6448226855248737, 1, 0.10716858927325197`], 
        Hue[0.6499991655407161, 1, 0.1000011554051624], 
        Hue[0.6499966739061288, 1, 0.10000460536074483`], 
        Hue[0.6499879519206576, 1, 0.1000166819560126], 
        Hue[0.6499855624175456, 1, 0.10001999049878303`], 
        Hue[0.6498948240795815, 1, 0.10014562819750247`], 
        Hue[0.63093349671357, 1, 0.12639977378121073`], 
        Hue[0.639857669156809, 1, 0.11404322732134148`], 
        Hue[0.6363391370261072, 1, 0.11891504104077469`], 
        Hue[0.5681211260708074, 1, 0.2133707485173436], 
        Hue[0.6035532562559285, 1, 0.16431087595332988`], 
        Hue[0.617566822406053, 1, 0.144907476668542], 
        Hue[0.6431583990630698, 1, 0.10947298591267261`], 
        Hue[0.6369345841079257, 1, 0.11809057585056448`], 
        Hue[0.6432412882886738, 1, 0.10935821621568247`], 
        Hue[0.644742260288362, 1, 0.10727994729303719`], 
        Hue[0.6432319744104082, 1, 0.10937111235481942`], 
        Hue[0.6448226855248731, 1, 0.10716858927325264`], 
        Hue[0.6456533105267654, 1, 0.10601849311678642`], 
        Hue[0.6498693537502516, 1, 0.100180894807344], 
        Hue[0.6499374484373719, 1, 0.10008660985594665`], 
        Hue[0.6498594518723237, 1, 0.1001946050998595], 
        Hue[0.6499933578423218, 1, 0.10000919683370825`], 
        Hue[0.6499920691746767, 1, 0.10001098114275549`], 
        Hue[0.6499965007467773, 1, 0.10000484511984688`], 
        Hue[0.6499970665105199, 1, 0.1000040617546648], 
        Hue[0.649988752611403, 1, 0.10001557330728819`], 
        Hue[0.6499858078426721, 1, 0.10001965067937708`], 
        Hue[0.6499977238559549, 1, 0.10000315158406245`], 
        Hue[0.6499991746468223, 1, 0.10000114279670756`], 
        Hue[0.6499926276132632, 1, 0.10001020792009714`], 
        Hue[0.6499908288660274, 1, 0.10001269849319284`], 
        Hue[0.6499958852039428, 1, 0.10000569740992533`], 
        Hue[0.6499967008729203, 1, 0.10000456802211048`], 
        Hue[0.649988018614091, 1, 0.10001658961125875`], 
        Hue[0.6499856125038711, 1, 0.10001992114848615`], 
        Hue[0.6499999068044836, 1, 0.10000012903994587`], 
        Hue[0.6499992554553338, 1, 0.10000103090799936`], 
        Hue[0.6499452847292683, 1, 0.10007575960562864`], 
        Hue[0.6499560274362279, 1, 0.10006088508829988`], 
        Hue[0.649997310025984, 1, 0.10000372457940669`], 
        Hue[0.6499980905392484, 1, 0.10000264386873307`], 
        Hue[0.6499992600207877, 1, 0.10000102458660165`], 
        Hue[0.6499999539215624, 1, 0.1000000638009137], 
        Hue[0.6499998099007703, 1, 0.10000026321431808`], 
        Hue[0.649998861931212, 1, 0.10000157578755257`], 
        Hue[0.6499453252164491, 1, 0.10007570354645512`], 
        Hue[0.6499927658336027, 1, 0.10001001653808872`], 
        Hue[0.6499970704909728, 1, 0.10000405624326845`], 
        Hue[0.6499999926822643, 1, 0.10000001013224943`], 
        Hue[0.649999231209965, 1, 0.10000106447851004`], 
        Hue[0.649999746592461, 1, 0.10000035087197716`], 
        Hue[0.649995048229519, 1, 0.10000685629758907`], 
        Hue[0.649912880804017, 1, 0.10012062657905337`], 
        Hue[0.6499334905618971, 1, 0.10009208999121949`], 
        Hue[0.6499428471125177, 1, 0.10007913476728314`], 
        Hue[0.6499742829535601, 1, 0.10003560821814764`], 
        Hue[0.6499995099093939, 1, 0.10000067858699309`], 
        Hue[0.6499997612218463, 1, 0.10000033061590513`], 
        Hue[0.6499996736696589, 1, 0.10000045184201072`], 
        Hue[0.6499997277891764, 1, 0.10000037690729435`], 
        Hue[0.6499998723238989, 1, 0.10000017678229389`], 
        Hue[0.6499997599027079, 1, 0.10000033244240446`], 
        Hue[0.6499996708038481, 1, 0.10000045581005648`], 
        Hue[0.6499998715320819, 1, 0.10000017787865574`], 
        Hue[0.6499981812644314, 1, 0.10000251824924884`], 
        Hue[0.6499155953597011, 1, 0.10011686796349077`], 
        Hue[0.6499442388258546, 1, 0.10007720777958598`], 
        Hue[0.6499955738243941, 1, 0.1000061285508389], 
        Hue[0.6499985371764694, 1, 0.10000202544796548`], 
        Hue[0.649976311639638, 1, 0.1000327992681936], 
        Hue[0.6499786307209967, 1, 0.10002958823246613`], 
        Hue[0.649983522105702, 1, 0.10002281554595112`], 
        Hue[0.6499919444905073, 1, 0.10001115378237442`], 
        Hue[0.6499910794886076, 1, 0.1000123514773127], 
        Hue[0.6499975708283137, 1, 0.10000336346848884`], 
        Hue[0.6499968945489246, 1, 0.1000042998553351], 
        Hue[0.6499986013933341, 1, 0.1000019365323067], 
        Hue[0.6499871127135868, 1, 0.10001784393503368`], 
        Hue[0.6499927658336027, 1, 0.10001001653808872`], 
        Hue[0.6499970704909728, 1, 0.10000405624326845`], 
        Hue[0.6499972818328055, 1, 0.10000376361611546`], 
        Hue[0.6499983540750625, 1, 0.10000227897299048`], 
        Hue[0.6499830415932077, 1, 0.10002348087094315`], 
        Hue[0.6499933017246096, 1, 0.10000927453515605`], 
        Hue[0.649920525041201, 1, 0.10011004225064472`], 
        Hue[0.6499371615166366, 1, 0.10008700713081092`], 
        Hue[0.6499811865783439, 1, 0.10002604935306231`], 
        Hue[0.6499774815479086, 1, 0.10003117939520352`], 
        Hue[0.6499579090308498, 1, 0.10005827980343876`], 
        Hue[0.6465824912328809, 1, 0.10473193521601107`], 
        Hue[0.6469518842360068, 1, 0.10422046798091374`], 
        Hue[0.6464981818998694, 1, 0.1048486712155655], 
        Hue[0.6486837082759831, 1, 0.1018225577717157], 
        Hue[0.6471966341309858, 1, 0.1038815835109428], 
        Hue[0.648252479877121, 1, 0.10241964324706332`], 
        Hue[0.6486829768945355, 1, 0.10182357045372016`], 
        Hue[0.6474500234495466, 1, 0.1035307367621662], 
        Hue[0.646551987163097, 1, 0.10477417162032727`], 
        Hue[0.6441390283452341, 1, 0.1081151915219836], 
        Hue[0.6499452554080251, 1, 0.10007580020427298`], 
        Hue[0.6378619063740157, 1, 0.11680659117443976`], 
        Hue[0.6394934187185672, 1, 0.1145475740819838], 
        Hue[0.641618216230081, 1, 0.11160554675834945`], 
        Hue[0.6090317928643224, 1, 0.15672520988016897`], 
        Hue[0.5965604897300457, 1, 0.17399316806609055`], 
        Hue[0.6058778207336497, 1, 0.16109224821494667`], 
        Hue[0.6210502495195851, 1, 0.14008426989595912`], 
        Hue[0.6416182162300761, 1, 0.11160554675835616`], 
        Hue[0.6417543806434738, 1, 0.11141701141672865`], 
        Hue[0.6499304140750839, 1, 0.10009634974219153`], 
        Hue[0.6499879519206576, 1, 0.10001668195601261`], 
        Hue[0.6499925770634212, 1, 0.10001027791218615`], 
        Hue[0.6499982700550374, 1, 0.10000239530840976`], 
        Hue[0.6499428471125177, 1, 0.10007913476728321`], 
        Hue[0.6499742829535601, 1, 0.10003560821814765`], 
        Hue[0.6499770919050559, 1, 0.10003171890069185`], 
        Hue[0.6353293129837174, 1, 0.12031325894562206`], 
        Hue[0.6210502495196695, 1, 0.1400842698958423], 
        Hue[0.6220796274099561, 1, 0.1386589774323685], 
        Hue[0.6498768869650647, 1, 0.10017046420221809`], 
        Hue[0.6499888903804653, 1, 0.10001538255012506`], 
        Hue[0.649972980055223, 1, 0.10003741223122971`], 
        Hue[0.6499980722882938, 1, 0.10000266913928554`], 
        Hue[0.6499992600207877, 1, 0.10000102458660165`], 
        Hue[0.6498182666377854, 1, 0.10025163080922017`], 
        Hue[0.649981132862961, 1, 0.10002612372820786`], 
        Hue[0.6499568986091694, 1, 0.10005967884884236`], 
        Hue[0.6499971342997227, 1, 0.10000396789269159`], 
        Hue[0.6499998555397438, 1, 0.10000020002189328`], 
        Hue[0.6465824912328155, 1, 0.1047319352161016], 
        Hue[0.646951884235956, 1, 0.10422046798098417`], 
        Hue[0.6464981818998243, 1, 0.10484867121562785`], 
        Hue[0.6464975004716572, 1, 0.10484961473155151`], 
        Hue[0.6497373247140598, 1, 0.1003637042420711], 
        Hue[0.6499719284481866, 1, 0.10003886830251084`], 
        Hue[0.6499369681039929, 1, 0.10008727493293283`], 
        Hue[0.6499954680826809, 1, 0.10000627496244185`], 
        Hue[0.649999454487984, 1, 0.10000075532432992`], 
        Hue[0.649983522105702, 1, 0.10002281554595117`], 
        Hue[0.6499919444905073, 1, 0.10001115378237445`], 
        Hue[0.6499910794886075, 1, 0.10001235147731274`], 
        Hue[0.649998606782629, 1, 0.10000192907020604`], 
        Hue[0.6499992903837791, 1, 0.10000098254553669`], 
        Hue[0.6499884844621604, 1, 0.10001594459085487`], 
        Hue[0.6499935635661466, 1, 0.10000891198533556`], 
        Hue[0.6499547241190271, 1, 0.10006268968134718`], 
        Hue[0.6471966341309734, 1, 0.10388158351096], 
        Hue[0.6486837082759777, 1, 0.10182255777172321`], 
        Hue[0.027091472130218897`, 1, 0.96248873089662], 
        Hue[0.6474500234496732, 1, 0.10353073676199107`], 
        Hue[0.649955125382828, 1, 0.10006213408531515`], 
        Hue[0.6499928827959313, 1, 0.10000985459024905`], 
        Hue[0.6499991262252099, 1, 0.10000120984201699`], 
        Hue[0.6499999658355468, 1, 0.10000004730462761`], 
        Hue[0.6498967127539552, 1, 0.1001430131099082], 
        Hue[0.6498321507756425, 1, 0.10023240661834114`], 
        Hue[0.6497387800110396, 1, 0.10036168921548362`], 
        Hue[0.649714030702675, 1, 0.10039595748860397`], 
        Hue[0.010673854646818914`, 1, 0.9852208166428661], 
        Hue[0.010667080104693194`, 1, 0.9852301967781171], 
        Hue[0.649983522105702, 1, 0.10002281554595115`], 
        Hue[0.6499919444905073, 1, 0.10001115378237443`], 
        Hue[0.6499999750758687, 1, 0.10000003451033561`], 
        Hue[0.6499997857288967, 1, 0.10000029668306613`], 
        Hue[0.6499979781484426, 1, 0.10000279948677178`], 
        Hue[0.6499857386104357, 1, 0.10001974653939674`], 
        Hue[0.6499227855829615, 1, 0.10010691226974568`], 
        Hue[0.649936968103993, 1, 0.10008727493293268`], 
        Hue[0.6496696618168444, 1, 0.1004573913305232], 
        Hue[0.6497373247140593, 1, 0.1003637042420717], 
        Hue[0.648252479877121, 1, 0.10241964324706324`], 
        Hue[0.6486829768945355, 1, 0.1018235704537201], 
        Hue[0.647450023449547, 1, 0.10353073676216572`], 
        Hue[0.6313031433718941, 1, 0.12588795533122368`], 
        Hue[0.0711638544660157, 1, 0.9014654322778245], 
        Hue[0.05244141947093095, 1, 0.9273888038094803], 
        Hue[0.05242945985472813, 1, 0.9274053632780688], 
        Hue[0.05810159962336514, 1, 0.9195516312907253], 
        Hue[0.6482530143241786, 1, 0.10241890324344512`], 
        Hue[0.6463635850694541, 1, 0.10503503605767897`], 
        Hue[0.6474507800969185, 1, 0.10352968909657442`], 
        Hue[0.6486837082759177, 1, 0.10182255777180628`], 
        Hue[0.6471966341308304, 1, 0.10388158351115798`], 
        Hue[0.6499910794886075, 1, 0.10001235147731273`], 
        Hue[0.6499938301355157, 1, 0.10000854288928591`], 
        Hue[0.6499987037961257, 1, 0.1000017947438261], 
        Hue[0.6499996352970167, 1, 0.10000050497336162`], 
        Hue[0.6499904461340845, 1, 0.1000132284297292], 
        Hue[0.6499477127625019, 1, 0.10007239771345895`], 
        Hue[0.6499568986091695, 1, 0.1000596788488423], 
        Hue[0.6497822958439452, 1, 0.1003014365237683], 
        Hue[0.649818266637786, 1, 0.10025163080921949`], 
        Hue[0.6465824912328294, 1, 0.10473193521608234`], 
        Hue[0.6469518842359252, 1, 0.10422046798102663`], 
        Hue[0.6499975567721432, 1, 0.10000338293087865`], 
        Hue[0.6499991607215534, 1, 0.10000116207784923`], 
        Hue[0.6499996979082646, 1, 0.10000041828086434`], 
        Hue[0.6499992600207877, 1, 0.10000102458660165`], 
        Hue[0.6499988738287195, 1, 0.10000155931408075`], 
        Hue[0.6499995822700525, 1, 0.1000005783953119], 
        Hue[0.6499941257642842, 1, 0.100008133557145], 
        Hue[0.6499982534432173, 1, 0.1000024183093915], 
        Hue[0.6499651447615216, 1, 0.10004826109943166`], 
        Hue[0.649972980055223, 1, 0.1000374122312297], 
        Hue[0.6498491275148006, 1, 0.10020890036412228`], 
        Hue[0.6498768869650648, 1, 0.10017046420221801`], 
        Hue[0.6058778207335989, 1, 0.161092248215017], 
        Hue[0.6210502495195549, 1, 0.14008426989600098`], 
        Hue[0.6220796274097713, 1, 0.1386589774326244], 
        Hue[0.6499428471125177, 1, 0.10007913476728315`], 
        Hue[0.6499742829535601, 1, 0.10003560821814764`], 
        Hue[0.6499770919050559, 1, 0.10003171890069183`], 
        Hue[0.6499807215560938, 1, 0.100026693230024], 
        Hue[0.6499925770634212, 1, 0.10001027791218614`], 
        Hue[0.6499035776827975, 1, 0.10013350782381886`], 
        Hue[0.649930414075084, 1, 0.10009634974219148`], 
        Hue[0.6394934187185649, 1, 0.11454757408198707`], 
        Hue[0.6416182162300839, 1, 0.11160554675834541`], 
        Hue[0.6417543806434844, 1, 0.11141701141671394`], 
        Hue[0.6499558704947553, 1, 0.1000611023918773], 
        Hue[0.6210502495196204, 1, 0.1400842698959103], 
        Hue[0.6220796274098989, 1, 0.1386589774324477], 
        Hue[0.5965604897305343, 1, 0.17399316806541407`], 
        Hue[0.6090317928649146, 1, 0.156725209879349], 
        Hue[0.6416182162300909, 1, 0.11160554675833581`], 
        Hue[0.6417543806434991, 1, 0.1114170114166936], 
        Hue[0.6378619063741094, 1, 0.11680659117431007`], 
        Hue[0.6441390283452455, 1, 0.10811519152196784`], 
        Hue[0.646551987163097, 1, 0.10477417162032729`], 
        Hue[0.6474500234496774, 1, 0.10353073676198514`], 
        Hue[0.6463635850694534, 1, 0.10503503605767994`], 
        Hue[0.6482530143241784, 1, 0.10241890324344531`], 
        Hue[0.647450780096918, 1, 0.10352968909657513`], 
        Hue[0.64719663413083, 1, 0.10388158351115853`], 
        Hue[0.6486837082759176, 1, 0.10182255777180639`], 
        Hue[0.6465824912328293, 1, 0.10473193521608254`], 
        Hue[0.6469518842359251, 1, 0.10422046798102687`], 
        Hue[0.6464981818997425, 1, 0.10484867121574122`], 
        Hue[0.6499453175635969, 1, 0.10007571414271205`], 
        Hue[0.649832150775643, 1, 0.1002324066183404], 
        Hue[0.6497389422959922, 1, 0.10036146451324161`], 
        Hue[0.6497143524323119, 1, 0.10039551201679897`], 
        Hue[0.649896973543708, 1, 0.10014265201640439`], 
        Hue[0.6499371615166366, 1, 0.10008700713081096`], 
        Hue[0.6499886776939561, 1, 0.10001567703913773`], 
        Hue[0.6499933017246096, 1, 0.10000927453515607`], 
        Hue[0.6499927658336027, 1, 0.10001001653808872`], 
        Hue[0.6499970704909728, 1, 0.10000405624326845`], 
        Hue[0.6499972818328055, 1, 0.10000376361611546`], 
        Hue[0.6499690892099144, 1, 0.10004279955550321`], 
        Hue[0.649983522105702, 1, 0.10002281554595113`], 
        Hue[0.6499919444905073, 1, 0.10001115378237443`], 
        Hue[0.6499910794886075, 1, 0.10001235147731273`], 
        Hue[0.6499908589738947, 1, 0.10001265680537647`], 
        Hue[0.6499786307209967, 1, 0.10002958823246615`], 
        Hue[0.6499984305375945, 1, 0.10000217310179225`], 
        Hue[0.6499949826603763, 1, 0.10000694708563292`], 
        Hue[0.6499983681725562, 1, 0.10000225945338377`], 
        Hue[0.6499887061646138, 1, 0.10001563761822713`], 
        Hue[0.6499980650680817, 1, 0.10000267913650228`], 
        Hue[0.6499442388258546, 1, 0.10007720777958594`], 
        Hue[0.6499155953597011, 1, 0.10011686796349074`], 
        Hue[0.6499967448026513, 1, 0.10000450719632889`], 
        Hue[0.6499993878957052, 1, 0.10000084752902356`], 
        Hue[0.6499428471125177, 1, 0.10007913476728314`], 
        Hue[0.6499742829535601, 1, 0.10003560821814764`], 
        Hue[0.6499770919050559, 1, 0.10003171890069183`], 
        Hue[0.6499334905618971, 1, 0.10009208999121944`], 
        Hue[0.6499306690177541, 1, 0.10009599674464822`], 
        Hue[0.6499128808040171, 1, 0.10012062657905328`], 
        Hue[0.6499899497720244, 1, 0.10001391570027393`], 
        Hue[0.649997998599588, 1, 0.10000277116980137`], 
        Hue[0.6499997205474622, 1, 0.10000038693428308`], 
        Hue[0.6499927658336027, 1, 0.10001001653808872`], 
        Hue[0.6499970704909728, 1, 0.10000405624326845`], 
        Hue[0.6499972818328055, 1, 0.10000376361611546`], 
        Hue[0.649999637473088, 1, 0.10000050196033976`], 
        Hue[0.6499990284977293, 1, 0.10000134515699023`], 
        Hue[0.6499985546968547, 1, 0.10000200118897033`], 
        Hue[0.6499983540750625, 1, 0.10000227897299048`], 
        Hue[0.6499977323549201, 1, 0.10000313981626457`], 
        Hue[0.6499453252164491, 1, 0.10007570354645513`], 
        Hue[0.6499879519206576, 1, 0.10001668195601261`], 
        Hue[0.6499972861634967, 1, 0.10000375761977373`], 
        Hue[0.6499980722882938, 1, 0.10000266913928554`], 
        Hue[0.6499993956352772, 1, 0.10000083681269313`], 
        Hue[0.6499996064912191, 1, 0.10000054485831195`], 
        Hue[0.6499975567721432, 1, 0.10000338293087865`], 
        Hue[0.6499991607215534, 1, 0.10000116207784923`], 
        Hue[0.6499996979082646, 1, 0.10000041828086434`], 
        Hue[0.6499992600207877, 1, 0.10000102458660165`], 
        Hue[0.6499996397889839, 1, 0.10000049875371464`], 
        Hue[0.6499995822700525, 1, 0.1000005783953119], 
        Hue[0.649999402582182, 1, 0.10000082719390185`], 
        Hue[0.6499999539215624, 1, 0.1000000638009137], 
        Hue[0.6499982700550374, 1, 0.10000239530840976`], 
        Hue[0.649997310025984, 1, 0.10000372457940668`], 
        Hue[0.6499452847292683, 1, 0.10007575960562862`], 
        Hue[0.6499886776939561, 1, 0.10001567703913773`], 
        Hue[0.6499977069520597, 1, 0.10000317498945578`], 
        Hue[0.6499984305375945, 1, 0.10000217310179225`], 
        Hue[0.6499995741123579, 1, 0.10000058969058151`], 
        Hue[0.6499997386779457, 1, 0.1000003618305367], 
        Hue[0.6499988738287195, 1, 0.10000155931408075`], 
        Hue[0.6499995822700525, 1, 0.1000005783953119], 
        Hue[0.6499977323549201, 1, 0.10000313981626457`], 
        Hue[0.6499972818328055, 1, 0.10000376361611546`], 
        Hue[0.6499983540750625, 1, 0.10000227897299048`], 
        Hue[0.6499995672298762, 1, 0.10000059922017145`], 
        Hue[0.6499998500410374, 1, 0.10000020763548673`], 
        Hue[0.6499999121863456, 1, 0.10000012158813694`], 
        Hue[0.6499306690177541, 1, 0.10009599674464828`], 
        Hue[0.6499731279556002, 1, 0.10003720744609199`], 
        Hue[0.6499770919050559, 1, 0.10003171890069185`], 
        Hue[0.649985171412803, 1, 0.10002053188996514`], 
        Hue[0.6499374484373719, 1, 0.1000866098559467], 
        Hue[0.6499995672298762, 1, 0.10000059922017145`], 
        Hue[0.6499998500410374, 1, 0.10000020763548673`], 
        Hue[0.6499969119221585, 1, 0.10000427580008833`], 
        Hue[0.6499938301355158, 1, 0.10000854288928589`], 
        Hue[0.6499775554215892, 1, 0.10003107710856879`], 
        Hue[0.6498969735437105, 1, 0.10014265201640095`], 
        Hue[0.649985171412803, 1, 0.10002053188996515`], 
        Hue[0.6499995822700525, 1, 0.1000005783953119], 
        Hue[0.6499998922117048, 1, 0.10000014924533172`], 
        Hue[0.6499997981432292, 1, 0.1000002794939904], 
        Hue[0.6499938301355157, 1, 0.10000854288928591`], 
        Hue[0.6499989602457273, 1, 0.10000143965976215`], 
        Hue[0.6499914127424963, 1, 0.10001189004885142`], 
        Hue[0.6499446791317125, 1, 0.10007659812532119`], 
        Hue[0.6497389422959958, 1, 0.10036146451323662`], 
        Hue[0.6497143524323192, 1, 0.10039551201678877`], 
        Hue[0.07116385446886964, 1, 0.9014654322738728], 
        Hue[0.05242945985811742, 1, 0.9274053632733759], 
        Hue[0.6498967127539569, 1, 0.10014301310990587`], 
        Hue[0.6499774815479087, 1, 0.10003117939520335`], 
        Hue[0.6499968945489246, 1, 0.1000042998553351], 
        Hue[0.6499996708038481, 1, 0.10000045581005648`], 
        Hue[0.05244141947316405, 1, 0.9273888038063882], 
        Hue[0.05812442404615403, 1, 0.9195200282437868], 
        Hue[0.6499996736696589, 1, 0.10000045184201072`], 
        Hue[0.649985171412803, 1, 0.10002053188996514`], 
        Hue[0.6497387800110449, 1, 0.10036168921547634`], 
        Hue[0.6497140307026844, 1, 0.10039595748859087`], 
        Hue[0.649999637473088, 1, 0.10000050196033976`], 
        Hue[0.6499990284977293, 1, 0.10000134515699023`], 
        Hue[0.6499983540750625, 1, 0.10000227897299048`], 
        Hue[0.6499938301355157, 1, 0.10000854288928591`], 
        Hue[0.6499988113356224, 1, 0.10000164584298435`], 
        Hue[0.6499979341247507, 1, 0.10000286044265294`], 
        Hue[0.6499995672298762, 1, 0.10000059922017145`], 
        Hue[0.6499998500410374, 1, 0.10000020763548673`], 
        Hue[0.6499999121863456, 1, 0.10000012158813694`], 
        Hue[0.6499999042768432, 1, 0.1000001325397556], 
        Hue[0.6499998912637305, 1, 0.10000015055791167`], 
        Hue[0.6499997965508454, 1, 0.10000028169882953`], 
        Hue[0.6499998391866144, 1, 0.10000022266468775`], 
        Hue[0.6499997047177185, 1, 0.1000004088523898], 
        Hue[0.649985171412803, 1, 0.10002053188996514`], 
        Hue[0.6499731279556002, 1, 0.10003720744609197`], 
        Hue[0.6499995672298762, 1, 0.10000059922017145`], 
        Hue[0.6499998500410374, 1, 0.10000020763548673`], 
        Hue[0.6499999121863456, 1, 0.10000012158813694`], 
        Hue[0.6499989556520133, 1, 0.10000144602028942`], 
        Hue[0.6499986750923046, 1, 0.10000183448757825`], 
        Hue[0.6499986615165546, 1, 0.10000185328477061`], 
        Hue[0.6361358775823458, 1, 0.11919647719367511`], 
        Hue[0.6305689978315345, 1, 0.12690446454095228`], 
        Hue[0.6499986615165546, 1, 0.10000185328477061`], 
        Hue[0.6499988738287195, 1, 0.10000155931408075`], 
        Hue[0.6499998405135435, 1, 0.10000022082740136`], 
        Hue[0.6499995620862684, 1, 0.10000060634208989`], 
        Hue[0.6499996292674944, 1, 0.10000051332193075`], 
        Hue[0.6499163609929386, 1, 0.10011580785593122`], 
        Hue[0.649953508291059, 1, 0.10006437313545684`], 
        Hue[0.6499778401621346, 1, 0.10003068285242904`], 
        Hue[0.6499484012887502, 1, 0.10007144436942277`], 
        Hue[0.6496729232052973, 1, 0.10045287556189605`], 
        Hue[0.6497922176029923, 1, 0.10028769870354916`], 
        Hue[0.6498869780840074, 1, 0.10015649188368214`], 
        Hue[0.6497661825364089, 1, 0.10032374725728002`], 
        Hue[0.6142939372009442, 1, 0.1494391638756158], 
        Hue[0.5985789422584301, 1, 0.1711983876421737], 
        Hue[0.6125143440885943, 1, 0.151903215877331], 
        Hue[0.6361358775824969, 1, 0.11919647719346589`], 
        Hue[0.6305688882453164, 1, 0.1269046162757158], 
        Hue[0.6465876268599808, 1, 0.10472482434771889`], 
        Hue[0.6451366804176951, 1, 0.10673382711396066`], 
        Hue[0.6499995573613431, 1, 0.10000061288429428`], 
        Hue[0.6499959668971751, 1, 0.10000558429621911`], 
        Hue[0.6499991796688471, 1, 0.10000113584313482`], 
        Hue[0.6499986163812986, 1, 0.10000191577974038`], 
        Hue[0.6499984458205482, 1, 0.1000021519407794], 
        Hue[0.649665854084627, 1, 0.10046266357513191`], 
        Hue[0.6497616318703321, 1, 0.10033004817954015`], 
        Hue[0.6035542763094158, 1, 0.16430946357157808`], 
        Hue[0.598578942259135, 1, 0.1711983876411977], 
        Hue[0.6125143304747075, 1, 0.15190323472732808`], 
        Hue[0.6361358775824881, 1, 0.11919647719347794`], 
        Hue[0.6402282639250334, 1, 0.11353009610379994`], 
        Hue[0.6496729232052978, 1, 0.10045287556189539`], 
        Hue[0.6497922176029911, 1, 0.10028769870355077`], 
        Hue[0.6497661825364055, 1, 0.10032374725728466`], 
        Hue[0.6498869780840066, 1, 0.10015649188368317`], 
        Hue[0.6499163609929388, 1, 0.10011580785593091`], 
        Hue[0.649953508291059, 1, 0.10006437313545678`], 
        Hue[0.6499484012887502, 1, 0.1000714443694229], 
        Hue[0.6499778401621347, 1, 0.10003068285242903`], 
        Hue[0.6499989556520133, 1, 0.10000144602028942`], 
        Hue[0.6499977899595798, 1, 0.10000306005596647`], 
        Hue[0.6499982819147156, 1, 0.10000237888731685`], 
        Hue[0.6499998400120321, 1, 0.10000022152180169`], 
        Hue[0.6499984384726788, 1, 0.10000216211475245`], 
        Hue[0.6499996979082646, 1, 0.10000041828086434`], 
        Hue[0.6474507800970327, 1, 0.10352968909641623`], 
        Hue[0.6449606118130902, 1, 0.10697761441264439`], 
        Hue[0.6474507800970283, 1, 0.10352968909642238`], 
        Hue[0.6404078578025713, 1, 0.11328142765797827`], 
        Hue[0.6464577349439569, 1, 0.10490467469298291`], 
        Hue[0.6486829768945996, 1, 0.10182357045363134`], 
        Hue[0.6446153322487039, 1, 0.10745569380948687`], 
        Hue[0.6447410918958292, 1, 0.10728156506731354`], 
        Hue[0.647503644126962, 1, 0.10345649274728333`], 
        Hue[0.6499893047672064, 1, 0.10001480878386815`], 
        Hue[0.6499911083843236, 1, 0.10001231146785962`], 
        Hue[0.6499896198214707, 1, 0.10001437255488663`], 
        Hue[0.6499914684832315, 1, 0.10001181286937179`], 
        Hue[0.6499999487815362, 1, 0.10000007091787295`], 
        Hue[0.6499999721042841, 1, 0.10000003862483756`], 
        Hue[0.6499895638291427, 1, 0.10001445008272541`], 
        Hue[0.6499914149327589, 1, 0.10001188701617994`], 
        Hue[0.6142939372009378, 1, 0.14943916387562456`], 
        Hue[0.6499998853986138, 1, 0.1000001586788426], 
        Hue[0.6499999311814529, 1, 0.10000009528721902`], 
        Hue[0.6499892543051299, 1, 0.10001487865443559`], 
        Hue[0.6499910605536277, 1, 0.10001237769497713`], 
        Hue[0.6326534458675356, 1, 0.12401830572187386`], 
        Hue[0.6407433486684658, 1, 0.11281690184366276`], 
        Hue[0.6499370372257507, 1, 0.10008717922588375`], 
        Hue[0.6499476195382329, 1, 0.100072526793216], 
        Hue[0.6499896198214709, 1, 0.10001437255488661`], 
        Hue[0.6499914684832315, 1, 0.10001181286937177`], 
        Hue[0.6499893047672064, 1, 0.10001480878386813`], 
        Hue[0.6499911083843236, 1, 0.1000123114678596], 
        Hue[0.6499943020069127, 1, 0.10000788952889027`], 
        Hue[0.6499845467767462, 1, 0.10002139677065916`], 
        Hue[0.6499863220642538, 1, 0.10001893868026403`], 
        Hue[0.6499892412346377, 1, 0.10001489675204013`], 
        Hue[0.6499934844894636, 1, 0.10000902147612738`], 
        Hue[0.6499950367916136, 1, 0.10000687213468888`], 
        Hue[0.6499954637608208, 1, 0.10000628094655577`], 
        Hue[0.6499967513886306, 1, 0.10000449807728083`], 
        Hue[0.6499947006281697, 1, 0.1000073375917652], 
        Hue[0.6499859066827985, 1, 0.10001951382381748`], 
        Hue[0.6499873317975113, 1, 0.1000175405880613], 
        Hue[0.6499902463376951, 1, 0.1000135050708837], 
        Hue[0.6499940295942708, 1, 0.10000826671562513`], 
        Hue[0.6499988353026608, 1, 0.10000161265785429`], 
        Hue[0.6499966447492621, 1, 0.10000464573179094`], 
        Hue[0.6499977585830018, 1, 0.10000310350045905`], 
        Hue[0.649994657510819, 1, 0.1000073972927123], 
        Hue[0.6499858086661352, 1, 0.10001964953919741`], 
        Hue[0.6499872454109917, 1, 0.10001766020016539`], 
        Hue[0.6415728722699721, 1, 0.1116683307031157], 
        Hue[0.6206979778759806, 1, 0.14057203063325774`], 
        Hue[0.6499949966845507, 1, 0.10000692766754513`], 
        Hue[0.6498853473010373, 1, 0.10015874989087152`], 
        Hue[0.6499966447492621, 1, 0.10000464573179095`], 
        Hue[0.03503912140502463, 1, 0.9514842934391966], 
        Hue[0.05053038130689036, 1, 0.9300348566519979], 
        Hue[0.6496729232052978, 1, 0.1004528755618954], 
        Hue[0.6497922176029911, 1, 0.10028769870355077`], 
        Hue[0.6498869780840066, 1, 0.10015649188368317`], 
        Hue[0.6499163609929388, 1, 0.10011580785593092`], 
        Hue[0.649953508291059, 1, 0.10006437313545678`], 
        Hue[0.6499778401621347, 1, 0.10003068285242903`], 
        Hue[0.6476910569498755, 1, 0.10319699806940323`], 
        Hue[0.6499942635068771, 1, 0.10000794283663174`], 
        Hue[0.6499844592214795, 1, 0.10002151800102843`], 
        Hue[0.6499862450977085, 1, 0.10001904524932675`], 
        Hue[0.6499966447492621, 1, 0.10000464573179095`], 
        Hue[0.6499977585830018, 1, 0.10000310350045905`], 
        Hue[0.6499959664758339, 1, 0.10000558487961463`], 
        Hue[0.649998606782629, 1, 0.10000192907020604`], 
        Hue[0.6499283483312326, 1, 0.10009921000290879`], 
        Hue[0.6499327220179499, 1, 0.1000931541289924], 
        Hue[0.6499994416116589, 1, 0.10000077315308772`], 
        Hue[0.6499960082225426, 1, 0.10000552707647957`], 
        Hue[0.6499962429355867, 1, 0.10000520208918776`], 
        Hue[0.6499859066827985, 1, 0.10001951382381748`], 
        Hue[0.6499947006281697, 1, 0.10000733759176518`], 
        Hue[0.6499940295942708, 1, 0.10000826671562513`], 
        Hue[0.6499922175652754, 1, 0.1000107756788496], 
        Hue[0.6499873317975113, 1, 0.10001754058806128`], 
        Hue[0.6499988738287195, 1, 0.10000155931408075`], 
        Hue[0.6499989503600303, 1, 0.10000145334765041`], 
        Hue[0.6499950367916136, 1, 0.10000687213468887`], 
        Hue[0.6499954637608208, 1, 0.10000628094655577`], 
        Hue[0.6499845467767462, 1, 0.10002139677065915`], 
        Hue[0.6499943020069127, 1, 0.10000788952889027`], 
        Hue[0.6499934844894636, 1, 0.10000902147612736`], 
        Hue[0.649991672053883, 1, 0.10001153100231586`], 
        Hue[0.6499863220642538, 1, 0.10001893868026401`], 
        Hue[0.6499960082225426, 1, 0.10000552707647957`], 
        Hue[0.6499962429355867, 1, 0.10000520208918777`], 
        Hue[0.6499999167013311, 1, 0.10000011533661854`], 
        Hue[0.649916360992939, 1, 0.10011580785593062`], 
        Hue[0.6499535082910592, 1, 0.10006437313545645`], 
        Hue[0.6499778401621348, 1, 0.10003068285242887`], 
        Hue[0.6499484012887506, 1, 0.10007144436942225`], 
        Hue[0.6496729232053008, 1, 0.10045287556189123`], 
        Hue[0.6497922176029945, 1, 0.10028769870354609`], 
        Hue[0.6498869780840084, 1, 0.1001564918836807], 
        Hue[0.6497661825364115, 1, 0.1003237472572765], 
        Hue[0.03502800528463057, 1, 0.9514996849905115], 
        Hue[0.05053038130973697, 1, 0.9300348566480565], 
        Hue[0.6494393528554369, 1, 0.10077628066170284`], 
        Hue[0.6496696646085355, 1, 0.10045738746510469`], 
        Hue[0.6497649268362281, 1, 0.10032548591906884`], 
        Hue[0.6499947044858404, 1, 0.10000733225037489`], 
        Hue[0.6499953064467493, 1, 0.10000649876603943`], 
        Hue[0.6499990600199379, 1, 0.10000130151085525`], 
        Hue[0.6499993276345999, 1, 0.10000093096747711`], 
        Hue[0.6499940623865799, 1, 0.10000822131088946`], 
        Hue[0.614294199630169, 1, 0.1494388005120738], 
        Hue[0.649998945518936, 1, 0.10000146005070401`], 
        Hue[0.6499988244681159, 1, 0.10000162765953191`], 
        Hue[0.649999241196809, 1, 0.10000105065057222`], 
        Hue[0.649998945518936, 1, 0.10000146005070401`], 
        Hue[0.6499990565619045, 1, 0.10000130629890147`], 
        Hue[0.6491923510353136, 1, 0.10111828318187353`], 
        Hue[0.6488160455145384, 1, 0.10163932159525459`], 
        Hue[0.6431143057311567, 1, 0.10953403821839845`], 
        Hue[0.6450736851083142, 1, 0.10682105138848809`], 
        Hue[0.6499978209312278, 1, 0.10000301717214612`], 
        Hue[0.6465876268599643, 1, 0.10472482434774179`], 
        Hue[0.6475877606688776, 1, 0.1033400236892465], 
        Hue[0.6365954599072247, 1, 0.11856013243615052`], 
        Hue[0.6491923510353136, 1, 0.10111828318187348`], 
        Hue[0.6488157819929059, 1, 0.10163968647136115`], 
        Hue[0.6462858945624259, 1, 0.1051426075289488], 
        Hue[0.6456956484192908, 1, 0.10595987141944353`], 
        Hue[0.6460003620577588, 1, 0.10553796022771858`], 
        Hue[0.6456223614019657, 1, 0.1060613457511244], 
        Hue[0.6471780107787616, 1, 0.10390736969094559`], 
        Hue[0.6465876268599798, 1, 0.1047248243477203], 
        Hue[0.6475874797640361, 1, 0.10334041263441161`], 
        Hue[0.5614912777433805, 1, 0.22255053850916562`], 
        Hue[0.5849385292515442, 1, 0.19008511334401573`], 
        Hue[0.5781206880423904, 1, 0.19952520117207484`], 
        Hue[0.591348319402325, 1, 0.18121001928908845`], 
        Hue[0.643114305731053, 1, 0.10953403821854209`], 
        Hue[0.6404083161808928, 1, 0.11328079298030237`], 
        Hue[0.649991672053883, 1, 0.10001153100231587`], 
        Hue[0.6499922175652753, 1, 0.10001077567884961`], 
        Hue[0.6499947044858404, 1, 0.10000733225037488`], 
        Hue[0.6499879463772358, 1, 0.10001668963151969`], 
        Hue[0.6499683182643626, 1, 0.10004386701857493`], 
        Hue[0.6499713739907875, 1, 0.10003963601275573`], 
        Hue[0.6499921601348203, 1, 0.10001085519794112`], 
        Hue[0.6361405484872709, 1, 0.11919000978685584`], 
        Hue[0.6304056690287502, 1, 0.12713061211403834`], 
        Hue[0.6499033184273612, 1, 0.10013386679288462`], 
        Hue[0.6499485358404218, 1, 0.10007125806710834`], 
        Hue[0.6499967228926259, 1, 0.10000453753328727`], 
        Hue[0.6499255031609498, 1, 0.10010314946945419`], 
        Hue[0.6499934162037112, 1, 0.10000911602563067`], 
        Hue[0.6499927108076778, 1, 0.10001009272783067`], 
        Hue[0.5848475422716374, 1, 0.19021109531619446`], 
        Hue[0.606443611541854, 1, 0.16030884555743297`], 
        Hue[0.6499916208740619, 1, 0.10001160186668359`], 
        Hue[0.6361405484872588, 1, 0.11919000978687258`], 
        Hue[0.6395664466518229, 1, 0.11444645848209142`], 
        Hue[0.645345147629168, 1, 0.10644518020576754`], 
        Hue[0.6461546244815918, 1, 0.10532436610241147`], 
        Hue[0.6498853473010362, 1, 0.10015874989087303`], 
        Hue[0.6499848149764142, 1, 0.10002102541727263`], 
        Hue[0.6499931061879602, 1, 0.10000954527820886`], 
        Hue[0.649961586942009, 1, 0.10005318731106444`], 
        Hue[0.6499818402890271, 1, 0.10002514421519335`], 
        Hue[0.6499973860644361, 1, 0.1000036192953962], 
        Hue[0.6499988179951584, 1, 0.1000016366220884], 
        Hue[0.6499742521499005, 1, 0.1000356508693687], 
        Hue[0.6499664920844146, 1, 0.10004639557542605`], 
        Hue[0.6499538534713674, 1, 0.10006389519349133`], 
        Hue[0.6499902463376951, 1, 0.10001350507088369`], 
        Hue[0.6499892412346377, 1, 0.10001489675204013`], 
        Hue[0.6499995967086464, 1, 0.10000055840341276`], 
        Hue[0.6499995967086464, 1, 0.10000055840341276`], 
        Hue[0.6499993652334957, 1, 0.10000087890746762`], 
        Hue[0.6499932958795042, 1, 0.10000928262837881`], 
        Hue[0.6499992914358198, 1, 0.10000098108886499`], 
        Hue[0.6499994978653971, 1, 0.10000069526329639`], 
        Hue[0.6499954119884139, 1, 0.10000635263142685`], 
        Hue[0.6494083156717524, 1, 0.10081925522372753`], 
        Hue[0.6496390806277188, 1, 0.10049973451546627`], 
        Hue[0.6498293943271902, 1, 0.10023622323927514`], 
        Hue[0.6499081642305828, 1, 0.100127157219193], 
        Hue[0.6474018333248249, 1, 0.10359746155024246`], 
        Hue[0.6480158984689418, 1, 0.10274721750454217`], 
        Hue[0.647966455917048, 1, 0.10281567642254884`], 
        Hue[0.6477721012453109, 1, 0.10308478289110791`], 
        Hue[0.6481282101836034, 1, 0.1025917089765491], 
        Hue[0.648038233050599, 1, 0.10271629269917062`], 
        Hue[0.6478300313592262, 1, 0.10300457196414828`], 
        Hue[0.6499987450974997, 1, 0.10000173755730814`], 
        Hue[0.6499968555673088, 1, 0.10000435382988013`], 
        Hue[0.6499969315998197, 1, 0.10000424855409581`], 
        Hue[0.644377884125887, 1, 0.1077844681333873], 
        Hue[0.6437589917918137, 1, 0.10864139598056559`], 
        Hue[0.6428975370312371, 1, 0.10983417949521028`], 
        Hue[0.6498293943271902, 1, 0.10023622323927515`], 
        Hue[0.6498124464093857, 1, 0.1002596895870044], 
        Hue[0.649961586942009, 1, 0.10005318731106445`], 
        Hue[0.6499577843531885, 1, 0.10005845243404672`], 
        Hue[0.648306135542982, 1, 0.10234535078664032`], 
        Hue[0.6475476903013399, 1, 0.10339550573660646`], 
        Hue[0.6472851403989724, 1, 0.10375903637065359`], 
        Hue[0.6498258895552936, 1, 0.10024107600036264`], 
        Hue[0.6499995384858683, 1, 0.10000063901956702`], 
        Hue[0.6499995484386257, 1, 0.10000062523882598`], 
        Hue[0.6499997367362648, 1, 0.10000036451901806`], 
        Hue[0.6499997506890729, 1, 0.10000034519974534`], 
        Hue[0.6494809479153911, 1, 0.10071868750176614`], 
        Hue[0.6495779574981979, 1, 0.10058436654095675`], 
        Hue[0.6499879463772358, 1, 0.1000166896315197], 
        Hue[0.6499924023154049, 1, 0.10001051987097787`], 
        Hue[0.6499987539211727, 1, 0.10000172533991486`], 
        Hue[0.6438294336870249, 1, 0.10854386104873467`], 
        Hue[0.6478386059597472, 1, 0.10299269944035015`], 
        Hue[0.6479232892384299, 1, 0.10287544566986638`], 
        Hue[0.6449089059890544, 1, 0.10704920709207866`], 
        Hue[0.6443963651954955, 1, 0.10775887896008324`], 
        Hue[0.6486592591767456, 1, 0.10185641037066004`], 
        Hue[0.6481400490447606, 1, 0.1025753167072545], 
        Hue[0.6499998406376782, 1, 0.10000022065552244`], 
        Hue[0.6499997285869414, 1, 0.10000037580269656`], 
        Hue[0.6499991149582264, 1, 0.10000122544245589`], 
        Hue[0.649990745780477, 1, 0.10001281353472413`], 
        Hue[0.6499872851621001, 1, 0.10001760516016904`], 
        Hue[0.6499928687028823, 1, 0.10000987410370149`], 
        Hue[0.6499902459174384, 1, 0.10001350565277763`], 
        Hue[0.6499993476936773, 1, 0.1000009031933699], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499987762295317, 1, 0.10000169445141764`], 
        Hue[0.649950538320686, 1, 0.10006848540212707`], 
        Hue[0.6499169012778275, 1, 0.10011505976916187`], 
        Hue[0.6499384202733739, 1, 0.10008526423686702`], 
        Hue[0.6499979396020884, 1, 0.10000285285864687`], 
        Hue[0.6499998944694872, 1, 0.10000014611917156`], 
        Hue[0.6499943973499914, 1, 0.10000775751539649`], 
        Hue[0.6496669893384682, 1, 0.1004610916851979], 
        Hue[0.649946398470897, 1, 0.10007421750183501`], 
        Hue[0.649993719165779, 1, 0.10000869653969072`], 
        Hue[0.6497827013349247, 1, 0.10030087507471978`], 
        Hue[0.6496669043016358, 1, 0.10046120942850442`], 
        Hue[0.6497492556366449, 1, 0.10034718450310716`], 
        Hue[0.6499936916833658, 1, 0.10000873459226267`], 
        Hue[0.6499735114284139, 1, 0.10003667648373474`], 
        Hue[0.6497686522347684, 1, 0.10032032767493607`], 
        Hue[0.6493221359730589, 1, 0.10093858096038005`], 
        Hue[0.6491243836319389, 1, 0.10121239189423846`], 
        Hue[0.6493577841898454, 1, 0.10088922189098344`], 
        Hue[0.6497848661512468, 1, 0.10029787763673528`], 
        Hue[0.6499645347886049, 1, 0.10004910567731624`], 
        Hue[0.6493571286681645, 1, 0.10089012953638754`], 
        Hue[0.6491243444061469, 1, 0.10121244620687354`], 
        Hue[0.6493225788760635, 1, 0.10093796771006598`], 
        Hue[0.64975855562808, 1, 0.10033430759188927`], 
        Hue[0.6499720083241632, 1, 0.10003875770500482`], 
        Hue[0.6499179695206531, 1, 0.1001135806637112], 
        Hue[0.6494608701931665, 1, 0.10074648742484656`], 
        Hue[0.6487286338295368, 1, 0.10176035315910295`], 
        Hue[0.648388110556423, 1, 0.10223184692187594`], 
        Hue[0.6486206497020784, 1, 0.10190986964327597`], 
        Hue[0.6493623255583338, 1, 0.10088293384230708`], 
        Hue[0.6498452129760722, 1, 0.10021432049466919`], 
        Hue[0.6486204310728421, 1, 0.10191017236068024`], 
        Hue[0.6483883164107923, 1, 0.10223156189274911`], 
        Hue[0.6487288669092452, 1, 0.10176003043335274`], 
        Hue[0.6494481187205927, 1, 0.10076414330994857`], 
        Hue[0.6498285638060287, 1, 0.1002373731916526], 
        Hue[0.6490732055840215, 1, 0.10128325380673955`], 
        Hue[0.6481845887416958, 1, 0.10251364635765203`], 
        Hue[0.6476640151146047, 1, 0.10323444061054733`], 
        Hue[0.6485080528944321, 1, 0.10206577291540167`], 
        Hue[0.6494626278600282, 1, 0.10074405373226872`], 
        Hue[0.6485074236435951, 1, 0.10206664418579137`], 
        Hue[0.6476644005941146, 1, 0.10323390686968757`], 
        Hue[0.6476782205548369, 1, 0.10321477153945656`], 
        Hue[0.6481847142239625, 1, 0.102513472612975], 
        Hue[0.6497498661728607, 1, 0.10034633914526986`], 
        Hue[0.6487943291253612, 1, 0.10166939044180758`], 
        Hue[0.6477867920179302, 1, 0.1030644418213274], 
        Hue[0.6470649192956859, 1, 0.10406395789828114`], 
        Hue[0.6466285838488329, 1, 0.10466811467084673`], 
        Hue[0.6471334129224622, 1, 0.1039691205688986], 
        Hue[0.6484656021365416, 1, 0.1021245508878656], 
        Hue[0.6471333502188961, 1, 0.10396920738922091`], 
        Hue[0.6466294094583314, 1, 0.10466697151923357`], 
        Hue[0.6470654457983444, 1, 0.10406322889460015`], 
        Hue[0.647787115327827, 1, 0.10306399416147034`], 
        Hue[0.6497201483868429, 1, 0.10038748684898678`], 
        Hue[0.6486615686527496, 1, 0.1018532126346544], 
        Hue[0.6464928403325366, 1, 0.10485606723187232`], 
        Hue[0.6452016973298763, 1, 0.10664380369709445`], 
        Hue[0.6459425149455625, 1, 0.10561805622922109`], 
        Hue[0.6465290067252066, 1, 0.10480599068817552`], 
        Hue[0.6455644065284432, 1, 0.10614159096061725`], 
        Hue[0.6464934559422196, 1, 0.10485521484923437`], 
        Hue[0.6474600972735771, 1, 0.1035167883904317], 
        Hue[0.6497444578897738, 1, 0.10035382753723636`], 
        Hue[0.6486721458807168, 1, 0.10183856724208448`], 
        Hue[0.6472340635887618, 1, 0.10382975810786839`], 
        Hue[0.6459052314226392, 1, 0.10566967956865347`], 
        Hue[0.6421307435745531, 1, 0.11089589351215723`], 
        Hue[0.6384784081121809, 1, 0.1159529733831342], 
        Hue[0.644391249173835, 1, 0.10776596268238246`], 
        Hue[0.6459060748044504, 1, 0.10566851180922257`], 
        Hue[0.6472266389834003, 1, 0.10384003833067652`], 
        Hue[0.6486721421475293, 1, 0.10183857241111328`], 
        Hue[0.6498178986902056, 1, 0.10025214027509997`], 
        Hue[0.6488754715936943, 1, 0.10155703933180799`], 
        Hue[0.6471954778691618, 1, 0.1038831844888529], 
        Hue[0.6343038838830037, 1, 0.12173308385430251`], 
        Hue[0.6131150084106854, 1, 0.151071526815974], 
        Hue[0.599873725624631, 1, 0.16940561067358784`], 
        Hue[0.6427107986431025, 1, 0.11009274034031961`], 
        Hue[0.6453186380741933, 1, 0.10648188574342467`], 
        Hue[0.6471976417124086, 1, 0.10388018839820357`], 
        Hue[0.6488751499378577, 1, 0.10155748470142792`], 
        Hue[0.649904864696231, 1, 0.10013172580521869`], 
        Hue[0.6492211282544359, 1, 0.10107843780155036`], 
        Hue[0.6474440549356896, 1, 0.103539000858276], 
        Hue[0.611318404019485, 1, 0.15355913289609768`], 
        Hue[0.5438542150943828, 1, 0.2469710867923931], 
        Hue[0.5054107485801693, 1, 0.3002005019659194], 
        Hue[0.5442403811389213, 1, 0.2464363953461091], 
        Hue[0.6391838480536877, 1, 0.11497621038720175`], 
        Hue[0.6448183521044771, 1, 0.10717458939380087`], 
        Hue[0.6474700106798146, 1, 0.10350306213564132`], 
        Hue[0.6492205124027042, 1, 0.10107929051933276`], 
        Hue[0.6499637194211009, 1, 0.10005023464770656`], 
        Hue[0.6495635854272803, 1, 0.10060426633145804`], 
        Hue[0.6479727326168065, 1, 0.10280698560749861`], 
        Hue[0.5613439013165955, 1, 0.2227545981770216], 
        Hue[0.420727802056995, 1, 0.4174538125364685], 
        Hue[0.35056984491384907`, 1, 0.5145955993500552], 
        Hue[0.42074601092973296`, 1, 0.41742860025113904`], 
        Hue[0.5603644258502979, 1, 0.2241107949765106], 
        Hue[0.632088131456607, 1, 0.12480104875239027`], 
        Hue[0.644535609635832, 1, 0.10756607896577114`], 
        Hue[0.6479722666001164, 1, 0.10280763086137731`], 
        Hue[0.6499896086305067, 1, 0.10001438805006765`], 
        Hue[0.64980367395518, 1, 0.10027183606205853`], 
        Hue[0.6486308130733798, 1, 0.1018957972830126], 
        Hue[0.4875629896788311, 1, 0.3249127835216185], 
        Hue[0.2794714163728054, 1, 0.6130395773299617], 
        Hue[0.19202572741733248`, 1, 0.7341182235760012], 
        Hue[0.2795012782577532, 1, 0.6129982301046494], 
        Hue[0.6197571630581281, 1, 0.1418746973041303], 
        Hue[0.6445188584206577, 1, 0.10758927295601249`], 
        Hue[0.6486298611368392, 1, 0.10189711534899197`], 
        Hue[0.6499974802341777, 1, 0.10000348890652329`], 
        Hue[0.649939804960482, 1, 0.10008334697779414`], 
        Hue[0.4134396293930329, 1, 0.42754512853272375`], 
        Hue[0.16660070648985764`, 1, 0.7693220987063509], 
        Hue[0.6051860768209053, 1, 0.16205004747874657`], 
        Hue[0.6446747005059876, 1, 0.10737349160709404`], 
        Hue[0.6492984661033738, 1, 0.10097135462609774`], 
        Hue[0.6499996082984593, 1, 0.1000005423559795], 
        Hue[0.6439828956081195, 1, 0.10833137531183465`], 
        Hue[0.5939696963120576, 1, 0.17758042049099715`], 
        Hue[0.3699235753786966, 1, 0.48779812639872777`], 
        Hue[0.10993697241782385`, 1, 0.8477795766522439], 
        Hue[0.5950760330690096, 1, 0.17604856959675602`], 
        Hue[0.6448213068074831, 1, 0.10717049826656197`], 
        Hue[0.37117736989663025`, 1, 0.4860621032200505], 
        Hue[0.10995731693026656`, 1, 0.8477514073273232], 
        Hue[0.36992357538044274`, 1, 0.48779812639631004`], 
        Hue[0.5939696963127171, 1, 0.17758042049008405`], 
        Hue[0.64482178764344, 1, 0.10716983249369852`], 
        Hue[0.6499978738704448, 1, 0.10000294387169176`], 
        Hue[0.6499395617051158, 1, 0.1000836837929167], 
        Hue[0.41486309731247367`, 1, 0.42557417295195954`], 
        Hue[0.16664015272547333`, 1, 0.7692674808416523], 
        Hue[0.41343962939487927`, 1, 0.42754512853016724`], 
        Hue[0.6042150040106968, 1, 0.16339460983134285`], 
        Hue[0.644675413069162, 1, 0.10737250498116035`], 
        Hue[0.6492993957289521, 1, 0.10097006745222023`], 
        Hue[0.6499974802341777, 1, 0.10000348890652329`], 
        Hue[0.6499895375823748, 1, 0.10001448642440418`], 
        Hue[0.6498247725796032, 1, 0.10024262258208785`], 
        Hue[0.6486298611368391, 1, 0.10189711534899205`], 
        Hue[0.48758898573002984`, 1, 0.3248767889891895], 
        Hue[0.2795012782574238, 1, 0.6129982301051055], 
        Hue[0.19202572741537732`, 1, 0.7341182235787083], 
        Hue[0.27947141637247735`, 1, 0.613039577330416], 
        Hue[0.6197500814767575, 1, 0.14188450257064347`], 
        Hue[0.6445187656803512, 1, 0.10758940136566773`], 
        Hue[0.648722707184793, 1, 0.10176855928259446`], 
        Hue[0.6498036739551807, 1, 0.1002718360620575], 
        Hue[0.6499887115763905, 1, 0.10001563012499778`], 
        Hue[0.6499635376940699, 1, 0.10005048626974944`], 
        Hue[0.6495955370911406, 1, 0.10056002556611313`], 
        Hue[0.6479722666001381, 1, 0.10280763086134731`], 
        Hue[0.5613710441027732, 1, 0.22271701585769876`], 
        Hue[0.42074601093061925`, 1, 0.4174286002499118], 
        Hue[0.3505698449147388, 1, 0.5145955993488232], 
        Hue[0.4207278020584655, 1, 0.4174538125344325], 
        Hue[0.6320807432699589, 1, 0.1248112785492878], 
        Hue[0.6445346715615178, 1, 0.10756737783789842`], 
        Hue[0.6479727326168283, 1, 0.1028069856074685], 
        Hue[0.6495635854272815, 1, 0.10060426633145629`], 
        Hue[0.6499045423782823, 1, 0.1001321720916092], 
        Hue[0.6492205124027052, 1, 0.10107929051933137`], 
        Hue[0.6113350077371776, 1, 0.1535361431331387], 
        Hue[0.5442403811399456, 1, 0.24643639534469083`], 
        Hue[0.5054107485816477, 1, 0.3002005019638725], 
        Hue[0.6393231015822665, 1, 0.11478339780916952`], 
        Hue[0.6448171573226971, 1, 0.10717624370703491`], 
        Hue[0.6474440549357099, 1, 0.10353900085824791`], 
        Hue[0.6492211282544369, 1, 0.10107843780154897`], 
        Hue[0.6498175387315117, 1, 0.10025263867944542`], 
        Hue[0.6488751499378581, 1, 0.1015574847014272], 
        Hue[0.6342357357138431, 1, 0.12182744285775579`], 
        Hue[0.6131190636402776, 1, 0.15106591188269267`], 
        Hue[0.6427084326690243, 1, 0.11009601630442792`], 
        Hue[0.6453175862657006, 1, 0.10648334209364542`], 
        Hue[0.6471954778691709, 1, 0.10388318448884043`], 
        Hue[0.6488754715936947, 1, 0.10155703933180728`], 
        Hue[0.6497442349944516, 1, 0.1003541361615287], 
        Hue[0.6486721421475296, 1, 0.1018385724111129], 
        Hue[0.6459060748044588, 1, 0.1056685118092109], 
        Hue[0.6421328552373109, 1, 0.11089296967141571`], 
        Hue[0.6384789975537066, 1, 0.11595215723332938`], 
        Hue[0.64438993383294, 1, 0.1077677839236217], 
        Hue[0.6459052314226476, 1, 0.10566967956864194`], 
        Hue[0.6472260492528706, 1, 0.10384085488064075`], 
        Hue[0.6486721458807171, 1, 0.10183856724208414`], 
        Hue[0.6497201201157684, 1, 0.10038752599355154`], 
        Hue[0.648666544096528, 1, 0.10184632355865361`], 
        Hue[0.6464934559422207, 1, 0.1048552148492328], 
        Hue[0.6452024257205371, 1, 0.10664279515617942`], 
        Hue[0.6459417553417114, 1, 0.10561910798839959`], 
        Hue[0.6455633919912057, 1, 0.10614299570448435`], 
        Hue[0.6464928403325377, 1, 0.10485606723187087`], 
        Hue[0.647459617606195, 1, 0.10351745254526855`], 
        Hue[0.6486615686527497, 1, 0.10185321263465423`], 
        Hue[0.6497500661969323, 1, 0.10034606218886297`], 
        Hue[0.6487973060787215, 1, 0.1016652685063855], 
        Hue[0.6477871153278271, 1, 0.10306399416147022`], 
        Hue[0.6470654457983444, 1, 0.10406322889460012`], 
        Hue[0.6466294094583315, 1, 0.10466697151923335`], 
        Hue[0.6471333502189089, 1, 0.10396920738920298`], 
        Hue[0.6484645052704798, 1, 0.1021260696254895], 
        Hue[0.6491328333766917, 1, 0.10120069224765768`], 
        Hue[0.6471334129224494, 1, 0.10396912056891619`], 
        Hue[0.6466285838488329, 1, 0.10466811467084676`], 
        Hue[0.6470649192956859, 1, 0.10406395789828118`], 
        Hue[0.64778679201793, 1, 0.1030644418213277], 
        Hue[0.6487943291253612, 1, 0.1016693904418076], 
        Hue[0.6498289592233316, 1, 0.10023682569077168`], 
        Hue[0.6490820712669709, 1, 0.10127097824573265`], 
        Hue[0.6481847142239626, 1, 0.1025134726129749], 
        Hue[0.6476782205548369, 1, 0.10321477153945664`], 
        Hue[0.6476644005941143, 1, 0.10323390686968784`], 
        Hue[0.6485074236435971, 1, 0.10206664418578854`], 
        Hue[0.6494782446417824, 1, 0.10072243049599366`], 
        Hue[0.6485080528944301, 1, 0.10206577291540447`], 
        Hue[0.6476640151146049, 1, 0.10323444061054705`], 
        Hue[0.6476673319658688, 1, 0.10322984804725867`], 
        Hue[0.6481845887416956, 1, 0.1025136463576523], 
        Hue[0.6490732055840214, 1, 0.10128325380673972`], 
        Hue[0.6499183291303126, 1, 0.10011308274264412`], 
        Hue[0.6494481187205927, 1, 0.10076414330994854`], 
        Hue[0.6487288669092454, 1, 0.10176003043335265`], 
        Hue[0.6483883164107922, 1, 0.10223156189274928`], 
        Hue[0.6486204310728418, 1, 0.10191017236068052`], 
        Hue[0.6493634059128112, 1, 0.10088143796687682`], 
        Hue[0.649854937980913, 1, 0.1002008551033513], 
        Hue[0.6493623255583336, 1, 0.10088293384230729`], 
        Hue[0.6486206497020787, 1, 0.1019098696432757], 
        Hue[0.6483881105564231, 1, 0.1022318469218758], 
        Hue[0.6487286338295367, 1, 0.10176035315910312`], 
        Hue[0.6499736942470771, 1, 0.10003642335020098`], 
        Hue[0.64975855562808, 1, 0.10033430759188922`], 
        Hue[0.6493225788760636, 1, 0.1009379677100659], 
        Hue[0.6491243444061467, 1, 0.10121244620687374`], 
        Hue[0.6497870627427598, 1, 0.10029483620233268`], 
        Hue[0.6497848661512468, 1, 0.10029787763673526`], 
        Hue[0.6493577841898455, 1, 0.10088922189098319`], 
        Hue[0.649124383631939, 1, 0.10121239189423825`], 
        Hue[0.6493221359730588, 1, 0.10093858096038015`], 
        Hue[0.6499936916833658, 1, 0.10000873459226267`], 
        Hue[0.6499293875019, 1, 0.10009777115121549`], 
        Hue[0.6497492556366449, 1, 0.1003471845031071], 
        Hue[0.6496669043016357, 1, 0.10046120942850455`], 
        Hue[0.6499461593618887, 1, 0.10007454857584651`], 
        Hue[0.649993719165779, 1, 0.10000869653969072`], 
        Hue[0.6497831131736973, 1, 0.10030030483641916`], 
        Hue[0.6496669893384683, 1, 0.10046109168519776`], 
        Hue[0.6497438699910105, 1, 0.10035464155090854`], 
        Hue[0.6499989806170189, 1, 0.10000141145335847`], 
        Hue[0.649985101517905, 1, 0.10002062866751625`], 
        Hue[0.6499903637000147, 1, 0.10001334256921046`], 
        Hue[0.649950695639109, 1, 0.1000682675766184], 
        Hue[0.6499169408087976, 1, 0.10011500503397268`], 
        Hue[0.6499382721143278, 1, 0.1000854693801616], 
        Hue[0.6499998944694872, 1, 0.10000014611917156`], 
        Hue[0.6499979396020884, 1, 0.10000285285864687`], 
        Hue[0.6499988051348664, 1, 0.10000165442864654`], 
        Hue[0.6499928687028823, 1, 0.10000987410370148`], 
        Hue[0.649990745780477, 1, 0.10001281353472413`], 
        Hue[0.6499993476880973, 1, 0.10000090320109607`], 
        Hue[0.6499925368181951, 1, 0.1000103336363452], 
        Hue[0.6499544789815872, 1, 0.10006302910241772`], 
        Hue[0.6499710158419191, 1, 0.10004013191118909`], 
        Hue[0.6499957079341608, 1, 0.10000594286039266`], 
        Hue[0.649956754063224, 1, 0.10005987898938218`], 
        Hue[0.6499973394962008, 1, 0.10000368377449126`], 
        Hue[0.6497967031430824, 1, 0.10028148795573211`], 
        Hue[0.6497422006045632, 1, 0.10035695300906637`], 
        Hue[0.6498543989283845, 1, 0.10020160148377542`], 
        Hue[0.6499796318088381, 1, 0.10002820211083958`], 
        Hue[0.6498201909540229, 1, 0.10024896637135303`], 
        Hue[0.6499821959348161, 1, 0.1000246517825623], 
        Hue[0.6493843083159343, 1, 0.10085249617793718`], 
        Hue[0.6492714389145247, 1, 0.10100877688758132`], 
        Hue[0.6495311358384765, 1, 0.10064919653134018`], 
        Hue[0.6499326287044422, 1, 0.10009328333231075`], 
        Hue[0.6490374185577825, 1, 0.10133280507383961`], 
        Hue[0.6489306887868327, 1, 0.10148058475669318`], 
        Hue[0.6493199214653447, 1, 0.10094164720183046`], 
        Hue[0.6494380510073351, 1, 0.10077808322061302`], 
        Hue[0.6499097362338689, 1, 0.10012498059925846`], 
        Hue[0.6486670765987008, 1, 0.10184558624795277`], 
        Hue[0.6485711159572851, 1, 0.10197845482837456`], 
        Hue[0.6489814055841803, 1, 0.1014103614988274], 
        Hue[0.6496859288220751, 1, 0.10043486778481915`], 
        Hue[0.6498492997424695, 1, 0.10020866189504221`], 
        Hue[0.6492162512642067, 1, 0.10108519055725237`], 
        Hue[0.6484785424654154, 1, 0.10210663350942495`], 
        Hue[0.6485590288669336, 1, 0.10199519079963036`], 
        Hue[0.6486312945647218, 1, 0.10189513060269287`], 
        Hue[0.64964448028359, 1, 0.10049225806887534`], 
        Hue[0.6477258602117325, 1, 0.10314880893760124`], 
        Hue[0.6478481526586202, 1, 0.10297948093421826`], 
        Hue[0.6483894496489135, 1, 0.10222999279381205`], 
        Hue[0.6497669433721043, 1, 0.1003226937924711], 
        Hue[0.6488750409140394, 1, 0.10155763565748402`], 
        Hue[0.6479927325367794, 1, 0.1027792934106133], 
        Hue[0.6475834488846898, 1, 0.103345993851968], 
        Hue[0.647294545382292, 1, 0.10374601408605726`], 
        Hue[0.6488721916036159, 1, 0.10156158085653198`], 
        Hue[0.6466982385822284, 1, 0.10457166965537615`], 
        Hue[0.6472169204860098, 1, 0.10385349471167879`], 
        Hue[0.6479788895815403, 1, 0.10279846057940577`], 
        Hue[0.6497220759135403, 1, 0.1003848179658674], 
        Hue[0.6486943253197311, 1, 0.10180785724960312`], 
        Hue[0.6454301116848207, 1, 0.10632753766717139`], 
        Hue[0.6468897902012749, 1, 0.1043064443366963], 
        Hue[0.6456433109470756, 1, 0.10603233868866456`], 
        Hue[0.6466457526689814, 1, 0.10464434245833346`], 
        Hue[0.6475978994814843, 1, 0.10332598533332953`], 
        Hue[0.6497395116100092, 1, 0.10036067623229504`], 
        Hue[0.648656146199945, 1, 0.10186072064622992`], 
        Hue[0.6425869541067043, 1, 0.11026421739071718`], 
        Hue[0.6412672325871597, 1, 0.1120915241100867], 
        Hue[0.6444863018191666, 1, 0.10763435132730781`], 
        Hue[0.6460978666860328, 1, 0.10540295381933926`], 
        Hue[0.6473189778091596, 1, 0.10371218457193296`], 
        Hue[0.649807523533853, 1, 0.10026650587620367`], 
        Hue[0.6488059954277982, 1, 0.10165323709997189`], 
        Hue[0.6355677813921233, 1, 0.11998307191859846`], 
        Hue[0.6225136803974088, 1, 0.1380579809882031], 
        Hue[0.6428745456415313, 1, 0.10986601372711048`], 
        Hue[0.6454891179706859, 1, 0.10624583665597352`], 
        Hue[0.6471883956275378, 1, 0.1038929906695631], 
        Hue[0.6487415025304522, 1, 0.10174253495783556`], 
        Hue[0.6498948423987034, 1, 0.10014560283256452`], 
        Hue[0.6491243397305968, 1, 0.10121245268071222`], 
        Hue[0.6472376528773863, 1, 0.10382478832361895`], 
        Hue[0.6150728538407592, 1, 0.14836066391279507`], 
        Hue[0.5682104334557555, 1, 0.21324709213818469`], 
        Hue[0.6397468996933341, 1, 0.11419660042461435`], 
        Hue[0.6449758474343685, 1, 0.10695651893702825`], 
        Hue[0.6473203313841579, 1, 0.10371031039116604`], 
        Hue[0.649958109515708, 1, 0.10005800220901968`], 
        Hue[0.6494842522907931, 1, 0.10071411221274804`], 
        Hue[0.6476512819636768, 1, 0.1032520711272168], 
        Hue[0.5687382725777202, 1, 0.2125162379693105], 
        Hue[0.4598365727270398, 1, 0.3633032069933295], 
        Hue[0.6330024607855063, 1, 0.12353505429699133`], 
        Hue[0.6446614119196817, 1, 0.10739189118813307`], 
        Hue[0.6477602551397409, 1, 0.10310118519112803`], 
        Hue[0.6499875975622534, 1, 0.10001717260611061`], 
        Hue[0.6497589618188877, 1, 0.1003337451738478], 
        Hue[0.6483004248350014, 1, 0.10235325792076734`], 
        Hue[0.49721716070323696`, 1, 0.3115454697955181], 
        Hue[0.31803818591272426`, 1, 0.5596394348900742], 
        Hue[0.621196668559564, 1, 0.13988153584060375`], 
        Hue[0.6446057461858452, 1, 0.10746896681959894`], 
        Hue[0.6484128933058226, 1, 0.10219753234578413`], 
        Hue[0.6499971946455725, 1, 0.10000388433689966`], 
        Hue[0.6499119444868917, 1, 0.10012192301814993`], 
        Hue[0.42186155100194733`, 1, 0.4158840063049961], 
        Hue[0.19690139772980203`, 1, 0.7273672954510433], 
        Hue[0.6066857938393704, 1, 0.15997351622241032`], 
        Hue[0.6447269791201125, 1, 0.10730110583369051`], 
        Hue[0.6490601902829536, 1, 0.10130127499283355`], 
        Hue[0.373210137296724, 1, 0.48324750220453605`], 
        Hue[0.12317793669624733`, 1, 0.829445933805196], 
        Hue[0.5959049495707656, 1, 0.1749008390558631], 
        Hue[0.36993896493495954`, 1, 0.4877768177823637], 
        Hue[0.10551553714933015`, 1, 0.8539015639470814], 
        Hue[0.5947857583630186, 1, 0.17645048842043587`], 
        Hue[0.6448143518714223, 1, 0.10718012817803063`], 
        Hue[0.6499983476490149, 1, 0.10000228787059483`], 
        Hue[0.4092648191983703, 1, 0.43332563495610266`], 
        Hue[0.1447215641957238, 1, 0.7996162957289977], 
        Hue[0.37321013729844094`, 1, 0.48324750220215873`], 
        Hue[0.6039331393082457, 1, 0.16378488403473676`], 
        Hue[0.6446386253954931, 1, 0.1074234417600865], 
        Hue[0.649992139261425, 1, 0.10001088409956545`], 
        Hue[0.47992518690075703`, 1, 0.335488202752798], 
        Hue[0.2386766428431551, 1, 0.669524648371016], 
        Hue[0.6189100178908071, 1, 0.1430476675358055], 
        Hue[0.6444502281867965, 1, 0.1076842994336663], 
        Hue[0.6490074389437255, 1, 0.10137431530868783`], 
        Hue[0.6499711752825617, 1, 0.10003991114722234`], 
        Hue[0.5547703620061074, 1, 0.23185642183769747`], 
        Hue[0.3752505842357152, 1, 0.4804222679813174], 
        Hue[0.31803818591257643`, 1, 0.5596394348902788], 
        Hue[0.6314113814489781, 1, 0.12573808722449184`], 
        Hue[0.6444285208655677, 1, 0.10771435572459868`], 
        Hue[0.6483403043967222, 1, 0.10229804006607698`], 
        Hue[0.6497589618188885, 1, 0.10033374517384673`], 
        Hue[0.6499202363144329, 1, 0.10011044202617], 
        Hue[0.6493814166270158, 1, 0.10085650005490128`], 
        Hue[0.607541900540672, 1, 0.1587881377129157], 
        Hue[0.510533983908946, 1, 0.2931067915106903], 
        Hue[0.6389584142500593, 1, 0.11528834949991792`], 
        Hue[0.6476512819636974, 1, 0.10325207112718823`], 
        Hue[0.6494842522907944, 1, 0.10071411221274629`], 
        Hue[0.6498383027784684, 1, 0.10022388846058228`], 
        Hue[0.6490246129733723, 1, 0.10135053588302294`], 
        Hue[0.6327196532762671, 1, 0.12392663392516859`], 
        Hue[0.5972214239241667, 1, 0.17307802841269226`], 
        Hue[0.6425408848188652, 1, 0.11032800563541752`], 
        Hue[0.6472376528774035, 1, 0.10382478832359508`], 
        Hue[0.6491243397305978, 1, 0.10121245268071082`], 
        Hue[0.6497608890911948, 1, 0.10033107664296116`], 
        Hue[0.6487415025304524, 1, 0.10174253495783517`], 
        Hue[0.6416071963746622, 1, 0.1116208050196985], 
        Hue[0.6333039763671718, 1, 0.12311757118391589`], 
        Hue[0.6442963774518267, 1, 0.10789732352824008`], 
        Hue[0.6457420223619781, 1, 0.10589566134495344`], 
        Hue[0.6471779091179248, 1, 0.10390751045210413`], 
        Hue[0.6488059954277986, 1, 0.10165323709997116`], 
        Hue[0.6497216053983531, 1, 0.1003854694484342], 
        Hue[0.6486614185740522, 1, 0.10185342043592767`], 
        Hue[0.6460978666860392, 1, 0.1054029538193304], 
        Hue[0.6449363081982395, 1, 0.10701126557166839`], 
        Hue[0.6443792387298783, 1, 0.10778259252786082`], 
        Hue[0.6454878932078376, 1, 0.10624753248145567`], 
        Hue[0.6463374972854069, 1, 0.10507115760482126`], 
        Hue[0.6486561461999453, 1, 0.1018607206462296], 
        Hue[0.6497446269774029, 1, 0.10035359341590379`], 
        Hue[0.6487385095926335, 1, 0.10174667902558446`], 
        Hue[0.6469167021582983, 1, 0.10426918162697163`], 
        Hue[0.6465464412567904, 1, 0.1047818505675211], 
        Hue[0.6469074083357891, 1, 0.10428204999659982`], 
        Hue[0.6476302589163752, 1, 0.10328117996194215`], 
        Hue[0.6486943253197311, 1, 0.10180785724960303`], 
        Hue[0.6498180333025885, 1, 0.10025195388872371`], 
        Hue[0.6489651538469169, 1, 0.1014328639042689], 
        Hue[0.6479788895815404, 1, 0.10279846057940568`], 
        Hue[0.6483449140191653, 1, 0.10229165751192505`], 
        Hue[0.6492133707832798, 1, 0.10108917891545874`], 
        Hue[0.6472945453822796, 1, 0.10374601408607449`], 
        Hue[0.6475834488846899, 1, 0.10334599385196792`], 
        Hue[0.647992732536779, 1, 0.10277929341061362`], 
        Hue[0.6488750409140392, 1, 0.1015576356574841], 
        Hue[0.6499074536869546, 1, 0.1001281410488322], 
        Hue[0.6493262593973559, 1, 0.10093287160366118`], 
        Hue[0.649261181264013, 1, 0.10102297978828971`], 
        Hue[0.6486312945647198, 1, 0.10189513060269563`], 
        Hue[0.6485590288669338, 1, 0.10199519079963013`], 
        Hue[0.6481847608283471, 1, 0.1025134080838271], 
        Hue[0.6484785424654151, 1, 0.10210663350942521`], 
        Hue[0.6499685517490378, 1, 0.10004354373210153`], 
        Hue[0.6496859288220751, 1, 0.10043486778481911`], 
        Hue[0.649748705671542, 1, 0.10034794599324967`], 
        Hue[0.6494380510073349, 1, 0.10077808322061324`], 
        Hue[0.6493199214653449, 1, 0.10094164720183023`], 
        Hue[0.6489306887868329, 1, 0.10148058475669298`], 
        Hue[0.6490374185577824, 1, 0.10133280507383975`], 
        Hue[0.6499926102537842, 1, 0.10001023195629886`], 
        Hue[0.6498879983365086, 1, 0.10015507922637275`], 
        Hue[0.6499334733653315, 1, 0.10009211380184874`], 
        Hue[0.6497651749073808, 1, 0.10032514243593432`], 
        Hue[0.6495445652662334, 1, 0.10063060193906152`], 
        Hue[0.649577435244752, 1, 0.10058508966111265`], 
        Hue[0.6499987823857478, 1, 0.1000016859274261], 
        Hue[0.6499871546152928, 1, 0.10001778591728701`], 
        Hue[0.6499450533801044, 1, 0.10007607993524002`], 
        Hue[0.6498702683563081, 1, 0.1001796284297273], 
        Hue[0.6499998525302062, 1, 0.10000020418894534`], 
        Hue[0.6499982837325233, 1, 0.10000237637035238`], 
        Hue[0.6499917724184623, 1, 0.1000113920359754], 
        Hue[0.649995513367399, 1, 0.10000621226052449`], 
        Hue[0.6499768211371815, 1, 0.10003209381005643`], 
        Hue[0.6499709311885555, 1, 0.1000402491235386], 
        Hue[0.6499998652875634, 1, 0.10000018652491231`], 
        Hue[0.6499997033584459, 1, 0.10000041073445946`], 
        Hue[0.6499916431084579, 1, 0.10001157108059679`], 
        Hue[0.6499768885403957, 1, 0.10003200048252905`], 
        Hue[0.6499955545015644, 1, 0.10000615530552621`], 
        Hue[0.6499921940479368, 1, 0.1000108082413183], 
        Hue[0.6499724972674363, 1, 0.10003808070662663`], 
        Hue[0.6498762763822666, 1, 0.10017130962455394`], 
        Hue[0.6498541257365453, 1, 0.1002019797493988], 
        Hue[0.6499986685807253, 1, 0.10000184350361113`], 
        Hue[0.6499973236426885, 1, 0.10000370572550824`], 
        Hue[0.6498868726098938, 1, 0.10015663792476255`], 
        Hue[0.6495774352447521, 1, 0.10058508966111257`], 
        Hue[0.6495306842520321, 1, 0.10064982180487866`], 
        Hue[0.6499903486487819, 1, 0.10001336340937898`], 
        Hue[0.6499821551229769, 1, 0.10002470829126286`], 
        Hue[0.6497647458011402, 1, 0.10032573658303667`], 
        Hue[0.6496752830842288, 1, 0.10044960803722157`], 
        Hue[0.6499471992776279, 1, 0.10007310869251525`], 
        Hue[0.6499098804701536, 1, 0.10012478088747968`], 
        Hue[0.6494383119686717, 1, 0.10077772188953145`], 
        Hue[0.6493256084315968, 1, 0.10093377294086603`], 
        Hue[0.649776996090499, 1, 0.10030877464392456`], 
        Hue[0.6496468100677264, 1, 0.10048903221391733`], 
        Hue[0.6498176582689631, 1, 0.10025247316605115`], 
        Hue[0.6472164168884315, 1, 0.10385419200063341`], 
        Hue[0.6492133707832604, 1, 0.10108917891548565`], 
        Hue[0.6488711177040118, 1, 0.10156306779444524`], 
        Hue[0.6475890729501657, 1, 0.10333820668438606`], 
        Hue[0.6476302589163754, 1, 0.10328117996194189`], 
        Hue[0.6475974574857243, 1, 0.10332659732745868`], 
        Hue[0.646907408335789, 1, 0.10428204999659996`], 
        Hue[0.6466451819682595, 1, 0.10464513265933302`], 
        Hue[0.6465464412567904, 1, 0.10478185056752098`], 
        Hue[0.6456423119377144, 1, 0.10603372193239557`], 
        Hue[0.6469167021582841, 1, 0.10426918162699127`], 
        Hue[0.6454307554303607, 1, 0.10632664632719298`], 
        Hue[0.6465472957244994, 1, 0.10478066745838542`], 
        Hue[0.6473386224356839, 1, 0.10368498431982238`], 
        Hue[0.6473184531260547, 1, 0.10371291105623187`], 
        Hue[0.6463374972854046, 1, 0.10507115760482454`], 
        Hue[0.6460736462773837, 1, 0.10543648976977642`], 
        Hue[0.6444850252643294, 1, 0.10763611886477478`], 
        Hue[0.6449354756217992, 1, 0.10701241836981658`], 
        Hue[0.6444510447211438, 1, 0.10768316884764709`], 
        Hue[0.6443792387296079, 1, 0.1077825925282352], 
        Hue[0.6412672295634202, 1, 0.11209152829680277`], 
        Hue[0.6449363081981927, 1, 0.10701126557173327`], 
        Hue[0.6471779091179208, 1, 0.10390751045210966`], 
        Hue[0.6471877544905376, 1, 0.10389387839771733`], 
        Hue[0.6457420223619642, 1, 0.10589566134497266`], 
        Hue[0.6454881245503387, 1, 0.10624721216106962`], 
        Hue[0.642880143347721, 1, 0.10985826305700162`], 
        Hue[0.6416047567880195, 1, 0.11162418290889603`], 
        Hue[0.6334576495991256, 1, 0.12290479286274922`], 
        Hue[0.6333039763666903, 1, 0.12311757118458268`], 
        Hue[0.6225162151465412, 1, 0.13805447133555832`], 
        Hue[0.6471785610476386, 1, 0.10390660778019273`], 
        Hue[0.6497523354002839, 1, 0.10034292021499154`], 
        Hue[0.6498071763115432, 1, 0.10026698664555568`], 
        Hue[0.6449747057502084, 1, 0.1069580997304807], 
        Hue[0.6397424833007522, 1, 0.11420271542972767`], 
        Hue[0.597215256587844, 1, 0.17308656780144682`], 
        Hue[0.6472745253097338, 1, 0.10377373418652247`], 
        Hue[0.6446604067396445, 1, 0.10739328297587684`], 
        Hue[0.6075239849976855, 1, 0.15881294384935868`], 
        Hue[0.5105208513498842, 1, 0.29312497505400636`], 
        Hue[0.6447422602882784, 1, 0.10727994729315306`], 
        Hue[0.649381416627015, 1, 0.10085650005490243`], 
        Hue[0.649486617144909, 1, 0.10071083779935683`], 
        Hue[0.6444285208655705, 1, 0.10771435572459478`], 
        Hue[0.6446054156460019, 1, 0.10746942449015119`], 
        Hue[0.6211894469842812, 1, 0.13989153494484138`], 
        Hue[0.554742913496705, 1, 0.23189442746610078`], 
        Hue[0.6444293000046293, 1, 0.1077132769166672], 
        Hue[0.6496976408126711, 1, 0.10041865118245545`], 
        Hue[0.6497610653711231, 1, 0.10033083256306041`], 
        Hue[0.6444502281869443, 1, 0.10768429943346178`], 
        Hue[0.6066823642767764, 1, 0.15997826484754044`], 
        Hue[0.47990058829306015`, 1, 0.33552226236345517`], 
        Hue[0.6444500571990789, 1, 0.10768453618589077`], 
        Hue[0.6490063830516137, 1, 0.10137577731315026`], 
        Hue[0.6498799412726698, 1, 0.10016623516091878`], 
        Hue[0.649911933583973, 1, 0.10012193811449889`], 
        Hue[0.6494787147610733, 1, 0.10072177956159074`], 
        Hue[0.6499615936668797, 1, 0.10005317799970509`], 
        Hue[0.6499730201144908, 1, 0.10003735676455126`], 
        Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
        Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
        Hue[0.6499730201144907, 1, 0.10003735676455143`], 
        Hue[0.6495118930856678, 1, 0.10067584034292153`], 
        Hue[0.6494787147610555, 1, 0.1007217795616155], 
        Hue[0.6499119335839733, 1, 0.10012193811449864`], 
        Hue[0.6490601902829449, 1, 0.10130127499284557`], 
        Hue[0.6490063830516063, 1, 0.10137577731316062`], 
        Hue[0.6447269791198692, 1, 0.10730110583402727`], 
        Hue[0.6444500571988938, 1, 0.107684536186147], 
        Hue[0.4218615510037922, 1, 0.4158840063024417], 
        Hue[0.47990058829466353`, 1, 0.33552226236123506`], 
        Hue[0.6066823642771331, 1, 0.15997826484704664`], 
        Hue[0.6448226855248735, 1, 0.10716858927325204`], 
        Hue[0.6497610653711238, 1, 0.10033083256305943`], 
        Hue[0.6446057461857632, 1, 0.1074689668197126], 
        Hue[0.6444293000046112, 1, 0.10771327691669216`], 
        Hue[0.5547429134976742, 1, 0.23189442746475877`], 
        Hue[0.6211894469844135, 1, 0.13989153494465828`], 
        Hue[0.6446054156459394, 1, 0.10746942449023777`], 
        Hue[0.64948661714491, 1, 0.10071083779935554`], 
        Hue[0.6446614119197258, 1, 0.10739189118807202`], 
        Hue[0.45983657272859146`, 1, 0.363303206991181], 
        Hue[0.5105208513514403, 1, 0.2931249750518519], 
        Hue[0.6075239849981006, 1, 0.1588129438487838], 
        Hue[0.6446153322487039, 1, 0.1074556938094869], 
        Hue[0.6473203313841712, 1, 0.10371031039114756`], 
        Hue[0.6472745253097465, 1, 0.10377373418650494`], 
        Hue[0.5682104334567644, 1, 0.21324709213678777`], 
        Hue[0.5972152565884311, 1, 0.17308656780063383`], 
        Hue[0.6397424833007788, 1, 0.11420271542969104`], 
        Hue[0.6449747057502664, 1, 0.10695809973040038`], 
        Hue[0.6498071763115433, 1, 0.10026698664555556`], 
        Hue[0.6471883956275423, 1, 0.10389299066955694`], 
        Hue[0.6471785610476427, 1, 0.1039066077801871], 
        Hue[0.6225162151471285, 1, 0.1380544713347452], 
        Hue[0.6225136803974847, 1, 0.13805798098809824`], 
        Hue[0.63345764959897, 1, 0.12290479286296463`], 
        Hue[0.6416047567879692, 1, 0.11162418290896563`], 
        Hue[0.642880143347735, 1, 0.10985826305698226`], 
        Hue[0.6454881245503643, 1, 0.10624721216103408`], 
        Hue[0.6471877544905419, 1, 0.10389387839771125`], 
        Hue[0.6412672295637786, 1, 0.11209152829630659`], 
        Hue[0.6412672325869215, 1, 0.11209152411041637`], 
        Hue[0.6444510447209121, 1, 0.10768316884796794`], 
        Hue[0.6449354756217571, 1, 0.10701241836987481`], 
        Hue[0.6444850252643324, 1, 0.10763611886477062`], 
        Hue[0.6460736462773896, 1, 0.10543648976976822`], 
        Hue[0.6473131697351501, 1, 0.10372022652056141`], 
        Hue[0.6456433109470772, 1, 0.10603233868866238`], 
        Hue[0.6465472957244996, 1, 0.10478066745838509`], 
        Hue[0.645430755430402, 1, 0.10632664632713582`], 
        Hue[0.6456423119377144, 1, 0.10603372193239552`], 
        Hue[0.6466451819682602, 1, 0.10464513265933213`], 
        Hue[0.6475974574857242, 1, 0.10332659732745889`], 
        Hue[0.6466982385822284, 1, 0.10457166965537615`], 
        Hue[0.6475890729501654, 1, 0.10333820668438629`], 
        Hue[0.6488711177040516, 1, 0.1015630677943901], 
        Hue[0.6472164168884315, 1, 0.10385419200063346`], 
        Hue[0.6497585093987792, 1, 0.1003343716016903], 
        Hue[0.6498176582689631, 1, 0.1002524731660512], 
        Hue[0.6496468100677315, 1, 0.1004890322139102], 
        Hue[0.6492162512642066, 1, 0.10108519055725255`], 
        Hue[0.6493256084315967, 1, 0.1009337729408662], 
        Hue[0.6494383119686719, 1, 0.10077772188953124`], 
        Hue[0.649909880470154, 1, 0.10012478088747913`], 
        Hue[0.649589967952851, 1, 0.10056773668066789`], 
        Hue[0.6496752830842288, 1, 0.1004496080372217], 
        Hue[0.6493843083159341, 1, 0.10085249617793741`], 
        Hue[0.6497647458011401, 1, 0.10032573658303681`], 
        Hue[0.6499821551229769, 1, 0.10002470829126284`], 
        Hue[0.6495306842520321, 1, 0.10064982180487875`], 
        Hue[0.6498432245869254, 1, 0.1002170736488725], 
        Hue[0.6498868726098938, 1, 0.1001566379247626], 
        Hue[0.6499973236426885, 1, 0.10000370572550824`], 
        Hue[0.6498541257365453, 1, 0.10020197974939885`], 
        Hue[0.64995742655059, 1, 0.10005894785302934`], 
        Hue[0.6499724972674363, 1, 0.10003808070662665`], 
        Hue[0.6499921940479368, 1, 0.10001080824131829`], 
        Hue[0.6499710158419191, 1, 0.10004013191118907`], 
        Hue[0.6499768885403957, 1, 0.10003200048252905`], 
        Hue[0.6499916431084579, 1, 0.1000115710805968], 
        Hue[0.6499997033584459, 1, 0.10000041073445946`], 
        Hue[0.6499709311885555, 1, 0.10004024912353861`], 
        Hue[0.6499921293089566, 1, 0.10001089787990629`], 
        Hue[0.649995513367399, 1, 0.10000621226052449`], 
        Hue[0.6499998925666856, 1, 0.1000001487538201], 
        Hue[0.6499996894548788, 1, 0.10000042998555234`], 
        Hue[0.6499745865383855, 1, 0.10003518786992782`], 
        Hue[0.6499382721143278, 1, 0.10008546938016159`], 
        Hue[0.6499800978129978, 1, 0.10002755687431077`], 
        Hue[0.6499964589486245, 1, 0.1000049029942124], 
        Hue[0.64999986712212, 1, 0.10000018398475698`], 
        Hue[0.6499999463041645, 1, 0.10000007434808002`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499993787624871, 1, 0.1000008601750178], 
        Hue[0.6499964290356581, 1, 0.10000494441216566`], 
        Hue[0.6499800210545625, 1, 0.10002766315522107`], 
        Hue[0.6499786432660215, 1, 0.10002957086243185`], 
        Hue[0.6499746602037512, 1, 0.10003508587172913`], 
        Hue[0.6499976810908947, 1, 0.10000321079722264`], 
        Hue[0.6499657096233139, 1, 0.10004747898310386`], 
        Hue[0.6498668777824628, 1, 0.1001843230704362], 
        Hue[0.6497438699910105, 1, 0.10035464155090848`], 
        Hue[0.649870268356308, 1, 0.10017962842972737`], 
        Hue[0.6497422679611429, 1, 0.10035685974610997`], 
        Hue[0.6498908903541091, 1, 0.10015107489431062`], 
        Hue[0.6499949427213864, 1, 0.10000700238577273`], 
        Hue[0.6499763529684163, 1, 0.10003274204373135`], 
        Hue[0.6499461593618887, 1, 0.10007454857584648`], 
        Hue[0.6498906156449327, 1, 0.1001514552608625], 
        Hue[0.6498765165910504, 1, 0.10017097702777646`], 
        Hue[0.6498671323084145, 1, 0.10018397064988767`], 
        Hue[0.6499728188455073, 1, 0.10003763544468222`], 
        Hue[0.6499576702370821, 1, 0.10005861044096338`], 
        Hue[0.6499875385469106, 1, 0.10001725431966231`], 
        Hue[0.6498661528906174, 1, 0.10018532676683745`], 
        Hue[0.6495445652662333, 1, 0.10063060193906169`], 
        Hue[0.6492714988092747, 1, 0.10100869395638892`], 
        Hue[0.6497651749073807, 1, 0.10032514243593448`], 
        Hue[0.6493848462505366, 1, 0.10085175134541081`], 
        Hue[0.6499272404251579, 1, 0.10010074402670449`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.649969296003201, 1, 0.10004251322633723`], 
        Hue[0.6498899253776143, 1, 0.10015241101561109`], 
        Hue[0.6497870627427598, 1, 0.10029483620233265`], 
        Hue[0.6493194313649149, 1, 0.10094232580242553`], 
        Hue[0.6495778694437395, 1, 0.10058448846251461`], 
        Hue[0.6498879983365086, 1, 0.10015507922637279`], 
        Hue[0.6498347039214942, 1, 0.1002288714933158], 
        Hue[0.6499510653458983, 1, 0.10006775567491014`], 
        Hue[0.6496322047027856, 1, 0.1005092550269123], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6498549379809121, 1, 0.10020085510335254`], 
        Hue[0.6496196896792598, 1, 0.10052658352102503`], 
        Hue[0.6492611812640128, 1, 0.10102297978828999`], 
        Hue[0.6486346449067906, 1, 0.10189049166752082`], 
        Hue[0.648932730765027, 1, 0.1014777574022703], 
        Hue[0.6490500614364054, 1, 0.10131529954959252`], 
        Hue[0.6499685517490378, 1, 0.10004354373210153`], 
        Hue[0.6499183291303127, 1, 0.10011308274264409`], 
        Hue[0.6498754872667991, 1, 0.10017240224597054`], 
        Hue[0.6499289484739935, 1, 0.10009837903600899`], 
        Hue[0.6499289484739935, 1, 0.10009837903600899`], 
        Hue[0.6494782446417726, 1, 0.10072243049600713`], 
        Hue[0.6485606730077387, 1, 0.10199291429697721`], 
        Hue[0.6481850644702218, 1, 0.10251298765661597`], 
        Hue[0.6484548050697109, 1, 0.10213950067270804`], 
        Hue[0.6493262593973559, 1, 0.10093287160366117`], 
        Hue[0.6492168120882642, 1, 0.10108441403163429`], 
        Hue[0.6489651538469169, 1, 0.1014328639042689], 
        Hue[0.648885852981722, 1, 0.10154266510223119`], 
        Hue[0.6498180333025885, 1, 0.10025195388872368`], 
        Hue[0.6497587426645933, 1, 0.10033404861825539`], 
        Hue[0.6497844884994876, 1, 0.10029840053917118`], 
        Hue[0.6492143200935674, 1, 0.10108786448582988`], 
        Hue[0.6479045331466708, 1, 0.10290141564307125`], 
        Hue[0.6496234965987956, 1, 0.10052131240166762`], 
        Hue[0.6496234965987956, 1, 0.10052131240166765`], 
        Hue[0.6490857182415352, 1, 0.10126592858864364`], 
        Hue[0.6479034511561871, 1, 0.10290291378374103`], 
        Hue[0.6468888344261866, 1, 0.10430776771758775`], 
        Hue[0.6483449140191628, 1, 0.10229165751192838`], 
        Hue[0.6473051809263888, 1, 0.10373128794807714`], 
        Hue[0.6471452171056802, 1, 0.10395277631521214`], 
        Hue[0.6475004150899578, 1, 0.10346096372159684`], 
        Hue[0.6487385095926334, 1, 0.1017466790255846], 
        Hue[0.6486985272829319, 1, 0.10180203914670977`], 
        Hue[0.6497446269774029, 1, 0.10035359341590382`], 
        Hue[0.6497220805506987, 1, 0.10038481154518647`], 
        Hue[0.6462369452811768, 1, 0.1052103834568321], 
        Hue[0.6469079421015003, 1, 0.10428131093638432`], 
        Hue[0.6476306747916084, 1, 0.10328060413469611`], 
        Hue[0.6473382110820148, 1, 0.10368555388644096`], 
        Hue[0.648661418574052, 1, 0.10185342043592796`], 
        Hue[0.6486592242610936, 1, 0.10185645871540887`], 
        Hue[0.6497216634938592, 1, 0.10038538900850272`], 
        Hue[0.6497525816504375, 1, 0.10034257925324044`], 
        Hue[0.6450042018600481, 1, 0.10691725896301033`], 
        Hue[0.6443899338329367, 1, 0.10776778392362601`], 
        Hue[0.6439216662083573, 1, 0.10841615448073602`], 
        Hue[0.6432968085982096, 1, 0.10928134194094055`], 
        Hue[0.6439229159369845, 1, 0.10841442408725224`], 
        Hue[0.6453175862656672, 1, 0.10648334209369166`], 
        Hue[0.6436612706901965, 1, 0.10877670212126647`], 
        Hue[0.6427084326690093, 1, 0.11009601630444861`], 
        Hue[0.6392482971262531, 1, 0.11488697320980351`], 
        Hue[0.6294670107067267, 1, 0.12843029286760918`], 
        Hue[0.6416071963745711, 1, 0.11162080501982463`], 
        Hue[0.645742913475472, 1, 0.10589442749550039`], 
        Hue[0.6451848600758338, 1, 0.10666711681807645`], 
        Hue[0.6497760637592552, 1, 0.10031006556410821`], 
        Hue[0.6498175387315116, 1, 0.10025263867944553`], 
        Hue[0.6448171573226332, 1, 0.10717624370712325`], 
        Hue[0.6413492538797264, 1, 0.11197795616653275`], 
        Hue[0.6393231015822374, 1, 0.11478339780920989`], 
        Hue[0.6255259248970585, 1, 0.13388718091176524`], 
        Hue[0.5591705448255907, 1, 0.22576386101072066`], 
        Hue[0.5591705448255893, 1, 0.22576386101072254`], 
        Hue[0.5972214239234073, 1, 0.1730780284137438], 
        Hue[0.5682182330617682, 1, 0.21323629268370556`], 
        Hue[0.6327196532761413, 1, 0.12392663392534278`], 
        Hue[0.6138281474123832, 1, 0.15008410358285407`], 
        Hue[0.6476889012124133, 1, 0.10319998293665852`], 
        Hue[0.6490246129733719, 1, 0.10135053588302363`], 
        Hue[0.649124059969674, 1, 0.10121284004198979`], 
        Hue[0.6498625824888393, 1, 0.10019027040006866`], 
        Hue[0.6499045423782822, 1, 0.10013217209160925`], 
        Hue[0.6445346715614864, 1, 0.10756737783794197`], 
        Hue[0.6363229297017776, 1, 0.11893748195138483`], 
        Hue[0.6320807432699075, 1, 0.12481127854935892`], 
        Hue[0.5900825238500126, 1, 0.18296265928459798`], 
        Hue[0.42804171263097834`, 1, 0.40732685943403], 
        Hue[0.428041712630976, 1, 0.40732685943403324`], 
        Hue[0.5105339839078467, 1, 0.2931067915122123], 
        Hue[0.4598523370119753, 1, 0.36328137952188033`], 
        Hue[0.6386880733811459, 1, 0.11566266762610583`], 
        Hue[0.6494358636771674, 1, 0.10078111183161441`], 
        Hue[0.6495955370911396, 1, 0.10056002556611444`], 
        Hue[0.649938736749848, 1, 0.10008482603867205`], 
        Hue[0.6499635376940699, 1, 0.10005048626974945`], 
        Hue[0.6445187656804581, 1, 0.10758940136551957`], 
        Hue[0.6264945721377744, 1, 0.13254597704000476`], 
        Hue[0.6197500814766024, 1, 0.14188450257085822`], 
        Hue[0.5262450270724327, 1, 0.2713530394381701], 
        Hue[0.2607299568423358, 1, 0.6389892905259966], 
        Hue[0.2607299568423336, 1, 0.6389892905259997], 
        Hue[0.3752505842350581, 1, 0.4804222679822273], 
        Hue[0.31924359861609497`, 1, 0.5579704019161762], 
        Hue[0.554770362006304, 1, 0.23185642183742522`], 
        Hue[0.4950793034126642, 1, 0.31450557989015726`], 
        Hue[0.4799251869017592, 1, 0.33548820275141034`], 
        Hue[0.42187632618428994`, 1, 0.415863548360214], 
        Hue[0.6483395074792696, 1, 0.10229914349024219`], 
        Hue[0.6483775520143685, 1, 0.10224646644164366`], 
        Hue[0.6497259877549584, 1, 0.10037940157005763`], 
        Hue[0.6498247725796027, 1, 0.10024262258208867`], 
        Hue[0.6499797919710948, 1, 0.10002798034771491`], 
        Hue[0.6499895375823748, 1, 0.10001448642440419`], 
        Hue[0.6490074389437328, 1, 0.10137431530867769`], 
        Hue[0.6490612179653512, 1, 0.10129985204797536`], 
        Hue[0.6123745783732009, 1, 0.15209673763710646`], 
        Hue[0.23864305325650226`, 1, 0.6695711570294584], 
        Hue[0.14468550878839948`, 1, 0.7996662186006775], 
        Hue[0.12170305563956119`, 1, 0.8314880768067614], 
        Hue[0.12170305563955952`, 1, 0.8314880768067637], 
        Hue[0.238676642843565, 1, 0.6695246483704484], 
        Hue[0.19694005227972833`, 1, 0.72731377376653], 
        Hue[0.14472156419557214`, 1, 0.7996162957292078], 
        Hue[0.12320664814156568`, 1, 0.8294061794962936], 
        Hue[0.40926481920002356`, 1, 0.4333256349538136], 
        Hue[0.374774116754797, 1, 0.4810819921856657], 
        Hue[0.6039357705145427, 1, 0.16378124082601786`], 
        Hue[0.6446378483467694, 1, 0.10742451767370392`], 
        Hue[0.6490365748044977, 1, 0.10133397334761854`], 
        Hue[0.6498942532833836, 1, 0.10014641853069964`], 
        Hue[0.6499395617051158, 1, 0.1000836837929167], 
        Hue[0.6499952798767935, 1, 0.100006535555209], 
        Hue[0.6499979498338926, 1, 0.10000283869153345`], 
        Hue[0.6499617603399275, 1, 0.10005294722163892`], 
        Hue[0.6499852500802348, 1, 0.10002042296582875`], 
        Hue[0.6494794345021933, 1, 0.10072078299696322`], 
        Hue[0.6495125444945455, 1, 0.10067493839216769`], 
        Hue[0.6496523580230951, 1, 0.10048135042956073`], 
        Hue[0.649652317451856, 1, 0.10048140660512248`], 
        Hue[0.13133504687157593`, 1, 0.8181514735624333], 
        Hue[0.10550699045289536`, 1, 0.8539133978344525], 
        Hue[0.033059327874931266`, 1, 0.954225546019326], 
        Hue[0.03305932787493049, 1, 0.9542255460193271], 
        Hue[0.008564162898874517, 1, 0.9881419282938662], 
        Hue[0.1313694777268779, 1, 0.8181038000704768], 
        Hue[0.1055155371471872, 1, 0.8539015639500485], 
        Hue[0.10550699045002132`, 1, 0.8539133978384321], 
        Hue[0.36993896493670303`, 1, 0.48777681777994963`], 
        Hue[0.36993665875161313`, 1, 0.4877800109593049], 
        Hue[0.5947858976879443, 1, 0.17645029550900027`], 
        Hue[0.6494921178875066, 1, 0.1007032213865294], 
        Hue[0.6496523174518573, 1, 0.10048140660512081`], 
        Hue[0.6499852320800056, 1, 0.10002044788922304`], 
        Hue[0.6499852500802348, 1, 0.1000204229658288], 
        Hue[0.6499990931632785, 1, 0.10000125562007593`], 
        Hue[0.6496149480433893, 1, 0.10053314886299958`], 
        Hue[0.5947857583623528, 1, 0.1764504884213577], 
        Hue[0.5947858976870672, 1, 0.17645029551021466`], 
        Hue[0.5959049495698923, 1, 0.17490083905707227`], 
        Hue[0.6039357705136676, 1, 0.1637812408272295], 
        Hue[0.36993665874980525`, 1, 0.48778001096180823`], 
        Hue[0.37477411675310107`, 1, 0.48108199218801395`], 
        Hue[0.12320664814257443`, 1, 0.8294061794948969], 
        Hue[0.03305932787187027, 1, 0.9542255460235642], 
        Hue[0.03305932787187105, 1, 0.9542255460235631], 
        Hue[0.12317793669320076`, 1, 0.8294459338094142], 
        Hue[0.14468550878547748`, 1, 0.7996662186047235], 
        Hue[0.6495125444945283, 1, 0.10067493839219155`], 
        Hue[0.6499731374090267, 1, 0.10003719435673222`], 
        Hue[0.6499560132855162, 1, 0.10006090468159291`], 
        Hue[0.6499979498338926, 1, 0.10000283869153345`], 
        Hue[0.6499990931632785, 1, 0.10000125562007593`], 
        Hue[0.6494921178874883, 1, 0.10070322138655469`], 
        Hue[0.6492984661033572, 1, 0.10097135462612092`], 
        Hue[0.6446378483465085, 1, 0.10742451767406523`], 
        Hue[0.6446747005057164, 1, 0.10737349160746958`], 
        Hue[0.606685793838532, 1, 0.1599735162235711], 
        Hue[0.42187632618276033`, 1, 0.41586354836233186`], 
        Hue[0.13136947772739593`, 1, 0.8181038000697596], 
        Hue[0.19694005227927935`, 1, 0.7273137737671517], 
        Hue[0.13133504686846842`, 1, 0.818151473566736], 
        Hue[0.1969013977278607, 1, 0.7273672954537314], 
        Hue[0.23864305325552504`, 1, 0.6695711570308115], 
        Hue[0.6494928049778319, 1, 0.10070227003069428`], 
        Hue[0.6499667588310656, 1, 0.10004602623390928`], 
        Hue[0.6499952798767935, 1, 0.100006535555209], 
        Hue[0.6498942532833839, 1, 0.10014641853069926`], 
        Hue[0.6490365748044896, 1, 0.10133397334762985`], 
        Hue[0.6445188584205228, 1, 0.10758927295619916`], 
        Hue[0.621196668559048, 1, 0.13988153584131827`], 
        Hue[0.495079303411862, 1, 0.31450557989126804`], 
        Hue[0.2153784744288908, 1, 0.7017836507907667], 
        Hue[0.12170305563612915`, 1, 0.8314880768115135], 
        Hue[0.12170305563613082`, 1, 0.8314880768115112], 
        Hue[0.21534157718856928`, 1, 0.7018347392773656], 
        Hue[0.48756298968034184`, 1, 0.32491278351952674`], 
        Hue[0.6123745783734575, 1, 0.15209673763675113`], 
        Hue[0.6490612179653427, 1, 0.10129985204798718`], 
        Hue[0.6499797919710948, 1, 0.1000279803477149], 
        Hue[0.6497259877549593, 1, 0.10037940157005647`], 
        Hue[0.6484128933058365, 1, 0.10219753234576491`], 
        Hue[0.6483395074792844, 1, 0.10229914349022172`], 
        Hue[0.6445356096358542, 1, 0.10756607896574029`], 
        Hue[0.6330024607853297, 1, 0.12353505429723577`], 
        Hue[0.6386880733811164, 1, 0.11566266762614656`], 
        Hue[0.3192435986162432, 1, 0.557970401915971], 
        Hue[0.26072995684176903`, 1, 0.6389892905267813], 
        Hue[0.26072995684177125`, 1, 0.6389892905267783], 
        Hue[0.5262450270736311, 1, 0.27135303943651085`], 
        Hue[0.5613439013174828, 1, 0.22275459817579313`], 
        Hue[0.6264945721378616, 1, 0.1325459770398839], 
        Hue[0.6499875780500365, 1, 0.1000171996230264], 
        Hue[0.649938736749848, 1, 0.10008482603867203`], 
        Hue[0.6477602551397624, 1, 0.10310118519109816`], 
        Hue[0.6476889012124346, 1, 0.10319998293662903`], 
        Hue[0.6474700106798329, 1, 0.1035030621356161], 
        Hue[0.6449758474344257, 1, 0.10695651893694909`], 
        Hue[0.4598523370130185, 1, 0.36328137952043593`], 
        Hue[0.4280417126324515, 1, 0.4073268594319903], 
        Hue[0.4280417126324537, 1, 0.4073268594319872], 
        Hue[0.54385421509572, 1, 0.24697108679054167`], 
        Hue[0.5900825238506199, 1, 0.18296265928375707`], 
        Hue[0.6113184040198553, 1, 0.153559132895585], 
        Hue[0.6363229297018138, 1, 0.11893748195133472`], 
        Hue[0.649904864696231, 1, 0.10013172580521863`], 
        Hue[0.6498625824888394, 1, 0.10019027040006856`], 
        Hue[0.6491240599696747, 1, 0.10121284004198884`], 
        Hue[0.6471976417124166, 1, 0.10388018839819256`], 
        Hue[0.6454891179707115, 1, 0.10624583665593802`], 
        Hue[0.645742913475486, 1, 0.10589442749548107`], 
        Hue[0.5682182330626965, 1, 0.21323629268242025`], 
        Hue[0.5591705448266979, 1, 0.22576386100918752`], 
        Hue[0.5591705448266993, 1, 0.22576386100918563`], 
        Hue[0.6131150084109671, 1, 0.1510715268155841], 
        Hue[0.6255259248972418, 1, 0.13388718091151136`], 
        Hue[0.641349253879749, 1, 0.1119779561665015], 
        Hue[0.6498075235338531, 1, 0.10026650587620355`], 
        Hue[0.6497525816504376, 1, 0.10034257925324029`], 
        Hue[0.6473189778091604, 1, 0.10371218457193178`], 
        Hue[0.6473382110820156, 1, 0.10368555388643992`], 
        Hue[0.6428823803202547, 1, 0.10985516571041662`], 
        Hue[0.6442709715647634, 1, 0.10793250091032752`], 
        Hue[0.639252008962006, 1, 0.11488183374491492`], 
        Hue[0.638478408111949, 1, 0.11595297338345519`], 
        Hue[0.6392482971262289, 1, 0.11488697320983701`], 
        Hue[0.6421307435744987, 1, 0.11089589351223259`], 
        Hue[0.6436612706902044, 1, 0.10877670212125548`], 
        Hue[0.6497395116100093, 1, 0.10036067623229489`], 
        Hue[0.6497216634938593, 1, 0.10038538900850259`], 
        Hue[0.6486592242610939, 1, 0.10185645871540853`], 
        Hue[0.648698527282932, 1, 0.10180203914670959`], 
        Hue[0.6475978994814844, 1, 0.10332598533332933`], 
        Hue[0.6476306747916085, 1, 0.10328060413469593`], 
        Hue[0.6444863018191734, 1, 0.10763435132729843`], 
        Hue[0.6439229159370509, 1, 0.10841442408716043`], 
        Hue[0.643921666208303, 1, 0.10841615448081116`], 
        Hue[0.6450042018600488, 1, 0.10691725896300938`], 
        Hue[0.6497220805506988, 1, 0.10038481154518636`], 
        Hue[0.6497587426645933, 1, 0.10033404861825539`], 
        Hue[0.648885852981722, 1, 0.10154266510223114`], 
        Hue[0.646645752668982, 1, 0.10464434245833251`], 
        Hue[0.6469079421015004, 1, 0.10428131093638407`], 
        Hue[0.6460988378741064, 1, 0.10540160909739126`], 
        Hue[0.6468888344263425, 1, 0.10430776771737202`], 
        Hue[0.6468897902011312, 1, 0.1043064443368952], 
        Hue[0.6479045331465779, 1, 0.10290141564319985`], 
        Hue[0.6488721916035767, 1, 0.10156158085658615`], 
        Hue[0.6492143200935481, 1, 0.10108786448585658`], 
        Hue[0.6492168120882642, 1, 0.10108441403163429`], 
        Hue[0.6472169204860098, 1, 0.10385349471167882`], 
        Hue[0.6475004150899578, 1, 0.10346096372159691`], 
        Hue[0.64714521710568, 1, 0.10395277631521234`], 
        Hue[0.6473051809264003, 1, 0.10373128794806115`], 
        Hue[0.6490857182415612, 1, 0.1012659285886076], 
        Hue[0.6496234965987958, 1, 0.10052131240166731`], 
        Hue[0.6496234965987958, 1, 0.1005213124016673], 
        Hue[0.6497844884994874, 1, 0.10029840053917122`], 
        Hue[0.6498285638060287, 1, 0.10023737319165266`], 
        Hue[0.6483894496489137, 1, 0.10222999279381195`], 
        Hue[0.648454805069711, 1, 0.1021395006727079], 
        Hue[0.6478481526586201, 1, 0.10297948093421838`], 
        Hue[0.6481850644702217, 1, 0.10251298765661612`], 
        Hue[0.6477258602117323, 1, 0.10314880893760156`], 
        Hue[0.6485606730077386, 1, 0.10199291429697746`], 
        Hue[0.6486346449067923, 1, 0.10189049166751832`], 
        Hue[0.6499289484739935, 1, 0.10009837903600897`], 
        Hue[0.6499289484739935, 1, 0.10009837903600897`], 
        Hue[0.6494608701931662, 1, 0.10074648742484672`], 
        Hue[0.649875487266799, 1, 0.10017240224597058`], 
        Hue[0.6499179695206531, 1, 0.10011358066371125`], 
        Hue[0.6489814055841803, 1, 0.10141036149882729`], 
        Hue[0.6490500614364055, 1, 0.1013152995495924], 
        Hue[0.6485711159572849, 1, 0.10197845482837475`], 
        Hue[0.6489327307650269, 1, 0.1014777574022705], 
        Hue[0.6486670765987006, 1, 0.10184558624795306`], 
        Hue[0.6493194313649148, 1, 0.10094232580242575`], 
        Hue[0.6493571286681644, 1, 0.10089012953638776`], 
        Hue[0.6496196896792598, 1, 0.10052658352102502`], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6496322047027855, 1, 0.10050925502691244`], 
        Hue[0.6497686522347683, 1, 0.10032032767493618`], 
        Hue[0.6499510653458982, 1, 0.10006775567491016`], 
        Hue[0.6499735114284139, 1, 0.10003667648373475`], 
        Hue[0.6498347039214942, 1, 0.10022887149331573`], 
        Hue[0.6495311358384767, 1, 0.1006491965313401], 
        Hue[0.6495778694437395, 1, 0.10058448846251451`], 
        Hue[0.6497827013349246, 1, 0.10030087507471992`], 
        Hue[0.6498899253776143, 1, 0.10015241101561112`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6498201909540229, 1, 0.100248966371353], 
        Hue[0.6499272404251579, 1, 0.10010074402670446`], 
        Hue[0.6493848462505368, 1, 0.10085175134541056`], 
        Hue[0.6492714988092748, 1, 0.1010086939563887], 
        Hue[0.6498661528906173, 1, 0.10018532676683752`], 
        Hue[0.6499298416416035, 1, 0.10009714234239514`], 
        Hue[0.6499875385469106, 1, 0.10001725431966232`], 
        Hue[0.6499576702370821, 1, 0.10005861044096336`], 
        Hue[0.6499659179555519, 1, 0.100047190523082], 
        Hue[0.6498543989283845, 1, 0.1002016014837754], 
        Hue[0.6498765165910504, 1, 0.10017097702777641`], 
        Hue[0.6498906156449326, 1, 0.1001514552608626], 
        Hue[0.6499763529684163, 1, 0.10003274204373136`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6497422679611429, 1, 0.10035685974610986`], 
        Hue[0.6498668777824628, 1, 0.10018432307043623`], 
        Hue[0.6499657096233139, 1, 0.10004747898310389`], 
        Hue[0.6499852101793618, 1, 0.10002047821319135`], 
        Hue[0.6499976810908947, 1, 0.10000321079722264`], 
        Hue[0.6499991804292786, 1, 0.10000113479022964`], 
        Hue[0.6499746602037513, 1, 0.10003508587172912`], 
        Hue[0.6499800210545625, 1, 0.1000276631552211], 
        Hue[0.6499964290356581, 1, 0.10000494441216566`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499997070467911, 1, 0.10000040562752005`], 
        Hue[0.64999986712212, 1, 0.10000018398475698`], 
        Hue[0.6499999463041645, 1, 0.10000007434808002`], 
        Hue[0.6499964589486245, 1, 0.1000049029942124], 
        Hue[0.6499800978129978, 1, 0.10002755687431074`], 
        Hue[0.6499452847292683, 1, 0.10007575960562862`], 
        Hue[0.6499745865383855, 1, 0.10003518786992784`], 
        Hue[0.6499996894548788, 1, 0.10000042998555234`], 
        Hue[0.6499998925666856, 1, 0.1000001487538201], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499872761827475, 1, 0.1000176175931189], 
        Hue[0.6499764872407213, 1, 0.10003255612823204`], 
        Hue[0.6499659179555519, 1, 0.10004719052308203`], 
        Hue[0.6496095597971275, 1, 0.10054060951166954`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6495581589251695, 1, 0.10061177994976521`], 
        Hue[0.6498666614359694, 1, 0.10018462262711933`], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.649363405912811, 1, 0.10088143796687704`], 
        Hue[0.6487551382058032, 1, 0.10172365479196484`], 
        Hue[0.6490171435581192, 1, 0.1013608781502964], 
        Hue[0.6499289484739935, 1, 0.10009837903600899`], 
        Hue[0.648157278257873, 1, 0.10255146087371447`], 
        Hue[0.6480091049759613, 1, 0.10275662387943817`], 
        Hue[0.6490820712669709, 1, 0.10127097824573264`], 
        Hue[0.6498289592233316, 1, 0.10023682569077165`], 
        Hue[0.6496234965987956, 1, 0.10052131240166763`], 
        Hue[0.6484645052704197, 1, 0.10212606962557286`], 
        Hue[0.6473537923316893, 1, 0.10366397984843018`], 
        Hue[0.6487973060787215, 1, 0.10166526850638559`], 
        Hue[0.6497500661969323, 1, 0.10034606218886298`], 
        Hue[0.6460988378741057, 1, 0.10540160909739217`], 
        Hue[0.6486665440965278, 1, 0.10184632355865385`], 
        Hue[0.6450053143732752, 1, 0.10691571856008053`], 
        Hue[0.6392520089618975, 1, 0.11488183374506498`], 
        Hue[0.5856239954315853, 1, 0.18913600632549732`], 
        Hue[0.6255368322474695, 1, 0.13387207842658083`], 
        Hue[0.48730850453537505`, 1, 0.3252651475664038], 
        Hue[0.26072995684233463`, 1, 0.6389892905259982], 
        Hue[0.346411220142523, 1, 0.5203536951872758], 
        Hue[0.4875889857309319, 1, 0.3248767889879404], 
        Hue[0.2153415771900969, 1, 0.7018347392752505], 
        Hue[0.1217030556395603, 1, 0.8314880768067627], 
        Hue[0.21537847442945068`, 1, 0.7017836507899914], 
        Hue[0.16664015272578908`, 1, 0.7692674808412151], 
        Hue[0.41486309731408044`, 1, 0.42557417294973476`], 
        Hue[0.6499667588310657, 1, 0.10004602623390908`], 
        Hue[0.6494928049778499, 1, 0.10070227003066942`], 
        Hue[0.649615310956585, 1, 0.10053264636780553`], 
        Hue[0.03305932787493093, 1, 0.9542255460193264], 
        Hue[0.10995731692864064`, 1, 0.8477514073295744], 
        Hue[0.37117736989835204`, 1, 0.4860621032176664], 
        Hue[0.6499817210220852, 1, 0.10002530935403599`], 
        Hue[0.5950760330681312, 1, 0.17604856959797222`], 
        Hue[0.008564162897190308, 1, 0.9881419282961981], 
        Hue[0.10993697241469957`, 1, 0.8477795766565698], 
        Hue[0.6499817845643628, 1, 0.10002522137242076`], 
        Hue[0.605186076820044, 1, 0.16205004747993917`], 
        Hue[0.1666007064873134, 1, 0.7693220987098738], 
        Hue[0.619757163057583, 1, 0.14187469730488508`], 
        Hue[0.12170305563612982`, 1, 0.8314880768115125], 
        Hue[0.648377552014383, 1, 0.10224646644162362`], 
        Hue[0.6320881314564141, 1, 0.12480104875265746`], 
        Hue[0.3464112201429481, 1, 0.5203536951866873], 
        Hue[0.2607299568417701, 1, 0.6389892905267799], 
        Hue[0.6499637194211009, 1, 0.10005023464770654`], 
        Hue[0.6494358636771683, 1, 0.10078111183161315`], 
        Hue[0.6448183521045393, 1, 0.10717458939371491`], 
        Hue[0.4873085045365092, 1, 0.3252651475648335], 
        Hue[0.4280417126324527, 1, 0.40732685943198865`], 
        Hue[0.6453186380742266, 1, 0.10648188574337857`], 
        Hue[0.6255368322476118, 1, 0.13387207842638366`], 
        Hue[0.585623995432426, 1, 0.1891360063243331], 
        Hue[0.5591705448266987, 1, 0.22576386100918638`], 
        Hue[0.6498178986902057, 1, 0.10025214027509986`], 
        Hue[0.6497760637592553, 1, 0.10031006556410807`], 
        Hue[0.6472266389834023, 1, 0.10384003833067385`], 
        Hue[0.6294670107072551, 1, 0.12843029286687765`], 
        Hue[0.6497444578897739, 1, 0.1003538275372362], 
        Hue[0.6474600972735775, 1, 0.10351678839043128`], 
        Hue[0.6450053143732791, 1, 0.10691571856007508`], 
        Hue[0.643296808598523, 1, 0.1092813419405066], 
        Hue[0.646236945281202, 1, 0.10521038345679727`], 
        Hue[0.6484656021364826, 1, 0.1021245508879472], 
        Hue[0.6473537923316893, 1, 0.10366397984843025`], 
        Hue[0.6496234965987958, 1, 0.10052131240166731`], 
        Hue[0.6480091049759613, 1, 0.10275662387943829`], 
        Hue[0.6481572782578727, 1, 0.10255146087371475`], 
        Hue[0.6499289484739935, 1, 0.10009837903600897`], 
        Hue[0.6490171435581193, 1, 0.10136087815029629`], 
        Hue[0.6487551382058031, 1, 0.10172365479196505`], 
        Hue[0.6499892775816672, 1, 0.10001484642538379`], 
        Hue[0.6498666614359694, 1, 0.10018462262711927`], 
        Hue[0.6495581589251697, 1, 0.10061177994976513`], 
        Hue[0.6496095597971278, 1, 0.10054060951166935`], 
        Hue[0.6498671323084145, 1, 0.10018397064988764`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499764872407213, 1, 0.10003255612823203`], 
        Hue[0.6498908903541091, 1, 0.10015107489431052`], 
        Hue[0.6499655367985427, 1, 0.10004771827894093`], 
        Hue[0.6499997961154858, 1, 0.10000028230163507`], 
        Hue[0.649965516562715, 1, 0.10004774629777935`], 
        Hue[0.6495577101050631, 1, 0.10061240139298958`], 
        Hue[0.6496090377308191, 1, 0.10054133237271205`], 
        Hue[0.6490867430856696, 1, 0.1012645095736882], 
        Hue[0.6474954669798254, 1, 0.10346781495101104`], 
        Hue[0.6474944451680356, 1, 0.10346922976733547`], 
        Hue[0.6294650459019114, 1, 0.12843301336658416`], 
        Hue[0.6492993957289686, 1, 0.10097006745219737`], 
        Hue[0.6294650459018397, 1, 0.1284330133666835], 
        Hue[0.6474944451681558, 1, 0.10346922976716888`], 
        Hue[0.6474954669797106, 1, 0.10346781495117001`], 
        Hue[0.6490867430856438, 1, 0.10126450957372388`], 
        Hue[0.6496090377308189, 1, 0.10054133237271225`], 
        Hue[0.649557710105063, 1, 0.10061240139298966`], 
        Hue[0.649965516562715, 1, 0.10004774629777938`], 
        Hue[0.6499997961154859, 1, 0.10000028230163507`], 
        Hue[0.6499655367985427, 1, 0.1000477182789409], 
        Hue[0.649999546284906, 1, 0.10000062822089953`], 
        Hue[0.6499921293089566, 1, 0.10001089787990629`], 
        Hue[0.6499882868309909, 1, 0.10001621823401269`], 
        Hue[0.6499773681890932, 1, 0.10003133635356326`], 
        Hue[0.6499968016948423, 1, 0.10000442842252606`], 
        Hue[0.64995742655059, 1, 0.10005894785302931`], 
        Hue[0.649941550412067, 1, 0.10008093019867641`], 
        Hue[0.6498799739553269, 1, 0.10016618990800887`], 
        Hue[0.6499837977879257, 1, 0.10002243383210294`], 
        Hue[0.6498432245869254, 1, 0.10021707364887242`], 
        Hue[0.6497995501416562, 1, 0.10027754595770676`], 
        Hue[0.6499427464970976, 1, 0.10007927408094187`], 
        Hue[0.6495899679528511, 1, 0.10056773668066774`], 
        Hue[0.649510432152012, 1, 0.10067786317413728`], 
        Hue[0.6498634854226076, 1, 0.10018902018408178`], 
        Hue[0.6435492187576689, 1, 0.10893185095091998`], 
        Hue[0.6383247155518019, 1, 0.11616577846673584`], 
        Hue[0.6228816248504461, 1, 0.13754851943784388`], 
        Hue[0.5843916311222078, 1, 0.19084235690771226`], 
        Hue[0.5180120543224636, 1, 0.2827525401688967], 
        Hue[0.6499987777339871, 1, 0.10000169236832561`], 
        Hue[0.6499615936668796, 1, 0.1000531779997052], 
        Hue[0.6499507438872519, 1, 0.10006820077149743`], 
        Hue[0.649993865184265, 1, 0.10000849436024842`], 
        Hue[0.6498799412726701, 1, 0.10016623516091828`], 
        Hue[0.6498506186895232, 1, 0.10020683566066013`], 
        Hue[0.6139219345410796, 1, 0.14995424448158212`], 
        Hue[0.6499762536549267, 1, 0.10003287955471694`], 
        Hue[0.6496976408126719, 1, 0.1004186511824543], 
        Hue[0.6496397195744826, 1, 0.10049884981994713`], 
        Hue[0.6276537703969356, 1, 0.13094093329655082`], 
        Hue[0.6499307068090907, 1, 0.10009594441818212`], 
        Hue[0.6369354292276367, 1, 0.11808940568481076`], 
        Hue[0.6498518987975389, 1, 0.10020506320340777`], 
        Hue[0.6416037038677828, 1, 0.1116256407984547], 
        Hue[0.6437749675546233, 1, 0.10861927569359858`], 
        Hue[0.6479034511562832, 1, 0.10290291378360782`], 
        Hue[0.6481488635226913, 1, 0.10256311204550442`], 
        Hue[0.649776996090501, 1, 0.10030877464392167`], 
        Hue[0.6498161665378698, 1, 0.10025453863987266`], 
        Hue[0.6496713073131245, 1, 0.1004551129510585], 
        Hue[0.649947199277628, 1, 0.10007310869251507`], 
        Hue[0.6499585389917858, 1, 0.10005740754983512`], 
        Hue[0.6499080428696403, 1, 0.1001273252574212], 
        Hue[0.6499903486487819, 1, 0.10001336340937897`], 
        Hue[0.6499928350255395, 1, 0.10000992073386847`], 
        Hue[0.6499810990463154, 1, 0.10002617055125557`], 
        Hue[0.6499986685807253, 1, 0.10000184350361113`], 
        Hue[0.6499990728488086, 1, 0.10000128374780339`], 
        Hue[0.6498762763822666, 1, 0.10017130962455396`], 
        Hue[0.6499312334274999, 1, 0.10009521525423096`], 
        Hue[0.6499998652875634, 1, 0.10000018652491231`], 
        Hue[0.6499999130990606, 1, 0.10000012032437766`], 
        Hue[0.6499786571222672, 1, 0.10002955167686084`], 
        Hue[0.6499786571222672, 1, 0.10002955167686084`], 
        Hue[0.6499546249480828, 1, 0.10006282699496238`], 
        Hue[0.6499774540762749, 1, 0.10003121743285015`], 
        Hue[0.6499999130990606, 1, 0.10000012032437766`], 
        Hue[0.6499312334274999, 1, 0.10009521525423093`], 
        Hue[0.6499990728488086, 1, 0.10000128374780339`], 
        Hue[0.6499871546152928, 1, 0.100017785917287], 
        Hue[0.6499810990463154, 1, 0.10002617055125557`], 
        Hue[0.6499928350255395, 1, 0.10000992073386847`], 
        Hue[0.6499334733653315, 1, 0.10009211380184871`], 
        Hue[0.6499080428696403, 1, 0.10012732525742117`], 
        Hue[0.6499585389917857, 1, 0.10005740754983526`], 
        Hue[0.649748705671542, 1, 0.10034794599324966`], 
        Hue[0.6496713073131244, 1, 0.10045511295105851`], 
        Hue[0.6498161665378682, 1, 0.1002545386398748], 
        Hue[0.644296377451823, 1, 0.1078973235282451], 
        Hue[0.6437749675546159, 1, 0.10861927569360877`], 
        Hue[0.6355280494073325, 1, 0.12003808543600118`], 
        Hue[0.6425408848188494, 1, 0.11032800563543929`], 
        Hue[0.6416037038677618, 1, 0.11162564079848367`], 
        Hue[0.6498383027784683, 1, 0.10022388846058237`], 
        Hue[0.6498518987975388, 1, 0.10020506320340787`], 
        Hue[0.6389584142500294, 1, 0.11528834949995931`], 
        Hue[0.6369354292276049, 1, 0.1180894056848547], 
        Hue[0.6499202363144327, 1, 0.10011044202617006`], 
        Hue[0.6499307068090907, 1, 0.10009594441818216`], 
        Hue[0.631411381448922, 1, 0.1257380872245697], 
        Hue[0.627653770396862, 1, 0.1309409332966527], 
        Hue[0.6496397195744819, 1, 0.10049884981994829`], 
        Hue[0.6499711752825617, 1, 0.10003991114722235`], 
        Hue[0.6499762536549266, 1, 0.10003287955471696`], 
        Hue[0.6189100178906387, 1, 0.1430476675360388], 
        Hue[0.6139219345408472, 1, 0.14995424448190392`], 
        Hue[0.6498506186895228, 1, 0.10020683566066077`], 
        Hue[0.649992139261425, 1, 0.10001088409956546`], 
        Hue[0.649993865184265, 1, 0.10000849436024842`], 
        Hue[0.6499507438872519, 1, 0.10006820077149738`], 
        Hue[0.6499983476490149, 1, 0.10000228787059483`], 
        Hue[0.6499987777339871, 1, 0.10000169236832561`], 
        Hue[0.49721716070467575`, 1, 0.31154546979352593`], 
        Hue[0.5180120543237592, 1, 0.2827525401671027], 
        Hue[0.5687382725785333, 1, 0.21251623796818472`], 
        Hue[0.5843916311228772, 1, 0.19084235690678542`], 
        Hue[0.6150728538410806, 1, 0.14836066391234995`], 
        Hue[0.6228816248506641, 1, 0.13754851943754204`], 
        Hue[0.6355280494071399, 1, 0.12003808543626789`], 
        Hue[0.635567781392156, 1, 0.11998307191855329`], 
        Hue[0.6383247155517912, 1, 0.11616577846675076`], 
        Hue[0.6425869541066499, 1, 0.11026421739079253`], 
        Hue[0.6435492187576146, 1, 0.10893185095099511`], 
        Hue[0.6498492997424695, 1, 0.10020866189504225`], 
        Hue[0.6498634854226076, 1, 0.10018902018408182`], 
        Hue[0.6495104321520119, 1, 0.10067786317413743`], 
        Hue[0.6499326287044422, 1, 0.10009328333231078`], 
        Hue[0.6499427464970975, 1, 0.1000792740809419], 
        Hue[0.6497995501416562, 1, 0.10027754595770684`], 
        Hue[0.6499796318088381, 1, 0.1000282021108396], 
        Hue[0.6499837977879257, 1, 0.10002243383210295`], 
        Hue[0.6497967031430822, 1, 0.10028148795573225`], 
        Hue[0.6498799739553269, 1, 0.10016618990800896`], 
        Hue[0.649941550412067, 1, 0.10008093019867645`], 
        Hue[0.6499957079341608, 1, 0.10000594286039267`], 
        Hue[0.6499968016948423, 1, 0.10000442842252608`], 
        Hue[0.6499544789815872, 1, 0.10006302910241778`], 
        Hue[0.6499773681890932, 1, 0.10003133635356329`], 
        Hue[0.6499546249480828, 1, 0.10006282699496233`], 
        Hue[0.6499774540762749, 1, 0.10003121743285012`], 
        Hue[0.6499882868309909, 1, 0.1000162182340127], 
        Hue[0.6499993476880973, 1, 0.10000090320109607`], 
        Hue[0.649999546284906, 1, 0.10000062822089954`], 
        Hue[0.6499786571222672, 1, 0.10002955167686085`], 
        Hue[0.6499786571222672, 1, 0.10002955167686085`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499786432660215, 1, 0.10002957086243183`], 
        Hue[0.6481499757638645, 1, 0.10256157201926468`], 
        Hue[0.6481488635226094, 1, 0.10256311204561784`], 
        Hue[0.6481499757637849, 1, 0.10256157201937481`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499786432660215, 1, 0.10002957086243186`], 
        Hue[0.6499786432660215, 1, 0.10002957086243186`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499872761827474, 1, 0.1000176175931189], 
        Hue[0.6499998499361392, 1, 0.10000020778073027`], 
        Hue[0.6499997756993264, 1, 0.10000031057016343`], 
        Hue[0.649998744591033, 1, 0.10000173825856974`], 
        Hue[0.649998257978814, 1, 0.10000241202933446`], 
        Hue[0.6499807313906684, 1, 0.10002667961292076`], 
        Hue[0.6499999454587057, 1, 0.10000007551871525`], 
        Hue[0.6499448820990992, 1, 0.10007631709355502`], 
        Hue[0.6498985097083886, 1, 0.1001405250191543], 
        Hue[0.6499985526901774, 1, 0.10000200396744671`], 
        Hue[0.6499924900042139, 1, 0.10001039845570384`], 
        Hue[0.6499902455567599, 1, 0.10001350615217873`], 
        Hue[0.6499145448836653, 1, 0.10011832246877118`], 
        Hue[0.6498226656875891, 1, 0.1002455398171844], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6498702084125652, 1, 0.10017971142875591`], 
        Hue[0.649822601052624, 1, 0.10024562931175142`], 
        Hue[0.6499915553675152, 1, 0.10001169256805592`], 
        Hue[0.6495444786347687, 1, 0.10063072189032035`], 
        Hue[0.649721605398353, 1, 0.10038546944843432`], 
        Hue[0.6497393167031354, 1, 0.100360946103351], 
        Hue[0.6430994341869618, 1, 0.10955462958728368`], 
        Hue[0.6430994341869617, 1, 0.10955462958728389`], 
        Hue[0.6497442349944514, 1, 0.10035413616152887`], 
        Hue[0.6326369084382304, 1, 0.12404120370091186`], 
        Hue[0.6278460623885441, 1, 0.13067468284663128`], 
        Hue[0.6227153440039708, 1, 0.13777875445604051`], 
        Hue[0.6227153440039702, 1, 0.13777875445604126`], 
        Hue[0.649925810454061, 1, 0.10010272398668485`], 
        Hue[0.6499740052775556, 1, 0.10003599269261546`], 
        Hue[0.6499931350584105, 1, 0.10000950530373938`], 
        Hue[0.6499731374090268, 1, 0.10003719435673206`], 
        Hue[0.6499785845670428, 1, 0.10002965213794066`], 
        Hue[0.6493278398912834, 1, 0.10093068322745373`], 
        Hue[0.645136680417695, 1, 0.10673382711396075`], 
        Hue[0.6493269366654968, 1, 0.10093193384777369`], 
        Hue[0.6495118930856854, 1, 0.10067584034289725`], 
        Hue[0.6496046189157386, 1, 0.10054745073205425`], 
        Hue[0.6499986042640042, 1, 0.10000193255753263`], 
        Hue[0.6499994842091842, 1, 0.10000071417189885`], 
        Hue[0.6499992967751281, 1, 0.10000097369597646`], 
        Hue[0.6499785002992391, 1, 0.10002976881643816`], 
        Hue[0.6448143518714428, 1, 0.10718012817800232`], 
        Hue[0.6448140890407283, 1, 0.10718049209745306`], 
        Hue[0.6448213068073145, 1, 0.1071704982667953], 
        Hue[0.008564162898874295, 1, 0.9881419282938664], 
        Hue[0.6496050201873774, 1, 0.10054689512516983`], 
        Hue[0.6499994103243372, 1, 0.1000008164739948], 
        Hue[0.649997177936394, 1, 0.10000390747268527`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.00856416289719053, 1, 0.9881419282961977], 
        Hue[0.6499785845670427, 1, 0.10002965213794082`], 
        Hue[0.6499968070349429, 1, 0.1000044210285406], 
        Hue[0.6499875143105937, 1, 0.10001728787763953`], 
        Hue[0.6499844331418096, 1, 0.10002155411134056`], 
        Hue[0.6499861817897984, 1, 0.1000191329064331], 
        Hue[0.632957681610334, 1, 0.12359705623184515`], 
        Hue[0.6358099147458792, 1, 0.11964781035185952`], 
        Hue[0.634495825261374, 1, 0.12146731886886677`], 
        Hue[0.6227153440043056, 1, 0.13777875445557686`], 
        Hue[0.6227153440043062, 1, 0.1377787544555762], 
        Hue[0.6430994341870133, 1, 0.1095546295872123], 
        Hue[0.6430994341870135, 1, 0.10955462958721211`], 
        Hue[0.6497220759135403, 1, 0.10038481796586732`], 
        Hue[0.6497444630285241, 1, 0.10035382042204369`], 
        Hue[0.6497498661728607, 1, 0.10034633914526984`], 
        Hue[0.6499766495074196, 1, 0.10003233145126512`], 
        Hue[0.6499380881968962, 1, 0.10008572403506673`], 
        Hue[0.6492714389145244, 1, 0.10100877688758152`], 
        Hue[0.6495444786347686, 1, 0.1006307218903205], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499820089674371, 1, 0.10002491066047177`], 
        Hue[0.6497422006045631, 1, 0.10035695300906648`], 
        Hue[0.6498702084125652, 1, 0.10017971142875598`], 
        Hue[0.6499924815348365, 1, 0.10001041018253413`], 
        Hue[0.649995066268984, 1, 0.10000683131986839`], 
        Hue[0.6499995584935135, 1, 0.10000061131667352`], 
        Hue[0.6498987693663226, 1, 0.10014016549278415`], 
        Hue[0.6499963588136884, 1, 0.10000504164258525`], 
        Hue[0.6499999454587057, 1, 0.10000007551871525`], 
        Hue[0.6499872851621001, 1, 0.10001760516016903`], 
        Hue[0.6499994700011782, 1, 0.10000073384452254`], 
        Hue[0.6459417553415034, 1, 0.10561910798868754`], 
        Hue[0.6447602379007432, 1, 0.10725505521435556`], 
        Hue[0.6499848496426992, 1, 0.10002097741780114`], 
        Hue[0.6499997133311914, 1, 0.10000039692604273`], 
        Hue[0.6447602379004879, 1, 0.10725505521470911`], 
        Hue[0.6445860308483408, 1, 0.10749626497922055`], 
        Hue[0.6450472715451145, 1, 0.10685762401445689`], 
        Hue[0.6451837682394977, 1, 0.10666862859146471`], 
        Hue[0.6451837682394977, 1, 0.1066686285914647], 
        Hue[0.622715344004306, 1, 0.13777875445557644`], 
        Hue[0.6430994341870134, 1, 0.10955462958721218`], 
        Hue[0.6473532864649094, 1, 0.10366468027935616`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.649992836251731, 1, 0.10000991903606476`], 
        Hue[0.6499979189376313, 1, 0.1000028814709721], 
        Hue[0.6499979189376313, 1, 0.1000028814709721], 
        Hue[0.6499892906359471, 1, 0.10001482835022706`], 
        Hue[0.6499987880908246, 1, 0.10000167802808904`], 
        Hue[0.6499982837325233, 1, 0.10000237637035238`], 
        Hue[0.6499972833772172, 1, 0.1000037614776993], 
        Hue[0.649992836251731, 1, 0.10000991903606475`], 
        Hue[0.6499907772481441, 1, 0.1000127699641082], 
        Hue[0.6499851015179049, 1, 0.10002062866751626`], 
        Hue[0.6497831131736972, 1, 0.1003003048364193], 
        Hue[0.6498758963289265, 1, 0.10017183585225567`], 
        Hue[0.649849705083499, 1, 0.10020810065361672`], 
        Hue[0.6498638958591649, 1, 0.10018845188731017`], 
        Hue[0.6473532864649095, 1, 0.10366468027935608`], 
        Hue[0.647459617606195, 1, 0.1035174525452686], 
        Hue[0.6455633919912058, 1, 0.10614299570448421`], 
        Hue[0.6454878932078376, 1, 0.10624753248145562`], 
        Hue[0.6450803703104614, 1, 0.10681179495474584`], 
        Hue[0.6452024257204934, 1, 0.10664279515624006`], 
        Hue[0.6421328552372222, 1, 0.11089296967153851`], 
        Hue[0.6227153440039706, 1, 0.13777875445604082`], 
        Hue[0.6384789975532855, 1, 0.11595215723391242`], 
        Hue[0.6498629460993739, 1, 0.10018976693932855`], 
        Hue[0.649838667427071, 1, 0.10022338356251717`], 
        Hue[0.6498522655918395, 1, 0.10020455533437608`], 
        Hue[0.6450472715450636, 1, 0.10685762401452739`], 
        Hue[0.6450484170872487, 1, 0.10685603787919415`], 
        Hue[0.6446438544073366, 1, 0.10741620158984168`], 
        Hue[0.6447422602882784, 1, 0.10727994729315304`], 
        Hue[0.6265023909906814, 1, 0.13253515093597962`], 
        Hue[0.644586417592622, 1, 0.10749572948713883`], 
        Hue[0.6445864175924405, 1, 0.10749572948739003`], 
        Hue[0.6265023909903279, 1, 0.13253515093646911`], 
        Hue[0.6446438544073931, 1, 0.10741620158976331`], 
        Hue[0.644742260288343, 1, 0.10727994729306359`], 
        Hue[0.644742260288343, 1, 0.10727994729306359`], 
        Hue[0.6450484170872991, 1, 0.10685603787912441`], 
        Hue[0.6498629460993739, 1, 0.10018976693932846`], 
        Hue[0.6498386674270711, 1, 0.10022338356251707`], 
        Hue[0.6498522655918396, 1, 0.10020455533437599`], 
        Hue[0.6459425149453752, 1, 0.1056180562294804], 
        Hue[0.6455644065284449, 1, 0.1061415909606147], 
        Hue[0.6498758963289265, 1, 0.10017183585225571`], 
        Hue[0.649849705083499, 1, 0.10020810065361677`], 
        Hue[0.6498638958591649, 1, 0.10018845188731021`], 
        Hue[0.6499907772481441, 1, 0.1000127699641082], 
        Hue[0.6499902459174384, 1, 0.10001350565277761`], 
        Hue[0.6499987880908246, 1, 0.10000167802808904`], 
        Hue[0.6499971170968787, 1, 0.10000399171201411`], 
        Hue[0.6499941827230284, 1, 0.1000080546911914], 
        Hue[0.6499169408087975, 1, 0.10011500503397273`], 
        Hue[0.6499450533801044, 1, 0.10007607993524008`], 
        Hue[0.6498987693663225, 1, 0.10014016549278425`], 
        Hue[0.649998299585341, 1, 0.10000235442029706`], 
        Hue[0.649997310025984, 1, 0.10000372457940669`], 
        Hue[0.6499954637608208, 1, 0.10000628094655577`], 
        Hue[0.6499999143695201, 1, 0.1000001185652799], 
        Hue[0.6499998973914634, 1, 0.10000014207335849`], 
        Hue[0.6499995584935135, 1, 0.10000061131667352`], 
        Hue[0.6499998069333369, 1, 0.10000026732307205`], 
        Hue[0.6499998959071556, 1, 0.10000014412855386`], 
        Hue[0.6499996498839958, 1, 0.10000048477600589`], 
        Hue[0.6499989198255313, 1, 0.10000149562618747`], 
        Hue[0.6499924815348365, 1, 0.10001041018253413`], 
        Hue[0.649995066268984, 1, 0.10000683131986839`], 
        Hue[0.6499903637000147, 1, 0.10001334256921045`], 
        Hue[0.6499883785355535, 1, 0.10001609125846449`], 
        Hue[0.6499971445555819, 1, 0.1000039536922713], 
        Hue[0.6499872378397605, 1, 0.1000176706834086], 
        Hue[0.6499812127959619, 1, 0.10002601305174516`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499981583263428, 1, 0.10000255000967932`], 
        Hue[0.6499969194200786, 1, 0.10000426541835268`], 
        Hue[0.6499565454836217, 1, 0.10006016779190839`], 
        Hue[0.6499694960336535, 1, 0.10004223626109525`], 
        Hue[0.6499293875018999, 1, 0.10009777115121551`], 
        Hue[0.6499680543081146, 1, 0.10004423249645675`], 
        Hue[0.6499611431173056, 1, 0.10005380183757688`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499766495074196, 1, 0.10003233145126515`], 
        Hue[0.6499870926215222, 1, 0.10001787175481541`], 
        Hue[0.6498198123292014, 1, 0.10024949062110575`], 
        Hue[0.6498658977018641, 1, 0.10018568010511125`], 
        Hue[0.6499070733798012, 1, 0.10012866762796759`], 
        Hue[0.6498941642091621, 1, 0.10014654186423702`], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6498880939419249, 1, 0.1001549468496424], 
        Hue[0.6499317360308979, 1, 0.10009451934183362`], 
        Hue[0.6499513388525884, 1, 0.10006737697333921`], 
        Hue[0.6499329557399242, 1, 0.10009283051395124`], 
        Hue[0.6499430494131799, 1, 0.10007885465867403`], 
        Hue[0.6499074536869546, 1, 0.10012814104883216`], 
        Hue[0.6498945576128976, 1, 0.10014599715137257`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6495806066420229, 1, 0.1005806984956607], 
        Hue[0.6497210465128498, 1, 0.1003862432899004], 
        Hue[0.6454889217763359, 1, 0.10624610830968877`], 
        Hue[0.6450814653729393, 1, 0.10681027871439172`], 
        Hue[0.6342357357137165, 1, 0.12182744285793096`], 
        Hue[0.6451848600758338, 1, 0.10666711681807643`], 
        Hue[0.6499389913540884, 1, 0.10008447350972376`], 
        Hue[0.6499205322569598, 1, 0.10011003225959413`], 
        Hue[0.6499309840236278, 1, 0.10009556058266922`], 
        Hue[0.6131190636396185, 1, 0.15106591188360513`], 
        Hue[0.636329096752552, 1, 0.11892894295800491`], 
        Hue[0.6498945035414182, 1, 0.10014607201957486`], 
        Hue[0.6498817551107648, 1, 0.10016372369278723`], 
        Hue[0.6329576816102909, 1, 0.123597056231905], 
        Hue[0.6358099147458411, 1, 0.11964781035191228`], 
        Hue[0.6314188285392712, 1, 0.12572777586870135`], 
        Hue[0.6276615081560073, 1, 0.13093021947629757`], 
        Hue[0.6499579058346595, 1, 0.10005828422893298`], 
        Hue[0.6499502404150022, 1, 0.1000688978869202], 
        Hue[0.6123798420904445, 1, 0.15208944941323072`], 
        Hue[0.6189168169702053, 1, 0.1430382534258697], 
        Hue[0.613927475741499, 1, 0.14994657205023218`], 
        Hue[0.6498038432915917, 1, 0.10027160159625775`], 
        Hue[0.6499875143105937, 1, 0.10001728787763954`], 
        Hue[0.6499844331418096, 1, 0.10002155411134057`], 
        Hue[0.6445860308485625, 1, 0.10749626497891357`], 
        Hue[0.6499305639619214, 1, 0.10009614220657034`], 
        Hue[0.6499569735915823, 1, 0.10005957502703981`], 
        Hue[0.649997177936394, 1, 0.10000390747268527`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499978738704448, 1, 0.10000294387169176`], 
        Hue[0.6499990165514296, 1, 0.10000136169802062`], 
        Hue[0.6499997433419163, 1, 0.10000035537273123`], 
        Hue[0.6499848496426992, 1, 0.10002097741780114`], 
        Hue[0.008564162898874739, 1, 0.9881419282938658], 
        Hue[0.018968293162327066`, 1, 0.9737362094675472], 
        Hue[0.0021628179028306826`, 1, 0.997005329057619], 
        Hue[0.6499785002992392, 1, 0.100029768816438], 
        Hue[0.6499682293104806, 1, 0.10004399018548843`], 
        Hue[0.6499994806519499, 1, 0.10000071909730011`], 
        Hue[0.6499992967751281, 1, 0.10000097369597646`], 
        Hue[0.6499997221218345, 1, 0.10000038475438296`], 
        Hue[0.6499763120114476, 1, 0.10003279875338035`], 
        Hue[0.6496046189157263, 1, 0.10054745073207125`], 
        Hue[0.008564162897190086, 1, 0.9881419282961984], 
        Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
        Hue[0.6499990165514296, 1, 0.10000136169802062`], 
        Hue[0.6499682293104805, 1, 0.10004399018548858`], 
        Hue[0.6499569735915823, 1, 0.1000595750270399], 
        Hue[0.6499305639619215, 1, 0.10009614220657022`], 
        Hue[0.6493269366654801, 1, 0.10093193384779679`], 
        Hue[0.64507301626234, 1, 0.10682197748291383`], 
        Hue[0.64507301626234, 1, 0.10682197748291383`], 
        Hue[0.6123798420897152, 1, 0.15208944941424052`], 
        Hue[0.618916816969635, 1, 0.14303825342665927`], 
        Hue[0.6139274757407954, 1, 0.14994657205120632`], 
        Hue[0.6494794345021757, 1, 0.10072078299698756`], 
        Hue[0.649327839891267, 1, 0.10093068322747654`], 
        Hue[0.6498038432915922, 1, 0.10027160159625687`], 
        Hue[0.6314188285390578, 1, 0.12572777586899692`], 
        Hue[0.6276615081556767, 1, 0.13093021947675546`], 
        Hue[0.6499579058346595, 1, 0.10005828422893297`], 
        Hue[0.6499502404150022, 1, 0.10006889788692015`], 
        Hue[0.6363290967524697, 1, 0.1189289429581188], 
        Hue[0.6499389913540885, 1, 0.10008447350972371`], 
        Hue[0.6499205322569599, 1, 0.10011003225959408`], 
        Hue[0.6499309840236278, 1, 0.10009556058266918`], 
        Hue[0.6498945035414182, 1, 0.10014607201957479`], 
        Hue[0.6498817551107648, 1, 0.10016372369278714`], 
        Hue[0.6451848600758766, 1, 0.10666711681801709`], 
        Hue[0.6451848600758766, 1, 0.10666711681801709`], 
        Hue[0.6498948423987034, 1, 0.10014560283256446`], 
        Hue[0.6498821047507632, 1, 0.10016323957586633`], 
        Hue[0.6326369084383059, 1, 0.12404120370080722`], 
        Hue[0.6278460623886937, 1, 0.1306746828464241], 
        Hue[0.6343038838830548, 1, 0.12173308385423177`], 
        Hue[0.644391249173842, 1, 0.10776596268237253`], 
        Hue[0.6454889217763379, 1, 0.106246108309686], 
        Hue[0.6450814653729429, 1, 0.10681027871438688`], 
        Hue[0.6499513388525884, 1, 0.10006737697333923`], 
        Hue[0.6499329557399242, 1, 0.10009283051395125`], 
        Hue[0.6499430494131799, 1, 0.10007885465867404`], 
        Hue[0.6495806066420295, 1, 0.10058069849565142`], 
        Hue[0.649721046512853, 1, 0.10038624328989595`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6499070733798011, 1, 0.10012866762796763`], 
        Hue[0.6498941642091621, 1, 0.10014654186423706`], 
        Hue[0.6498880939419255, 1, 0.10015494684964163`], 
        Hue[0.6499317360308982, 1, 0.10009451934183332`], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499680543081146, 1, 0.10004423249645678`], 
        Hue[0.6499611431173056, 1, 0.10005380183757691`], 
        Hue[0.6498198123292014, 1, 0.10024949062110576`], 
        Hue[0.6498658977018641, 1, 0.10018568010511128`], 
        Hue[0.6499870926215222, 1, 0.1000178717548154], 
        Hue[0.6499969194200786, 1, 0.10000426541835268`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499145448836653, 1, 0.10011832246877124`], 
        Hue[0.6499924900042139, 1, 0.10001039845570384`], 
        Hue[0.6499902455567598, 1, 0.10001350615217874`], 
        Hue[0.6499943973499914, 1, 0.10000775751539649`], 
        Hue[0.6499384202733739, 1, 0.100085264236867], 
        Hue[0.6499448820990992, 1, 0.10007631709355508`], 
        Hue[0.6498985097083885, 1, 0.10014052501915438`], 
        Hue[0.6499505383206859, 1, 0.10006848540212712`], 
        Hue[0.6499565454836217, 1, 0.10006016779190842`], 
        Hue[0.6499694960336534, 1, 0.10004223626109526`], 
        Hue[0.6499981583263428, 1, 0.10000255000967932`], 
        Hue[0.6499989198255313, 1, 0.10000149562618747`], 
        Hue[0.6499996498839958, 1, 0.10000048477600589`], 
        Hue[0.649946398470897, 1, 0.10007421750183498`], 
        Hue[0.6499872378397605, 1, 0.1000176706834086], 
        Hue[0.6499812127959619, 1, 0.10002601305174515`], 
        Hue[0.6499807313906684, 1, 0.10002667961292078`], 
        Hue[0.649998744591033, 1, 0.10000173825856974`], 
        Hue[0.649998257978814, 1, 0.10000241202933446`], 
        Hue[0.6499991149582264, 1, 0.10000122544245589`], 
        Hue[0.6499883785355535, 1, 0.10001609125846449`], 
        Hue[0.6499955545015644, 1, 0.1000061553055262], 
        Hue[0.6499971445555819, 1, 0.10000395369227129`], 
        Hue[0.6499169012778275, 1, 0.10011505976916192`], 
        Hue[0.6499452554080251, 1, 0.10007580020427298`], 
        Hue[0.6499452554080251, 1, 0.10007580020427298`], 
        Hue[0.6499972861634967, 1, 0.10000375761977373`], 
        Hue[0.6499998069333369, 1, 0.10000026732307205`], 
        Hue[0.6499998959071556, 1, 0.10000014412855386`], 
        Hue[0.6499999143695201, 1, 0.1000001185652799], 
        Hue[0.6499998973914634, 1, 0.10000014207335849`], 
        Hue[0.649998299585341, 1, 0.10000235442029706`], 
        Hue[0.6499925368181951, 1, 0.10001033363634519`], 
        Hue[0.6499971170968787, 1, 0.10000399171201411`], 
        Hue[0.6499941827230284, 1, 0.1000080546911914], 
        Hue[0.6499998499361392, 1, 0.10000020778073027`], 
        Hue[0.6499997930401497, 1, 0.10000028655979275`], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.6499696557470173, 1, 0.10004201511951462`], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6498821047507631, 1, 0.1001632395758664], 
        Hue[0.6499504648283491, 1, 0.10006858716074747`], 
        Hue[0.6499993034614677, 1, 0.10000096443796776`], 
        Hue[0.6499996952446704, 1, 0.10000042196891794`], 
        Hue[0.6499997231111884, 1, 0.10000038338450845`], 
        Hue[0.6499764116330908, 1, 0.10003266081572036`], 
        Hue[0.6496050201873893, 1, 0.10054689512515333`], 
        Hue[0.6499835735373027, 1, 0.10002274433296544`], 
        Hue[0.6499763120114477, 1, 0.10003279875338018`], 
        Hue[0.6499996718109462, 1, 0.10000045441561291`], 
        Hue[0.6499997221218345, 1, 0.10000038475438296`], 
        Hue[0.0021628179019728133`, 1, 0.9970053290588069], 
        Hue[0.018968293159893457`, 1, 0.9737362094709167], 
        Hue[0.6499836181429695, 1, 0.10002268257127306`], 
        Hue[0.6499764116330907, 1, 0.10003266081572053`], 
        Hue[0.6499996739625998, 1, 0.1000004514364003], 
        Hue[0.6499997231111884, 1, 0.10000038338450845`], 
        Hue[0.6499994854782605, 1, 0.10000071241471627`], 
        Hue[0.6499993034614677, 1, 0.10000096443796776`], 
        Hue[0.6499581095157081, 1, 0.10005800220901966`], 
        Hue[0.6499504648283491, 1, 0.10006858716074744`], 
        Hue[0.6498945576128976, 1, 0.1001459971513726], 
        Hue[0.6499961977161761, 1, 0.10000526470067919`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.6499567540632241, 1, 0.10005987898938216`], 
        Hue[0.6499696557470173, 1, 0.1000420151195146], 
        Hue[0.6499998221998805, 1, 0.10000024618478089`], 
        Hue[0.6499852101793618, 1, 0.10002047821319134`], 
        Hue[0.6499979259072688, 1, 0.10000287182070478`], 
        Hue[0.6499979068548963, 1, 0.10000289820091286`], 
        Hue[0.6499298416416036, 1, 0.1000971423423951], 
        Hue[0.6497773350123875, 1, 0.10030830536746345`], 
        Hue[0.649832150775643, 1, 0.10023240661834047`], 
        Hue[0.649832150775643, 1, 0.10023240661834047`], 
        Hue[0.6497201201157683, 1, 0.10038752599355165`], 
        Hue[0.6499994159454975, 1, 0.1000008086908497], 
        Hue[0.6499994890716042, 1, 0.10000070743931735`], 
        Hue[0.6499995709517367, 1, 0.10000059406682617`], 
        Hue[0.6499836181429696, 1, 0.10002268257127296`], 
        Hue[0.649981784564363, 1, 0.10002522137242062`], 
        Hue[0.07116385446975892, 1, 0.9014654322726414], 
        Hue[0.07116385446975826, 1, 0.9014654322726423], 
        Hue[0.10275085519718585`, 1, 0.8577295851115889], 
        Hue[0.6450730162625566, 1, 0.10682197748261398`], 
        Hue[0.6450730162625566, 1, 0.10682197748261398`], 
        Hue[0.649649578370901, 1, 0.10048519917875254`], 
        Hue[0.6496211353704912, 1, 0.10052458179470464`], 
        Hue[0.6496149480434008, 1, 0.10053314886298349`], 
        Hue[0.6499997099087569, 1, 0.10000040166479822`], 
        Hue[0.649999693272125, 1, 0.10000042470013458`], 
        Hue[0.6499996487226951, 1, 0.10000048638396059`], 
        Hue[0.6499995670990851, 1, 0.10000059940126672`], 
        Hue[0.6499852320800056, 1, 0.1000204478892231], 
        Hue[0.6499835735373027, 1, 0.10002274433296553`], 
        Hue[0.6499817210220851, 1, 0.10002530935403613`], 
        Hue[0.6496523580230942, 1, 0.10048135042956187`], 
        Hue[0.6496214584224937, 1, 0.10052413449193183`], 
        Hue[0.6496153109565737, 1, 0.10053264636782111`], 
        Hue[0.6497703804347833, 1, 0.10031793478260782`], 
        Hue[0.649720148386843, 1, 0.10038748684898668`], 
        Hue[0.649969296003201, 1, 0.10004251322633716`], 
        Hue[0.6499715658257952, 1, 0.1000393703950529], 
        Hue[0.6499949427213864, 1, 0.10000700238577272`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6498226010526239, 1, 0.1002456293117515], 
        Hue[0.6499993787624871, 1, 0.1000008601750178], 
        Hue[0.6499997881961503, 1, 0.10000029326686882`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6498226656875892, 1, 0.10024553981718431`], 
        Hue[0.6499986816144642, 1, 0.10000182545689576`], 
        Hue[0.6499452554080252, 1, 0.10007580020427294`], 
        Hue[0.6499452554080252, 1, 0.10007580020427295`], 
        Hue[0.6483242391402425, 1, 0.1023202842673565], 
        Hue[0.6483242391402425, 1, 0.10232028426735655`], 
        Hue[0.6483242391402425, 1, 0.10232028426735651`], 
        Hue[0.6499906782378703, 1, 0.10001290705525658`], 
        Hue[0.644843834309606, 1, 0.1071393063405455], 
        Hue[0.6447609920664562, 1, 0.10725401098490685`], 
        Hue[0.6446427123917257, 1, 0.10741778284222608`], 
        Hue[0.6447410918958293, 1, 0.10728156506731333`], 
        Hue[0.6447410918958293, 1, 0.10728156506731332`], 
        Hue[0.6454301116847827, 1, 0.10632753766722401`], 
        Hue[0.6469166687904662, 1, 0.10426922782858536`], 
        Hue[0.6452016973298361, 1, 0.10664380369715003`], 
        Hue[0.6450803703104621, 1, 0.10681179495474484`], 
        Hue[0.6473254666988636, 1, 0.10370319995541974`], 
        Hue[0.6473386224356844, 1, 0.10368498431982166`], 
        Hue[0.6474431293251606, 1, 0.10354028247285457`], 
        Hue[0.648324239140247, 1, 0.10232028426735044`], 
        Hue[0.648324239140247, 1, 0.1023202842673504], 
        Hue[0.648324239140247, 1, 0.10232028426735042`], 
        Hue[0.6478300313592262, 1, 0.10300457196414826`], 
        Hue[0.6499979068548963, 1, 0.10000289820091286`], 
        Hue[0.6499768211371815, 1, 0.10003209381005644`], 
        Hue[0.6499892906359471, 1, 0.10001482835022706`], 
        Hue[0.6499998221998805, 1, 0.10000024618478089`], 
        Hue[0.6499893270949103, 1, 0.10001477786858572`], 
        Hue[0.6499965329720212, 1, 0.10000480050027838`], 
        Hue[0.6499942337059641, 1, 0.10000798409943434`], 
        Hue[0.6499906738504719, 1, 0.10001291313011582`], 
        Hue[0.6497970985365656, 1, 0.10028094048783229`], 
        Hue[0.6498802677343509, 1, 0.10016578313705254`], 
        Hue[0.6481847608283471, 1, 0.1025134080838272], 
        Hue[0.647847739448394, 1, 0.10298005307145443`], 
        Hue[0.6476673319658688, 1, 0.10322984804725865`], 
        Hue[0.6475036441269622, 1, 0.10345649274728327`], 
        Hue[0.6475036441269622, 1, 0.10345649274728327`], 
        Hue[0.6473254666988629, 1, 0.10370319995542056`], 
        Hue[0.6474431293251606, 1, 0.1035402824728547], 
        Hue[0.64691666879048, 1, 0.10426922782856618`], 
        Hue[0.643297066847292, 1, 0.10928098436528796`], 
        Hue[0.6450761923628352, 1, 0.10681757980530521`], 
        Hue[0.6425888456319467, 1, 0.11026159835576614`], 
        Hue[0.64355065154183, 1, 0.10892986709592774`], 
        Hue[0.6451837682394547, 1, 0.10666862859152434`], 
        Hue[0.6451837682394547, 1, 0.10666862859152436`], 
        Hue[0.6446427123916647, 1, 0.10741778284231042`], 
        Hue[0.6447410918957623, 1, 0.10728156506740608`], 
        Hue[0.6447410918957623, 1, 0.10728156506740608`], 
        Hue[0.6446754130693809, 1, 0.1073725049808572], 
        Hue[0.6448226855250837, 1, 0.10716858927296101`], 
        Hue[0.6448226855250837, 1, 0.10716858927296102`], 
        Hue[0.5959045810178848, 1, 0.17490134935985185`], 
        Hue[0.5991242399822707, 1, 0.17044336002454824`], 
        Hue[0.6448438343094491, 1, 0.1071393063407628], 
        Hue[0.5959045810185308, 1, 0.1749013493589574], 
        Hue[0.5991242399827919, 1, 0.17044336002382665`], 
        Hue[0.6448226855248735, 1, 0.10716858927325205`], 
        Hue[0.6425888456320292, 1, 0.11026159835565194`], 
        Hue[0.6435506515418995, 1, 0.10892986709583152`], 
        Hue[0.643297066847046, 1, 0.10928098436562861`], 
        Hue[0.6450761923626177, 1, 0.10681757980560624`], 
        Hue[0.6497970985365658, 1, 0.10028094048783215`], 
        Hue[0.649880267734351, 1, 0.10016578313705245`], 
        Hue[0.6499942337059641, 1, 0.10000798409943434`], 
        Hue[0.6499906738504719, 1, 0.10001291313011582`], 
        Hue[0.6499965329720212, 1, 0.10000480050027838`], 
        Hue[0.6499893270949103, 1, 0.10001477786858572`], 
        Hue[0.6499994700011782, 1, 0.10000073384452254`], 
        Hue[0.6499452847292683, 1, 0.10007575960562866`], 
        Hue[0.6499452847292683, 1, 0.10007575960562864`], 
        Hue[0.6499506956391089, 1, 0.10006826757661845`], 
        Hue[0.649997310025984, 1, 0.10000372457940669`], 
        Hue[0.6499963588136884, 1, 0.10000504164258524`], 
        Hue[0.6499996087792145, 1, 0.10000054169031843`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499313963608999, 1, 0.10009498965413857`], 
        Hue[0.6499418600005051, 1, 0.10008050153776214`], 
        Hue[0.6499820089674371, 1, 0.10002491066047176`], 
        Hue[0.6499885678296751, 1, 0.10001582915891155`], 
        Hue[0.649986680500004, 1, 0.10001844238460986`], 
        Hue[0.6499926102537842, 1, 0.10001023195629886`], 
        Hue[0.6499766758185227, 1, 0.100032295020507], 
        Hue[0.6499380881968964, 1, 0.10008572403506669`], 
        Hue[0.6355735873342747, 1, 0.11997503292177353`], 
        Hue[0.6383290297328666, 1, 0.11615980498526153`], 
        Hue[0.607541900540555, 1, 0.15878813771307765`], 
        Hue[0.566628613718335, 1, 0.2154373040823055], 
        Hue[0.6113350077370387, 1, 0.15353614313333103`], 
        Hue[0.6413526165411375, 1, 0.11197330017380966`], 
        Hue[0.649979910447695, 1, 0.10002781630319162`], 
        Hue[0.6499713297183559, 1, 0.1000396973130457], 
        Hue[0.649976389667182, 1, 0.1000326912300558], 
        Hue[0.6344958252613342, 1, 0.1214673188689219], 
        Hue[0.6497842792878252, 1, 0.10029869021685743`], 
        Hue[0.6499861817897983, 1, 0.10001913290643312`], 
        Hue[0.6499223977301634, 1, 0.1001074492966969], 
        Hue[0.6499968070349429, 1, 0.1000044210285406], 
        Hue[0.6499848535204814, 1, 0.10002097204856426`], 
        Hue[0.6499994103243372, 1, 0.1000008164739948], 
        Hue[0.6496495783709008, 1, 0.10048519917875282`], 
        Hue[0.6496211353704804, 1, 0.10052458179471949`], 
        Hue[0.6499986042640042, 1, 0.10000193255753263`], 
        Hue[0.6499223977301635, 1, 0.10010744929669671`], 
        Hue[0.0711638544660157, 1, 0.9014654322778244], 
        Hue[0.07116385446601503, 1, 0.9014654322778253], 
        Hue[0.6447609920662626, 1, 0.10725401098517487`], 
        Hue[0.6499931350584105, 1, 0.10000950530373938`], 
        Hue[0.6497842792878259, 1, 0.1002986902168565], 
        Hue[0.6499971946455725, 1, 0.10000388433689966`], 
        Hue[0.6499906782378703, 1, 0.10001290705525656`], 
        Hue[0.6499740052775556, 1, 0.10003599269261544`], 
        Hue[0.5666286137182638, 1, 0.215437304082404], 
        Hue[0.649979910447695, 1, 0.1000278163031916], 
        Hue[0.6499713297183559, 1, 0.10003969731304568`], 
        Hue[0.649976389667182, 1, 0.10003269123005579`], 
        Hue[0.649925810454061, 1, 0.10010272398668481`], 
        Hue[0.6424451989541748, 1, 0.11046049375575792`], 
        Hue[0.6413526165411441, 1, 0.11197330017380058`], 
        Hue[0.6150881106097981, 1, 0.14833953915566422`], 
        Hue[0.6228939004998529, 1, 0.13753152238481903`], 
        Hue[0.6427107986431155, 1, 0.11009274034030155`], 
        Hue[0.6355735873343954, 1, 0.11997503292160647`], 
        Hue[0.638329029732976, 1, 0.11615980498511017`], 
        Hue[0.649832150775643, 1, 0.1002324066183404], 
        Hue[0.6499766758185227, 1, 0.100032295020507], 
        Hue[0.6499822607431958, 1, 0.10002456204788279`], 
        Hue[0.649988567829675, 1, 0.10001582915891156`], 
        Hue[0.649986680500004, 1, 0.10001844238460987`], 
        Hue[0.6499915553675152, 1, 0.10001169256805592`], 
        Hue[0.6499418600005051, 1, 0.1000805015377621], 
        Hue[0.6499313963608999, 1, 0.10009498965413854`], 
        Hue[0.6499985526901774, 1, 0.10000200396744673`], 
        Hue[0.6499972861634967, 1, 0.10000375761977373`], 
        Hue[0.6499973394962008, 1, 0.10000368377449126`], 
        Hue[0.649998345225296, 1, 0.10000229122651329`], 
        Hue[0.6499993476936773, 1, 0.1000009031933699], 
        Hue[0.6499995636115868, 1, 0.10000060423011056`], 
        Hue[0.6499979259072688, 1, 0.10000287182070478`], 
        Hue[0.649997310025984, 1, 0.10000372457940668`], 
        Hue[0.649997310025984, 1, 0.10000372457940668`], 
        Hue[0.6499452847292683, 1, 0.10007575960562862`], 
        Hue[0.6499997355438514, 1, 0.10000036617005202`], 
        Hue[0.6499996943596676, 1, 0.10000042319430641`], 
        Hue[0.6499998525302062, 1, 0.10000020418894534`], 
        Hue[0.649999779338247, 1, 0.10000030553165791`], 
        Hue[0.6496214584225041, 1, 0.10052413449191748`], 
        Hue[0.10275085519977545`, 1, 0.8577295851080031], 
        Hue[0.6499996049868014, 1, 0.10000054694135192`], 
        Hue[0.6499996082984593, 1, 0.1000005423559795], 
        Hue[0.649832150775643, 1, 0.1002324066183404], 
        Hue[0.6499996709568588, 1, 0.10000045559819547`], 
        Hue[0.649999779338247, 1, 0.10000030553165791`], 
        Hue[0.6361358775823458, 1, 0.1191964771936751], 
        Hue[0.6361358775823456, 1, 0.11919647719367533`], 
        Hue[0.6499997114379519, 1, 0.10000039954745131`], 
        Hue[0.6499996514685767, 1, 0.10000048258197074`], 
        Hue[0.6498691588927477, 1, 0.1001811646100417], 
        Hue[0.6499509547899046, 1, 0.1000679087524398], 
        Hue[0.5936528925793111, 1, 0.17801907181326165`], 
        Hue[0.6448435305234992, 1, 0.10713972696746268`], 
        Hue[0.645136680417695, 1, 0.10673382711396075`], 
        Hue[0.6499996140825955, 1, 0.10000053434717537`], 
        Hue[0.6497253768389183, 1, 0.10038024745380555`], 
        Hue[0.6497432633695928, 1, 0.10035548148825621`], 
        Hue[0.6497376874239058, 1, 0.1003632020284381], 
        Hue[0.598578942259135, 1, 0.17119838764119769`], 
        Hue[0.5985789422591354, 1, 0.17119838764119716`], 
        Hue[0.6361358775824882, 1, 0.11919647719347792`], 
        Hue[0.6361358775824884, 1, 0.11919647719347777`], 
        Hue[0.6496475412721135, 1, 0.10048801977707356`], 
        Hue[0.6497575876165927, 1, 0.10033564791548695`], 
        Hue[0.6497176586044328, 1, 0.10039093424001616`], 
        Hue[0.6499102134211718, 1, 0.10012431987837749`], 
        Hue[0.6499402202393392, 1, 0.1000827719762997], 
        Hue[0.6499302912297339, 1, 0.10009651983575311`], 
        Hue[0.6499977899595798, 1, 0.10000306005596647`], 
        Hue[0.6499977899595798, 1, 0.10000306005596647`], 
        Hue[0.6499997881961503, 1, 0.10000029326686882`], 
        Hue[0.6499997070467911, 1, 0.10000040562752005`], 
        Hue[0.6499995636115868, 1, 0.10000060423011056`], 
        Hue[0.6449606118130902, 1, 0.10697761441264436`], 
        Hue[0.6449606118130902, 1, 0.10697761441264435`], 
        Hue[0.6446153322487039, 1, 0.10745569380948691`], 
        Hue[0.647503644126962, 1, 0.10345649274728334`], 
        Hue[0.647503644126962, 1, 0.10345649274728333`], 
        Hue[0.6499917724184623, 1, 0.10001139203597541`], 
        Hue[0.6499818441000457, 1, 0.10002513893839829`], 
        Hue[0.6499818441000457, 1, 0.10002513893839826`], 
        Hue[0.6499941069072821, 1, 0.10000815966684015`], 
        Hue[0.6499954637608208, 1, 0.10000628094655577`], 
        Hue[0.6425433794512151, 1, 0.1103245515290869], 
        Hue[0.6416068802400501, 1, 0.11162124274454605`], 
        Hue[0.033059327871870714`, 1, 0.9542255460235637], 
        Hue[0.05053038130689047, 1, 0.9300348566519978], 
        Hue[0.6499119444868918, 1, 0.10012192301814975`], 
        Hue[0.6498691588927481, 1, 0.1001811646100411], 
        Hue[0.649939804960482, 1, 0.10008334697779414`], 
        Hue[0.6499941069072821, 1, 0.10000815966684015`], 
        Hue[0.6499954637608208, 1, 0.10000628094655577`], 
        Hue[0.6499954637608208, 1, 0.10000628094655577`], 
        Hue[0.6499402202393393, 1, 0.10008277197629949`], 
        Hue[0.6499302912297341, 1, 0.10009651983575281`], 
        Hue[0.649757587616595, 1, 0.10033564791548386`], 
        Hue[0.649717658604436, 1, 0.1003909342400118], 
        Hue[0.6497282099863698, 1, 0.10037632463425723`], 
        Hue[0.6497476124961666, 1, 0.1003494596206924], 
        Hue[0.6497411112793049, 1, 0.10035846130557781`], 
        Hue[0.6499980775521905, 1, 0.10000266185081316`], 
        Hue[0.6499980775521905, 1, 0.10000266185081316`], 
        Hue[0.6499990826018167, 1, 0.1000012702436384], 
        Hue[0.6491923510353136, 1, 0.10111828318187353`], 
        Hue[0.6491923510353136, 1, 0.10111828318187355`], 
        Hue[0.6430994341869618, 1, 0.10955462958728375`], 
        Hue[0.6448435305234644, 1, 0.1071397269675108], 
        Hue[0.6465876268599798, 1, 0.1047248243477203], 
        Hue[0.6465876268599798, 1, 0.10472482434772026`], 
        Hue[0.5591705448255901, 1, 0.2257638610107214], 
        Hue[0.6051830845544243, 1, 0.1620541906169511], 
        Hue[0.6046239357498318, 1, 0.16282839665407917`], 
        Hue[0.6005020220421993, 1, 0.16853566178772414`], 
        Hue[0.6499949689168733, 1, 0.10000696611509867`], 
        Hue[0.6393277909144052, 1, 0.11477690488774678`], 
        Hue[0.639728945108811, 1, 0.11422146061856951`], 
        Hue[0.6411052738355187, 1, 0.11231577468928183`], 
        Hue[0.649968486457508, 1, 0.10004363413575815`], 
        Hue[0.6499767769522725, 1, 0.10003215498916111`], 
        Hue[0.649972676899105, 1, 0.10003783198585474`], 
        Hue[0.64998086534737, 1, 0.10002649413441077`], 
        Hue[0.6494791005751184, 1, 0.10072124535752844`], 
        Hue[0.6495813893887272, 1, 0.10057961469253159`], 
        Hue[0.6498553820677755, 1, 0.10020024021384928`], 
        Hue[0.6498884717547347, 1, 0.10015442372421353`], 
        Hue[0.6472339664152774, 1, 0.10382989265576983`], 
        Hue[0.6480087375848742, 1, 0.10275713257478956`], 
        Hue[0.6478300313592262, 1, 0.10300457196414828`], 
        Hue[0.6499948524777456, 1, 0.10000712733850615`], 
        Hue[0.6499975641411304, 1, 0.10000337272766563`], 
        Hue[0.643662976523736, 1, 0.1087743401979039], 
        Hue[0.6435436281016695, 1, 0.10893959185922679`], 
        Hue[0.6498946193265016, 1, 0.10014591170176698`], 
        Hue[0.6484137240052498, 1, 0.10219638214657721`], 
        Hue[0.649999065923293, 1, 0.10000129333697895`], 
        Hue[0.6499993569254062, 1, 0.10000089041097601`], 
        Hue[0.6499995531364383, 1, 0.10000061873416236`], 
        Hue[0.6499845305213169, 1, 0.10002141927817669`], 
        Hue[0.6499987610373165, 1, 0.10000171548679268`], 
        Hue[0.6499982793327067, 1, 0.10000238246240618`], 
        Hue[0.644297740872205, 1, 0.10789543571540844`], 
        Hue[0.6437766022656166, 1, 0.10861701224760785`], 
        Hue[0.6499998925666856, 1, 0.1000001487538201], 
        Hue[0.6499720083241632, 1, 0.10003875770500484`], 
        Hue[0.6499989806170189, 1, 0.10000141145335847`], 
        Hue[0.6499979189376313, 1, 0.1000028814709721], 
        Hue[0.6490732055840214, 1, 0.1012832538067396], 
        Hue[0.6487943291253612, 1, 0.10166939044180762`], 
        Hue[0.6486615686527496, 1, 0.1018532126346544], 
        Hue[0.6486721458807169, 1, 0.10183856724208436`], 
        Hue[0.6488754715936946, 1, 0.10155703933180743`], 
        Hue[0.6492211282544369, 1, 0.10107843780154896`], 
        Hue[0.6495635854272818, 1, 0.10060426633145604`], 
        Hue[0.6498036739551811, 1, 0.10027183606205689`], 
        Hue[0.6492205124027053, 1, 0.10107929051933126`], 
        Hue[0.6488751499378582, 1, 0.10155748470142709`], 
        Hue[0.6486721421475297, 1, 0.10183857241111285`], 
        Hue[0.6494481187205927, 1, 0.10076414330994858`], 
        Hue[0.64975855562808, 1, 0.10033430759188922`], 
        Hue[0.6499382721143278, 1, 0.10008546938016159`], 
        Hue[0.6497438699910106, 1, 0.10035464155090847`], 
        Hue[0.6493221359730589, 1, 0.10093858096038001`], 
        Hue[0.6487286338295368, 1, 0.1017603531591029], 
        Hue[0.6481845887416958, 1, 0.10251364635765203`], 
        Hue[0.6477867920179302, 1, 0.1030644418213274], 
        Hue[0.6474596176061952, 1, 0.10351745254526823`], 
        Hue[0.6472340635887639, 1, 0.10382975810786547`], 
        Hue[0.6471954778691708, 1, 0.10388318448884046`], 
        Hue[0.6474440549357112, 1, 0.1035390008582461], 
        Hue[0.6479727326168359, 1, 0.10280698560745806`], 
        Hue[0.6486308130734021, 1, 0.10189579728298169`], 
        Hue[0.6492993957289775, 1, 0.10097006745218497`], 
        Hue[0.6492984661033571, 1, 0.10097135462612099`], 
        Hue[0.6486298611368391, 1, 0.10189711534899212`], 
        Hue[0.6479722666001381, 1, 0.10280763086134728`], 
        Hue[0.6474700106798329, 1, 0.10350306213561597`], 
        Hue[0.6471976417124167, 1, 0.10388018839819235`], 
        Hue[0.6472266389834024, 1, 0.10384003833067365`], 
        Hue[0.6474600972735775, 1, 0.10351678839043123`], 
        Hue[0.647787115327827, 1, 0.10306399416147033`], 
        Hue[0.6481847142239625, 1, 0.102513472612975], 
        Hue[0.6487288669092454, 1, 0.10176003043335265`], 
        Hue[0.6493225788760636, 1, 0.10093796771006586`], 
        Hue[0.6497492556366449, 1, 0.10034718450310709`], 
        Hue[0.6499384202733739, 1, 0.100085264236867], 
        Hue[0.6499907772481441, 1, 0.1000127699641082], 
        Hue[0.6499169408087975, 1, 0.10011500503397273`], 
        Hue[0.6496669893384682, 1, 0.10046109168519789`], 
        Hue[0.6491243836319389, 1, 0.10121239189423845`], 
        Hue[0.6483881105564229, 1, 0.10223184692187601`], 
        Hue[0.6476673319658686, 1, 0.10322984804725902`], 
        Hue[0.6470649192956847, 1, 0.10406395789828284`], 
        Hue[0.646492840332535, 1, 0.10485606723187464`], 
        Hue[0.6459052314226442, 1, 0.10566967956864651`], 
        Hue[0.6453175862656999, 1, 0.10648334209364638`], 
        Hue[0.6448171573227068, 1, 0.10717624370702135`], 
        Hue[0.6445346715615721, 1, 0.10756737783782327`], 
        Hue[0.6445187656805075, 1, 0.10758940136545116`], 
        Hue[0.6446754130693914, 1, 0.10737250498084282`], 
        Hue[0.6448217876435393, 1, 0.10716983249356107`], 
        Hue[0.6448213068073135, 1, 0.10717049826679662`], 
        Hue[0.6446747005057164, 1, 0.1073734916074697], 
        Hue[0.6445188584205228, 1, 0.1075892729561992], 
        Hue[0.6445356096358542, 1, 0.10756607896574033`], 
        Hue[0.6448183521045389, 1, 0.10717458939371549`], 
        Hue[0.6453186380742251, 1, 0.10648188574338074`], 
        Hue[0.6459060748044555, 1, 0.10566851180921547`], 
        Hue[0.646493455942218, 1, 0.10485521484923671`], 
        Hue[0.647065445798343, 1, 0.10406322889460198`], 
        Hue[0.6476782205548365, 1, 0.10321477153945717`], 
        Hue[0.6483883164107922, 1, 0.10223156189274935`], 
        Hue[0.6491243444061467, 1, 0.10121244620687372`], 
        Hue[0.6496669043016357, 1, 0.10046120942850455`], 
        Hue[0.6499169012778275, 1, 0.10011505976916191`], 
        Hue[0.6499872761827474, 1, 0.1000176175931189], 
        Hue[0.6499506956391089, 1, 0.10006826757661845`], 
        Hue[0.6497831131736972, 1, 0.1003003048364193], 
        Hue[0.6493577841898452, 1, 0.10088922189098354`], 
        Hue[0.6486206497020778, 1, 0.1019098696432769], 
        Hue[0.6476640151146004, 1, 0.10323444061055342`], 
        Hue[0.6466285838488163, 1, 0.10466811467086985`], 
        Hue[0.645563391991172, 1, 0.1061429957045311], 
        Hue[0.6443899338329055, 1, 0.10776778392366933`], 
        Hue[0.6427084326690079, 1, 0.11009601630445065`], 
        Hue[0.6393231015822478, 1, 0.11478339780919544`], 
        Hue[0.6320807432698805, 1, 0.1248112785493963], 
        Hue[0.6197500814765424, 1, 0.14188450257094132`], 
        Hue[0.6042150040102856, 1, 0.1633946098319123], 
        Hue[0.595075849977109, 1, 0.1760488231086183], 
        Hue[0.5950760330681816, 1, 0.17604856959790252`], 
        Hue[0.6051860768200773, 1, 0.162050047479893], 
        Hue[0.6197571630575969, 1, 0.14187469730486596`], 
        Hue[0.6320881314564221, 1, 0.12480104875264642`], 
        Hue[0.6393277909144098, 1, 0.11477690488774024`], 
        Hue[0.642710798643102, 1, 0.1100927403403204], 
        Hue[0.6443912491738061, 1, 0.10776596268242239`], 
        Hue[0.6455644065284103, 1, 0.10614159096066272`], 
        Hue[0.6466294094583147, 1, 0.10466697151925652`], 
        Hue[0.64766440059411, 1, 0.10323390686969391`], 
        Hue[0.6486204310728412, 1, 0.10191017236068144`], 
        Hue[0.6493571286681643, 1, 0.10089012953638786`], 
        Hue[0.6497827013349246, 1, 0.10030087507471992`], 
        Hue[0.6499505383206859, 1, 0.10006848540212712`], 
        Hue[0.649992836251731, 1, 0.10000991903606476`], 
        Hue[0.6499987880908246, 1, 0.10000167802808904`], 
        Hue[0.6497848661512465, 1, 0.10029787763673556`], 
        Hue[0.6493623255583317, 1, 0.10088293384231], 
        Hue[0.6485080528944187, 1, 0.10206577291542022`], 
        Hue[0.6471334129224147, 1, 0.1039691205689644], 
        Hue[0.4134396293934205, 1, 0.42754512853218696`], 
        Hue[0.36992357537943527`, 1, 0.48779812639770503`], 
        Hue[0.560364425850268, 1, 0.22411079497655204`], 
        Hue[0.6471333502188614, 1, 0.10396920738926879`], 
        Hue[0.6485074236435838, 1, 0.10206664418580709`], 
        Hue[0.649993719165779, 1, 0.10000869653969073`], 
        Hue[0.6499645347886048, 1, 0.1000491056773164], 
        Hue[0.6498452129760711, 1, 0.10021432049467077`], 
        Hue[0.6494626278600213, 1, 0.10074405373227828`], 
        Hue[0.42072780205667315`, 1, 0.41745381253691416`], 
        Hue[0.2794714163724129, 1, 0.6130395773305052], 
        Hue[0.27950127825763316`, 1, 0.6129982301048157], 
        Hue[0.4207460109307008, 1, 0.4174286002497989], 
        Hue[0.5442403811400227, 1, 0.24643639534458395`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.6498321507756425, 1, 0.10023240661834114`], 
        Hue[0.649132833376689, 1, 0.10120069224766141`], 
        Hue[0.6465876268599643, 1, 0.10472482434774179`], 
        Hue[0.6363436379563803, 1, 0.11890880898347347`], 
        Hue[0.5985789422584301, 1, 0.17119838764217368`], 
        Hue[0.5054107485799124, 1, 0.3002005019662751], 
        Hue[0.35056984491302934`, 1, 0.5145955993511901], 
        Hue[0.1920257274160761, 1, 0.7341182235777408], 
        Hue[0.07116385446886986, 1, 0.9014654322738725], 
        Hue[0.07116385446585693, 1, 0.9014654322780442], 
        Hue[0.19202572741530333`, 1, 0.7341182235788108], 
        Hue[0.35056984491472737`, 1, 0.514595599348839], 
        Hue[0.5054107485816628, 1, 0.3002005019638515], 
        Hue[0.5998737256253059, 1, 0.16940561067265333`], 
        Hue[0.6361358775824969, 1, 0.11919647719346589`], 
        Hue[0.6465876268599808, 1, 0.10472482434771889`], 
        Hue[0.6491923510353136, 1, 0.10111828318187349`], 
        Hue[0.6498321507756426, 1, 0.10023240661834108`], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6498549379809121, 1, 0.10020085510335255`], 
        Hue[0.6494782446417727, 1, 0.1007224304960071], 
        Hue[0.6484645052704198, 1, 0.10212606962557269`], 
        Hue[0.6459417553415037, 1, 0.10561910798868726`], 
        Hue[0.6384789975532839, 1, 0.11595215723391462`], 
        Hue[0.6131190636395967, 1, 0.1510659118836354], 
        Hue[0.5442403811387878, 1, 0.24643639534629383`], 
        Hue[0.4207460109293239, 1, 0.41742860025170536`], 
        Hue[0.27950127825713017`, 1, 0.6129982301055121], 
        Hue[0.1666401527254356, 1, 0.7692674808417046], 
        Hue[0.10995731692870991`, 1, 0.8477514073294786], 
        Hue[0.10993697241483547`, 1, 0.8477795766563816], 
        Hue[0.16660070648733238`, 1, 0.7693220987098475], 
        Hue[0.27947141637245565`, 1, 0.613039577330446], 
        Hue[0.4207278020584586, 1, 0.4174538125344419], 
        Hue[0.5438542150957212, 1, 0.24697108679053995`], 
        Hue[0.6131150084109688, 1, 0.15107152681558167`], 
        Hue[0.63847840811195, 1, 0.11595297338345392`], 
        Hue[0.6459425149453757, 1, 0.10561805622947988`], 
        Hue[0.6484656021364827, 1, 0.10212455088794703`], 
        Hue[0.6494626278600188, 1, 0.10074405373228157`], 
        Hue[0.6498553820677755, 1, 0.1002002402138493], 
        Hue[0.649968486457508, 1, 0.10004363413575816`], 
        Hue[0.6499947516409308, 1, 0.10000726695871127`], 
        Hue[0.6499993476936773, 1, 0.1000009031933699], 
        Hue[0.6499903637000147, 1, 0.10001334256921046`], 
        Hue[0.6499461593618887, 1, 0.1000745485758465], 
        Hue[0.6497870627427598, 1, 0.1002948362023327], 
        Hue[0.6493634059128109, 1, 0.10088143796687715`], 
        Hue[0.648507423643595, 1, 0.10206664418579148`], 
        Hue[0.6471333502188961, 1, 0.10396920738922087`], 
        Hue[0.6452024257204935, 1, 0.1066427951562399], 
        Hue[0.6421328552372216, 1, 0.11089296967153926`], 
        Hue[0.6342357357137098, 1, 0.12182744285794023`], 
        Hue[0.6113350077370074, 1, 0.15353614313337435`], 
        Hue[0.560364425850219, 1, 0.22411079497661998`], 
        Hue[0.48758898573082615`, 1, 0.3248767889880869], 
        Hue[0.4148630973140133, 1, 0.4255741729498278], 
        Hue[0.37117736989834854`, 1, 0.4860621032176713], 
        Hue[0.3699235753804618, 1, 0.4877981263962837], 
        Hue[0.41343962939488754`, 1, 0.4275451285301558], 
        Hue[0.48756298968034234`, 1, 0.324912783519526], 
        Hue[0.5613439013174827, 1, 0.22275459817579318`], 
        Hue[0.6113184040198557, 1, 0.15355913289558448`], 
        Hue[0.6343038838830553, 1, 0.12173308385423123`], 
        Hue[0.642130743574499, 1, 0.11089589351223221`], 
        Hue[0.6452016973298363, 1, 0.10664380369714979`], 
        Hue[0.6471334129224495, 1, 0.10396912056891615`], 
        Hue[0.64850805289443, 1, 0.10206577291540458`], 
        Hue[0.6493623255583336, 1, 0.1008829338423074], 
        Hue[0.6497848661512468, 1, 0.1002978776367353], 
        Hue[0.649946398470897, 1, 0.100074217501835], 
        Hue[0.6499902459174384, 1, 0.10001350565277761`], 
        Hue[0.6499988168962403, 1, 0.10000163814366736`], 
        Hue[0.649992836251731, 1, 0.10000991903606475`], 
        Hue[0.648620431072842, 1, 0.10191017236068038`], 
        Hue[0.6476644005941145, 1, 0.1032339068696878], 
        Hue[0.6466294094583313, 1, 0.10466697151923365`], 
        Hue[0.639183848053694, 1, 0.11497621038719294`], 
        Hue[0.593969696312709, 1, 0.17758042049009526`], 
        Hue[0.6042150040106946, 1, 0.16339460983134596`], 
        Hue[0.6466285838488328, 1, 0.10466811467084695`], 
        Hue[0.6476640151146048, 1, 0.10323444061054728`], 
        Hue[0.6486206497020786, 1, 0.10190986964327584`], 
        Hue[0.6493577841898455, 1, 0.10088922189098325`], 
        Hue[0.649124344406147, 1, 0.1012124462068735], 
        Hue[0.6483883164107923, 1, 0.10223156189274908`], 
        Hue[0.6476782205548369, 1, 0.10321477153945663`], 
        Hue[0.6470654457983444, 1, 0.10406322889460017`], 
        Hue[0.6464934559422207, 1, 0.10485521484923278`], 
        Hue[0.6459060748044588, 1, 0.10566851180921094`], 
        Hue[0.6439828956080353, 1, 0.10833137531195104`], 
        Hue[0.6459052314226476, 1, 0.10566967956864184`], 
        Hue[0.6464928403325377, 1, 0.10485606723187091`], 
        Hue[0.6470649192956857, 1, 0.10406395789828136`], 
        Hue[0.6483881105564231, 1, 0.10223184692187579`], 
        Hue[0.6491243836319391, 1, 0.10121239189423821`], 
        Hue[0.6496669893384683, 1, 0.10046109168519775`], 
        Hue[0.6499907772481441, 1, 0.1000127699641082], 
        Hue[0.6497492556366449, 1, 0.10034718450310712`], 
        Hue[0.6493225788760636, 1, 0.10093796771006587`], 
        Hue[0.6487288669092454, 1, 0.10176003043335262`], 
        Hue[0.6481847142239626, 1, 0.10251347261297492`], 
        Hue[0.6477871153278271, 1, 0.10306399416147023`], 
        Hue[0.6479722666001457, 1, 0.10280763086133675`], 
        Hue[0.6486298611368615, 1, 0.10189711534896101`], 
        Hue[0.64863081307338, 1, 0.10189579728301236`], 
        Hue[0.6479727326168283, 1, 0.10280698560746845`], 
        Hue[0.64744405493571, 1, 0.10353900085824778`], 
        Hue[0.647195477869171, 1, 0.10388318448884022`], 
        Hue[0.647234063588764, 1, 0.10382975810786524`], 
        Hue[0.64778679201793, 1, 0.10306444182132772`], 
        Hue[0.6481845887416956, 1, 0.10251364635765228`], 
        Hue[0.6487286338295367, 1, 0.10176035315910302`], 
        Hue[0.6493221359730589, 1, 0.10093858096038005`], 
        Hue[0.649985101517905, 1, 0.10002062866751625`], 
        Hue[0.6499293875019, 1, 0.1000977711512155], 
        Hue[0.64975855562808, 1, 0.10033430759188924`], 
        Hue[0.6494481187205927, 1, 0.10076414330994854`], 
        Hue[0.6490820712669709, 1, 0.10127097824573265`], 
        Hue[0.6487973060787215, 1, 0.10166526850638562`], 
        Hue[0.6486665440965278, 1, 0.10184632355865385`], 
        Hue[0.6486721421475294, 1, 0.10183857241111316`], 
        Hue[0.648875149937858, 1, 0.10155748470142736`], 
        Hue[0.6492205124027052, 1, 0.10107929051933136`], 
        Hue[0.6495955370911407, 1, 0.10056002556611295`], 
        Hue[0.6498247725796036, 1, 0.10024262258208744`], 
        Hue[0.6499395617051161, 1, 0.10008368379291611`], 
        Hue[0.649939804960482, 1, 0.10008334697779414`], 
        Hue[0.6498036739551808, 1, 0.10027183606205746`], 
        Hue[0.6495635854272817, 1, 0.10060426633145621`], 
        Hue[0.649221128254437, 1, 0.10107843780154885`], 
        Hue[0.6488754715936949, 1, 0.10155703933180717`], 
        Hue[0.6486721458807171, 1, 0.10183856724208408`], 
        Hue[0.6486615686527497, 1, 0.10185321263465427`], 
        Hue[0.6487943291253612, 1, 0.10166939044180771`], 
        Hue[0.6490732055840213, 1, 0.1012832538067398], 
        Hue[0.6494608701931662, 1, 0.10074648742484674`], 
        Hue[0.6497686522347683, 1, 0.10032032767493616`], 
        Hue[0.6499979189376313, 1, 0.1000028814709721], 
        Hue[0.6499989806170189, 1, 0.10000141145335847`], 
        Hue[0.6499936916833658, 1, 0.10000873459226267`], 
        Hue[0.6499720083241632, 1, 0.10003875770500482`], 
        Hue[0.6499210378689576, 1, 0.10010933218144337`], 
        Hue[0.6498289592233316, 1, 0.10023682569077165`], 
        Hue[0.6497500661969323, 1, 0.100346062188863], 
        Hue[0.6497201201157683, 1, 0.10038752599355166`], 
        Hue[0.6497442349944514, 1, 0.10035413616152887`], 
        Hue[0.6498175387315116, 1, 0.10025263867944555`], 
        Hue[0.6499045423782822, 1, 0.10013217209160924`], 
        Hue[0.6499635376940699, 1, 0.10005048626974944`], 
        Hue[0.6499895375823748, 1, 0.10001448642440418`], 
        Hue[0.6499978738704448, 1, 0.10000294387169176`], 
        Hue[0.6499996049868014, 1, 0.10000054694135192`], 
        Hue[0.6499996082984593, 1, 0.1000005423559795], 
        Hue[0.6499977154256198, 1, 0.10000316325683417`], 
        Hue[0.6499887115763905, 1, 0.10001563012499778`], 
        Hue[0.6499637194211009, 1, 0.10005023464770653`], 
        Hue[0.649904864696231, 1, 0.10013172580521862`], 
        Hue[0.6498178986902057, 1, 0.10025214027509985`], 
        Hue[0.6497444578897739, 1, 0.1003538275372362], 
        Hue[0.649720148386843, 1, 0.1003874868489867], 
        Hue[0.6497498661728607, 1, 0.10034633914526989`], 
        Hue[0.6498285638060286, 1, 0.10023737319165268`], 
        Hue[0.649917969520653, 1, 0.10011358066371126`], 
        Hue[0.6499735114284139, 1, 0.10003667648373475`], 
        Hue[0.6499943973499914, 1, 0.10000775751539649`], 
        Hue[0.6499991149582264, 1, 0.10000122544245589`], 
        Hue[0.6499998925666856, 1, 0.1000001487538201], 
        Hue[0.6499993476880973, 1, 0.10000090320109607`], 
        Hue[0.6499796318088381, 1, 0.10002820211083958`], 
        Hue[0.6499326287044422, 1, 0.10009328333231075`], 
        Hue[0.6498492997424695, 1, 0.10020866189504221`], 
        Hue[0.6497585093987792, 1, 0.10033437160169031`], 
        Hue[0.6497220759135403, 1, 0.10038481796586742`], 
        Hue[0.6497395116100092, 1, 0.10036067623229504`], 
        Hue[0.649807523533853, 1, 0.10026650587620367`], 
        Hue[0.6498948423987034, 1, 0.10014560283256452`], 
        Hue[0.6499875975622534, 1, 0.1000171726061106], 
        Hue[0.6499971946455725, 1, 0.10000388433689966`], 
        Hue[0.6499994854782605, 1, 0.10000071241471627`], 
        Hue[0.6499996718109462, 1, 0.10000045441561291`], 
        Hue[0.6499983476490149, 1, 0.10000228787059483`], 
        Hue[0.649992139261425, 1, 0.10001088409956545`], 
        Hue[0.6499711752825617, 1, 0.10003991114722234`], 
        Hue[0.6499202363144329, 1, 0.10011044202616999`], 
        Hue[0.649752335400284, 1, 0.10034292021499139`], 
        Hue[0.6497216053983531, 1, 0.10038546944843423`], 
        Hue[0.6497446269774029, 1, 0.10035359341590382`], 
        Hue[0.6498180333025885, 1, 0.10025195388872375`], 
        Hue[0.6499074536869546, 1, 0.10012814104883222`], 
        Hue[0.6499685517490378, 1, 0.10004354373210154`], 
        Hue[0.6499926102537842, 1, 0.10001023195629886`], 
        Hue[0.6499987684026548, 1, 0.10000170528863186`], 
        Hue[0.6499998525302062, 1, 0.10000020418894534`], 
        Hue[0.6492162512642067, 1, 0.1010851905572524], 
        Hue[0.6488750409140394, 1, 0.10155763565748406`], 
        Hue[0.6486943253197311, 1, 0.10180785724960313`], 
        Hue[0.6486561461999452, 1, 0.10186072064622981`], 
        Hue[0.6488059954277985, 1, 0.10165323709997136`], 
        Hue[0.6491243397305977, 1, 0.10121245268071086`], 
        Hue[0.6497589618188889, 1, 0.10033374517384615`], 
        Hue[0.6493814166270159, 1, 0.10085650005490117`], 
        Hue[0.6487415025304525, 1, 0.10174253495783511`], 
        Hue[0.6487385095926334, 1, 0.10174667902558458`], 
        Hue[0.6489651538469169, 1, 0.10143286390426902`], 
        Hue[0.6493262593973558, 1, 0.10093287160366125`], 
        Hue[0.6496859288220751, 1, 0.10043486778481912`], 
        Hue[0.6498879983365086, 1, 0.10015507922637275`], 
        Hue[0.6499728188455073, 1, 0.10003763544468221`], 
        Hue[0.6484785424654154, 1, 0.10210663350942493`], 
        Hue[0.6472376528774046, 1, 0.10382478832359364`], 
        Hue[0.6483004248350253, 1, 0.10235325792073424`], 
        Hue[0.6485590288669325, 1, 0.10199519079963201`], 
        Hue[0.6499925368181951, 1, 0.1000103336363452], 
        Hue[0.649956754063224, 1, 0.10005987898938219`], 
        Hue[0.6498201909540227, 1, 0.10024896637135326`], 
        Hue[0.6494380510073331, 1, 0.1007780832206157], 
        Hue[0.6486312945647095, 1, 0.10189513060270997`], 
        Hue[0.6472945453822478, 1, 0.10374601408611843`], 
        Hue[0.6454301116847382, 1, 0.10632753766728567`], 
        Hue[0.6425869541066359, 1, 0.11026421739081178`], 
        Hue[0.6355677813921327, 1, 0.11998307191858565`], 
        Hue[0.6150728538407967, 1, 0.14836066391274305`], 
        Hue[0.49721716070329236`, 1, 0.3115454697954414], 
        Hue[0.4218615510022992, 1, 0.41588400630450884`], 
        Hue[0.3732101372974441, 1, 0.48324750220353896`], 
        Hue[0.3699389649357174, 1, 0.48777681778131443`], 
        Hue[0.4092648191988564, 1, 0.43332563495542964`], 
        Hue[0.4799251869009553, 1, 0.3354882027525234], 
        Hue[0.5547703620061858, 1, 0.23185642183758892`], 
        Hue[0.6075419005407393, 1, 0.15878813771282255`], 
        Hue[0.6416071963746115, 1, 0.11162080501976875`], 
        Hue[0.6449363081981523, 1, 0.10701126557178922`], 
        Hue[0.6469167021582444, 1, 0.10426918162704622`], 
        Hue[0.6483449140191484, 1, 0.10229165751194842`], 
        Hue[0.64926118126401, 1, 0.1010229797882938], 
        Hue[0.6497487056715416, 1, 0.10034794599325009`], 
        Hue[0.6499334733653315, 1, 0.10009211380184876`], 
        Hue[0.6499871546152928, 1, 0.10001778591728701`], 
        Hue[0.6499982837325233, 1, 0.10000237637035238`], 
        Hue[0.6499821959348161, 1, 0.10002465178256237`], 
        Hue[0.6499097362338683, 1, 0.10012498059925928`], 
        Hue[0.649644480283586, 1, 0.10049225806888096`], 
        Hue[0.6488721916036004, 1, 0.10156158085655329`], 
        Hue[0.6468897902012477, 1, 0.10430644433673392`], 
        Hue[0.6412672325871528, 1, 0.11209152411009617`], 
        Hue[0.622513680397445, 1, 0.1380579809881531], 
        Hue[0.5682104334557424, 1, 0.2132470921382028], 
        Hue[0.31803818591230487`, 1, 0.5596394348906548], 
        Hue[0.12317793669702404`, 1, 0.8294459338041205], 
        Hue[0.10551553715041861`, 1, 0.8539015639455743], 
        Hue[0.1447215641964955, 1, 0.7996162957279294], 
        Hue[0.23867664284349838`, 1, 0.6695246483705407], 
        Hue[0.3752505842358355, 1, 0.48042226798115084`], 
        Hue[0.5105339839090244, 1, 0.2931067915105816], 
        Hue[0.6333039763672068, 1, 0.12311757118386749`], 
        Hue[0.6492133707832681, 1, 0.10108917891547486`], 
        Hue[0.3180381859125545, 1, 0.5596394348903092], 
        Hue[0.3732101372984604, 1, 0.48324750220213175`], 
        Hue[0.6486312945647198, 1, 0.10189513060269574`], 
        Hue[0.6499544789815872, 1, 0.10006302910241772`], 
        Hue[0.6497967031430824, 1, 0.10028148795573212`], 
        Hue[0.6493843083159343, 1, 0.10085249617793722`], 
        Hue[0.6486670765987007, 1, 0.10184558624795291`], 
        Hue[0.6477258602117323, 1, 0.10314880893760145`], 
        Hue[0.6466982385822283, 1, 0.10457166965537625`], 
        Hue[0.6456433109470764, 1, 0.10603233868866352`], 
        Hue[0.6444863018191712, 1, 0.10763435132730144`], 
        Hue[0.6428823803202537, 1, 0.10985516571041797`], 
        Hue[0.6397468996933413, 1, 0.11419660042460432`], 
        Hue[0.6330024607854741, 1, 0.12353505429703592`], 
        Hue[0.6211966685594903, 1, 0.13988153584070584`], 
        Hue[0.6066857938393038, 1, 0.15997351622250255`], 
        Hue[0.5959049495707341, 1, 0.17490083905590664`], 
        Hue[0.5947857583630093, 1, 0.17645048842044875`], 
        Hue[0.6039331393082432, 1, 0.16378488403474026`], 
        Hue[0.6189100178908061, 1, 0.14304766753580686`], 
        Hue[0.6314113814489777, 1, 0.12573808722449245`], 
        Hue[0.6389584142500591, 1, 0.1152883494999182], 
        Hue[0.6442963774518267, 1, 0.10789732352823997`], 
        Hue[0.6454878932078376, 1, 0.10624753248145569`], 
        Hue[0.6465464412567902, 1, 0.10478185056752126`], 
        Hue[0.6475834488846897, 1, 0.10334599385196813`], 
        Hue[0.6485590288669337, 1, 0.10199519079963026`], 
        Hue[0.6493199214653448, 1, 0.10094164720183028`], 
        Hue[0.6497651749073808, 1, 0.10032514243593434`], 
        Hue[0.6499450533801044, 1, 0.10007607993524002`], 
        Hue[0.6499916808511504, 1, 0.10001151882148406`], 
        Hue[0.6492714389145247, 1, 0.10100877688758128`], 
        Hue[0.6485711159572851, 1, 0.10197845482837452`], 
        Hue[0.6478481526586202, 1, 0.10297948093421831`], 
        Hue[0.6472169204860098, 1, 0.10385349471167885`], 
        Hue[0.646645752668982, 1, 0.10464434245833251`], 
        Hue[0.6460978666860392, 1, 0.10540295381933042`], 
        Hue[0.645489117970712, 1, 0.10624583665593737`], 
        Hue[0.6449758474344328, 1, 0.10695651893693928`], 
        Hue[0.6446057461859066, 1, 0.10746896681951394`], 
        Hue[0.6447269791201302, 1, 0.10730110583366587`], 
        Hue[0.6448143518714197, 1, 0.10718012817803428`], 
        Hue[0.6446386253954922, 1, 0.1074234417600878], 
        Hue[0.6444502281867962, 1, 0.1076842994336668], 
        Hue[0.6444285208655675, 1, 0.10771435572459899`], 
        Hue[0.6457420223619782, 1, 0.10589566134495336`], 
        Hue[0.646907408335789, 1, 0.10428204999659998`], 
        Hue[0.6481847608283471, 1, 0.10251340808382711`], 
        Hue[0.6489306887868329, 1, 0.10148058475669296`], 
        Hue[0.6495445652662334, 1, 0.1006306019390615], 
        Hue[0.6498702683563081, 1, 0.10017962842972729`], 
        Hue[0.6499710158419191, 1, 0.10004013191118907`], 
        Hue[0.6495311358384767, 1, 0.1006491965313401], 
        Hue[0.6483894496489137, 1, 0.10222999279381192`], 
        Hue[0.6479788895815404, 1, 0.10279846057940568`], 
        Hue[0.6475978994814844, 1, 0.10332598533332932`], 
        Hue[0.6473189778091604, 1, 0.10371218457193178`], 
        Hue[0.6471883956275422, 1, 0.10389299066955707`], 
        Hue[0.6473203313841714, 1, 0.10371031039114721`], 
        Hue[0.6484128933058474, 1, 0.10219753234574976`], 
        Hue[0.6490074389437255, 1, 0.1013743153086879], 
        Hue[0.6483004248350057, 1, 0.10235325792076135`], 
        Hue[0.6476512819636975, 1, 0.10325207112718815`], 
        Hue[0.647177909117925, 1, 0.10390751045210388`], 
        Hue[0.6476302589163752, 1, 0.1032811799619421], 
        Hue[0.6484785424654151, 1, 0.10210663350942516`], 
        Hue[0.6490374185577825, 1, 0.10133280507383965`], 
        Hue[0.6495774352447521, 1, 0.10058508966111258`], 
        Hue[0.6487415025304523, 1, 0.10174253495783539`], 
        Hue[0.6497589618188885, 1, 0.10033374517384669`], 
        Hue[0.6494842522907944, 1, 0.10071411221274619`], 
        Hue[0.6488059954277987, 1, 0.10165323709997108`], 
        Hue[0.6486943253197311, 1, 0.10180785724960309`], 
        Hue[0.6498071763115433, 1, 0.10026698664555554`], 
        Hue[0.649995513367399, 1, 0.10000621226052449`], 
        Hue[0.6499724972674363, 1, 0.10003808070662663`], 
        Hue[0.6498868726098938, 1, 0.10015663792476255`], 
        Hue[0.649675283084229, 1, 0.10044960803722157`], 
        Hue[0.6493256084315968, 1, 0.10093377294086604`], 
        Hue[0.6499730201144907, 1, 0.10003735676455142`], 
        Hue[0.6499119335839733, 1, 0.10012193811449863`], 
        Hue[0.6497610653711238, 1, 0.10033083256305937`], 
        Hue[0.64948661714491, 1, 0.10071083779935544`], 
        Hue[0.6499921940479368, 1, 0.10001080824131829`], 
        Hue[0.6499768211371815, 1, 0.10003209381005643`], 
        Hue[0.6499709311885555, 1, 0.1000402491235386], 
        Hue[0.6498762763822666, 1, 0.10017130962455392`], 
        Hue[0.6498541257365453, 1, 0.1002019797493988], 
        Hue[0.6495774352447521, 1, 0.10058508966111254`], 
        Hue[0.6495306842520321, 1, 0.10064982180487864`], 
        Hue[0.6476302589163754, 1, 0.10328117996194178`], 
        Hue[0.6475974574857244, 1, 0.10332659732745854`], 
        Hue[0.6473386224356845, 1, 0.10368498431982145`], 
        Hue[0.6473184531260556, 1, 0.10371291105623075`], 
        Hue[0.6471779091179248, 1, 0.10390751045210418`], 
        Hue[0.6471877544905419, 1, 0.1038938783977113], 
        Hue[0.6495118930856678, 1, 0.1006758403429215], 
        Hue[0.6494787147610555, 1, 0.1007217795616155], 
        Hue[0.6490601902829448, 1, 0.10130127499284564`], 
        Hue[0.6490063830516062, 1, 0.10137577731316069`], 
        Hue[0.6473203313841713, 1, 0.10371031039114739`], 
        Hue[0.6472745253097466, 1, 0.10377373418650476`], 
        Hue[0.6471883956275424, 1, 0.10389299066955672`], 
        Hue[0.6471785610476428, 1, 0.1039066077801869], 
        Hue[0.6499710158419191, 1, 0.10004013191118907`], 
        Hue[0.6499768885403957, 1, 0.10003200048252905`], 
        Hue[0.6472164168884309, 1, 0.10385419200063425`], 
        Hue[0.6469074083357877, 1, 0.10428204999660161`], 
        Hue[0.6466451819682585, 1, 0.10464513265933437`], 
        Hue[0.6460736462773871, 1, 0.10543648976977178`], 
        Hue[0.6457420223619759, 1, 0.10589566134495648`], 
        Hue[0.6454881245503626, 1, 0.10624721216103636`], 
        Hue[0.6449747057502719, 1, 0.10695809973039276`], 
        Hue[0.6446604067397317, 1, 0.10739328297575611`], 
        Hue[0.6444285208656477, 1, 0.10771435572448775`], 
        Hue[0.6446054156460634, 1, 0.10746942449006598`], 
        Hue[0.6444502281869823, 1, 0.10768429943340925`], 
        Hue[0.6444500571988938, 1, 0.10768453618614703`], 
        Hue[0.6446057461857632, 1, 0.10746896681971264`], 
        Hue[0.6444293000046112, 1, 0.10771327691669219`], 
        Hue[0.6446614119197257, 1, 0.10739189118807217`], 
        Hue[0.6499916808511504, 1, 0.10001151882148407`], 
        Hue[0.6465464412567721, 1, 0.10478185056754641`], 
        Hue[0.645642311937682, 1, 0.1060337219324404], 
        Hue[0.6444850252642972, 1, 0.10763611886481932`], 
        Hue[0.6428801433477171, 1, 0.10985826305700704`], 
        Hue[0.6397424833007631, 1, 0.11420271542971269`], 
        Hue[0.6211894469842212, 1, 0.13989153494492462`], 
        Hue[0.6456433109470441, 1, 0.10603233868870826`], 
        Hue[0.6465472957244812, 1, 0.10478066745841058`], 
        Hue[0.6466982385822131, 1, 0.10457166965539727`], 
        Hue[0.6493843083159341, 1, 0.10085249617793748`], 
        Hue[0.6497647458011401, 1, 0.10032573658303683`], 
        Hue[0.6499916431084579, 1, 0.1000115710805968], 
        Hue[0.6416047567879677, 1, 0.11162418290896782`], 
        Hue[0.6075239849977159, 1, 0.15881294384931657`], 
        Hue[0.5547429134967014, 1, 0.23189442746610583`], 
        Hue[0.479900588293155, 1, 0.33552226236332383`], 
        Hue[0.6454307554303194, 1, 0.10632664632725011`], 
        Hue[0.6444510447211244, 1, 0.10768316884767408`], 
        Hue[0.6334576495991543, 1, 0.12290479286270953`], 
        Hue[0.5972152565878802, 1, 0.1730865678013966], 
        Hue[0.510520851349772, 1, 0.2931249750541619], 
        Hue[0.6225162151471804, 1, 0.1380544713346734], 
        Hue[0.6412672295637734, 1, 0.11209152829631382`], 
        Hue[0.6488711177040362, 1, 0.10156306779441146`], 
        Hue[0.6496468100677274, 1, 0.10048903221391596`], 
        Hue[0.6499821551229769, 1, 0.1000247082912629], 
        Hue[0.6499973236426885, 1, 0.10000370572550824`], 
        Hue[0.6499997033584459, 1, 0.10000041073445946`], 
        Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
        Hue[0.6499998652875634, 1, 0.10000018652491231`], 
        Hue[0.6499997033584459, 1, 0.10000041073445946`], 
        Hue[0.6499986685807253, 1, 0.10000184350361113`], 
        Hue[0.6499973236426885, 1, 0.10000370572550824`], 
        Hue[0.6499903486487819, 1, 0.10001336340937898`], 
        Hue[0.6499821551229769, 1, 0.10002470829126286`], 
        Hue[0.6499471992776279, 1, 0.10007310869251526`], 
        Hue[0.649776996090499, 1, 0.10030877464392456`], 
        Hue[0.6496468100677264, 1, 0.10048903221391733`], 
        Hue[0.6488711177040118, 1, 0.10156306779444513`], 
        Hue[0.644379238729608, 1, 0.10778259252823516`], 
        Hue[0.6412672295634195, 1, 0.11209152829680384`], 
        Hue[0.633303976366686, 1, 0.12311757118458871`], 
        Hue[0.6225162151465272, 1, 0.13805447133557772`], 
        Hue[0.45983657272858763`, 1, 0.36330320699118634`], 
        Hue[0.5105208513514405, 1, 0.2931249750518516], 
        Hue[0.5682104334567659, 1, 0.21324709213678578`], 
        Hue[0.597215256588433, 1, 0.17308656780063125`], 
        Hue[0.6225136803974861, 1, 0.13805798098809613`], 
        Hue[0.6334576495989711, 1, 0.12290479286296306`], 
        Hue[0.6412672325869223, 1, 0.11209152411041531`], 
        Hue[0.6444510447209125, 1, 0.10768316884796729`], 
        Hue[0.6469167021582841, 1, 0.1042691816269912], 
        Hue[0.6454307554303608, 1, 0.10632664632719284`], 
        Hue[0.47990058829466425`, 1, 0.33552226236123417`], 
        Hue[0.5547429134976741, 1, 0.23189442746475897`], 
        Hue[0.6075239849981009, 1, 0.15881294384878336`], 
        Hue[0.6416047567879696, 1, 0.11162418290896522`], 
        Hue[0.6497647458011402, 1, 0.10032573658303669`], 
        Hue[0.6465472957244994, 1, 0.10478066745838548`], 
        Hue[0.6211894469844126, 1, 0.1398915349446595], 
        Hue[0.6397424833007785, 1, 0.11420271542969126`], 
        Hue[0.642880143347735, 1, 0.10985826305698225`], 
        Hue[0.6444850252643324, 1, 0.10763611886477051`], 
        Hue[0.6456423119377144, 1, 0.10603372193239556`], 
        Hue[0.644742260288362, 1, 0.10727994729303722`], 
        Hue[0.6444293000047064, 1, 0.10771327691656032`], 
        Hue[0.6444500571991165, 1, 0.10768453618583873`], 
        Hue[0.6446054156459392, 1, 0.10746942449023812`], 
        Hue[0.6446604067396938, 1, 0.10739328297580855`], 
        Hue[0.6449747057502663, 1, 0.10695809973040055`], 
        Hue[0.6454881245503643, 1, 0.10624721216103405`], 
        Hue[0.6460736462773897, 1, 0.10543648976976815`], 
        Hue[0.64664518196826, 1, 0.10464513265933222`], 
        Hue[0.6472164168884312, 1, 0.10385419200063364`], 
        Hue[0.6499768885403957, 1, 0.10003200048252905`], 
        Hue[0.6471785610476426, 1, 0.10390660778018722`], 
        Hue[0.6472745253097466, 1, 0.10377373418650467`], 
        Hue[0.6490063830516288, 1, 0.1013757773131294], 
        Hue[0.6494787147610784, 1, 0.1007217795615837], 
        Hue[0.6471877544905421, 1, 0.103893878397711], 
        Hue[0.6473184531260556, 1, 0.10371291105623072`], 
        Hue[0.6475974574857242, 1, 0.10332659732745883`], 
        Hue[0.6495306842520321, 1, 0.10064982180487868`], 
        Hue[0.6498541257365453, 1, 0.10020197974939882`], 
        Hue[0.6499709311885555, 1, 0.1000402491235386], 
        Hue[0.6499955545015644, 1, 0.10000615530552621`], 
        Hue[0.6499921940479368, 1, 0.10001080824131829`], 
        Hue[0.6493814166270158, 1, 0.10085650005490124`], 
        Hue[0.64948661714491, 1, 0.1007108377993554], 
        Hue[0.6496976408126721, 1, 0.10041865118245408`], 
        Hue[0.649761065371124, 1, 0.10033083256305912`], 
        Hue[0.6498799412726705, 1, 0.10016623516091785`], 
        Hue[0.6499119335839736, 1, 0.10012193811449815`], 
        Hue[0.64996159366688, 1, 0.10005317799970473`], 
        Hue[0.649973020114491, 1, 0.10003735676455103`], 
        Hue[0.6492162512642065, 1, 0.10108519055725261`], 
        Hue[0.6493256084315966, 1, 0.10093377294086624`], 
        Hue[0.6496752830842288, 1, 0.10044960803722168`], 
        Hue[0.6498432245869254, 1, 0.10021707364887249`], 
        Hue[0.6498868726098938, 1, 0.10015663792476259`], 
        Hue[0.64995742655059, 1, 0.10005894785302934`], 
        Hue[0.6499724972674363, 1, 0.10003808070662665`], 
        Hue[0.6499921293089566, 1, 0.10001089787990629`], 
        Hue[0.649995513367399, 1, 0.10000621226052449`], 
        Hue[0.6497523354002839, 1, 0.10034292021499154`], 
        Hue[0.6498071763115432, 1, 0.10026698664555568`], 
        Hue[0.6497585093987792, 1, 0.10033437160169033`], 
        Hue[0.6499996894548788, 1, 0.10000042998555234`], 
        Hue[0.6499976810908947, 1, 0.10000321079722264`], 
        Hue[0.6499735114284139, 1, 0.10003667648373474`], 
        Hue[0.6499875385469106, 1, 0.10001725431966231`], 
        Hue[0.6499179695206531, 1, 0.10011358066371122`], 
        Hue[0.6499510653458983, 1, 0.10006775567491014`], 
        Hue[0.6498285638060287, 1, 0.10023737319165262`], 
        Hue[0.6498754872667991, 1, 0.10017240224597054`], 
        Hue[0.6497844884994874, 1, 0.10029840053917119`], 
        Hue[0.6497525816504375, 1, 0.10034257925324044`], 
        Hue[0.6498178986902056, 1, 0.10025214027509997`], 
        Hue[0.6499979498338926, 1, 0.10000283869153345`], 
        Hue[0.6499990931632785, 1, 0.10000125562007593`], 
        Hue[0.6499895375823748, 1, 0.10001448642440418`], 
        Hue[0.6499952798767935, 1, 0.100006535555209], 
        Hue[0.6499635376940699, 1, 0.10005048626974943`], 
        Hue[0.6499797919710948, 1, 0.1000279803477149], 
        Hue[0.6499045423782823, 1, 0.10013217209160918`], 
        Hue[0.649938736749848, 1, 0.10008482603867201`], 
        Hue[0.6498175387315117, 1, 0.10025263867944541`], 
        Hue[0.6498625824888394, 1, 0.10019027040006855`], 
        Hue[0.6497220805506988, 1, 0.10038481154518639`], 
        Hue[0.6497587426645933, 1, 0.10033404861825541`], 
        Hue[0.6498289592233316, 1, 0.10023682569077172`], 
        Hue[0.6499991804292786, 1, 0.10000113479022964`], 
        Hue[0.6499617603399277, 1, 0.10005294722163856`], 
        Hue[0.6491240599696748, 1, 0.10121284004198873`], 
        Hue[0.6499852101793618, 1, 0.10002047821319134`], 
        Hue[0.6499298416416036, 1, 0.1000971423423951], 
        Hue[0.6499657096233139, 1, 0.10004747898310386`], 
        Hue[0.6497686522347684, 1, 0.10032032767493607`], 
        Hue[0.6498661528906174, 1, 0.10018532676683745`], 
        Hue[0.6494608701931663, 1, 0.10074648742484657`], 
        Hue[0.6496322047027856, 1, 0.1005092550269123], 
        Hue[0.6499817210220851, 1, 0.10002530935403611`], 
        Hue[0.6499395617051158, 1, 0.1000836837929167], 
        Hue[0.6498247725796032, 1, 0.10024262258208783`], 
        Hue[0.6498942532833839, 1, 0.10014641853069925`], 
        Hue[0.6495955370911406, 1, 0.10056002556611304`], 
        Hue[0.6497259877549593, 1, 0.1003794015700564], 
        Hue[0.6486592242610939, 1, 0.10185645871540853`], 
        Hue[0.6486985272829319, 1, 0.10180203914670968`], 
        Hue[0.6488858529817219, 1, 0.10154266510223128`], 
        Hue[0.6492168120882641, 1, 0.10108441403163439`], 
        Hue[0.6498347039214942, 1, 0.10022887149331575`], 
        Hue[0.6499576702370821, 1, 0.10005861044096336`], 
        Hue[0.6499659179555519, 1, 0.100047190523082], 
        Hue[0.6499745865383855, 1, 0.10003518786992782`], 
        Hue[0.6498668777824628, 1, 0.10018432307043619`], 
        Hue[0.6494794345021984, 1, 0.10072078299695619`], 
        Hue[0.64951254449455, 1, 0.1006749383921616], 
        Hue[0.6494921178874883, 1, 0.10070322138655469`], 
        Hue[0.6490365748044895, 1, 0.10133397334762992`], 
        Hue[0.6484128933058365, 1, 0.10219753234576491`], 
        Hue[0.6483395074792844, 1, 0.10229914349022172`], 
        Hue[0.6489814055841804, 1, 0.10141036149882726`], 
        Hue[0.6490500614364055, 1, 0.10131529954959236`], 
        Hue[0.6495311358384767, 1, 0.10064919653134007`], 
        Hue[0.6495778694437395, 1, 0.1005844884625145], 
        Hue[0.6498543989283845, 1, 0.10020160148377538`], 
        Hue[0.6498765165910504, 1, 0.10017097702777641`], 
        Hue[0.6499746602037513, 1, 0.10003508587172912`], 
        Hue[0.6490074389437478, 1, 0.10137431530865688`], 
        Hue[0.6490612179653654, 1, 0.1012998520479556], 
        Hue[0.6496523174518567, 1, 0.1004814066051215], 
        Hue[0.6477602551397625, 1, 0.10310118519109808`], 
        Hue[0.6476889012124347, 1, 0.10319998293662894`], 
        Hue[0.6473189778091605, 1, 0.10371218457193164`], 
        Hue[0.6473382110820157, 1, 0.1036855538864398], 
        Hue[0.6475978994814844, 1, 0.10332598533332936`], 
        Hue[0.6476306747916085, 1, 0.10328060413469597`], 
        Hue[0.6483894496489135, 1, 0.10222999279381198`], 
        Hue[0.648454805069711, 1, 0.10213950067270793`], 
        Hue[0.6472169204860091, 1, 0.10385349471167978`], 
        Hue[0.64784815265862, 1, 0.10297948093421863`], 
        Hue[0.6481850644702216, 1, 0.10251298765661626`], 
        Hue[0.6489327307650269, 1, 0.1014777574022705], 
        Hue[0.649870268356308, 1, 0.10017962842972737`], 
        Hue[0.6497422679611429, 1, 0.10035685974610997`], 
        Hue[0.6495445652662333, 1, 0.10063060193906168`], 
        Hue[0.6492714988092747, 1, 0.1010086939563889], 
        Hue[0.6446378483465082, 1, 0.1074245176740656], 
        Hue[0.6449758474344249, 1, 0.10695651893695021`], 
        Hue[0.6454891179707094, 1, 0.10624583665594087`], 
        Hue[0.6457429134754836, 1, 0.10589442749548424`], 
        Hue[0.6466457526689804, 1, 0.1046443424583349], 
        Hue[0.6469079421014989, 1, 0.10428131093638608`], 
        Hue[0.6499800978129978, 1, 0.10002755687431077`], 
        Hue[0.6498908903541091, 1, 0.10015107489431062`], 
        Hue[0.6497651749073807, 1, 0.10032514243593448`], 
        Hue[0.6493848462505366, 1, 0.10085175134541088`], 
        Hue[0.6450042018600114, 1, 0.10691725896306116`], 
        Hue[0.6436612706901785, 1, 0.10877670212129127`], 
        Hue[0.6413492538797367, 1, 0.11197795616651847`], 
        Hue[0.6363229297017741, 1, 0.11893748195138976`], 
        Hue[0.6264945721377247, 1, 0.13254597704007343`], 
        Hue[0.6123745783731487, 1, 0.15209673763717874`], 
        Hue[0.6444863018191366, 1, 0.10763435132734933`], 
        Hue[0.6460988378740803, 1, 0.10540160909742732`], 
        Hue[0.6471452171056709, 1, 0.10395277631522504`], 
        Hue[0.6477258602117284, 1, 0.10314880893760692`], 
        Hue[0.6485606730077377, 1, 0.1019929142969787], 
        Hue[0.6498906156449326, 1, 0.10015145526086258`], 
        Hue[0.6499800210545625, 1, 0.10002766315522109`], 
        Hue[0.6499272404251578, 1, 0.10010074402670452`], 
        Hue[0.5947858976871175, 1, 0.17645029551014493`], 
        Hue[0.5959049495699404, 1, 0.1749008390570056], 
        Hue[0.6039357705137042, 1, 0.16378124082717888`], 
        Hue[0.6211966685590604, 1, 0.13988153584130092`], 
        Hue[0.6386880733811215, 1, 0.11566266762613948`], 
        Hue[0.6428823803202386, 1, 0.10985516571043896`], 
        Hue[0.6442709715647295, 1, 0.10793250091037464`], 
        Hue[0.647305180926357, 1, 0.10373128794812109`], 
        Hue[0.6493194313649147, 1, 0.10094232580242588`], 
        Hue[0.6499964589486245, 1, 0.1000049029942124], 
        Hue[0.6421307435744927, 1, 0.11089589351224086`], 
        Hue[0.6439216662082725, 1, 0.10841615448085354`], 
        Hue[0.6392482971262327, 1, 0.11488697320983171`], 
        Hue[0.6113184040195201, 1, 0.1535591328960491], 
        Hue[0.6255259248970978, 1, 0.1338871809117108], 
        Hue[0.561343901316591, 1, 0.22275459817702792`], 
        Hue[0.5900825238500264, 1, 0.18296265928457897`], 
        Hue[0.487562989678903, 1, 0.324912783521519], 
        Hue[0.5262450270724396, 1, 0.2713530394381607], 
        Hue[0.3747741167538307, 1, 0.48108199218700365`], 
        Hue[0.49507930341202766`, 1, 0.3145055798910387], 
        Hue[0.6392520089619881, 1, 0.11488183374493961`], 
        Hue[0.643922915936966, 1, 0.1084144240872778], 
        Hue[0.6486346449067806, 1, 0.10189049166753458`], 
        Hue[0.649363405912809, 1, 0.10088143796687978`], 
        Hue[0.6497870627427595, 1, 0.10029483620233297`], 
        Hue[0.6496196896792591, 1, 0.10052658352102598`], 
        Hue[0.6499461593618886, 1, 0.10007454857584652`], 
        Hue[0.6498899253776141, 1, 0.1001524110156112], 
        Hue[0.6499763529684163, 1, 0.10003274204373136`], 
        Hue[0.6499964290356581, 1, 0.10000494441216566`], 
        Hue[0.64999986712212, 1, 0.10000018398475698`], 
        Hue[0.4598523370130971, 1, 0.36328137952032713`], 
        Hue[0.5682182330627773, 1, 0.21323629268230834`], 
        Hue[0.6479045331466449, 1, 0.10290141564310716`], 
        Hue[0.638478408112191, 1, 0.11595297338312012`], 
        Hue[0.6131150084107319, 1, 0.15107152681590974`], 
        Hue[0.5438542150943324, 1, 0.24697108679246285`], 
        Hue[0.23864305325628815`, 1, 0.6695711570297549], 
        Hue[0.14468550878889286`, 1, 0.7996662185999945], 
        Hue[0.12320664814348603`, 1, 0.8294061794936347], 
        Hue[0.1969400522797311, 1, 0.7273137737665262], 
        Hue[0.31924359861640145`, 1, 0.5579704019157519], 
        Hue[0.6468888344263154, 1, 0.10430776771740956`], 
        Hue[0.6484645052704583, 1, 0.10212606962551937`], 
        Hue[0.6494782446417755, 1, 0.10072243049600321`], 
        Hue[0.6490857182415478, 1, 0.1012659285886261], 
        Hue[0.6498549379809119, 1, 0.10020085510335289`], 
        Hue[0.6499692960032009, 1, 0.1000425132263373], 
        Hue[0.6499949427213864, 1, 0.10000700238577273`], 
        Hue[0.6499993787624871, 1, 0.1000008601750178], 
        Hue[0.6499999454587057, 1, 0.10000007551871525`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.6499289484739933, 1, 0.10009837903600931`], 
        Hue[0.6499289484739933, 1, 0.10009837903600931`], 
        Hue[0.6496234965987948, 1, 0.10052131240166877`], 
        Hue[0.6496234965987948, 1, 0.10052131240166878`], 
        Hue[0.26072995684113986`, 1, 0.6389892905276525], 
        Hue[0.26072995684113764`, 1, 0.6389892905276556], 
        Hue[0.12170305563831885`, 1, 0.8314880768084816], 
        Hue[0.12170305563831718`, 1, 0.8314880768084838], 
        Hue[0.033059327874478295`, 1, 0.9542255460199531], 
        Hue[0.03305932787447752, 1, 0.9542255460199542], 
        Hue[0.03305932787175303, 1, 0.9542255460237266], 
        Hue[0.03305932787175392, 1, 0.9542255460237254], 
        Hue[0.1217030556359836, 1, 0.831488076811715], 
        Hue[0.12170305563598527`, 1, 0.8314880768117127], 
        Hue[0.2607299568417166, 1, 0.6389892905268539], 
        Hue[0.26072995684171885`, 1, 0.6389892905268508], 
        Hue[0.4280417126324534, 1, 0.40732685943198765`], 
        Hue[0.4280417126324556, 1, 0.40732685943198454`], 
        Hue[0.559170544826714, 1, 0.22576386100916526`], 
        Hue[0.5591705448267154, 1, 0.22576386100916337`], 
        Hue[0.649623496598795, 1, 0.10052131240166846`], 
        Hue[0.649623496598795, 1, 0.10052131240166845`], 
        Hue[0.6499289484739933, 1, 0.1000983790360093], 
        Hue[0.6499289484739933, 1, 0.1000983790360093], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.5591705448254742, 1, 0.22576386101088186`], 
        Hue[0.5591705448254729, 1, 0.22576386101088372`], 
        Hue[0.42804171263043833`, 1, 0.40732685943477775`], 
        Hue[0.42804171263043606`, 1, 0.40732685943478086`], 
        Hue[0.6490857182415353, 1, 0.10126592858864356`], 
        Hue[0.6432968085982096, 1, 0.10928134194094068`], 
        Hue[0.6294670107067198, 1, 0.12843029286761867`], 
        Hue[0.5972214239233667, 1, 0.17307802841379993`], 
        Hue[0.5682182330616764, 1, 0.21323629268383273`], 
        Hue[0.510533983907657, 1, 0.2931067915124749], 
        Hue[0.45985233701165773`, 1, 0.3632813795223201], 
        Hue[0.3752505842345883, 1, 0.4804222679828778], 
        Hue[0.3192435986155256, 1, 0.5579704019169646], 
        Hue[0.2386766428429961, 1, 0.6695246483712362], 
        Hue[0.14472156419534377`, 1, 0.7996162957295241], 
        Hue[0.12320664814153293`, 1, 0.829406179496339], 
        Hue[0.12317793669330279`, 1, 0.8294459338092731], 
        Hue[0.14468550878552755`, 1, 0.7996662186046541], 
        Hue[0.23864305325551322`, 1, 0.6695711570308279], 
        Hue[0.6499999454587057, 1, 0.10000007551871525`], 
        Hue[0.6479034511561872, 1, 0.10290291378374081`], 
        Hue[0.6468888344261868, 1, 0.10430776771758747`], 
        Hue[0.10550699045016398`, 1, 0.8539133978382344], 
        Hue[0.6468897902011316, 1, 0.10430644433689479`], 
        Hue[0.6479045331465781, 1, 0.1029014156431996], 
        Hue[0.6488721916035768, 1, 0.10156158085658602`], 
        Hue[0.6499997070467911, 1, 0.10000040562752005`], 
        Hue[0.64999986712212, 1, 0.10000018398475698`], 
        Hue[0.6499964290356581, 1, 0.10000494441216566`], 
        Hue[0.6499763529684163, 1, 0.10003274204373135`], 
        Hue[0.6498899253776143, 1, 0.10015241101561112`], 
        Hue[0.6496196896792596, 1, 0.10052658352102511`], 
        Hue[0.6462369452811769, 1, 0.10521038345683198`], 
        Hue[0.6439229159369845, 1, 0.10841442408725223`], 
        Hue[0.6416071963745702, 1, 0.11162080501982595`], 
        Hue[0.6327196532761324, 1, 0.12392663392535516`], 
        Hue[0.5262450270736306, 1, 0.27135303943651146`], 
        Hue[0.5900825238506201, 1, 0.18296265928375688`], 
        Hue[0.6255259248972422, 1, 0.13388718091151078`], 
        Hue[0.6392482971262292, 1, 0.11488697320983655`], 
        Hue[0.6439216662083033, 1, 0.10841615448081084`], 
        Hue[0.6499964589486245, 1, 0.1000049029942124], 
        Hue[0.6492611812640128, 1, 0.1010229797882901], 
        Hue[0.6486346449067905, 1, 0.10189049166752093`], 
        Hue[0.6473051809263888, 1, 0.10373128794807712`], 
        Hue[0.6442709715647609, 1, 0.10793250091033112`], 
        Hue[0.5547703620062218, 1, 0.23185642183753913`], 
        Hue[0.49507930341255957`, 1, 0.31450557989030214`], 
        Hue[0.47992518690165575`, 1, 0.33548820275155355`], 
        Hue[0.4092648191999626, 1, 0.433325634953898], 
        Hue[0.37477411675478794`, 1, 0.48108199218567826`], 
        Hue[0.36993665875162945`, 1, 0.48778001095928225`], 
        Hue[0.6498201909540229, 1, 0.10024896637135305`], 
        Hue[0.6499272404251579, 1, 0.10010074402670448`], 
        Hue[0.6493848462505368, 1, 0.10085175134541062`], 
        Hue[0.6499800210545625, 1, 0.10002766315522107`], 
        Hue[0.6497827013349247, 1, 0.1003008750747198], 
        Hue[0.6498906156449327, 1, 0.10015145526086251`], 
        Hue[0.6493194313649149, 1, 0.10094232580242558`], 
        Hue[0.6485606730077386, 1, 0.10199291429697735`], 
        Hue[0.64714521710568, 1, 0.10395277631521234`], 
        Hue[0.6386880733811489, 1, 0.11566266762610168`], 
        Hue[0.6039357705144809, 1, 0.16378124082610337`], 
        Hue[0.6197500814767566, 1, 0.14188450257064478`], 
        Hue[0.6123745783734561, 1, 0.15209673763675313`], 
        Hue[0.6320807432699584, 1, 0.12481127854928835`], 
        Hue[0.626494572137861, 1, 0.1325459770398848], 
        Hue[0.6393231015822664, 1, 0.11478339780916977`], 
        Hue[0.6363229297018136, 1, 0.1189374819513351], 
        Hue[0.6427084326690243, 1, 0.11009601630442789`], 
        Hue[0.6413492538797488, 1, 0.1119779561665016], 
        Hue[0.64438993383294, 1, 0.10776778392362159`], 
        Hue[0.6436612706902045, 1, 0.10877670212125537`], 
        Hue[0.6450042018600488, 1, 0.10691725896300931`], 
        Hue[0.6499800978129978, 1, 0.10002755687431074`], 
        Hue[0.6481850644702218, 1, 0.10251298765661598`], 
        Hue[0.6469079421015004, 1, 0.10428131093638413`], 
        Hue[0.6492714988092749, 1, 0.10100869395638867`], 
        Hue[0.6497422679611429, 1, 0.10035685974610985`], 
        Hue[0.6499452847292683, 1, 0.10007575960562862`], 
        Hue[0.6499786432660215, 1, 0.10002957086243183`], 
        Hue[0.6489327307650271, 1, 0.10147775740227026`], 
        Hue[0.645742913475486, 1, 0.10589442749548096`], 
        Hue[0.6451848600758786, 1, 0.10666711681801426`], 
        Hue[0.6448183521045512, 1, 0.10717458939369848`], 
        Hue[0.6445356096359176, 1, 0.10756607896565253`], 
        Hue[0.6445188584207069, 1, 0.10758927295594438`], 
        Hue[0.6446378483467755, 1, 0.10742451767369551`], 
        Hue[0.6445187656803508, 1, 0.10758940136566814`], 
        Hue[0.6445346715615177, 1, 0.1075673778378987], 
        Hue[0.6448171573226968, 1, 0.1071762437070351], 
        Hue[0.6453175862657006, 1, 0.10648334209364543`], 
        Hue[0.6499872851621001, 1, 0.10001760516016903`], 
        Hue[0.6498765165910504, 1, 0.10017097702777644`], 
        Hue[0.6495778694437395, 1, 0.10058448846251454`], 
        Hue[0.6490500614364055, 1, 0.10131529954959238`], 
        Hue[0.648454805069711, 1, 0.1021395006727079], 
        Hue[0.6495125444945283, 1, 0.10067493839219152`], 
        Hue[0.6490612179653426, 1, 0.10129985204798726`], 
        Hue[0.6499746602037512, 1, 0.10003508587172912`], 
        Hue[0.6498671323084145, 1, 0.10018397064988765`], 
        Hue[0.6476306747916085, 1, 0.10328060413469592`], 
        Hue[0.6473382110820156, 1, 0.10368555388643992`], 
        Hue[0.6472266389834022, 1, 0.10384003833067391`], 
        Hue[0.6471976417124164, 1, 0.10388018839819263`], 
        Hue[0.6476889012124372, 1, 0.10319998293662551`], 
        Hue[0.6483395074792947, 1, 0.10229914349020733`], 
        Hue[0.6483775520143936, 1, 0.10224646644160888`], 
        Hue[0.6492984661033829, 1, 0.10097135462608528`], 
        Hue[0.6490365748045124, 1, 0.10133397334759822`], 
        Hue[0.6494921178875113, 1, 0.10070322138652285`], 
        Hue[0.6496153109565739, 1, 0.10053264636782082`], 
        Hue[0.6497438699910105, 1, 0.1003546415509085], 
        Hue[0.6499382721143278, 1, 0.10008546938016159`], 
        Hue[0.6498668777824628, 1, 0.10018432307043622`], 
        Hue[0.6499745865383855, 1, 0.10003518786992784`], 
        Hue[0.6499728188455073, 1, 0.10003763544468222`], 
        Hue[0.6499576702370821, 1, 0.10005861044096337`], 
        Hue[0.6498879983365086, 1, 0.10015507922637276`], 
        Hue[0.6498347039214942, 1, 0.10022887149331577`], 
        Hue[0.6494358636771683, 1, 0.10078111183161306`], 
        Hue[0.6497259877549595, 1, 0.10037940157005618`], 
        Hue[0.6498942532833842, 1, 0.10014641853069874`], 
        Hue[0.6499731374090267, 1, 0.10003719435673221`], 
        Hue[0.6499617603399274, 1, 0.10005294722163902`], 
        Hue[0.6496322047027855, 1, 0.10050925502691242`], 
        Hue[0.6498661528906173, 1, 0.1001853267668375], 
        Hue[0.6499657096233139, 1, 0.10004747898310387`], 
        Hue[0.6493262593973559, 1, 0.10093287160366116`], 
        Hue[0.6492168120882642, 1, 0.10108441403163429`], 
        Hue[0.648885852981722, 1, 0.10154266510223121`], 
        Hue[0.6487385095926334, 1, 0.10174667902558462`], 
        Hue[0.6486985272829319, 1, 0.10180203914670978`], 
        Hue[0.648661418574052, 1, 0.10185342043592793`], 
        Hue[0.6486592242610937, 1, 0.10185645871540881`], 
        Hue[0.6490246129733722, 1, 0.10135053588302306`], 
        Hue[0.6491240599696747, 1, 0.1012128400419889], 
        Hue[0.6499852500802348, 1, 0.10002042296582875`], 
        Hue[0.6497760637592552, 1, 0.10031006556410822`], 
        Hue[0.6498625824888393, 1, 0.10019027040006864`], 
        Hue[0.649938736749848, 1, 0.10008482603867204`], 
        Hue[0.6499797919710948, 1, 0.1000279803477149], 
        Hue[0.6499952798767935, 1, 0.100006535555209], 
        Hue[0.6499990931632785, 1, 0.10000125562007593`], 
        Hue[0.6497844884994874, 1, 0.10029840053917125`], 
        Hue[0.649875487266799, 1, 0.10017240224597061`], 
        Hue[0.6499510653458982, 1, 0.10006775567491018`], 
        Hue[0.6499875385469106, 1, 0.10001725431966232`], 
        Hue[0.6499976810908947, 1, 0.10000321079722264`], 
        Hue[0.6499996894548788, 1, 0.10000042998555234`], 
        Hue[0.6499991804292786, 1, 0.10000113479022964`], 
        Hue[0.6499685517490378, 1, 0.10004354373210152`], 
        Hue[0.6497587426645933, 1, 0.1003340486182554], 
        Hue[0.6497446269774028, 1, 0.10035359341590383`], 
        Hue[0.6497220805506987, 1, 0.10038481154518647`], 
        Hue[0.6499875780500365, 1, 0.1000171996230264], 
        Hue[0.6498075235338531, 1, 0.10026650587620353`], 
        Hue[0.6497525816504376, 1, 0.10034257925324029`], 
        Hue[0.6497395116100093, 1, 0.10036067623229489`], 
        Hue[0.6497444578897738, 1, 0.10035382753723637`], 
        Hue[0.649904864696231, 1, 0.10013172580521867`], 
        Hue[0.6499637194211009, 1, 0.10005023464770654`], 
        Hue[0.6497760637592553, 1, 0.10031006556410807`], 
        Hue[0.6497500661969323, 1, 0.100346062188863], 
        Hue[0.6499183291303126, 1, 0.10011308274264415`], 
        Hue[0.6499817845643631, 1, 0.10002522137242048`], 
        Hue[0.6499667588310659, 1, 0.10004602623390876`], 
        Hue[0.6494358636771684, 1, 0.10078111183161303`], 
        Hue[0.6486665440965279, 1, 0.10184632355865368`], 
        Hue[0.6487973060787215, 1, 0.10166526850638564`], 
        Hue[0.6490820712669708, 1, 0.10127097824573278`], 
        Hue[0.6498666614359694, 1, 0.10018462262711927`], 
        Hue[0.6494928049778546, 1, 0.10070227003066289`], 
        Hue[0.648377552014383, 1, 0.10224646644162362`], 
        Hue[0.6490171435581193, 1, 0.10136087815029625`], 
        Hue[0.6495581589251697, 1, 0.1006117799497651], 
        Hue[0.6498671323084145, 1, 0.10018397064988763`], 
        Hue[0.6473537923316887, 1, 0.10366397984843105`], 
        Hue[0.6480091049759611, 1, 0.10275662387943847`], 
        Hue[0.648755138205803, 1, 0.10172365479196505`], 
        Hue[0.6496095597971275, 1, 0.10054060951166957`], 
        Hue[0.6450053143732403, 1, 0.10691571856012894`], 
        Hue[0.6481572782578708, 1, 0.10255146087371726`], 
        Hue[0.6499764872407213, 1, 0.10003255612823204`], 
        Hue[0.3711773698973812, 1, 0.48606210321901067`], 
        Hue[0.41486309731293136`, 1, 0.42557417295132594`], 
        Hue[0.4875889857302076, 1, 0.32487678898894345`], 
        Hue[0.6255368322476673, 1, 0.13387207842630677`], 
        Hue[0.646236945281131, 1, 0.10521038345689565`], 
        Hue[0.64846560213652, 1, 0.10212455088789542`], 
        Hue[0.16660070649009112`, 1, 0.7693220987060277], 
        Hue[0.2153415771899569, 1, 0.7018347392754444], 
        Hue[0.10993697241880118`, 1, 0.8477795766508907], 
        Hue[0.13133504687222974`, 1, 0.8181514735615281], 
        Hue[0.10995731693131072`, 1, 0.8477514073258775], 
        Hue[0.1666401527260788, 1, 0.769267480840814], 
        Hue[0.1313694777282427, 1, 0.818103800068587], 
        Hue[0.2153784744292791, 1, 0.701783650790229], 
        Hue[0.3464112201430799, 1, 0.5203536951865048], 
        Hue[0.4873085045365856, 1, 0.32526514756472774`], 
        Hue[0.585623995432508, 1, 0.18913600632421984`], 
        Hue[0.6294670107072995, 1, 0.12843029286681606`], 
        Hue[0.6432968085985096, 1, 0.10928134194052527`], 
        Hue[0.6496234965987948, 1, 0.10052131240166877`], 
        Hue[0.2607299568411387, 1, 0.6389892905276541], 
        Hue[0.12170305563831796`, 1, 0.8314880768084828], 
        Hue[0.033059327871753474`, 1, 0.954225546023726], 
        Hue[0.12170305563598438`, 1, 0.831488076811714], 
        Hue[0.2607299568417177, 1, 0.6389892905268524], 
        Hue[0.4280417126324546, 1, 0.407326859431986], 
        Hue[0.5591705448267148, 1, 0.22576386100916412`], 
        Hue[0.649623496598795, 1, 0.10052131240166845`], 
        Hue[0.6499289484739933, 1, 0.1000983790360093], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.5856239954315277, 1, 0.18913600632557717`], 
        Hue[0.48730850453512964`, 1, 0.32526514756674363`], 
        Hue[0.3464112201419854, 1, 0.5203536951880203], 
        Hue[0.21537847442891117`, 1, 0.7017836507907383], 
        Hue[0.13136947772675878`, 1, 0.8181038000706417], 
        Hue[0.1313350468685427, 1, 0.8181514735666332], 
        Hue[0.2153415771885579, 1, 0.7018347392773814], 
        Hue[0.6392520089618953, 1, 0.11488183374506818`], 
        Hue[0.6255368322474537, 1, 0.1338720784266026], 
        Hue[0.6499764872407213, 1, 0.10003255612823203`], 
        Hue[0.6493571286681645, 1, 0.1008901295363876], 
        Hue[0.6481572782578727, 1, 0.10255146087371465`], 
        Hue[0.6460988378741058, 1, 0.10540160909739191`], 
        Hue[0.6450053143732773, 1, 0.10691571856007749`], 
        Hue[0.6320881314565716, 1, 0.12480104875243928`], 
        Hue[0.6197571630580532, 1, 0.14187469730423413`], 
        Hue[0.6051860768208408, 1, 0.16205004747883583`], 
        Hue[0.5950760330689806, 1, 0.17604856959679616`], 
        Hue[0.6496095597971278, 1, 0.10054060951166938`], 
        Hue[0.6498908903541091, 1, 0.10015107489431052`], 
        Hue[0.6487551382058032, 1, 0.1017236547919648], 
        Hue[0.6480091049759613, 1, 0.10275662387943818`], 
        Hue[0.6473537923316892, 1, 0.10366397984843027`], 
        Hue[0.6453186380742276, 1, 0.10648188574337719`], 
        Hue[0.6446747005059975, 1, 0.10737349160708046`], 
        Hue[0.6495581589251697, 1, 0.10061177994976514`], 
        Hue[0.6490171435581193, 1, 0.10136087815029626`], 
        Hue[0.6474600972735775, 1, 0.10351678839043126`], 
        Hue[0.6474700106798338, 1, 0.10350306213561476`], 
        Hue[0.6496149480434029, 1, 0.10053314886298056`], 
        Hue[0.6494928049778319, 1, 0.10070227003069426`], 
        Hue[0.6499659179555519, 1, 0.10004719052308203`], 
        Hue[0.6498666614359694, 1, 0.1001846226271193], 
        Hue[0.6499667588310656, 1, 0.10004602623390928`], 
        Hue[0.6499998944694872, 1, 0.10000014611917156`], 
        Hue[0.6495577101050631, 1, 0.10061240139298953`], 
        Hue[0.6499655367985427, 1, 0.10004771827894092`], 
        Hue[0.649965516562715, 1, 0.10004774629777938`], 
        Hue[0.6496090377308189, 1, 0.10054133237271227`], 
        Hue[0.6499997961154858, 1, 0.10000028230163507`], 
        Hue[0.6490867430856564, 1, 0.10126450957370664`], 
        Hue[0.6474954669797973, 1, 0.10346781495104992`], 
        Hue[0.6294650459019475, 1, 0.12843301336653418`], 
        Hue[0.6474944451681277, 1, 0.10346922976720777`], 
        Hue[0.6474944451680357, 1, 0.10346922976733522`], 
        Hue[0.629465045901841, 1, 0.12843301336668167`], 
        Hue[0.6474954669797108, 1, 0.1034678149511697], 
        Hue[0.649086743085644, 1, 0.1012645095737238], 
        Hue[0.6499997961154859, 1, 0.10000028230163507`], 
        Hue[0.6496090377308191, 1, 0.10054133237271208`], 
        Hue[0.649965516562715, 1, 0.10004774629777935`], 
        Hue[0.6499655367985427, 1, 0.1000477182789409], 
        Hue[0.649299395728952, 1, 0.1009700674522203], 
        Hue[0.6495577101050631, 1, 0.10061240139298959`], 
        Hue[0.649999546284906, 1, 0.10000062822089953`], 
        Hue[0.6499968016948423, 1, 0.10000442842252606`], 
        Hue[0.6499837977879257, 1, 0.10002243383210294`], 
        Hue[0.6499427464970976, 1, 0.10007927408094187`], 
        Hue[0.6498634854226076, 1, 0.10018902018408178`], 
        Hue[0.6499987777339871, 1, 0.10000169236832561`], 
        Hue[0.649993865184265, 1, 0.1000084943602484], 
        Hue[0.6499762536549267, 1, 0.10003287955471693`], 
        Hue[0.6499307068090907, 1, 0.1000959444181821], 
        Hue[0.6498518987975389, 1, 0.10020506320340776`], 
        Hue[0.6499921293089566, 1, 0.10001089787990629`], 
        Hue[0.6499882868309909, 1, 0.10001621823401269`], 
        Hue[0.64995742655059, 1, 0.10005894785302931`], 
        Hue[0.6498432245869256, 1, 0.10021707364887242`], 
        Hue[0.6497995501416562, 1, 0.10027754595770674`], 
        Hue[0.649510432152012, 1, 0.1006778631741373], 
        Hue[0.6499615936668796, 1, 0.1000531779997052], 
        Hue[0.6499507438872519, 1, 0.10006820077149742`], 
        Hue[0.6498799412726701, 1, 0.10016623516091826`], 
        Hue[0.6498506186895233, 1, 0.1002068356606601], 
        Hue[0.649697640812672, 1, 0.10041865118245424`], 
        Hue[0.6496397195744827, 1, 0.10049884981994704`], 
        Hue[0.6435492187575874, 1, 0.1089318509510328], 
        Hue[0.638324715551791, 1, 0.1161657784667509], 
        Hue[0.6228816248504861, 1, 0.1375485194377885], 
        Hue[0.584391631122217, 1, 0.1908423569076996], 
        Hue[0.5180120543224829, 1, 0.28275254016886997`], 
        Hue[0.649671307313124, 1, 0.10045511295105926`], 
        Hue[0.6499080428696402, 1, 0.10012732525742125`], 
        Hue[0.6499810990463154, 1, 0.10002617055125558`], 
        Hue[0.6479034511562572, 1, 0.10290291378364377`], 
        Hue[0.6481488635226674, 1, 0.10256311204553752`], 
        Hue[0.6497769960904989, 1, 0.10030877464392474`], 
        Hue[0.6498161665378681, 1, 0.10025453863987495`], 
        Hue[0.6499471992776278, 1, 0.10007310869251541`], 
        Hue[0.6499585389917856, 1, 0.10005740754983537`], 
        Hue[0.6499903486487819, 1, 0.100013363409379], 
        Hue[0.6499928350255395, 1, 0.10000992073386848`], 
        Hue[0.6499986685807253, 1, 0.10000184350361113`], 
        Hue[0.6499990728488086, 1, 0.10000128374780339`], 
        Hue[0.6499998652875634, 1, 0.10000018652491231`], 
        Hue[0.6499999130990606, 1, 0.10000012032437766`], 
        Hue[0.6499773681890932, 1, 0.10003133635356326`], 
        Hue[0.6498799739553269, 1, 0.10016618990800887`], 
        Hue[0.6139219345410782, 1, 0.14995424448158404`], 
        Hue[0.6276537703969349, 1, 0.13094093329655168`], 
        Hue[0.6369354292276365, 1, 0.11808940568481112`], 
        Hue[0.6416037038677826, 1, 0.11162564079845479`], 
        Hue[0.6437749675546234, 1, 0.10861927569359847`], 
        Hue[0.6499786571222672, 1, 0.10002955167686084`], 
        Hue[0.6499786571222672, 1, 0.10002955167686084`], 
        Hue[0.6498762763822666, 1, 0.10017130962455395`], 
        Hue[0.6499312334274999, 1, 0.10009521525423094`], 
        Hue[0.6499312334274999, 1, 0.10009521525423093`], 
        Hue[0.6499546249480828, 1, 0.10006282699496238`], 
        Hue[0.6499774540762749, 1, 0.10003121743285015`], 
        Hue[0.6442963774517934, 1, 0.1078973235282862], 
        Hue[0.6437749675545958, 1, 0.10861927569363655`], 
        Hue[0.6416037038677707, 1, 0.11162564079847141`], 
        Hue[0.6389584142500377, 1, 0.11528834949994783`], 
        Hue[0.6369354292276032, 1, 0.11808940568485717`], 
        Hue[0.6314113814488912, 1, 0.12573808722461224`], 
        Hue[0.6276537703968138, 1, 0.13094093329671944`], 
        Hue[0.6189100178905788, 1, 0.14304766753612178`], 
        Hue[0.6139219345407914, 1, 0.1499542444819813], 
        Hue[0.6498799739553269, 1, 0.10016618990800895`], 
        Hue[0.6499544789815872, 1, 0.10006302910241778`], 
        Hue[0.6499773681890932, 1, 0.10003133635356329`], 
        Hue[0.6355280494073535, 1, 0.12003808543597211`], 
        Hue[0.6499999130990606, 1, 0.10000012032437766`], 
        Hue[0.6499990728488086, 1, 0.10000128374780339`], 
        Hue[0.6499928350255395, 1, 0.10000992073386847`], 
        Hue[0.6499585389917857, 1, 0.10005740754983528`], 
        Hue[0.6498161665378682, 1, 0.1002545386398748], 
        Hue[0.6355280494071409, 1, 0.12003808543626643`], 
        Hue[0.6499871546152928, 1, 0.100017785917287], 
        Hue[0.6499810990463154, 1, 0.10002617055125557`], 
        Hue[0.6499334733653315, 1, 0.10009211380184872`], 
        Hue[0.6499080428696403, 1, 0.1001273252574212], 
        Hue[0.6497487056715419, 1, 0.10034794599324971`], 
        Hue[0.6496713073131244, 1, 0.10045511295105859`], 
        Hue[0.49721716070467614`, 1, 0.31154546979352543`], 
        Hue[0.518012054323759, 1, 0.28275254016710305`], 
        Hue[0.5843916311228773, 1, 0.1908423569067853], 
        Hue[0.615072853841081, 1, 0.14836066391234937`], 
        Hue[0.6228816248506646, 1, 0.13754851943754146`], 
        Hue[0.6355677813921563, 1, 0.11998307191855279`], 
        Hue[0.6383247155517915, 1, 0.11616577846675029`], 
        Hue[0.6425869541066501, 1, 0.11026421739079217`], 
        Hue[0.643549218757615, 1, 0.10893185095099478`], 
        Hue[0.6499546249480828, 1, 0.10006282699496233`], 
        Hue[0.6499774540762749, 1, 0.10003121743285012`], 
        Hue[0.6496397195744829, 1, 0.10049884981994692`], 
        Hue[0.6498506186895235, 1, 0.10020683566065973`], 
        Hue[0.6499507438872523, 1, 0.10006820077149693`], 
        Hue[0.6495104321520119, 1, 0.10067786317413745`], 
        Hue[0.6497995501416562, 1, 0.10027754595770683`], 
        Hue[0.6499882868309909, 1, 0.10001621823401269`], 
        Hue[0.6498383027784683, 1, 0.10022388846058239`], 
        Hue[0.6498518987975388, 1, 0.10020506320340787`], 
        Hue[0.6499202363144327, 1, 0.10011044202617005`], 
        Hue[0.6499307068090907, 1, 0.10009594441818215`], 
        Hue[0.6499711752825617, 1, 0.10003991114722235`], 
        Hue[0.6499762536549267, 1, 0.10003287955471694`], 
        Hue[0.649992139261425, 1, 0.10001088409956545`], 
        Hue[0.649993865184265, 1, 0.1000084943602484], 
        Hue[0.6499983476490149, 1, 0.10000228787059483`], 
        Hue[0.6499987777339871, 1, 0.10000169236832561`], 
        Hue[0.6498492997424695, 1, 0.10020866189504228`], 
        Hue[0.6498634854226075, 1, 0.10018902018408185`], 
        Hue[0.6499326287044422, 1, 0.1000932833323108], 
        Hue[0.6499427464970975, 1, 0.10007927408094192`], 
        Hue[0.6499796318088381, 1, 0.1000282021108396], 
        Hue[0.6499837977879257, 1, 0.10002243383210295`], 
        Hue[0.6499968016948423, 1, 0.10000442842252608`], 
        Hue[0.6499993476880973, 1, 0.10000090320109607`], 
        Hue[0.649999546284906, 1, 0.10000062822089954`], 
        Hue[0.6499786571222672, 1, 0.10002955167686085`], 
        Hue[0.6499786571222672, 1, 0.10002955167686085`], 
        Hue[0.6499872851621001, 1, 0.10001760516016904`], 
        Hue[0.6499786432660215, 1, 0.10002957086243185`], 
        Hue[0.6499786432660215, 1, 0.10002957086243186`], 
        Hue[0.6481499757638406, 1, 0.10256157201929773`], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499999994667391, 1, 0.10000000073836127`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6499999860214585, 1, 0.10000001935490364`], 
        Hue[0.6481488635226095, 1, 0.10256311204561763`], 
        Hue[0.6481499757637851, 1, 0.10256157201937459`], 
        Hue[0.6499786432660215, 1, 0.10002957086243183`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.6499999936474662, 1, 0.10000000879581607`], 
        Hue[0.649744463028524, 1, 0.10035382042204373`], 
        Hue[0.6497201483868429, 1, 0.1003874868489868], 
        Hue[0.6497393167031356, 1, 0.10036094610335085`], 
        Hue[0.6497201201157683, 1, 0.10038752599355157`], 
        Hue[0.6499731374090271, 1, 0.10003719435673182`], 
        Hue[0.649978584567043, 1, 0.10002965213794048`], 
        Hue[0.64932693666548, 1, 0.10093193384779686`], 
        Hue[0.6496050201873916, 1, 0.10054689512515011`], 
        Hue[0.6496046189157265, 1, 0.10054745073207098`], 
        Hue[0.6498226656875891, 1, 0.1002455398171844], 
        Hue[0.6497422006045631, 1, 0.10035695300906647`], 
        Hue[0.6498702084125652, 1, 0.10017971142875598`], 
        Hue[0.6448140890407267, 1, 0.10718049209745545`], 
        Hue[0.6492714389145245, 1, 0.1010087768875815], 
        Hue[0.6495444786347686, 1, 0.10063072189032049`], 
        Hue[0.635809914745834, 1, 0.11964781035192219`], 
        Hue[0.6499450533801044, 1, 0.10007607993524008`], 
        Hue[0.6498987693663225, 1, 0.10014016549278425`], 
        Hue[0.6499448820990992, 1, 0.10007631709355506`], 
        Hue[0.6498985097083886, 1, 0.10014052501915438`], 
        Hue[0.6499999143695201, 1, 0.1000001185652799], 
        Hue[0.6227153440039659, 1, 0.13777875445604731`], 
        Hue[0.6227153440039653, 1, 0.13777875445604798`], 
        Hue[0.00856416289874995, 1, 0.9881419282940385], 
        Hue[0.008564162897155558, 1, 0.9881419282962461], 
        Hue[0.6227153440043187, 1, 0.13777875445555868`], 
        Hue[0.6227153440043193, 1, 0.13777875445555793`], 
        Hue[0.6430994341870176, 1, 0.10955462958720644`], 
        Hue[0.6430994341870178, 1, 0.10955462958720621`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6430994341869646, 1, 0.10955462958727985`], 
        Hue[0.6430994341869645, 1, 0.10955462958728006`], 
        Hue[0.008564162898749617, 1, 0.988141928294039], 
        Hue[0.008564162897156002, 1, 0.9881419282962455], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.6499995584935135, 1, 0.10000061131667352`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499766495074196, 1, 0.10003233145126517`], 
        Hue[0.6499993787624871, 1, 0.1000008601750178], 
        Hue[0.6499949427213864, 1, 0.10000700238577273`], 
        Hue[0.649969296003201, 1, 0.10004251322633723`], 
        Hue[0.6499999143695201, 1, 0.1000001185652799], 
        Hue[0.6499924815348365, 1, 0.10001041018253413`], 
        Hue[0.649995066268984, 1, 0.10000683131986839`], 
        Hue[0.6326369084383063, 1, 0.12404120370080668`], 
        Hue[0.6278460623886941, 1, 0.13067468284642353`], 
        Hue[0.6498702084125652, 1, 0.10017971142875591`], 
        Hue[0.6495444786347687, 1, 0.10063072189032032`], 
        Hue[0.6499872761827475, 1, 0.1000176175931189], 
        Hue[0.649822601052624, 1, 0.1002456293117514], 
        Hue[0.6494794345021757, 1, 0.10072078299698756`], 
        Hue[0.649327839891267, 1, 0.10093068322747661`], 
        Hue[0.6499785002992394, 1, 0.10002976881643783`], 
        Hue[0.6499785845670428, 1, 0.10002965213794081`], 
        Hue[0.6499145448836653, 1, 0.10011832246877123`], 
        Hue[0.6499298416416035, 1, 0.10009714234239513`], 
        Hue[0.6499807313906684, 1, 0.10002667961292078`], 
        Hue[0.6499852101793618, 1, 0.10002047821319135`], 
        Hue[0.6499875143105937, 1, 0.10001728787763953`], 
        Hue[0.6499844331418096, 1, 0.10002155411134056`], 
        Hue[0.649997177936394, 1, 0.10000390747268527`], 
        Hue[0.6499994806519499, 1, 0.10000071909730011`], 
        Hue[0.6499992967751281, 1, 0.10000097369597646`], 
        Hue[0.6499924900042139, 1, 0.10001039845570384`], 
        Hue[0.6499902455567598, 1, 0.10001350615217874`], 
        Hue[0.649998744591033, 1, 0.10000173825856974`], 
        Hue[0.649998257978814, 1, 0.10000241202933446`], 
        Hue[0.6499998499361392, 1, 0.10000020778073027`], 
        Hue[0.6499997756993264, 1, 0.10000031057016343`], 
        Hue[0.6497393167031354, 1, 0.100360946103351], 
        Hue[0.6497220759135403, 1, 0.10038481796586733`], 
        Hue[0.649744463028524, 1, 0.10035382042204372`], 
        Hue[0.6447602379004875, 1, 0.10725505521470961`], 
        Hue[0.6445860308483407, 1, 0.1074962649792206], 
        Hue[0.6499987762295317, 1, 0.10000169445141766`], 
        Hue[0.6499972833772172, 1, 0.1000037614776993], 
        Hue[0.622715344004319, 1, 0.1377787544555582], 
        Hue[0.6430994341870176, 1, 0.1095546295872063], 
        Hue[0.6455633919912057, 1, 0.10614299570448438`], 
        Hue[0.6499169012778275, 1, 0.10011505976916187`], 
        Hue[0.6499452554080252, 1, 0.10007580020427294`], 
        Hue[0.6499452554080252, 1, 0.10007580020427294`], 
        Hue[0.6448213068074805, 1, 0.10717049826656548`], 
        Hue[0.6447602379007439, 1, 0.10725505521435462`], 
        Hue[0.6450472715451144, 1, 0.106857624014457], 
        Hue[0.6473532864649093, 1, 0.10366468027935632`], 
        Hue[0.6474596176061951, 1, 0.10351745254526841`], 
        Hue[0.649990745780477, 1, 0.10001281353472413`], 
        Hue[0.6499768211371815, 1, 0.10003209381005643`], 
        Hue[0.6499892906359471, 1, 0.10001482835022706`], 
        Hue[0.6499848496426992, 1, 0.10002097741780107`], 
        Hue[0.6499997433419163, 1, 0.10000035537273122`], 
        Hue[0.6497498661728607, 1, 0.10034633914526987`], 
        Hue[0.6498629460993739, 1, 0.10018976693932853`], 
        Hue[0.6497442349944516, 1, 0.10035413616152872`], 
        Hue[0.6498758963289264, 1, 0.10017183585225574`], 
        Hue[0.6499979396020884, 1, 0.10000285285864687`], 
        Hue[0.649985101517905, 1, 0.10002062866751625`], 
        Hue[0.6499883785355535, 1, 0.10001609125846449`], 
        Hue[0.649990745780477, 1, 0.10001281353472413`], 
        Hue[0.6499893270949103, 1, 0.10001477786858572`], 
        Hue[0.6450484170872981, 1, 0.1068560378791257], 
        Hue[0.647353286464909, 1, 0.10366468027935681`], 
        Hue[0.645047271545117, 1, 0.10685762401445344`], 
        Hue[0.6451837682394984, 1, 0.10666862859146373`], 
        Hue[0.6451837682394984, 1, 0.10666862859146374`], 
        Hue[0.644586417592649, 1, 0.10749572948710148`], 
        Hue[0.644643854407393, 1, 0.1074162015897635], 
        Hue[0.6265023909903372, 1, 0.13253515093645618`], 
        Hue[0.6499928687028823, 1, 0.10000987410370149`], 
        Hue[0.6498802677343509, 1, 0.10016578313705254`], 
        Hue[0.6499902459174384, 1, 0.10001350565277763`], 
        Hue[0.649998299585341, 1, 0.10000235442029706`], 
        Hue[0.649997307226403, 1, 0.10000372845574963`], 
        Hue[0.6452024257204503, 1, 0.10664279515629968`], 
        Hue[0.6421328552372512, 1, 0.11089296967149839`], 
        Hue[0.6425888456319614, 1, 0.11026159835574584`], 
        Hue[0.6435506515418182, 1, 0.10892986709594407`], 
        Hue[0.6459425149455353, 1, 0.10561805622925885`], 
        Hue[0.6384789975537194, 1, 0.11595215723331168`], 
        Hue[0.6227153440039657, 1, 0.13777875445604756`], 
        Hue[0.6499987762295317, 1, 0.10000169445141764`], 
        Hue[0.6425888456319463, 1, 0.11026159835576668`], 
        Hue[0.6435506515418299, 1, 0.10892986709592786`], 
        Hue[0.649997307226403, 1, 0.10000372845574962`], 
        Hue[0.6455644065284439, 1, 0.10614159096061612`], 
        Hue[0.6497831131736973, 1, 0.10030030483641918`], 
        Hue[0.649880267734351, 1, 0.10016578313705246`], 
        Hue[0.6499928687028823, 1, 0.10000987410370148`], 
        Hue[0.6265023909906217, 1, 0.13253515093606227`], 
        Hue[0.6446438544074229, 1, 0.1074162015897222], 
        Hue[0.6445864175924402, 1, 0.10749572948739058`], 
        Hue[0.645048417087303, 1, 0.10685603787911896`], 
        Hue[0.6499893270949103, 1, 0.10001477786858572`], 
        Hue[0.6499883785355535, 1, 0.10001609125846449`], 
        Hue[0.6499979396020884, 1, 0.10000285285864687`], 
        Hue[0.6498758963289265, 1, 0.10017183585225567`], 
        Hue[0.6498629460993739, 1, 0.10018976693932845`], 
        Hue[0.649998744591033, 1, 0.10000173825856974`], 
        Hue[0.649998257978814, 1, 0.10000241202933446`], 
        Hue[0.6499998499361392, 1, 0.10000020778073027`], 
        Hue[0.6499997756993264, 1, 0.10000031057016343`], 
        Hue[0.6499924900042139, 1, 0.10001039845570384`], 
        Hue[0.6499902455567599, 1, 0.10001350615217873`], 
        Hue[0.6499985526901774, 1, 0.10000200396744671`], 
        Hue[0.6499680543081146, 1, 0.10004423249645675`], 
        Hue[0.6499611431173056, 1, 0.1000538018375769], 
        Hue[0.6499915553675152, 1, 0.10001169256805592`], 
        Hue[0.6499070733798012, 1, 0.10012866762796759`], 
        Hue[0.6498941642091621, 1, 0.10014654186423702`], 
        Hue[0.6499389913540884, 1, 0.10008447350972374`], 
        Hue[0.6499994806519499, 1, 0.10000071909730011`], 
        Hue[0.6499992967751281, 1, 0.10000097369597646`], 
        Hue[0.649997177936394, 1, 0.10000390747268527`], 
        Hue[0.6499994103243372, 1, 0.1000008164739948], 
        Hue[0.6499875143105937, 1, 0.10001728787763953`], 
        Hue[0.6499844331418096, 1, 0.10002155411134056`], 
        Hue[0.6499968070349429, 1, 0.1000044210285406], 
        Hue[0.6499579058346595, 1, 0.10005828422893295`], 
        Hue[0.6499502404150022, 1, 0.10006889788692015`], 
        Hue[0.6499861817897984, 1, 0.1000191329064331], 
        Hue[0.6498945035414182, 1, 0.10014607201957478`], 
        Hue[0.6498817551107648, 1, 0.10016372369278713`], 
        Hue[0.6499513388525884, 1, 0.10006737697333923`], 
        Hue[0.6499990165514296, 1, 0.10000136169802062`], 
        Hue[0.6499997133311914, 1, 0.10000039692604273`], 
        Hue[0.6499807313906684, 1, 0.10002667961292076`], 
        Hue[0.6499971170968787, 1, 0.10000399171201411`], 
        Hue[0.6499145448836653, 1, 0.10011832246877118`], 
        Hue[0.6499785002992391, 1, 0.10002976881643814`], 
        Hue[0.6499763120114476, 1, 0.10003279875338034`], 
        Hue[0.6499569735915823, 1, 0.1000595750270399], 
        Hue[0.6499305639619215, 1, 0.1000961422065702], 
        Hue[0.6499223977301635, 1, 0.1001074492966967], 
        Hue[0.6499682293104805, 1, 0.10004399018548857`], 
        Hue[0.6498038432915924, 1, 0.10027160159625682`], 
        Hue[0.6497842792878259, 1, 0.10029869021685645`], 
        Hue[0.6499293875019, 1, 0.10009777115121549`], 
        Hue[0.6499955545015644, 1, 0.1000061553055262], 
        Hue[0.6499971445555819, 1, 0.10000395369227129`], 
        Hue[0.6499942337059641, 1, 0.10000798409943434`], 
        Hue[0.6499848496426992, 1, 0.10002097741780107`], 
        Hue[0.6499313963608999, 1, 0.10009498965413854`], 
        Hue[0.6499452847292683, 1, 0.10007575960562864`], 
        Hue[0.6499452847292683, 1, 0.10007575960562864`], 
        Hue[0.6450730162623394, 1, 0.10682197748291483`], 
        Hue[0.6450730162623393, 1, 0.10682197748291483`], 
        Hue[0.6451848600758754, 1, 0.10666711681801869`], 
        Hue[0.6451848600758754, 1, 0.10666711681801869`], 
        Hue[0.6363290967524772, 1, 0.11892894295810859`], 
        Hue[0.6454889217763025, 1, 0.10624610830973502`], 
        Hue[0.649946398470897, 1, 0.10007421750183504`], 
        Hue[0.6499872378397605, 1, 0.10001767068340861`], 
        Hue[0.6499812127959619, 1, 0.10002601305174517`], 
        Hue[0.6123798420897374, 1, 0.15208944941420982`], 
        Hue[0.6314188285390657, 1, 0.1257277758689859], 
        Hue[0.6276615081556854, 1, 0.13093021947674333`], 
        Hue[0.6342357357138686, 1, 0.12182744285772036`], 
        Hue[0.6355735873344104, 1, 0.1199750329215857], 
        Hue[0.6383290297329686, 1, 0.11615980498512041`], 
        Hue[0.6499951048581283, 1, 0.10000677788874544`], 
        Hue[0.6326369084382553, 1, 0.12404120370087737`], 
        Hue[0.6278460623885795, 1, 0.1306746828465822], 
        Hue[0.6498198123292013, 1, 0.10024949062110598`], 
        Hue[0.649865897701864, 1, 0.10018568010511139`], 
        Hue[0.6499924815348365, 1, 0.10001041018253413`], 
        Hue[0.649995066268984, 1, 0.10000683131986839`], 
        Hue[0.6499694960336534, 1, 0.10004223626109528`], 
        Hue[0.6131190636403478, 1, 0.15106591188259538`], 
        Hue[0.6459417553416843, 1, 0.10561910798843711`], 
        Hue[0.6495806066420243, 1, 0.10058069849565873`], 
        Hue[0.6499766495074196, 1, 0.10003233145126522`], 
        Hue[0.6498880939419247, 1, 0.10015494684964274`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499969194200786, 1, 0.10000426541835268`], 
        Hue[0.6499870926215222, 1, 0.10001787175481543`], 
        Hue[0.6499995584935135, 1, 0.10000061131667352`], 
        Hue[0.6499989198255313, 1, 0.10000149562618747`], 
        Hue[0.6499996498839958, 1, 0.10000048477600589`], 
        Hue[0.6499981583263428, 1, 0.10000255000967932`], 
        Hue[0.6499998959071556, 1, 0.10000014412855386`], 
        Hue[0.6499998069333369, 1, 0.10000026732307205`], 
        Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.018968293162061722`, 1, 0.9737362094679146], 
        Hue[0.0021628179027943784`, 1, 0.9970053290576693], 
        Hue[0.0021628179019673732`, 1, 0.9970053290588143], 
        Hue[0.01896829315981796, 1, 0.9737362094710212], 
        Hue[0.6499999419197341, 1, 0.1000000804188298], 
        Hue[0.6499998069333369, 1, 0.10000026732307205`], 
        Hue[0.6499981583263428, 1, 0.10000255000967932`], 
        Hue[0.6499870926215222, 1, 0.10001787175481541`], 
        Hue[0.6498880939419249, 1, 0.10015494684964242`], 
        Hue[0.6495806066420229, 1, 0.10058069849566069`], 
        Hue[0.6499996498839958, 1, 0.10000048477600589`], 
        Hue[0.6499989198255313, 1, 0.10000149562618747`], 
        Hue[0.6499998959071556, 1, 0.10000014412855386`], 
        Hue[0.6499969194200786, 1, 0.10000426541835268`], 
        Hue[0.6499982837325233, 1, 0.10000237637035238`], 
        Hue[0.6499972833772172, 1, 0.1000037614776993], 
        Hue[0.6499694960336535, 1, 0.10004223626109526`], 
        Hue[0.6498198123292014, 1, 0.10024949062110579`], 
        Hue[0.6498658977018641, 1, 0.10018568010511128`], 
        Hue[0.6355735873342693, 1, 0.11997503292178105`], 
        Hue[0.6383290297328634, 1, 0.11615980498526599`], 
        Hue[0.6499872378397605, 1, 0.1000176706834086], 
        Hue[0.6499812127959619, 1, 0.10002601305174516`], 
        Hue[0.6499925368181951, 1, 0.10001033363634519`], 
        Hue[0.6499951048581283, 1, 0.10000677788874544`], 
        Hue[0.6443912491738397, 1, 0.10776596268237587`], 
        Hue[0.6450814653729413, 1, 0.10681027871438892`], 
        Hue[0.6499448820990992, 1, 0.10007631709355502`], 
        Hue[0.6498985097083886, 1, 0.1001405250191543], 
        Hue[0.6314188285392321, 1, 0.12572777586875555`], 
        Hue[0.6276615081559497, 1, 0.1309302194763774], 
        Hue[0.6123798420903684, 1, 0.15208944941333602`], 
        Hue[0.635809914745879, 1, 0.11964781035185994`], 
        Hue[0.6344958252613736, 1, 0.12146731886886732`], 
        Hue[0.6498987693663226, 1, 0.10014016549278415`], 
        Hue[0.649950695639109, 1, 0.1000682675766184], 
        Hue[0.6363290967525409, 1, 0.11892894295802031`], 
        Hue[0.6499169408087976, 1, 0.10011500503397268`], 
        Hue[0.6499452847292683, 1, 0.10007575960562862`], 
        Hue[0.6451848600758786, 1, 0.10666711681801425`], 
        Hue[0.6499384202733739, 1, 0.10008526423686702`], 
        Hue[0.6499313963608999, 1, 0.10009498965413856`], 
        Hue[0.644586030848589, 1, 0.10749626497887677`], 
        Hue[0.6493269366655053, 1, 0.10093193384776192`], 
        Hue[0.6496050201873775, 1, 0.10054689512516958`], 
        Hue[0.6499971445555819, 1, 0.1000039536922713], 
        Hue[0.6499942337059641, 1, 0.10000798409943434`], 
        Hue[0.6499682293104808, 1, 0.10004399018548812`], 
        Hue[0.6499971170968787, 1, 0.10000399171201411`], 
        Hue[0.6498038432915926, 1, 0.10027160159625655`], 
        Hue[0.6497842792878261, 1, 0.10029869021685618`], 
        Hue[0.6499305639619218, 1, 0.10009614220656972`], 
        Hue[0.6499223977301639, 1, 0.10010744929669622`], 
        Hue[0.6499569735915827, 1, 0.10005957502703941`], 
        Hue[0.6499764116330907, 1, 0.10003266081572051`], 
        Hue[0.649999101927029, 1, 0.10000124348565209`], 
        Hue[0.649925810454061, 1, 0.10010272398668485`], 
        Hue[0.6499740052775556, 1, 0.10003599269261544`], 
        Hue[0.6499931350584105, 1, 0.10000950530373938`], 
        Hue[0.6499986042640042, 1, 0.10000193255753263`], 
        Hue[0.6499380881968962, 1, 0.10008572403506673`], 
        Hue[0.6499820089674371, 1, 0.10002491066047177`], 
        Hue[0.6499963588136884, 1, 0.10000504164258525`], 
        Hue[0.6499994700011782, 1, 0.10000073384452254`], 
        Hue[0.6499513388525884, 1, 0.10006737697333921`], 
        Hue[0.6499074536869546, 1, 0.10012814104883216`], 
        Hue[0.6498945576128976, 1, 0.10014599715137257`], 
        Hue[0.6498945035414182, 1, 0.10014607201957484`], 
        Hue[0.6498817551107648, 1, 0.10016372369278721`], 
        Hue[0.6499579058346595, 1, 0.10005828422893297`], 
        Hue[0.6499502404150022, 1, 0.10006889788692018`], 
        Hue[0.6499389913540885, 1, 0.10008447350972371`], 
        Hue[0.6498948423987034, 1, 0.10014560283256445`], 
        Hue[0.6498821047507632, 1, 0.10016323957586631`], 
        Hue[0.6499070733798011, 1, 0.10012866762796764`], 
        Hue[0.6498941642091621, 1, 0.10014654186423709`], 
        Hue[0.6499680543081146, 1, 0.10004423249645678`], 
        Hue[0.6499611431173056, 1, 0.10005380183757692`], 
        Hue[0.6498821047507631, 1, 0.1001632395758664], 
        Hue[0.6499504648283491, 1, 0.10006858716074746`], 
        Hue[0.6498945576128976, 1, 0.10014599715137261`], 
        Hue[0.6499836181429697, 1, 0.10002268257127285`], 
        Hue[0.6499764116330911, 1, 0.10003266081572015`], 
        Hue[0.649327839891292, 1, 0.100930683227442], 
        Hue[0.6499696557470173, 1, 0.10004201511951463`], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499998973914634, 1, 0.10000014207335849`], 
        Hue[0.6499696557470173, 1, 0.1000420151195146], 
        Hue[0.6495118930856898, 1, 0.10067584034289113`], 
        Hue[0.649604618915741, 1, 0.10054745073205101`], 
        Hue[0.6499763120114478, 1, 0.10003279875337998`], 
        Hue[0.6499996718109462, 1, 0.10000045441561291`], 
        Hue[0.6499997221218345, 1, 0.10000038475438296`], 
        Hue[0.6499996739625998, 1, 0.1000004514364003], 
        Hue[0.6499997231111884, 1, 0.10000038338450845`], 
        Hue[0.6499994854782605, 1, 0.10000071241471627`], 
        Hue[0.6499993034614677, 1, 0.10000096443796776`], 
        Hue[0.6499581095157081, 1, 0.10005800220901964`], 
        Hue[0.6499504648283491, 1, 0.10006858716074744`], 
        Hue[0.6499994700011782, 1, 0.10000073384452254`], 
        Hue[0.6499963588136884, 1, 0.10000504164258524`], 
        Hue[0.6499820089674371, 1, 0.10002491066047176`], 
        Hue[0.6499380881968964, 1, 0.10008572403506669`], 
        Hue[0.6499986042640042, 1, 0.10000193255753263`], 
        Hue[0.6499931350584105, 1, 0.10000950530373937`], 
        Hue[0.6499740052775556, 1, 0.10003599269261543`], 
        Hue[0.6499258104540611, 1, 0.1001027239866848], 
        Hue[0.6496495783709015, 1, 0.10048519917875173`], 
        Hue[0.649621458422506, 1, 0.10052413449191479`], 
        Hue[0.649615310956587, 1, 0.10053264636780261`], 
        Hue[0.6496211353704806, 1, 0.10052458179471914`], 
        Hue[0.6496149480433895, 1, 0.10053314886299929`], 
        Hue[0.6498226010526239, 1, 0.1002456293117515], 
        Hue[0.6344958252613189, 1, 0.12146731886894314`], 
        Hue[0.6499979068548963, 1, 0.10000289820091286`], 
        Hue[0.6499999463041645, 1, 0.10000007434808002`], 
        Hue[0.6499997881961503, 1, 0.10000029326686882`], 
        Hue[0.6499998875844862, 1, 0.10000015565224989`], 
        Hue[0.6499961977161761, 1, 0.1000052647006792], 
        Hue[0.6499715658257951, 1, 0.10003937039505302`], 
        Hue[0.10275085520088534`, 1, 0.8577295851064664], 
        Hue[0.07116385446585627, 1, 0.9014654322780451], 
        Hue[0.6498321507756426, 1, 0.10023240661834108`], 
        Hue[0.6499999706508989, 1, 0.1000000406372169], 
        Hue[0.008564162898749839, 1, 0.9881419282940387], 
        Hue[0.00856416289715578, 1, 0.9881419282962458], 
        Hue[0.6499999463041645, 1, 0.10000007434808002`], 
        Hue[0.6499979259072688, 1, 0.10000287182070478`], 
        Hue[0.6498226656875892, 1, 0.1002455398171843], 
        Hue[0.6499835735373029, 1, 0.10002274433296532`], 
        Hue[0.6499817210220853, 1, 0.10002530935403585`], 
        Hue[0.6499836181429695, 1, 0.10002268257127303`], 
        Hue[0.6499817845643628, 1, 0.10002522137242074`], 
        Hue[0.6499861817897984, 1, 0.1000191329064331], 
        Hue[0.6499968070349429, 1, 0.1000044210285406], 
        Hue[0.6499994103243372, 1, 0.1000008164739948], 
        Hue[0.6499915553675152, 1, 0.10001169256805592`], 
        Hue[0.6499985526901774, 1, 0.10000200396744673`], 
        Hue[0.6499998221998805, 1, 0.10000024618478089`], 
        Hue[0.6499906782378703, 1, 0.10001290705525656`], 
        Hue[0.6446386253957014, 1, 0.10742344175979816`], 
        Hue[0.6447609920664576, 1, 0.10725401098490486`], 
        Hue[0.649998345225296, 1, 0.1000022912265133], 
        Hue[0.6499993476936773, 1, 0.1000009031933699], 
        Hue[0.6499997070467911, 1, 0.10000040562752005`], 
        Hue[0.6499995636115868, 1, 0.10000060423011056`], 
        Hue[0.6483242391402418, 1, 0.10232028426735747`], 
        Hue[0.6483242391402418, 1, 0.10232028426735751`], 
        Hue[0.6483242391402418, 1, 0.10232028426735748`], 
        Hue[0.6483242391402463, 1, 0.1023202842673513], 
        Hue[0.6483242391402464, 1, 0.10232028426735125`], 
        Hue[0.6483242391402463, 1, 0.10232028426735128`], 
        Hue[0.6469166687904662, 1, 0.10426922782858529`], 
        Hue[0.6450730162625556, 1, 0.10682197748261522`], 
        Hue[0.6450730162625556, 1, 0.10682197748261522`], 
        Hue[0.6446427123917254, 1, 0.10741778284222633`], 
        Hue[0.6451837682394976, 1, 0.10666862859146478`], 
        Hue[0.6451837682394977, 1, 0.10666862859146477`], 
        Hue[0.647847739448394, 1, 0.10298005307145448`], 
        Hue[0.6476673319658687, 1, 0.1032298480472588], 
        Hue[0.6475036441269619, 1, 0.1034564927472835], 
        Hue[0.6475036441269619, 1, 0.10345649274728348`], 
        Hue[0.6473254666988637, 1, 0.10370319995541953`], 
        Hue[0.6499997114379519, 1, 0.10000039954745131`], 
        Hue[0.649838667427071, 1, 0.10022338356251717`], 
        Hue[0.6498522655918395, 1, 0.10020455533437608`], 
        Hue[0.649849705083499, 1, 0.1002081006536168], 
        Hue[0.6498638958591648, 1, 0.10018845188731024`], 
        Hue[0.6499964999597848, 1, 0.10000484620952874`], 
        Hue[0.6499892906359471, 1, 0.10001482835022706`], 
        Hue[0.6473254666988637, 1, 0.10370319995541954`], 
        Hue[0.648184760828347, 1, 0.10251340808382732`], 
        Hue[0.6478477394483939, 1, 0.10298005307145464`], 
        Hue[0.6475036441269618, 1, 0.10345649274728375`], 
        Hue[0.6475036441269617, 1, 0.10345649274728376`], 
        Hue[0.644642712391751, 1, 0.10741778284219103`], 
        Hue[0.6447410918958458, 1, 0.1072815650672905], 
        Hue[0.6447410918958458, 1, 0.1072815650672905], 
        Hue[0.644822685525103, 1, 0.1071685892729343], 
        Hue[0.644822685525103, 1, 0.10716858927293431`], 
        Hue[0.6447422602883427, 1, 0.10727994729306398`], 
        Hue[0.6447422602883427, 1, 0.10727994729306398`], 
        Hue[0.6039331393078194, 1, 0.16378488403532698`], 
        Hue[0.599124239982273, 1, 0.17044336002454505`], 
        Hue[0.6450803703104249, 1, 0.10681179495479633`], 
        Hue[0.6469166687904262, 1, 0.10426922782864076`], 
        Hue[0.6452016973297894, 1, 0.10664380369721467`], 
        Hue[0.6432970668472778, 1, 0.10928098436530766`], 
        Hue[0.6432970668470466, 1, 0.10928098436562779`], 
        Hue[0.6450761923626182, 1, 0.10681757980560565`], 
        Hue[0.5959045810185231, 1, 0.17490134935896817`], 
        Hue[0.5991242399827877, 1, 0.17044336002383234`], 
        Hue[0.6448438343094479, 1, 0.10713930634076449`], 
        Hue[0.644742260288362, 1, 0.1072799472930372], 
        Hue[0.6446754130691614, 1, 0.1073725049811612], 
        Hue[0.6448226855248731, 1, 0.1071685892732527], 
        Hue[0.649849705083499, 1, 0.10020810065361674`], 
        Hue[0.6498638958591649, 1, 0.10018845188731017`], 
        Hue[0.6498386674270711, 1, 0.10022338356251706`], 
        Hue[0.6498522655918396, 1, 0.10020455533437599`], 
        Hue[0.6499766758185227, 1, 0.10003229502050702`], 
        Hue[0.6499991149582264, 1, 0.10000122544245589`], 
        Hue[0.6499998221998805, 1, 0.10000024618478089`], 
        Hue[0.6499943973499914, 1, 0.10000775751539649`], 
        Hue[0.6499205322569598, 1, 0.10011003225959411`], 
        Hue[0.6499309840236278, 1, 0.10009556058266922`], 
        Hue[0.649979910447695, 1, 0.1000278163031916], 
        Hue[0.6499993034614677, 1, 0.10000096443796776`], 
        Hue[0.6499996739625998, 1, 0.1000004514364003], 
        Hue[0.6499997231111884, 1, 0.10000038338450845`], 
        Hue[0.6499996082984593, 1, 0.1000005423559795], 
        Hue[0.6499997221218345, 1, 0.10000038475438296`], 
        Hue[0.6499996049868014, 1, 0.10000054694135192`], 
        Hue[0.6499978738704448, 1, 0.10000294387169176`], 
        Hue[0.6499329557399242, 1, 0.10009283051395126`], 
        Hue[0.6499430494131798, 1, 0.10007885465867405`], 
        Hue[0.6499941827230284, 1, 0.1000080546911914], 
        Hue[0.6499852320800056, 1, 0.10002044788922305`], 
        Hue[0.6499835735373027, 1, 0.1000227443329655], 
        Hue[0.6499452554080251, 1, 0.10007580020427298`], 
        Hue[0.6499452554080251, 1, 0.10007580020427298`], 
        Hue[0.6397468996933219, 1, 0.1141966004246313], 
        Hue[0.6413526165411418, 1, 0.1119733001738037], 
        Hue[0.6189168169696497, 1, 0.14303825342663892`], 
        Hue[0.6139274757408153, 1, 0.14994657205117884`], 
        Hue[0.5666286137183364, 1, 0.21543730408230344`], 
        Hue[0.6499979259072688, 1, 0.10000287182070478`], 
        Hue[0.634303883883022, 1, 0.12173308385427735`], 
        Hue[0.6113350077372445, 1, 0.15353614313304617`], 
        Hue[0.615088110609863, 1, 0.14833953915557424`], 
        Hue[0.6228939004999126, 1, 0.13753152238473657`], 
        Hue[0.6499903637000147, 1, 0.10001334256921046`], 
        Hue[0.6499998973914634, 1, 0.10000014207335849`], 
        Hue[0.6497210465128499, 1, 0.10038624328990012`], 
        Hue[0.6499317360308978, 1, 0.10009451934183383`], 
        Hue[0.649988567829675, 1, 0.10001582915891158`], 
        Hue[0.649986680500004, 1, 0.1000184423846099], 
        Hue[0.6499987371330672, 1, 0.10000174858498384`], 
        Hue[0.6499992903837791, 1, 0.10000098254553669`], 
        Hue[0.6499892775816672, 1, 0.10001484642538383`], 
        Hue[0.6499935635661466, 1, 0.10000891198533556`], 
        Hue[0.6499547241190271, 1, 0.10006268968134718`], 
        Hue[0.6499821959348161, 1, 0.10002465178256234`], 
        Hue[0.6499904136321839, 1, 0.10001327343236079`], 
        Hue[0.649986680500004, 1, 0.10001844238460987`], 
        Hue[0.6499317360308979, 1, 0.10009451934183364`], 
        Hue[0.6497210465128498, 1, 0.1003862432899004], 
        Hue[0.10275085519733629`, 1, 0.8577295851113805], 
        Hue[0.6499973394962008, 1, 0.10000368377449126`], 
        Hue[0.649998345225296, 1, 0.1000022912265133], 
        Hue[0.6499995636115868, 1, 0.10000060423011056`], 
        Hue[0.6499979068548963, 1, 0.10000289820091286`], 
        Hue[0.6150881106096312, 1, 0.14833953915589532`], 
        Hue[0.6228939004996968, 1, 0.1375315223850352], 
        Hue[0.6424451989541747, 1, 0.11046049375575805`], 
        Hue[0.6427107986431146, 1, 0.1100927403403028], 
        Hue[0.649950538320686, 1, 0.10006848540212708`], 
        Hue[0.6189168169701293, 1, 0.1430382534259747], 
        Hue[0.6139274757414217, 1, 0.14994657205033926`], 
        Hue[0.6413526165411501, 1, 0.11197330017379226`], 
        Hue[0.6447609920662616, 1, 0.10725401098517635`], 
        Hue[0.6496495783709018, 1, 0.10048519917875146`], 
        Hue[0.649652358023095, 1, 0.10048135042956088`], 
        Hue[0.649621458422494, 1, 0.10052413449193147`], 
        Hue[0.6499941827230284, 1, 0.1000080546911914], 
        Hue[0.6499329557399242, 1, 0.10009283051395124`], 
        Hue[0.6499430494131799, 1, 0.10007885465867403`], 
        Hue[0.649979910447695, 1, 0.10002781630319159`], 
        Hue[0.6499713297183559, 1, 0.10003969731304567`], 
        Hue[0.649976389667182, 1, 0.10003269123005579`], 
        Hue[0.6499205322569599, 1, 0.10011003225959407`], 
        Hue[0.6499309840236278, 1, 0.10009556058266918`], 
        Hue[0.6499926102537842, 1, 0.10001023195629886`], 
        Hue[0.6499766758185227, 1, 0.100032295020507], 
        Hue[0.6499906782378703, 1, 0.10001290705525656`], 
        Hue[0.6499713297183559, 1, 0.10003969731304568`], 
        Hue[0.649976389667182, 1, 0.10003269123005579`], 
        Hue[0.6499996709568588, 1, 0.10000045559819547`], 
        Hue[0.649999779338247, 1, 0.10000030553165791`], 
        Hue[0.6498321507756425, 1, 0.10023240661834114`], 
        Hue[0.07116385446886919, 1, 0.9014654322738734], 
        Hue[0.649621135370493, 1, 0.10052458179470194`], 
        Hue[0.6499996709568588, 1, 0.10000045559819547`], 
        Hue[0.6499998525302062, 1, 0.10000020418894534`], 
        Hue[0.649999779338247, 1, 0.10000030553165791`], 
        Hue[0.6499997881961503, 1, 0.10000029326686882`], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.649940220239339, 1, 0.1000827719762999], 
        Hue[0.6499302912297338, 1, 0.10009651983575332`], 
        Hue[0.6497575876165925, 1, 0.10033564791548731`], 
        Hue[0.649717658604433, 1, 0.10039093424001597`], 
        Hue[0.5985789422584306, 1, 0.17119838764217316`], 
        Hue[0.6361358775824967, 1, 0.11919647719346611`], 
        Hue[0.6465876268599808, 1, 0.10472482434771894`], 
        Hue[0.6499984458205482, 1, 0.1000021519407794], 
        Hue[0.6499984458205482, 1, 0.1000021519407794], 
        Hue[0.6496628369321749, 1, 0.10046684117083483`], 
        Hue[0.5991253617568926, 1, 0.17044180679814872`], 
        Hue[0.5936528925800798, 1, 0.17801907181219717`], 
        Hue[0.6499122626117608, 1, 0.10012148253756195`], 
        Hue[0.6498691588927481, 1, 0.10018116461004108`], 
        Hue[0.6499509547899046, 1, 0.10006790875243984`], 
        Hue[0.6449129383762623, 1, 0.10704362378671385`], 
        Hue[0.6447410918958291, 1, 0.10728156506731357`], 
        Hue[0.6447410918958292, 1, 0.10728156506731355`], 
        Hue[0.6474431293251607, 1, 0.10354028247285443`], 
        Hue[0.6499917352412674, 1, 0.10001144351209136`], 
        Hue[0.6499817734807857, 1, 0.10002523671891218`], 
        Hue[0.6416068802400537, 1, 0.11162124274454101`], 
        Hue[0.6499940613673298, 1, 0.10000822272215877`], 
        Hue[0.6498321507756425, 1, 0.10023240661834114`], 
        Hue[0.6496444802835842, 1, 0.10049225806888334`], 
        Hue[0.6497775656083637, 1, 0.10030798608072715`], 
        Hue[0.6497176586044328, 1, 0.10039093424001616`], 
        Hue[0.649947428513126, 1, 0.10007279128951778`], 
        Hue[0.6499302912297339, 1, 0.10009651983575313`], 
        Hue[0.6499999025254264, 1, 0.10000013496479421`], 
        Hue[0.6498691588927484, 1, 0.10018116461004063`], 
        Hue[0.6499398049604824, 1, 0.10008334697779356`], 
        Hue[0.6499509547899049, 1, 0.10006790875243936`], 
        Hue[0.03305932787447796, 1, 0.9542255460199536], 
        Hue[0.05053038130973697, 1, 0.9300348566480564], 
        Hue[0.6499983626934944, 1, 0.10000226703977699`], 
        Hue[0.6499987893805093, 1, 0.10000167624237187`], 
        Hue[0.6499977154256198, 1, 0.10000316325683417`], 
        Hue[0.6450736851083142, 1, 0.10682105138848805`], 
        Hue[0.6450736851083142, 1, 0.10682105138848805`], 
        Hue[0.6465876268599643, 1, 0.10472482434774175`], 
        Hue[0.6491923510353136, 1, 0.1011182831818735], 
        Hue[0.646236624228737, 1, 0.10521082799097971`], 
        Hue[0.6454530964615557, 1, 0.10629571259169222`], 
        Hue[0.6459907714908584, 1, 0.10555123947419615`], 
        Hue[0.6448435305234965, 1, 0.10713972696746633`], 
        Hue[0.5961398668207601, 1, 0.1745755690174091], 
        Hue[0.5988995745045004, 1, 0.170754435301461], 
        Hue[0.5856170866541521, 1, 0.18914557232502022`], 
        Hue[0.6499896086305067, 1, 0.10001438805006765`], 
        Hue[0.6499845305213169, 1, 0.10002141927817668`], 
        Hue[0.6498891968769868, 1, 0.10015341970878756`], 
        Hue[0.6499289484739933, 1, 0.10009837903600931`], 
        Hue[0.6499928871566862, 1, 0.10000984855228068`], 
        Hue[0.5901051118871274, 1, 0.1829313835409005], 
        Hue[0.6072701026756729, 1, 0.159164473218299], 
        Hue[0.595645576906745, 1, 0.17525997043681454`], 
        Hue[0.6444958224282412, 1, 0.1076211689455122], 
        Hue[0.6490376229975539, 1, 0.10133252200338695`], 
        Hue[0.6498946193265016, 1, 0.10014591170176697`], 
        Hue[0.6499308362608209, 1, 0.1000957651773249], 
        Hue[0.6499948524777456, 1, 0.10000712733850615`], 
        Hue[0.649994143903924, 1, 0.10000810844072064`], 
        Hue[0.6498166833888368, 1, 0.1002538230000721], 
        Hue[0.6499587350003936, 1, 0.10005713615330115`], 
        Hue[0.6499998252030462, 1, 0.10000024202655138`], 
        Hue[0.6476127536334878, 1, 0.10330541804594007`], 
        Hue[0.6499581095157081, 1, 0.10005800220901967`], 
        Hue[0.6498383027784684, 1, 0.10022388846058226`], 
        Hue[0.6494842522907945, 1, 0.10071411221274607`], 
        Hue[0.6499119444868923, 1, 0.10012192301814919`], 
        Hue[0.6490246129733724, 1, 0.10135053588302283`], 
        Hue[0.6486614185740522, 1, 0.1018534204359277], 
        Hue[0.6490374185577825, 1, 0.10133280507383957`], 
        Hue[0.6476512819637038, 1, 0.10325207112717934`], 
        Hue[0.6479788895815403, 1, 0.10279846057940577`], 
        Hue[0.6489306887868327, 1, 0.1014805847566932], 
        Hue[0.6460978666860362, 1, 0.10540295381933454`], 
        Hue[0.6493199214653446, 1, 0.10094164720183067`], 
        Hue[0.6475834488846838, 1, 0.10334599385197639`], 
        Hue[0.6327196532763, 1, 0.12392663392512315`], 
        Hue[0.6499973394962008, 1, 0.10000368377449126`], 
        Hue[0.45983657272680345`, 1, 0.3633032069936568], 
        Hue[0.5972214239242457, 1, 0.1730780284125829], 
        Hue[0.6443792387298601, 1, 0.10778259252788604`], 
        Hue[0.6472945453822796, 1, 0.10374601408607448`], 
        Hue[0.6494380510073349, 1, 0.10077808322061334`], 
        Hue[0.6497422006045632, 1, 0.10035695300906636`], 
        Hue[0.6446614119197689, 1, 0.1073918911880123], 
        Hue[0.6498543989283845, 1, 0.1002016014837754], 
        Hue[0.6489814055841804, 1, 0.10141036149882726`], 
        Hue[0.6477602551397652, 1, 0.10310118519109432`], 
        Hue[0.6490601902829679, 1, 0.10130127499281374`], 
        Hue[0.6472376528774036, 1, 0.10382478832359494`], 
        Hue[0.6496859288220751, 1, 0.10043486778481911`], 
        Hue[0.6491243397305978, 1, 0.1012124526807107], 
        Hue[0.6486561461999454, 1, 0.10186072064622959`], 
        Hue[0.6488750409140392, 1, 0.1015576356574842], 
        Hue[0.6499987823857478, 1, 0.1000016859274261], 
        Hue[0.6498176582689631, 1, 0.10025247316605117`], 
        Hue[0.6447269791198692, 1, 0.10730110583402737`], 
        Hue[0.6066823642767425, 1, 0.15997826484758743`], 
        Hue[0.6475890729501602, 1, 0.1033382066843936], 
        Hue[0.6449354756217119, 1, 0.1070124183699374], 
        Hue[0.6494383119686701, 1, 0.10077772188953373`], 
        Hue[0.6499098804701534, 1, 0.10012478088747992`], 
        Hue[0.6499098804701535, 1, 0.1001247808874797], 
        Hue[0.6492133707832605, 1, 0.10108917891548559`], 
        Hue[0.6494383119686716, 1, 0.10077772188953155`], 
        Hue[0.6449363081981928, 1, 0.10701126557173313`], 
        Hue[0.42186155100379946`, 1, 0.4158840063024316], 
        Hue[0.6475890729501655, 1, 0.10333820668438627`], 
        Hue[0.6066823642771308, 1, 0.1599782648470497], 
        Hue[0.6448226855248731, 1, 0.1071685892732527], 
        Hue[0.649817658268963, 1, 0.10025247316605124`], 
        Hue[0.6497216634938592, 1, 0.10038538900850273`], 
        Hue[0.6499852500802349, 1, 0.10002042296582866`], 
        Hue[0.649652358023096, 1, 0.1004813504295595], 
        Hue[0.6475004150899573, 1, 0.1034609637215976], 
        Hue[0.6485711159572849, 1, 0.10197845482837478`], 
        Hue[0.5947857583623852, 1, 0.17645048842131275`], 
        Hue[0.6066857938385622, 1, 0.15997351622352923`], 
        Hue[0.6330024607853376, 1, 0.12353505429722485`], 
        Hue[0.6486670765987, 1, 0.10184558624795385`], 
        Hue[0.369936658750547, 1, 0.48778001096078116`], 
        Hue[0.4218763261831908, 1, 0.4158635483617358], 
        Hue[0.6492143200935557, 1, 0.10108786448584597`], 
        Hue[0.10550699045395528`, 1, 0.853913397832985], 
        Hue[0.19694005227927658`, 1, 0.7273137737671554], 
        Hue[0.10551553714730144`, 1, 0.8539015639498903], 
        Hue[0.6492143200935481, 1, 0.10108786448585651`], 
        Hue[0.6483449140191628, 1, 0.10229165751192848`], 
        Hue[0.42187632618421733`, 1, 0.41586354836031447`], 
        Hue[0.3699389649367029, 1, 0.48777681777994986`], 
        Hue[0.594785897687917, 1, 0.176450295509038], 
        Hue[0.6475004150899578, 1, 0.10346096372159692`], 
        Hue[0.6496523174518581, 1, 0.10048140660511957`], 
        Hue[0.6489651538469169, 1, 0.10143286390426892`], 
        Hue[0.6499852320800057, 1, 0.10002044788922296`], 
        Hue[0.6498180333025885, 1, 0.1002519538887237], 
        Hue[0.6497216634938593, 1, 0.10038538900850262`], 
        Hue[0.649941550412067, 1, 0.10008093019867641`], 
        Hue[0.6497967031430822, 1, 0.10028148795573225`], 
        Hue[0.649941550412067, 1, 0.10008093019867643`], 
        Hue[0.6448143518714418, 1, 0.10718012817800371`], 
        Hue[0.6329576816102662, 1, 0.12359705623193912`], 
        Hue[0.6448140890408159, 1, 0.10718049209733183`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.649721605398353, 1, 0.10038546944843434`], 
        Hue[0.6450803703104622, 1, 0.10681179495474478`], 
        Hue[0.6497970985365656, 1, 0.10028094048783229`], 
        Hue[0.6497970985365656, 1, 0.10028094048783216`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499418600005051, 1, 0.1000805015377621], 
        Hue[0.6450814653729043, 1, 0.10681027871444017`], 
        Hue[0.6499565454836217, 1, 0.10006016779190843`], 
        Hue[0.6499565454836217, 1, 0.1000601677919084], 
        Hue[0.6454889217763369, 1, 0.1062461083096875], 
        Hue[0.6329576816103337, 1, 0.12359705623184569`], 
        Hue[0.6499418600005051, 1, 0.10008050153776213`], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499996087792145, 1, 0.10000054169031844`], 
        Hue[0.6499567540632241, 1, 0.10005987898938218`], 
        Hue[0.6474431293251608, 1, 0.10354028247285428`], 
        Hue[0.6454878932078032, 1, 0.10624753248150337`], 
        Hue[0.6450761923628122, 1, 0.10681757980533695`], 
        Hue[0.5666286137182623, 1, 0.21543730408240602`], 
        Hue[0.6499971946455725, 1, 0.10000388433689966`], 
        Hue[0.6442370654339595, 1, 0.10797944786067142`], 
        Hue[0.6473386224356845, 1, 0.10368498431982147`], 
        Hue[0.6425433794512151, 1, 0.1103245515290868], 
        Hue[0.6499097362338684, 1, 0.10012498059925916`], 
        Hue[0.6497911224533827, 1, 0.10028921506454719`], 
        Hue[0.6497234483054741, 1, 0.10038291773088195`], 
        Hue[0.649995891364032, 1, 0.10000568888057104`], 
        Hue[0.6499997133311914, 1, 0.10000039692604273`], 
        Hue[0.6497233765288313, 1, 0.10038301711392589`], 
        Hue[0.6497943170473904, 1, 0.10028479178053641`], 
        Hue[0.6499458125596493, 1, 0.10007502876356245`], 
        Hue[0.6489344903150339, 1, 0.10147532110226072`], 
        Hue[0.6486593996716279, 1, 0.10185621583928456`], 
        Hue[0.6489003584073849, 1, 0.10152258066669777`], 
        Hue[0.6499848496426992, 1, 0.10002097741780107`], 
        Hue[0.648945328630618, 1, 0.10146031420375959`], 
        Hue[0.6495908047814821, 1, 0.10056657799487091`], 
        Hue[0.6472015028703471, 1, 0.10387484217951948`], 
        Hue[0.6495371410484513, 1, 0.10064088162522138`], 
        Hue[0.6479012991383333, 1, 0.10290589350076933`], 
        Hue[0.6445975391505655, 1, 0.10748033040690941`], 
        Hue[0.4363713103250134, 1, 0.39579357031921225`], 
        Hue[0.3699378118431322, 1, 0.48777841437104774`], 
        Hue[0.4363885413626311, 1, 0.3957697119594339], 
        Hue[0.6479116918971519, 1, 0.10289150352702038`], 
        Hue[0.649559230442396, 1, 0.10061029631052858`], 
        Hue[0.6491292687549561, 1, 0.10120562787775308`], 
        Hue[0.10275085520088556`, 1, 0.8577295851064661], 
        Hue[0.6489000604437772, 1, 0.10152299323169314`], 
        Hue[0.6472086250834637, 1, 0.10386498065366576`], 
        Hue[0.5936528925800799, 1, 0.17801907181219712`], 
        Hue[0.6099350580464594, 1, 0.1554745350125947], 
        Hue[0.647201502870347, 1, 0.10387484217951967`], 
        Hue[0.648900358407385, 1, 0.10152258066669763`], 
        Hue[0.6473904480212564, 1, 0.10361322581672193`], 
        Hue[0.6463615928568269, 1, 0.105037794505932], 
        Hue[0.6448435305234965, 1, 0.10713972696746633`], 
        Hue[0.6447636185417649, 1, 0.10725037432678715`], 
        Hue[0.648659399671628, 1, 0.10185621583928438`], 
        Hue[0.6480246283909675, 1, 0.10273512992019884`], 
        Hue[0.6496495783709018, 1, 0.10048519917875146`], 
        Hue[0.6479012991383548, 1, 0.1029058935007395], 
        Hue[0.6489344903150339, 1, 0.10147532110226079`], 
        Hue[0.6495371410484526, 1, 0.10064088162521953`], 
        Hue[0.6495371410484527, 1, 0.10064088162521938`], 
        Hue[0.648934490315034, 1, 0.10147532110226068`], 
        Hue[0.647901299138362, 1, 0.10290589350072946`], 
        Hue[0.6480246283909674, 1, 0.10273512992019894`], 
        Hue[0.6486593996716278, 1, 0.1018562158392846], 
        Hue[0.6447636185419895, 1, 0.1072503743264761], 
        Hue[0.6448142204560843, 1, 0.10718031013772958`], 
        Hue[0.646361592856824, 1, 0.10503779450593599`], 
        Hue[0.6473904480212559, 1, 0.1036132258167227], 
        Hue[0.6489003584073845, 1, 0.1015225806666984], 
        Hue[0.6472015028703367, 1, 0.10387484217953377`], 
        Hue[0.6099350580461176, 1, 0.15547453501306802`], 
        Hue[0.5947858280247514, 1, 0.17645039196572884`], 
        Hue[0.647208625083455, 1, 0.1038649806536777], 
        Hue[0.6489000604437767, 1, 0.10152299323169388`], 
        Hue[0.19694005227927797`, 1, 0.7273137737671536], 
        Hue[0.6491292687549454, 1, 0.10120562787776805`], 
        Hue[0.649559230442397, 1, 0.10061029631052726`], 
        Hue[0.6479116918971736, 1, 0.1028915035269904], 
        Hue[0.5666286137182632, 1, 0.2154373040824048], 
        Hue[0.43638854136357774`, 1, 0.39576971195812316`], 
        Hue[0.36993781184416613`, 1, 0.4877784143696161], 
        Hue[0.4363713103265153, 1, 0.3957935703171326], 
        Hue[0.6479012991383548, 1, 0.10290589350073955`], 
        Hue[0.6495371410484525, 1, 0.10064088162521961`], 
        Hue[0.6472015028703471, 1, 0.10387484217951946`], 
        Hue[0.6495908047814821, 1, 0.10056657799487088`], 
        Hue[0.6489453286306182, 1, 0.10146031420375949`], 
        Hue[0.6489003584073851, 1, 0.10152258066669752`], 
        Hue[0.648659399671628, 1, 0.10185621583928439`], 
        Hue[0.6489344903150338, 1, 0.10147532110226089`], 
        Hue[0.6499948664608386, 1, 0.10000710797730039`], 
        Hue[0.6499458125596493, 1, 0.10007502876356242`], 
        Hue[0.6497943170473904, 1, 0.10028479178053637`], 
        Hue[0.6497233765288313, 1, 0.100383017113926], 
        Hue[0.649995891364032, 1, 0.10000568888057104`], 
        Hue[0.6497234483054742, 1, 0.10038291773088184`], 
        Hue[0.6497911224533826, 1, 0.10028921506454724`], 
        Hue[0.6499455194466978, 1, 0.10007543461226463`], 
        Hue[0.6473908758804227, 1, 0.10361263339633786`], 
        Hue[0.649128269088777, 1, 0.1012070120309243], 
        Hue[0.64459851077779, 1, 0.10747898507690626`], 
        Hue[0.4363713103247258, 1, 0.3957935703196105], 
        Hue[0.6446917420522249, 1, 0.10734989561999628`], 
        Hue[0.6446917420519871, 1, 0.10734989562032558`], 
        Hue[0.4363713103265097, 1, 0.39579357031714046`], 
        Hue[0.6445985107778432, 1, 0.10747898507683241`], 
        Hue[0.6491282690888007, 1, 0.10120701203089132`], 
        Hue[0.6473908758804227, 1, 0.10361263339633796`], 
        Hue[0.6499455194466978, 1, 0.10007543461226466`], 
        Hue[0.649824821602494, 1, 0.10024255470423904`], 
        Hue[0.6499597831211297, 1, 0.1000556849092051], 
        Hue[0.6489000604437772, 1, 0.10152299323169305`], 
        Hue[0.649559230442397, 1, 0.10061029631052716`], 
        Hue[0.6486631270815442, 1, 0.10185105481016969`], 
        Hue[0.6489453286306182, 1, 0.10146031420375946`], 
        Hue[0.6497943170473904, 1, 0.10028479178053637`], 
        Hue[0.6497911224533827, 1, 0.10028921506454717`], 
        Hue[0.6479116918971737, 1, 0.10289150352699036`], 
        Hue[0.6472086250834638, 1, 0.10386498065366556`], 
        Hue[0.6497234483054741, 1, 0.10038291773088194`], 
        Hue[0.6445975391506519, 1, 0.10748033040678968`], 
        Hue[0.645284131759114, 1, 0.10652966371814983`], 
        Hue[0.6498244600804971, 1, 0.10024305527315781`], 
        Hue[0.6334776944950843, 1, 0.12287703839142183`], 
        Hue[0.6445985107777569, 1, 0.1074789850769521], 
        Hue[0.4363885413636581, 1, 0.3957697119580119], 
        Hue[0.6099395356971271, 1, 0.15546833518859332`], 
        Hue[0.609935058046162, 1, 0.15547453501300657`], 
        Hue[0.649128269088788, 1, 0.10120701203090902`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6496495783709008, 1, 0.10048519917875282`], 
        Hue[0.10275085519718585`, 1, 0.8577295851115888], 
        Hue[0.3699378118441581, 1, 0.4877784143696273], 
        Hue[0.5947858280254814, 1, 0.17645039196471807`], 
        Hue[0.6499848496426992, 1, 0.10002097741780114`], 
        Hue[0.6499997133311914, 1, 0.10000039692604273`], 
        Hue[0.5936528925793111, 1, 0.17801907181326163`], 
        Hue[0.3699378118423824, 1, 0.4877784143720859], 
        Hue[0.649128269088777, 1, 0.10120701203092423`], 
        Hue[0.609939535696351, 1, 0.155468335189668], 
        Hue[0.4363885413622587, 1, 0.3957697119599496], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6099350580464612, 1, 0.15547453501259223`], 
        Hue[0.6445985107777901, 1, 0.10747898507690615`], 
        Hue[0.6334776944949212, 1, 0.12287703839164765`], 
        Hue[0.6498244600804972, 1, 0.1002430552731577], 
        Hue[0.6452841317591499, 1, 0.10652966371810024`], 
        Hue[0.6497234483054742, 1, 0.10038291773088183`], 
        Hue[0.6445975391506057, 1, 0.10748033040685363`], 
        Hue[0.6497943170473904, 1, 0.10028479178053638`], 
        Hue[0.6489453286306182, 1, 0.10146031420375946`], 
        Hue[0.6472086250834637, 1, 0.10386498065366578`], 
        Hue[0.6479116918971799, 1, 0.10289150352698177`], 
        Hue[0.6497911224533826, 1, 0.10028921506454722`], 
        Hue[0.6486631270815439, 1, 0.10185105481016991`], 
        Hue[0.6489000604437771, 1, 0.10152299323169331`], 
        Hue[0.6495592304423972, 1, 0.10061029631052709`], 
        Hue[0.6499597831211297, 1, 0.10005568490920513`], 
        Hue[0.6473904480212564, 1, 0.10361322581672185`], 
        Hue[0.6486631270815439, 1, 0.10185105481016993`], 
        Hue[0.6452851935746376, 1, 0.10652819351204024`], 
        Hue[0.6499599794841723, 1, 0.10005541302191531`], 
        Hue[0.19694005227972972`, 1, 0.7273137737665281], 
        Hue[0.6499599794841723, 1, 0.10005541302191528`], 
        Hue[0.6486631270815442, 1, 0.10185105481016965`], 
        Hue[0.6452851935746403, 1, 0.10652819351203645`], 
        Hue[0.6473904480212564, 1, 0.10361322581672192`], 
        Hue[0.6498248216024941, 1, 0.10024255470423891`], 
        Hue[0.6491292687549689, 1, 0.10120562787773542`], 
        Hue[0.6491292687549453, 1, 0.10120562787776811`], 
        Hue[0.6499455194466978, 1, 0.10007543461226463`], 
        Hue[0.6498244600804972, 1, 0.10024305527315769`], 
        Hue[0.6498244600804971, 1, 0.10024305527315783`], 
        Hue[0.6499455194466978, 1, 0.10007543461226467`], 
        Hue[0.6497233765288313, 1, 0.100383017113926], 
        Hue[0.6334703961606172, 1, 0.12288714377760701`], 
        Hue[0.6448435305234644, 1, 0.1071397269675108], 
        Hue[0.6334703961606807, 1, 0.12288714377751916`], 
        Hue[0.6497223596864661, 1, 0.10038442504950848`], 
        Hue[0.6446917420519871, 1, 0.10734989562032567`], 
        Hue[0.6452841317591496, 1, 0.10652966371810071`], 
        Hue[0.6498248216024941, 1, 0.10024255470423904`], 
        Hue[0.6498248216024941, 1, 0.10024255470423893`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499171656570684, 1, 0.10011469370559767`], 
        Hue[0.6499458125596493, 1, 0.10007502876356242`], 
        Hue[0.633477694494929, 1, 0.12287703839163683`], 
        Hue[0.6452851935746035, 1, 0.1065281935120876], 
        Hue[0.6099395356963766, 1, 0.15546833518963252`], 
        Hue[0.6499597831211297, 1, 0.10005568490920515`], 
        Hue[0.6499597831211297, 1, 0.10005568490920512`], 
        Hue[0.6452851935746391, 1, 0.1065281935120382], 
        Hue[0.6099395356970551, 1, 0.15546833518869302`], 
        Hue[0.6334703961606802, 1, 0.1228871437775197], 
        Hue[0.6334776944950551, 1, 0.12287703839146225`], 
        Hue[0.6446917420522449, 1, 0.10734989561996859`], 
        Hue[0.6499458125596493, 1, 0.10007502876356243`], 
        Hue[0.6499171656570687, 1, 0.1001146937055972], 
        Hue[0.6499599794841723, 1, 0.1000554130219153], 
        Hue[0.6499599794841723, 1, 0.10005541302191527`], 
        Hue[0.6496495783709015, 1, 0.10048519917875173`], 
        Hue[0.6499997433419163, 1, 0.10000035537273123`], 
        Hue[0.6499848496426992, 1, 0.10002097741780114`], 
        Hue[0.649649578370901, 1, 0.10048519917875254`], 
        Hue[0.6499848496426992, 1, 0.10002097741780107`], 
        Hue[0.6499962816736484, 1, 0.10000514845187147`], 
        Hue[0.6499997433419163, 1, 0.10000035537273122`], 
        Hue[0.649995891364032, 1, 0.10000568888057104`], 
        Hue[0.6452841317591498, 1, 0.10652966371810027`], 
        Hue[0.6473908758804225, 1, 0.10361263339633812`], 
        Hue[0.6473908758804222, 1, 0.10361263339633854`], 
        Hue[0.6447636185419683, 1, 0.10725037432650547`], 
        Hue[0.6447636185417653, 1, 0.10725037432678652`], 
        Hue[0.5666286137183357, 1, 0.21543730408230438`], 
        Hue[0.6334703961606387, 1, 0.12288714377757717`], 
        Hue[0.6499171656570683, 1, 0.10011469370559789`], 
        Hue[0.6499171656570684, 1, 0.10011469370559768`], 
        Hue[0.10275085519733629`, 1, 0.8577295851113804], 
        Hue[0.6499963043540927, 1, 0.10000511704817927`], 
        Hue[0.6424451989541748, 1, 0.11046049375575796`], 
        Hue[0.10275085519977556`, 1, 0.857729585108003], 
        Hue[0.6499165878991569, 1, 0.10011549367809063`], 
        Hue[0.6448435305234992, 1, 0.10713972696746267`], 
        Hue[0.6499169060240259, 1, 0.10011505319750269`], 
        Hue[0.6445750019051109, 1, 0.10751153582369267`], 
        Hue[0.6425433794512151, 1, 0.11032455152908685`], 
        Hue[0.6499165878991569, 1, 0.10011549367809049`], 
        Hue[0.6499165878991573, 1, 0.10011549367808992`], 
        Hue[0.6499948524777456, 1, 0.10000712733850615`]},
      VertexNormals->CompressedData["
1:eJw8XHc8le//lhFlyx4hq6JBkpFzkyIqK1JShIQyiqhEkUoUH0KkpGWGJC3q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       "]],
     Axes->True,
     BoxRatios->{1, 1, 0.4},
     DisplayFunction->((Print[#]; #)& ),
     FormatType->OutputForm,
     Lighting->"Neutral",
     Method->{"RotationControl" -> "Globe"},
     PlotLabel->"Surface Intensity",
     PlotRange->All,
     PlotRangePadding->{Automatic, Automatic, Automatic}]}], ",", 
   RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
   RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
   RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
   RowBox[{"SmoothKernelSize", "\[Rule]", "0.009487737662714256`"}], ",", 
   RowBox[{"RayBoundary", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.05251096725908422`"}], ",", "0.05251096725908422`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.05251096725908422`"}], ",", "0.05251096725908422`"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"NumberOfRays", "\[Rule]", "956"}], ",", 
   RowBox[{"Full3D", "\[Rule]", "True"}], ",", 
   RowBox[{"Energy", "\[Rule]", "99.25836042132417`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563367603961586*^9, 3.566087057306097*^9, 
  3.566101842976563*^9, 3.5661392887782993`*^9, 3.614707872822344*^9},
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->"Out[70]=",ExpressionUUID->"faea0d3b-afe1-4883-b972-798f0b1cc126"]
}, Open  ]],

Cell[TextData[{
 "Previously, we had used ",
 StyleBox["Plot2D -> False", "Input"],
 " to display a three-dimensional plot of the surface intensity profile. Next \
we will call ",
 StyleBox["FindIntensity", "Input"],
 " for a second time with ",
 StyleBox["Plot2D -> True", "Input"],
 " to examine the intensity function along the horizontal-axis of each \
surface."
}], "Text",
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"41ceb80e-2181-4cd7-b774-e47b379c16d3"],

Cell[CellGroupData[{

Cell["FindIntensity[focusintensity, Plot2D -> True];", "Input",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->"In[71]:=",ExpressionUUID->"4bb39fd2-06ac-4850-8973-a84b4945ffe4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "956"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.009487737662714256`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 3., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 956, Optica`Optica`SmoothKernelSize -> 
    0.009487737662714256}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563367605731072*^9, 3.566087057632818*^9, 
  3.566101843278183*^9, 3.566139289207*^9, 3.6147078731831207`*^9},
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->
  "During evaluation of \
In[71]:=",ExpressionUUID->"e31d0700-a56e-4a47-9922-4c9df4642880"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxNmHk0VW/Y/hVKKGMylChkKCQNxvsRMmRKlCgzCRnLPJUiMpN5Ho6Zcw5J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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl12WcVVUYxeE7dEuH5CCNhEWHQTcjXQoqqWKA3Q2o2IAKKmDRYYBBSRh0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      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999987595857, 1, 0.10000000171749676`], 
     Hue[0.6499999570444391, 1, 0.10000005947693046`], 
     Hue[0.6499989027279862, 1, 0.10000151929971147`], 
     Hue[0.6499852311579242, 1, 0.10002044916595111`], 
     Hue[0.6498360615543404, 1, 0.10022699169399035`], 
     Hue[0.6487683957861401, 1, 0.10170529814226766`], 
     Hue[0.6430950377920042, 1, 0.1095607169033789], 
     Hue[0.6089881422143617, 1, 0.15678564924165306`], 
     Hue[0.495776915507658, 1, 0.3135396554509351], 
     Hue[0.3021792378647242, 1, 0.5815979783411511], 
     Hue[0.11541773494486485`, 1, 0.8401908285378794], 
     Hue[0.01774277014186798, 1, 0.9754330874958751], 
     Hue[0.012139980318543797`, 1, 0.9831907964820162], 
     Hue[0.10998918930687873`, 1, 0.8477072763443217], 
     Hue[0.2777984162909474, 1, 0.6153560389817652], 
     Hue[0.4905593921076993, 1, 0.3207639186201087], 
     Hue[0.6067962370094394, 1, 0.15982059491000697`], 
     Hue[0.6427953302673834, 1, 0.10997569655285365`], 
     Hue[0.6488704835567435, 1, 0.10156394584450908`], 
     Hue[0.6498288324797792, 1, 0.1002370011818443], 
     Hue[0.6499842422860722, 1, 0.10002181837313079`], 
     Hue[0.6499988381128619, 1, 0.10000160876680671`], 
     Hue[0.6499999397166153, 1, 0.10000008346930193`], 
     Hue[0.6499999986552525, 1, 0.10000000186195815`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999919210153, 1, 0.1000000111862866], 
     Hue[0.6499997690621028, 1, 0.10000031976016548`], 
     Hue[0.6499957754533446, 1, 0.10000584937229205`], 
     Hue[0.6499482551111707, 1, 0.10007164676914826`], 
     Hue[0.6495345013474286, 1, 0.1006445365958681], 
     Hue[0.6470640487883708, 1, 0.10406516321610211`], 
     Hue[0.6327628784675728, 1, 0.12386678366028381`], 
     Hue[0.5656825152401651, 1, 0.21674728659054068`], 
     Hue[0.4040791651717768, 1, 0.44050577130061674`], 
     Hue[0.19888365998042812`, 1, 0.7246226246424842], 
     Hue[0.0571461870081964, 1, 0.9208745102963435], 
     Hue[0.00014155855340813872`, 1, 0.9998039958491273], 
     Hue[0.050202151260878125`, 1, 0.9304893290233995], 
     Hue[0.18497325762465705`, 1, 0.7438831817504749], 
     Hue[0.38872574771353263`, 1, 0.4617643493197241], 
     Hue[0.5619767641251362, 1, 0.2218783265959653], 
     Hue[0.6318956506509438, 1, 0.12506756063715474`], 
     Hue[0.6471239000860829, 1, 0.10398229218850072`], 
     Hue[0.6495463798982187, 1, 0.10062808937169722`], 
     Hue[0.6499454231946515, 1, 0.10007556788432861`], 
     Hue[0.6499955074285463, 1, 0.10000622048355133`], 
     Hue[0.6499997210810065, 1, 0.1000003861955296], 
     Hue[0.6499999899327075, 1, 0.10000001393932814`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999966719506, 1, 0.10000000460806845`], 
     Hue[0.6499998987716357, 1, 0.10000014016235066`], 
     Hue[0.6499978199210609, 1, 0.10000301857083878`], 
     Hue[0.6499719932630081, 1, 0.10003877855891186`], 
     Hue[0.6497209327798362, 1, 0.10038640076638061`], 
     Hue[0.6480928465834249, 1, 0.10264067396141172`], 
     Hue[0.6390575575908237, 1, 0.11515107410501342`], 
     Hue[0.5904183164032372, 1, 0.1824977157493639], 
     Hue[0.4521937195607664, 1, 0.3738856190697081], 
     Hue[0.2485518444857176, 1, 0.6558512922505448], 
     Hue[0.08398424019580575, 1, 0.8837141289596535], 
     Hue[0.0053527071227106315`, 1, 0.9925885593685545], 
     Hue[0.028246672890001157`, 1, 0.960889222152306], 
     Hue[0.14509699512685026`, 1, 0.7990964682858996], 
     Hue[0.33302187295361035`, 1, 0.5388927912950011], 
     Hue[0.5296456491655794, 1, 0.26664448577073624`], 
     Hue[0.6217563507946599, 1, 0.13910659120739413`], 
     Hue[0.6454438063950346, 1, 0.10630857576072128`], 
     Hue[0.6492794811126132, 1, 0.10099764153638173`], 
     Hue[0.649902189148454, 1, 0.10013543040983304`], 
     Hue[0.6499914873698582, 1, 0.10001178671865783`], 
     Hue[0.649999422888675, 1, 0.10000079907721937`], 
     Hue[0.6499999750852857, 1, 0.10000003449729669`], 
     Hue[0.6499999995340657, 1, 0.10000000064513978`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999995766492, 1, 0.10000000058617801`], 
     Hue[0.6499999811868934, 1, 0.10000002604891682`], 
     Hue[0.6499994885586885, 1, 0.10000070814950826`], 
     Hue[0.6499920091998522, 1, 0.10001106418481998`], 
     Hue[0.6499067772725531, 1, 0.10012907762261886`], 
     Hue[0.6492372758613163, 1, 0.10105607957663898`], 
     Hue[0.6454939807684126, 1, 0.10623910355142878`], 
     Hue[0.6231645680609188, 1, 0.1371567519156509], 
     Hue[0.5341495983608379, 1, 0.2604082484234552], 
     Hue[0.15437522069014953`, 1, 0.7862496944290237], 
     Hue[0.03495250760794333, 1, 0.9516042202351555], 
     Hue[0.0024570304507370855`, 1, 0.996597957837441], 
     Hue[0.07749918120209665, 1, 0.8926934414124815], 
     Hue[0.229446514040139, 1, 0.6823048267136537], 
     Hue[0.44210475543600897`, 1, 0.3878549540116799], 
     Hue[0.5875064466874689, 1, 0.18652953535581235`], 
     Hue[0.6385413652643779, 1, 0.11586580194163068`], 
     Hue[0.6481910746445878, 1, 0.10250466587672459`], 
     Hue[0.6497188720629395, 1, 0.10038925406669906`], 
     Hue[0.6499702925063836, 1, 0.1000411334526997], 
     Hue[0.6499976862567803, 1, 0.10000320364445804`], 
     Hue[0.6499998683632785, 1, 0.10000018226622978`], 
     Hue[0.6499999961215386, 1, 0.10000000537017742`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999978588689, 1, 0.10000000296464318`], 
     Hue[0.6499999339611294, 1, 0.10000009143843629`], 
     Hue[0.6499984482642926, 1, 0.10000214855713323`], 
     Hue[0.6499795944094938, 1, 0.10002825389454705`], 
     Hue[0.6497855390529128, 1, 0.1002969459267362], 
     Hue[0.6484659562655498, 1, 0.10212406055539267`], 
     Hue[0.6413035988924809, 1, 0.11204117076425722`], 
     Hue[0.6004177241848492, 1, 0.16865238189790122`], 
     Hue[0.4746527271621541, 1, 0.3427885316216328], 
     Hue[0.2749807428856876, 1, 0.6192574329275096], 
     Hue[0.09911961270393743, 1, 0.8627574593330097], 
     Hue[0.01068863440135559, 1, 0.9852003523673537], 
     Hue[0.019420114036509672`, 1, 0.9731106113340635], 
     Hue[0.12695142274714422`, 1, 0.8242211069654926], 
     Hue[0.30518212877287654`, 1, 0.5774401293914018], 
     Hue[0.5109155574233618, 1, 0.29257845895226825`], 
     Hue[0.6149671026070569, 1, 0.14850708869792134`], 
     Hue[0.6442694155801989, 1, 0.10793465535049379`], 
     Hue[0.6490965571738484, 1, 0.1012509208362099], 
     Hue[0.6498702312720064, 1, 0.10017967977722189`], 
     Hue[0.6499883840627226, 1, 0.10001608360546098`], 
     Hue[0.6499991785772757, 1, 0.1000011373545413], 
     Hue[0.6499999608386079, 1, 0.1000000542234661], 
     Hue[0.6499999991406891, 1, 0.10000000118981517`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999998377441, 1, 0.10000000022466196`], 
     Hue[0.649999987671639, 1, 0.10000001707003832`], 
     Hue[0.6499996552727808, 1, 0.10000047731461126`], 
     Hue[0.6499941722386838, 1, 0.10000806920797625`], 
     Hue[0.6499303325100904, 1, 0.1000964626783364], 
     Hue[0.6494029204692038, 1, 0.10082672550417936`], 
     Hue[0.6463618739470227, 1, 0.10503740530412241`], 
     Hue[0.6284520805408856, 1, 0.12983558078954296`], 
     Hue[0.5507845469977285, 1, 0.23737524261852977`], 
     Hue[0.1759437130346332, 1, 0.7563856281058925], 
     Hue[0.04545422167079005, 1, 0.937063385378906], 
     Hue[0.00035618299365269834`, 1, 0.9995068235472502], 
     Hue[0.06320122896401259, 1, 0.9124906060498287], 
     Hue[0.20666521807811178`, 1, 0.7138481595841529], 
     Hue[0.4158796014813757, 1, 0.4241667056411721], 
     Hue[0.5755685364005863, 1, 0.2030589495991883], 
     Hue[0.6355799956219004, 1, 0.11996615990813797`], 
     Hue[0.6477175774465963, 1, 0.1031602773816359], 
     Hue[0.6496421403921677, 1, 0.10049549791853711`], 
     Hue[0.6499596075997995, 1, 0.10005592793873908`], 
     Hue[0.6499967661162291, 1, 0.10000447768522117`], 
     Hue[0.6499998076600052, 1, 0.10000026631691589`], 
     Hue[0.6499999938179519, 1, 0.10000000855975895`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999948670745, 1, 0.10000000710712774`], 
     Hue[0.6499998465310868, 1, 0.10000021249541832`], 
     Hue[0.6499969560872395, 1, 0.10000421464843763`], 
     Hue[0.6499618086294234, 1, 0.10005288035925987`], 
     Hue[0.6496387079154099, 1, 0.10050025057866321`], 
     Hue[0.6476324499398995, 1, 0.10327814623706226`], 
     Hue[0.6362515374697252, 1, 0.11903633273422674`], 
     Hue[0.5788718565750782, 1, 0.1984851216652764], 
     Hue[0.06999433178563252, 1, 0.9030847713737397], 
     Hue[0.0018170510445381094`, 1, 0.9974840831691011], 
     Hue[0.03853234370400627, 1, 0.9466475241021451], 
     Hue[0.5466749665835448, 1, 0.24306543088432267`], 
     Hue[0.6273416536174435, 1, 0.1313730949912321], 
     Hue[0.6463790071943689, 1, 0.10501368234625848`], 
     Hue[0.6494272588271347, 1, 0.10079302623935205`], 
     Hue[0.6499267133973502, 1, 0.10010147375751521`], 
     Hue[0.649993796877837, 1, 0.10000858893837959`], 
     Hue[0.6499995975668055, 1, 0.1000005572151924], 
     Hue[0.6499999841543135, 1, 0.10000002194018143`], 
     Hue[0.649999999821463, 1, 0.10000000024720515`], 
     Hue[0.6499999993151845, 1, 0.1000000009482061], 
     Hue[0.6499999714670283, 1, 0.1000000395071917], 
     Hue[0.6499992481054965, 1, 0.10000104108469726`], 
     Hue[0.6499891067737449, 1, 0.10001508292866097`], 
     Hue[0.6498760114679637, 1, 0.1001716764289733], 
     Hue[0.6490292431124864, 1, 0.10134412492117263`], 
     Hue[0.6444210365033773, 1, 0.10772471868763137`], 
     Hue[0.616734124789199, 1, 0.14606044259957074`], 
     Hue[0.5157927643505172, 1, 0.28582540320697614`], 
     Hue[0.025693287327209435`, 1, 0.9644246790854023], 
     Hue[0.006406868653340614, 1, 0.9911289510953745], 
     Hue[0.5978783695392718, 1, 0.1721684114071622], 
     Hue[0.6409092738783994, 1, 0.11258715924529321`], 
     Hue[0.6485689230071646, 1, 0.10198149122084897`], 
     Hue[0.649780130063638, 1, 0.10030443529650128`], 
     Hue[0.6499782925631946, 1, 0.1000300564509613], 
     Hue[0.6499983549397397, 1, 0.10000227777574516`], 
     Hue[0.6499999106611284, 1, 0.10000012369997616`], 
     Hue[0.6499999975888745, 1, 0.1000000033384815], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999982875769, 1, 0.10000000237104736`], 
     Hue[0.64999994668486, 1, 0.10000007382096306`], 
     Hue[0.6499986939165981, 1, 0.10000180842317186`], 
     Hue[0.6499826265819972, 1, 0.10002405550185009`], 
     Hue[0.6498123680431962, 1, 0.10025979809403605`], 
     Hue[0.64862510897496, 1, 0.10190369526544009`], 
     Hue[0.6422502203123701, 1, 0.11073046418287213`], 
     Hue[0.6048735210468599, 1, 0.16248281701204015`], 
     Hue[0.4853921746188681, 1, 0.32791852745079814`], 
     Hue[0.28850047952231683`, 1, 0.6005377975844844], 
     Hue[0.10712189918086046`, 1, 0.8516773703649624], 
     Hue[0.014006646293381442`, 1, 0.9806061820553179], 
     Hue[0.01558106928439229, 1, 0.9784262117600723], 
     Hue[0.1183237006245823, 1, 0.8361671837505783], 
     Hue[0.2914139437301017, 1, 0.5965037702198592], 
     Hue[0.5009341420814676, 1, 0.30639888019489114`], 
     Hue[0.6110654706205737, 1, 0.15390934837151335`], 
     Hue[0.6435741195537905, 1, 0.10889737292552089`], 
     Hue[0.6489894839432289, 1, 0.1013991760786063], 
     Hue[0.6498508560823862, 1, 0.10020650696284984`], 
     Hue[0.6499864604375848, 1, 0.10001874708642106`], 
     Hue[0.6499990223072247, 1, 0.10000135372845805`], 
     Hue[0.649999951362843, 1, 0.10000006734375576`], 
     Hue[0.6499999989238046, 1, 0.10000000149011681`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999998716341, 1, 0.1000000001777373], 
     Hue[0.6499999900109829, 1, 0.10000001383094691`], 
     Hue[0.6499997176846738, 1, 0.10000039089814405`], 
     Hue[0.649995034450516, 1, 0.10000687537620874`], 
     Hue[0.649939911177576, 1, 0.1000831999079717], 
     Hue[0.6494725164386409, 1, 0.10073036185418956`], 
     Hue[0.6467315211000866, 1, 0.10452558616911098`], 
     Hue[0.63071958614134, 1, 0.12669595765045222`], 
     Hue[0.5584498341235165, 1, 0.2267617681366695], 
     Hue[0.18724536865068248`, 1, 0.7407371818682857], 
     Hue[0.051154009984101134`, 1, 0.9291713707912446], 
     Hue[0.000012040113837485933`, 1, 0.9999833290731481], 
     Hue[0.05653802843890099, 1, 0.9217165760076755], 
     Hue[0.1956778711895441, 1, 0.7290614091221698], 
     Hue[0.4023977771376405, 1, 0.44283384704019], 
     Hue[0.5689837213246479, 1, 0.21217638585817977`], 
     Hue[0.6338369771807323, 1, 0.12237957005744757`], 
     Hue[0.6474375321671166, 1, 0.10354803238399231`], 
     Hue[0.6495968908375223, 1, 0.10055815114804616`], 
     Hue[0.6499530102768692, 1, 0.10006506269356576`], 
     Hue[0.6499961854753794, 1, 0.10000528164947471`], 
     Hue[0.6499997681917754, 1, 0.10000032096523408`], 
     Hue[0.6499999920010389, 1, 0.10000001107548474`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999958628625, 1, 0.10000000572834426`], 
     Hue[0.6499998751692391, 1, 0.10000017284259208`], 
     Hue[0.6499974219745973, 1, 0.1000035695736346], 
     Hue[0.6499672679158504, 1, 0.10004532134728421`], 
     Hue[0.6496822752489173, 1, 0.1004399265784223], 
     Hue[0.64787474487832, 1, 0.10294266093771078`], 
     Hue[0.6377318055285718, 1, 0.11698673080659289`], 
     Hue[0.5848450721069699, 1, 0.19021451554419552`], 
     Hue[0.07684671959633715, 1, 0.8935968497896871], 
     Hue[0.003355474576096973, 1, 0.9953539582792503], 
     Hue[0.033212199636848516`, 1, 0.9540138774259022], 
     Hue[0.5383756680756824, 1, 0.25455676727982435`], 
     Hue[0.6246885066984148, 1, 0.1350466830329641], 
     Hue[0.6459380027013386, 1, 0.1056243039519927], 
     Hue[0.649357325526252, 1, 0.1008898569636511], 
     Hue[0.6499152710299873, 1, 0.10011731703540236`], 
     Hue[0.6499927279419067, 1, 0.10001006900351395`], 
     Hue[0.6499995174063783, 1, 0.10000066820655318`], 
     Hue[0.6499999800386811, 1, 0.10000002763874927`], 
     Hue[0.6499999996340011, 1, 0.10000000050676769`], 
     Hue[0.6499999994608191, 1, 0.10000000074655818`], 
     Hue[0.6499999769029641, 1, 0.10000003198051129`], 
     Hue[0.6499993793040153, 1, 0.1000008594252096], 
     Hue[0.6499906639882799, 1, 0.10001292678545871`], 
     Hue[0.6498924080552134, 1, 0.10014897346201229`], 
     Hue[0.6491391543786811, 1, 0.101191940091057], 
     Hue[0.6449859226768205, 1, 0.10694256860132546`], 
     Hue[0.6201029252984277, 1, 0.14139594958679247`], 
     Hue[0.525183642978733, 1, 0.2728226481832929], 
     Hue[0.030163709337872602`, 1, 0.9582348639937148], 
     Hue[0.004204349737246149, 1, 0.9941785926715053], 
     Hue[0.5928816333681948, 1, 0.1790869691824995], 
     Hue[0.6397921103852183, 1, 0.11413400100508232`], 
     Hue[0.6483906379284926, 1, 0.10222834748362562`], 
     Hue[0.6497512402599196, 1, 0.10034443656318821`], 
     Hue[0.6499745855144097, 1, 0.10003518928774043`], 
     Hue[0.649998047500806, 1, 0.10000270346042248`], 
     Hue[0.6499998913008743, 1, 0.1000001505064817], 
     Hue[0.6499999969385021, 1, 0.10000000423899713`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999973279978, 1, 0.1000000036996954], 
     Hue[0.6499999181388346, 1, 0.10000011334622903`], 
     Hue[0.6499981592973804, 1, 0.10000254866516561`], 
     Hue[0.6499760741740509, 1, 0.10003312806669878`], 
     Hue[0.6497552005838935, 1, 0.100338953037686], 
     Hue[0.6482891891759686, 1, 0.10236881498712046`], 
     Hue[0.6402435891169513, 1, 0.11350887660729814`], 
     Hue[0.5956044531556415, 1, 0.1753169110152657], 
     Hue[0.007800359289607317, 1, 0.9891995025220821], 
     Hue[0.0236457269482252, 1, 0.9672597626870728], 
     Hue[0.6185232888464531, 1, 0.1435831385202957], 
     Hue[0.6448899983066891, 1, 0.10707538695996889`], 
     Hue[0.6491928751777488, 1, 0.10111755744619393`], 
     Hue[0.6498872543462391, 1, 0.10015610936674596`], 
     Hue[0.6499900490227762, 1, 0.10001377827615607`], 
     Hue[0.6499993109455435, 1, 0.10000095407540129`], 
     Hue[0.6499999685321909, 1, 0.10000004357081263`], 
     Hue[0.6499999994084465, 1, 0.100000000819074], 
     Hue[0.6499999997955614, 1, 0.10000000028306873`], 
     Hue[0.6499999848118632, 1, 0.10000002102972796`], 
     Hue[0.6499995796476804, 1, 0.10000058202628864`], 
     Hue[0.6499931709051703, 1, 0.10000945566976423`], 
     Hue[0.649919350563331, 1, 0.10011166845077245`], 
     Hue[0.6493248303959716, 1, 0.10093485022096255`], 
     Hue[0.6459509144563771, 1, 0.10560642613732406`], 
     Hue[0.6259405817691229, 1, 0.13331304062736826`], 
     Hue[0.040051706691054956`, 1, 0.9445437907354624], 
     Hue[0.0011724112195317105`, 1, 0.9983766613883407], 
     Hue[0.5817393875039782, 1, 0.19451469422526085`], 
     Hue[0.6371425392969982, 1, 0.1178026378964642], 
     Hue[0.6479676786548162, 1, 0.1028139834010238], 
     Hue[0.6496826477767821, 1, 0.10043941077060947`], 
     Hue[0.6499653327883533, 1, 0.10004800075458771`], 
     Hue[0.6499972624728438, 1, 0.10000379042221633`], 
     Hue[0.6499998408505323, 1, 0.10000022036080139`], 
     Hue[0.6499999950977734, 1, 0.10000000678769844`], 
     Hue[0.6499999936440256, 1, 0.10000000880058002`], 
     Hue[0.6499998114534487, 1, 0.1000002610644558], 
     Hue[0.6499964113284898, 1, 0.10000496892978335`], 
     Hue[0.6499555092827468, 1, 0.10006160253158136`], 
     Hue[0.6495896624132862, 1, 0.10056815973544987`], 
     Hue[0.6473632292907446, 1, 0.10365091328973819`], 
     Hue[0.6346008750226441, 1, 0.12132186535326211`], 
     Hue[0.0007441439141230299, 1, 0.9989696468881374], 
     Hue[0.6297371483549068, 1, 0.1280562561239752], 
     Hue[0.6467725895074485, 1, 0.10446872222045585`], 
     Hue[0.6494900459567299, 1, 0.10070609021375873`], 
     Hue[0.6499367068778734, 1, 0.10008763663063679`], 
     Hue[0.6499947168140445, 1, 0.10000731518055372`], 
     Hue[0.6499996646876851, 1, 0.10000046427858987`], 
     Hue[0.6499999873563674, 1, 0.10000001750656815`], 
     Hue[0.6499999998582823, 1, 0.10000000019622458`], 
     Hue[0.6499999990100558, 1, 0.10000000137069207`], 
     Hue[0.6499999648651915, 1, 0.10000004864819641`], 
     Hue[0.6499990908533337, 1, 0.10000125881846109`], 
     Hue[0.6499873063621092, 1, 0.10001757580631034`], 
     Hue[0.649857324923019, 1, 0.10019755010658914`], 
     Hue[0.6489061701381815, 1, 0.10151453365482555`], 
     Hue[0.6437930438930989, 1, 0.10859424691724771`], 
     Hue[0.6130364297820455, 1, 0.15118032799409084`], 
     Hue[0.021549918824180336`, 1, 0.9701616508588273], 
     Hue[0.009055522872934096, 1, 0.9874615837143988], 
     Hue[0.6419062478778759, 1, 0.11120673370755649`], 
     Hue[0.6487281978934255, 1, 0.1017609567629494], 
     Hue[0.6498058899531833, 1, 0.10026876775713088`], 
     Hue[0.6499814893425971, 1, 0.10002563014101942`], 
     Hue[0.6499986161651821, 1, 0.10000191607897878`], 
     Hue[0.6499999266574893, 1, 0.10000010155116869`], 
     Hue[0.6499999981053907, 1, 0.1000000026233052], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999986157491, 1, 0.10000000191665513`], 
     Hue[0.6499999521319999, 1, 0.10000006627876938`], 
     Hue[0.6499988028251594, 1, 0.10000165762670242`], 
     Hue[0.6499839778780003, 1, 0.10002218447661497`], 
     Hue[0.6498245852128981, 1, 0.1002428820129104], 
     Hue[0.6486986320959671, 1, 0.10180189402096859`], 
     Hue[0.6426846718209357, 1, 0.11012891594024285`], 
     Hue[0.6069724319226621, 1, 0.15957663272246786`], 
     Hue[0.49063004832597956`, 1, 0.3206660869332591], 
     Hue[0.2953222309585681, 1, 0.5910922955958289], 
     Hue[0.11123292905153814`, 1, 0.8459851751594087], 
     Hue[0.015823189633991208`, 1, 0.9780909681990891], 
     Hue[0.013810071893495257`, 1, 0.9808783619936219], 
     Hue[0.11411997995294343`, 1, 0.8419877200651553], 
     Hue[0.284584824760627, 1, 0.6059594734083626], 
     Hue[0.4957949417440739, 1, 0.3135146960466669], 
     Hue[0.6089781744368316, 1, 0.15679945077977173`], 
     Hue[0.6431957445314529, 1, 0.10942127680260379`], 
     Hue[0.6489315511640148, 1, 0.10147939069597961`], 
     Hue[0.6498401938693497, 1, 0.10022127002705436`], 
     Hue[0.649985390434969, 1, 0.1000202286285045], 
     Hue[0.6499989339753761, 1, 0.10000147603409466`], 
     Hue[0.64999994583822, 1, 0.10000007499323388`], 
     Hue[0.6499999987966549, 1, 0.1000000016661701], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649999991014594, 1, 0.10000001244133136`], 
     Hue[0.6499997446009192, 1, 0.1000003536294965], 
     Hue[0.6499954189400304, 1, 0.10000634300611176`], 
     Hue[0.6499442296139947, 1, 0.10007722053446892`], 
     Hue[0.6495044086356274, 1, 0.10068620342759284`], 
     Hue[0.6469021785753198, 1, 0.10428929120340329`], 
     Hue[0.6317680561302864, 1, 0.12524422997344967`], 
     Hue[0.5621200065992755, 1, 0.22167999086254164`], 
     Hue[0.19302298487617459`, 1, 0.7327374055560659], 
     Hue[0.054113807875611264`, 1, 0.9250731890953074], 
     Hue[0.00001757782965361443, 1, 0.9999756614666335], 
     Hue[0.05332892425071445, 1, 0.9261599510374723], 
     Hue[0.19028970858498329`, 1, 0.7365219419592539], 
     Hue[0.3955828237569447, 1, 0.4522699363365381], 
     Hue[0.5655334389851405, 1, 0.21695369986672847`], 
     Hue[0.6328922576320909, 1, 0.12368764327864344`], 
     Hue[0.6472851573694384, 1, 0.10375901287308537`], 
     Hue[0.6495723271265104, 1, 0.10059216244021646`], 
     Hue[0.6499493480325406, 1, 0.10007013349340546`], 
     Hue[0.6499958593933102, 1, 0.10000573314772443`], 
     Hue[0.6499997456732277, 1, 0.10000035214476173`], 
     Hue[0.6499999910238906, 1, 0.10000001242845914`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999962884925, 1, 0.10000000513901051`], 
     Hue[0.6499998875000167, 1, 0.10000015576920768`], 
     Hue[0.649997628824609, 1, 0.100003283165926], 
     Hue[0.6499697156036316, 1, 0.10004193224112558`], 
     Hue[0.649702183191231, 1, 0.10041236173521877`], 
     Hue[0.6479866622311419, 1, 0.10278769844918818`], 
     Hue[0.6384130449934375, 1, 0.11604347616293274`], 
     Hue[0.587680922557116, 1, 0.1862879533824547], 
     Hue[0.08037979728400946, 1, 0.8887048960682946], 
     Hue[0.004297227603059284, 1, 0.9940499925496102], 
     Hue[0.03068450807176093, 1, 0.9575137580544849], 
     Hue[0.5340642694206366, 1, 0.26052639618681106`], 
     Hue[0.6232586626638958, 1, 0.13702646708075966`], 
     Hue[0.6456979384566754, 1, 0.10595670059844939`], 
     Hue[0.6493194429986408, 1, 0.10094230969418981`], 
     Hue[0.6499089465089427, 1, 0.10012607406454084`], 
     Hue[0.6499921304777695, 1, 0.10001089626155002`], 
     Hue[0.6499994721551353, 1, 0.1000007308621204], 
     Hue[0.6499999776931557, 1, 0.1000000308863999], 
     Hue[0.6499999995869057, 1, 0.10000000057197682`], 
     Hue[0.6499999995220671, 1, 0.10000000066175324`], 
     Hue[0.6499999791499663, 1, 0.10000002886927745`], 
     Hue[0.6499994364424428, 1, 0.10000078031046385`], 
     Hue[0.6499913611455046, 1, 0.10001196149083978`], 
     Hue[0.6498998309403411, 1, 0.10013869562106616`], 
     Hue[0.6491896102225851, 1, 0.10112207815334376`], 
     Hue[0.6452466840975251, 1, 0.10658151432650381`], 
     Hue[0.6216707898238734, 1, 0.13922506024386763`], 
     Hue[0.5297202018304465, 1, 0.26654125900399717`], 
     Hue[0.032518828823293044`, 1, 0.9549739293215943], 
     Hue[0.0032732815674287874`, 1, 0.9954677639835602], 
     Hue[0.5902422164513526, 1, 0.18274154645197344`], 
     Hue[0.6391843135970843, 1, 0.11497556578865253`], 
     Hue[0.6482936688294636, 1, 0.10236261238997357`], 
     Hue[0.6497355144297574, 1, 0.10036621078956673`], 
     Hue[0.6499725180247081, 1, 0.10003805196578883`], 
     Hue[0.6499978741218331, 1, 0.10000294352361577`], 
     Hue[0.6499998803556987, 1, 0.10000016566134033`], 
     Hue[0.6499999965531651, 1, 0.10000000477254065`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999976075383, 1, 0.10000000331263928`], 
     Hue[0.6499999265581481, 1, 0.10000010168871803`], 
     Hue[0.649998309615184, 1, 0.10000234053282218`], 
     Hue[0.6499778996399611, 1, 0.10003060049851549`], 
     Hue[0.6497708331975137, 1, 0.10031730788036568`], 
     Hue[0.6483798910683389, 1, 0.10224322775153076`], 
     Hue[0.6407885332770704, 1, 0.112754338539441], 
     Hue[0.598056757948779, 1, 0.17192141207092143`], 
     Hue[0.009190077841479627, 1, 0.9872752768348743], 
     Hue[0.021485309207827874`, 1, 0.9702511103276229], 
     Hue[0.6167869824949278, 1, 0.14598725500702303`], 
     Hue[0.6445885310285383, 1, 0.10749280319125462`], 
     Hue[0.6491459920911069, 1, 0.10118247248923667`], 
     Hue[0.6498790197205659, 1, 0.10016751115613948`], 
     Hue[0.6499892477616456, 1, 0.10001488771464469`], 
     Hue[0.6499992475198968, 1, 0.10000104189552748`], 
     Hue[0.6499999648866249, 1, 0.10000004861851937`], 
     Hue[0.6499999993341318, 1, 0.1000000009219714], 
     Hue[0.6499999998177972, 1, 0.10000000025228085`], 
     Hue[0.6499999863131705, 1, 0.1000000189509948], 
     Hue[0.649999619245963, 1, 0.10000052719789755`], 
     Hue[0.6499936902286829, 1, 0.10000873660643911`], 
     Hue[0.6499250269867438, 1, 0.10010380878758554`], 
     Hue[0.6493649941031455, 1, 0.1008792389341062], 
     Hue[0.6461618373824476, 1, 0.10531437900891877`], 
     Hue[0.6272280969620759, 1, 0.1315303272832795], 
     Hue[0.04271545343092553, 1, 0.9408555260187185], 
     Hue[0.0007054687797197756, 1, 0.9990231970742341], 
     Hue[0.5787051158307247, 1, 0.1987159934651504], 
     Hue[0.6363827535819212, 1, 0.11885464888657074`], 
     Hue[0.6478461582717419, 1, 0.10298224239297282`], 
     Hue[0.6496629554482654, 1, 0.10046667707163255`], 
     Hue[0.64996257093981, 1, 0.10005182485257076`], 
     Hue[0.6499970240484663, 1, 0.10000412054827755`], 
     Hue[0.6499998251165594, 1, 0.10000024214630238`], 
     Hue[0.6499999944933501, 1, 0.1000000076245922], 
     Hue[0.6499999942867963, 1, 0.10000000791058977`], 
     Hue[0.6499998299602009, 1, 0.10000023543972182`], 
     Hue[0.6499966943672557, 1, 0.10000457702995362`], 
     Hue[0.6499587725164944, 1, 0.10005708420793089`], 
     Hue[0.6496149094122663, 1, 0.10053320235224673`], 
     Hue[0.6475013862307546, 1, 0.10345961906510899`], 
     Hue[0.6354485406032601, 1, 0.12014817454933228`], 
     Hue[0.0012220608422045531`, 1, 0.9983079157569476], 
     Hue[0.6285702980455206, 1, 0.12967189501389464`], 
     Hue[0.6465813903250548, 1, 0.10473345954992418`], 
     Hue[0.6494595008027183, 1, 0.10074838350392862`], 
     Hue[0.6499318807384853, 1, 0.10009431897748189`], 
     Hue[0.6499942741462893, 1, 0.10000792810513794`], 
     Hue[0.64999963248408, 1, 0.10000050886819696`], 
     Hue[0.6499999858418511, 1, 0.10000001960359077`], 
     Hue[0.6499999998408719, 1, 0.10000000022033123`], 
     Hue[0.6499999991164015, 1, 0.10000000122344405`], 
     Hue[0.6499999682447852, 1, 0.10000004396875888`], 
     Hue[0.6499991730194752, 1, 0.10000114504995748`], 
     Hue[0.6499882382456036, 1, 0.1000162855060874], 
     Hue[0.64986697027507, 1, 0.10018419500374921`], 
     Hue[0.6489694456112823, 1, 0.10142692146130144`], 
     Hue[0.644115344316906, 1, 0.10814798479197638`], 
     Hue[0.6149277492149414, 1, 0.14856157801008119`], 
     Hue[0.02358015726292728, 1, 0.9673505514821007], 
     Hue[0.007676048569205451, 1, 0.9893716250580232], 
     Hue[0.641421990255638, 1, 0.11187724426142437`], 
     Hue[0.6486508052766113, 1, 0.10186811577084587`], 
     Hue[0.6497933810994336, 1, 0.10028608770847652`], 
     Hue[0.6499799505156734, 1, 0.10002776082445226`], 
     Hue[0.6499984908954445, 1, 0.1000020895293846], 
     Hue[0.6499999189303272, 1, 0.10000011225031627`], 
     Hue[0.6499999978620732, 1, 0.10000000296020642`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999980847216, 1, 0.10000000265192387`], 
     Hue[0.6499999406480068, 1, 0.10000008217968291`], 
     Hue[0.6499985760993673, 1, 0.10000197155472221`], 
     Hue[0.6499811666500098, 1, 0.10002607694614021`], 
     Hue[0.6497993687572233, 1, 0.10027779710538315`], 
     Hue[0.012294636876409082`, 1, 0.9829766566326643], 
     Hue[0.6498608547487977, 1, 0.10019266265551093`], 
     Hue[0.6499874568512528, 1, 0.100017367436727], 
     Hue[0.6499991036677211, 1, 0.10000124107546322`], 
     Hue[0.6499999563460765, 1, 0.100000060443894], 
     Hue[0.649999999038068, 1, 0.10000000133190574`], 
     Hue[0.6499999998556228, 1, 0.10000000019990683`], 
     Hue[0.6499999889002813, 1, 0.10000001536884133`], 
     Hue[0.6499996878561737, 1, 0.10000043219914415`], 
     Hue[0.6499946195590616, 1, 0.10000744984129935`], 
     Hue[0.6499352859255867, 1, 0.10008960410303379`], 
     Hue[0.00012495178060101253`, 1, 0.9998269898422447], 
     Hue[0.6499564254830472, 1, 0.10006033394655009`], 
     Hue[0.6499964870084193, 1, 0.1000048641421887], 
     Hue[0.649999788802825, 1, 0.10000029242685761`], 
     Hue[0.6499999928755881, 1, 0.10000000986457033`], 
     Hue[0.649999995390665, 1, 0.10000000638215611`], 
     Hue[0.6499998615549235, 1, 0.10000019169318285`], 
     Hue[0.6499971981607479, 1, 0.10000387946973381`], 
     Hue[0.649964637574064, 1, 0.10004896335898845`], 
     Hue[0.6496611376723661, 1, 0.10046919399210849`], 
     Hue[0.0025284501879048182`, 1, 0.9964990689705933], 
     Hue[0.6499211855515638, 1, 0.10010912769783484`], 
     Hue[0.6499932823729541, 1, 0.10000930132975588`], 
     Hue[0.6499995591041515, 1, 0.10000061047117488`], 
     Hue[0.6499999822750272, 1, 0.10000002454227006`], 
     Hue[0.649999999799844, 1, 0.10000000027713905`], 
     Hue[0.6499999993921404, 1, 0.10000000084165185`], 
     Hue[0.6499999742296395, 1, 0.1000000356820376], 
     Hue[0.6499993166891697, 1, 0.1000009461226882], 
     Hue[0.6499899128979453, 1, 0.1000139667566912], 
     Hue[0.6498844796868891, 1, 0.10015995120276888`], 
     Hue[0.005249242345128691, 1, 0.9927318182913603], 
     Hue[0.6499765072904052, 1, 0.10003252836713131`], 
     Hue[0.6499982074463364, 1, 0.10000248199738039`], 
     Hue[0.6499999013927659, 1, 0.10000013653309339`], 
     Hue[0.6499999972823076, 1, 0.10000000376295873`], 
     Hue[0.6499999970172388, 1, 0.10000000412997716`], 
     Hue[0.6499999090384453, 1, 0.10000012594676817`], 
     Hue[0.0065208136688272855`, 1, 0.9909711810739315], 
     Hue[0.6499999719653755, 1, 0.10000003881717248`], 
     Hue[0.6499999994748225, 1, 0.10000000072716896`], 
     Hue[0.6499999996252561, 1, 0.10000000051887625`], 
     Hue[0.6499999831534786, 1, 0.10000002332595265`], 
     Hue[0.6499995362344706, 1, 0.10000064213688688`], 
     Hue[0.001756482736108178, 1, 0.9975679469807732], 
     Hue[0.6499998552290649, 1, 0.10000020045206405`], 
     Hue[0.6499999956383523, 1, 0.10000000603920452`], 
     Hue[0.649999992739275, 1, 0.10000001005331162`], 
     Hue[0.6499997912811158, 1, 0.10000028899537804`], 
     Hue[0.00038383975226097267`, 1, 0.9994685295737924], 
     Hue[0.6499996942354481, 1, 0.10000042336630258`], 
     Hue[0.6499999887148519, 1, 0.10000001562558977`], 
     Hue[0.6499999998738869, 1, 0.10000000017461821`], 
     Hue[0.6499999988915531, 1, 0.10000000153477266`], 
     Hue[0.6499999611427255, 1, 0.10000005380238008`], 
     Hue[0.6499990009816932, 1, 0.1000013832561172], 
     Hue[0.6499999334925771, 1, 0.10000009208720091`], 
     Hue[0.6499999983219668, 1, 0.10000000232343072`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999986895477, 1, 0.10000000181447247`], 
     Hue[0.6499999546518136, 1, 0.10000006278979653`], 
     Hue[0.6499988538077084, 1, 0.10000158703548066`], 
     Hue[0.6499846170584781, 1, 0.1000212994574919], 
     Hue[0.6498304131530114, 1, 0.10023481255736892`], 
     Hue[0.6487339718610075, 1, 0.10175296203860515`], 
     Hue[0.6428927834936017, 1, 0.1098407613165515], 
     Hue[0.6079905540356331, 1, 0.15816692518143122`], 
     Hue[0.4932149938073337, 1, 0.31708693165138413`], 
     Hue[0.29874661811960695`, 1, 0.586350836449775], 
     Hue[0.11331608545236338`, 1, 0.843100804758266], 
     Hue[0.016770194322036525`, 1, 0.9767797309387187], 
     Hue[0.012962325358047977`, 1, 0.9820521648888567], 
     Hue[0.1120454922757399, 1, 0.8448600876182063], 
     Hue[0.2811860075005391, 1, 0.6106655280761766], 
     Hue[0.49318907543008766`, 1, 0.31712281863526326`], 
     Hue[0.6078992055060303, 1, 0.15829340776088124`], 
     Hue[0.6429983684432586, 1, 0.10969456677087275`], 
     Hue[0.6489014195906515, 1, 0.10152111133602107`], 
     Hue[0.6498346033886708, 1, 0.10022901069260967`], 
     Hue[0.6499848266497743, 1, 0.10002100925415863`], 
     Hue[0.6499988870220003, 1, 0.10000154104646115`], 
     Hue[0.6499999428557182, 1, 0.10000007912285178`], 
     Hue[0.6499999987278259, 1, 0.1000000017614719], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999914793696, 1, 0.10000001179779601`], 
     Hue[0.649999757124664, 1, 0.10000033628892684`], 
     Hue[0.6499956007097535, 1, 0.1000060913249568], 
     Hue[0.6499462774139085, 1, 0.10007438511920352`], 
     Hue[0.6495196742108279, 1, 0.10066506647731524`], 
     Hue[0.6469841832251647, 1, 0.1041757463036182], 
     Hue[0.6322720258813754, 1, 0.12454642570271099`], 
     Hue[0.5639146798249193, 1, 0.21919505870395803`], 
     Hue[0.19594301971242695`, 1, 0.7286942803981781], 
     Hue[0.05562095274016088, 1, 0.922986373129008], 
     Hue[0.00006476854096326701, 1, 0.9999103204817431], 
     Hue[0.05175520946008094, 1, 0.9283389407475802], 
     Hue[0.18762246319115516`, 1, 0.7402150509660929], 
     Hue[0.392159207446811, 1, 0.4570103281505694], 
     Hue[0.563768447046152, 1, 0.21939753485917407`], 
     Hue[0.6324005881953736, 1, 0.12436841634486737`], 
     Hue[0.6472056713721284, 1, 0.10386907040782223`], 
     Hue[0.6495595296978528, 1, 0.10060988195681927`], 
     Hue[0.64994741966244, 1, 0.10007280354431392`], 
     Hue[0.6499956867928566, 1, 0.10000597213296793`], 
     Hue[0.6499997336472276, 1, 0.1000003687961464], 
     Hue[0.6499999904933138, 1, 0.10000001316310402`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.65, 1, 0.1], 
     Hue[0.649999996485234, 1, 0.10000000486659906`], 
     Hue[0.6499998933341241, 1, 0.10000014769121277`], 
     Hue[0.6499977262695861, 1, 0.10000314824211166`], 
     Hue[0.6499708739806658, 1, 0.10004032833446282`], 
     Hue[0.6497116989153795, 1, 0.10039918611716682`], 
     Hue[0.6480404511332438, 1, 0.10271322150781627`], 
     Hue[0.638739778138648, 1, 0.11559107642341046`], 
     Hue[0.5890618254339812, 1, 0.18437593401448754`], 
     Hue[0.08217308946847146, 1, 0.886221876120578], 
     Hue[0.004810818088818114, 1, 0.9933388672616364], 
     Hue[0.029454279868477484`, 1, 0.9592171509513389], 
     Hue[0.5318683230536829, 1, 0.26356693731028513`], 
     Hue[0.6225167371114272, 1, 0.13805374861494696`], 
     Hue[0.6455726819219234, 1, 0.10613013272349067`], 
     Hue[0.6492997283882395, 1, 0.10096960684705304`], 
     Hue[0.6499056238795023, 1, 0.10013067462838136`], 
     Hue[0.6499918148537729, 1, 0.10001133327939143`], 
     Hue[0.649999448044136, 1, 0.10000076424658093`], 
     Hue[0.6499999764236851, 1, 0.10000003264412838`], 
     Hue[0.6499999995612433, 1, 0.10000000060750922`], 
     Hue[0.6499999995501466, 1, 0.10000000062287397`], 
     Hue[0.6499999801934777, 1, 0.10000002742441548`], 
     Hue[0.6499994631013634, 1, 0.1000007433981123], 
     Hue[0.6499916911040348, 1, 0.10001150462518264`], 
     Hue[0.6499033629470845, 1, 0.10013380515019074`], 
     Hue[0.6492137823879475, 1, 0.10108860900130351`], 
     Hue[0.6453719713921683, 1, 0.10640803961084395`], 
     Hue[0.6224267715498065, 1, 0.13817831631565258`], 
     Hue[0.5319483424646598, 1, 0.2634561412027787], 
     Hue[0.03372591034979455, 1, 0.9533025856695152], 
     Hue[0.0028507459002765634`, 1, 0.9960528133688479], 
     Hue[0.5888864801468465, 1, 0.1846187197966741], 
     Hue[0.6388673486360551, 1, 0.11541444035007759`], 
     Hue[0.648243096232276, 1, 0.10243263598607938`], 
     Hue[0.6497273101174665, 1, 0.10037757060658486`], 
     Hue[0.6499714267721023, 1, 0.10003956293093529`], 
     Hue[0.649997782068769, 1, 0.10000307098170444`], 
     Hue[0.6499998744961235, 1, 0.10000017377459827`], 
     Hue[0.6499999963434548, 1, 0.10000000506290872`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999977365529, 1, 0.10000000313400373`], 
     Hue[0.6499999303535207, 1, 0.1000000964335868], 
     Hue[0.6499983803434939, 1, 0.10000224260131618`], 
     Hue[0.6499787622312235, 1, 0.10002940614138281`], 
     Hue[0.6497782994629911, 1, 0.10030696997432], 
     Hue[0.6484234893478215, 1, 0.10218286090301641`], 
     Hue[0.6410497024189983, 1, 0.11239271972754086`], 
     Hue[0.5992485384364192, 1, 0.1702712544726504], 
     Hue[0.00992583716622586, 1, 0.9862565331544565], 
     Hue[0.020440720585321426`, 1, 0.9716974638049396], 
     Hue[0.6158876625910282, 1, 0.14723246718165328`], 
     Hue[0.6444312417610134, 1, 0.1077105883309045], 
     Hue[0.6491216016611556, 1, 0.1012162438537845], 
     Hue[0.6498746974961213, 1, 0.10017349577460141`], 
     Hue[0.6499888248088734, 1, 0.10001547334155991`], 
     Hue[0.6499992137655591, 1, 0.10000108863230274`], 
     Hue[0.6499999629154593, 1, 0.10000005134782572`], 
     Hue[0.649999999187991, 1, 0.1000000011243202], 
     Hue[0.6499999998280425, 1, 0.10000000023809502`], 
     Hue[0.6499999870094187, 1, 0.10000001798695868`], 
     Hue[0.6499996375857561, 1, 0.10000050180433775`], 
     Hue[0.6499939357372946, 1, 0.10000839667143832`], 
     Hue[0.6499277248844461, 1, 0.10010007323692084`], 
     Hue[0.6493842275287619, 1, 0.1008526080370989], 
     Hue[0.6462631809207381, 1, 0.1051740571866703], 
     Hue[0.6278478700226119, 1, 0.13067217996869127`], 
     Hue[0.04407550660045001, 1, 0.9389723754763], 
     Hue[0.0005160908523312857, 1, 0.9992854126660028], 
     Hue[0.5771496928061046, 1, 0.2008696561146244], 
     Hue[0.6359868772240326, 1, 0.11940278538210872`], 
     Hue[0.6477827759744967, 1, 0.10307000249685068`], 
     Hue[0.6496526922230316, 1, 0.10048088769118713`], 
     Hue[0.6499611155616423, 1, 0.10005383999157226`], 
     Hue[0.6499968976113, 1, 0.10000429561512315`], 
     Hue[0.6499998164756905, 1, 0.10000025411058248`], 
     Hue[0.6499999941649969, 1, 0.1000000080792352], 
     Hue[0.6499999945843716, 1, 0.10000000749856237`], 
     Hue[0.6499998384480976, 1, 0.10000022368724955`], 
     Hue[0.6499968277734428, 1, 0.10000439231369461`], 
     Hue[0.6499603176134447, 1, 0.10005494484292267`], 
     Hue[0.6496269843951507, 1, 0.1005164831451761], 
     Hue[0.6475677824921865, 1, 0.10336768578004948`], 
     Hue[0.6358554902913877, 1, 0.11958470575038635`], 
     Hue[0.001504960438257541, 1, 0.997916208623951], 
     Hue[0.6279638618150875, 1, 0.13051157594834048`], 
     Hue[0.6464816375632579, 1, 0.10487157875856597`], 
     Hue[0.6494435975586479, 1, 0.10077040338033376`], 
     Hue[0.6499293417728174, 1, 0.10009783446840677`], 
     Hue[0.6499940400051483, 1, 0.10000825230056393`], 
     Hue[0.6499996154022655, 1, 0.1000005325199402], 
     Hue[0.6499999850208378, 1, 0.10000002074037845`], 
     Hue[0.64999999983143, 1, 0.10000000023340462`], 
     Hue[0.6499999991653913, 1, 0.10000000115561203`], 
     Hue[0.6499999698155458, 1, 0.1000000417938597], 
     Hue[0.6499992114103147, 1, 0.10000109189341046`], 
     Hue[0.649988680275961, 1, 0.10001567346405406`], 
     Hue[0.6498715659173889, 1, 0.10017783180669233`], 
     Hue[0.6489997667354211, 1, 0.10138493836634006`], 
     Hue[0.644270212886219, 1, 0.10793355138831226`], 
     Hue[0.615841383934827, 1, 0.14729654532100883`], 
     Hue[0.024626432470307047`, 1, 0.965901862733421], 
     Hue[0.00702759144106635, 1, 0.9902694887739082], 
     Hue[0.6411692860354885, 1, 0.11222714241240049`], 
     Hue[0.6486104417454643, 1, 0.10192400373704942`], 
     Hue[0.6497868499256562, 1, 0.10029513087216844`], 
     Hue[0.6499791375571835, 1, 0.10002888645928443`], 
     Hue[0.6499984243051491, 1, 0.100002181731332], 
     Hue[0.6499999148916165, 1, 0.10000011784237722`], 
     Hue[0.6499999977294184, 1, 0.10000000314388229`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999981888782, 1, 0.10000000250770709`], 
     Hue[0.6499999437437876, 1, 0.10000007789321734`], 
     Hue[0.6499986362126332, 1, 0.10000188832096944`], 
     Hue[0.6499819104634493, 1, 0.1000250470506086], 
     Hue[0.6498059691963517, 1, 0.10026865803582077`], 
     Hue[0.013137482100077702`, 1, 0.9818096401691231], 
     Hue[0.6498559356642916, 1, 0.10019947369559637`], 
     Hue[0.6499869681193208, 1, 0.1000180441424789], 
     Hue[0.6499990638254846, 1, 0.10000129624163685`], 
     Hue[0.6499999539188556, 1, 0.10000006380466162`], 
     Hue[0.6499999989824666, 1, 0.10000000140889244`], 
     Hue[0.6499999998638502, 1, 0.10000000018851526`], 
     Hue[0.6499999894696733, 1, 0.10000001458045245`], 
     Hue[0.649999703234268, 1, 0.10000041090639808`], 
     Hue[0.6499948308480435, 1, 0.10000715728732433`], 
     Hue[0.6499376381923154, 1, 0.1000863471183325], 
     Hue[0.00005369470381844099, 1, 0.9999256534870206], 
     Hue[0.6499547468432694, 1, 0.1000626582170116], 
     Hue[0.6499963391686168, 1, 0.10000506884345381`], 
     Hue[0.6499997787258522, 1, 0.1000003063795892], 
     Hue[0.6499999924504675, 1, 0.1000000104531989], 
     Hue[0.6499999956328758, 1, 0.10000000604678738`], 
     Hue[0.6499998685301378, 1, 0.1000001820351938], 
     Hue[0.6499973122670737, 1, 0.10000372147635953`], 
     Hue[0.6499659764366523, 1, 0.10004710954925068`], 
     Hue[0.6496718625650953, 1, 0.10045434414063718`], 
     Hue[0.002927562699996056, 1, 0.9959464516461592], 
     Hue[0.649918278156374, 1, 0.10011315332194375`], 
     Hue[0.6499930103231023, 1, 0.10000967801416603`], 
     Hue[0.6499995387858082, 1, 0.1000006386042656], 
     Hue[0.6499999811210364, 1, 0.10000002614010346`], 
     Hue[0.6499999997881343, 1, 0.10000000029335257`], 
     Hue[0.6499999994274595, 1, 0.10000000079274846`], 
     Hue[0.6499999756943535, 1, 0.10000003365397206`], 
     Hue[0.6499993487109922, 1, 0.10000090178478008`], 
     Hue[0.6499902946419781, 1, 0.10001343818803031`], 
     Hue[0.6498885091356831, 1, 0.10015437196597732`], 
     Hue[0.004712633958761203, 1, 0.9934748145186384], 
     Hue[0.6499755643817695, 1, 0.10003383393293451`], 
     Hue[0.6499981290898009, 1, 0.10000259049104492`], 
     Hue[0.6499998965191928, 1, 0.10000014328111768`], 
     Hue[0.6499999971153176, 1, 0.10000000399417566`], 
     Hue[0.6499999971767201, 1, 0.10000000390915682`], 
     Hue[0.6499999137031582, 1, 0.10000011948793482`], 
     Hue[0.00714673408177724, 1, 0.9901045220406162], 
     Hue[0.6499999702161572, 1, 0.100000041239167], 
     Hue[0.6499999994425746, 1, 0.10000000077181984`], 
     Hue[0.6499999997835108, 1, 0.10000000029975437`], 
     Hue[0.6499999840032462, 1, 0.1000000221493514], 
     Hue[0.6499995583752298, 1, 0.100000611480451], 
     Hue[0.0014498437695712463`, 1, 0.9979925240113628], 
     Hue[0.6499998482020746, 1, 0.10000021018174296`], 
     Hue[0.649999995375625, 1, 0.10000000640298083`], 
     Hue[0.6499999931179452, 1, 0.10000000952899896`], 
     Hue[0.649999801611542, 1, 0.10000027469171101`], 
     Hue[0.000549261524755984, 1, 0.9992394840426456], 
     Hue[0.6499996796719513, 1, 0.10000044353114443`], 
     Hue[0.6499999880541155, 1, 0.10000001654045554`], 
     Hue[0.649999999866299, 1, 0.1000000001851246], 
     Hue[0.6499999989524029, 1, 0.10000000145051917`], 
     Hue[0.6499999630488099, 1, 0.10000005116318629`], 
     Hue[0.6499990469217429, 1, 0.1000013196468175], 
     Hue[0.649999930154843, 1, 0.10000009670867885`], 
     Hue[0.6499999982168378, 1, 0.10000000246899379`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999985379996, 1, 0.1000000020243082], 
     Hue[0.65, 1, 0.1], 
     Hue[0., 1, 1.], 
     Hue[0.0038120702626179837`, 1, 0.9947217488671443], 
     Hue[0.6499999996111329, 1, 0.10000000053843149`], 
     Hue[0.649999978053963, 1, 0.10000003038682044`], 
     Hue[0.6499999993723352, 1, 0.10000000086907443`], 
     Hue[0.64999999980698, 1, 0.10000000026725847`], 
     Hue[0.6499999855812316, 1, 0.1000000199644486], 
     Hue[0.000924262898536421, 1, 0.9987202513712572], 
     Hue[0.6499999939736065, 1, 0.1000000083442372], 
     Hue[0.0009684315173636993, 1, 0.9986590948221118], 
     Hue[0.6499999998498145, 1, 0.10000000020794926`], 
     Hue[0.6499999990646713, 1, 0.10000000129507053`], 
     Hue[0.6499999990907607, 1, 0.10000000125894673`], 
     Hue[0.00022579085765728202`, 1, 0.9996873665047823], 
     Hue[0.6499999934512071, 1, 0.10000000906755943`], 
     Hue[0.0021582457530301413`, 1, 0.9970116597265737], 
     Hue[0.6499999998109437, 1, 0.10000000026177024`], 
     Hue[0.6499999993547534, 1, 0.10000000089341847`], 
     Hue[0.6499999734699781, 1, 0.10000003673387664`], 
     Hue[0.6499999996016591, 1, 0.10000000055154896`], 
     Hue[0.0020922426277821815`, 1, 0.9971030486692246], 
     Hue[0.00024792579585874996`, 1, 0.999656718128811], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6499999985731095, 1, 0.10000000197569452`], 
     Hue[0.65, 1, 0.1]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563367605731072*^9, 3.566087057632818*^9, 
  3.566101843278183*^9, 3.566139289207*^9, 3.61470787371667*^9},
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"},
 CellLabel->
  "During evaluation of \
In[71]:=",ExpressionUUID->"e24be2f9-c5d4-481a-b7cb-42d643c4e308"]
}, Open  ]],

Cell[TextData[{
 "The last intensity plot is taken at the focal plane of the system and shows \
the point spread function. ",
 StyleBox["FindIntensity", "Input"],
 " works by convolving a Gaussian smoothing kernel with the ray-trace data. \
However, the result may not accurately depict the diffractive performance of \
the system. In particular, ",
 StyleBox["FindIntensity", "Input"],
 " automatically adjusts the smooth kernel size to maximize the measurement \
resolution to the available ray-density. In this way, if the number of input \
rays are sufficiently great, ",
 StyleBox["FindIntensity", "Input"],
 " models the geometric behavior of the system. However, you can approximate \
some effects of the diffraction performance if you have independent knowledge \
of the diffraction-limited spot-size for the system. In this case, you can \
manually set the ",
 StyleBox["SmoothKernelSize", "Input"],
 " option to correspond with the diffraction-limited spot-size of the optical \
system (together with ",
 StyleBox["KernelScale -> Absolute", "Input"],
 "). In that case, the intensity plot generated by ",
 StyleBox["FindIntensity", "Input"],
 " can depict both the geometric and incoherent diffractive properties of a \
system. However, if the ",
 StyleBox["SmoothKernelSize", "Input"],
 " is manually set, it is always necessary that make sure that there are a \
sufficient number of rays are present in order to meet the Nyquist sampling \
criterion. Otherwise, the resulting calculation will not be correct. Here is \
the definition of ",
 StyleBox["SmoothKernelSize", "Input",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"6a8298d3-cd1c-4426-ba27-6e0e9d9c4ef0"],

Cell[TextData[{
 StyleBox["SmoothKernelSize", "Input",
  FontWeight->"Bold"],
 " ",
 StyleBox["->",
  FontWeight->"Bold"],
 " ",
 StyleBox["radius",
  FontSlant->"Italic"],
 " is an option that specifies the ",
 StyleBox["radius",
  FontSlant->"Italic"],
 " of a Gaussian smoothing kernel: ",
 StyleBox["Exp[", "Input",
  FontWeight->"Bold"],
 StyleBox["-",
  FontWeight->"Bold"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox["^",
  FontWeight->"Bold"],
 "2",
 StyleBox["/",
  FontWeight->"Bold"],
 StyleBox["radius",
  FontSlant->"Italic"],
 StyleBox["^",
  FontWeight->"Bold"],
 "2",
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 ", where ",
 StyleBox["s",
  FontSlant->"Italic"],
 " is distance along the surface. ",
 StyleBox["\[InvisibleSpace]",
  FontSize->3],
 "In particular, this smoothing kernel is convolved with another function in \
order to low",
 StyleBox["-",
  FontWeight->"Bold"],
 "pass filter its shape along a spatial surface. "
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"383b92d9-bb1f-4fa8-9b79-4d97513a96de"],

Cell[TextData[{
 StyleBox["SmoothKernelSize", "Input",
  FontWeight->"Bold"],
 " works together with the ",
 StyleBox["KernelScale", "Input",
  FontWeight->"Bold"],
 " option to smooth the calculated intensity function. Here is the definition \
of ",
 StyleBox["KernelScale", "Input",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"8f2a8809-ca0e-424e-b3dd-02b65ee36fc7"],

Cell[TextData[{
 StyleBox["KernelScale", "Input",
  FontWeight->"Bold"],
 StyleBox[" ", "Input"],
 StyleBox["->", "Input",
  FontWeight->"Bold"],
 StyleBox[" ", "Input"],
 StyleBox["Relative", "Input",
  FontWeight->"Bold"],
 " ",
 StyleBox["/",
  FontWeight->"Bold"],
 " ",
 StyleBox["Absolute", "Input",
  FontWeight->"Bold"],
 " is used with ",
 StyleBox["FindIntensity", "Input",
  FontWeight->"Bold"],
 " to specify the form of the ",
 StyleBox["SmoothKernelSize", "Input",
  FontWeight->"Bold"],
 " option. ",
 StyleBox["\[InvisibleSpace]", "Input",
  FontSize->10]
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"de33a8b9-bafc-4dc0-a878-7ae11c86ac7a"],

Cell[TextData[{
 StyleBox["KernelScale", "Input",
  FontWeight->"Bold"],
 StyleBox[" ", "Input"],
 StyleBox["->", "Input",
  FontWeight->"Bold"],
 StyleBox[" ", "Input"],
 StyleBox["Relative", "Input",
  FontWeight->"Bold"],
 " indicates that the specified ",
 StyleBox["SmoothKernelSize", "Input",
  FontWeight->"Bold"],
 " dimensions is a relative multiplicative factor of the minimum estimated \
spatial sampling dimension, as determined from Nyquist sampling criteria. ",
 StyleBox["KernelScale", "Input",
  FontWeight->"Bold"],
 StyleBox[" ", "Input"],
 StyleBox["->", "Input",
  FontWeight->"Bold"],
 StyleBox[" ", "Input"],
 StyleBox["Absolute", "Input",
  FontWeight->"Bold"],
 " denotes that the specified ",
 StyleBox["SmoothKernelSize", "Input",
  FontWeight->"Bold"],
 " dimensions are given in absolute spatial dimensions."
}], "Text",
 CellTags->{
  "FindIntensity", "RG17.", "RG17.3", 
   "Point Spread Function \
(PSF)"},ExpressionUUID->"b6b2e779-1a5b-4ed1-b908-aea9d02a4f32"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "FindIntensity", 
   "RG17."},ExpressionUUID->"c35f1e2e-2fa0-4f19-b803-21670f38c3eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Measuring the Modulation Transfer Function", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", 
   "17.4"},ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786"],

Cell[TextData[{
 "Now that we have used ",
 StyleBox["FindIntensity", "Input"],
 " to determine the point spread function of this lens system, we can also \
calculate the ",
 StyleBox["ModulationTransferFunction", "Input"],
 " of this system. First we define ",
 StyleBox["ModulationTransferFunction", "Input"],
 "."
}], "Text",
 CellTags->{
  "ModulationTransferFunction", "FindIntensity", "RG17.", 
   "RG17.4"},ExpressionUUID->"30c801a3-37d5-4911-b3a1-d9d387a5f414"],

Cell[TextData[{
 StyleBox["ModulationTransferFunction[", "Input",
  FontWeight->"Bold"],
 StyleBox["intensitydata",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontWeight->"Bold"],
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input",
  FontWeight->"Bold"],
 " calculates the modulation and phase transfer functions of an optical \
system for a given object source input."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "ModulationTransferFunction", "RG17.", 
   "RG17.4"},ExpressionUUID->"9c0d1061-6d13-4c39-8a38-fc416aeca7f4"],

Cell[TextData[{
 StyleBox["ModulationTransferFunction", "Input"],
 " works together with ",
 StyleBox["FindIntensity", "Input"],
 ". As input, ",
 StyleBox["ModulationTransferFunction", "Input"],
 " takes the returned output from ",
 StyleBox["FindIntensity", "Input"],
 ". The optical system must contain a light source followed by the imaging \
optics with the focal surface as its last element."
}], "Text",
 CellTags->{
  "ModulationTransferFunction", "FindIntensity", "RG17.", 
   "RG17.4"},ExpressionUUID->"86795780-c101-4bd7-81de-63e3b9e5d003"],

Cell[CellGroupData[{

Cell["Options[ModulationTransferFunction]", "Input",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"},
 
 CellLabel->"In[72]:=",ExpressionUUID->"69d700c4-c02f-46db-91df-f1f4ad496ccd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
   RowBox[{"FrequencyCutoff", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PaddingFactor", "\[Rule]", "7"}], ",", 
   RowBox[{"NormalizePlot", "\[Rule]", "True"}], ",", 
   RowBox[{"InterpolationOrder", "\[Rule]", "1"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "40"}], ",", 
   RowBox[{"Plot2D", "\[Rule]", "True"}], ",", 
   RowBox[{"ContourLines", "\[Rule]", "False"}], ",", 
   RowBox[{"Contours", "\[Rule]", "50"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Hue", "[", 
       RowBox[{
        RowBox[{"0.65`", "\[VeryThinSpace]", "-", 
         RowBox[{"Intensity", " ", "0.65`"}]}], ",", "1", ",", 
        RowBox[{
         RowBox[{"Intensity", " ", "0.9`"}], "+", "0.1`"}]}], "]"}], "&"}], 
     ")"}]}], ",", 
   RowBox[{"RenderedParameters", "\[Rule]", 
    RowBox[{"{", "ModulationTransferFunction", "}"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.56336760652106*^9, 3.566087058218466*^9, 
  3.5661018441920233`*^9, 3.56613929000276*^9, 3.6147078737547503`*^9},
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"},
 
 CellLabel->"Out[72]=",ExpressionUUID->"b3e7fbc4-8c5c-4773-8b21-2c1f50002099"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ModulationTransferFunction[focusintensity]", "Input",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"},
 
 CellLabel->"In[73]:=",ExpressionUUID->"05011727-66ba-42d7-9311-76ce95abffd2"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwVl3c8lf8bxu3MjEKlkOQrUSl7dN9nmYUWlZJUVtlCkhUl83hOUZJESiSJ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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Xe81mMcBuDT3nur1GmX9tJA9mogoYVEFKWSUpFCaBBStPeUvSkrm8zs
vWXvPXLdH39c576/zzm973ue5/mdCoeP7X92kYKCgi2+JLv58pa8hhPZh0HW
/pK3cyEt6W3tG7mOcYw3V+MZ/ShO00uyhAfMc2Ub1jHbPE024DW9KN31t+V8
TmJfBlv7W97BdFrRx9q3cj2X6E1Zw3jzObI6z+pHM0IvxYP6HIrRw/yOvJaT
2Y8h1v6RdzJLb8UMfbLcgxW8lD2RndhL7yu/kxvyvhxDcXpaf1cuYBijzRV5
XJ8n27OBXuah8l95FxfRmhLZc+vvyYWcwv60oSSlKE0ZylKO8lSgIpWoTBWq
Uo3q1KBm9tVrvy+vYzgH0JZa2Qvf+0Bez6kcSDtq08v3PpSLcrYcRHv6Wf9e
bmQC/amTz2z9I7k458DBdMjdsP6D3MS5+TfmGuzQj+V0vTQP6VfItszNvZMN
WcnrOT/ZhRtyRvk95MdySV6DQ3J/re2Wd3MxHXMvrP0oNzNTb8bEfBZZk2U8
Z75KdmAjA8xnyDI8nM9F3eyP+RO5NN/n0NzdPETck/vJFL0uL+udck/0n7L/
+ezyUtmcSfpx1Mvemj+VyxjJGHMlntAPy73Ns8oi7jXPzp1kLTPNU2U9duqd
cyb6z3IL53F8XtdaWR7Rr6R+zsj8mVye+6g3ZjWjzPkjUZkn9cNzt/Wi3Jff
gS45P/Mv8kYmM9Fci+f1Exill2N73lO2Yz3zzNNlIat4w7xAdmXPnKX8XK7g
TI7Ic2GtGPfrl9GVAeZf5U1Z01swRZ8ka7OcF8xXy45sYmBeU5bn0Zw7DXKW
5l1yJWdxZJ4Xa8XZql/O+Xp9XtHny85sZu+cpfwtz5K8OT8vWzI1ZyDr8KI+
iIY5V/MXchWjGWuuwlN67zyPegkWs808R7Zmln5B9olX9W45X/13eUs+I4Mp
zLlZ/1KuzvOgN2GMPk5WZSlPm/vQPWdm/kPemvdgCI2y/9a/kmtyL+hLDxrT
hKY0o3n2zc9+Ldfmd6IfPRlo/U95G9MYmn22VoHHckbM0Bvxpr4w+1rk//+n
Wpj/A6bNu/4=
      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0., 1, 1.], 
     Hue[0.003969540733167354, 1, 0.994503712830999], 
     Hue[0.015964203665723598`, 1, 0.9778957180013058], 
     Hue[0.03381351919966624, 1, 0.9531812811081544], 
     Hue[0.05702616656296999, 1, 0.9210406924512723], 
     Hue[0.08804715288668818, 1, 0.8780885575415086], 
     Hue[0.12115303588207504`, 1, 0.8322496426248192], 
     Hue[0.16016571418836928`, 1, 0.7782320880468733], 
     Hue[0.2005117607428496, 1, 0.7223683312791314], 
     Hue[0.23911972855193425`, 1, 0.6689111450819372], 
     Hue[0.28096556473772577`, 1, 0.6109707565169951], 
     Hue[0.3193725306438068, 1, 0.5577918806470368], 
     Hue[0.35593307134720303`, 1, 0.5071695935192574], 
     Hue[0.3938805880202113, 1, 0.45462687812586133`], 
     Hue[0.4273583634380576, 1, 0.40827303523961256`], 
     Hue[0.4614762536820767, 1, 0.3610328795171247], 
     Hue[0.4926702116531927, 1, 0.31784124540327163`], 
     Hue[0.5193803564486097, 1, 0.2808579679942327], 
     Hue[0.5456459396940175, 1, 0.24449023734674502`], 
     Hue[0.567762267294848, 1, 0.21386762989944125`], 
     Hue[0.5890549163078942, 1, 0.18438550049676183`], 
     Hue[0.6069100963648001, 1, 0.1596629434948923], 
     Hue[0.6209888825880338, 1, 0.1401692394934917], 
     Hue[0.633645995749648, 1, 0.12264400588510288`], 
     Hue[0.6431442065741193, 1, 0.10949263705121946`], 
     Hue[0.6499491782990613, 1, 0.10007036850899206`], 
     Hue[0.6478354447016597, 1, 0.10299707656693284`], 
     Hue[0.6441278099584556, 1, 0.10813072467290756`], 
     Hue[0.641516425333477, 1, 0.11174648799980116`], 
     Hue[0.6401647508933085, 1, 0.11361803722464976`], 
     Hue[0.6397118770822456, 1, 0.11424509327073684`], 
     Hue[0.6398181270847271, 1, 0.11409797788268569`], 
     Hue[0.6403205452088672, 1, 0.11340232201849168`], 
     Hue[0.6410866473616429, 1, 0.11234156519157149`], 
     Hue[0.6421482860262874, 1, 0.11087160396360207`], 
     Hue[0.6432605840714736, 1, 0.10933149897795977`], 
     Hue[0.6445496366805256, 1, 0.10754665690388775`], 
     Hue[0.6457873866109285, 1, 0.10583284930794513`], 
     Hue[0.646981830301977, 1, 0.10417900419726271`], 
     Hue[0.6482477916258018, 1, 0.10242613467196673`], 
     Hue[0.0014986057601861225`, 1, 0.997925007408973], 
     Hue[0.008797544726510842, 1, 0.987818784224831], 
     Hue[0.023778146434517367`, 1, 0.9670764126291298], 
     Hue[0.04483885018140965, 1, 0.937915438210356], 
     Hue[0.07209410609377909, 1, 0.9001773915624598], 
     Hue[0.6142682141282336, 1, 0.1494747804378304], 
     Hue[0.627828023844626, 1, 0.13069965929205637`], 
     Hue[0.6386488872898687, 1, 0.11571692529095112`], 
     Hue[0.6468690845273481, 1, 0.10433511373136407`], 
     Hue[0.6493610820136828, 1, 0.10088465567336231`], 
     Hue[0.6457054943572267, 1, 0.10594623858230148`], 
     Hue[0.642637811704947, 1, 0.11019379917776571`], 
     Hue[0.6407552449743882, 1, 0.1128004300354625], 
     Hue[0.6398685126012229, 1, 0.11402821332138378`], 
     Hue[0.6396644662474301, 1, 0.11431073904201981`], 
     Hue[0.6400235581801557, 1, 0.11381353482747682`], 
     Hue[0.6406874110817132, 1, 0.11289435388685869`], 
     Hue[0.6416032149509483, 1, 0.11162631776022554`], 
     Hue[0.6476330374909519, 1, 0.10327733270483586`], 
     Hue[0.0007493028800931167, 1, 0.9989625037044865], 
     Hue[0.006383542729839098, 1, 0.9911612485279151], 
     Hue[0.019650629670878494`, 1, 0.972791435840322], 
     Hue[0.038745191990629424`, 1, 0.9463528110898977], 
     Hue[0.06437827330744528, 1, 0.9108608523435373], 
     Hue[0.6105891552465168, 1, 0.15456886196636133`], 
     Hue[0.6244280396327723, 1, 0.1354073297392384], 
     Hue[0.636362011161562, 1, 0.1188833691609142], 
     Hue[0.6450909816665281, 1, 0.10679710230788424`], 
     Hue[0.6496551301563721, 1, 0.1004775120911772], 
     Hue[0.6467704695294432, 1, 0.10447165757461715`], 
     Hue[0.6432960781721615, 1, 0.10928235330008414`], 
     Hue[0.6410878583588733, 1, 0.1123398884261755], 
     Hue[0.6400166317472656, 1, 0.11382312527301677`], 
     Hue[0.6396881716648379, 1, 0.11427791615637833`], 
     Hue[0.6398934749197009, 1, 0.11399365011118329`], 
     Hue[0.6404886052236335, 1, 0.11316962353650745`], 
     Hue[0.6413449311562955, 1, 0.1119839414758985], 
     Hue[0.6473074338964644, 1, 0.10372816845104929`], 
     Hue[0.002247908640279239, 1, 0.9968875111134595], 
     Hue[0.012016146607155442`, 1, 0.9833622585439387], 
     Hue[0.02879583281709186, 1, 0.9601288468686421], 
     Hue[0.6408965469319939, 1, 0.11260478117108529`], 
     Hue[0.6486471873881683, 1, 0.10187312515484391`], 
     Hue[0.6489766572825391, 1, 0.10141693607033055`], 
     Hue[0.6448952215602058, 1, 0.10706815476279197`], 
     Hue[0.642077118519212, 1, 0.11097014358878345`], 
     Hue[0.6404226315899032, 1, 0.11326097164474952`], 
     Hue[0.6397337364194063, 1, 0.11421482649620665`], 
     Hue[0.6397374104694511, 1, 0.11420973934999086`], 
     Hue[0.6401720516945114, 1, 0.11360792842298426`], 
     Hue[0.6408862169397929, 1, 0.11261908423720991`], 
     Hue[0.6479450605500523, 1, 0.10284530077685067`], 
     Hue[0.00037465144004655837`, 1, 0.9994812518522432], 
     Hue[0.005176541731503281, 1, 0.992832480679457], 
     Hue[0.01780741666830099, 1, 0.975343576920814], 
     Hue[0.036273148846592385`, 1, 0.9497756400585644], 
     Hue[0.06052035691427826, 1, 0.9162025827340763], 
     Hue[0.6087496258056584, 1, 0.15711590273062684`], 
     Hue[0.622708461110403, 1, 0.13778828461636503`], 
     Hue[0.6350040034556049, 1, 0.12076368752300856`], 
     Hue[0.644201930236118, 1, 0.10802809659614435`], 
     Hue[0.6498021542277167, 1, 0.10027394030008463`], 
     Hue[0.6473029571155514, 1, 0.10373436707077502`], 
     Hue[0.6437119440653086, 1, 0.10870653898649585`], 
     Hue[0.6412541650511158, 1, 0.11210961762153199`], 
     Hue[0.6400906913202871, 1, 0.11372058124883326`], 
     Hue[0.6397000243735418, 1, 0.11426150471355759`], 
     Hue[0.639855801002214, 1, 0.11404581399693449`], 
     Hue[0.6403933297562053, 1, 0.11330154341448496`], 
     Hue[0.6412157892589692, 1, 0.11216275333373499`], 
     Hue[0.6471446320992207, 1, 0.103953586324156], 
     Hue[0.0018732572002326808`, 1, 0.9974062592612163], 
     Hue[0.010042118077871254`, 1, 0.9860955288152551], 
     Hue[0.02628698962580467, 1, 0.9636026297488859], 
     Hue[0.6397727171109313, 1, 0.11416085323101821`], 
     Hue[0.6477581359577582, 1, 0.10310411944310402`], 
     Hue[0.6492140579423382, 1, 0.10108822746445488`], 
     Hue[0.645278927361081, 1, 0.10653686980773418`], 
     Hue[0.6423574651120795, 1, 0.11058197138327458`], 
     Hue[0.6405889382821457, 1, 0.11303070084010601`], 
     Hue[0.6397944530282015, 1, 0.11413075734556728`], 
     Hue[0.639697052161813, 1, 0.11426562008364345`], 
     Hue[0.6400978049373335, 1, 0.11371073162523053`], 
     Hue[0.640786814010753, 1, 0.1127567190620343], 
     Hue[0.6477936950121775, 1, 0.10305488382929263`], 
     Hue[0.001123954320139564, 1, 0.9984437555567298], 
     Hue[0.007590543728175025, 1, 0.989490016376373], 
     Hue[0.021493842673456, 1, 0.9702392947598302], 
     Hue[0.04179202108601954, 1, 0.9421341246501268], 
     Hue[0.6495081060850274, 1, 0.10068108388226975`], 
     Hue[0.6462379819433349, 1, 0.1052089480784593], 
     Hue[0.6429181582978145, 1, 0.10980562697225686`], 
     Hue[0.6409215516666308, 1, 0.112570159230819], 
     Hue[0.6399425721742442, 1, 0.11392566929720027`], 
     Hue[0.6396763189561341, 1, 0.11429432759919907`], 
     Hue[0.6399493114229778, 1, 0.1139163380297231], 
     Hue[0.0028561888712423933`, 1, 0.9960452769475105], 
     Hue[0.01399017513643952, 1, 0.9806289882726222], 
     Hue[0.6495362388185784, 1, 0.1006421308665838], 
     Hue[0.6484060509920994, 1, 0.1022070063186317], 
     Hue[0.6417967719263444, 1, 0.1113583157942923], 
     Hue[0.6402563248976606, 1, 0.11349124244939303`], 
     Hue[0.6397228067508259, 1, 0.11422995988347175`], 
     Hue[0.6480964260879271, 1, 0.10263571772440869`], 
     Hue[0.00018732572002322367`, 1, 0.9997406259261217], 
     Hue[0.004573041232335373, 1, 0.9936680967552279], 
     Hue[0.016885810167012294`, 1, 0.9766196474610599], 
     Hue[0.03504333402312931, 1, 0.9514784605833594], 
     Hue[0.05867870183218771, 1, 0.918752566693894], 
     Hue[0.6078298610852293, 1, 0.15838942311275953`], 
     Hue[0.6218486718492184, 1, 0.13897876205492835`], 
     Hue[0.6343249996026264, 1, 0.12170384670405575`], 
     Hue[0.6436950868820425, 1, 0.10872987970178741`], 
     Hue[0.649875666263389, 1, 0.10017215440453835`], 
     Hue[0.6475692009086055, 1, 0.10336572181885394`], 
     Hue[0.6439198770118821, 1, 0.10841863182970173`], 
     Hue[0.6413788110138431, 1, 0.11193703090390966`], 
     Hue[0.6401277211067978, 1, 0.11366930923674151`], 
     Hue[0.6397059507278937, 1, 0.11425329899214721`], 
     Hue[0.6398369640434706, 1, 0.11407189593981008`], 
     Hue[0.6403569374825362, 1, 0.11335193271648833`], 
     Hue[0.641151218310306, 1, 0.11225215926265324`], 
     Hue[0.6470632312005988, 1, 0.10406629526070936`], 
     Hue[0.0016859314802094572`, 1, 0.9976656333350946], 
     Hue[0.00940104522567875, 1, 0.9869831681490602], 
     Hue[0.025032568030160962`, 1, 0.9653395211890079], 
     Hue[0.6392108022004, 1, 0.11493888926098464`], 
     Hue[0.6473136102425532, 1, 0.10371961658723405`], 
     Hue[0.6492875699780105, 1, 0.1009864415689086], 
     Hue[0.6454707802615185, 1, 0.10627122733020528`], 
     Hue[0.6424976384085133, 1, 0.11038788528052015`], 
     Hue[0.640672091628267, 1, 0.11291556543778425`], 
     Hue[0.6398314828147121, 1, 0.11407948533347553`], 
     Hue[0.6396768730079941, 1, 0.11429356045046973`], 
     Hue[0.6400606815587446, 1, 0.11376213322635367`], 
     Hue[0.6407371125462331, 1, 0.11282553647444649`], 
     Hue[0.6477144383895738, 1, 0.10316462376828249`], 
     Hue[0.0009366286001163404, 1, 0.9987031296306081], 
     Hue[0.006987043229007006, 1, 0.9903256324521441], 
     Hue[0.02057223617216719, 1, 0.9715153653000761], 
     Hue[0.040268606538324425`, 1, 0.9442434678700122], 
     Hue[0.6495816181206997, 1, 0.10057929798672348`], 
     Hue[0.6465042257363891, 1, 0.10484030282653821`], 
     Hue[0.6430881452255879, 1, 0.10957026045687829`], 
     Hue[0.641004705012752, 1, 0.11245502382849724`], 
     Hue[0.639979601960755, 1, 0.11387439728510852`], 
     Hue[0.639682245310486, 1, 0.11428612187778871`], 
     Hue[0.6399123118784444, 1, 0.11396756816830769`], 
     Hue[0.002435234360302574, 1, 0.9966281370395811], 
     Hue[0.013003160871797426`, 1, 0.9819956234082804], 
     Hue[0.6490917131033733, 1, 0.10125762801071388`], 
     Hue[0.6486913541373193, 1, 0.10181197119448113`], 
     Hue[0.6419369452227782, 1, 0.11116422969153789`], 
     Hue[0.6403394782437819, 1, 0.11337610704707127`], 
     Hue[0.6397282715851161, 1, 0.1142223931898392], 
     Hue[0.6480207433189897, 1, 0.10274050925062968`], 
     Hue[0.037502963670055456`, 1, 0.9480728195337694], 
     Hue[0.643504011118735, 1, 0.10899444614328999`], 
     Hue[0.6411710117049946, 1, 0.11222475302385373`], 
     Hue[0.6398746379609574, 1, 0.11401973205405888`], 
     Hue[0.6404389037591136, 1, 0.11323844094891963`], 
     Hue[0.0020605829202560155`, 1, 0.9971468851873379], 
     Hue[0.011029132342513348`, 1, 0.9847288936795969], 
     Hue[0.6482026616729633, 1, 0.10248862229897394`], 
     Hue[0.6491405459066658, 1, 0.10119001336000116`], 
     Hue[0.6405057849360244, 1, 0.11314583624242776`], 
     Hue[0.6397574232416907, 1, 0.11418202935765905`], 
     Hue[0.6397172313156321, 1, 0.11423767971681716`], 
     Hue[0.02252372483887366, 1, 0.9688133040692518], 
     Hue[0.6459717381502809, 1, 0.10557759333038039`], 
     Hue[0.6427779850013807, 1, 0.10999971307501127`], 
     Hue[0.639670392601782, 1, 0.11430253332060944`], 
     Hue[0.6399864348015667, 1, 0.11386493642859996`], 
     Hue[0.003412864802204929, 1, 0.9952744948892548], 
     Hue[0.6499807645337834, 1, 0.10002663372245377`], 
     Hue[0.6402044516836848, 1, 0.11356306689951348`], 
     Hue[0.6481721088568645, 1, 0.10253092619818771`], 
     Hue[0.00009366286001166735, 1, 0.9998703129630608], 
     Hue[0.004271290982751363, 1, 0.9940859047931134], 
     Hue[0.016425006916367946`, 1, 0.9772576827311827], 
     Hue[0.03442842661139778, 1, 0.9523298708457568], 
     Hue[0.057852434197578795`, 1, 0.9198966295725831], 
     Hue[0.6073699787250146, 1, 0.1590261833038259], 
     Hue[0.6214187772186262, 1, 0.13957400077421], 
     Hue[0.6339854976761372, 1, 0.1221739262945793], 
     Hue[0.6434196467280808, 1, 0.10911125837650347`], 
     Hue[0.6499124222812251, 1, 0.10012126145676521`], 
     Hue[0.6477023228051326, 1, 0.10318139919289339`], 
     Hue[0.644023843485169, 1, 0.10827467825130464`], 
     Hue[0.64144761817366, 1, 0.11184175945185541`], 
     Hue[0.6401462360000532, 1, 0.11364367323069563`], 
     Hue[0.6397089139050697, 1, 0.11424919613144204`], 
     Hue[0.6398275455640988, 1, 0.11408493691124788`], 
     Hue[0.6403387413457017, 1, 0.11337712736749], 
     Hue[0.6411189328359744, 1, 0.11229686222711237`], 
     Hue[0.6470225307512879, 1, 0.10412264972898604`], 
     Hue[0.0015922686201977898`, 1, 0.9977953203720339], 
     Hue[0.009099294976094852, 1, 0.9874009761869457], 
     Hue[0.024405357232339164`, 1, 0.9662079669090688], 
     Hue[0.6389298447451344, 1, 0.11532790727596788`], 
     Hue[0.6470913473849507, 1, 0.10402736515929908`], 
     Hue[0.6493243259958467, 1, 0.10093554862113545`], 
     Hue[0.6455723724606997, 1, 0.10613056120826202`], 
     Hue[0.6425677250567301, 1, 0.11029084222914294`], 
     Hue[0.6407136683013276, 1, 0.11285799773662337`], 
     Hue[0.6398499977079675, 1, 0.11405384932742965`], 
     Hue[0.6396667834310846, 1, 0.11430753063388288`], 
     Hue[0.6400421198694501, 1, 0.11378783402691525`], 
     Hue[0.6407122618139731, 1, 0.1128599451806526], 
     Hue[0.6476737379402628, 1, 0.10322097823655917`], 
     Hue[0.0008429657401046731, 1, 0.9988328166675473], 
     Hue[0.0066852929794231075`, 1, 0.9907434404900296], 
     Hue[0.020111432921522843`, 1, 0.9721534005701992], 
     Hue[0.039506899264476925`, 1, 0.945298139479955], 
     Hue[0.6496183741385358, 1, 0.10052840503895033`], 
     Hue[0.6466373476329161, 1, 0.1046559802005777], 
     Hue[0.6431921116988747, 1, 0.10942630687848122`], 
     Hue[0.6410462816858127, 1, 0.11239745612733637`], 
     Hue[0.6399981168540103, 1, 0.11384876127906265`], 
     Hue[0.639685208487662, 1, 0.11428201901708351`], 
     Hue[0.6399028933990727, 1, 0.11398060913974549`], 
     Hue[0.0023415715002909065`, 1, 0.9967578240765204], 
     Hue[0.012509653739476434`, 1, 0.9826789409761095], 
     Hue[0.6488694502457708, 1, 0.10156537658277887`], 
     Hue[0.6488340057099291, 1, 0.10161445363240582`], 
     Hue[0.6420070318709951, 1, 0.11106718664016066`], 
     Hue[0.6403810549168425, 1, 0.1133185393459104], 
     Hue[0.6397310040022612, 1, 0.11421860984302293`], 
     Hue[0.647982901934521, 1, 0.10279290501374017`], 
     Hue[0.03688805625832392, 1, 0.9489242297961669], 
     Hue[0.6436079775920218, 1, 0.10885049256489293`], 
     Hue[0.6412125883780552, 1, 0.11216718532269286`], 
     Hue[0.6398652194815857, 1, 0.11403277302549669`], 
     Hue[0.6404140530268536, 1, 0.11327284965512574`], 
     Hue[0.001966920060244348, 1, 0.9972765722242771], 
     Hue[0.010535625210192356`, 1, 0.985412211247426], 
     Hue[0.6479803988153607, 1, 0.10279637087103898`], 
     Hue[0.6491773019245021, 1, 0.10113912041222801`], 
     Hue[0.6405473616090851, 1, 0.11308826854126688`], 
     Hue[0.639775938134946, 1, 0.11415639335161316`], 
     Hue[0.6397071417387226, 1, 0.1142516499002303], 
     Hue[0.021954645924100347`, 1, 0.9696012594897072], 
     Hue[0.6461048600468079, 1, 0.10539327070441984`], 
     Hue[0.6428480716495977, 1, 0.10990267002363407`], 
     Hue[0.639673355778958, 1, 0.11429843045990426`], 
     Hue[0.6399678731122722, 1, 0.11389063722916153`], 
     Hue[0.003134526836723661, 1, 0.9956598859183827], 
     Hue[0.6497585016761809, 1, 0.10033438229451881`], 
     Hue[0.6402243020788728, 1, 0.11353558173694533`], 
     Hue[0.6481342674723958, 1, 0.1025833219612982], 
     Hue[0.6413100038540261, 1, 0.11203230235596391`], 
     Hue[0.6403751336193708, 1, 0.11332673806548664`], 
     Hue[0.00970279547526276, 1, 0.9865653601111747], 
     Hue[0.6492508139601744, 1, 0.10103733451668175`], 
     Hue[0.6453748538112997, 1, 0.10640404856896972`], 
     Hue[0.6398129679214568, 1, 0.11410512133952141`], 
     Hue[0.6396869625849037, 1, 0.11427959026705659`], 
     Hue[0.02103303942281154, 1, 0.9708773300299532], 
     Hue[0.6429882449460314, 1, 0.10970858392087963`], 
     Hue[0.6399307497336834, 1, 0.11394203883028467`], 
     Hue[0.0025778509057611254`, 1, 0.9964306679766385], 
     Hue[0.6493139759609758, 1, 0.10094987943864885`], 
     Hue[0.6402979015707213, 1, 0.11343367474823214`], 
     Hue[0.03811787108178688, 1, 0.947221409271372], 
     Hue[0.6491037898888297, 1, 0.1012409063077743], 
     Hue[0.6397389083484354, 1, 0.11420766536370491`], 
     Hue[0.02315093563669557, 1, 0.9679448583491908], 
     Hue[0.6396674294246061, 1, 0.11430663618131463`], 
     Hue[0.6499830594330205, 1, 0.10002345616966403`], 
     Hue[0.6401846012884966, 1, 0.11359055206208162`], 
     Hue[0.6482099502413331, 1, 0.10247853043507721`], 
     Hue[0.00004683143000572265, 1, 0.9999351564815305], 
     Hue[0.004120415857959414, 1, 0.9942948088120562], 
     Hue[0.01619460529104577, 1, 0.9775767003662442], 
     Hue[0.034120972905532065`, 1, 0.9527555759769557], 
     Hue[0.05743930038027445, 1, 0.9204686610119277], 
     Hue[0.6071400375449074, 1, 0.15934456339935907`], 
     Hue[0.62120382990333, 1, 0.13987162013385082`], 
     Hue[0.6338157467128926, 1, 0.12240896608984106`], 
     Hue[0.6432819266511001, 1, 0.10930194771386147`], 
     Hue[0.6499308002901433, 1, 0.10009581498287864`], 
     Hue[0.6477688837533961, 1, 0.1030892378799131], 
     Hue[0.6440758267218123, 1, 0.10820270146210609`], 
     Hue[0.6414820217535685, 1, 0.11179412372582828`], 
     Hue[0.6401554934466809, 1, 0.11363085522767269`], 
     Hue[0.6397103954936576, 1, 0.11424714470108943`], 
     Hue[0.639822836324413, 1, 0.11409145739696679`], 
     Hue[0.6403296432772844, 1, 0.11338972469299084`], 
     Hue[0.6411027900988087, 1, 0.11231921370934192`], 
     Hue[0.6470021805266324, 1, 0.10415082696312437`], 
     Hue[0.0015454371901920672`, 1, 0.9978601638905034], 
     Hue[0.008948419851302791, 1, 0.9876098802058885], 
     Hue[0.024091751833428265`, 1, 0.9666421897690993], 
     Hue[0.6387893660175015, 1, 0.11552241628345952`], 
     Hue[0.6469802159561494, 1, 0.10418123944533159`], 
     Hue[0.6493427040047647, 1, 0.10091010214724888`], 
     Hue[0.6456389334089632, 1, 0.10603839989528173`], 
     Hue[0.6426027683808385, 1, 0.11024232070345433`], 
     Hue[0.6407344566378579, 1, 0.11282921388604294`], 
     Hue[0.6398592551545952, 1, 0.11404103132440672`], 
     Hue[0.6396629846588422, 1, 0.1143127904723724], 
     Hue[0.6400328390248029, 1, 0.11380068442719603`], 
     Hue[0.6406998364478432, 1, 0.11287714953375563`], 
     Hue[0.6476533877156074, 1, 0.10324915547069752`], 
     Hue[0.0007961343100989504, 1, 0.9988976601860168], 
     Hue[0.006534417854631047, 1, 0.9909523445089723], 
     Hue[0.01988103129620078, 1, 0.9724724182052605], 
     Hue[0.039126045627553174`, 1, 0.9458254752849263], 
     Hue[0.649636752147454, 1, 0.10050295856506376`], 
     Hue[0.6467039085811797, 1, 0.10456381888759744`], 
     Hue[0.6432440949355182, 1, 0.10935433008928266`], 
     Hue[0.641067070022343, 1, 0.11236867227675593`], 
     Hue[0.640007374300638, 1, 0.11383594327603971`], 
     Hue[0.6396866900762499, 1, 0.11427996758673092`], 
     Hue[0.6398981841593868, 1, 0.11398712962546438`], 
     Hue[0.002294740070285073, 1, 0.9968226675949899], 
     Hue[0.012262900173315883`, 1, 0.9830205997600241], 
     Hue[0.6487583188169695, 1, 0.10171925086881137`], 
     Hue[0.6489053314962341, 1, 0.10151569485136819`], 
     Hue[0.6420420751951036, 1, 0.11101866511447205`], 
     Hue[0.6404018432533728, 1, 0.11328975549532995`], 
     Hue[0.6397323702108338, 1, 0.11421671816961479`], 
     Hue[0.6479639812422867, 1, 0.10281910289529542`], 
     Hue[0.0365806025524581, 1, 0.9493499349273657], 
     Hue[0.6436599608286652, 1, 0.1087785157756944], 
     Hue[0.6412333767145855, 1, 0.11213840147211242`], 
     Hue[0.6398605102418998, 1, 0.11403929351121558`], 
     Hue[0.6404024278246226, 1, 0.11328894608898413`], 
     Hue[0.0019200886302385145`, 1, 0.9973414157427467], 
     Hue[0.010288871644031805`, 1, 0.9857538700313405], 
     Hue[0.6478692673865595, 1, 0.10295024515707153`], 
     Hue[0.6491956799334201, 1, 0.10111367393834145`], 
     Hue[0.6405681499456154, 1, 0.11305948469068644`], 
     Hue[0.6397851955815738, 1, 0.11414357534859022`], 
     Hue[0.6397020969502678, 1, 0.11425863499193688`], 
     Hue[0.021724244298778173`, 1, 0.9699202771247686], 
     Hue[0.6461714209950714, 1, 0.10530110939143955`], 
     Hue[0.6428831149737061, 1, 0.10985414849794548`], 
     Hue[0.639674837367546, 1, 0.11429637902955167`], 
     Hue[0.639958592267625, 1, 0.11390348762944232`], 
     Hue[0.0029953578539829717`, 1, 0.9958525814329466], 
     Hue[0.6496473702473796, 1, 0.10048825658055131`], 
     Hue[0.6402355365611303, 1, 0.11352002629997346`], 
     Hue[0.6481153467801615, 1, 0.10260951984285345`], 
     Hue[0.6413444074339346, 1, 0.11198466662993678`], 
     Hue[0.6403660355509535, 1, 0.11333933539098748`], 
     Hue[0.0095519203504707, 1, 0.9867742641301175], 
     Hue[0.6492691919690924, 1, 0.10101188804279518`], 
     Hue[0.645422817036409, 1, 0.10633763794958748`], 
     Hue[0.6398222253680844, 1, 0.11409230333649847`], 
     Hue[0.6396819177964489, 1, 0.11428657535876316`], 
     Hue[0.020802637797489476`, 1, 0.9711963476650146], 
     Hue[0.6430361619889445, 1, 0.10964223724607683`], 
     Hue[0.6399214688890361, 1, 0.11395488923056546`], 
     Hue[0.0024820657903082965`, 1, 0.9965632935211116], 
     Hue[0.6492028445321746, 1, 0.10110375372468139`], 
     Hue[0.6403186899072516, 1, 0.11340489089765171`], 
     Hue[0.03781041737592117, 1, 0.9476471144025707], 
     Hue[0.6491221678977478, 1, 0.10121545983388773`], 
     Hue[0.639748165795063, 1, 0.11419484736068197`], 
     Hue[0.02283733023778456, 1, 0.9683790812092213], 
     Hue[0.6396689110131941, 1, 0.11430458475096203`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6401945264860907, 1, 0.11357680948079754`], 
     Hue[0.6481910295490988, 1, 0.10250472831663246`], 
     Hue[0.6455187434866279, 1, 0.10620481671082305`], 
     Hue[0.6396718282195394, 1, 0.11430054554217631`], 
     Hue[0.6431401284622313, 1, 0.10949828366767977`], 
     Hue[0.6399076026387586, 1, 0.11397408865402658`], 
     Hue[0.0023884029302967402`, 1, 0.9966929805580507], 
     Hue[0.6404264783929836, 1, 0.11325564530202269`], 
     Hue[0.6491589239155839, 1, 0.10116456688611458`], 
     Hue[0.6397666806883184, 1, 0.1141692113546361], 
     Hue[0.022210119439962872`, 1, 0.9692475269292822], 
     Hue[0.6498696331049821, 1, 0.10018050800848632`], 
     Hue[0.6402143768812788, 1, 0.11354932431822941`], 
     Hue[0.6412756002741176, 1, 0.11207993808199104`], 
     Hue[0.00985367060005482, 1, 0.9863564560922318], 
     Hue[0.6429532016219229, 1, 0.10975710544656825`], 
     Hue[0.002717019888501704, 1, 0.9962379724620745], 
     Hue[0.6402771132341909, 1, 0.11346245859881258`], 
     Hue[0.038425324787652704`, 1, 0.9467957041401731], 
     Hue[0.649047983068844, 1, 0.10131817728929292`], 
     Hue[0.6397351026279788, 1, 0.11421293482279851`], 
     Hue[0.6396659478360182, 1, 0.11430868761166722`], 
     Hue[0.6499661188660408, 1, 0.10004691233932805`], 
     Hue[0.6482288709335675, 1, 0.10245233255352197`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction->((Print[#]; #)& ),
  FormatType:>OutputForm,
  Frame->True,
  FrameLabel->{None, None},
  Method->{},
  PlotLabel->"Modulation",
  PlotRange->{{0, 52.699602136444376`}, {-0.05, 1.05}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], Automatic}]], "Print",
 CellChangeTimes->{3.5633676069696903`*^9, 3.5660870584585333`*^9, 
  3.566101844582582*^9, 3.566139290343261*^9, 3.614707874300829*^9},
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"},
 
 CellLabel->
  "During evaluation of \
In[73]:=",ExpressionUUID->"532b389b-e46b-494e-850f-5801f1dd3eb4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ModulationTransferFunction", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "61.8918326902036`"}], ",", "60.80601106405969`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "61.8918326902036`"}], ",", "60.80601106405969`"}], 
          "}"}]}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], ",", 
   RowBox[{"PhaseTransferFunction", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "61.8918326902036`"}], ",", "60.80601106405969`"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "61.8918326902036`"}], ",", "60.80601106405969`"}], 
          "}"}]}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], ",", 
   RowBox[{"OutputGraphics", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ModulationTransferFunction", "\[Rule]", 
       GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwVl3c8lf8bxu3MjEKlkOQrUSl7dN9nmYUWlZJUVtlCkhUl83hOUZJESiSJ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         "], {{}, {}, 
          {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1Xe81mMcBuDT3nur1GmX9tJA9mogoYVEFKWSUpFCaBBStPeUvSkrm8zs
vWXvPXLdH39c576/zzm973ue5/mdCoeP7X92kYKCgi2+JLv58pa8hhPZh0HW
/pK3cyEt6W3tG7mOcYw3V+MZ/ShO00uyhAfMc2Ub1jHbPE024DW9KN31t+V8
TmJfBlv7W97BdFrRx9q3cj2X6E1Zw3jzObI6z+pHM0IvxYP6HIrRw/yOvJaT
2Y8h1v6RdzJLb8UMfbLcgxW8lD2RndhL7yu/kxvyvhxDcXpaf1cuYBijzRV5
XJ8n27OBXuah8l95FxfRmhLZc+vvyYWcwv60oSSlKE0ZylKO8lSgIpWoTBWq
Uo3q1KBm9tVrvy+vYzgH0JZa2Qvf+0Bez6kcSDtq08v3PpSLcrYcRHv6Wf9e
bmQC/amTz2z9I7k458DBdMjdsP6D3MS5+TfmGuzQj+V0vTQP6VfItszNvZMN
WcnrOT/ZhRtyRvk95MdySV6DQ3J/re2Wd3MxHXMvrP0oNzNTb8bEfBZZk2U8
Z75KdmAjA8xnyDI8nM9F3eyP+RO5NN/n0NzdPETck/vJFL0uL+udck/0n7L/
+ezyUtmcSfpx1Mvemj+VyxjJGHMlntAPy73Ns8oi7jXPzp1kLTPNU2U9duqd
cyb6z3IL53F8XtdaWR7Rr6R+zsj8mVye+6g3ZjWjzPkjUZkn9cNzt/Wi3Jff
gS45P/Mv8kYmM9Fci+f1Exill2N73lO2Yz3zzNNlIat4w7xAdmXPnKX8XK7g
TI7Ic2GtGPfrl9GVAeZf5U1Z01swRZ8ka7OcF8xXy45sYmBeU5bn0Zw7DXKW
5l1yJWdxZJ4Xa8XZql/O+Xp9XtHny85sZu+cpfwtz5K8OT8vWzI1ZyDr8KI+
iIY5V/MXchWjGWuuwlN67zyPegkWs808R7Zmln5B9olX9W45X/13eUs+I4Mp
zLlZ/1KuzvOgN2GMPk5WZSlPm/vQPWdm/kPemvdgCI2y/9a/kmtyL+hLDxrT
hKY0o3n2zc9+Ldfmd6IfPRlo/U95G9MYmn22VoHHckbM0Bvxpr4w+1rk//+n
Wpj/A6bNu/4=
            "],
            VertexColors->Automatic]}},
         VertexColors->{
           Hue[0., 1, 1.], 
           Hue[0.003969540733167354, 1, 0.994503712830999], 
           Hue[0.015964203665723598`, 1, 0.9778957180013058], 
           Hue[0.03381351919966624, 1, 0.9531812811081544], 
           Hue[0.05702616656296999, 1, 0.9210406924512723], 
           Hue[0.08804715288668818, 1, 0.8780885575415086], 
           Hue[0.12115303588207504`, 1, 0.8322496426248192], 
           Hue[0.16016571418836928`, 1, 0.7782320880468733], 
           Hue[0.2005117607428496, 1, 0.7223683312791314], 
           Hue[0.23911972855193425`, 1, 0.6689111450819372], 
           Hue[0.28096556473772577`, 1, 0.6109707565169951], 
           Hue[0.3193725306438068, 1, 0.5577918806470368], 
           Hue[0.35593307134720303`, 1, 0.5071695935192574], 
           Hue[0.3938805880202113, 1, 0.45462687812586133`], 
           Hue[0.4273583634380576, 1, 0.40827303523961256`], 
           Hue[0.4614762536820767, 1, 0.3610328795171247], 
           Hue[0.4926702116531927, 1, 0.31784124540327163`], 
           Hue[0.5193803564486097, 1, 0.2808579679942327], 
           Hue[0.5456459396940175, 1, 0.24449023734674502`], 
           Hue[0.567762267294848, 1, 0.21386762989944125`], 
           Hue[0.5890549163078942, 1, 0.18438550049676183`], 
           Hue[0.6069100963648001, 1, 0.1596629434948923], 
           Hue[0.6209888825880338, 1, 0.1401692394934917], 
           Hue[0.633645995749648, 1, 0.12264400588510288`], 
           Hue[0.6431442065741193, 1, 0.10949263705121946`], 
           Hue[0.6499491782990613, 1, 0.10007036850899206`], 
           Hue[0.6478354447016597, 1, 0.10299707656693284`], 
           Hue[0.6441278099584556, 1, 0.10813072467290756`], 
           Hue[0.641516425333477, 1, 0.11174648799980116`], 
           Hue[0.6401647508933085, 1, 0.11361803722464976`], 
           Hue[0.6397118770822456, 1, 0.11424509327073684`], 
           Hue[0.6398181270847271, 1, 0.11409797788268569`], 
           Hue[0.6403205452088672, 1, 0.11340232201849168`], 
           Hue[0.6410866473616429, 1, 0.11234156519157149`], 
           Hue[0.6421482860262874, 1, 0.11087160396360207`], 
           Hue[0.6432605840714736, 1, 0.10933149897795977`], 
           Hue[0.6445496366805256, 1, 0.10754665690388775`], 
           Hue[0.6457873866109285, 1, 0.10583284930794513`], 
           Hue[0.646981830301977, 1, 0.10417900419726271`], 
           Hue[0.6482477916258018, 1, 0.10242613467196673`], 
           Hue[0.0014986057601861225`, 1, 0.997925007408973], 
           Hue[0.008797544726510842, 1, 0.987818784224831], 
           Hue[0.023778146434517367`, 1, 0.9670764126291298], 
           Hue[0.04483885018140965, 1, 0.937915438210356], 
           Hue[0.07209410609377909, 1, 0.9001773915624598], 
           Hue[0.6142682141282336, 1, 0.1494747804378304], 
           Hue[0.627828023844626, 1, 0.13069965929205637`], 
           Hue[0.6386488872898687, 1, 0.11571692529095112`], 
           Hue[0.6468690845273481, 1, 0.10433511373136407`], 
           Hue[0.6493610820136828, 1, 0.10088465567336231`], 
           Hue[0.6457054943572267, 1, 0.10594623858230148`], 
           Hue[0.642637811704947, 1, 0.11019379917776571`], 
           Hue[0.6407552449743882, 1, 0.1128004300354625], 
           Hue[0.6398685126012229, 1, 0.11402821332138378`], 
           Hue[0.6396644662474301, 1, 0.11431073904201981`], 
           Hue[0.6400235581801557, 1, 0.11381353482747682`], 
           Hue[0.6406874110817132, 1, 0.11289435388685869`], 
           Hue[0.6416032149509483, 1, 0.11162631776022554`], 
           Hue[0.6476330374909519, 1, 0.10327733270483586`], 
           Hue[0.0007493028800931167, 1, 0.9989625037044865], 
           Hue[0.006383542729839098, 1, 0.9911612485279151], 
           Hue[0.019650629670878494`, 1, 0.972791435840322], 
           Hue[0.038745191990629424`, 1, 0.9463528110898977], 
           Hue[0.06437827330744528, 1, 0.9108608523435373], 
           Hue[0.6105891552465168, 1, 0.15456886196636133`], 
           Hue[0.6244280396327723, 1, 0.1354073297392384], 
           Hue[0.636362011161562, 1, 0.1188833691609142], 
           Hue[0.6450909816665281, 1, 0.10679710230788424`], 
           Hue[0.6496551301563721, 1, 0.1004775120911772], 
           Hue[0.6467704695294432, 1, 0.10447165757461715`], 
           Hue[0.6432960781721615, 1, 0.10928235330008414`], 
           Hue[0.6410878583588733, 1, 0.1123398884261755], 
           Hue[0.6400166317472656, 1, 0.11382312527301677`], 
           Hue[0.6396881716648379, 1, 0.11427791615637833`], 
           Hue[0.6398934749197009, 1, 0.11399365011118329`], 
           Hue[0.6404886052236335, 1, 0.11316962353650745`], 
           Hue[0.6413449311562955, 1, 0.1119839414758985], 
           Hue[0.6473074338964644, 1, 0.10372816845104929`], 
           Hue[0.002247908640279239, 1, 0.9968875111134595], 
           Hue[0.012016146607155442`, 1, 0.9833622585439387], 
           Hue[0.02879583281709186, 1, 0.9601288468686421], 
           Hue[0.6408965469319939, 1, 0.11260478117108529`], 
           Hue[0.6486471873881683, 1, 0.10187312515484391`], 
           Hue[0.6489766572825391, 1, 0.10141693607033055`], 
           Hue[0.6448952215602058, 1, 0.10706815476279197`], 
           Hue[0.642077118519212, 1, 0.11097014358878345`], 
           Hue[0.6404226315899032, 1, 0.11326097164474952`], 
           Hue[0.6397337364194063, 1, 0.11421482649620665`], 
           Hue[0.6397374104694511, 1, 0.11420973934999086`], 
           Hue[0.6401720516945114, 1, 0.11360792842298426`], 
           Hue[0.6408862169397929, 1, 0.11261908423720991`], 
           Hue[0.6479450605500523, 1, 0.10284530077685067`], 
           Hue[0.00037465144004655837`, 1, 0.9994812518522432], 
           Hue[0.005176541731503281, 1, 0.992832480679457], 
           Hue[0.01780741666830099, 1, 0.975343576920814], 
           Hue[0.036273148846592385`, 1, 0.9497756400585644], 
           Hue[0.06052035691427826, 1, 0.9162025827340763], 
           Hue[0.6087496258056584, 1, 0.15711590273062684`], 
           Hue[0.622708461110403, 1, 0.13778828461636503`], 
           Hue[0.6350040034556049, 1, 0.12076368752300856`], 
           Hue[0.644201930236118, 1, 0.10802809659614435`], 
           Hue[0.6498021542277167, 1, 0.10027394030008463`], 
           Hue[0.6473029571155514, 1, 0.10373436707077502`], 
           Hue[0.6437119440653086, 1, 0.10870653898649585`], 
           Hue[0.6412541650511158, 1, 0.11210961762153199`], 
           Hue[0.6400906913202871, 1, 0.11372058124883326`], 
           Hue[0.6397000243735418, 1, 0.11426150471355759`], 
           Hue[0.639855801002214, 1, 0.11404581399693449`], 
           Hue[0.6403933297562053, 1, 0.11330154341448496`], 
           Hue[0.6412157892589692, 1, 0.11216275333373499`], 
           Hue[0.6471446320992207, 1, 0.103953586324156], 
           Hue[0.0018732572002326808`, 1, 0.9974062592612163], 
           Hue[0.010042118077871254`, 1, 0.9860955288152551], 
           Hue[0.02628698962580467, 1, 0.9636026297488859], 
           Hue[0.6397727171109313, 1, 0.11416085323101821`], 
           Hue[0.6477581359577582, 1, 0.10310411944310402`], 
           Hue[0.6492140579423382, 1, 0.10108822746445488`], 
           Hue[0.645278927361081, 1, 0.10653686980773418`], 
           Hue[0.6423574651120795, 1, 0.11058197138327458`], 
           Hue[0.6405889382821457, 1, 0.11303070084010601`], 
           Hue[0.6397944530282015, 1, 0.11413075734556728`], 
           Hue[0.639697052161813, 1, 0.11426562008364345`], 
           Hue[0.6400978049373335, 1, 0.11371073162523053`], 
           Hue[0.640786814010753, 1, 0.1127567190620343], 
           Hue[0.6477936950121775, 1, 0.10305488382929263`], 
           Hue[0.001123954320139564, 1, 0.9984437555567298], 
           Hue[0.007590543728175025, 1, 0.989490016376373], 
           Hue[0.021493842673456, 1, 0.9702392947598302], 
           Hue[0.04179202108601954, 1, 0.9421341246501268], 
           Hue[0.6495081060850274, 1, 0.10068108388226975`], 
           Hue[0.6462379819433349, 1, 0.1052089480784593], 
           Hue[0.6429181582978145, 1, 0.10980562697225686`], 
           Hue[0.6409215516666308, 1, 0.112570159230819], 
           Hue[0.6399425721742442, 1, 0.11392566929720027`], 
           Hue[0.6396763189561341, 1, 0.11429432759919907`], 
           Hue[0.6399493114229778, 1, 0.1139163380297231], 
           Hue[0.0028561888712423933`, 1, 0.9960452769475105], 
           Hue[0.01399017513643952, 1, 0.9806289882726222], 
           Hue[0.6495362388185784, 1, 0.1006421308665838], 
           Hue[0.6484060509920994, 1, 0.1022070063186317], 
           Hue[0.6417967719263444, 1, 0.1113583157942923], 
           Hue[0.6402563248976606, 1, 0.11349124244939303`], 
           Hue[0.6397228067508259, 1, 0.11422995988347175`], 
           Hue[0.6480964260879271, 1, 0.10263571772440869`], 
           Hue[0.00018732572002322367`, 1, 0.9997406259261217], 
           Hue[0.004573041232335373, 1, 0.9936680967552279], 
           Hue[0.016885810167012294`, 1, 0.9766196474610599], 
           Hue[0.03504333402312931, 1, 0.9514784605833594], 
           Hue[0.05867870183218771, 1, 0.918752566693894], 
           Hue[0.6078298610852293, 1, 0.15838942311275953`], 
           Hue[0.6218486718492184, 1, 0.13897876205492835`], 
           Hue[0.6343249996026264, 1, 0.12170384670405575`], 
           Hue[0.6436950868820425, 1, 0.10872987970178741`], 
           Hue[0.649875666263389, 1, 0.10017215440453835`], 
           Hue[0.6475692009086055, 1, 0.10336572181885394`], 
           Hue[0.6439198770118821, 1, 0.10841863182970173`], 
           Hue[0.6413788110138431, 1, 0.11193703090390966`], 
           Hue[0.6401277211067978, 1, 0.11366930923674151`], 
           Hue[0.6397059507278937, 1, 0.11425329899214721`], 
           Hue[0.6398369640434706, 1, 0.11407189593981008`], 
           Hue[0.6403569374825362, 1, 0.11335193271648833`], 
           Hue[0.641151218310306, 1, 0.11225215926265324`], 
           Hue[0.6470632312005988, 1, 0.10406629526070936`], 
           Hue[0.0016859314802094572`, 1, 0.9976656333350946], 
           Hue[0.00940104522567875, 1, 0.9869831681490602], 
           Hue[0.025032568030160962`, 1, 0.9653395211890079], 
           Hue[0.6392108022004, 1, 0.11493888926098464`], 
           Hue[0.6473136102425532, 1, 0.10371961658723405`], 
           Hue[0.6492875699780105, 1, 0.1009864415689086], 
           Hue[0.6454707802615185, 1, 0.10627122733020528`], 
           Hue[0.6424976384085133, 1, 0.11038788528052015`], 
           Hue[0.640672091628267, 1, 0.11291556543778425`], 
           Hue[0.6398314828147121, 1, 0.11407948533347553`], 
           Hue[0.6396768730079941, 1, 0.11429356045046973`], 
           Hue[0.6400606815587446, 1, 0.11376213322635367`], 
           Hue[0.6407371125462331, 1, 0.11282553647444649`], 
           Hue[0.6477144383895738, 1, 0.10316462376828249`], 
           Hue[0.0009366286001163404, 1, 0.9987031296306081], 
           Hue[0.006987043229007006, 1, 0.9903256324521441], 
           Hue[0.02057223617216719, 1, 0.9715153653000761], 
           Hue[0.040268606538324425`, 1, 0.9442434678700122], 
           Hue[0.6495816181206997, 1, 0.10057929798672348`], 
           Hue[0.6465042257363891, 1, 0.10484030282653821`], 
           Hue[0.6430881452255879, 1, 0.10957026045687829`], 
           Hue[0.641004705012752, 1, 0.11245502382849724`], 
           Hue[0.639979601960755, 1, 0.11387439728510852`], 
           Hue[0.639682245310486, 1, 0.11428612187778871`], 
           Hue[0.6399123118784444, 1, 0.11396756816830769`], 
           Hue[0.002435234360302574, 1, 0.9966281370395811], 
           Hue[0.013003160871797426`, 1, 0.9819956234082804], 
           Hue[0.6490917131033733, 1, 0.10125762801071388`], 
           Hue[0.6486913541373193, 1, 0.10181197119448113`], 
           Hue[0.6419369452227782, 1, 0.11116422969153789`], 
           Hue[0.6403394782437819, 1, 0.11337610704707127`], 
           Hue[0.6397282715851161, 1, 0.1142223931898392], 
           Hue[0.6480207433189897, 1, 0.10274050925062968`], 
           Hue[0.037502963670055456`, 1, 0.9480728195337694], 
           Hue[0.643504011118735, 1, 0.10899444614328999`], 
           Hue[0.6411710117049946, 1, 0.11222475302385373`], 
           Hue[0.6398746379609574, 1, 0.11401973205405888`], 
           Hue[0.6404389037591136, 1, 0.11323844094891963`], 
           Hue[0.0020605829202560155`, 1, 0.9971468851873379], 
           Hue[0.011029132342513348`, 1, 0.9847288936795969], 
           Hue[0.6482026616729633, 1, 0.10248862229897394`], 
           Hue[0.6491405459066658, 1, 0.10119001336000116`], 
           Hue[0.6405057849360244, 1, 0.11314583624242776`], 
           Hue[0.6397574232416907, 1, 0.11418202935765905`], 
           Hue[0.6397172313156321, 1, 0.11423767971681716`], 
           Hue[0.02252372483887366, 1, 0.9688133040692518], 
           Hue[0.6459717381502809, 1, 0.10557759333038039`], 
           Hue[0.6427779850013807, 1, 0.10999971307501127`], 
           Hue[0.639670392601782, 1, 0.11430253332060944`], 
           Hue[0.6399864348015667, 1, 0.11386493642859996`], 
           Hue[0.003412864802204929, 1, 0.9952744948892548], 
           Hue[0.6499807645337834, 1, 0.10002663372245377`], 
           Hue[0.6402044516836848, 1, 0.11356306689951348`], 
           Hue[0.6481721088568645, 1, 0.10253092619818771`], 
           Hue[0.00009366286001166735, 1, 0.9998703129630608], 
           Hue[0.004271290982751363, 1, 0.9940859047931134], 
           Hue[0.016425006916367946`, 1, 0.9772576827311827], 
           Hue[0.03442842661139778, 1, 0.9523298708457568], 
           Hue[0.057852434197578795`, 1, 0.9198966295725831], 
           Hue[0.6073699787250146, 1, 0.1590261833038259], 
           Hue[0.6214187772186262, 1, 0.13957400077421], 
           Hue[0.6339854976761372, 1, 0.1221739262945793], 
           Hue[0.6434196467280808, 1, 0.10911125837650347`], 
           Hue[0.6499124222812251, 1, 0.10012126145676521`], 
           Hue[0.6477023228051326, 1, 0.10318139919289339`], 
           Hue[0.644023843485169, 1, 0.10827467825130464`], 
           Hue[0.64144761817366, 1, 0.11184175945185541`], 
           Hue[0.6401462360000532, 1, 0.11364367323069563`], 
           Hue[0.6397089139050697, 1, 0.11424919613144204`], 
           Hue[0.6398275455640988, 1, 0.11408493691124788`], 
           Hue[0.6403387413457017, 1, 0.11337712736749], 
           Hue[0.6411189328359744, 1, 0.11229686222711237`], 
           Hue[0.6470225307512879, 1, 0.10412264972898604`], 
           Hue[0.0015922686201977898`, 1, 0.9977953203720339], 
           Hue[0.009099294976094852, 1, 0.9874009761869457], 
           Hue[0.024405357232339164`, 1, 0.9662079669090688], 
           Hue[0.6389298447451344, 1, 0.11532790727596788`], 
           Hue[0.6470913473849507, 1, 0.10402736515929908`], 
           Hue[0.6493243259958467, 1, 0.10093554862113545`], 
           Hue[0.6455723724606997, 1, 0.10613056120826202`], 
           Hue[0.6425677250567301, 1, 0.11029084222914294`], 
           Hue[0.6407136683013276, 1, 0.11285799773662337`], 
           Hue[0.6398499977079675, 1, 0.11405384932742965`], 
           Hue[0.6396667834310846, 1, 0.11430753063388288`], 
           Hue[0.6400421198694501, 1, 0.11378783402691525`], 
           Hue[0.6407122618139731, 1, 0.1128599451806526], 
           Hue[0.6476737379402628, 1, 0.10322097823655917`], 
           Hue[0.0008429657401046731, 1, 0.9988328166675473], 
           Hue[0.0066852929794231075`, 1, 0.9907434404900296], 
           Hue[0.020111432921522843`, 1, 0.9721534005701992], 
           Hue[0.039506899264476925`, 1, 0.945298139479955], 
           Hue[0.6496183741385358, 1, 0.10052840503895033`], 
           Hue[0.6466373476329161, 1, 0.1046559802005777], 
           Hue[0.6431921116988747, 1, 0.10942630687848122`], 
           Hue[0.6410462816858127, 1, 0.11239745612733637`], 
           Hue[0.6399981168540103, 1, 0.11384876127906265`], 
           Hue[0.639685208487662, 1, 0.11428201901708351`], 
           Hue[0.6399028933990727, 1, 0.11398060913974549`], 
           Hue[0.0023415715002909065`, 1, 0.9967578240765204], 
           Hue[0.012509653739476434`, 1, 0.9826789409761095], 
           Hue[0.6488694502457708, 1, 0.10156537658277887`], 
           Hue[0.6488340057099291, 1, 0.10161445363240582`], 
           Hue[0.6420070318709951, 1, 0.11106718664016066`], 
           Hue[0.6403810549168425, 1, 0.1133185393459104], 
           Hue[0.6397310040022612, 1, 0.11421860984302293`], 
           Hue[0.647982901934521, 1, 0.10279290501374017`], 
           Hue[0.03688805625832392, 1, 0.9489242297961669], 
           Hue[0.6436079775920218, 1, 0.10885049256489293`], 
           Hue[0.6412125883780552, 1, 0.11216718532269286`], 
           Hue[0.6398652194815857, 1, 0.11403277302549669`], 
           Hue[0.6404140530268536, 1, 0.11327284965512574`], 
           Hue[0.001966920060244348, 1, 0.9972765722242771], 
           Hue[0.010535625210192356`, 1, 0.985412211247426], 
           Hue[0.6479803988153607, 1, 0.10279637087103898`], 
           Hue[0.6491773019245021, 1, 0.10113912041222801`], 
           Hue[0.6405473616090851, 1, 0.11308826854126688`], 
           Hue[0.639775938134946, 1, 0.11415639335161316`], 
           Hue[0.6397071417387226, 1, 0.1142516499002303], 
           Hue[0.021954645924100347`, 1, 0.9696012594897072], 
           Hue[0.6461048600468079, 1, 0.10539327070441984`], 
           Hue[0.6428480716495977, 1, 0.10990267002363407`], 
           Hue[0.639673355778958, 1, 0.11429843045990426`], 
           Hue[0.6399678731122722, 1, 0.11389063722916153`], 
           Hue[0.003134526836723661, 1, 0.9956598859183827], 
           Hue[0.6497585016761809, 1, 0.10033438229451881`], 
           Hue[0.6402243020788728, 1, 0.11353558173694533`], 
           Hue[0.6481342674723958, 1, 0.1025833219612982], 
           Hue[0.6413100038540261, 1, 0.11203230235596391`], 
           Hue[0.6403751336193708, 1, 0.11332673806548664`], 
           Hue[0.00970279547526276, 1, 0.9865653601111747], 
           Hue[0.6492508139601744, 1, 0.10103733451668175`], 
           Hue[0.6453748538112997, 1, 0.10640404856896972`], 
           Hue[0.6398129679214568, 1, 0.11410512133952141`], 
           Hue[0.6396869625849037, 1, 0.11427959026705659`], 
           Hue[0.02103303942281154, 1, 0.9708773300299532], 
           Hue[0.6429882449460314, 1, 0.10970858392087963`], 
           Hue[0.6399307497336834, 1, 0.11394203883028467`], 
           Hue[0.0025778509057611254`, 1, 0.9964306679766385], 
           Hue[0.6493139759609758, 1, 0.10094987943864885`], 
           Hue[0.6402979015707213, 1, 0.11343367474823214`], 
           Hue[0.03811787108178688, 1, 0.947221409271372], 
           Hue[0.6491037898888297, 1, 0.1012409063077743], 
           Hue[0.6397389083484354, 1, 0.11420766536370491`], 
           Hue[0.02315093563669557, 1, 0.9679448583491908], 
           Hue[0.6396674294246061, 1, 0.11430663618131463`], 
           Hue[0.6499830594330205, 1, 0.10002345616966403`], 
           Hue[0.6401846012884966, 1, 0.11359055206208162`], 
           Hue[0.6482099502413331, 1, 0.10247853043507721`], 
           Hue[0.00004683143000572265, 1, 0.9999351564815305], 
           Hue[0.004120415857959414, 1, 0.9942948088120562], 
           Hue[0.01619460529104577, 1, 0.9775767003662442], 
           Hue[0.034120972905532065`, 1, 0.9527555759769557], 
           Hue[0.05743930038027445, 1, 0.9204686610119277], 
           Hue[0.6071400375449074, 1, 0.15934456339935907`], 
           Hue[0.62120382990333, 1, 0.13987162013385082`], 
           Hue[0.6338157467128926, 1, 0.12240896608984106`], 
           Hue[0.6432819266511001, 1, 0.10930194771386147`], 
           Hue[0.6499308002901433, 1, 0.10009581498287864`], 
           Hue[0.6477688837533961, 1, 0.1030892378799131], 
           Hue[0.6440758267218123, 1, 0.10820270146210609`], 
           Hue[0.6414820217535685, 1, 0.11179412372582828`], 
           Hue[0.6401554934466809, 1, 0.11363085522767269`], 
           Hue[0.6397103954936576, 1, 0.11424714470108943`], 
           Hue[0.639822836324413, 1, 0.11409145739696679`], 
           Hue[0.6403296432772844, 1, 0.11338972469299084`], 
           Hue[0.6411027900988087, 1, 0.11231921370934192`], 
           Hue[0.6470021805266324, 1, 0.10415082696312437`], 
           Hue[0.0015454371901920672`, 1, 0.9978601638905034], 
           Hue[0.008948419851302791, 1, 0.9876098802058885], 
           Hue[0.024091751833428265`, 1, 0.9666421897690993], 
           Hue[0.6387893660175015, 1, 0.11552241628345952`], 
           Hue[0.6469802159561494, 1, 0.10418123944533159`], 
           Hue[0.6493427040047647, 1, 0.10091010214724888`], 
           Hue[0.6456389334089632, 1, 0.10603839989528173`], 
           Hue[0.6426027683808385, 1, 0.11024232070345433`], 
           Hue[0.6407344566378579, 1, 0.11282921388604294`], 
           Hue[0.6398592551545952, 1, 0.11404103132440672`], 
           Hue[0.6396629846588422, 1, 0.1143127904723724], 
           Hue[0.6400328390248029, 1, 0.11380068442719603`], 
           Hue[0.6406998364478432, 1, 0.11287714953375563`], 
           Hue[0.6476533877156074, 1, 0.10324915547069752`], 
           Hue[0.0007961343100989504, 1, 0.9988976601860168], 
           Hue[0.006534417854631047, 1, 0.9909523445089723], 
           Hue[0.01988103129620078, 1, 0.9724724182052605], 
           Hue[0.039126045627553174`, 1, 0.9458254752849263], 
           Hue[0.649636752147454, 1, 0.10050295856506376`], 
           Hue[0.6467039085811797, 1, 0.10456381888759744`], 
           Hue[0.6432440949355182, 1, 0.10935433008928266`], 
           Hue[0.641067070022343, 1, 0.11236867227675593`], 
           Hue[0.640007374300638, 1, 0.11383594327603971`], 
           Hue[0.6396866900762499, 1, 0.11427996758673092`], 
           Hue[0.6398981841593868, 1, 0.11398712962546438`], 
           Hue[0.002294740070285073, 1, 0.9968226675949899], 
           Hue[0.012262900173315883`, 1, 0.9830205997600241], 
           Hue[0.6487583188169695, 1, 0.10171925086881137`], 
           Hue[0.6489053314962341, 1, 0.10151569485136819`], 
           Hue[0.6420420751951036, 1, 0.11101866511447205`], 
           Hue[0.6404018432533728, 1, 0.11328975549532995`], 
           Hue[0.6397323702108338, 1, 0.11421671816961479`], 
           Hue[0.6479639812422867, 1, 0.10281910289529542`], 
           Hue[0.0365806025524581, 1, 0.9493499349273657], 
           Hue[0.6436599608286652, 1, 0.1087785157756944], 
           Hue[0.6412333767145855, 1, 0.11213840147211242`], 
           Hue[0.6398605102418998, 1, 0.11403929351121558`], 
           Hue[0.6404024278246226, 1, 0.11328894608898413`], 
           Hue[0.0019200886302385145`, 1, 0.9973414157427467], 
           Hue[0.010288871644031805`, 1, 0.9857538700313405], 
           Hue[0.6478692673865595, 1, 0.10295024515707153`], 
           Hue[0.6491956799334201, 1, 0.10111367393834145`], 
           Hue[0.6405681499456154, 1, 0.11305948469068644`], 
           Hue[0.6397851955815738, 1, 0.11414357534859022`], 
           Hue[0.6397020969502678, 1, 0.11425863499193688`], 
           Hue[0.021724244298778173`, 1, 0.9699202771247686], 
           Hue[0.6461714209950714, 1, 0.10530110939143955`], 
           Hue[0.6428831149737061, 1, 0.10985414849794548`], 
           Hue[0.639674837367546, 1, 0.11429637902955167`], 
           Hue[0.639958592267625, 1, 0.11390348762944232`], 
           Hue[0.0029953578539829717`, 1, 0.9958525814329466], 
           Hue[0.6496473702473796, 1, 0.10048825658055131`], 
           Hue[0.6402355365611303, 1, 0.11352002629997346`], 
           Hue[0.6481153467801615, 1, 0.10260951984285345`], 
           Hue[0.6413444074339346, 1, 0.11198466662993678`], 
           Hue[0.6403660355509535, 1, 0.11333933539098748`], 
           Hue[0.0095519203504707, 1, 0.9867742641301175], 
           Hue[0.6492691919690924, 1, 0.10101188804279518`], 
           Hue[0.645422817036409, 1, 0.10633763794958748`], 
           Hue[0.6398222253680844, 1, 0.11409230333649847`], 
           Hue[0.6396819177964489, 1, 0.11428657535876316`], 
           Hue[0.020802637797489476`, 1, 0.9711963476650146], 
           Hue[0.6430361619889445, 1, 0.10964223724607683`], 
           Hue[0.6399214688890361, 1, 0.11395488923056546`], 
           Hue[0.0024820657903082965`, 1, 0.9965632935211116], 
           Hue[0.6492028445321746, 1, 0.10110375372468139`], 
           Hue[0.6403186899072516, 1, 0.11340489089765171`], 
           Hue[0.03781041737592117, 1, 0.9476471144025707], 
           Hue[0.6491221678977478, 1, 0.10121545983388773`], 
           Hue[0.639748165795063, 1, 0.11419484736068197`], 
           Hue[0.02283733023778456, 1, 0.9683790812092213], 
           Hue[0.6396689110131941, 1, 0.11430458475096203`], 
           Hue[0.65, 1, 0.1], 
           Hue[0.6401945264860907, 1, 0.11357680948079754`], 
           Hue[0.6481910295490988, 1, 0.10250472831663246`], 
           Hue[0.6455187434866279, 1, 0.10620481671082305`], 
           Hue[0.6396718282195394, 1, 0.11430054554217631`], 
           Hue[0.6431401284622313, 1, 0.10949828366767977`], 
           Hue[0.6399076026387586, 1, 0.11397408865402658`], 
           Hue[0.0023884029302967402`, 1, 0.9966929805580507], 
           Hue[0.6404264783929836, 1, 0.11325564530202269`], 
           Hue[0.6491589239155839, 1, 0.10116456688611458`], 
           Hue[0.6397666806883184, 1, 0.1141692113546361], 
           Hue[0.022210119439962872`, 1, 0.9692475269292822], 
           Hue[0.6498696331049821, 1, 0.10018050800848632`], 
           Hue[0.6402143768812788, 1, 0.11354932431822941`], 
           Hue[0.6412756002741176, 1, 0.11207993808199104`], 
           Hue[0.00985367060005482, 1, 0.9863564560922318], 
           Hue[0.6429532016219229, 1, 0.10975710544656825`], 
           Hue[0.002717019888501704, 1, 0.9962379724620745], 
           Hue[0.6402771132341909, 1, 0.11346245859881258`], 
           Hue[0.038425324787652704`, 1, 0.9467957041401731], 
           Hue[0.649047983068844, 1, 0.10131817728929292`], 
           Hue[0.6397351026279788, 1, 0.11421293482279851`], 
           Hue[0.6396659478360182, 1, 0.11430868761166722`], 
           Hue[0.6499661188660408, 1, 0.10004691233932805`], 
           Hue[0.6482288709335675, 1, 0.10245233255352197`]}],
        AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
        Axes->True,
        AxesOrigin->{0, 0},
        DisplayFunction->((Print[#]; #)& ),
        FormatType:>OutputForm,
        Frame->True,
        FrameLabel->{None, None},
        Method->{},
        PlotLabel->"Modulation",
        PlotRange->{{0, 52.699602136444376`}, {-0.05, 1.05}},
        PlotRangeClipping->True,
        PlotRangePadding->{
          Scaled[0.02], Automatic}]}], ",", 
      RowBox[{"FindIntensity", "\[Rule]", 
       Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxcnWWY1UqzRnF3d3d3h71hcHd3dxjk4M7gLoMc3N3d3Qd35+A+yOByuXmz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         "], {{
           {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxEnXm8VdP//88dz3Dne8+58znn3tskKg1CCA1UVCikIlTIkIyhIlOojBmT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               "]], Polygon3DBox[CompressedData["
1:eJw0nQV0XUXXhm/SSNO0Sdv4zb1RoLhDW9ytuLu7FfdSoLi7u7trcXeHIsWK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               "]], Polygon3DBox[CompressedData["
1:eJwt13mcz3UeB/APg5zDMKZdzSRXKq2OYaNtI61jG2WZ6KKiVM6UK0fO5GhM
lJDkGtYRCiE6JI2jXJtUKJVkd0LIXZh9fh4zf7wf83u/Pq/36318Pt/v5zvV
Oj3dpmfREMIXrDh7v3oIWX8O4SU2if/5VSFsuSKEvxUJYWdKCP9hM3BeZNsq
h7CMv0zgVJzl7Fa8K+H72WicLtVCqFdBfJUQWvwphMlVQ5gOzxV3/PIQ+pYM
YbW46mnyilmdHELRhBA6pIbwBt4GvGN4vfFW4p2GP4o3CC9T4dfzu6uxZdkQ
rlNzWfauuIOwfHVtj/XCfuJfKcdwsTlit4ltKXYlbrL14yytfAiV1TcL/gvO
vkohPGYGj8tbXB+5JfSilgs0ssRNY+vp32a9C+4Kf/eJbWD9d/hd+PddGcKH
8KbmUg3+PRsjbg7eYTm+FddZjidwNsCusZ6hlo/1k6Xm92FXww5ULpjtZrxc
2LX8TSkFulthQW/d48xpDtVbPZyd8J7WD+MdYbPknQUrBUvCXQibChsutojf
94s9ZW0E/3n44MiJc6B3XB8vwCbDtsHuskdPyDGD5fH36qOjMjrRb483ld/C
71HmlSd2OGy82PW4VxXu701sMO2ncLqwhTjD2Di8D/Aq4LXCGQl7GbYBVhPW
EVbWPs0QswJ2lkY5/nl5xl6GC0/Xz0J9LLdvtZJCuAzvcxp3x15xp+L9z5wb
4C2HLaR5AueAuvvqo4faf43nyh7+gXNS7Evq2IRbybl6FLYANgr2IL15zmeG
M54k9yB1PCm2oT0sRue4c1+ff4wtlfOi2FqJcP5n4qvgVIA9VCyEt8UeVsvD
tJPF7aPbg/6JuL/yHlPfe9bS+TP0lufZ6iVvTfHTYBfEdrPeO9ZhLjfyX5dj
kfW3WGn7O1u+PHgHvEpy7JGjmxxF5Z6Bc1qORWaQwC+KdzmdDNxGNOfSqijP
IP7r5rXG2h0469TyD3OerpZiNMbg5ODeKqakHJ/KcU7eNXqupY8ncQaYxXv8
srjP0BtPbyK9W+nNE9tK7L9YY1gZWHXc3mXo4y0WX159b+Jt9nsLa6a3j+To
DPsO5wt9DC5nD9X2ldgc+1Ea/qq8u/mJ8Vmn/y7svBzl+SNxc8z0fn08a223
HEPpDVXfYryDeM3UcoC1h7XHaQSrxc/HneRcrcS7RT1L9TVf7L04SWawywyS
8f6QYyf99ngX1XyBf3t8X+Gk477sbJSGPaye98W0w6sDn0i/Cs0h8s6EbSys
ZQm7xP9Nv7PtW38zGCFvNt4n8OqemUdw6sIqWMtg03A78AewrnjZeD+bbYY6
1sMOmNGP7IQc94htqZasuIfqOKm3TLUMxhsodp7Yc9b64/ym7t3OQa7+Am5n
vN54N+PdgTdGvxNxNsPrmNU+OfbG9x1OH1YP7854DvC6xnMBS4XVgN0MW6T2
p2Mf8fmAlYC9CWsD66anv8fn1loXseVgP6sjF+8GMyjL78nKWk+M7zolvoRf
Q88/mn0j3Ex731t9U/Be1+chPWTq7WlYTfa9WlNx26p9rx7uhG3yezO93601
4Tc2h4FiTojdRWMmrWdZbXnr4Q221gQnFfaH39XojcddxP9QfH3zm6iWH/DH
wprjjsY7g3OC3uyoJ3cZ/iU2O54RnH6wcvx8lgO7H/YZvUTPwGfyzqa5hf94
zOF3vnrbuvM6x/NnXmvjvUa/j+fzNL+fPLfAmsX9oNeaXl/YX2FNYS/DWsE2
im+r5pk0a4h/FacXuwKvOt6N9mhBvLtxl+t1ifpyzewMvyveMZwj9i7bfuTJ
m5JWcOcsiPtGbw7/Kbyj/F/wRuE15h+Ct1frGH2skOt6/nPxfez3YNx7aVR1
dp+EHeHniR1ZeNf2lPtb9VdWTyf1LMDpzx4o/LZoIzZNbDEzXSzmbHy21FKc
vz6+n/WUjrdWzwf1/w7NA2r5L71DbAWttayf2p5j4+zBDvW9IfYBel/TayXm
EZzuLJ/WJdi6wue3BOzqimqk/w0rwm+cVvBePoP3QXye4l1E7wt9VJAzUx//
xhurxrfVl0GzCmwcf2Rawd3+ACxBHy/w7zGDbLHncQ7G7xW8IeKfp70Ib4Q9
OgXrAUuAJcC2yj9CfYthc8XVlrdUKXpmkExzj7nNj8+5taNiu+FdiM9GvLfE
9orfSrBfYYdhWbB9sRbxd6jlO3HD1DIZZ1B8P8k7F7e/Wg7Ty4/3iphTYqfg
BVhdfdwpdn98l+PXxWkCT3R378b5GTaOVlNYEizHfsxhH8a717Of6b23Tx+P
4b4GK22m2+klwsrAsmErYDUKz/NN5pirj2x618lZHG8tfgd1jKDXmHYjNs99
M5LfB3eGUl+0j6Pj+yjeCWrcQa8J3kK8UXgN2Dla/5RjiRwN+W/hTpejFryE
ObeO50eeufLdjVfe2gB1zJdjNZ0W9JrHezV+b+Hux6lnrZ15NYcti/eovKnq
OOtM7pFjiPiKdKrD5tNtT/+ImI/VUBNWi20Q+ymr6/cNbLE7qhqtTfGbkP8a
y8afQK+Y3nrKkabmo/T60suxv73jncqOeMfO5Y+WN0Xeu5ILzusY/r24b4pp
Gd/t1nrAnpDje/6XeqjtGZuO01qe3+xbkl6XyrMMZ756juP9IK4ZjZvwpsB+
hHW1j3XEfqO25mJPOQe9Yg7xzfgDxfdQ88R4l5njdNhUdtjv+3DasTU4U2B5
sK/5X7F1sOvkyHDuK8mRzF6Jz25qwXdLEr8imxi/YePd43drcQdolMOZACsH
S0wp0EiBfRBnirMWtkPNt+ljpnkN8304UG/PmOEs/ni8i2quD9ukn2P27BNY
VeuX2Brvj2r8rTTT8YL1Hua8w9+d8RuVXm15rmGr8b6kuUTcEH4G+i7+82LP
ePY2yNFEPZPw9sb3Hd6gOBe8PfFbhTV0x9aFpVt7hL8KN4Xfgb/Wnnen9Z35
T3NXrILdbd/exnkN/oO57+d3sKepZnxWjdv11FDev7A58RtWzU39Lo23xf52
jvcJ/Cd+A/wHnY/J/q6kV7PwmyFdv5vidydbJm+N+L8m2yruHTV+o/7b1ThW
Pcv459T3ij4PytNKjvpyrIJnWS8Zzxb+yti/+Kx4b7OT9uhjmtvivvubyRaq
JUEdF+hNiu8geq3p3UJvgfgx9r+hvMPjM8f/PN6X4lLZSbOaB9sYz4z1CXEv
8Rdbe8oMEmidhr1Brw29LXh5/PSYO/7/Im8Sa+Y8tTOHXdY2x/e6WvL518Zv
DbPNotVQntq+AVbFd6deipr9knh38evwK3nndI37wx4S+xgs1XlYJ7Yk7CKd
HfrYzj6K72zYp+rvKOcnNJbCzsI6Ft7JbdVUl/9/jbF3YA==
               
               "]]}]}, {}, {}, {}, {}}, {
           {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl1F9MlmUYx/FLkBJC/INKCi8KmqYCvUXLzWi1eZK0TspVWpiaf4gIBRIF
I0WbdVId9MfClavVUSetcssDW8NipkUJaE7dtMWBtam5lW6OUZ+7tvd9r+/v
uq/7d1/v81zPU7Fu8yMt4yJii5/sLRGJDxdEnB0fUUvPpofowryIhtKI++jX
CiOeFF8X18h14jfxPrF7TsR+fBCvnhDRxmMIF8if4/MRn6v0p2omOewV+YO4
Gn8tHuH3EO7Hz4q1N0V0VDhvslp6hMfjcu/x/YTeWx7RQx/BN6x9gI9a+5Ue
o3utfyP3D32SZyZHr848j+/FF8V5ZREr8RW8LeX0Xa9mhM/bdJ649uaIL/Co
mjr1J3DORHvED9Xm44m5zp8asVjc6cJNzY84pO/ldPukiFy+M+zfRE/mmUMf
td5Il4il6oem+d/0Kj5VxRFNuJj3sPxzeDpuFhtm8sLP4wI+JXxb8MCtETW8
M7w202vkt4h3qF+LbzinlV6HR/FJvm30M/QY3Y6n8MuonyX3QuqNX7FcGb2V
Pl6iD7oDl1qbkerTtaOb9T1gfabc9rSux07xaX4Z3IXLxVPO3YFn4xdTTn25
mnI+3anfNHv+w0t4vdwv6nfiDXjclIhdOKt+I51L99CbcB7ejYf1cBvPCrk9
dCW/BfRc+mV6Dj2frqQ30kV00Lvd2wfpp+QXiSvFDXKF+DF82f1udb8fxT/j
a/b8bu/nOFf8zbytNitv0X+r6RB71V/CT+AR8UfXaC7PpfQP+H3X/ax8Gd3P
r8e875cbM7OjZviw+R3kfYHuxZc8I334D2vd9GfWPqbP0w3OXyG3l76LZ6O4
3vlZXI9rxD77q3AVLhKbnNmVnif5P12GM3wOeE4H8QE1r8p/id/F74hd/N7A
2/Eyfa4S76/0Na9LeNXJ1cmdEPP51PPWVgzynUBn5TP0Ic9EVv1P9rkcUZ2e
AXEP7wG5WbgHu82xxM8ubLyjxp7lPN3iWCCeAtXp2UrvHzXTxXvU78DGJjrF
Y/x8Yht2yeO699sws2X2G5k4pre/5B6gtRFX8fc2aDH6rF2h66wVpXelDSsc
dlnO+MZWnj5R68x2kEapTey339ZoxUY5FupxqcXviv8btZiHbwfGJVrUfCvv
1kVzmmPxTn5N2DHRmOZcfNi55yTuTu8P+isHnB7//7v7X0Xlrsw=
             "],
             VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwV0slOVFEUheHtOxgUwSAaAfUhHDpAJ8JUMRKwQTRxYDM0CkprA0WfOFGR
AhR7BcXYgoJAUTRCeBi+M1hZe69/73PuvVWlZ6+cvLwjIrJ0qiji2b6If6UR
w/zb3oiukoh6/e3iiHn+RJ6lp/Qd78bPybd2Rizw5/JxGqGfeAY/L79j/4d+
VD5Gv9V1ByJ68At4E/5L9gJ7SbPqXqxZPqNu2u98+qO+K7tmppDuqffwDLZI
Lfoye3/NtarneIV7htOz0XWzlbwNKze3qF6iCflxXueMW+YrsAL1LsrJq3m7
nSremXZ4h/4Yn3fHtP1leadsledphXL4V2xNfR9b56/0b+l1+tZ2+9x1Uf4A
/8/fyD/QVc8xmd7LTL+ZBuyhmQX9O3yS3lNOP4Bfwh/hS/pDdj9inyivH8Qb
8S58WT8l/0yr6qH0G7un3s6K/mDal3WbvWGmKL0bntEXp3fBe9SHzayr81hv
enb1iDuydNPcCd4nP2JuQ72ZvonZL1i//LT/25xsQH1G/tj9NXxQX4NtOG+3
vpBqaUh+lG8DTsJ6nA==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lSk1EUhuHjLqwiUcAqkZAAsgJ0AaHKFUhskoDNQEfikDU4S59AJAMW
4ETBlnaETRr7Duxmjn0cvPU1597/nn8kd/PCjWMRsYyLQxGPhiM6IxGnkxE9
WjoZUUZffmg2Rt+iokucilgfjRjIG2Zn6HtUzWp4x4/jI7LHI+q6D3wKpUTE
vPcO3C/zOb5CL9GXuip/ma/RK/SVrs5f5fP8X+T5hq5AZ+XC/2/Z6Rw9j653
Mt5M2m3Ov5ygaTnL3zN/jX1dXx7gk/Ob8mNM8M9pw/kntEk/657yz3DLO2n5
K1pmK/jCvzDbQob/jlV9G9/4CXcm6aTctHfR3j25aI+U2YLc0i/SQ/2CPq2f
cv5IXjGb5n/wb8xW5bPyT7nNX3Ovq7/PX+d/6WfM1+RtOz0wu+17v/V/0NEv
6e9iSt6jO9jFHfwDG3JeOg==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DdSA1EQhOHBQ06GkQQx3nufU2SkEAIS3hvhuQGXAG5BFSE5l8B79yn4
q3t6+82+3dRUZiKdFxFrOKuI2E1GjFVF/GIUp7Jb2Q/fkYj4pvW1ESfyL75d
9kmPzR+0zfxO63SOZGXVEaU4zD2viZjDAV8iK8Y+P6lbxBciax5xfhh7fJNn
Q/wgds0FOvlolO+Y3+St3vlKt80D9AX9qNbZkiXcv8/8jF6kzIupiAXk2ZWm
h7rn7pbh55HUedJtsfuRjss27ZrWC2f+ZBvmq8qIdfru7CzW+EvZHb/K9+h1
Y4Xvopf2dNIqe651luUduf+IJf6n3N3ohR0Lue/TmcE836aTdZ9WmjE32NHC
P6AZN56lc/+Mv0cjLrxvx7f8A5qSRd0=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Us3lWEYxvG7WTYR2gysCMU8E3wAIqc2I2aMmuw98AFCZS2HnU2O5UzT
ytlHMHVqWN8DtfoZ/Nd1vf/nuZ/nffeuHsyk0g8iYgTfKiLyn0UUYKwq4k91
xG/s8s+5Yb1Wvq2N2OHq9Tps648qI5rN9FtbqYnY4gq4Ji5fbnpe5v+hkUtw
G1y5LMO6/tdaBmt6knuCVX3Amdfu+YV3KOW/8ife5xQfub6nEVX2feF79RRW
9DdyyHra2rizl7kS84PcFS6xxL2Qd9b3sej5lWxDzvkzWOCO5DFu+Q/29zh7
nu+WXfisN7inU9+37xAHmOM7uFEz7+9/W2Tsm+Vf8+3I6W3yLOm++/v1VnzS
W+SImayZPef9RJb/Ib9jWr/xTmlM6cW+7zEm9ZdmivQa84VygjvXLzDqf8iT
D5HAfwywS64=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lOlFEUxfELugikqoCqUkQ6jdEwQPcAJIAgYjNkYJOgLoBEKrIDLae0
ShWgdIUIDExAlEYRBkpsFqI/Bif3nf85973vS9970HG/LCJGaCMRcTcVUVcV
8b064oDWsYaaiEY6j3/DrmYjipmINdkd/SHstvmBv6xzWv5KvsrX8tfl58z3
fA4/JT/L99tZwW6ZWb7PLPFH3nqis6J7zW5GtoxfMi/SkvO2LK/TYv5OR/yi
RbxZfmj/sSwvW8B+8sf0jJrk89gf/b/0A3uq+1L3Hd4ob6C3zvVmueyFbI5v
M9tp2d4SzWLDfJlOWverb92nGfymf6nB9vhdKmJzugO6g3brvFst35F9oYK8
104V9pl/XhExjfVgKWwb+0RvsBtYEiu554r7Prr3Nd6Nd9GUc+CP8EnnQjJi
wvzHP6Rx54T9VvdVmmP84klmJ+e7zmD15gUalW3qbVEF3un+Yfw/u4BYAQ==

             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0cdOlGEUBuDjRbgSCxgXLg0ygwpTGNoWE3euKC41ITHhFoam3oCuRenN
NhY66A1gY2AKM16Fz79487Zzvu/L/7cOP7n/+EJEFGH7UsTktYhaa8QUbr8S
cYaXWvT4J/yCzNWIITMPr0cs645lN80+aItY4Xec85tepXfpNbyH/8jW6X36
k/0NuoSL8r/Q4YzXzt6U36aHL0ek8Jzsnaxu9oU7K+6rQqfuje69Lk2PmL+L
38puXIy4Q4/KuvC87IO5e/SY7MR9H/mD5C34EL+UlaHEZ813m/1M5+hX8lP4
wuf5jO4rfWTvuTdVve0bf44b0IQec+N2UvoT7y3DKWTtbpmdoWfhGeRkaXPb
8mn+kTcW7O/w391xK/kXztrlf/B5fo/uwZPyCvTSC3b25QW65pw69NOL8gN5
H10yO+Gupm6AX9Id6v5583nyXfUNPJh8K/xUfqQfpf8DuVxj8g==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0FtTjmEUxvHVF5CYhqlJvZnBkSRUkm1HnL0VwqSiknZk00YlVDaHZggf
wofgO9hvEkVkJpsZsonfc3DN/76ute617udJNXWnuzIi4j59zo3IKogYWxWx
EkdxOS6lbbSFMlIRV+QH8TLuXh3xsDBizt3f6pdkB9RGcD9+kv+SX+SP5EcM
4y53atU+qi2oDckOqw3irGxIbVzPBf6QfAA/yPfZc1ftHt2h97J1SaZ3szmt
tIlm5GvlJc4ttJGmZTv19ZtVZ2YfvpP1Jt/Cn8cd6m9l55JvkJ3FKf5M8i18
D27X80Y2aP9pvlZ+CoOvsGcEi/Ef9eRF/MQf2RGLuDX5D+ob8C91u7fHO7uw
CnNp0uwJOzplNWZ34GtZO1bzJ/EVX6XnhvN1eslfw6vJPPkLfo1ZRXbcpPX0
XFaOZdSu5xm/V89t75mgW/RU1mZG2p4TWKkvR8+T5C62Jv8BW/C7/hp6rDaA
Y3qb5V+dj+M3rKZH6v14TDaPTfgF05Qy6wGNutvLFzg3qvc5N+Afby2lYT4T
l9FR+QqsxyU4jv8B8RVrbg==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0blOlGEUh/FDxTIMO8gOAxV03ANLIktBhRQUBKkIlmprx06i0FARVmWH
oLKEioJwDyAogoLXoP6meHLOef7n+973m0kNvuodzYiIKTRWRzQ1RDTjXSpi
vj5itzaiVF+CBnmRWozhuoh+daAx4tx+SnZq9wT1+jz+DV+nv0Ytktxrrka/
4NkufQ+6Uc21qAt2LtUd7/njjCdUyaZrIra5R/NvVHIjdtvdsQNbsl/8Aypk
U/Y3uXvzYnlEOTfJbXA/uTs84ya4XO+ZdWaZ+QqlOLaX4Nf4EvOR+SuK9atc
juyLucj8WT1Eof5Cli3rU/vxAgX8P98b+pfO/WS3004+X8AXYoj/yOdxH3zP
HNbNz+3NeC7Jj7vrGjeWvrP5QJ8lX5EnzPvmPeSkfy8uU7Zq/uHd35Gd/l+c
lY8V/pa7QRZ/Zv+t/aRsWfaNv0amrNVd2rDE58r/IoH33H86oE+T
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwVz0lSk2EUheEbUHYgKpAOBAGJM12FTtyAVUwMgkGmNjuwUHqbDbgAqywH
gTTYK+AKVFRiEhN7QUc+DE7dc9/znfsn2fHpc4VERNygY30Rp/ojTtNqKqKY
jniLddqPZCOOUglfxc8MRLyTrdlvJiNmsff2C2YZ29HZtg9SxZ7HP/BDNCer
URX/aD9Ot9yY8OYTv5JxV37FNw775kV8B+/mH+jU+A75sjxhdtFnbJjW5Vnv
rsvq9kndHnsv3XO3gU1hB3QOUh9+1dsmfgl/rD+Gf7EX7Pf3b1OOWtgIlXUq
1OZHaV5Wp6e6azpfsSf8nP/03Cxh37Bn+967a76X0k/SS6ws/y5/wc/rvDYr
2PlDEa/4BWzTrGI/vNvgF7Et86F7Z937ief9vyX8F3+CGrLf5hj9oRw1sV3z
JBX1p93c42/rPpLNuHWHv4yn/b6/sozZsrfpjc4/7K43/wEnRWS/
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Mky3HEUxfFrl9iImILWhhTFPkvzPFYZsmNDWZNQZZ5egReQoEk8CAuv
YZ7nIat8LE6d7z331P3/uktHxvvH0iJilqoTEeslEb+KIs6TERm8vDSigg7N
FzRfFtH7NaJG98g8VRzxSa/WfGyeNi/o9OnUyU5kmfb1+E7+GTfgS3kWntEf
1r0yZ5uv+W+eQze4324D59Ks7q1s0Z0BeeP7TfM95dk3mTf5o3lJp1znAVd6
/5b8CQ/iIZpzK6GzS/f0gT5SOj3rVemcvv9evW7/SQ+t4lE3z+RDel/cbPbN
fN7CH2QFuBUv4wzdNpySFVI73uYptw/sK+y/8R9u78hHcYJ36K3kRHTyInMX
f7RL4m78h695SzF/8Zbv7vzFb3hPvk+veFf2j0+4P0k/6T/hLEnj
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0UtTkmEYxvGbslIpI3VamQE600wH0Fr1IQKCgLKgpNrWpmUHyrDv4KrW
kEaZdrBFnyjtsCrTH4tr/tf9v5/3eV+GTOth+UEiIjpyfyriQibi26mIZDZi
C3+fjqikI8ry1XzY/AXPzET0nbnKl+Qzd8juE/7Ce+7a1If0yycjfuJdboP7
KC190h1L7ljUZ7k7OMG94G7rM1wTx7nnXEPPcn/0W3pGv4n5wU5ysuJsExf4
OTzovU/lgFzy24q+9RUuS4p7NJg903P2JdeRAtfAdfefxw94EXecvzG4V5+X
tufe2yX4Pm7jdfucXV7eccGt4Q+s29U9s2rem454izXuuN2Y1Oyq5jR/DY9x
R6XKV8xJfVTK+gie4LuD/8A8bD4iJT3Ft/mi/t97nvC7WDB/55/Z/zM/5v/i
Ff6139zz3nO+u4tn8Q23Dw9lSHI=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0slSU1EUheENKE5EpQkkQAgBfQN7sUPBZkghAjaQ2CA2IGjsAaUcAOrM
J9AqqxjgDIfqzOZ9FERFvzv4a+211tnnpG4lXxzvGSuLiEXMNkdcaI14lY+4
SJtzEZtoB19Jn+nP0Zf8edqk30gP8MvpiKf6Af4FP0gb9Rvofr6CzuhPmU8j
o7vWHlEu38eX0Wn9CfNJpPUh+0en5K/bvOd8A/85G/FEVtAP47H5vb5Rv0P/
iN9O2/HQXJR/c+d3vHW+m3bhga7aXg2O81dwGbPO39dtlW/DFrS5654sZc4k
99ES30W7sdPeJRRxVz5M36GAkjfn7Qwl3xV39GdlC+Z+Wu/udezl/9JJfV+y
w8/ZW3Z/Sv4He2S/6YQzvc7M8WdonWwNu/lf9La+324nfwy1slXsMq/Qcf0R
81HU8D/xAyN2xnSffONq/iO9xQ95I6374Lfc5PO6Vtww52iDbkl3nf/izq94
Y+cwPYRR+WZ9FeqdPShrSf4D8jpZLUaS76t7br5qzuqz5hxaMMP/BwoFVVs=

             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0TlP1GEUxeHrB7CkcoEBLClNRCgFYWbYRkRQaWgAQcCINLRswcSIUljC
RxBXxNhasO+LrTRsgystzxQn5z2/e+77/ieTaOvN9FyIiElqvRrxNT/if0HE
HD/jT65E/OW/6aH5F/yP8yz/x/vMT3mWyosiHuh8NvtEv7Be82N+H/+IfaDj
RMQr3eeFESdmLWbv8Xd0ZNZj5wi/h/+4HFGm2+z8GG/iM3pvaYzuyoe6CZ0B
9zVg3XoT2J7derlLPpBLdZ7p1GEpe5uXInZ1auWkfMN8A9vBarBGbF3eltPy
HblVJ+m8haV4Bqvmm/Kgb993/zTdxjawKt6gU8Gv50VU8np5zb3r5qu8wJ39
dh75zrrcDM/InfJNs1psFRu124Ft8xpsBfvmzXbshd53Oy/9zmV8RCetc1G+
5byEDfOfOlO04t1F7JpzMS3LC/Ib9xTJhbSEzWNZb5zQojxu/tRsIvcf0iS9
piF3V+f+C+cSbw7wczKLZ3U=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0Us71GEYx/GbYaS1rhZSDi/AXohcpK2Ny8Jp7LWoRCWmFGXG5FgUOb0P
vYH2Hd9CJ+dT+Vjc1/f5fe/7OfxnKlJ32vrzImJBLV2N+Hwtorgi4m5ZRD7e
wyKsK49oUF/0L8j3+QQO4EWs12utimjEr2Ye8AX8IN7gbqpv/JB8wM+azVRG
FFr/LI34rvdQ71B+hEn8xWfNNJud9LbH/G+uxFnv5Jf2vMc/XKWZYf2M/AT/
ciOYlUdxW24xMyV32pfDHe41dsnTeEt/l5ux7uZmcU+ewx65UH/de/a5ea6X
W8ADeYOf0z/y7mXukHuDKTNv8UiuvhzRJy/Kx+fffCXiBKvsS3vjU3UqP8Mx
dZv/Jz+3fmXfC/yB/7lx6y13TWDO3EfrcN6KsyfNfMBLfqc8btU6wyXNbXpn
PleDteq66lUJ7hMum6nHOpVSBfyus/fVnmo//8+4eXPH8olKyqe45p6se9ax
Q25yfxrPALr5Yhg=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0LlO1XEQxfFhRxA6qNgxsbCQXdEXYEkgoaWA0CmbgBZQkBBLSSAxQZZ7
QYWGnjdgeQD2XZYWlx63zy2+mTNn5szvf29l33DXUFpETOG2LGK7PGILszjU
V1dGVKGwNOK9esDrqI54WRJRwNvXv6Af0r+qIprpfPqL3a9YwyqmZYYrIlbM
ntvJU5fxjH5TFJGkm+gHagI37n6Q+Sy7giHZJf41v947dVjmL/I67V3xc+lu
/oL6TZ+jJuV+8j5ix/42svk5+k260ZtZqRv6H9jAgEzSLIFB+tKtd/6PTHuT
3nrMn6cv+BnqJ5zTj8wm5BMyc7wte2f89NRv5Z2mdni99t66l8Y/4TX4hqC/
y9bT/7DHr1P/Yszundk6avV/MMrbtVND/0aPmyO8Y95T/T1avflEZtBsXG3X
t+AV+vEaMzJHMsV0G/4DjmBQtw==
             "],
             VertexColors->None]}, {Line3DBox[CompressedData["
1:eJwVz7sv5GEUh/GDLagEi5mlcVkiRDGJhIKCoJxZvSxbrUioUPAHUEh2S4lL
NyRmG6VbQ8ZUG1tsI9luQ4REJCjc4qP45nnOec/vvO+v4dv0yFRRRMzJcVVE
KhmxXh2RronYwAwuJCI2+Rjfwt+NEeM8x1POfuGZby8/Rvx1ds7v+C2+4BMe
mDmUPvuXPkUsN0Xk1Yv8BMvNneIfSfJwXs+beDP+s7eTd/AevHL/tfzX7/aG
GymqdZcUS4O9z3iPJdhr3wn/wAtYjfve8mhfy/t3eKRu5YNmX9Rd/BW/uq+f
l7ljACfVpWbSPCNfpMJbKuXCe0bVCZ6UhG++qyfk2lmdeobPyoo98/bf6mf5
D72fssMr7F/ln82v4YHeNrapc5hX15rZ5e16e3juvx78w5B7C+phzOqN6r0B
K1VJdg==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzss3XEYxvHXQlwSQuuco5FwqlKTpZEYxGKpQeJgRDDRpswdKoIek9uh
Q4caMZs6uAwEiRAkRCpNp0qa2FUkfAzfPM//eW//X+3gaOZTXkRMYK8iYisZ
sY1GrFdFrGEwhcqIX7IhepKOONU7yo895/y/FxEX8ht+0swUpvEVWVS/jmix
5+fLiAc923QH+eYO6CHK+DN6jg1735mZMzuP92av5ZvyRd85LOCP7Le7R/K/
/A2u+FvaYWbWjm/6lrGE5KuIFEb44ee9bt551wd9zfL//D12ze6hDm8TEQ14
tDOt740s3GiS5dMCtPHtaiV8p3oXMii1K6PWzV/iAp/1lcv75P3I+oePdt96
xzz/RTaO73yW1ugdMDPDr8oWaVqWoxu+f9Ae9XrZCr8lK3enAvt8Uq2S7/Xe
BC2kRShGq5lDHOAYTwn7TrY=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwVzztIFXAUx/GjEIJrpd6yoFy0IUfpcTOTJGopB8FNLBAMvOQiOpWLWVSU
TxDsMUVQQSo6SGqDpXTFQair9+p6QXIQpBqMPg5ffr/zO+f8H6daU40dBRHx
BIuHI04cjziJWyURPWUR3Xh3LOJ2IuLOAfJedWVFxAN6TnZPlimN6KRZZ2wf
ifhxOiLP7/G79B/dkO3zC0cjvqDW7mWknFVHP9hfln+kfe59iEl+TTZFH6kf
4zOfk83Rp+pnSPMvnTHvTc+dN86vyF7oDWCdz9vZoCPqUfziz5vdkSf9+RJq
MeqMEVz35hL/qjdTKC/lC+yV0QQO8Wdog/6i+77hK4rkNfKbfBrfUSy7Krth
dlXdwNc58wrqkXHfsN5PmkW7/l3kzHbRcvtbfIuZTdqMSu+/r1dFx7z1LO1X
N5qp5t/KBtUVdofopPoVbdJ/Td/ggrmk/kX6Xv2Jb9OfoLPqP+75jb+Yls1g
SX7NfLXsP/ENWkc=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j1I1WEUx/GTS13vXUKvrxXYi5JooIWGVlNGrlEZEVQXrM2WrCYLgiQr
chC0hqYcNaEaNW0o6hrUEERoJWmYQ5RDL6Tg5z98+T7nd849z8O9typ34UjX
uogYxauiiMmyiGMlEXk+ztM8hfelETNcWhHRIR/lE/xua8SIc095xFVclH00
283l8huy3qSnnpVf4w8+U6F3V96PPtmc3i3eLz+A69si7qm/ye9zU2VEMzr1
zuMcUsURK3Z99a69evO8Il/FovNBu7/zJnMF9k3Zs8/cc66WvU3ejy92NKhn
nZfd9ymZU//k3+pfvGCmzd5DWC9bxQY8ccdjpJz/u+up859sxAT/5Wrz484F
esE16s1mt3vHFt7B07I8BryxJdlrtpVz3nCYM+p27lKnzRx13pj8TnxFdpaz
6hwvemfKzkKk3LcThUirM0g71yKDH2ZbZK3odv9lXMIDO2/bVWXnHV4290/+
GYPJ2+VDvGBHHU7Ke73roaxGb5iX5PVo0CuyvxiP5KfUY8l3qrcLu9U3ffY0
Z81M6J1xfsZ7uBF1dr7AG0zKXyf/SX7JeV4DHNVnig==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T9I1HEYx/HnnFpS+mdZRNS1XBIEdSGBCN6Wg+jS0VAQodtdDVIXoXR6
Q1Di0ur1Ry7FyUO4q5ZAa2i5vURIXTuFOqPJXje8+Xyez/N8n+/3x+/8vfxo
LhERz/HtWMS1nogbpyPS9HZ3xAOax0NMnoqYwpj8iTqVjCjQcfUzeRGP+GlZ
EY/5GVmp3eN7za+eiNg8aabdQ8ud8/SKXpnG8Yg1MxV+nQ7a06Dn9KuyWW97
iYy8rm7aVVfX8Eo2Ye6LfE/+lX6Sf8Cc/CO9av9P+Rb+mNmmfXo79J96n/7F
AX8YA3qddMS5jHdkaUI/Ke+g/Xpl3/caN/lDsiH6Rv0Wt/guWZa+Uy/gPv/D
W7/jqT0btCJ/j5zeWfN5uqheQoEfNnex/T98Qw55lL1l0pt+X4hY5kt8jb6g
LdlnfsXZKg7ckXamaM91etneBA3c0TtKU2f8I1xCw5mmbBe/cAR3zf0H+LhV
Vw==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwVzzFI1GEYx/HnxNmhO8/Mpf4HlUQQQVEuFbbp5G231WJiGOoSeFhBjUGe
EgS5dKXgHVyDnoNTWFBLU0aIk52YKFGXtdTQ54aH7/f5Pf/3fZ//iZt3hsZS
EfFIfUxHTHZHTB+LeNkZcQ9f4X2ckF9So9mIL10Rt/FTEvHabEo+pd+SF3Hb
PT8zEZvm3/kT2YxqmJfwbC5iFvf0L7CsDnhBvsQrKut8t7ePY7v8veyDOqNv
yDf4Dn71xmc+dzRiX7/bugvf2GvRXt/0z8yasr/8F5bct25eMf8ne25e5b/N
VvEP5szrPMwSfsR+15xLZGl+WtZultL38kR2XuVas56Ied+exLw6pYbtnXfv
JHaYFXiR38B9//CQj/DHOI4/ZE/5XV7GB3goq/ELdr7Y+i9vVe1wmS/wPlzE
muwKX+FXsWnHOl+W3/J2v+yt/jq22f0dXzMb0Gf0g5jGc879Bwp3VJ4=
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0EtI1GEYxeFXyqVJ5ExlQYRGkGZgtNGgcN+F8JZIixZZm8Jo0cJ9UWoF
TQsvBV1Ai9GCvERKEOGiFmWaWq26mDS6KUdqI/jM4sc57znv933/mZ2nL5w4
nxcRabzfFLFcHJHFXzRsi6hHHU6iCcdxryTiGJ21/9zeEH7wV5IR17ZGXNK3
0+u4KuugnajCQVRjfnPEbV2F3RTNmB/SRzjkvm9bIs7pvtN5fElEvNR9pWP0
QO4NeQfemnvd2YN3/E1ZBrcwa34gv4/LzsyZU/JF3MFvc7/utTf7aMbcJV9C
N1bNA7nvdvaNnTQ/iF5dFndR5NtfyCb0o/QfLcUu1DhXIivj9+A/yrEXr+Sl
zjYXRXwwp+we9r9O8mdlR3TT/Aw+ocBbp+xU8Psw6fwUPqLJ7hz9jDo0oB6t
9pPOndG3oJhvpUflF2lj7l57G1CISr+3U16r38/f4B878wRd/IKdX+jm07KN
/ADdbb9PtmReRD//VJ7gn9ERc5b/6b1luoIh+XY6TCf063ULWId8jMl36Mfp
lP6PLIk2JDAtWwOXhnO9
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0j9IlWEUx/FTXSuIlspuqRUWLRFk18Gl4epgl0i7iPTvapAuJlghLqIS
RA42RJNWc9BioIMSRTYURENqVniDoJKGtiAoqEj7PMOXc87ve57nva+vtV1X
2i6vi4gZvN0Rca8y4m9VxB+8zEa8lo3LKg9EvNDf1n/mnujHUr874hq3on7B
lPy6vM7OeXMHSrgvH5QX7Q67d8Lcbx7S39L36vu4jdURm7EJo/Iu+Rl3ZXdh
Z8SI7KS9krxbVnL+vfvfYYBrly/bv8i1cgvyeQw6cymd5Zf4Tj7PZ7gKbEAn
38zP8+f4en5NLTi7nl/Vt9vJ23ll57T5oJ1f6j/8RFFe4befUlvRgsfOTuOG
e/aZV7EXayi4r0ltRB57MJWe5V0buZxn3XSuR95gPmQ+6/6n5meYw2F5h539
XI15wvm7uINarkpeLW82F3AcV+1nuW3cQ8/aqt+iz8knzRlzJn1Hz8rhKH5v
978hP+aucTtH7D6y813+Q170/mPy0fSu+Cr/Jp9Nfweuxv5I+obcMMr8Cj/N
n+D7uA/qJ5SxyH/kJ9NvN1/gl9RlvMFzvsw/4JvS9+YX1Qbzgtpi/g9jFmq6

             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D9I1GEYB/DnhuuCJIIrO7tF7xYhHMIGwanOUkiUOzkUEy+VFgUdzpYg
l9DARaLFxamuoaYTgqIGFW4xqCGXolU3I2g4EkE/N3z5/nuf3/u8v67ZpdJi
IiJewMHViIs3ImqQgtdwrz3iDb4A3/SD2Yj78Ol6xEdoz0cc6hq6l9ciujMR
7+Rf+HX+ir5OP6fX5DX6KV2UP+M3+Sq/TG/QFfkCX+XX+Dl6BR/lIqboKfkT
vkxfdtcl+6XMzLdm+Wm440xS/t1eXztkuofySbitOzX7ysy+fk9f1k/odulx
vIP/O/MZN/kx50pQhG3ZqtnwnQZfgAH441wnPsYnujP3J/ynu7696Xyv7wXf
x9+ke/Bvb8rTOTqLz/gMnW69DbfhE1mSTrZ02u50U/aX/kd/kB/So+4dgRX3
1mU/ZcP8A1iUvZf9ovvtOIQf22kQV3RvdT/ovtZbcAFmvHNL/gjfgnOcyU44

             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T1IlWEYxvHbpRBsEDWPiuFXiyINCqm0iIKDiHgyawlErED8CDpJgRKC
g+ikgw5+LE4iiIttoluRg1BIaB0hglLoYwgkDMzfGW6u6/pfz/2+78Nb3jeS
HM6KiBlzkB+xWBDxsjgix5yYd4URRUURCbOvX9A/TURs4/+wB5UR5/Stbk43
pNvQ/cJ+mh18Bh/AV/H7zt++HrGFT+Lz2Bo/xt/VTctLckq+Yafa2Vl5SK7S
v9Cv+K5lM4X344PYsZw2r7Bx5x7iefY/YUdmFO/BPvDZ+kG5Q26w28u38W14
jdwjN8slfCd/h2/VFcvtcqPcQutpGf6bNsm19J53fvbNp/wt7CbtxvaxL5k7
YKWZu2K72Hf6zQxknq/L1yXl17oDPhe7RruwTazOuT35Kn6FTrvPRV7Ef/lv
RcQf/ow/pT/oGZbmv/LP7L/n0/yE5yTsfnSn5/5TyrzRHerKSiKeyOU0aWfd
ucdyI31E68wlBVlUAQ==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0D1Im2EUxfEbCtW6BPyqH9SgIoqFilQCUggd6hAwUDMZIrQELR1KTYcO
cRGXDha76CA1QyKtk4PgouLSwaVdHNTBRRA6BR1LR38Oh3vP/9z7PM/79pcW
8x8TEfGNLtojqh0Rqd6I08cRR10Rh3SKb+K93RHP+O2eiNJgRF39LVuXjeL7
dn7xa3yr/ED/Rb+rLqtJrKb/rH/aaU+/qP+Kf3LWkv0hfBV/hy84s4z1YSvY
G2weW8A6sAo2i5WwAtbkfc30wXkP1bL8tfytfFr+yM48lsXmsAyWNfsAL+Cv
8C3v+E55PsO/lCfN5fgX/H+zU/q0flL2wz079JMy+Bie09epRhPYMJY2u8Wf
2R/BUtixewb96wGqyp/gnXien6E5KlIbnsRvvGPDGUWz62oL3ow38BM1wSfU
mjvGzRzr/7V5M35tZg1v8Lf8qLzCX/F/+ef+x575M/7q/v/Ls9h7MxfqOf2R
Xcqm9EV8+/67vOMOr1lNVw==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0L0rxmEUxvGjpwyiyDsDD4MogwWlkEVhEkpSMggDhRJSSj0ZlMk/wMLC
bjWIWCiSwUuhlPI2IMnHcHWu63uf+9zn90sOT3ZPpEXEHF3kRSyURMzTaWFE
R4GKzRRFTNM+1oaVVkYc4+v5Ec14M7Yvr8l5zvb4FX5HXVI31Fm1Vt/6/zzz
V/VNq1NUhXeVYs5G9ZXLy/xTRcSQvMD3q1nuTPHdfI/+Eb6Tb7FXurMB+ag4
4pDqsCT92K/PG73UQx2U0pvjrJPvonc9b5SNfZj3yreb1aSvUf62z6vaitWp
D/I91ct3dqzGDuQaOclfU8LdMrmIv6R8Pkfd1vfrTqacIW/JCT7Bf+Gfud77
/5f4M3+Jvcg3dktht9ijfCXPy+fymZ5bbFweo13fdIJfYYPyptmLWIP/8geU
DEob
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0UtLVWEUh/HlwJQkkTzejimo6EjtDI6YioMiKEEkNBAJwgt5IT2iYA1C
sVmioyB0Yh+gYYFfwEmDBoLg8AjqwAQvgy4Drz8Hf9Z6nrX2++7Nrhme7s3k
RMQXeVkaMV4RMSF9+lR5RGllRJn8LI5oUYeTEWk1m4jYqo3Y5r9zP+SAy+JG
8yb5WhdxzB1xzfih/Md/8KrzR8zT7oiSiGtuU7/Gt6h5XL7dFeeeu+cXXtYX
qvf5JTs7+la1RK3kcpyX1VdLPd5TG2TX8yncrO9QT9zxt8w9+Ck+xbm4HXfj
O/pVZ/1zXyf3gnvANcoT3I9zzZtwmzznhrhn+gLv04On8F07fVwR18+95wZx
Ar/GH8wXuaT7K7g33BKuwVU4gxfsfOY+3r4fNypjss6l7C3z9Xbm7X7j9v27
NH+gjtubkA3+ED/iF+3+1r/lJ2XANxbhTrNTNcNNyyv+k90EdyaPzS/UGbNL
dfb2G+wk9VfSZX4Pz/GF6ju1ir8BRpFOzA==
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0T1I1XEYxfEnggbzqpXmK2Y6uJUUCKJFQ1LpEDSEDS1pi28XFFQQ4fpK
gYstgSnm4FBDUkEXakyHIB0qyC2tQSxB0kQn6XOHw/ec5zm/3/93uecfJO90
H4uIp7RaGJFbEpFHK/y1oojPuC3/od90uTRiC4urIj7lR/zkf9EGNdpdp1N0
mqZ18rCZmiiHcilBt+gmjbu/Ta/Bt8b4c7hMo3w9jmBLccRz9+9URlSdjZjj
K7HLbkGnjK/DUmw129LL58/QXTkHE5TtO0lvvl2ghzV2DXSRTjhfgRcyb6Dj
cjbe8K2rzp3kj2jfPVn4Dw9xD+/bH/C7/BX3ruOe/AMvyRve85X/a/YFq82W
cEf+iP3OT/uNa96Vlr9jo7yKr+UV7NapMJuVa71tBpdw0x0f7J/J5Trv+Ul+
SjfNP8F3OKE7bP5Ifiv36j7m3/Cjdn12KXlRHsZXmDJ/aN6j22c2QC/N+/FF
5k04pHNPp53vonnzjsz/hZ04aP+N/gOkmlqQ
             "],
             VertexColors->None], Line3DBox[CompressedData["
1:eJwV0DtInFEQhuHx0mgawWt2RV2FVdFCC7FcUkS8i1opNt6w8JpGJWVISBEw
jQiLNlaBQLo0Wm6rFgraqQuCiAjaiYXgY/Ex77xn5uyePzWzOrZSEBHf5aI6
IlcTMVUV0anOJiLm5Lg84lJ/JfmKiLPGiHMur7/V5/EPO9f225siHrkHbou7
4V70z/p9/YTzO66wUvg/XAn+gF/dW4Yr8AFfjevwup2djxGHXL/awLfyg/gG
D6gtare5Lv4ed0gGP6l/naecdeMe7sU9Ka7X2/pkmCtOmvWerLkinDE7zmed
n8hn/aR+Dxfb/21uxB39/Dxfyo3iL3jXWcIdZdyi+SVZlq/Oqri0veb3/yxD
Zr/x9fyC/V84jdfwNm7H63gfd+I2O2k7SffXyj9+WN10/5D60+wBV25mC+fw
f997Gx/hBJ/TT5vPcqfv3wifcp+8f0M2pc7vvAHnKUnq
             "],
             VertexColors->None]}, {}, {}}},
         VertexColors->{
           Hue[0.6499999999669532, 1, 0.10000000004575714`], 
           Hue[0.6499999852880078, 1, 0.10000002037045079`], 
           Hue[0.6499998575374961, 1, 0.1000001972557747], 
           Hue[0.6499991538514573, 1, 0.1000011715902899], 
           Hue[0.6499968622093047, 1, 0.10000434463327044`], 
           Hue[0.6499926810152515, 1, 0.10001013397888259`], 
           Hue[0.6499886753209286, 1, 0.1000156803248681], 
           Hue[0.6499871827318621, 1, 0.10001774698665249`], 
           Hue[0.6499886974241673, 1, 0.10001564972038382`], 
           Hue[0.6499925949688808, 1, 0.10001025312001116`], 
           Hue[0.6499966840514407, 1, 0.10000459131338975`], 
           Hue[0.6499990174111819, 1, 0.10000136050759434`], 
           Hue[0.6499998034253445, 1, 0.10000027218029237`], 
           Hue[0.6499999729662879, 1, 0.10000003743129375`], 
           Hue[0.6499999980637757, 1, 0.10000000268092593`], 
           Hue[0.6499999980108732, 1, 0.10000000275417563`], 
           Hue[0.649999972502692, 1, 0.10000003807319564`], 
           Hue[0.6499998007707878, 1, 0.10000027585583228`], 
           Hue[0.6499990071984714, 1, 0.10000137464827052`], 
           Hue[0.6499966598024274, 1, 0.10000462488894667`], 
           Hue[0.6499925622199799, 1, 0.1000102984646433], 
           Hue[0.6499886739785015, 1, 0.10001568218361344`], 
           Hue[0.6499871792649814, 1, 0.10001775178694884`], 
           Hue[0.649988696060685, 1, 0.10001565160828231`], 
           Hue[0.6499927167322246, 1, 0.10001008452461209`], 
           Hue[0.6499968893754299, 1, 0.10000430701863561`], 
           Hue[0.6499991646891583, 1, 0.10000115658424233`], 
           Hue[0.6499998599977125, 1, 0.1000001938493212], 
           Hue[0.6499999856334239, 1, 0.10000001989218238`], 
           Hue[0.65, 1, 0.1], 
           Hue[0.6499999852880078, 1, 0.10000002037045079`], 
           Hue[0.6499998368066057, 1, 0.10000022596008445`], 
           Hue[0.6499987662030103, 1, 0.10000170833429345`], 
           Hue[0.6499935549624519, 1, 0.10000892389814346`], 
           Hue[0.6499778300417067, 1, 0.10003069686532913`], 
           Hue[0.6499505462683586, 1, 0.10006847439765738`], 
           Hue[0.6499252913219769, 1, 0.10010344278495513`], 
           Hue[0.6499158508823386, 1, 0.10011651416291577`], 
           Hue[0.6499247160158207, 1, 0.10010423936270982`], 
           Hue[0.6499489183734026, 1, 0.10007072840605798`], 
           Hue[0.6499755737898713, 1, 0.1000338209063321], 
           Hue[0.6499918966134397, 1, 0.10001122007369896`], 
           Hue[0.6499980735657545, 1, 0.10000266737049385`], 
           Hue[0.6499996593138839, 1, 0.1000004717192377], 
           Hue[0.6499999506826558, 1, 0.10000006828555356`], 
           Hue[0.6499999500906315, 1, 0.10000006910527945`], 
           Hue[0.649999655185399, 1, 0.10000047743560135`], 
           Hue[0.6499980549290366, 1, 0.10000269317518012`], 
           Hue[0.6499918370195641, 1, 0.10001130258829587`], 
           Hue[0.6499754483540974, 1, 0.10003399458663449`], 
           Hue[0.6499487609293296, 1, 0.10007094640554366`], 
           Hue[0.6499246089762626, 1, 0.1001043875713287], 
           Hue[0.6499158353957267, 1, 0.10011653560591685`], 
           Hue[0.6499253861002506, 1, 0.10010331155349914`], 
           Hue[0.6499507186578939, 1, 0.10006823570445467`], 
           Hue[0.6499779704371008, 1, 0.10003050247170654`], 
           Hue[0.6499936165544795, 1, 0.1000088386168745], 
           Hue[0.6499987823857478, 1, 0.1000016859274261], 
           Hue[0.6499998396191935, 1, 0.1000002220657321], 
           Hue[0.6499999856334239, 1, 0.10000001989218238`], 
           Hue[0.6499998575374961, 1, 0.1000001972557747], 
           Hue[0.6499987662030103, 1, 0.10000170833429345`], 
           Hue[0.6499924447114087, 1, 0.10001046116881876`], 
           Hue[0.649966803005242, 1, 0.10004596506966493`], 
           Hue[0.6498986870713849, 1, 0.10014027943962096`], 
           Hue[0.6497903076682764, 1, 0.10029034322854044`], 
           Hue[0.6496956694759822, 1, 0.10042138072556306`], 
           Hue[0.6496598500920082, 1, 0.10047097679568098`], 
           Hue[0.6496884070778483, 1, 0.10043143635374868`], 
           Hue[0.6497763140913129, 1, 0.10030971895048985`], 
           Hue[0.6498816573421481, 1, 0.100163859064718], 
           Hue[0.6499540431582559, 1, 0.10006363255010721`], 
           Hue[0.6499865511173065, 1, 0.1000186215298833], 
           Hue[0.64999697736963, 1, 0.10000418518051227`], 
           Hue[0.6499994121848602, 1, 0.10000081389788582`], 
           Hue[0.6499994075356613, 1, 0.10000082033523827`], 
           Hue[0.6499969516884851, 1, 0.10000422073902053`], 
           Hue[0.6499864629461425, 1, 0.1000187436130335], 
           Hue[0.6499538247815461, 1, 0.10006393491785928`], 
           Hue[0.6498812811242848, 1, 0.10016437998175962`], 
           Hue[0.6497759033253894, 1, 0.10031028770330704`], 
           Hue[0.6496881578673747, 1, 0.10043178141440438`], 
           Hue[0.6496598197797228, 1, 0.10047101876653777`], 
           Hue[0.6496958940624493, 1, 0.10042106975968566`], 
           Hue[0.6497907590832415, 1, 0.10028971819243498`], 
           Hue[0.6498991064821327, 1, 0.10013969871704716`], 
           Hue[0.6499670218094749, 1, 0.100045662109958], 
           Hue[0.6499925169058931, 1, 0.10001036120722495`], 
           Hue[0.6499987823857478, 1, 0.1000016859274261], 
           Hue[0.6499998599977125, 1, 0.1000001938493212], 
           Hue[0.6499991538514573, 1, 0.1000011715902899], 
           Hue[0.6499935549624519, 1, 0.10000892389814346`], 
           Hue[0.649966803005242, 1, 0.10004596506966493`], 
           Hue[0.649879101783133, 1, 0.10016739753104668`], 
           Hue[0.6496852145273001, 1, 0.10043585680835372`], 
           Hue[0.6494162997265167, 1, 0.10080820037866924`], 
           Hue[0.6492010682900416, 1, 0.1011062131368654], 
           Hue[0.6491137171780911, 1, 0.10122716083033544`], 
           Hue[0.6491563829934823, 1, 0.10116808508594756`], 
           Hue[0.6493416527692054, 1, 0.10091155770417709`], 
           Hue[0.6495997554994432, 1, 0.10055418469307868`], 
           Hue[0.6498113105300759, 1, 0.10026126234297193`], 
           Hue[0.6499305428935218, 1, 0.1000961713782006], 
           Hue[0.6499799856500064, 1, 0.10002771217691427`], 
           Hue[0.6499948089502459, 1, 0.10000718760735187`], 
           Hue[0.6499947831523833, 1, 0.1000072233274692], 
           Hue[0.6499798727551617, 1, 0.1000278684928531], 
           Hue[0.6499302554975778, 1, 0.10009656931104621`], 
           Hue[0.6498107930448382, 1, 0.1002619788609932], 
           Hue[0.6495991042255871, 1, 0.10055508645687941`], 
           Hue[0.6493411176280112, 1, 0.10091229866890762`], 
           Hue[0.6491561566068836, 1, 0.10116839854431495`], 
           Hue[0.6491137403392346, 1, 0.10122712876105974`], 
           Hue[0.6492013214066819, 1, 0.10110586266767127`], 
           Hue[0.649416890241138, 1, 0.10080738274303964`], 
           Hue[0.6496859288220751, 1, 0.10043486778481918`], 
           Hue[0.6498796003047549, 1, 0.10016670727033943`], 
           Hue[0.6499670218094749, 1, 0.10004566210995798`], 
           Hue[0.6499936165544795, 1, 0.1000088386168745], 
           Hue[0.6499991646891583, 1, 0.10000115658424232`], 
           Hue[0.6499968622093047, 1, 0.10000434463327044`], 
           Hue[0.6499778300417067, 1, 0.10003069686532913`], 
           Hue[0.6498986870713849, 1, 0.10014027943962096`], 
           Hue[0.6496852145273001, 1, 0.10043585680835371`], 
           Hue[0.6493047777680848, 1, 0.10096261539803639`], 
           Hue[0.6488673490985243, 1, 0.10156828586358183`], 
           Hue[0.6485502856265529, 1, 0.10200729682477297`], 
           Hue[0.6483902795375447, 1, 0.10222884371724578`], 
           Hue[0.6483816036130576, 1, 0.10224085653576644`], 
           Hue[0.6485957628883882, 1, 0.10194432830838562`], 
           Hue[0.6489939519074331, 1, 0.10139298966663111`], 
           Hue[0.6494149503656054, 1, 0.1008100687245465], 
           Hue[0.6497275525921767, 1, 0.10037723487237067`], 
           Hue[0.6498986949687521, 1, 0.10014026850480488`], 
           Hue[0.6499645086924556, 1, 0.10004914181044619`], 
           Hue[0.6499644084648013, 1, 0.10004928058719827`], 
           Hue[0.6498983451179355, 1, 0.10014075291362773`], 
           Hue[0.6497269063824568, 1, 0.10037812962429069`], 
           Hue[0.6494141593805527, 1, 0.10081116393461945`], 
           Hue[0.6489933573089761, 1, 0.10139381295680236`], 
           Hue[0.6485955693237665, 1, 0.10194459632093877`], 
           Hue[0.6483817334719172, 1, 0.10224067673119161`], 
           Hue[0.6483905107237508, 1, 0.10222852361326827`], 
           Hue[0.6485504399625566, 1, 0.10200708312876784`], 
           Hue[0.6488676434233365, 1, 0.10156787833691877`], 
           Hue[0.6493054326597033, 1, 0.10096170862502624`], 
           Hue[0.6496859288220751, 1, 0.1004348677848191], 
           Hue[0.6498991064821327, 1, 0.10013969871704712`], 
           Hue[0.6499779704371008, 1, 0.10003050247170653`], 
           Hue[0.6499968893754299, 1, 0.10000430701863561`], 
           Hue[0.6499926810152515, 1, 0.10001013397888259`], 
           Hue[0.6499505462683586, 1, 0.10006847439765738`], 
           Hue[0.6497903076682764, 1, 0.10029034322854043`], 
           Hue[0.6494162997265167, 1, 0.1008082003786692], 
           Hue[0.6488673490985243, 1, 0.10156828586358178`], 
           Hue[0.6483447647008006, 1, 0.10229186426042995`], 
           Hue[0.6479786482228467, 1, 0.10279879476836613`], 
           Hue[0.6477162367776388, 1, 0.10316213369250021`], 
           Hue[0.647562318571634, 1, 0.10337525120850674`], 
           Hue[0.6476410815525707, 1, 0.10326619477336373`], 
           Hue[0.6480080185451157, 1, 0.10275812816830143`], 
           Hue[0.648579486372906, 1, 0.10196686502213027`], 
           Hue[0.6491668432411315, 1, 0.10115360166612573`], 
           Hue[0.6495970754140722, 1, 0.10055789558051553`], 
           Hue[0.6498068783412693, 1, 0.10026739921978108`], 
           Hue[0.6498066105961633, 1, 0.10026776994377398`], 
           Hue[0.6495963220340493, 1, 0.10055893872208573`], 
           Hue[0.64916586418334, 1, 0.10115495728460613`], 
           Hue[0.648578777570923, 1, 0.10196784644026052`], 
           Hue[0.6480079461523003, 1, 0.10275822840450731`], 
           Hue[0.6476414975569021, 1, 0.10326561876736627`], 
           Hue[0.6475628209177057, 1, 0.10337455565240761`], 
           Hue[0.6477166871005474, 1, 0.10316151016847287`], 
           Hue[0.6479788895815403, 1, 0.10279846057940578`], 
           Hue[0.6483448000569576, 1, 0.10229181530575106`], 
           Hue[0.6488676434233366, 1, 0.10156787833691866`], 
           Hue[0.6494168902411381, 1, 0.10080738274303949`], 
           Hue[0.6497907590832415, 1, 0.1002897181924349], 
           Hue[0.6499507186578939, 1, 0.10006823570445465`], 
           Hue[0.6499927167322246, 1, 0.10001008452461209`], 
           Hue[0.6499886753209286, 1, 0.1000156803248681], 
           Hue[0.6499252913219769, 1, 0.10010344278495513`], 
           Hue[0.6496956694759822, 1, 0.10042138072556304`], 
           Hue[0.6492010682900418, 1, 0.10110621313686535`], 
           Hue[0.6485502856265529, 1, 0.10200729682477291`], 
           Hue[0.6479786482228467, 1, 0.10279879476836615`], 
           Hue[0.6475401197544662, 1, 0.10340598803227762`], 
           Hue[0.6471492185716042, 1, 0.10394723582393262`], 
           Hue[0.6468120214679307, 1, 0.10441412412132671`], 
           Hue[0.6466225588476567, 1, 0.1046764569801677], 
           Hue[0.6467189588664768, 1, 0.10454298003103212`], 
           Hue[0.6471926206447458, 1, 0.10388714064573666`], 
           Hue[0.6479416314291787, 1, 0.10285004879036792`], 
           Hue[0.6486847327742014, 1, 0.10182113923572118`], 
           Hue[0.6491330712110971, 1, 0.101200362938481], 
           Hue[0.6491325955422843, 1, 0.10120102155683719`], 
           Hue[0.648683647156053, 1, 0.10182264239931124`], 
           Hue[0.6479407143627663, 1, 0.10285131857463126`], 
           Hue[0.6471924667805575, 1, 0.10388735368845883`], 
           Hue[0.6467195342872655, 1, 0.10454218329455547`], 
           Hue[0.6466234011364024, 1, 0.10467529073421211`], 
           Hue[0.6468126895154238, 1, 0.1044131991324902], 
           Hue[0.6471496978926512, 1, 0.1039465721486368], 
           Hue[0.6475405484301956, 1, 0.10340539448126762`], 
           Hue[0.6479788895815403, 1, 0.10279846057940577`], 
           Hue[0.6485504399625567, 1, 0.10200708312876777`], 
           Hue[0.649201321406682, 1, 0.1011058626676712], 
           Hue[0.6496958940624493, 1, 0.10042106975968564`], 
           Hue[0.6499253861002506, 1, 0.10010331155349914`], 
           Hue[0.649988696060685, 1, 0.10001565160828231`], 
           Hue[0.6499871827318621, 1, 0.10001774698665249`], 
           Hue[0.6499158508823386, 1, 0.10011651416291577`], 
           Hue[0.6496598500920082, 1, 0.10047097679568097`], 
           Hue[0.6491137171780911, 1, 0.10122716083033541`], 
           Hue[0.6483902795375447, 1, 0.10222884371724579`], 
           Hue[0.6477162367776386, 1, 0.10316213369250041`], 
           Hue[0.6471492185716038, 1, 0.10394723582393323`], 
           Hue[0.6466247658365454, 1, 0.10467340114939871`], 
           Hue[0.6460970638205105, 1, 0.10540406547929318`], 
           Hue[0.645589268197284, 1, 0.10610716711145293`], 
           Hue[0.6452371269589686, 1, 0.10659474728758193`], 
           Hue[0.6452105445038666, 1, 0.106631553763877], 
           Hue[0.645564334064698, 1, 0.10614169129503348`], 
           Hue[0.6461188517281143, 1, 0.1053738976072263], 
           Hue[0.6465292695559217, 1, 0.10480562676872378`], 
           Hue[0.6465287438944914, 1, 0.10480635460762724`], 
           Hue[0.646117940680914, 1, 0.10537515905719602`], 
           Hue[0.6455640968389634, 1, 0.10614201976143531`], 
           Hue[0.6452112044766596, 1, 0.1066306399553944], 
           Hue[0.6452381831863726, 1, 0.10659328481886882`], 
           Hue[0.6455902756764894, 1, 0.10610577214024544`], 
           Hue[0.6460978666860379, 1, 0.10540295381933218`], 
           Hue[0.6466253190276136, 1, 0.10467263519253509`], 
           Hue[0.6471496978926508, 1, 0.10394657214863749`], 
           Hue[0.6477166871005472, 1, 0.10316151016847318`], 
           Hue[0.6483905107237506, 1, 0.10222852361326844`], 
           Hue[0.6491137403392345, 1, 0.1012271287610599], 
           Hue[0.6496598197797226, 1, 0.10047101876653787`], 
           Hue[0.6499158353957267, 1, 0.10011653560591688`], 
           Hue[0.6499871792649814, 1, 0.10001775178694884`], 
           Hue[0.6499886974241673, 1, 0.10001564972038382`], 
           Hue[0.6499247160158207, 1, 0.10010423936270982`], 
           Hue[0.6496884070778483, 1, 0.10043143635374868`], 
           Hue[0.6491563829934823, 1, 0.10116808508594757`], 
           Hue[0.6483816036130574, 1, 0.10224085653576663`], 
           Hue[0.6475623185716332, 1, 0.10337525120850805`], 
           Hue[0.6468120214679272, 1, 0.10441412412133169`], 
           Hue[0.6460970638205038, 1, 0.10540406547930246`], 
           Hue[0.6453297342290453, 1, 0.10646652183670652`], 
           Hue[0.6444525596532943, 1, 0.10768107124928494`], 
           Hue[0.6433834721860854, 1, 0.10916134620388175`], 
           Hue[0.6419342693173481, 1, 0.11116793479136415`], 
           Hue[0.6399724772615234, 1, 0.11388426225327539`], 
           Hue[0.6378190830503149, 1, 0.11686588500725631`], 
           Hue[0.6363437737647057, 1, 0.11890862094117663`], 
           Hue[0.6363435021480464, 1, 0.11890899702578202`], 
           Hue[0.6378192495710805, 1, 0.11686565444004243`], 
           Hue[0.6399739959560372, 1, 0.11388215944548692`], 
           Hue[0.6419364029752823, 1, 0.11116498049576298`], 
           Hue[0.6433852867591608, 1, 0.10915883371808509`], 
           Hue[0.6444538432672651, 1, 0.107679293937633], 
           Hue[0.6453306991597083, 1, 0.10646518577886538`], 
           Hue[0.6460978666860311, 1, 0.10540295381934163`], 
           Hue[0.6468126895154199, 1, 0.10441319913249546`], 
           Hue[0.6475628209177045, 1, 0.10337455565240919`], 
           Hue[0.6483817334719169, 1, 0.1022406767311921], 
           Hue[0.6491561566068834, 1, 0.10116839854431524`], 
           Hue[0.6496881578673745, 1, 0.10043178141440455`], 
           Hue[0.6499246089762626, 1, 0.10010438757132877`], 
           Hue[0.6499886739785015, 1, 0.10001568218361344`], 
           Hue[0.6499925949688808, 1, 0.10001025312001116`], 
           Hue[0.6499489183734026, 1, 0.10007072840605798`], 
           Hue[0.6497763140913129, 1, 0.10030971895048985`], 
           Hue[0.6493416527692054, 1, 0.10091155770417717`], 
           Hue[0.6485957628883876, 1, 0.10194432830838648`], 
           Hue[0.6476410815525666, 1, 0.1032661947733693], 
           Hue[0.6466225588476413, 1, 0.10467645698018899`], 
           Hue[0.6455892681972526, 1, 0.10610716711149638`], 
           Hue[0.6444525596532654, 1, 0.10768107124932486`], 
           Hue[0.6428646294941891, 1, 0.10987974377727662`], 
           Hue[0.6397787456596381, 1, 0.11415250600973181`], 
           Hue[0.6332784547823019, 1, 0.12315290876296653`], 
           Hue[0.622205306537433, 1, 0.13848496017893902`], 
           Hue[0.6090491411989667, 1, 0.1567011891091231], 
           Hue[0.5998736460104983, 1, 0.1694057209085409], 
           Hue[0.5998738052387638, 1, 0.16940550043863484`], 
           Hue[0.6090518863173507, 1, 0.15669738817597592`], 
           Hue[0.6222118250047584, 1, 0.1384759346087962], 
           Hue[0.6332852682945339, 1, 0.12314347466910694`], 
           Hue[0.639783111261144, 1, 0.1141464613307238], 
           Hue[0.6428668818449628, 1, 0.10987662513774389`], 
           Hue[0.6444538432672381, 1, 0.10767929393767041`], 
           Hue[0.6455902756764588, 1, 0.10610577214028791`], 
           Hue[0.6466234011363869, 1, 0.10467529073423344`], 
           Hue[0.6476414975568979, 1, 0.10326561876737213`], 
           Hue[0.6485955693237656, 1, 0.1019445963209399], 
           Hue[0.6493411176280109, 1, 0.10091229866890794`], 
           Hue[0.6497759033253893, 1, 0.10031028770330719`], 
           Hue[0.6499487609293295, 1, 0.10007094640554372`], 
           Hue[0.6499925622199799, 1, 0.10001029846464331`], 
           Hue[0.6499966840514407, 1, 0.10000459131338975`], 
           Hue[0.6499755737898713, 1, 0.1000338209063321], 
           Hue[0.6498816573421481, 1, 0.10016385906471802`], 
           Hue[0.649599755499443, 1, 0.1005541846930789], 
           Hue[0.6489939519074316, 1, 0.10139298966663324`], 
           Hue[0.6480080185451057, 1, 0.10275812816831516`], 
           Hue[0.6467189588664403, 1, 0.10454298003108281`], 
           Hue[0.6452371269588972, 1, 0.10659474728768085`], 
           Hue[0.6433834721860215, 1, 0.10916134620397015`], 
           Hue[0.6397787456596258, 1, 0.11415250600974894`], 
           Hue[0.6301844468266199, 1, 0.1274369197785264], 
           Hue[0.6080792206635541, 1, 0.15804415600430965`], 
           Hue[0.5717905289829107, 1, 0.20829003679289282`], 
           Hue[0.5317029461800612, 1, 0.26379592067376145`], 
           Hue[0.5054104508359922, 1, 0.3002009142270876], 
           Hue[0.5054110463243464, 1, 0.3002000897047511], 
           Hue[0.5317100440196496, 1, 0.2637860928958698], 
           Hue[0.5718071228013197, 1, 0.20826706073663426`], 
           Hue[0.6080965938095235, 1, 0.15802010087912133`], 
           Hue[0.6301948999416345, 1, 0.12742244623466004`], 
           Hue[0.6397831112611579, 1, 0.11414646133070443`], 
           Hue[0.6433852867591167, 1, 0.10915883371814625`], 
           Hue[0.6452381831863105, 1, 0.1065932848189547], 
           Hue[0.6467195342872314, 1, 0.10454218329460267`], 
           Hue[0.6480079461522906, 1, 0.10275822840452063`], 
           Hue[0.6489933573089745, 1, 0.10139381295680457`], 
           Hue[0.6495991042255869, 1, 0.10055508645687973`], 
           Hue[0.6498812811242847, 1, 0.1001643799817597], 
           Hue[0.6499754483540974, 1, 0.1000339945866345], 
           Hue[0.6499966598024274, 1, 0.10000462488894668`], 
           Hue[0.6499990174111819, 1, 0.10000136050759434`], 
           Hue[0.6499918966134397, 1, 0.10001122007369898`], 
           Hue[0.6499540431582559, 1, 0.10006363255010724`], 
           Hue[0.6498113105300757, 1, 0.10026126234297222`], 
           Hue[0.6494149503656031, 1, 0.10081006872454952`], 
           Hue[0.6485794863728921, 1, 0.10196686502214951`], 
           Hue[0.6471926206446967, 1, 0.10388714064580462`], 
           Hue[0.6452105445037793, 1, 0.10663155376399788`], 
           Hue[0.6419342693172904, 1, 0.11116793479144421`], 
           Hue[0.6332784547823264, 1, 0.12315290876293279`], 
           Hue[0.6080792206635947, 1, 0.15804415600425353`], 
           Hue[0.5535172220443463, 1, 0.23359153870782828`], 
           Hue[0.47393025290694657`, 1, 0.3437888805903817], 
           Hue[0.3965448698524707, 1, 0.4509378725119636], 
           Hue[0.3505683074570688, 1, 0.5145977281363663], 
           Hue[0.35057138237062935`, 1, 0.514593470563744], 
           Hue[0.3965589856306645, 1, 0.45091832758831074`], 
           Hue[0.47395746658768534`, 1, 0.34375120010935883`], 
           Hue[0.553545544713231, 1, 0.23355232270475706`], 
           Hue[0.6080965938097692, 1, 0.15802010087878113`], 
           Hue[0.6332852682947127, 1, 0.12314347466885944`], 
           Hue[0.6419364029753274, 1, 0.11116498049570052`], 
           Hue[0.6452112044766228, 1, 0.10663063995544537`], 
           Hue[0.6471924667805229, 1, 0.10388735368850681`], 
           Hue[0.6485787775709114, 1, 0.10196784644027657`], 
           Hue[0.6494141593805507, 1, 0.1008111639346222], 
           Hue[0.649810793044838, 1, 0.1002619788609935], 
           Hue[0.6499538247815461, 1, 0.10006393491785932`], 
           Hue[0.6499918370195641, 1, 0.10001130258829588`], 
           Hue[0.6499990071984714, 1, 0.10000137464827052`], 
           Hue[0.6499998034253445, 1, 0.10000027218029237`], 
           Hue[0.6499980735657545, 1, 0.10000266737049385`], 
           Hue[0.6499865511173065, 1, 0.10001862152988332`], 
           Hue[0.6499305428935217, 1, 0.10009617137820083`], 
           Hue[0.649727552592175, 1, 0.10037723487237314`], 
           Hue[0.6491668432411204, 1, 0.10115360166614108`], 
           Hue[0.647941631429142, 1, 0.10285004879041884`], 
           Hue[0.6455643340646423, 1, 0.1061416912951107], 
           Hue[0.639972477261512, 1, 0.1138842622532912], 
           Hue[0.6222053065374926, 1, 0.13848496017885642`], 
           Hue[0.5717905289829407, 1, 0.20829003679285135`], 
           Hue[0.47393025290686036`, 1, 0.34378888059050106`], 
           Hue[0.350516590379209, 1, 0.5146693363980183], 
           Hue[0.24717815546080268`, 1, 0.6577533232081193], 
           Hue[0.192019443012804, 1, 0.7341269250591944], 
           Hue[0.19203201182186103`, 1, 0.7341095220928078], 
           Hue[0.2472070239801022, 1, 0.6577133514121661], 
           Hue[0.35054863766858774`, 1, 0.5146249632281092], 
           Hue[0.47395746658837945`, 1, 0.3437512001083977], 
           Hue[0.571807122802092, 1, 0.2082670607355649], 
           Hue[0.6222118250052738, 1, 0.13847593460808238`], 
           Hue[0.6399739959563222, 1, 0.11388215944509239`], 
           Hue[0.6455640968390548, 1, 0.10614201976130883`], 
           Hue[0.647940714362772, 1, 0.10285131857462335`], 
           Hue[0.6491658641833358, 1, 0.10115495728461198`], 
           Hue[0.6497269063824556, 1, 0.10037812962429228`], 
           Hue[0.6499302554975777, 1, 0.10009656931104641`], 
           Hue[0.6499864629461425, 1, 0.10001874361303353`], 
           Hue[0.6499980549290366, 1, 0.10000269317518012`], 
           Hue[0.6499998007707878, 1, 0.10000027585583228`], 
           Hue[0.6499999729662879, 1, 0.10000003743129375`], 
           Hue[0.6499996593138839, 1, 0.1000004717192377], 
           Hue[0.64999697736963, 1, 0.10000418518051228`], 
           Hue[0.6499799856500063, 1, 0.10002771217691438`], 
           Hue[0.6498986949687512, 1, 0.10014026850480605`], 
           Hue[0.6495970754140672, 1, 0.10055789558052244`], 
           Hue[0.6486847327741864, 1, 0.10182113923574201`], 
           Hue[0.646118851728098, 1, 0.1053738976072489], 
           Hue[0.6378190830503302, 1, 0.11686588500723522`], 
           Hue[0.609049141199, 1, 0.1567011891090769], 
           Hue[0.5317029461799629, 1, 0.26379592067389745`], 
           Hue[0.3965448698520418, 1, 0.45093787251255757`], 
           Hue[0.24717815546023186`, 1, 0.6577533232089097], 
           Hue[0.13586707405626453`, 1, 0.8118763589990183], 
           Hue[0.07851354847794556, 1, 0.8912889328766908], 
           Hue[0.07853633966851448, 1, 0.8912573758435953], 
           Hue[0.13590944914320868`, 1, 0.8118176858017111], 
           Hue[0.24720702397992556`, 1, 0.6577133514124108], 
           Hue[0.3965589856317552, 1, 0.4509183275868006], 
           Hue[0.5317100440208999, 1, 0.2637860928941386], 
           Hue[0.6090518863181518, 1, 0.15669738817486675`], 
           Hue[0.6378192495715569, 1, 0.11686565443938277`], 
           Hue[0.6461179406811218, 1, 0.10537515905690827`], 
           Hue[0.6486836471561027, 1, 0.10182264239924246`], 
           Hue[0.6495963220340547, 1, 0.10055893872207818`], 
           Hue[0.6498983451179356, 1, 0.10014075291362756`], 
           Hue[0.6499798727551617, 1, 0.10002786849285314`], 
           Hue[0.6499969516884851, 1, 0.10000422073902054`], 
           Hue[0.649999655185399, 1, 0.10000047743560135`], 
           Hue[0.649999972502692, 1, 0.10000003807319564`], 
           Hue[0.6499999980637757, 1, 0.10000000268092593`], 
           Hue[0.6499999506826558, 1, 0.10000006828555356`], 
           Hue[0.6499994121848602, 1, 0.10000081389788582`], 
           Hue[0.6499948089502459, 1, 0.1000071876073519], 
           Hue[0.6499645086924554, 1, 0.1000491418104465], 
           Hue[0.649806878341268, 1, 0.1002673992197828], 
           Hue[0.649133071211094, 1, 0.10120036293848536`], 
           Hue[0.6465292695559209, 1, 0.10480562676872485`], 
           Hue[0.6363437737647146, 1, 0.11890862094116436`], 
           Hue[0.5998736460104778, 1, 0.16940572090856923`], 
           Hue[0.5054104508357453, 1, 0.3002009142274296], 
           Hue[0.35056830745625983`, 1, 0.5145977281374865], 
           Hue[0.1920194430115696, 1, 0.7341269250609037], 
           Hue[0.07851354847718961, 1, 0.8912889328777374], 
           Hue[0.016906005021812276`, 1, 0.9765916853544138], 
           Hue[0.016918907565830477`, 1, 0.9765738202934655], 
           Hue[0.07853633966586049, 1, 0.8912573758472702], 
           Hue[0.1920320118201158, 1, 0.7341095220952243], 
           Hue[0.35057138237145397`, 1, 0.5145934705626022], 
           Hue[0.5054110463257803, 1, 0.30020008970276585`], 
           Hue[0.5998738052395493, 1, 0.16940550043754726`], 
           Hue[0.6363435021483804, 1, 0.11890899702531947`], 
           Hue[0.6465287438946181, 1, 0.10480635460745186`], 
           Hue[0.649132595542316, 1, 0.10120102155679332`], 
           Hue[0.6498066105961676, 1, 0.10026776994376801`], 
           Hue[0.6499644084648015, 1, 0.10004928058719788`], 
           Hue[0.6499947831523833, 1, 0.10000722332746918`], 
           Hue[0.6499994075356613, 1, 0.10000082033523827`], 
           Hue[0.6499999500906315, 1, 0.10000006910527945`], 
           Hue[0.6499999980108732, 1, 0.10000000275417563`], 
           Hue[0.6499999980108732, 1, 0.10000000275417563`], 
           Hue[0.6499999500906315, 1, 0.10000006910527945`], 
           Hue[0.6499994075356613, 1, 0.10000082033523827`], 
           Hue[0.6499947831523833, 1, 0.1000072233274692], 
           Hue[0.6499644084648013, 1, 0.10004928058719831`], 
           Hue[0.6498066105961631, 1, 0.10026776994377418`], 
           Hue[0.6491325955422841, 1, 0.10120102155683748`], 
           Hue[0.6465287438944921, 1, 0.1048063546076263], 
           Hue[0.6363435021480459, 1, 0.11890899702578257`], 
           Hue[0.5998738052387229, 1, 0.16940550043869146`], 
           Hue[0.5054110463240795, 1, 0.3002000897051206], 
           Hue[0.3505713823697989, 1, 0.5145934705648939], 
           Hue[0.19203201182058266`, 1, 0.7341095220945779], 
           Hue[0.07853633966768225, 1, 0.8912573758447476], 
           Hue[0.016918907565741215`, 1, 0.9765738202935891], 
           Hue[0.016906005018723635`, 1, 0.9765916853586903], 
           Hue[0.07851354847341785, 1, 0.89128893288296], 
           Hue[0.19201944301049073`, 1, 0.7341269250623975], 
           Hue[0.35056830745800077`, 1, 0.5145977281350759], 
           Hue[0.5054104508375454, 1, 0.3002009142249371], 
           Hue[0.5998736460110626, 1, 0.1694057209077594], 
           Hue[0.6363437737646683, 1, 0.11890862094122849`], 
           Hue[0.6465292695558271, 1, 0.1048056267688548], 
           Hue[0.6491330712110641, 1, 0.10120036293852665`], 
           Hue[0.6498068783412636, 1, 0.10026739921978885`], 
           Hue[0.649964508692455, 1, 0.10004914181044693`], 
           Hue[0.6499948089502459, 1, 0.10000718760735192`], 
           Hue[0.6499994121848602, 1, 0.10000081389788582`], 
           Hue[0.6499999506826558, 1, 0.10000006828555356`], 
           Hue[0.6499999980637757, 1, 0.10000000268092593`], 
           Hue[0.649999972502692, 1, 0.10000003807319564`], 
           Hue[0.649999655185399, 1, 0.10000047743560135`], 
           Hue[0.6499969516884851, 1, 0.10000422073902053`], 
           Hue[0.6499798727551617, 1, 0.10002786849285311`], 
           Hue[0.6498983451179355, 1, 0.10014075291362773`], 
           Hue[0.6495963220340493, 1, 0.1005589387220857], 
           Hue[0.6486836471560531, 1, 0.10182264239931109`], 
           Hue[0.6461179406809142, 1, 0.10537515905719567`], 
           Hue[0.6378192495710786, 1, 0.11686565444004504`], 
           Hue[0.6090518863173231, 1, 0.1566973881760142], 
           Hue[0.5317100440194852, 1, 0.2637860928960975], 
           Hue[0.3965589856301587, 1, 0.45091832758901107`], 
           Hue[0.24720702397933064`, 1, 0.6577133514132345], 
           Hue[0.13590944914274938`, 1, 0.811817685802347], 
           Hue[0.07853633966592277, 1, 0.8912573758471839], 
           Hue[0.07851354847355607, 1, 0.8912889328827686], 
           Hue[0.13586707405281984`, 1, 0.8118763590037879], 
           Hue[0.24717815545988908`, 1, 0.6577533232093843], 
           Hue[0.3965448698539299, 1, 0.4509378725099432], 
           Hue[0.5317029461815325, 1, 0.26379592067172436`], 
           Hue[0.6090491411993084, 1, 0.15670118910864986`], 
           Hue[0.6378190830500777, 1, 0.11686588500758477`], 
           Hue[0.6461188517279151, 1, 0.10537389760750222`], 
           Hue[0.6486847327741383, 1, 0.10182113923580859`], 
           Hue[0.6495970754140618, 1, 0.10055789558052991`], 
           Hue[0.6498986949687511, 1, 0.10014026850480622`], 
           Hue[0.6499799856500064, 1, 0.10002771217691435`], 
           Hue[0.64999697736963, 1, 0.10000418518051228`], 
           Hue[0.6499996593138839, 1, 0.1000004717192377], 
           Hue[0.6499999729662879, 1, 0.10000003743129375`], 
           Hue[0.6499998007707878, 1, 0.10000027585583228`], 
           Hue[0.6499980549290366, 1, 0.10000269317518012`], 
           Hue[0.6499864629461425, 1, 0.10001874361303352`], 
           Hue[0.6499302554975778, 1, 0.10009656931104624`], 
           Hue[0.6497269063824568, 1, 0.10037812962429073`], 
           Hue[0.64916586418334, 1, 0.10115495728460613`], 
           Hue[0.6479407143627665, 1, 0.10285131857463113`], 
           Hue[0.6455640968389635, 1, 0.10614201976143513`], 
           Hue[0.6399739959560363, 1, 0.11388215944548823`], 
           Hue[0.6222118250047468, 1, 0.13847593460881222`], 
           Hue[0.5718071228012546, 1, 0.20826706073672444`], 
           Hue[0.47395746658748916`, 1, 0.34375120010963045`], 
           Hue[0.35054863766829164`, 1, 0.5146249632285194], 
           Hue[0.24720702397975558`, 1, 0.6577133514126461], 
           Hue[0.19203201182016771`, 1, 0.7341095220951525], 
           Hue[0.19201944301058688`, 1, 0.7341269250622643], 
           Hue[0.2471781554599206, 1, 0.6577533232093407], 
           Hue[0.3505165903801044, 1, 0.5146693363967786], 
           Hue[0.47393025290842367`, 1, 0.34378888058833645`], 
           Hue[0.5717905289838813, 1, 0.20829003679154906`], 
           Hue[0.6222053065376022, 1, 0.13848496017870468`], 
           Hue[0.6399724772613484, 1, 0.11388426225351767`], 
           Hue[0.645564334064564, 1, 0.10614169129521904`], 
           Hue[0.6479416314291371, 1, 0.10285004879042564`], 
           Hue[0.6491668432411246, 1, 0.10115360166613523`], 
           Hue[0.6497275525921761, 1, 0.10037723487237159`], 
           Hue[0.6499305428935218, 1, 0.10009617137820066`], 
           Hue[0.6499865511173065, 1, 0.1000186215298833], 
           Hue[0.6499980735657545, 1, 0.10000266737049385`], 
           Hue[0.6499998034253445, 1, 0.10000027218029237`], 
           Hue[0.6499990071984714, 1, 0.10000137464827052`], 
           Hue[0.6499918370195641, 1, 0.10001130258829587`], 
           Hue[0.6499538247815461, 1, 0.1000639349178593], 
           Hue[0.6498107930448382, 1, 0.10026197886099324`], 
           Hue[0.6494141593805526, 1, 0.10081116393461954`], 
           Hue[0.6485787775709229, 1, 0.10196784644026062`], 
           Hue[0.6471924667805575, 1, 0.10388735368845878`], 
           Hue[0.6452112044766597, 1, 0.10663063995539425`], 
           Hue[0.6419364029752817, 1, 0.11116498049576384`], 
           Hue[0.633285268294527, 1, 0.12314347466911642`], 
           Hue[0.6080965938094919, 1, 0.15802010087916515`], 
           Hue[0.5535455447131511, 1, 0.2335523227048677], 
           Hue[0.4739574665882697, 1, 0.34375120010854965`], 
           Hue[0.3965589856316865, 1, 0.45091832758689565`], 
           Hue[0.35057138237145447`, 1, 0.5145934705626015], 
           Hue[0.3505683074580232, 1, 0.5145977281350448], 
           Hue[0.3965448698539395, 1, 0.45093787250993], 
           Hue[0.4739302529084245, 1, 0.34378888058833534`], 
           Hue[0.5535172220453116, 1, 0.2335915387064916], 
           Hue[0.608079220663972, 1, 0.15804415600373106`], 
           Hue[0.633278454782362, 1, 0.12315290876288346`], 
           Hue[0.6419342693172857, 1, 0.11116793479145054`], 
           Hue[0.6452105445038205, 1, 0.10663155376394089`], 
           Hue[0.6471926206447316, 1, 0.10388714064575626`], 
           Hue[0.6485794863729036, 1, 0.10196686502213353`], 
           Hue[0.649414950365605, 1, 0.10081006872454687`], 
           Hue[0.6498113105300758, 1, 0.10026126234297196`], 
           Hue[0.6499540431582559, 1, 0.10006363255010721`], 
           Hue[0.6499918966134397, 1, 0.10001122007369896`], 
           Hue[0.6499990174111819, 1, 0.10000136050759434`], 
           Hue[0.6499966598024274, 1, 0.10000462488894667`], 
           Hue[0.6499754483540974, 1, 0.10003399458663449`], 
           Hue[0.6498812811242848, 1, 0.10016437998175964`], 
           Hue[0.6495991042255871, 1, 0.10055508645687948`], 
           Hue[0.648993357308976, 1, 0.10139381295680251`], 
           Hue[0.6480079461523002, 1, 0.10275822840450749`], 
           Hue[0.6467195342872655, 1, 0.1045421832945555], 
           Hue[0.6452381831863728, 1, 0.1065932848188684], 
           Hue[0.6433852867591614, 1, 0.10915883371808421`], 
           Hue[0.6397831112611403, 1, 0.11414646133072888`], 
           Hue[0.6301948999416069, 1, 0.12742244623469806`], 
           Hue[0.6080965938096965, 1, 0.15802010087888185`], 
           Hue[0.5718071228019954, 1, 0.20826706073569862`], 
           Hue[0.5317100440208316, 1, 0.2637860928942333], 
           Hue[0.5054110463257548, 1, 0.300200089702801], 
           Hue[0.5054104508375404, 1, 0.30020091422494405`], 
           Hue[0.5317029461815312, 1, 0.2637959206717261], 
           Hue[0.5717905289838803, 1, 0.2082900367915504], 
           Hue[0.6080792206639716, 1, 0.1580441560037317], 
           Hue[0.6301844468267296, 1, 0.1274369197783744], 
           Hue[0.6397787456596526, 1, 0.1141525060097118], 
           Hue[0.6433834721860744, 1, 0.10916134620389706`], 
           Hue[0.6452371269589603, 1, 0.10659474728759341`], 
           Hue[0.6467189588664743, 1, 0.1045429800310355], 
           Hue[0.6480080185451152, 1, 0.10275812816830196`], 
           Hue[0.648993951907433, 1, 0.10139298966663116`], 
           Hue[0.6495997554994433, 1, 0.10055418469307864`], 
           Hue[0.6498816573421482, 1, 0.10016385906471795`], 
           Hue[0.6499755737898713, 1, 0.10003382090633207`], 
           Hue[0.6499966840514407, 1, 0.10000459131338975`], 
           Hue[0.6499925622199799, 1, 0.1000102984646433], 
           Hue[0.6499487609293296, 1, 0.10007094640554366`], 
           Hue[0.6497759033253894, 1, 0.10031028770330705`], 
           Hue[0.6493411176280112, 1, 0.10091229866890768`], 
           Hue[0.6485955693237664, 1, 0.10194459632093891`], 
           Hue[0.647641497556902, 1, 0.10326561876736648`], 
           Hue[0.6466234011364024, 1, 0.1046752907342122], 
           Hue[0.6455902756764903, 1, 0.10610577214024428`], 
           Hue[0.6444538432672702, 1, 0.10767929393762596`], 
           Hue[0.6428668818449762, 1, 0.10987662513772525`], 
           Hue[0.6397831112611666, 1, 0.11414646133069248`], 
           Hue[0.633285268294681, 1, 0.1231434746689032], 
           Hue[0.6222118250052016, 1, 0.13847593460818255`], 
           Hue[0.6090518863180883, 1, 0.1566973881749547], 
           Hue[0.5998738052395204, 1, 0.16940550043758723`], 
           Hue[0.5998736460110543, 1, 0.16940572090777092`], 
           Hue[0.6090491411993062, 1, 0.15670118910865305`], 
           Hue[0.6222053065376013, 1, 0.13848496017870593`], 
           Hue[0.6332784547823616, 1, 0.12315290876288401`], 
           Hue[0.6397787456596524, 1, 0.11415250600971207`], 
           Hue[0.6428646294942048, 1, 0.109879743777255], 
           Hue[0.6444525596532982, 1, 0.10768107124927954`], 
           Hue[0.6455892681972842, 1, 0.10610716711145265`], 
           Hue[0.6466225588476566, 1, 0.10467645698016773`], 
           Hue[0.6476410815525707, 1, 0.10326619477336363`], 
           Hue[0.6485957628883883, 1, 0.10194432830838548`], 
           Hue[0.6493416527692056, 1, 0.1009115577041769], 
           Hue[0.649776314091313, 1, 0.1003097189504897], 
           Hue[0.6499489183734026, 1, 0.10007072840605792`], 
           Hue[0.6499925949688808, 1, 0.10001025312001115`], 
           Hue[0.6499886739785015, 1, 0.10001568218361342`], 
           Hue[0.6499246089762626, 1, 0.1001043875713287], 
           Hue[0.6496881578673747, 1, 0.10043178141440437`], 
           Hue[0.6491561566068836, 1, 0.10116839854431495`], 
           Hue[0.6483817334719172, 1, 0.10224067673119168`], 
           Hue[0.6475628209177056, 1, 0.10337455565240777`], 
           Hue[0.6468126895154237, 1, 0.10441319913249028`], 
           Hue[0.6460978666860392, 1, 0.10540295381933039`], 
           Hue[0.6453306991597177, 1, 0.10646518577885243`], 
           Hue[0.644453843267272, 1, 0.10767929393762347`], 
           Hue[0.643385286759181, 1, 0.10915883371805703`], 
           Hue[0.6419364029753845, 1, 0.11116498049562153`], 
           Hue[0.6399739959563322, 1, 0.11388215944507858`], 
           Hue[0.6378192495715385, 1, 0.1168656544394084], 
           Hue[0.6363435021483664, 1, 0.11890899702533884`], 
           Hue[0.6363437737646637, 1, 0.11890862094123503`], 
           Hue[0.6378190830500764, 1, 0.1168658850075865], 
           Hue[0.6399724772613479, 1, 0.11388426225351829`], 
           Hue[0.6419342693172855, 1, 0.11116793479145093`], 
           Hue[0.6433834721860742, 1, 0.10916134620389735`], 
           Hue[0.6444525596532981, 1, 0.10768107124927964`], 
           Hue[0.6453297342290546, 1, 0.1064665218366937], 
           Hue[0.6460970638205118, 1, 0.10540406547929135`], 
           Hue[0.6468120214679307, 1, 0.10441412412132668`], 
           Hue[0.647562318571634, 1, 0.10337525120850674`], 
           Hue[0.6483816036130577, 1, 0.10224085653576623`], 
           Hue[0.6491563829934826, 1, 0.10116808508594727`], 
           Hue[0.6496884070778484, 1, 0.10043143635374849`], 
           Hue[0.6499247160158208, 1, 0.10010423936270975`], 
           Hue[0.6499886974241673, 1, 0.10001564972038382`], 
           Hue[0.6499871792649814, 1, 0.10001775178694883`], 
           Hue[0.6499158353957267, 1, 0.10011653560591685`], 
           Hue[0.6496598197797228, 1, 0.10047101876653775`], 
           Hue[0.6491137403392347, 1, 0.10122712876105969`], 
           Hue[0.6483905107237508, 1, 0.10222852361326822`], 
           Hue[0.6477166871005474, 1, 0.10316151016847291`], 
           Hue[0.6471496978926512, 1, 0.10394657214863678`], 
           Hue[0.6466253190276147, 1, 0.10467263519253359`], 
           Hue[0.6460978666860392, 1, 0.10540295381933043`], 
           Hue[0.645590275676491, 1, 0.10610577214024328`], 
           Hue[0.6452381831863822, 1, 0.10659328481885547`], 
           Hue[0.6452112044767101, 1, 0.10663063995532446`], 
           Hue[0.6455640968391104, 1, 0.10614201976123169`], 
           Hue[0.6461179406811379, 1, 0.10537515905688595`], 
           Hue[0.6465287438946186, 1, 0.1048063546074513], 
           Hue[0.6465292695558261, 1, 0.10480562676885623`], 
           Hue[0.6461188517279146, 1, 0.10537389760750286`], 
           Hue[0.6455643340645638, 1, 0.10614169129521937`], 
           Hue[0.6452105445038203, 1, 0.10663155376394112`], 
           Hue[0.6452371269589602, 1, 0.10659474728759356`], 
           Hue[0.6455892681972842, 1, 0.10610716711145261`], 
           Hue[0.6460970638205119, 1, 0.10540406547929121`], 
           Hue[0.6466247658365464, 1, 0.10467340114939741`], 
           Hue[0.647149218571604, 1, 0.10394723582393292`], 
           Hue[0.6477162367776387, 1, 0.1031621336925004], 
           Hue[0.6483902795375448, 1, 0.10222884371724564`], 
           Hue[0.6491137171780913, 1, 0.10122716083033519`], 
           Hue[0.6496598500920083, 1, 0.10047097679568083`], 
           Hue[0.6499158508823387, 1, 0.10011651416291573`], 
           Hue[0.6499871827318622, 1, 0.10001774698665247`], 
           Hue[0.649988696060685, 1, 0.10001565160828231`], 
           Hue[0.6499253861002506, 1, 0.10010331155349914`], 
           Hue[0.6496958940624493, 1, 0.10042106975968562`], 
           Hue[0.649201321406682, 1, 0.10110586266767116`], 
           Hue[0.6485504399625567, 1, 0.1020070831287677], 
           Hue[0.6479788895815404, 1, 0.10279846057940567`], 
           Hue[0.6475405484301957, 1, 0.1034053944812675], 
           Hue[0.6471496978926513, 1, 0.10394657214863673`], 
           Hue[0.6468126895154237, 1, 0.10441319913249034`], 
           Hue[0.6466234011364024, 1, 0.1046752907342121], 
           Hue[0.646719534287268, 1, 0.10454218329455199`], 
           Hue[0.647192466780572, 1, 0.10388735368843882`], 
           Hue[0.6479407143628089, 1, 0.10285131857457236`], 
           Hue[0.6486836471561178, 1, 0.10182264239922159`], 
           Hue[0.6491325955423191, 1, 0.10120102155678898`], 
           Hue[0.6491330712110643, 1, 0.10120036293852638`], 
           Hue[0.6486847327741382, 1, 0.10182113923580877`], 
           Hue[0.647941631429137, 1, 0.10285004879042578`], 
           Hue[0.6471926206447316, 1, 0.1038871406457563], 
           Hue[0.6467189588664745, 1, 0.10454298003103545`], 
           Hue[0.6466225588476568, 1, 0.10467645698016752`], 
           Hue[0.6468120214679309, 1, 0.10441412412132642`], 
           Hue[0.6471492185716041, 1, 0.10394723582393277`], 
           Hue[0.6475401197544659, 1, 0.10340598803227799`], 
           Hue[0.6479786482228466, 1, 0.10279879476836637`], 
           Hue[0.6485502856265529, 1, 0.10200729682477296`], 
           Hue[0.6492010682900418, 1, 0.10110621313686532`], 
           Hue[0.6496956694759822, 1, 0.10042138072556303`], 
           Hue[0.6499252913219769, 1, 0.10010344278495513`], 
           Hue[0.6499886753209286, 1, 0.1000156803248681], 
           Hue[0.6499927167322246, 1, 0.10001008452461209`], 
           Hue[0.6499507186578939, 1, 0.10006823570445467`], 
           Hue[0.6497907590832415, 1, 0.10028971819243494`], 
           Hue[0.6494168902411381, 1, 0.10080738274303955`], 
           Hue[0.6488676434233366, 1, 0.10156787833691865`], 
           Hue[0.6483448000569576, 1, 0.10229181530575097`], 
           Hue[0.6479788895815404, 1, 0.10279846057940568`], 
           Hue[0.6477166871005474, 1, 0.10316151016847291`], 
           Hue[0.6475628209177055, 1, 0.10337455565240786`], 
           Hue[0.6476414975569019, 1, 0.10326561876736656`], 
           Hue[0.6480079461523006, 1, 0.10275822840450693`], 
           Hue[0.6485787775709253, 1, 0.10196784644025733`], 
           Hue[0.6491658641833469, 1, 0.1011549572845966], 
           Hue[0.6495963220340597, 1, 0.10055893872207124`], 
           Hue[0.6498066105961688, 1, 0.10026776994376628`], 
           Hue[0.6498068783412638, 1, 0.10026739921978865`], 
           Hue[0.6495970754140618, 1, 0.10055789558052994`], 
           Hue[0.6491668432411246, 1, 0.10115360166613523`], 
           Hue[0.6485794863729036, 1, 0.10196686502213344`], 
           Hue[0.6480080185451154, 1, 0.1027581281683018], 
           Hue[0.6476410815525709, 1, 0.1032661947733634], 
           Hue[0.6475623185716342, 1, 0.10337525120850653`], 
           Hue[0.6477162367776387, 1, 0.1031621336925003], 
           Hue[0.6479786482228466, 1, 0.1027987947683664], 
           Hue[0.6483447647008004, 1, 0.10229186426043022`], 
           Hue[0.6488673490985242, 1, 0.10156828586358195`], 
           Hue[0.6494162997265166, 1, 0.10080820037866929`], 
           Hue[0.6497903076682764, 1, 0.10029034322854048`], 
           Hue[0.6499505462683586, 1, 0.1000684743976574], 
           Hue[0.6499926810152515, 1, 0.10001013397888259`], 
           Hue[0.6499968893754299, 1, 0.10000430701863561`], 
           Hue[0.6499779704371008, 1, 0.10003050247170653`], 
           Hue[0.6498991064821327, 1, 0.10013969871704714`], 
           Hue[0.6496859288220751, 1, 0.10043486778481912`], 
           Hue[0.6493054326597033, 1, 0.1009617086250262], 
           Hue[0.6488676434233366, 1, 0.10156787833691865`], 
           Hue[0.6485504399625566, 1, 0.10200708312876779`], 
           Hue[0.6483905107237506, 1, 0.1022285236132684], 
           Hue[0.648381733471917, 1, 0.10224067673119189`], 
           Hue[0.6485955693237663, 1, 0.10194459632093905`], 
           Hue[0.648993357308976, 1, 0.10139381295680246`], 
           Hue[0.6494141593805528, 1, 0.10081116393461917`], 
           Hue[0.6497269063824574, 1, 0.1003781296242898], 
           Hue[0.6498983451179365, 1, 0.1001407529136264], 
           Hue[0.6499644084648017, 1, 0.10004928058719757`], 
           Hue[0.649964508692455, 1, 0.10004914181044688`], 
           Hue[0.6498986949687511, 1, 0.1001402685048062], 
           Hue[0.6497275525921762, 1, 0.10037723487237155`], 
           Hue[0.6494149503656051, 1, 0.10081006872454676`], 
           Hue[0.6489939519074331, 1, 0.101392989666631], 
           Hue[0.6485957628883884, 1, 0.10194432830838535`], 
           Hue[0.6483816036130579, 1, 0.10224085653576616`], 
           Hue[0.6483902795375448, 1, 0.10222884371724568`], 
           Hue[0.6485502856265528, 1, 0.10200729682477307`], 
           Hue[0.6488673490985241, 1, 0.10156828586358203`], 
           Hue[0.6493047777680847, 1, 0.10096261539803657`], 
           Hue[0.6496852145273001, 1, 0.1004358568083538], 
           Hue[0.6498986870713849, 1, 0.100140279439621], 
           Hue[0.6499778300417067, 1, 0.10003069686532914`], 
           Hue[0.6499968622093047, 1, 0.10000434463327044`], 
           Hue[0.6499991646891583, 1, 0.10000115658424233`], 
           Hue[0.6499936165544795, 1, 0.1000088386168745], 
           Hue[0.6499670218094749, 1, 0.100045662109958], 
           Hue[0.6498796003047549, 1, 0.10016670727033941`], 
           Hue[0.6496859288220751, 1, 0.1004348677848191], 
           Hue[0.6494168902411381, 1, 0.1008073827430395], 
           Hue[0.649201321406682, 1, 0.10110586266767124`], 
           Hue[0.6491137403392345, 1, 0.10122712876105991`], 
           Hue[0.6491561566068835, 1, 0.10116839854431522`], 
           Hue[0.649341117628011, 1, 0.10091229866890786`], 
           Hue[0.6495991042255871, 1, 0.10055508645687952`], 
           Hue[0.6498107930448382, 1, 0.10026197886099321`], 
           Hue[0.6499302554975778, 1, 0.10009656931104617`], 
           Hue[0.6499798727551618, 1, 0.10002786849285303`], 
           Hue[0.6499947831523835, 1, 0.10000722332746916`], 
           Hue[0.6499948089502459, 1, 0.10000718760735192`], 
           Hue[0.6499799856500064, 1, 0.10002771217691434`], 
           Hue[0.6499305428935218, 1, 0.10009617137820065`], 
           Hue[0.6498113105300759, 1, 0.10026126234297192`], 
           Hue[0.6495997554994433, 1, 0.10055418469307857`], 
           Hue[0.6493416527692056, 1, 0.10091155770417684`], 
           Hue[0.6491563829934826, 1, 0.10116808508594727`], 
           Hue[0.6491137171780912, 1, 0.10122716083033526`], 
           Hue[0.6492010682900416, 1, 0.10110621313686542`], 
           Hue[0.6494162997265166, 1, 0.10080820037866937`], 
           Hue[0.6496852145273, 1, 0.10043585680835385`], 
           Hue[0.6498791017831329, 1, 0.10016739753104674`], 
           Hue[0.649966803005242, 1, 0.10004596506966494`], 
           Hue[0.6499935549624519, 1, 0.10000892389814348`], 
           Hue[0.6499991538514573, 1, 0.1000011715902899], 
           Hue[0.6499998599977125, 1, 0.1000001938493212], 
           Hue[0.6499987823857478, 1, 0.1000016859274261], 
           Hue[0.6499925169058931, 1, 0.10001036120722495`], 
           Hue[0.6499670218094749, 1, 0.10004566210995798`], 
           Hue[0.6498991064821327, 1, 0.10013969871704712`], 
           Hue[0.6497907590832415, 1, 0.10028971819243492`], 
           Hue[0.6496958940624493, 1, 0.10042106975968565`], 
           Hue[0.6496598197797226, 1, 0.10047101876653788`], 
           Hue[0.6496881578673745, 1, 0.10043178141440456`], 
           Hue[0.6497759033253893, 1, 0.10031028770330719`], 
           Hue[0.6498812811242847, 1, 0.10016437998175969`], 
           Hue[0.6499538247815461, 1, 0.1000639349178593], 
           Hue[0.6499864629461425, 1, 0.1000187436130335], 
           Hue[0.6499969516884851, 1, 0.10000422073902053`], 
           Hue[0.6499994075356613, 1, 0.10000082033523827`], 
           Hue[0.6499994121848602, 1, 0.10000081389788582`], 
           Hue[0.64999697736963, 1, 0.10000418518051227`], 
           Hue[0.6499865511173065, 1, 0.1000186215298833], 
           Hue[0.6499540431582559, 1, 0.1000636325501072], 
           Hue[0.6498816573421482, 1, 0.10016385906471793`], 
           Hue[0.649776314091313, 1, 0.10030971895048969`], 
           Hue[0.6496884070778484, 1, 0.1004314363537485], 
           Hue[0.6496598500920083, 1, 0.10047097679568086`], 
           Hue[0.6496956694759822, 1, 0.10042138072556307`], 
           Hue[0.6497903076682763, 1, 0.10029034322854052`], 
           Hue[0.6498986870713849, 1, 0.10014027943962103`], 
           Hue[0.649966803005242, 1, 0.10004596506966494`], 
           Hue[0.6499924447114087, 1, 0.10001046116881876`], 
           Hue[0.6499987662030103, 1, 0.10000170833429346`], 
           Hue[0.6499998575374961, 1, 0.1000001972557747], 
           Hue[0.6499999856334239, 1, 0.10000001989218238`], 
           Hue[0.6499998396191935, 1, 0.1000002220657321], 
           Hue[0.6499987823857478, 1, 0.1000016859274261], 
           Hue[0.6499936165544795, 1, 0.10000883861687448`], 
           Hue[0.6499779704371008, 1, 0.10003050247170653`], 
           Hue[0.6499507186578939, 1, 0.10006823570445465`], 
           Hue[0.6499253861002506, 1, 0.10010331155349914`], 
           Hue[0.6499158353957267, 1, 0.10011653560591689`], 
           Hue[0.6499246089762626, 1, 0.10010438757132877`], 
           Hue[0.6499487609293295, 1, 0.10007094640554372`], 
           Hue[0.6499754483540974, 1, 0.1000339945866345], 
           Hue[0.6499918370195641, 1, 0.10001130258829588`], 
           Hue[0.6499980549290366, 1, 0.10000269317518012`], 
           Hue[0.649999655185399, 1, 0.10000047743560135`], 
           Hue[0.6499999500906315, 1, 0.10000006910527945`], 
           Hue[0.6499999506826558, 1, 0.10000006828555356`], 
           Hue[0.6499996593138839, 1, 0.1000004717192377], 
           Hue[0.6499980735657545, 1, 0.10000266737049385`], 
           Hue[0.6499918966134397, 1, 0.10001122007369896`], 
           Hue[0.6499755737898713, 1, 0.10003382090633207`], 
           Hue[0.6499489183734026, 1, 0.10007072840605792`], 
           Hue[0.6499247160158208, 1, 0.10010423936270976`], 
           Hue[0.6499158508823387, 1, 0.10011651416291573`], 
           Hue[0.6499252913219769, 1, 0.10010344278495513`], 
           Hue[0.6499505462683586, 1, 0.10006847439765741`], 
           Hue[0.6499778300417067, 1, 0.10003069686532914`], 
           Hue[0.6499935549624519, 1, 0.10000892389814348`], 
           Hue[0.6499987662030103, 1, 0.10000170833429346`], 
           Hue[0.6499998368066057, 1, 0.10000022596008445`], 
           Hue[0.6499999852880078, 1, 0.10000002037045079`], 
           Hue[0.65, 1, 0.1], 
           Hue[0.6499999856334239, 1, 0.10000001989218238`], 
           Hue[0.6499998599977125, 1, 0.1000001938493212], 
           Hue[0.6499991646891583, 1, 0.10000115658424232`], 
           Hue[0.6499968893754299, 1, 0.10000430701863561`], 
           Hue[0.6499927167322246, 1, 0.10001008452461209`], 
           Hue[0.649988696060685, 1, 0.10001565160828231`], 
           Hue[0.6499871792649814, 1, 0.10001775178694884`], 
           Hue[0.6499886739785015, 1, 0.10001568218361344`], 
           Hue[0.6499925622199799, 1, 0.10001029846464331`], 
           Hue[0.6499966598024274, 1, 0.10000462488894668`], 
           Hue[0.6499990071984713, 1, 0.10000137464827052`], 
           Hue[0.6499998007707878, 1, 0.10000027585583228`], 
           Hue[0.649999972502692, 1, 0.10000003807319564`], 
           Hue[0.6499999980108732, 1, 0.10000000275417563`], 
           Hue[0.6499999980637757, 1, 0.10000000268092593`], 
           Hue[0.6499999729662879, 1, 0.10000003743129375`], 
           Hue[0.6499998034253445, 1, 0.10000027218029237`], 
           Hue[0.6499990174111819, 1, 0.10000136050759434`], 
           Hue[0.6499966840514407, 1, 0.10000459131338975`], 
           Hue[0.6499925949688808, 1, 0.10001025312001115`], 
           Hue[0.6499886974241673, 1, 0.10001564972038382`], 
           Hue[0.6499871827318622, 1, 0.10001774698665247`], 
           Hue[0.6499886753209286, 1, 0.1000156803248681], 
           Hue[0.6499926810152515, 1, 0.10001013397888259`], 
           Hue[0.6499968622093047, 1, 0.10000434463327044`], 
           Hue[0.6499991538514573, 1, 0.1000011715902899], 
           Hue[0.6499998575374961, 1, 0.1000001972557747], 
           Hue[0.6499999852880078, 1, 0.10000002037045079`], 
           Hue[0.6499999999669532, 1, 0.10000000004575714`], 
           Hue[0.6499999849238686, 1, 0.10000002087464362`], 
           Hue[0.6499998410900942, 1, 0.10000022002910035`], 
           Hue[0.6499989027437987, 1, 0.1000015192778172], 
           Hue[0.6499950637214474, 1, 0.10000683484722672`], 
           Hue[0.6499858880248885, 1, 0.10001953965784668`], 
           Hue[0.6499738433200122, 1, 0.10003621694152162`], 
           Hue[0.6499736137013089, 1, 0.10003653487511074`], 
           Hue[0.6499852820270374, 1, 0.10002037873179444`], 
           Hue[0.6499944257549256, 1, 0.10000771818548765`], 
           Hue[0.6499985573975376, 1, 0.10000199744956326`], 
           Hue[0.6499999644133952, 1, 0.10000004927376044`], 
           Hue[0.649999963849577, 1, 0.10000005005443176`], 
           Hue[0.6499997310457263, 1, 0.1000003723982252], 
           Hue[0.6499985427449788, 1, 0.10000201773772166`], 
           Hue[0.6499943838807886, 1, 0.10000777616506201`], 
           Hue[0.6499852093278041, 1, 0.10002047939227127`], 
           Hue[0.6499735432029402, 1, 0.10003663248823666`], 
           Hue[0.6499739154396369, 1, 0.1000361170835797], 
           Hue[0.6499859694850614, 1, 0.1000194268668381], 
           Hue[0.6499951095696064, 1, 0.10000677136516045`], 
           Hue[0.6499999852765213, 1, 0.10000002038635529`], 
           Hue[0.6499998410900942, 1, 0.10000022002910035`], 
           Hue[0.6499987284592187, 1, 0.10000176059492807`], 
           Hue[0.6499926958443384, 1, 0.10001011344630079`], 
           Hue[0.6499709105190519, 1, 0.10004027774285126`], 
           Hue[0.6499228820634163, 1, 0.10010677868142358`], 
           Hue[0.6498632426034409, 1, 0.10018935639523571`], 
           Hue[0.6499166783476851, 1, 0.10011536844166691`], 
           Hue[0.6499995658652175, 1, 0.10000060110969894`], 
           Hue[0.6499975345136633, 1, 0.1000034137503124], 
           Hue[0.6499892148045759, 1, 0.10001493334751028`], 
           Hue[0.6499646928280673, 1, 0.10004888685344525`], 
           Hue[0.6499164076341196, 1, 0.10011574327583442`], 
           Hue[0.649859297955133, 1, 0.10019481821596973`], 
           Hue[0.6499231865672959, 1, 0.10010635706066737`], 
           Hue[0.6499989027437987, 1, 0.1000015192778172], 
           Hue[0.6499926958443384, 1, 0.10001011344630079`], 
           Hue[0.6499655474797963, 1, 0.1000477034895128], 
           Hue[0.649883813694463, 1, 0.10016087334612819`], 
           Hue[0.6497258842286484, 1, 0.10037954491417912`], 
           Hue[0.6495470248985343, 1, 0.10062719629433715`], 
           Hue[0.6499962208090388, 1, 0.10000523272594622`], 
           Hue[0.6499834211304725, 1, 0.10002295535780738`], 
           Hue[0.6499425936539298, 1, 0.10007948570994332`], 
           Hue[0.6498463773044624, 1, 0.10021270834766752`], 
           Hue[0.6496866431313959, 1, 0.10043387874114412`], 
           Hue[0.6499950637214474, 1, 0.10000683484722672`], 
           Hue[0.6499709105190519, 1, 0.10004027774285126`], 
           Hue[0.649883813694463, 1, 0.10016087334612818`], 
           Hue[0.6496719726032052, 1, 0.10045419178017752`], 
           Hue[0.6493325519861007, 1, 0.10092415878847594`], 
           Hue[0.6499750001267646, 1, 0.10003461520909523`], 
           Hue[0.6499160398116125, 1, 0.10011625256853653`], 
           Hue[0.6497718388043817, 1, 0.1003159155016253], 
           Hue[0.6495107697330291, 1, 0.10067739575426744`], 
           Hue[0.6499951095696064, 1, 0.10000677136516044`], 
           Hue[0.6499858880248885, 1, 0.10001953965784668`], 
           Hue[0.6499228820634163, 1, 0.10010677868142358`], 
           Hue[0.6497258842286484, 1, 0.10037954491417911`], 
           Hue[0.6493325519861007, 1, 0.10092415878847591`], 
           Hue[0.6498706375066201, 1, 0.10017911729852608`], 
           Hue[0.6496722119092209, 1, 0.1004538604333865], 
           Hue[0.6493021059490827, 1, 0.10096631483973172`], 
           Hue[0.6499231865672959, 1, 0.10010635706066733`], 
           Hue[0.6499859694850614, 1, 0.10001942686683808`], 
           Hue[0.6499738433200122, 1, 0.10003621694152162`], 
           Hue[0.6498632426034409, 1, 0.10018935639523571`], 
           Hue[0.6495470248985343, 1, 0.10062719629433713`], 
           Hue[0.647580489015451, 1, 0.1033500921324526], 
           Hue[0.6472836152052587, 1, 0.10376114817733419`], 
           Hue[0.6471229934816806, 1, 0.10398354748690382`], 
           Hue[0.6494582860502159, 1, 0.10075006546893182`], 
           Hue[0.6489836000327871, 1, 0.10140732303152564`], 
           Hue[0.6472221007030101, 1, 0.10384632210352455`], 
           Hue[0.6471236667804909, 1, 0.10398261522701252`], 
           Hue[0.6499739154396369, 1, 0.1000361170835797], 
           Hue[0.6475804890154508, 1, 0.10335009213245272`], 
           Hue[0.6471111373540478, 1, 0.10399996366362618`], 
           Hue[0.6466655980999736, 1, 0.10461686416926731`], 
           Hue[0.6462649933797092, 1, 0.10517154762809496`], 
           Hue[0.6460136181207266, 1, 0.10551960567899407`], 
           Hue[0.6460894082914638, 1, 0.10541466544258865`], 
           Hue[0.6460145578411789, 1, 0.1055183045275985], 
           Hue[0.6472836152052579, 1, 0.10376114817733527`], 
           Hue[0.6466655980999717, 1, 0.10461686416927002`], 
           Hue[0.6460502287342637, 1, 0.10546891406025037`], 
           Hue[0.6453869809034413, 1, 0.10638725721061978`], 
           Hue[0.6447122845415751, 1, 0.10732145217320362`], 
           Hue[0.6441102689755968, 1, 0.10815501218763528`], 
           Hue[0.6436464972274288, 1, 0.10879715768509854`], 
           Hue[0.6433361223092663, 1, 0.1092269075717851], 
           Hue[0.6433360175588242, 1, 0.1092270526108588], 
           Hue[0.6436473955325628, 1, 0.10879591387799005`], 
           Hue[0.6441116193627917, 1, 0.10815314242074998`], 
           Hue[0.6499736137013089, 1, 0.10003653487511074`], 
           Hue[0.6471229934816762, 1, 0.1039835474869099], 
           Hue[0.6462649933796968, 1, 0.10517154762811219`], 
           Hue[0.6453869809034246, 1, 0.10638725721064288`], 
           Hue[0.6443765815752575, 1, 0.1077862716650282], 
           Hue[0.6429887403224448, 1, 0.10970789801507655`], 
           Hue[0.6406162192000339, 1, 0.11299292726149159`], 
           Hue[0.6364545540009836, 1, 0.1187552329217151], 
           Hue[0.6305924039164738, 1, 0.12687205611565178`], 
           Hue[0.625034954606874, 1, 0.1345669859289438], 
           Hue[0.630594812444056, 1, 0.12686872123130705`], 
           Hue[0.6364584596844344, 1, 0.11874982505232165`], 
           Hue[0.6471236667804864, 1, 0.10398261522701893`], 
           Hue[0.649859297955133, 1, 0.10019481821596983`], 
           Hue[0.6499735432029402, 1, 0.10003663248823669`], 
           Hue[0.6499852820270374, 1, 0.10002037873179444`], 
           Hue[0.6499166783476851, 1, 0.10011536844166691`], 
           Hue[0.6460136181206872, 1, 0.10551960567904847`], 
           Hue[0.6447122845415196, 1, 0.10732145217328057`], 
           Hue[0.6429887403224135, 1, 0.10970789801511988`], 
           Hue[0.6394886467886375, 1, 0.11455418136957889`], 
           Hue[0.6310134115394466, 1, 0.12628912248384325`], 
           Hue[0.6140784301117376, 1, 0.14973755830682497`], 
           Hue[0.5901149258211708, 1, 0.18291779501684047`], 
           Hue[0.6460145578411413, 1, 0.10551830452765065`], 
           Hue[0.647222100702996, 1, 0.10384632210354394`], 
           Hue[0.6496866431313958, 1, 0.1004338787411443], 
           Hue[0.6499164076341196, 1, 0.10011574327583449`], 
           Hue[0.6499852093278041, 1, 0.10002047939227128`], 
           Hue[0.6499944257549256, 1, 0.10000771818548765`], 
           Hue[0.6441102689755097, 1, 0.10815501218775583`], 
           Hue[0.6406162192, 1, 0.1129929272615385], 
           Hue[0.6310134115394676, 1, 0.1262891224838142], 
           Hue[0.6058582780000794, 1, 0.1611193073845055], 
           Hue[0.5584199878537663, 1, 0.22680309374093893`], 
           Hue[0.4978115944517789, 1, 0.3107224076821523], 
           Hue[0.6441116193627406, 1, 0.1081531424208207], 
           Hue[0.646089408291409, 1, 0.10541466544266438`], 
           Hue[0.6495107697330285, 1, 0.10067739575426836`], 
           Hue[0.6498463773044623, 1, 0.10021270834766764`], 
           Hue[0.6499646928280673, 1, 0.10004888685344528`], 
           Hue[0.6499943838807886, 1, 0.10000777616506201`], 
           Hue[0.6499985573975376, 1, 0.10000199744956326`], 
           Hue[0.6436464972273616, 1, 0.10879715768519174`], 
           Hue[0.636454554000992, 1, 0.11875523292170333`], 
           Hue[0.6140784301118009, 1, 0.1497375583067373], 
           Hue[0.558419987853781, 1, 0.2268030937409187], 
           Hue[0.4653501926787307, 1, 0.35566896398329606`], 
           Hue[0.6364584596846764, 1, 0.11874982505198657`], 
           Hue[0.6436473955326357, 1, 0.10879591387788896`], 
           Hue[0.6493021059490783, 1, 0.10096631483973767`], 
           Hue[0.6497718388043812, 1, 0.10031591550162612`], 
           Hue[0.6499425936539298, 1, 0.10007948570994339`], 
           Hue[0.6499892148045759, 1, 0.1000149333475103], 
           Hue[0.6499985427449788, 1, 0.10000201773772166`], 
           Hue[0.6433361223092463, 1, 0.10922690757181291`], 
           Hue[0.6305924039165115, 1, 0.12687205611559949`], 
           Hue[0.5901149258212088, 1, 0.18291779501678784`], 
           Hue[0.49781159445165823`, 1, 0.31072240768231946`], 
           Hue[0.6305948124445969, 1, 0.1268687212305581], 
           Hue[0.6433360175591031, 1, 0.10922705261047262`], 
           Hue[0.6489836000327963, 1, 0.10140732303151286`], 
           Hue[0.6496722119092204, 1, 0.10045386043338717`], 
           Hue[0.6499160398116123, 1, 0.10011625256853683`], 
           Hue[0.6499834211304725, 1, 0.10002295535780742`], 
           Hue[0.6499975345136633, 1, 0.1000034137503124], 
           Hue[0.6499997310457263, 1, 0.1000003723982252], 
           Hue[0.6499999644133952, 1, 0.10000004927376044`], 
           Hue[0.6250349546068943, 1, 0.13456698592891564`], 
           Hue[0.6494582860502358, 1, 0.10075006546890423`], 
           Hue[0.6498706375066219, 1, 0.10017911729852358`], 
           Hue[0.6499750001267647, 1, 0.10003461520909515`], 
           Hue[0.6499962208090388, 1, 0.10000523272594623`], 
           Hue[0.6499995658652175, 1, 0.10000060110969894`], 
           Hue[0.649999963849577, 1, 0.10000005005443176`], 
           Hue[0., 1, 1.], 
           Hue[0.649999963849577, 1, 0.10000005005443176`], 
           Hue[0.6499995658652175, 1, 0.10000060110969894`], 
           Hue[0.6499962208090388, 1, 0.10000523272594622`], 
           Hue[0.6499750001267646, 1, 0.10003461520909523`], 
           Hue[0.6498706375066201, 1, 0.10017911729852609`], 
           Hue[0.6494582860502159, 1, 0.10075006546893184`], 
           Hue[0.6250349546069032, 1, 0.1345669859289033], 
           Hue[0.6499999644133952, 1, 0.10000004927376044`], 
           Hue[0.6499997310457263, 1, 0.1000003723982252], 
           Hue[0.6499975345136633, 1, 0.1000034137503124], 
           Hue[0.6499834211304725, 1, 0.10002295535780739`], 
           Hue[0.6499160398116125, 1, 0.10011625256853654`], 
           Hue[0.6496722119092209, 1, 0.1004538604333865], 
           Hue[0.6489836000327871, 1, 0.10140732303152555`], 
           Hue[0.6433360175588241, 1, 0.10922705261085894`], 
           Hue[0.6305948124440502, 1, 0.12686872123131515`], 
           Hue[0.49781159445338463`, 1, 0.310722407679929], 
           Hue[0.5901149258219073, 1, 0.18291779501582073`], 
           Hue[0.6305924039163933, 1, 0.12687205611576322`], 
           Hue[0.6433361223090291, 1, 0.10922690757211345`], 
           Hue[0.6499985427449788, 1, 0.10000201773772166`], 
           Hue[0.6499892148045759, 1, 0.10001493334751028`], 
           Hue[0.6499425936539298, 1, 0.10007948570994334`], 
           Hue[0.6497718388043817, 1, 0.10031591550162536`], 
           Hue[0.6493021059490827, 1, 0.1009663148397318], 
           Hue[0.6436473955325627, 1, 0.10879591387799013`], 
           Hue[0.6364584596844316, 1, 0.11874982505232544`], 
           Hue[0.46535019268013794`, 1, 0.3556689639813475], 
           Hue[0.5584199878547623, 1, 0.22680309373955995`], 
           Hue[0.6140784301120935, 1, 0.14973755830633206`], 
           Hue[0.6364545540009346, 1, 0.11875523292178278`], 
           Hue[0.6436464972273148, 1, 0.10879715768525641`], 
           Hue[0.6499985573975376, 1, 0.10000199744956326`], 
           Hue[0.6499943838807886, 1, 0.10000777616506201`], 
           Hue[0.6499646928280673, 1, 0.10004888685344525`], 
           Hue[0.6498463773044624, 1, 0.10021270834766756`], 
           Hue[0.649510769733029, 1, 0.10067739575426754`], 
           Hue[0.6460894082914639, 1, 0.10541466544258854`], 
           Hue[0.6441116193627918, 1, 0.10815314242074982`], 
           Hue[0.49781159445338496`, 1, 0.3107224076799285], 
           Hue[0.5584199878547618, 1, 0.22680309373956073`], 
           Hue[0.6058582780004875, 1, 0.16111930738394037`], 
           Hue[0.6310134115395549, 1, 0.12628912248369326`], 
           Hue[0.6406162192000211, 1, 0.11299292726150936`], 
           Hue[0.6441102689755677, 1, 0.10815501218767563`], 
           Hue[0.6499944257549256, 1, 0.10000771818548763`], 
           Hue[0.6499852093278041, 1, 0.10002047939227127`], 
           Hue[0.6499164076341196, 1, 0.10011574327583443`], 
           Hue[0.6496866431313959, 1, 0.10043387874114416`], 
           Hue[0.6472221007030099, 1, 0.10384632210352472`], 
           Hue[0.646014557841179, 1, 0.10551830452759829`], 
           Hue[0.5901149258219057, 1, 0.1829177950158229], 
           Hue[0.6140784301120928, 1, 0.14973755830633298`], 
           Hue[0.6310134115395546, 1, 0.12628912248369367`], 
           Hue[0.6394886467886615, 1, 0.11455418136954568`], 
           Hue[0.6429887403224473, 1, 0.109707898015073], 
           Hue[0.6447122845415725, 1, 0.10732145217320734`], 
           Hue[0.6460136181207251, 1, 0.10551960567899599`], 
           Hue[0.6499166783476851, 1, 0.10011536844166684`], 
           Hue[0.6499852820270374, 1, 0.10002037873179442`], 
           Hue[0.6499735432029402, 1, 0.10003663248823666`], 
           Hue[0.649859297955133, 1, 0.10019481821596973`], 
           Hue[0.6471236667804908, 1, 0.10398261522701273`], 
           Hue[0.6364584596846646, 1, 0.11874982505200281`], 
           Hue[0.6305948124445522, 1, 0.12686872123062018`], 
           Hue[0.6250349546068997, 1, 0.1345669859289081], 
           Hue[0.6305924039163923, 1, 0.12687205611576466`], 
           Hue[0.6364545540009342, 1, 0.1187552329217834], 
           Hue[0.6406162192000208, 1, 0.11299292726150978`], 
           Hue[0.6429887403224471, 1, 0.10970789801507319`], 
           Hue[0.6443765815752722, 1, 0.10778627166500773`], 
           Hue[0.6453869809034444, 1, 0.10638725721061551`], 
           Hue[0.6462649933797096, 1, 0.10517154762809447`], 
           Hue[0.6471229934816807, 1, 0.10398354748690375`], 
           Hue[0.6499736137013089, 1, 0.10003653487511072`], 
           Hue[0.6441116193628278, 1, 0.1081531424207001], 
           Hue[0.6436473955327029, 1, 0.10879591387779611`], 
           Hue[0.6433360175591226, 1, 0.10922705261044566`], 
           Hue[0.6433361223090287, 1, 0.10922690757211413`], 
           Hue[0.6436464972273146, 1, 0.10879715768525677`], 
           Hue[0.6441102689755674, 1, 0.10815501218767593`], 
           Hue[0.6447122845415724, 1, 0.10732145217320749`], 
           Hue[0.6453869809034444, 1, 0.10638725721061548`], 
           Hue[0.6460502287342674, 1, 0.10546891406024508`], 
           Hue[0.6466655980999738, 1, 0.10461686416926702`], 
           Hue[0.6472836152052586, 1, 0.10376114817733438`], 
           Hue[0.6460145578411807, 1, 0.10551830452759606`], 
           Hue[0.6460894082914773, 1, 0.10541466544256996`], 
           Hue[0.6460136181207252, 1, 0.10551960567899595`], 
           Hue[0.6462649933797097, 1, 0.10517154762809428`], 
           Hue[0.6466655980999739, 1, 0.10461686416926684`], 
           Hue[0.6471111373540477, 1, 0.10399996366362627`], 
           Hue[0.6475804890154506, 1, 0.10335009213245296`], 
           Hue[0.6499739154396369, 1, 0.1000361170835797], 
           Hue[0.6471236667804907, 1, 0.10398261522701283`], 
           Hue[0.6472221007030102, 1, 0.10384632210352437`], 
           Hue[0.648983600032812, 1, 0.10140732303149122`], 
           Hue[0.6494582860502409, 1, 0.10075006546889727`], 
           Hue[0.6471229934816808, 1, 0.10398354748690349`], 
           Hue[0.6472836152052587, 1, 0.10376114817733417`], 
           Hue[0.6475804890154507, 1, 0.1033500921324529], 
           Hue[0.6495470248985343, 1, 0.10062719629433717`], 
           Hue[0.6498632426034409, 1, 0.10018935639523573`], 
           Hue[0.6499738433200122, 1, 0.10003621694152162`], 
           Hue[0.6499859694850614, 1, 0.1000194268668381], 
           Hue[0.6499231865672959, 1, 0.10010635706066735`], 
           Hue[0.6493021059490841, 1, 0.10096631483972977`], 
           Hue[0.6496722119092239, 1, 0.10045386043338231`], 
           Hue[0.6498706375066231, 1, 0.1001791172985219], 
           Hue[0.6493325519861006, 1, 0.10092415878847606`], 
           Hue[0.6497258842286484, 1, 0.10037954491417919`], 
           Hue[0.6499228820634163, 1, 0.1001067786814236], 
           Hue[0.6499858880248885, 1, 0.10001953965784668`], 
           Hue[0.6499951095696064, 1, 0.10000677136516045`], 
           Hue[0.6495107697330291, 1, 0.10067739575426747`], 
           Hue[0.6497718388043818, 1, 0.10031591550162516`], 
           Hue[0.6499160398116127, 1, 0.10011625256853622`], 
           Hue[0.6499750001267648, 1, 0.10003461520909494`], 
           Hue[0.6493325519861006, 1, 0.10092415878847612`], 
           Hue[0.6496719726032051, 1, 0.10045419178017764`], 
           Hue[0.649883813694463, 1, 0.10016087334612823`], 
           Hue[0.6499709105190519, 1, 0.10004027774285129`], 
           Hue[0.6499950637214474, 1, 0.10000683484722674`], 
           Hue[0.6496866431313958, 1, 0.10043387874114428`], 
           Hue[0.6498463773044624, 1, 0.10021270834766757`], 
           Hue[0.6499425936539298, 1, 0.10007948570994332`], 
           Hue[0.6499834211304725, 1, 0.10002295535780736`], 
           Hue[0.6499962208090388, 1, 0.1000052327259462], 
           Hue[0.6495470248985342, 1, 0.10062719629433724`], 
           Hue[0.6497258842286484, 1, 0.10037954491417923`], 
           Hue[0.6498838136944629, 1, 0.10016087334612825`], 
           Hue[0.6499655474797963, 1, 0.10004770348951282`], 
           Hue[0.6499926958443384, 1, 0.10001011344630079`], 
           Hue[0.6499989027437987, 1, 0.1000015192778172], 
           Hue[0.6499231865672959, 1, 0.10010635706066733`], 
           Hue[0.6498592979551329, 1, 0.10019481821596984`], 
           Hue[0.6499164076341195, 1, 0.10011574327583449`], 
           Hue[0.6499646928280673, 1, 0.10004888685344526`], 
           Hue[0.6499892148045759, 1, 0.1000149333475103], 
           Hue[0.6499975345136633, 1, 0.1000034137503124], 
           Hue[0.6499995658652175, 1, 0.10000060110969894`], 
           Hue[0.6499166783476851, 1, 0.10011536844166684`], 
           Hue[0.6498632426034409, 1, 0.10018935639523575`], 
           Hue[0.6499228820634163, 1, 0.10010677868142362`], 
           Hue[0.6499709105190519, 1, 0.10004027774285129`], 
           Hue[0.6499926958443384, 1, 0.1000101134463008], 
           Hue[0.6499987284592187, 1, 0.10000176059492807`], 
           Hue[0.6499998410900942, 1, 0.10000022002910035`], 
           Hue[0.6499999852765213, 1, 0.10000002038635529`], 
           Hue[0.6499951095696064, 1, 0.10000677136516044`], 
           Hue[0.6499859694850614, 1, 0.10001942686683808`], 
           Hue[0.6499739154396369, 1, 0.1000361170835797], 
           Hue[0.6499735432029402, 1, 0.10003663248823669`], 
           Hue[0.6499852093278041, 1, 0.10002047939227128`], 
           Hue[0.6499943838807886, 1, 0.10000777616506201`], 
           Hue[0.6499985427449788, 1, 0.10000201773772166`], 
           Hue[0.6499997310457263, 1, 0.1000003723982252], 
           Hue[0.649999963849577, 1, 0.10000005005443176`], 
           Hue[0.6499999644133952, 1, 0.10000004927376044`], 
           Hue[0.6499985573975376, 1, 0.10000199744956326`], 
           Hue[0.6499944257549256, 1, 0.10000771818548763`], 
           Hue[0.6499852820270374, 1, 0.10002037873179442`], 
           Hue[0.6499736137013089, 1, 0.10003653487511072`], 
           Hue[0.6499738433200122, 1, 0.10003621694152164`], 
           Hue[0.6499858880248885, 1, 0.10001953965784668`], 
           Hue[0.6499950637214474, 1, 0.10000683484722674`], 
           Hue[0.6499989027437987, 1, 0.1000015192778172], 
           Hue[0.6499998410900942, 1, 0.10000022002910035`], 
           Hue[0.6499999849238686, 1, 0.10000002087464362`], 
           Hue[0.6499999965856617, 1, 0.10000000472754546`], 
           Hue[0.6499999480469419, 1, 0.10000007193500345`], 
           Hue[0.6499999480469419, 1, 0.10000007193500345`], 
           Hue[0.6499999965856617, 1, 0.10000000472754546`], 
           Hue[0.6499999509486679, 1, 0.10000006791722911`], 
           Hue[0.6499995605902448, 1, 0.10000060841350733`], 
           Hue[0.6499995314220489, 1, 0.10000064880024004`], 
           Hue[0.6499975387906934, 1, 0.10000340782827066`], 
           Hue[0.6499970370468677, 1, 0.10000410255049084`], 
           Hue[0.649991166860452, 1, 0.10001223050091258`], 
           Hue[0.6499873787655159, 1, 0.10001747555543954`], 
           Hue[0.6499797890669986, 1, 0.10002798436877125`], 
           Hue[0.6499650867010297, 1, 0.10004834149088197`], 
           Hue[0.6499365186637519, 1, 0.10008789723480505`], 
           Hue[0.6499660419264217, 1, 0.10004701887110848`], 
           Hue[0.6499660352996491, 1, 0.10004702804663976`], 
           Hue[0.6499689720806963, 1, 0.10004296173442062`], 
           Hue[0.6499793572109922, 1, 0.10002858232324167`], 
           Hue[0.6499904847358855, 1, 0.10001317498108164`], 
           Hue[0.6499630030101804, 1, 0.10005122660128868`], 
           Hue[0.649997032693306, 1, 0.10000410857849946`], 
           Hue[0.6499997344623704, 1, 0.10000036766748721`], 
           Hue[0.6499999234519708, 1, 0.10000010598957898`], 
           Hue[0.6499999917956835, 1, 0.10000001135982291`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499999878784672, 1, 0.1000000167836607], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499999916279817, 1, 0.10000001159202533`], 
           Hue[0.6499998974223291, 1, 0.10000014203062124`], 
           Hue[0.6499998686930739, 1, 0.10000018180959001`], 
           Hue[0.6499999222917153, 1, 0.10000010759608655`], 
           Hue[0.6499993483460993, 1, 0.10000090229001642`], 
           Hue[0.6499991515859967, 1, 0.10000117472708145`], 
           Hue[0.6499970064878591, 1, 0.10000414486296436`], 
           Hue[0.6499958569645508, 1, 0.10000573651062201`], 
           Hue[0.6499904256749581, 1, 0.10001325675775032`], 
           Hue[0.6499852021769049, 1, 0.10002048929351634`], 
           Hue[0.6499792798726709, 1, 0.10002868940707105`], 
           Hue[0.6499628521968075, 1, 0.10005143541980506`], 
           Hue[0.6499353113077606, 1, 0.1000895689584853], 
           Hue[0.6499660027761931, 1, 0.10004707307911731`], 
           Hue[0.6499660613044453, 1, 0.10004699203999874`], 
           Hue[0.6499690957937134, 1, 0.10004279043947381`], 
           Hue[0.6499798735525514, 1, 0.100027867388775], 
           Hue[0.6499912329900899, 1, 0.10001213893679865`], 
           Hue[0.6499989171085051, 1, 0.10000149938822367`], 
           Hue[0.6499998438351633, 1, 0.10000021622823552`], 
           Hue[0.6499999966971565, 1, 0.10000000457316796`], 
           Hue[0.6499999966971565, 1, 0.10000000457316796`], 
           Hue[0.6499995314220489, 1, 0.10000064880024004`], 
           Hue[0.6499995605902448, 1, 0.10000060841350733`], 
           Hue[0.6499999509486679, 1, 0.10000006791722911`], 
           Hue[0.6499968197541345, 1, 0.10000440341735237`], 
           Hue[0.6499968197541345, 1, 0.10000440341735237`], 
           Hue[0.6499846921337001, 1, 0.10002119550718443`], 
           Hue[0.6499834669215924, 1, 0.10002289195471835`], 
           Hue[0.6499501069361, 1, 0.10006908270386163`], 
           Hue[0.6499391582420061, 1, 0.10008424243414546`], 
           Hue[0.6498923240356159, 1, 0.10014908979683958`], 
           Hue[0.6498470503888287, 1, 0.10021177638469872`], 
           Hue[0.6497372360371154, 1, 0.10036382702553248`], 
           Hue[0.6498246858302774, 1, 0.10024274269653898`], 
           Hue[0.6498595392714196, 1, 0.10019448408572672`], 
           Hue[0.6498872063550267, 1, 0.10015617581611685`], 
           Hue[0.6499648695962024, 1, 0.10004864209756598`], 
           Hue[0.6499892896045865, 1, 0.10001482977826487`], 
           Hue[0.6499995706076633, 1, 0.10000059454323541`], 
           Hue[0.6499998222703252, 1, 0.1000002460872421], 
           Hue[0.6499998205406813, 1, 0.10000024848213372`], 
           Hue[0.6499989347644688, 1, 0.1000014749415048], 
           Hue[0.649998672028374, 1, 0.10000183872994367`], 
           Hue[0.6499946619760952, 1, 0.10000739111002195`], 
           Hue[0.6499933666375028, 1, 0.10000918465576535`], 
           Hue[0.6499797258816096, 1, 0.100028071856233], 
           Hue[0.6499741382710061, 1, 0.10003580854783767`], 
           Hue[0.6499433111349449, 1, 0.10007849227469179`], 
           Hue[0.6499231631029164, 1, 0.10010638954980806`], 
           Hue[0.6498869310750488, 1, 0.10015655697300938`], 
           Hue[0.6498302874016713, 1, 0.10023498667460903`], 
           Hue[0.6495193091275062, 1, 0.10066557197729911`], 
           Hue[0.6498258485023254, 1, 0.10024113284293408`], 
           Hue[0.6498634903348335, 1, 0.10018901338253836`], 
           Hue[0.6498926261234818, 1, 0.10014867152133293`], 
           Hue[0.6499711016483095, 1, 0.10004001310234079`], 
           Hue[0.6499998438351633, 1, 0.10000021622823552`], 
           Hue[0.6499970370468677, 1, 0.10000410255049084`], 
           Hue[0.6499975387906934, 1, 0.10000340782827066`], 
           Hue[0.6499834669215924, 1, 0.10002289195471835`], 
           Hue[0.6499846921337001, 1, 0.10002119550718443`], 
           Hue[0.6499339441898728, 1, 0.10009146189094531`], 
           Hue[0.6499339441898728, 1, 0.10009146189094531`], 
           Hue[0.6498131704790807, 1, 0.10025868702896522`], 
           Hue[0.6497964648039245, 1, 0.10028181796379686`], 
           Hue[0.6495530687696348, 1, 0.10061882785742883`], 
           Hue[0.6494292804404583, 1, 0.1007902270824424], 
           Hue[0.6495197235700737, 1, 0.10066499813374416`], 
           Hue[0.6496872006198551, 1, 0.10043310683404684`], 
           Hue[0.6498468322258638, 1, 0.10021207845649631`], 
           Hue[0.6499962490896035, 1, 0.10000519356824138`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499751193911049, 1, 0.10003445007385486`], 
           Hue[0.6499981815209614, 1, 0.10000251789405334`], 
           Hue[0.649991888260414, 1, 0.10001123163942685`], 
           Hue[0.6499899581044661, 1, 0.10001390416304694`], 
           Hue[0.649968151589994, 1, 0.10004409779846983`], 
           Hue[0.6499613986682437, 1, 0.10005344799781657`], 
           Hue[0.6499029637901637, 1, 0.1001343578290042], 
           Hue[0.6498815309986415, 1, 0.100164034001881], 
           Hue[0.6497727314760293, 1, 0.10031467949472868`], 
           Hue[0.6497158718365242, 1, 0.10039340822635104`], 
           Hue[0.6491676275232411, 1, 0.10115251573705085`], 
           Hue[0.6494394618677293, 1, 0.10077612972160567`], 
           Hue[0.6495474566380963, 1, 0.1006265985010974], 
           Hue[0.6497265096835253, 1, 0.1003786788997342], 
           Hue[0.6498842956213006, 1, 0.10016020606281466`], 
           Hue[0.6499989171085051, 1, 0.10000149938822367`], 
           Hue[0.6499975662514333, 1, 0.10000336980570772`], 
           Hue[0.6499873787655159, 1, 0.10001747555543954`], 
           Hue[0.649991166860452, 1, 0.10001223050091258`], 
           Hue[0.6499391582420061, 1, 0.10008424243414546`], 
           Hue[0.6499501069361, 1, 0.10006908270386163`], 
           Hue[0.6497964648039245, 1, 0.10028181796379684`], 
           Hue[0.6498131704790807, 1, 0.10025868702896522`], 
           Hue[0.6495129010015269, 1, 0.10067444476711664`], 
           Hue[0.6495129010015269, 1, 0.10067444476711662`], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6498709896006915, 1, 0.100178629783658], 
           Hue[0.6499859604962616, 1, 0.1000194393128687], 
           Hue[0.6499533005675091, 1, 0.10006466075267968`], 
           Hue[0.649941462651146, 1, 0.1000810517137978], 
           Hue[0.6498573946453188, 1, 0.1001974535680202], 
           Hue[0.649828893698698, 1, 0.10023691641718743`], 
           Hue[0.6496559963280033, 1, 0.1004763127766109], 
           Hue[0.6495884346066919, 1, 0.10056985977534973`], 
           Hue[0.6488022469143933, 1, 0.10165842734930168`], 
           Hue[0.6487517211908194, 1, 0.10172838604348085`], 
           Hue[0.6488011994693257, 1, 0.10165987765785683`], 
           Hue[0.6489976573214437, 1, 0.10138785909338578`], 
           Hue[0.6493332016432399, 1, 0.10092325926320626`], 
           Hue[0.6498842956213006, 1, 0.10016020606281463`], 
           Hue[0.6497265096835254, 1, 0.10037867889973409`], 
           Hue[0.6499711016483095, 1, 0.10004001310234076`], 
           Hue[0.6499503668772793, 1, 0.10006872278530574`], 
           Hue[0.6499912329900899, 1, 0.10001213893679864`], 
           Hue[0.6499650867010297, 1, 0.10004834149088197`], 
           Hue[0.6499797890669986, 1, 0.10002798436877125`], 
           Hue[0.6498470503888287, 1, 0.10021177638469872`], 
           Hue[0.6498923240356159, 1, 0.10014908979683958`], 
           Hue[0.6495530687696348, 1, 0.10061882785742882`], 
           Hue[0.6499289484739935, 1, 0.10009837903600899`], 
           Hue[0.6494589962075535, 1, 0.10074908217415667`], 
           Hue[0.6499147887623509, 1, 0.10011798479059121`], 
           Hue[0.6497916794686949, 1, 0.10028844381257641`], 
           Hue[0.6497289407483949, 1, 0.1003753128099147], 
           Hue[0.6495085615470422, 1, 0.10068045324255707`], 
           Hue[0.6494073982064067, 1, 0.10082052556035999`], 
           Hue[0.6483053260376217, 1, 0.10234647164021618`], 
           Hue[0.6483163987955445, 1, 0.1023311401292462], 
           Hue[0.6480161564309219, 1, 0.10274686032641583`], 
           Hue[0.6479796182166929, 1, 0.10279745169996367`], 
           Hue[0.6481284893528518, 1, 0.10259132243451285`], 
           Hue[0.6483958281620501, 1, 0.1022211610063922], 
           Hue[0.64933320164324, 1, 0.10092325926320615`], 
           Hue[0.6489976573214438, 1, 0.10138785909338563`], 
           Hue[0.6495474566380964, 1, 0.1006265985010973], 
           Hue[0.6498634903348335, 1, 0.1001890133825383], 
           Hue[0.6499798735525514, 1, 0.10002786738877499`], 
           Hue[0.6499365186637519, 1, 0.10008789723480505`], 
           Hue[0.6497372360371154, 1, 0.10036382702553247`], 
           Hue[0.6489846669012644, 1, 0.10140584582901847`], 
           Hue[0.6473523532851713, 1, 0.10366597237437833`], 
           Hue[0.6496234965987956, 1, 0.10052131240166763`], 
           Hue[0.6480476331533843, 1, 0.1027032771722371], 
           Hue[0.6495819204902942, 1, 0.10057887932113115`], 
           Hue[0.6492559152561154, 1, 0.10103027118384031`], 
           Hue[0.6480467041527054, 1, 0.10270456348086947`], 
           Hue[0.6473513706733502, 1, 0.10366733291382275`], 
           Hue[0.6476433233638824, 1, 0.10326309072693203`], 
           Hue[0.6473931627551948, 1, 0.10360946695434578`], 
           Hue[0.647134233734633, 1, 0.10396798405973895`], 
           Hue[0.6472841430793683, 1, 0.10376041727472078`], 
           Hue[0.6475809298216182, 1, 0.10334948178545172`], 
           Hue[0.6483958281620502, 1, 0.10222116100639211`], 
           Hue[0.6481284893528518, 1, 0.10259132243451291`], 
           Hue[0.6488011994693256, 1, 0.10165987765785686`], 
           Hue[0.6494394618677293, 1, 0.10077612972160571`], 
           Hue[0.6498258485023254, 1, 0.10024113284293411`], 
           Hue[0.6499660613044453, 1, 0.10004699203999876`], 
           Hue[0.6499660419264217, 1, 0.10004701887110848`], 
           Hue[0.6465822717265688, 1, 0.1047322391478279], 
           Hue[0.6462861242777479, 1, 0.10514228946157993`], 
           Hue[0.6460011934807784, 1, 0.10553680902661455`], 
           Hue[0.6462658582790937, 1, 0.10517035007510118`], 
           Hue[0.6466661863103492, 1, 0.10461604972413183`], 
           Hue[0.6475809298216181, 1, 0.10334948178545186`], 
           Hue[0.6472841430793674, 1, 0.10376041727472206`], 
           Hue[0.6479796182166926, 1, 0.1027974516999641], 
           Hue[0.6487517211908193, 1, 0.10172838604348111`], 
           Hue[0.6499875583936996, 1, 0.10001722683949292`], 
           Hue[0.6499660352996491, 1, 0.10004702804663974`], 
           Hue[0.6499689720806963, 1, 0.10004296173442062`], 
           Hue[0.6499875752276579, 1, 0.10001720353093523`], 
           Hue[0.6498246858302774, 1, 0.10024274269653896`], 
           Hue[0.6498595392714196, 1, 0.1001944840857267], 
           Hue[0.6494292804404583, 1, 0.10079022708244238`], 
           Hue[0.6495197235700737, 1, 0.10066499813374416`], 
           Hue[0.6450459043341157, 1, 0.10685951707583985`], 
           Hue[0.6449078143256106, 1, 0.10705071862607762`], 
           Hue[0.644397187686445, 1, 0.1077577401264608], 
           Hue[0.6439515530904346, 1, 0.10837477264401368`], 
           Hue[0.6438587986192775, 1, 0.10850320191176961`], 
           Hue[0.6427201663461681, 1, 0.1100797696745365], 
           Hue[0.6434731972963169, 1, 0.10903711143586889`], 
           Hue[0.6410125786951648, 1, 0.11244412180669497`], 
           Hue[0.6388740031493004, 1, 0.11540522640866098`], 
           Hue[0.6431577560121023, 1, 0.10947387629093527`], 
           Hue[0.6432314603305186, 1, 0.10937182415774348`], 
           Hue[0.6434736200020822, 1, 0.10903652615096315`], 
           Hue[0.6438600147950488, 1, 0.10850151797608631`], 
           Hue[0.6447135116824771, 1, 0.10731975305503161`], 
           Hue[0.6453879602649294, 1, 0.10638590117163631`], 
           Hue[0.6466661863103472, 1, 0.1046160497241347], 
           Hue[0.646265858279081, 1, 0.10517035007511863`], 
           Hue[0.6471786129927855, 1, 0.10390653585614328`], 
           Hue[0.6480161564309208, 1, 0.10274686032641733`], 
           Hue[0.6499660027761931, 1, 0.10004707307911734`], 
           Hue[0.6499793572109922, 1, 0.10002858232324166`], 
           Hue[0.6498872063550267, 1, 0.10015617581611685`], 
           Hue[0.6496872006198551, 1, 0.10043310683404687`], 
           Hue[0.6449078143255991, 1, 0.10705071862609364`], 
           Hue[0.6450459043340817, 1, 0.10685951707588696`], 
           Hue[0.6437573464570181, 1, 0.10864367413643647`], 
           Hue[0.6437573464570021, 1, 0.10864367413645863`], 
           Hue[0.6419793946935759, 1, 0.11110545350120263`], 
           Hue[0.6416150548927508, 1, 0.11160992399465273`], 
           Hue[0.6387923231016593, 1, 0.11551832185924087`], 
           Hue[0.6370814322963922, 1, 0.1178872475896108], 
           Hue[0.6336566410847779, 1, 0.12262926619030753`], 
           Hue[0.6282683067128656, 1, 0.13009003685910922`], 
           Hue[0.6155545287377167, 1, 0.14769372944008474`], 
           Hue[0.6250352667022192, 1, 0.13456655379692734`], 
           Hue[0.6275873411445113, 1, 0.1310329122614459], 
           Hue[0.6336600539028828, 1, 0.1226245407498546], 
           Hue[0.6406195765724375, 1, 0.11298827859200967`], 
           Hue[0.6429908696471925, 1, 0.10970494971927194`], 
           Hue[0.6453879602649129, 1, 0.10638590117165914`], 
           Hue[0.6447135116824265, 1, 0.10731975305510176`], 
           Hue[0.6461108778787858, 1, 0.10538493832168114`], 
           Hue[0.6471342337346244, 1, 0.1039679840597509], 
           Hue[0.6483163987955415, 1, 0.10233114012925029`], 
           Hue[0.6495193091275061, 1, 0.10066557197729935`], 
           Hue[0.6497261232417286, 1, 0.10037921397299124`], 
           Hue[0.6499353113077606, 1, 0.10008956895848536`], 
           Hue[0.6498869310750488, 1, 0.10015655697300946`], 
           Hue[0.6499792798726709, 1, 0.10002868940707106`], 
           Hue[0.6499630030101804, 1, 0.10005122660128868`], 
           Hue[0.6499904847358855, 1, 0.10001317498108164`], 
           Hue[0.6499648695962024, 1, 0.10004864209756599`], 
           Hue[0.6498468322258637, 1, 0.10021207845649638`], 
           Hue[0.6439515530903862, 1, 0.1083747726440807], 
           Hue[0.6443971876863692, 1, 0.10775774012656568`], 
           Hue[0.6416150548927391, 1, 0.11160992399466907`], 
           Hue[0.6419793946935369, 1, 0.11110545350125665`], 
           Hue[0.6361335930405146, 1, 0.11919964040544136`], 
           Hue[0.6361335930405176, 1, 0.1191996404054371], 
           Hue[0.623696762682929, 1, 0.1364198670544061], 
           Hue[0.621035954087277, 1, 0.14010406357146268`], 
           Hue[0.6025635060503066, 1, 0.1656812993149601], 
           Hue[0.591356231466683, 1, 0.18119906412305425`], 
           Hue[0.5511449764429753, 1, 0.23687618646357272`], 
           Hue[0.55917054482559, 1, 0.22576386101072146`], 
           Hue[0.568122959888174, 1, 0.21336820938560533`], 
           Hue[0.5901231464870408, 1, 0.18290641255640516`], 
           Hue[0.6140905734391747, 1, 0.14972074446883504`], 
           Hue[0.6310228082209636, 1, 0.12627611169405048`], 
           Hue[0.6429908696471691, 1, 0.1097049497193044], 
           Hue[0.6406195765724637, 1, 0.11298827859197333`], 
           Hue[0.6443985210226438, 1, 0.10775589396864699`], 
           Hue[0.6460011934807279, 1, 0.10553680902668437`], 
           Hue[0.6476433233638594, 1, 0.10326309072696392`], 
           Hue[0.6491676275232406, 1, 0.10115251573705152`], 
           Hue[0.6494692059492381, 1, 0.1007349456087473], 
           Hue[0.6498302874016711, 1, 0.10023498667460914`], 
           Hue[0.6497727314760292, 1, 0.10031467949472883`], 
           Hue[0.6499628521968075, 1, 0.1000514354198051], 
           Hue[0.6499433111349449, 1, 0.10007849227469183`], 
           Hue[0.6499904256749581, 1, 0.10001325675775032`], 
           Hue[0.649997032693306, 1, 0.10000410857849946`], 
           Hue[0.6499892896045865, 1, 0.10001482977826487`], 
           Hue[0.6427201663461, 1, 0.11007976967463086`], 
           Hue[0.6438587986191934, 1, 0.1085032019118861], 
           Hue[0.6370814322963932, 1, 0.11788724758960933`], 
           Hue[0.6387923231016436, 1, 0.11551832185926283`], 
           Hue[0.6210359540872956, 1, 0.14010406357143684`], 
           Hue[0.6236967626829744, 1, 0.1364198670543432], 
           Hue[0.5848239391333233, 1, 0.19024377658462932`], 
           Hue[0.5848239391333415, 1, 0.19024377658460404`], 
           Hue[0.5284611999947693, 1, 0.2682844923149349], 
           Hue[0.5155200401453298, 1, 0.2862030213372357], 
           Hue[0.4280417126309771, 1, 0.4073268594340317], 
           Hue[0.44738231990342936`, 1, 0.3805475570567901], 
           Hue[0.49782834784076413`, 1, 0.31069921068201894`], 
           Hue[0.5584448138850497, 1, 0.22676871923608494`], 
           Hue[0.631022808221062, 1, 0.12627611169391412`], 
           Hue[0.6140905734395959, 1, 0.14972074446825182`], 
           Hue[0.6387961530918295, 1, 0.11551301879592843`], 
           Hue[0.6438600147950412, 1, 0.10850151797609685`], 
           Hue[0.646582271726557, 1, 0.1047322391478442], 
           Hue[0.6488022469143883, 1, 0.10165842734930862`], 
           Hue[0.6492111455095844, 1, 0.10109226006365249`], 
           Hue[0.649715871836524, 1, 0.10039340822635136`], 
           Hue[0.6496559963280025, 1, 0.10047631277661184`], 
           Hue[0.6499231631029164, 1, 0.10010638954980812`], 
           Hue[0.6499029637901635, 1, 0.10013435782900432`], 
           Hue[0.6499852021769049, 1, 0.10002048929351635`], 
           Hue[0.6499797258816095, 1, 0.10002807185623301`], 
           Hue[0.6499970064878591, 1, 0.10000414486296437`], 
           Hue[0.6499997344623704, 1, 0.10000036766748721`], 
           Hue[0.6410125786951287, 1, 0.11244412180674491`], 
           Hue[0.6434731972962738, 1, 0.10903711143592851`], 
           Hue[0.6282683067129132, 1, 0.13009003685904325`], 
           Hue[0.633656641084807, 1, 0.12262926619026732`], 
           Hue[0.591356231466732, 1, 0.18119906412298648`], 
           Hue[0.6025635060503691, 1, 0.16568129931487363`], 
           Hue[0.5155200401453158, 1, 0.28620302133725506`], 
           Hue[0.5284611999947402, 1, 0.26828449231497525`], 
           Hue[0.28735888634961493`, 1, 0.6021184650543793], 
           Hue[0.26072995684233446`, 1, 0.6389892905259984], 
           Hue[0.2873725448605462, 1, 0.602099553270013], 
           Hue[0.3624655433976934, 1, 0.4981246322185784], 
           Hue[0.5584448138855233, 1, 0.22676871923542932`], 
           Hue[0.4978283478418999, 1, 0.3106992106804463], 
           Hue[0.5901231464879024, 1, 0.18290641255521203`], 
           Hue[0.6336600539032805, 1, 0.12262454074930401`], 
           Hue[0.6434736200022606, 1, 0.10903652615071605`], 
           Hue[0.6483053260376065, 1, 0.10234647164023727`], 
           Hue[0.6488831338517029, 1, 0.10154643005148822`], 
           Hue[0.6495884346066901, 1, 0.1005698597753521], 
           Hue[0.6495085615470396, 1, 0.10068045324256061`], 
           Hue[0.6498815309986413, 1, 0.10016403400188124`], 
           Hue[0.6498573946453183, 1, 0.10019745356802079`], 
           Hue[0.6499741382710061, 1, 0.1000358085478377], 
           Hue[0.649968151589994, 1, 0.10004409779846989`], 
           Hue[0.6499958569645508, 1, 0.10000573651062203`], 
           Hue[0.6499946619760952, 1, 0.10000739111002195`], 
           Hue[0.6499993483460993, 1, 0.10000090229001643`], 
           Hue[0.6499999234519708, 1, 0.10000010598957898`], 
           Hue[0.6489846669012489, 1, 0.10140584582904005`], 
           Hue[0.6473523532851375, 1, 0.10366597237442497`], 
           Hue[0.6388740031493075, 1, 0.1154052264086511], 
           Hue[0.6155545287377708, 1, 0.14769372944000964`], 
           Hue[0.5511449764429537, 1, 0.2368761864636027], 
           Hue[0.2335219919339223, 1, 0.6766618573222615], 
           Hue[0.1499765696284696, 1, 0.7923401343605806], 
           Hue[0.14997656962768036`, 1, 0.7923401343616734], 
           Hue[0.12170305563956019`, 1, 0.8314880768067628], 
           Hue[0.06372301272420777, 1, 0.91176813622802], 
           Hue[0.15000883322846736`, 1, 0.7922954616836606], 
           Hue[0.2335584141616424, 1, 0.6766114265454182], 
           Hue[0.06375799796092974, 1, 0.9117196951310205], 
           Hue[0.1500088332269906, 1, 0.7922954616857053], 
           Hue[0.36246554339828446`, 1, 0.49812463221775993`], 
           Hue[0.28737254486065156`, 1, 0.6020995532698671], 
           Hue[0.44738231990483157`, 1, 0.38054755705484866`], 
           Hue[0.5681229598892839, 1, 0.21336820938406859`], 
           Hue[0.6250352667028372, 1, 0.13456655379607163`], 
           Hue[0.6431577560124171, 1, 0.10947387629049946`], 
           Hue[0.6473513706734314, 1, 0.10366733291371037`], 
           Hue[0.6483330201390716, 1, 0.10230812596128551`], 
           Hue[0.649407398206408, 1, 0.10082052556035821`], 
           Hue[0.6492559152561338, 1, 0.1010302711838148], 
           Hue[0.6498288936986976, 1, 0.10023691641718807`], 
           Hue[0.649791679468696, 1, 0.1002884438125748], 
           Hue[0.6499613986682435, 1, 0.10005344799781668`], 
           Hue[0.6499533005675091, 1, 0.10006466075267974`], 
           Hue[0.6499933666375028, 1, 0.10000918465576536`], 
           Hue[0.649991888260414, 1, 0.10001123163942686`], 
           Hue[0.6499991515859967, 1, 0.10000117472708145`], 
           Hue[0.6499989347644688, 1, 0.10000147494150481`], 
           Hue[0.6499999222917153, 1, 0.10000010759608655`], 
           Hue[0.6499998974223291, 1, 0.10000014203062124`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999917956835, 1, 0.10000001135982291`], 
           Hue[0.6499995706076633, 1, 0.10000059454323541`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499962490896035, 1, 0.10000519356824139`], 
           Hue[0.6499751193911047, 1, 0.10003445007385507`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6498709896006902, 1, 0.10017862978365968`], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.6494589962075485, 1, 0.10074908217416359`], 
           Hue[0.6499289484739933, 1, 0.10009837903600931`], 
           Hue[0.6480476331533758, 1, 0.10270327717224897`], 
           Hue[0.6496234965987948, 1, 0.10052131240166877`], 
           Hue[0.28735888634874723`, 1, 0.6021184650555808], 
           Hue[0.2607299568411386, 1, 0.6389892905276543], 
           Hue[0.10026584227806645`, 1, 0.8611703722303696], 
           Hue[0.12170305563831785`, 1, 0.8314880768084829], 
           Hue[0.03305932787493082, 1, 0.9542255460193266], 
           Hue[0.03305932787447774, 1, 0.9542255460199538], 
           Hue[0.04091504616611452, 1, 0.9433483976161491], 
           Hue[0.008564162898874406, 1, 0.9881419282938663], 
           Hue[0.1003038852266922, 1, 0.8611176973784263], 
           Hue[0.03305932787175336, 1, 0.9542255460237261], 
           Hue[0.12170305563598427`, 1, 0.831488076811714], 
           Hue[0.26072995684171757`, 1, 0.6389892905268526], 
           Hue[0.4280417126324545, 1, 0.4073268594319861], 
           Hue[0.5591705448267148, 1, 0.2257638610091642], 
           Hue[0.6480467041528128, 1, 0.10270456348072075`], 
           Hue[0.6489583372556369, 1, 0.10144230226142584`], 
           Hue[0.6497289407484016, 1, 0.10037531280990554`], 
           Hue[0.649623496598795, 1, 0.10052131240166845`], 
           Hue[0.6499414626511464, 1, 0.10008105171379728`], 
           Hue[0.6499289484739933, 1, 0.1000983790360093], 
           Hue[0.6499899581044661, 1, 0.10001390416304694`], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.649998672028374, 1, 0.10000183872994367`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499998686930739, 1, 0.10000018180959001`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499999916279817, 1, 0.10000001159202533`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499999878784672, 1, 0.1000000167836607], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499998205406813, 1, 0.10000024848213372`], 
           Hue[0.6499981815209614, 1, 0.10000251789405334`], 
           Hue[0.6499859604962616, 1, 0.10001943931286872`], 
           Hue[0.6499147887623508, 1, 0.10011798479059132`], 
           Hue[0.649581920490294, 1, 0.10057887932113145`], 
           Hue[0.5591705448254737, 1, 0.22576386101088267`], 
           Hue[0.568122959888075, 1, 0.21336820938574236`], 
           Hue[0.4280417126304372, 1, 0.4073268594347793], 
           Hue[0.44738231990300226`, 1, 0.3805475570573815], 
           Hue[0.2873725448596086, 1, 0.6020995532713111], 
           Hue[0.15000883322750808`, 1, 0.7922954616849889], 
           Hue[0.008564162898749728, 1, 0.9881419282940389], 
           Hue[0.0637579979606423, 1, 0.9117196951314183], 
           Hue[0.00856416289715567, 1, 0.988141928296246], 
           Hue[0.0330593278718706, 1, 0.9542255460235638], 
           Hue[0.0637230127197419, 1, 0.9117681362342035], 
           Hue[0.14997656962507233`, 1, 0.7923401343652845], 
           Hue[0.28735888634955103`, 1, 0.6021184650544679], 
           Hue[0.649458996207529, 1, 0.10074908217419068`], 
           Hue[0.6498709896006885, 1, 0.10017862978366218`], 
           Hue[0.6499751193911046, 1, 0.10003445007385516`], 
           Hue[0.6499962490896035, 1, 0.10000519356824138`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499995706076633, 1, 0.10000059454323541`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499999880630696, 1, 0.10000001652805754`], 
           Hue[0.6499998686930739, 1, 0.10000018180959001`], 
           Hue[0.6499998974223291, 1, 0.10000014203062124`], 
           Hue[0.6499999916279817, 1, 0.10000001159202533`], 
           Hue[0.649998672028374, 1, 0.10000183872994367`], 
           Hue[0.6499989347644688, 1, 0.1000014749415048], 
           Hue[0.6499899581044661, 1, 0.10001390416304694`], 
           Hue[0.649991888260414, 1, 0.10001123163942685`], 
           Hue[0.649941462651146, 1, 0.10008105171379782`], 
           Hue[0.6499533005675091, 1, 0.10006466075267968`], 
           Hue[0.6497289407483949, 1, 0.10037531280991473`], 
           Hue[0.6497916794686949, 1, 0.10028844381257641`], 
           Hue[0.6480467041527056, 1, 0.10270456348086918`], 
           Hue[0.6492559152561154, 1, 0.10103027118384024`], 
           Hue[0.6431577560121026, 1, 0.10947387629093487`], 
           Hue[0.6432314603305186, 1, 0.10937182415774356`], 
           Hue[0.6250352667022085, 1, 0.13456655379694196`], 
           Hue[0.6275873411445028, 1, 0.1310329122614577], 
           Hue[0.5901231464869925, 1, 0.18290641255647203`], 
           Hue[0.4978283478405595, 1, 0.3106992106823023], 
           Hue[0.3624655433972453, 1, 0.4981246322191988], 
           Hue[0.1003038852272069, 1, 0.8611176973777135], 
           Hue[0.23355841416119505`, 1, 0.6766114265460376], 
           Hue[0.040915046164483715`, 1, 0.9433483976184072], 
           Hue[0.15000883322690067`, 1, 0.7922954616858299], 
           Hue[0.040893852336497005`, 1, 0.9433777429186965], 
           Hue[0.10026584227413049`, 1, 0.8611703722358194], 
           Hue[0.14997656962515238`, 1, 0.7923401343651736], 
           Hue[0.23352199193288742`, 1, 0.6766618573236943], 
           Hue[0.6480476331532764, 1, 0.10270327717238656`], 
           Hue[0.6489591993613006, 1, 0.10144110857666067`], 
           Hue[0.6497294663699528, 1, 0.10037458502621935`], 
           Hue[0.6499416771509483, 1, 0.10008075471407167`], 
           Hue[0.6499900187740281, 1, 0.10001382015903812`], 
           Hue[0.6499999917956835, 1, 0.10000001135982291`], 
           Hue[0.6499991515859967, 1, 0.10000117472708145`], 
           Hue[0.6499993483460993, 1, 0.10000090229001642`], 
           Hue[0.6499999222917153, 1, 0.10000010759608655`], 
           Hue[0.6499933666375028, 1, 0.10000918465576535`], 
           Hue[0.6499946619760952, 1, 0.10000739111002195`], 
           Hue[0.6499613986682437, 1, 0.10005344799781657`], 
           Hue[0.649968151589994, 1, 0.10004409779846984`], 
           Hue[0.649828893698698, 1, 0.10023691641718745`], 
           Hue[0.6498573946453188, 1, 0.10019745356802023`], 
           Hue[0.6494073982064067, 1, 0.10082052556035996`], 
           Hue[0.6495085615470421, 1, 0.1006804532425571], 
           Hue[0.6473513706733505, 1, 0.1036673329138225], 
           Hue[0.6434736200020821, 1, 0.10903652615096326`], 
           Hue[0.633660053902879, 1, 0.12262454074985986`], 
           Hue[0.6140905734391554, 1, 0.14972074446886185`], 
           Hue[0.5584448138849759, 1, 0.2267687192361872], 
           Hue[0.18507857487504847`, 1, 0.7437373578653175], 
           Hue[0.12170305563612982`, 1, 0.8314880768115126], 
           Hue[0.1287910267796043, 1, 0.821673962920548], 
           Hue[0.18504088594804108`, 1, 0.7437895425334816], 
           Hue[0.5511449764442349, 1, 0.23687618646182867`], 
           Hue[0.5284611999960993, 1, 0.26828449231309326`], 
           Hue[0.6155545287379652, 1, 0.14769372943974055`], 
           Hue[0.6025635060508471, 1, 0.16568129931421172`], 
           Hue[0.6388740031490734, 1, 0.1154052264089754], 
           Hue[0.6336566410847063, 1, 0.12262926619040662`], 
           Hue[0.6434731972961383, 1, 0.10903711143611633`], 
           Hue[0.6473523532850615, 1, 0.10366597237453028`], 
           Hue[0.6489846669012399, 1, 0.10140584582905249`], 
           Hue[0.6499997344623704, 1, 0.10000036766748721`], 
           Hue[0.6499993557516623, 1, 0.10000089203615993`], 
           Hue[0.6499958569645508, 1, 0.10000573651062201`], 
           Hue[0.6499970064878591, 1, 0.10000414486296436`], 
           Hue[0.6499741382710061, 1, 0.10003580854783768`], 
           Hue[0.6499797258816096, 1, 0.100028071856233], 
           Hue[0.6498815309986415, 1, 0.10016403400188102`], 
           Hue[0.6499029637901637, 1, 0.10013435782900423`], 
           Hue[0.6495884346066918, 1, 0.1005698597753498], 
           Hue[0.6496559963280032, 1, 0.10047631277661098`], 
           Hue[0.6483053260376217, 1, 0.10234647164021617`], 
           Hue[0.6465822717265689, 1, 0.10473223914782774`], 
           Hue[0.6462861242777479, 1, 0.1051422894615798], 
           Hue[0.6438600147950487, 1, 0.10850151797608636`], 
           Hue[0.6406195765724355, 1, 0.1129882785920124], 
           Hue[0.6310228082209484, 1, 0.12627611169407155`], 
           Hue[0.3624655433981332, 1, 0.49812463221796943`], 
           Hue[0.2873725448606186, 1, 0.6020995532699127], 
           Hue[0.26072995684176997`, 1, 0.6389892905267801], 
           Hue[0.2873588863495887, 1, 0.6021184650544156], 
           Hue[0.5155200401465881, 1, 0.28620302133549336`], 
           Hue[0.5155200401465878, 1, 0.2862030213354939], 
           Hue[0.5913562314673553, 1, 0.1811990641221235], 
           Hue[0.584823939133998, 1, 0.19024377658369515`], 
           Hue[0.6282683067129716, 1, 0.1300900368589624], 
           Hue[0.6236967626831381, 1, 0.13641986705411643`], 
           Hue[0.6410125786950517, 1, 0.11244412180685161`], 
           Hue[0.6387923231016319, 1, 0.1155183218592789], 
           Hue[0.6438587986192152, 1, 0.1085032019118559], 
           Hue[0.6499892896045865, 1, 0.10001482977826487`], 
           Hue[0.6499648695962024, 1, 0.10004864209756596`], 
           Hue[0.649997032693306, 1, 0.10000410857849946`], 
           Hue[0.6499852021769049, 1, 0.10002048929351634`], 
           Hue[0.6499904256749581, 1, 0.10001325675775032`], 
           Hue[0.6499231631029164, 1, 0.10010638954980809`], 
           Hue[0.6499433111349449, 1, 0.10007849227469179`], 
           Hue[0.6497158718365242, 1, 0.1003934082263511], 
           Hue[0.6497727314760293, 1, 0.10031467949472872`], 
           Hue[0.6488022469143931, 1, 0.10165842734930183`], 
           Hue[0.6476433233638824, 1, 0.10326309072693211`], 
           Hue[0.6473931627551947, 1, 0.1036094669543459], 
           Hue[0.6460011934807786, 1, 0.10553680902661441`], 
           Hue[0.6447135116824785, 1, 0.1073197530550298], 
           Hue[0.6429908696471961, 1, 0.10970494971926699`], 
           Hue[0.5584448138854339, 1, 0.22676871923555317`], 
           Hue[0.4978283478418154, 1, 0.3106992106805634], 
           Hue[0.4473823199047938, 1, 0.38054755705490095`], 
           Hue[0.4280417126324526, 1, 0.40732685943198865`], 
           Hue[0.528461199996099, 1, 0.26828449231309376`], 
           Hue[0.5511449764442337, 1, 0.2368761864618304], 
           Hue[0.5848239391339978, 1, 0.1902437765836954], 
           Hue[0.5913562314673545, 1, 0.18119906412212453`], 
           Hue[0.6210359540875073, 1, 0.1401040635711437], 
           Hue[0.6210359540875072, 1, 0.1401040635711439], 
           Hue[0.6370814322964223, 1, 0.11788724758956906`], 
           Hue[0.636133593040564, 1, 0.11919964040537295`], 
           Hue[0.6427201663461387, 1, 0.11007976967457717`], 
           Hue[0.641979394693572, 1, 0.11110545350120805`], 
           Hue[0.6443971876864337, 1, 0.10775774012647635`], 
           Hue[0.6498468322258638, 1, 0.10021207845649628`], 
           Hue[0.6496872006198552, 1, 0.10043310683404671`], 
           Hue[0.6499435436197024, 1, 0.10007817037271977`], 
           Hue[0.6499904847358855, 1, 0.10001317498108163`], 
           Hue[0.6499628521968075, 1, 0.10005143541980507`], 
           Hue[0.6499792798726709, 1, 0.10002868940707105`], 
           Hue[0.6498302874016713, 1, 0.10023498667460905`], 
           Hue[0.6498869310750488, 1, 0.10015655697300938`], 
           Hue[0.649167627523241, 1, 0.10115251573705095`], 
           Hue[0.6483163987955443, 1, 0.10233114012924638`], 
           Hue[0.6480161564309218, 1, 0.10274686032641599`], 
           Hue[0.6471342337346329, 1, 0.10396798405973914`], 
           Hue[0.6462658582790939, 1, 0.10517035007510085`], 
           Hue[0.6453879602649326, 1, 0.10638590117163177`], 
           Hue[0.6310228082210256, 1, 0.12627611169396455`], 
           Hue[0.6140905734395123, 1, 0.14972074446836753`], 
           Hue[0.5901231464878142, 1, 0.18290641255533424`], 
           Hue[0.5681229598892343, 1, 0.21336820938413703`], 
           Hue[0.5591705448266987, 1, 0.22576386100918644`], 
           Hue[0.602563506050846, 1, 0.1656812993142133], 
           Hue[0.6155545287379638, 1, 0.14769372943974254`], 
           Hue[0.6236967626831377, 1, 0.13641986705411707`], 
           Hue[0.628268306712971, 1, 0.13009003685896328`], 
           Hue[0.6361335930405639, 1, 0.11919964040537312`], 
           Hue[0.6370814322964221, 1, 0.11788724758956945`], 
           Hue[0.6416150548927615, 1, 0.11160992399463798`], 
           Hue[0.6416150548927614, 1, 0.11160992399463811`], 
           Hue[0.6439515530904331, 1, 0.10837477264401578`], 
           Hue[0.643757346457027, 1, 0.10864367413642426`], 
           Hue[0.6450459043341169, 1, 0.10685951707583816`], 
           Hue[0.6495197235700738, 1, 0.10066499813374392`], 
           Hue[0.6499630030101804, 1, 0.10005122660128865`], 
           Hue[0.6498595392714197, 1, 0.10019448408572659`], 
           Hue[0.6499793572109922, 1, 0.10002858232324165`], 
           Hue[0.6499353113077606, 1, 0.1000895689584853], 
           Hue[0.6495193091275062, 1, 0.10066557197729913`], 
           Hue[0.6479796182166929, 1, 0.10279745169996372`], 
           Hue[0.6472841430793682, 1, 0.10376041727472092`], 
           Hue[0.6466661863103496, 1, 0.10461604972413144`], 
           Hue[0.6429908696472039, 1, 0.10970494971925615`], 
           Hue[0.6406195765724956, 1, 0.11298827859192927`], 
           Hue[0.6387961530918427, 1, 0.11551301879591018`], 
           Hue[0.6336600539032469, 1, 0.12262454074935054`], 
           Hue[0.6250352667028026, 1, 0.13456655379611943`], 
           Hue[0.6336566410847058, 1, 0.12262926619040751`], 
           Hue[0.6388740031490726, 1, 0.11540522640897635`], 
           Hue[0.6387923231016316, 1, 0.11551832185927938`], 
           Hue[0.6410125786950513, 1, 0.11244412180685208`], 
           Hue[0.6419793946935718, 1, 0.11110545350120836`], 
           Hue[0.6427201663461385, 1, 0.1100797696745775], 
           Hue[0.6437573464570269, 1, 0.10864367413642435`], 
           Hue[0.643951553090433, 1, 0.10837477264401599`], 
           Hue[0.644907814325618, 1, 0.10705071862606744`], 
           Hue[0.644907814325618, 1, 0.10705071862606746`], 
           Hue[0.6494292804404584, 1, 0.10079022708244216`], 
           Hue[0.6498246858302775, 1, 0.10024274269653886`], 
           Hue[0.6499660352996491, 1, 0.10004702804663972`], 
           Hue[0.6499660027761931, 1, 0.10004707307911731`], 
           Hue[0.6487517211908195, 1, 0.10172838604348083`], 
           Hue[0.6488011994693257, 1, 0.10165987765785672`], 
           Hue[0.6481284893528519, 1, 0.10259132243451279`], 
           Hue[0.6475809298216183, 1, 0.10334948178545168`], 
           Hue[0.6453879602649328, 1, 0.10638590117163146`], 
           Hue[0.6447135116824834, 1, 0.10731975305502306`], 
           Hue[0.6443985210227201, 1, 0.10775589396854145`], 
           Hue[0.6438600147951252, 1, 0.10850151797598054`], 
           Hue[0.6434736200023033, 1, 0.10903652615065697`], 
           Hue[0.6431577560124131, 1, 0.10947387629050494`], 
           Hue[0.6434731972961379, 1, 0.10903711143611679`], 
           Hue[0.643858798619215, 1, 0.10850320191185622`], 
           Hue[0.6443971876864336, 1, 0.1077577401264766], 
           Hue[0.6450459043341169, 1, 0.10685951707583821`], 
           Hue[0.6499875752276579, 1, 0.10001720353093521`], 
           Hue[0.6499660613044453, 1, 0.10004699203999874`], 
           Hue[0.6499690957937134, 1, 0.1000427904394738], 
           Hue[0.6499875583936996, 1, 0.10001722683949292`], 
           Hue[0.6498258485023254, 1, 0.10024113284293407`], 
           Hue[0.6498634903348335, 1, 0.10018901338253833`], 
           Hue[0.6494394618677293, 1, 0.1007761297216056], 
           Hue[0.6495474566380964, 1, 0.10062659850109733`], 
           Hue[0.6489976573214438, 1, 0.10138785909338563`], 
           Hue[0.6483958281620502, 1, 0.10222116100639206`], 
           Hue[0.6466661863103496, 1, 0.10461604972413144`], 
           Hue[0.6462658582790938, 1, 0.1051703500751009], 
           Hue[0.64611087787881, 1, 0.1053849383216477], 
           Hue[0.6460011934807838, 1, 0.10553680902660717`], 
           Hue[0.6465822717266224, 1, 0.10473223914775362`], 
           Hue[0.6473513706734652, 1, 0.1036673329136637], 
           Hue[0.6483330201390971, 1, 0.10230812596125023`], 
           Hue[0.6480467041528214, 1, 0.10270456348070894`], 
           Hue[0.6489583372556444, 1, 0.10144230226141537`], 
           Hue[0.6480476331532762, 1, 0.10270327717238693`], 
           Hue[0.649458996207529, 1, 0.10074908217419068`], 
           Hue[0.6473523532850612, 1, 0.10366597237453057`], 
           Hue[0.6489846669012398, 1, 0.10140584582905257`], 
           Hue[0.6499660419264217, 1, 0.10004701887110846`], 
           Hue[0.6499798735525514, 1, 0.100027867388775], 
           Hue[0.6498926261234819, 1, 0.10014867152133292`], 
           Hue[0.6497265096835254, 1, 0.10037867889973415`], 
           Hue[0.64933320164324, 1, 0.10092325926320618`], 
           Hue[0.6475809298216183, 1, 0.10334948178545166`], 
           Hue[0.6472841430793682, 1, 0.1037604172747209], 
           Hue[0.6471786129927874, 1, 0.10390653585614049`], 
           Hue[0.6471342337346329, 1, 0.1039679840597392], 
           Hue[0.6476433233638853, 1, 0.10326309072692814`], 
           Hue[0.6483053260376332, 1, 0.10234647164020018`], 
           Hue[0.6488831338517164, 1, 0.10154643005146977`], 
           Hue[0.6492559152561433, 1, 0.10103027118380156`], 
           Hue[0.649407398206416, 1, 0.10082052556034711`], 
           Hue[0.6496234965987958, 1, 0.10052131240166731`], 
           Hue[0.6497289407484043, 1, 0.10037531280990179`], 
           Hue[0.6495822971313279, 1, 0.10057835781816142`], 
           Hue[0.6498709896006885, 1, 0.10017862978366215`], 
           Hue[0.6497372360371154, 1, 0.1003638270255325], 
           Hue[0.6499365186637519, 1, 0.10008789723480506`], 
           Hue[0.6498923240356159, 1, 0.1001490897968396], 
           Hue[0.6499797890669986, 1, 0.10002798436877125`], 
           Hue[0.6499912329900899, 1, 0.10001213893679865`], 
           Hue[0.6499711016483095, 1, 0.10004001310234077`], 
           Hue[0.6498842956213006, 1, 0.10016020606281464`], 
           Hue[0.6483958281620502, 1, 0.10222116100639209`], 
           Hue[0.6481284893528518, 1, 0.10259132243451285`], 
           Hue[0.6479796182166928, 1, 0.10279745169996383`], 
           Hue[0.6480161564309217, 1, 0.10274686032641614`], 
           Hue[0.6483163987955443, 1, 0.10233114012924639`], 
           Hue[0.6488022469143936, 1, 0.10165842734930128`], 
           Hue[0.6492111455095863, 1, 0.10109226006364978`], 
           Hue[0.6495085615470444, 1, 0.10068045324255397`], 
           Hue[0.6495884346066922, 1, 0.10056985977534917`], 
           Hue[0.6497916794686982, 1, 0.10028844381257172`], 
           Hue[0.6498288936986989, 1, 0.10023691641718625`], 
           Hue[0.6499289484739935, 1, 0.10009837903600897`], 
           Hue[0.6499414626511469, 1, 0.10008105171379662`], 
           Hue[0.6499149607103801, 1, 0.10011774670870442`], 
           Hue[0.6499751193911046, 1, 0.10003445007385514`], 
           Hue[0.6495530687696347, 1, 0.10061882785742893`], 
           Hue[0.6495129010015268, 1, 0.10067444476711676`], 
           Hue[0.6498470503888287, 1, 0.10021177638469878`], 
           Hue[0.6498131704790806, 1, 0.10025868702896529`], 
           Hue[0.6499650867010297, 1, 0.10004834149088199`], 
           Hue[0.6499501069360999, 1, 0.10006908270386165`], 
           Hue[0.649991166860452, 1, 0.10001223050091258`], 
           Hue[0.6499989171085051, 1, 0.10000149938822367`], 
           Hue[0.64933320164324, 1, 0.10092325926320615`], 
           Hue[0.6489976573214437, 1, 0.10138785909338567`], 
           Hue[0.6488011994693256, 1, 0.10165987765785689`], 
           Hue[0.6487517211908193, 1, 0.1017283860434811], 
           Hue[0.649167627523241, 1, 0.10115251573705104`], 
           Hue[0.6494692059492382, 1, 0.10073494560874716`], 
           Hue[0.6496559963280033, 1, 0.10047631277661086`], 
           Hue[0.6497158718365242, 1, 0.1003934082263511], 
           Hue[0.6498573946453189, 1, 0.10019745356801998`], 
           Hue[0.6498815309986415, 1, 0.10016403400188097`], 
           Hue[0.6499533005675093, 1, 0.10006466075267935`], 
           Hue[0.6499613986682437, 1, 0.1000534479978165], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6499899581044661, 1, 0.10001390416304687`], 
           Hue[0.6499860137071367, 1, 0.10001936563627234`], 
           Hue[0.6499962490896035, 1, 0.10000519356824138`], 
           Hue[0.6495129010015268, 1, 0.10067444476711679`], 
           Hue[0.6495530687696347, 1, 0.10061882785742898`], 
           Hue[0.6497964648039245, 1, 0.10028181796379694`], 
           Hue[0.6497964648039245, 1, 0.10028181796379694`], 
           Hue[0.6499391582420061, 1, 0.10008424243414549`], 
           Hue[0.6499339441898728, 1, 0.10009146189094534`], 
           Hue[0.6499873787655159, 1, 0.10001747555543954`], 
           Hue[0.6499846921337001, 1, 0.10002119550718444`], 
           Hue[0.6499975387906934, 1, 0.10000340782827066`], 
           Hue[0.6498842956213006, 1, 0.10016020606281462`], 
           Hue[0.6497265096835254, 1, 0.1003786788997341], 
           Hue[0.6495474566380964, 1, 0.10062659850109733`], 
           Hue[0.6494394618677292, 1, 0.10077612972160574`], 
           Hue[0.6495193091275061, 1, 0.10066557197729935`], 
           Hue[0.6497261232417286, 1, 0.10037921397299124`], 
           Hue[0.6497727314760292, 1, 0.10031467949472878`], 
           Hue[0.6498302874016713, 1, 0.10023498667460914`], 
           Hue[0.6499029637901637, 1, 0.10013435782900423`], 
           Hue[0.6499231631029164, 1, 0.1001063895498081], 
           Hue[0.649968151589994, 1, 0.10004409779846982`], 
           Hue[0.6499741382710061, 1, 0.10003580854783767`], 
           Hue[0.649991888260414, 1, 0.10001123163942684`], 
           Hue[0.6499933666375028, 1, 0.10000918465576535`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.649998672028374, 1, 0.10000183872994367`], 
           Hue[0.6499981929645616, 1, 0.10000250204906862`], 
           Hue[0.6498468322258638, 1, 0.10021207845649625`], 
           Hue[0.6496872006198552, 1, 0.10043310683404669`], 
           Hue[0.6495197235700738, 1, 0.10066499813374391`], 
           Hue[0.6494292804404584, 1, 0.10079022708244217`], 
           Hue[0.6497372360371154, 1, 0.10036382702553254`], 
           Hue[0.6498131704790806, 1, 0.10025868702896532`], 
           Hue[0.6498470503888286, 1, 0.1002117763846988], 
           Hue[0.6499339441898728, 1, 0.10009146189094535`], 
           Hue[0.6499391582420061, 1, 0.1000842424341455], 
           Hue[0.6499834669215924, 1, 0.10002289195471836`], 
           Hue[0.6499834669215924, 1, 0.10002289195471836`], 
           Hue[0.6499970370468677, 1, 0.10000410255049084`], 
           Hue[0.6499968197541345, 1, 0.10000440341735237`], 
           Hue[0.6499995605902448, 1, 0.10000060841350733`], 
           Hue[0.6499998438351633, 1, 0.10000021622823552`], 
           Hue[0.6499711016483095, 1, 0.10004001310234076`], 
           Hue[0.6499503668772793, 1, 0.10006872278530574`], 
           Hue[0.6498634903348335, 1, 0.10018901338253831`], 
           Hue[0.6498258485023254, 1, 0.10024113284293411`], 
           Hue[0.6498869310750488, 1, 0.10015655697300946`], 
           Hue[0.6499353113077606, 1, 0.10008956895848536`], 
           Hue[0.6499433111349449, 1, 0.10007849227469183`], 
           Hue[0.6499628521968075, 1, 0.1000514354198051], 
           Hue[0.6499797258816096, 1, 0.10002807185623301`], 
           Hue[0.6499852021769049, 1, 0.10002048929351635`], 
           Hue[0.6499946619760952, 1, 0.10000739111002195`], 
           Hue[0.6499958569645508, 1, 0.10000573651062203`], 
           Hue[0.6499989347644688, 1, 0.1000014749415048], 
           Hue[0.6499991515859967, 1, 0.10000117472708145`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499998686930739, 1, 0.10000018180959001`], 
           Hue[0.6499995706076633, 1, 0.10000059454323541`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499892896045865, 1, 0.10001482977826487`], 
           Hue[0.6499648695962024, 1, 0.10004864209756596`], 
           Hue[0.6499435436197024, 1, 0.10007817037271975`], 
           Hue[0.6498595392714197, 1, 0.10019448408572659`], 
           Hue[0.6499630030101805, 1, 0.10005122660128864`], 
           Hue[0.6498246858302775, 1, 0.10024274269653886`], 
           Hue[0.6498923240356158, 1, 0.10014908979683962`], 
           Hue[0.6499365186637519, 1, 0.10008789723480506`], 
           Hue[0.6499501069360999, 1, 0.10006908270386165`], 
           Hue[0.6499650867010297, 1, 0.10004834149088199`], 
           Hue[0.6499846921337001, 1, 0.10002119550718444`], 
           Hue[0.6499873787655159, 1, 0.10001747555543954`], 
           Hue[0.6499968197541345, 1, 0.10000440341735237`], 
           Hue[0.6499970370468677, 1, 0.10000410255049084`], 
           Hue[0.6499995314220489, 1, 0.10000064880024004`], 
           Hue[0.6499995314220489, 1, 0.10000064880024004`], 
           Hue[0.6499999509486679, 1, 0.10000006791722911`], 
           Hue[0.6499999480469419, 1, 0.10000007193500345`], 
           Hue[0.6499999966971565, 1, 0.10000000457316796`], 
           Hue[0.6499999966971565, 1, 0.10000000457316796`], 
           Hue[0.6499998438351633, 1, 0.10000021622823552`], 
           Hue[0.6499989171085051, 1, 0.10000149938822367`], 
           Hue[0.6499975662514333, 1, 0.10000336980570772`], 
           Hue[0.6499912329900899, 1, 0.10001213893679864`], 
           Hue[0.6499798735525514, 1, 0.10002786738877499`], 
           Hue[0.6499660613044453, 1, 0.10004699203999876`], 
           Hue[0.6499875583936996, 1, 0.10001722683949292`], 
           Hue[0.6499660027761931, 1, 0.10004707307911734`], 
           Hue[0.6499792798726709, 1, 0.10002868940707108`], 
           Hue[0.6499904256749581, 1, 0.10001325675775033`], 
           Hue[0.6499970064878591, 1, 0.10000414486296437`], 
           Hue[0.6499993483460993, 1, 0.10000090229001643`], 
           Hue[0.6499998974223291, 1, 0.10000014203062124`], 
           Hue[0.6499999222917153, 1, 0.10000010759608655`], 
           Hue[0.6499999878784672, 1, 0.1000000167836607], 
           Hue[0.6499999916279817, 1, 0.10000001159202533`], 
           Hue[0.6499999880630696, 1, 0.10000001652805754`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499999917956835, 1, 0.10000001135982291`], 
           Hue[0.6499997344623704, 1, 0.10000036766748721`], 
           Hue[0.6499993557516623, 1, 0.10000089203615993`], 
           Hue[0.6499999234519708, 1, 0.10000010598957898`], 
           Hue[0.649997032693306, 1, 0.10000410857849946`], 
           Hue[0.6499904847358855, 1, 0.10001317498108163`], 
           Hue[0.6499793572109922, 1, 0.10002858232324165`], 
           Hue[0.6499660352996491, 1, 0.10004702804663973`], 
           Hue[0.6499875752276579, 1, 0.10001720353093521`], 
           Hue[0.6499660419264217, 1, 0.10004701887110846`], 
           Hue[0.6499797890669986, 1, 0.10002798436877126`], 
           Hue[0.649991166860452, 1, 0.1000122305009126], 
           Hue[0.6499975387906934, 1, 0.10000340782827066`], 
           Hue[0.6499995605902448, 1, 0.10000060841350733`], 
           Hue[0.6499999480469419, 1, 0.10000007193500345`], 
           Hue[0.6499999509486679, 1, 0.10000006791722911`], 
           Hue[0.6499999965856617, 1, 0.10000000472754546`], 
           Hue[0.6499999965856617, 1, 0.10000000472754546`], 
           Hue[0.6499875499410278, 1, 0.10001723854319232`], 
           Hue[0.6499875752276579, 1, 0.10001720353093523`], 
           Hue[0.6499993557516623, 1, 0.10000089203615993`], 
           Hue[0.6499999880630696, 1, 0.10000001652805754`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499875610519944, 1, 0.10001722315877695`], 
           Hue[0.6499875583936996, 1, 0.10001722683949292`], 
           Hue[0.6499975662514333, 1, 0.10000336980570773`], 
           Hue[0.6499999519224451, 1, 0.10000006656892216`], 
           Hue[0.6498378759096497, 1, 0.10022447950971584`], 
           Hue[0.6499435436197024, 1, 0.10007817037271981`], 
           Hue[0.6499798465258424, 1, 0.10002790481037209`], 
           Hue[0.6497261232417287, 1, 0.10037921397299106`], 
           Hue[0.6498403530877374, 1, 0.10022104957082523`], 
           Hue[0.6499503668772791, 1, 0.10006872278530578`], 
           Hue[0.6499999519224451, 1, 0.10000006656892216`], 
           Hue[0.6494616792468534, 1, 0.10074536719666463`], 
           Hue[0.6495984682510236, 1, 0.10055596703704421`], 
           Hue[0.6497732626026613, 1, 0.1003139440886228], 
           Hue[0.6499981929645616, 1, 0.10000250204906862`], 
           Hue[0.6499900187740281, 1, 0.10001382015903805`], 
           Hue[0.6494692059492383, 1, 0.10073494560874698`], 
           Hue[0.6494812112006415, 1, 0.10071832295295798`], 
           Hue[0.6496330749346824, 1, 0.10050805009043988`], 
           Hue[0.649813758879976, 1, 0.10025787232003332`], 
           Hue[0.6499860137071368, 1, 0.10001936563627217`], 
           Hue[0.6499416771509491, 1, 0.10008075471407049`], 
           Hue[0.6492111455095863, 1, 0.10109226006364984`], 
           Hue[0.648758555220787, 1, 0.10171892354044881`], 
           Hue[0.6488795947841098, 1, 0.10155133029892492`], 
           Hue[0.6491535472148489, 1, 0.10117201154867078`], 
           Hue[0.6498137588799761, 1, 0.10025787232003325`], 
           Hue[0.6499149607103819, 1, 0.10011774670870197`], 
           Hue[0.649729466369962, 1, 0.10037458502620653`], 
           Hue[0.648883133851712, 1, 0.10154643005147576`], 
           Hue[0.6481345467524913, 1, 0.10258293526578137`], 
           Hue[0.647966797245455, 1, 0.10281520381398546`], 
           Hue[0.6480385917352298, 1, 0.10271579605891265`], 
           Hue[0.6482450581235273, 1, 0.10242991952126995`], 
           Hue[0.649153547214849, 1, 0.10117201154867062`], 
           Hue[0.6496330749346825, 1, 0.10050805009043975`], 
           Hue[0.6498926261234819, 1, 0.10014867152133289`], 
           Hue[0.6483341237539456, 1, 0.10230659787915224`], 
           Hue[0.6495822971313424, 1, 0.10057835781814135`], 
           Hue[0.6489591993613566, 1, 0.10144110857658323`], 
           Hue[0.6489583372555867, 1, 0.10144230226149542`], 
           Hue[0.6483330201390396, 1, 0.10230812596132983`], 
           Hue[0.6471786129927877, 1, 0.10390653585614024`], 
           Hue[0.6474234415840103, 1, 0.10356754242213957`], 
           Hue[0.6482450581235273, 1, 0.10242991952126992`], 
           Hue[0.6488795947841098, 1, 0.10155133029892484`], 
           Hue[0.6494812112006415, 1, 0.10071832295295793`], 
           Hue[0.6498403530877374, 1, 0.10022104957082521`], 
           Hue[0.6499690957937134, 1, 0.1000427904394738], 
           Hue[0.6499875499410278, 1, 0.10001723854319232`], 
           Hue[0.6461108778788095, 1, 0.10538493832164841`], 
           Hue[0.6464564564606159, 1, 0.10490644490068565`], 
           Hue[0.64742344158401, 1, 0.10356754242214004`], 
           Hue[0.6480385917352296, 1, 0.10271579605891286`], 
           Hue[0.6487585552207868, 1, 0.10171892354044898`], 
           Hue[0.6498378759096497, 1, 0.10022447950971583`], 
           Hue[0.6494616792468534, 1, 0.10074536719666462`], 
           Hue[0.6443985210227051, 1, 0.1077558939685622], 
           Hue[0.6450470004719606, 1, 0.10685799934651607`], 
           Hue[0.6464564564606102, 1, 0.10490644490069351`], 
           Hue[0.6479667972454544, 1, 0.10281520381398628`], 
           Hue[0.6499875610519944, 1, 0.10001722315877697`], 
           Hue[0.6495984682510236, 1, 0.10055596703704424`], 
           Hue[0.6387961530917176, 1, 0.11551301879608337`], 
           Hue[0.6419821243866809, 1, 0.11110167392613411`], 
           Hue[0.6450470004719279, 1, 0.1068579993465614], 
           Hue[0.6481345467524894, 1, 0.10258293526578396`], 
           Hue[0.6499435436197024, 1, 0.10007817037271981`], 
           Hue[0.6497732626026613, 1, 0.10031394408862286`], 
           Hue[0.5614916278741021, 1, 0.22255005371278172`], 
           Hue[0.57812541033916, 1, 0.19951866260731693`], 
           Hue[0.6025745294274645, 1, 0.1656660361773569], 
           Hue[0.6237081735896381, 1, 0.13640406733742408`], 
           Hue[0.6419821243866659, 1, 0.11110167392615486`], 
           Hue[0.6473931627551752, 1, 0.10360946695437283`], 
           Hue[0.6499798465258424, 1, 0.1000279048103721], 
           Hue[0.43299533247763233`, 1, 0.40046800118481685`], 
           Hue[0.4697754323597277, 1, 0.34954170904037707`], 
           Hue[0.5284835431577712, 1, 0.2682535556277013], 
           Hue[0.623708173589869, 1, 0.1364040673371045], 
           Hue[0.6462861242777049, 1, 0.10514228946163941`], 
           Hue[0.6499993557516623, 1, 0.10000089203615993`], 
           Hue[0.2674438253340051, 1, 0.6296931649221468], 
           Hue[0.267450645458638, 1, 0.6296837216726551], 
           Hue[0.3196540147172407, 1, 0.5574021334684359], 
           Hue[0.5284835431585925, 1, 0.2682535556265643], 
           Hue[0.6025745294281106, 1, 0.1656660361764622], 
           Hue[0.6483341237539202, 1, 0.10230659787918744`], 
           Hue[0.18504088595038598`, 1, 0.7437895425302348], 
           Hue[0.18504088595001256`, 1, 0.7437895425307519], 
           Hue[0.12879102678331356`, 1, 0.8216739629154121], 
           Hue[0.10026584227849467`, 1, 0.8611703722297765], 
           Hue[0.12880990328898734`, 1, 0.8216478262152483], 
           Hue[0.18507857487579976`, 1, 0.7437373578642772], 
           Hue[0.10030388522786648`, 1, 0.8611176973768003], 
           Hue[0.1850785748753384, 1, 0.743737357864916], 
           Hue[0.31965401471773736`, 1, 0.5574021334677483], 
           Hue[0.46977543236106056`, 1, 0.34954170903853155`], 
           Hue[0.5781254103401833, 1, 0.1995186626059001], 
           Hue[0.627587341145137, 1, 0.13103291226057956`], 
           Hue[0.6432314603308535, 1, 0.10937182415727968`], 
           Hue[0.6499999880630696, 1, 0.10000001652805754`], 
           Hue[0.6499998222703252, 1, 0.1000002460872421], 
           Hue[0.6499900187740281, 1, 0.1000138201590381], 
           Hue[0.6499981929645616, 1, 0.10000250204906863`], 
           Hue[0.6499416771509486, 1, 0.10008075471407114`], 
           Hue[0.6499860137071367, 1, 0.10001936563627227`], 
           Hue[0.6497294663699593, 1, 0.10037458502621026`], 
           Hue[0.6499149607103814, 1, 0.10011774670870276`], 
           Hue[0.648959199361349, 1, 0.10144110857659368`], 
           Hue[0.6495822971313402, 1, 0.10057835781814445`], 
           Hue[0.267443825332904, 1, 0.6296931649236714], 
           Hue[0.12879102678220322`, 1, 0.8216739629169494], 
           Hue[0.04089385234061427, 1, 0.9433777429129957], 
           Hue[0.04089385234029075, 1, 0.9433777429134436], 
           Hue[0.040915046164482605`, 1, 0.9433483976184087], 
           Hue[0.12880990328631003`, 1, 0.8216478262189554], 
           Hue[0.26745064545827635`, 1, 0.6296837216731559], 
           Hue[0.432995332479051, 1, 0.40046800118285253`], 
           Hue[0.5614916278752367, 1, 0.22255005371121075`], 
           Hue[0.6495819204903069, 1, 0.10057887932111356`], 
           Hue[0.6499147887623521, 1, 0.10011798479058953`], 
           Hue[0.6499859604962616, 1, 0.10001943931286864`], 
           Hue[0.6499981815209614, 1, 0.10000251789405334`], 
           Hue[0.6499998205406813, 1, 0.10000024848213372`], 
           Hue[0.6499999878784672, 1, 0.1000000167836607], 
           Hue[0.5614916278739857, 1, 0.22255005371294295`], 
           Hue[0.43299533247711963`, 1, 0.4004680011855267], 
           Hue[0.26745064545750746`, 1, 0.6296837216742204], 
           Hue[0.12880990328781605`, 1, 0.8216478262168702], 
           Hue[0.04091504616570485, 1, 0.9433483976167164], 
           Hue[0.008564162897190197, 1, 0.9881419282961982], 
           Hue[0.0408938523364103, 1, 0.9433777429188165], 
           Hue[0.12879102677946985`, 1, 0.821673962920734], 
           Hue[0.26744382533350425`, 1, 0.6296931649228403], 
           Hue[0.6495822971313276, 1, 0.10057835781816173`], 
           Hue[0.6499149607103801, 1, 0.10011774670870452`], 
           Hue[0.6499860137071367, 1, 0.10001936563627235`], 
           Hue[0.6499981929645616, 1, 0.10000250204906863`], 
           Hue[0.6499998222703252, 1, 0.1000002460872421], 
           Hue[0.6489583372555867, 1, 0.10144230226149535`], 
           Hue[0.5781254103390867, 1, 0.19951866260741846`], 
           Hue[0.4697754323594143, 1, 0.34954170904081094`], 
           Hue[0.3196540147165537, 1, 0.5574021334693872], 
           Hue[0.18507857487510665`, 1, 0.743737357865237], 
           Hue[0.10030388522652434`, 1, 0.8611176973786585], 
           Hue[0.10026584227419488`, 1, 0.8611703722357301], 
           Hue[0.1850408859480107, 1, 0.7437895425335237], 
           Hue[0.6483330201390397, 1, 0.10230812596132967`], 
           Hue[0.6025745294274348, 1, 0.16566603617739795`], 
           Hue[0.5284835431576489, 1, 0.2682535556278708], 
           Hue[0.1288099032863832, 1, 0.821647826218854], 
           Hue[0.6483341237538894, 1, 0.1023065978792301], 
           Hue[0.6499999234519708, 1, 0.10000010598957898`], 
           Hue[0.6488831338517119, 1, 0.1015464300514758], 
           Hue[0.6387961530917151, 1, 0.11551301879608673`], 
           Hue[0.6237081735896223, 1, 0.1364040673374461], 
           Hue[0.319654014717638, 1, 0.5574021334678859], 
           Hue[0.2674506454582996, 1, 0.6296837216731236], 
           Hue[0.26744382533355726`, 1, 0.6296931649227668], 
           Hue[0.6499798465258424, 1, 0.10002790481037209`], 
           Hue[0.6492111455095861, 1, 0.10109226006364998`], 
           Hue[0.6443985210227057, 1, 0.10775589396856143`], 
           Hue[0.6419821243866807, 1, 0.11110167392613443`], 
           Hue[0.5284835431584985, 1, 0.2682535556266944], 
           Hue[0.46977543236099784`, 1, 0.3495417090386184], 
           Hue[0.43299533247903554`, 1, 0.40046800118287396`], 
           Hue[0.6497732626026613, 1, 0.10031394408862274`], 
           Hue[0.6494692059492383, 1, 0.10073494560874705`], 
           Hue[0.6481345467524912, 1, 0.10258293526578155`], 
           Hue[0.6461108778788097, 1, 0.10538493832164814`], 
           Hue[0.645047000471963, 1, 0.10685799934651287`], 
           Hue[0.6237081735898071, 1, 0.1364040673371902], 
           Hue[0.602574529428017, 1, 0.1656660361765918], 
           Hue[0.5781254103401121, 1, 0.1995186626059986], 
           Hue[0.5614916278752068, 1, 0.2225500537112522], 
           Hue[0.6495984682510237, 1, 0.10055596703704404`], 
           Hue[0.6498872063550268, 1, 0.10015617581611677`], 
           Hue[0.6497261232417287, 1, 0.10037921397299107`], 
           Hue[0.6479667972454549, 1, 0.10281520381398558`], 
           Hue[0.6471786129927874, 1, 0.10390653585614043`], 
           Hue[0.6464564564606162, 1, 0.10490644490068528`], 
           Hue[0.6419821243867047, 1, 0.11110167392610121`], 
           Hue[0.6275873411450932, 1, 0.13103291226064023`], 
           Hue[0.6494616792468535, 1, 0.10074536719666437`], 
           Hue[0.6498378759096498, 1, 0.10022447950971572`], 
           Hue[0.6499689720806963, 1, 0.1000429617344206], 
           Hue[0.6499875610519944, 1, 0.10001722315877695`], 
           Hue[0.6487585552207871, 1, 0.10171892354044876`], 
           Hue[0.6480385917352298, 1, 0.10271579605891265`], 
           Hue[0.6474234415840103, 1, 0.10356754242213963`], 
           Hue[0.6450470004719643, 1, 0.10685799934651109`], 
           Hue[0.6432314603308571, 1, 0.10937182415727481`], 
           Hue[0.6498403530877374, 1, 0.10022104957082521`], 
           Hue[0.6494812112006415, 1, 0.1007183229529579], 
           Hue[0.64887959478411, 1, 0.10155133029892478`], 
           Hue[0.6482450581235274, 1, 0.10242991952126983`], 
           Hue[0.6464564564606162, 1, 0.10490644490068533`], 
           Hue[0.6462861242777769, 1, 0.10514228946153971`], 
           Hue[0.6489591993613006, 1, 0.10144110857666075`], 
           Hue[0.6483341237538893, 1, 0.10230659787923027`], 
           Hue[0.6499875499410278, 1, 0.1000172385431923], 
           Hue[0.6496330749346824, 1, 0.10050805009043981`], 
           Hue[0.649153547214849, 1, 0.10117201154867066`], 
           Hue[0.6474234415840103, 1, 0.10356754242213959`], 
           Hue[0.6473931627551958, 1, 0.10360946695434443`], 
           Hue[0.6495819204903092, 1, 0.10057887932111045`], 
           Hue[0.6497294663699528, 1, 0.10037458502621932`], 
           Hue[0.6499503668772793, 1, 0.10006872278530576`], 
           Hue[0.649813758879976, 1, 0.10025787232003329`], 
           Hue[0.6482450581235273, 1, 0.10242991952126988`], 
           Hue[0.6480385917352297, 1, 0.10271579605891275`], 
           Hue[0.6479667972454548, 1, 0.10281520381398572`], 
           Hue[0.648134546752491, 1, 0.10258293526578166`], 
           Hue[0.6499147887623526, 1, 0.10011798479058873`], 
           Hue[0.6499416771509483, 1, 0.10008075471407167`], 
           Hue[0.6499975662514333, 1, 0.10000336980570773`], 
           Hue[0.649153547214849, 1, 0.10117201154867064`], 
           Hue[0.6488795947841098, 1, 0.10155133029892488`], 
           Hue[0.6487585552207868, 1, 0.10171892354044898`], 
           Hue[0.6499859604962617, 1, 0.10001943931286852`], 
           Hue[0.6499900187740281, 1, 0.1000138201590381], 
           Hue[0.6498137588799761, 1, 0.10025787232003325`], 
           Hue[0.6496330749346824, 1, 0.10050805009043978`], 
           Hue[0.6494812112006415, 1, 0.10071832295295796`], 
           Hue[0.6499981815209614, 1, 0.10000251789405334`], 
           Hue[0.6497732626026614, 1, 0.1003139440886227], 
           Hue[0.6495984682510237, 1, 0.10055596703704402`], 
           Hue[0.6494616792468535, 1, 0.10074536719666437`], 
           Hue[0.6499999519224451, 1, 0.10000006656892216`], 
           Hue[0.6498926261234819, 1, 0.10014867152133289`], 
           Hue[0.6498403530877374, 1, 0.10022104957082523`], 
           Hue[0.6499998205406813, 1, 0.10000024848213372`], 
           Hue[0.6499998222703252, 1, 0.1000002460872421], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499798465258424, 1, 0.10002790481037208`], 
           Hue[0.6498872063550268, 1, 0.10015617581611676`], 
           Hue[0.6498378759096498, 1, 0.10022447950971572`], 
           Hue[0.6499999519224451, 1, 0.10000006656892216`], 
           Hue[0.6499690957937134, 1, 0.10004279043947381`], 
           Hue[0.6499875610519944, 1, 0.10001722315877697`], 
           Hue[0.6499689720806963, 1, 0.1000429617344206], 
           Hue[0.6499875499410278, 1, 0.1000172385431923], 
           Hue[0.6499690478431731, 1, 0.10004285683252959`], 
           Hue[0.6499650382974362, 1, 0.10004840851124211`], 
           Hue[0.6499998988706782, 1, 0.10000014002521485`], 
           Hue[0.6499689178987232, 1, 0.10004303675561406`], 
           Hue[0.6499650303492368, 1, 0.10004841951644139`], 
           Hue[0.6496325065507648, 1, 0.10050883708355646`], 
           Hue[0.6495979512450224, 1, 0.10055668289150747`], 
           Hue[0.6496325065507649, 1, 0.10050883708355643`], 
           Hue[0.6499690478431731, 1, 0.10004285683252959`], 
           Hue[0.6492568700596784, 1, 0.10102894914813774`], 
           Hue[0.6499650382974362, 1, 0.1000484085112421], 
           Hue[0.647733989804249, 1, 0.1031375525787322], 
           Hue[0.6477329026591776, 1, 0.10313905785652336`], 
           Hue[0.6469512230735474, 1, 0.10422138343662676`], 
           Hue[0.6499650303492368, 1, 0.10004841951644142`], 
           Hue[0.6499689178987231, 1, 0.10004303675561409`], 
           Hue[0.6275861158776409, 1, 0.13103460878480497`], 
           Hue[0.6495979512450223, 1, 0.1005566828915077], 
           Hue[0.6469512230735815, 1, 0.10422138343657948`], 
           Hue[0.6499998988706782, 1, 0.10000014002521485`], 
           Hue[0.6492568700596688, 1, 0.10102894914815094`], 
           Hue[0.6477339898042302, 1, 0.10313755257875815`], 
           Hue[0.6275861158776742, 1, 0.13103460878475878`], 
           Hue[0.6477329026592883, 1, 0.10313905785637009`], 
           Hue[0.6477329026591778, 1, 0.10313905785652307`], 
           Hue[0.6275861158775875, 1, 0.1310346087848789], 
           Hue[0.6477339898041263, 1, 0.1031375525789021], 
           Hue[0.6492568700596507, 1, 0.10102894914817598`], 
           Hue[0.6499998988706782, 1, 0.10000014002521485`], 
           Hue[0.6469512230735475, 1, 0.10422138343662657`], 
           Hue[0.6495979512450224, 1, 0.1005566828915075], 
           Hue[0.6499689178987232, 1, 0.10004303675561406`], 
           Hue[0.6275861158775856, 1, 0.13103460878488143`], 
           Hue[0.6499650303492368, 1, 0.10004841951644139`], 
           Hue[0.6499650382974363, 1, 0.10004840851124208`], 
           Hue[0.6469512230736324, 1, 0.10422138343650898`], 
           Hue[0.647732902659307, 1, 0.10313905785634415`], 
           Hue[0.647733989804126, 1, 0.10313755257890245`], 
           Hue[0.6499690478431731, 1, 0.10004285683252957`], 
           Hue[0.6492568700596506, 1, 0.10102894914817606`], 
           Hue[0.6496325065507648, 1, 0.10050883708355651`], 
           Hue[0.6495979512450223, 1, 0.10055668289150767`], 
           Hue[0.6496325065507648, 1, 0.10050883708355657`], 
           Hue[0.6499650303492368, 1, 0.10004841951644142`], 
           Hue[0.6499689178987231, 1, 0.10004303675561409`], 
           Hue[0.6499998988706782, 1, 0.10000014002521485`], 
           Hue[0.6499650382974363, 1, 0.10004840851124208`], 
           Hue[0.6499690478431731, 1, 0.10004285683252959`], 
           Hue[0.6499999477487557, 1, 0.10000007234787675`], 
           Hue[0.6499995415164597, 1, 0.1000006348233636], 
           Hue[0.6499972508920432, 1, 0.10000380645717097`], 
           Hue[0.6499891948964658, 1, 0.10001496091258584`], 
           Hue[0.6499727635994403, 1, 0.10003771193923645`], 
           Hue[0.6499999833152275, 1, 0.10000002310199285`], 
           Hue[0.6499998838143439, 1, 0.10000016087244698`], 
           Hue[0.6499992517330715, 1, 0.10000103606190107`], 
           Hue[0.6499964365371523, 1, 0.10000493402548141`], 
           Hue[0.6499878785449099, 1, 0.10001678355320162`], 
           Hue[0.64997163313836, 1, 0.10003927719303991`], 
           Hue[0.6499995415164597, 1, 0.1000006348233636], 
           Hue[0.6499967956750783, 1, 0.10000443675758397`], 
           Hue[0.6499839080767035, 1, 0.10002228112456447`], 
           Hue[0.6499439425821281, 1, 0.10007761796320734`], 
           Hue[0.6498689637672006, 1, 0.10018143478387614`], 
           Hue[0.6499988129691915, 1, 0.10000164358111958`], 
           Hue[0.6499940313665191, 1, 0.10000826426174277`], 
           Hue[0.6499769587829002, 1, 0.10003190322367668`], 
           Hue[0.6499332213778155, 1, 0.10009246270764012`], 
           Hue[0.6498591025961614, 1, 0.10019508871300734`], 
           Hue[0.6499972508920432, 1, 0.10000380645717097`], 
           Hue[0.6499839080767035, 1, 0.10002228112456447`], 
           Hue[0.6499333273424222, 1, 0.1000923159874155], 
           Hue[0.649802635479388, 1, 0.10027327395161664`], 
           Hue[0.6499910204721564, 1, 0.10001243319239884`], 
           Hue[0.6499648950093987, 1, 0.10004860691006341`], 
           Hue[0.6498924977752071, 1, 0.10014884923432864`], 
           Hue[0.6497443765290007, 1, 0.10035394019061437`], 
           Hue[0.6499891948964658, 1, 0.10001496091258584`], 
           Hue[0.6499439425821281, 1, 0.10007761796320734`], 
           Hue[0.649802635479388, 1, 0.10027327395161664`], 
           Hue[0.649507963302497, 1, 0.10068128158115795`], 
           Hue[0.6499481872069947, 1, 0.10007174079031515`], 
           Hue[0.6498438427337278, 1, 0.1002162177533], 
           Hue[0.6496234428209622, 1, 0.10052138686328319`], 
           Hue[0.6499727635994403, 1, 0.10003771193923645`], 
           Hue[0.6498689637672006, 1, 0.10018143478387613`], 
           Hue[0.6497656401713836, 1, 0.10032449822423818`], 
           Hue[0.6494616592083259, 1, 0.10074539494231807`], 
           Hue[0.649978647617328, 1, 0.10002956483754584`], 
           Hue[0.6441375780758971, 1, 0.10811719958721938`], 
           Hue[0.6432396388960604, 1, 0.1093604999900703], 
           Hue[0.642231751769465, 1, 0.11075603601151002`], 
           Hue[0.6499798790222463, 1, 0.10002785981535132`], 
           Hue[0.6437344762513189, 1, 0.10867534057509703`], 
           Hue[0.6417513908539809, 1, 0.11142115112525726`], 
           Hue[0.6378571080019445, 1, 0.11681323507423075`], 
           Hue[0.6309283188212801, 1, 0.12640694317053525`], 
           Hue[0.6441375780758337, 1, 0.10811719958730724`], 
           Hue[0.6417513908539563, 1, 0.11142115112529143`], 
           Hue[0.6360099177032927, 1, 0.11937088318005631`], 
           Hue[0.6220664870179633, 1, 0.13867717182128156`], 
           Hue[0.5965457485369448, 1, 0.17401357894884573`], 
           Hue[0.6498013526819988, 1, 0.10027505013261706`], 
           Hue[0.6499532866781321, 1, 0.10006467998412484`], 
           Hue[0.6432396388959816, 1, 0.10936049999017944`], 
           Hue[0.6378571080019386, 1, 0.11681323507423888`], 
           Hue[0.6220664870179979, 1, 0.13867717182123368`], 
           Hue[0.5839593231110924, 1, 0.19144093723079508`], 
           Hue[0.5205040684996355, 1, 0.2793020590005047], 
           Hue[0.6496866182982453, 1, 0.10043391312550666`], 
           Hue[0.6499131219491169, 1, 0.10012029268583819`], 
           Hue[0.6499824722110213, 1, 0.10002426924627814`], 
           Hue[0.6422317517694232, 1, 0.11075603601156796`], 
           Hue[0.63092831882132, 1, 0.1264069431704799], 
           Hue[0.5965457485370032, 1, 0.1740135789487649], 
           Hue[0.520504068499611, 1, 0.2793020590005387], 
           Hue[0.6495503990542772, 1, 0.10062252438638544`], 
           Hue[0.6498698870997501, 1, 0.10018015632342288`], 
           Hue[0.6499712182270595, 1, 0.10003985168560998`], 
           Hue[0.6499952676247932, 1, 0.10000655251951718`], 
           Hue[0.6480874779838659, 1, 0.10264810740695487`], 
           Hue[0.6498119241509249, 1, 0.10026041271410392`], 
           Hue[0.6499575857662996, 1, 0.10005872740050828`], 
           Hue[0.6499926578215517, 1, 0.1000101660932362], 
           Hue[0.6499990466030793, 1, 0.10000132008804404`], 
           Hue[0.6499999100348424, 1, 0.10000012456714136`], 
           Hue[0.6499314498889781, 1, 0.10009491553833798`], 
           Hue[0.6499884615950133, 1, 0.10001597625305847`], 
           Hue[0.6499984854790767, 1, 0.10000209702897084`], 
           Hue[0.6499998499633765, 1, 0.10000020774301727`], 
           Hue[0.6499999901267185, 1, 0.10000001367069754`], 
           Hue[0.6499999833152275, 1, 0.10000002310199285`], 
           Hue[0.649999996933637, 1, 0.1000000042457334], 
           Hue[0.6499998838143439, 1, 0.10000016087244698`], 
           Hue[0.6499988129691915, 1, 0.10000164358111958`], 
           Hue[0.6499910204721564, 1, 0.10001243319239884`], 
           Hue[0.6499481872069947, 1, 0.10007174079031517`], 
           Hue[0.6497656401713836, 1, 0.10032449822423817`], 
           Hue[0.6499999689061249, 1, 0.10000004305305792`], 
           Hue[0.6499992517330715, 1, 0.10000103606190107`], 
           Hue[0.6499940313665191, 1, 0.10000826426174277`], 
           Hue[0.6499648950093987, 1, 0.10004860691006343`], 
           Hue[0.6498438427337278, 1, 0.10021621775330003`], 
           Hue[0.6494616592083259, 1, 0.10074539494231807`], 
           Hue[0.6090241519504237, 1, 0.15673578960710566`], 
           Hue[0.6363371711390605, 1, 0.11891776303822395`], 
           Hue[0.6499964365371523, 1, 0.10000493402548141`], 
           Hue[0.6499769587829002, 1, 0.1000319032236767], 
           Hue[0.6498924977752071, 1, 0.10014884923432867`], 
           Hue[0.6496234428209621, 1, 0.10052138686328327`], 
           Hue[0.5138230752066207, 1, 0.2885526650985252], 
           Hue[0.5873524065680152, 1, 0.1867428216750559], 
           Hue[0.6258101614488276, 1, 0.1334936226093157], 
           Hue[0.6398547950462351, 1, 0.11404720685905909`], 
           Hue[0.6499878785449099, 1, 0.10001678355320162`], 
           Hue[0.6499332213778155, 1, 0.10009246270764013`], 
           Hue[0.6497443765290007, 1, 0.10035394019061443`], 
           Hue[0.5873524065680147, 1, 0.18674282167505662`], 
           Hue[0.6206832762213136, 1, 0.14059238677048885`], 
           Hue[0.6364974200212797, 1, 0.11869587997053574`], 
           Hue[0.6423011565880341, 1, 0.11065993703195276`], 
           Hue[0.64997163313836, 1, 0.10003927719303991`], 
           Hue[0.6498591025961614, 1, 0.10019508871300735`], 
           Hue[0.6090241519504225, 1, 0.1567357896071074], 
           Hue[0.625810161448827, 1, 0.1334936226093165], 
           Hue[0.6364974200212795, 1, 0.11869587997053603`], 
           Hue[0.6415696507928466, 1, 0.11167279120990485`], 
           Hue[0.6438278308474126, 1, 0.10854608036512113`], 
           Hue[0.6363371711390599, 1, 0.11891776303822488`], 
           Hue[0.6398547950462348, 1, 0.11404720685905957`], 
           Hue[0.6423011565880339, 1, 0.11065993703195309`], 
           Hue[0.6438278308474125, 1, 0.1085460803651213], 
           Hue[0.6499786571222672, 1, 0.10002955167686084`], 
           Hue[0.6480874779838893, 1, 0.10264810740692248`], 
           Hue[0.6499798927908357, 1, 0.10002784075115065`], 
           Hue[0.6499153777187439, 1, 0.10011716931250861`], 
           Hue[0.6495503990542805, 1, 0.10062252438638086`], 
           Hue[0.6498119241509267, 1, 0.10026041271410145`], 
           Hue[0.6499314498889787, 1, 0.10009491553833723`], 
           Hue[0.6495278596636377, 1, 0.10065373277342475`], 
           Hue[0.6498281137840707, 1, 0.1002379962989791], 
           Hue[0.6499573290700602, 1, 0.10005908282607058`], 
           Hue[0.6496866182982456, 1, 0.10043391312550613`], 
           Hue[0.6498698870997506, 1, 0.10018015632342239`], 
           Hue[0.6499575857662998, 1, 0.100058727400508], 
           Hue[0.6499884615950134, 1, 0.10001597625305839`], 
           Hue[0.6495278596636377, 1, 0.1006537327734248], 
           Hue[0.6497944442738895, 1, 0.10028461562076833`], 
           Hue[0.649935848726795, 1, 0.10008882483982239`], 
           Hue[0.649985852682855, 1, 0.10001958859296996`], 
           Hue[0.6498013526819988, 1, 0.10027505013261703`], 
           Hue[0.6499131219491169, 1, 0.10012029268583815`], 
           Hue[0.6499712182270595, 1, 0.10003985168560994`], 
           Hue[0.6499926578215517, 1, 0.10001016609323618`], 
           Hue[0.6499984854790767, 1, 0.10000209702897084`], 
           Hue[0.6498281137840707, 1, 0.10023799629897913`], 
           Hue[0.649935848726795, 1, 0.10008882483982239`], 
           Hue[0.6499833260191297, 1, 0.10002308705043594`], 
           Hue[0.6499968965922412, 1, 0.10000429702612754`], 
           Hue[0.6499532866781321, 1, 0.10006467998412485`], 
           Hue[0.6499824722110213, 1, 0.10002426924627814`], 
           Hue[0.6499952676247932, 1, 0.10000655251951718`], 
           Hue[0.6499990466030794, 1, 0.10000132008804404`], 
           Hue[0.6499998499633765, 1, 0.10000020774301727`], 
           Hue[0.6499153777187437, 1, 0.10011716931250862`], 
           Hue[0.6499573290700602, 1, 0.10005908282607058`], 
           Hue[0.649985852682855, 1, 0.10001958859296996`], 
           Hue[0.6499968965922412, 1, 0.10000429702612754`], 
           Hue[0.6499995283469943, 1, 0.10000065305800795`], 
           Hue[0.6499999489931797, 1, 0.1000000706248282], 
           Hue[0.649978647617328, 1, 0.10002956483754584`], 
           Hue[0.6499798790222463, 1, 0.10002785981535132`], 
           Hue[0.6499999100348424, 1, 0.10000012456714136`], 
           Hue[0.6499999901267185, 1, 0.10000001367069754`], 
           Hue[0.649999996933637, 1, 0.1000000042457334], 
           Hue[0.6499999689061249, 1, 0.10000004305305792`], 
           Hue[0.6499786571222672, 1, 0.10002955167686084`], 
           Hue[0.6499798927908357, 1, 0.10002784075115065`], 
           Hue[0.6499999489931797, 1, 0.1000000706248282], 
           Hue[0.6499999965648129, 1, 0.100000004756413], 
           Hue[0.6499999965648129, 1, 0.100000004756413], 
           Hue[0.6499999850058028, 1, 0.10000002076119612`], 
           Hue[0.6499999850058028, 1, 0.10000002076119612`], 
           Hue[0.6499999489931797, 1, 0.1000000706248282], 
           Hue[0.6499717446721232, 1, 0.1000391227616756], 
           Hue[0.6499999689061249, 1, 0.10000004305305792`], 
           Hue[0.6499999903087575, 1, 0.10000001341864341`], 
           Hue[0.6499999901267185, 1, 0.10000001367069754`], 
           Hue[0.6499999683904712, 1, 0.1000000437670398], 
           Hue[0.6499999583631957, 1, 0.10000005765095982`], 
           Hue[0.6499999100348424, 1, 0.10000012456714136`], 
           Hue[0.649999996676745, 1, 0.10000000460143], 
           Hue[0.6499999489931797, 1, 0.1000000706248282], 
           Hue[0.6499995283469943, 1, 0.10000065305800795`], 
           Hue[0.6499968965922412, 1, 0.10000429702612754`], 
           Hue[0.649985852682855, 1, 0.10001958859296996`], 
           Hue[0.6499573290700602, 1, 0.10005908282607055`], 
           Hue[0.6499153777187439, 1, 0.1001171693125086], 
           Hue[0.6499534788862268, 1, 0.10006441384983993`], 
           Hue[0.6499998499633765, 1, 0.10000020774301727`], 
           Hue[0.6499990466030794, 1, 0.10000132008804404`], 
           Hue[0.6499952676247932, 1, 0.10000655251951718`], 
           Hue[0.6499824722110213, 1, 0.10002426924627812`], 
           Hue[0.6499532866781321, 1, 0.10006467998412481`], 
           Hue[0.6499968965922412, 1, 0.10000429702612754`], 
           Hue[0.6499833260191297, 1, 0.10002308705043593`], 
           Hue[0.649935848726795, 1, 0.10008882483982234`], 
           Hue[0.6498281137840707, 1, 0.10023799629897905`], 
           Hue[0.6499984854790767, 1, 0.10000209702897084`], 
           Hue[0.6499926578215517, 1, 0.10001016609323618`], 
           Hue[0.6499712182270595, 1, 0.10003985168560994`], 
           Hue[0.6499131219491169, 1, 0.10012029268583812`], 
           Hue[0.6498013526819989, 1, 0.10027505013261694`], 
           Hue[0.649985852682855, 1, 0.10001958859296996`], 
           Hue[0.649935848726795, 1, 0.10008882483982234`], 
           Hue[0.6497944442738897, 1, 0.10028461562076825`], 
           Hue[0.6495278596636378, 1, 0.10065373277342464`], 
           Hue[0.6499884615950133, 1, 0.1000159762530585], 
           Hue[0.6499575857662997, 1, 0.10005872740050815`], 
           Hue[0.6498698870997505, 1, 0.10018015632342248`], 
           Hue[0.6496866182982456, 1, 0.10043391312550612`], 
           Hue[0.6499573290700602, 1, 0.10005908282607055`], 
           Hue[0.6498281137840707, 1, 0.10023799629897903`], 
           Hue[0.6495278596636378, 1, 0.10065373277342463`], 
           Hue[0.6499314498889773, 1, 0.1000949155383391], 
           Hue[0.6498119241509249, 1, 0.10026041271410391`], 
           Hue[0.6495503990542795, 1, 0.10062252438638224`], 
           Hue[0.6499153777187439, 1, 0.10011716931250858`], 
           Hue[0.6438278308474092, 1, 0.10854608036512567`], 
           Hue[0.6423011565880492, 1, 0.11065993703193187`], 
           Hue[0.6398547950463043, 1, 0.11404720685896333`], 
           Hue[0.6363371711392205, 1, 0.11891776303800249`], 
           Hue[0.634412731493343, 1, 0.12158237177844815`], 
           Hue[0.6499717446721232, 1, 0.1000391227616756], 
           Hue[0.6499534788862268, 1, 0.10006441384983993`], 
           Hue[0.643827830847377, 1, 0.1085460803651703], 
           Hue[0.6415696507928302, 1, 0.11167279120992746`], 
           Hue[0.636497420021236, 1, 0.11869587997059636`], 
           Hue[0.625810161448658, 1, 0.13349362260955047`], 
           Hue[0.6090241519500147, 1, 0.15673578960767195`], 
           Hue[0.6498591025961613, 1, 0.10019508871300743`], 
           Hue[0.64997163313836, 1, 0.10003927719303994`], 
           Hue[0.6423011565879951, 1, 0.1106599370320068], 
           Hue[0.63649742002124, 1, 0.11869587997059089`], 
           Hue[0.6206832762210897, 1, 0.14059238677079894`], 
           Hue[0.587352406567333, 1, 0.18674282167600043`], 
           Hue[0.6497443765290006, 1, 0.10035394019061458`], 
           Hue[0.6499332213778155, 1, 0.10009246270764016`], 
           Hue[0.6499878785449099, 1, 0.10001678355320164`], 
           Hue[0.6398547950462775, 1, 0.11404720685900034`], 
           Hue[0.6258101614487078, 1, 0.13349362260948144`], 
           Hue[0.587352406567368, 1, 0.18674282167595202`], 
           Hue[0.5138230752053732, 1, 0.28855266510025257`], 
           Hue[0.6496234428209611, 1, 0.10052138686328474`], 
           Hue[0.649892497775207, 1, 0.10014884923432879`], 
           Hue[0.6499769587829002, 1, 0.10003190322367671`], 
           Hue[0.6499964365371523, 1, 0.10000493402548143`], 
           Hue[0.6363371711392378, 1, 0.11891776303797848`], 
           Hue[0.6344127314933686, 1, 0.12158237177841268`], 
           Hue[0.6090241519500755, 1, 0.15673578960758772`], 
           Hue[0.6494616592083241, 1, 0.10074539494232045`], 
           Hue[0.6498438427337273, 1, 0.10021621775330074`], 
           Hue[0.6499648950093986, 1, 0.1000486069100635], 
           Hue[0.6499940313665191, 1, 0.10000826426174277`], 
           Hue[0.6499992517330715, 1, 0.10000103606190107`], 
           Hue[0.6499999689061249, 1, 0.10000004305305792`], 
           Hue[0.6499999903087575, 1, 0.10000001341864341`], 
           Hue[0.6497656401713869, 1, 0.10032449822423352`], 
           Hue[0.6499481872069948, 1, 0.10007174079031503`], 
           Hue[0.6499910204721564, 1, 0.10001243319239886`], 
           Hue[0.6499988129691915, 1, 0.10000164358111958`], 
           Hue[0.6499998838143439, 1, 0.10000016087244698`], 
           Hue[0.6499999683904712, 1, 0.1000000437670398], 
           Hue[0.6499999583631957, 1, 0.10000005765095982`], 
           Hue[0.6499999901267185, 1, 0.10000001367069754`], 
           Hue[0.6499999583631957, 1, 0.10000005765095982`], 
           Hue[0.6499999683904712, 1, 0.1000000437670398], 
           Hue[0.6499998499633765, 1, 0.10000020774301727`], 
           Hue[0.6499984854790767, 1, 0.10000209702897084`], 
           Hue[0.6499884615950133, 1, 0.1000159762530585], 
           Hue[0.6499314498889773, 1, 0.10009491553833913`], 
           Hue[0.6499999903087575, 1, 0.10000001341864341`], 
           Hue[0.6499999100348424, 1, 0.10000012456714136`], 
           Hue[0.6499990466030794, 1, 0.10000132008804404`], 
           Hue[0.6499926578215517, 1, 0.10001016609323618`], 
           Hue[0.6499575857662997, 1, 0.10005872740050817`], 
           Hue[0.6498119241509249, 1, 0.10026041271410392`], 
           Hue[0.6344127314931636, 1, 0.12158237177869655`], 
           Hue[0.6499952676247932, 1, 0.10000655251951718`], 
           Hue[0.6499712182270595, 1, 0.10003985168560996`], 
           Hue[0.6498698870997505, 1, 0.1001801563234225], 
           Hue[0.6495503990542795, 1, 0.10062252438638229`], 
           Hue[0.5205040685009305, 1, 0.2793020589987117], 
           Hue[0.5965457485375734, 1, 0.1740135789479753], 
           Hue[0.6309283188213023, 1, 0.12640694317050455`], 
           Hue[0.642231751769313, 1, 0.11075603601172052`], 
           Hue[0.6499824722110213, 1, 0.10002426924627812`], 
           Hue[0.6499131219491169, 1, 0.10012029268583815`], 
           Hue[0.6496866182982456, 1, 0.10043391312550619`], 
           Hue[0.5205040685009303, 1, 0.2793020589987119], 
           Hue[0.5839593231117566, 1, 0.19144093722987549`], 
           Hue[0.6220664870181908, 1, 0.13867717182096656`], 
           Hue[0.637857108001951, 1, 0.11681323507422176`], 
           Hue[0.6432396388960145, 1, 0.1093604999901337], 
           Hue[0.6499532866781321, 1, 0.10006467998412481`], 
           Hue[0.6498013526819989, 1, 0.10027505013261696`], 
           Hue[0.5965457485375725, 1, 0.1740135789479767], 
           Hue[0.6220664870181905, 1, 0.13867717182096712`], 
           Hue[0.6360099177033423, 1, 0.11937088317998765`], 
           Hue[0.6417513908539852, 1, 0.11142115112525128`], 
           Hue[0.6441375780758909, 1, 0.10811719958722801`], 
           Hue[0.6499534788862268, 1, 0.1000644138498399], 
           Hue[0.6499717446721233, 1, 0.10003912276167556`], 
           Hue[0.6344127314931625, 1, 0.12158237177869816`], 
           Hue[0.6309283188213016, 1, 0.12640694317050544`], 
           Hue[0.6378571080019506, 1, 0.11681323507422223`], 
           Hue[0.641751390853985, 1, 0.11142115112525151`], 
           Hue[0.6437344762513346, 1, 0.10867534057507511`], 
           Hue[0.6422317517693127, 1, 0.11075603601172099`], 
           Hue[0.6432396388960143, 1, 0.10936049999013404`], 
           Hue[0.6441375780758908, 1, 0.10811719958722825`], 
           Hue[0.6494616592083307, 1, 0.10074539494231151`], 
           Hue[0.6497656401713895, 1, 0.10032449822422998`], 
           Hue[0.6498689637672006, 1, 0.10018143478387617`], 
           Hue[0.6499727635994403, 1, 0.10003771193923647`], 
           Hue[0.6496234428209623, 1, 0.10052138686328298`], 
           Hue[0.6498438427337282, 1, 0.10021621775329947`], 
           Hue[0.6499481872069951, 1, 0.10007174079031451`], 
           Hue[0.6495079633024969, 1, 0.1006812815811581], 
           Hue[0.649802635479388, 1, 0.10027327395161673`], 
           Hue[0.6499439425821281, 1, 0.10007761796320737`], 
           Hue[0.6499891948964658, 1, 0.10001496091258584`], 
           Hue[0.6497443765290007, 1, 0.10035394019061446`], 
           Hue[0.6498924977752071, 1, 0.10014884923432864`], 
           Hue[0.6499648950093987, 1, 0.10004860691006338`], 
           Hue[0.6499910204721564, 1, 0.1000124331923988], 
           Hue[0.6498026354793879, 1, 0.10027327395161674`], 
           Hue[0.6499333273424222, 1, 0.10009231598741554`], 
           Hue[0.6499839080767035, 1, 0.10002228112456447`], 
           Hue[0.6499972508920432, 1, 0.10000380645717097`], 
           Hue[0.6498591025961613, 1, 0.10019508871300745`], 
           Hue[0.6499332213778155, 1, 0.10009246270764016`], 
           Hue[0.6499769587829002, 1, 0.1000319032236767], 
           Hue[0.6499940313665191, 1, 0.10000826426174277`], 
           Hue[0.6499988129691915, 1, 0.10000164358111958`], 
           Hue[0.6499534788862268, 1, 0.10006441384983988`], 
           Hue[0.6498689637672006, 1, 0.1001814347838762], 
           Hue[0.6499439425821281, 1, 0.10007761796320738`], 
           Hue[0.6499839080767035, 1, 0.10002228112456449`], 
           Hue[0.6499967956750783, 1, 0.10000443675758397`], 
           Hue[0.6499995415164597, 1, 0.1000006348233636], 
           Hue[0.649999996676745, 1, 0.10000000460143], 
           Hue[0.64997163313836, 1, 0.10003927719303995`], 
           Hue[0.6499878785449099, 1, 0.10001678355320164`], 
           Hue[0.6499964365371523, 1, 0.10000493402548143`], 
           Hue[0.6499992517330715, 1, 0.10000103606190107`], 
           Hue[0.6499998838143439, 1, 0.10000016087244698`], 
           Hue[0.6499999583631957, 1, 0.10000005765095982`], 
           Hue[0.6499999683904712, 1, 0.1000000437670398], 
           Hue[0.6499999903087575, 1, 0.10000001341864341`], 
           Hue[0.6499717446721233, 1, 0.10003912276167556`], 
           Hue[0.6499727635994403, 1, 0.10003771193923647`], 
           Hue[0.6499891948964658, 1, 0.10001496091258585`], 
           Hue[0.6499972508920432, 1, 0.10000380645717098`], 
           Hue[0.6499995415164597, 1, 0.1000006348233636], 
           Hue[0.6499999477487557, 1, 0.10000007234787675`], 
           Hue[0.6499999850058028, 1, 0.10000002076119612`], 
           Hue[0.6499999850058028, 1, 0.10000002076119612`], 
           Hue[0.6499999925396918, 1, 0.10000001032965763`], 
           Hue[0.6499999924509668, 1, 0.1000000104525075], 
           Hue[0.6499999714959052, 1, 0.10000003946720826`], 
           Hue[0.6499999718281185, 1, 0.1000000390072206], 
           Hue[0.6499999714959052, 1, 0.10000003946720826`], 
           Hue[0.6499999987909204, 1, 0.1000000016741103], 
           Hue[0.6499999924509668, 1, 0.1000000104525075], 
           Hue[0.6499798927908357, 1, 0.10002784075115066`], 
           Hue[0.6499786439810903, 1, 0.10002956987233663`], 
           Hue[0.6499786571222672, 1, 0.10002955167686085`], 
           Hue[0.6499999958851704, 1, 0.10000000569745643`], 
           Hue[0.6499999823388529, 1, 0.10000002445389598`], 
           Hue[0.649999996933637, 1, 0.1000000042457334], 
           Hue[0.6499999968907343, 1, 0.1000000043051372], 
           Hue[0.6499999834633291, 1, 0.10000002289692897`], 
           Hue[0.6499999747414913, 1, 0.10000003497331982`], 
           Hue[0.6499999923535981, 1, 0.10000001058732584`], 
           Hue[0.6499999790874041, 1, 0.10000002895590207`], 
           Hue[0.6499999843722919, 1, 0.10000002163836517`], 
           Hue[0.6499999820241611, 1, 0.10000002488962312`], 
           Hue[0.6499999385497581, 1, 0.10000008508495034`], 
           Hue[0.6499999199446159, 1, 0.10000011084591645`], 
           Hue[0.649999930191259, 1, 0.10000009665825685`], 
           Hue[0.6499798790222463, 1, 0.1000278598153513], 
           Hue[0.6499786432660215, 1, 0.10002957086243183`], 
           Hue[0.649978647617328, 1, 0.10002956483754584`], 
           Hue[0.6499999988522372, 1, 0.10000000158920994`], 
           Hue[0.6499999726116505, 1, 0.10000003792233012`], 
           Hue[0.6499885213023262, 1, 0.10001589358139451`], 
           Hue[0.6499316532667695, 1, 0.10009463393831913`], 
           Hue[0.648088593100504, 1, 0.10264656339930217`], 
           Hue[0.6480874779837993, 1, 0.10264810740704716`], 
           Hue[0.6499798927908357, 1, 0.10002784075115066`], 
           Hue[0.6499786439810903, 1, 0.10002956987233663`], 
           Hue[0.6499872728813456, 1, 0.10001762216429065`], 
           Hue[0.6499786571222672, 1, 0.10002955167686085`], 
           Hue[0.6499872851621001, 1, 0.10001760516016904`], 
           Hue[0.6499786432660215, 1, 0.10002957086243185`], 
           Hue[0.6480885931004806, 1, 0.10264656339933452`], 
           Hue[0.6499999531810358, 1, 0.10000006482625813`], 
           Hue[0.6499999385497581, 1, 0.10000008508495034`], 
           Hue[0.649999996933637, 1, 0.1000000042457334], 
           Hue[0.6499999834633291, 1, 0.10000002289692897`], 
           Hue[0.6499999968907343, 1, 0.1000000043051372], 
           Hue[0.6499999846564967, 1, 0.10000002124485077`], 
           Hue[0.6499999823388529, 1, 0.10000002445389598`], 
           Hue[0.6499885213023262, 1, 0.1000158935813946], 
           Hue[0.649931653266769, 1, 0.10009463393831988`], 
           Hue[0.6499999199446159, 1, 0.10000011084591645`], 
           Hue[0.649999930191259, 1, 0.10000009665825685`], 
           Hue[0.6499999957862591, 1, 0.10000000583441045`], 
           Hue[0.6499999820241611, 1, 0.10000002488962312`], 
           Hue[0.6499999833152275, 1, 0.10000002310199285`], 
           Hue[0.6499999968907343, 1, 0.1000000043051372], 
           Hue[0.6499999834633291, 1, 0.10000002289692897`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499999946476501, 1, 0.10000000741094602`], 
           Hue[0.6499999923535981, 1, 0.10000001058732584`], 
           Hue[0.6499999790874041, 1, 0.10000002895590207`], 
           Hue[0.6499316532667682, 1, 0.10009463393832103`], 
           Hue[0.6499885213023261, 1, 0.10001589358139462`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499999924343713, 1, 0.10000001047548586`], 
           Hue[0.649999930191259, 1, 0.10000009665825685`], 
           Hue[0.6499999459827224, 1, 0.1000000747931536], 
           Hue[0.6499999385497581, 1, 0.10000008508495034`], 
           Hue[0.6499999957862591, 1, 0.10000000583441045`], 
           Hue[0.6499999820241611, 1, 0.10000002488962312`], 
           Hue[0.6499999846564967, 1, 0.10000002124485077`], 
           Hue[0.6499999823388529, 1, 0.10000002445389598`], 
           Hue[0.6499999531810358, 1, 0.10000006482625813`], 
           Hue[0.6480874779837994, 1, 0.10264810740704695`], 
           Hue[0.6480885931004169, 1, 0.10264656339942274`], 
           Hue[0.6499798790222463, 1, 0.1000278598153513], 
           Hue[0.6499786432660215, 1, 0.10002957086243183`], 
           Hue[0.6499872851621001, 1, 0.10001760516016903`], 
           Hue[0.649978647617328, 1, 0.10002956483754584`], 
           Hue[0.6499872728813457, 1, 0.10001762216429065`], 
           Hue[0.6480885931004168, 1, 0.10264656339942299`], 
           Hue[0.6499786439810903, 1, 0.10002956987233662`], 
           Hue[0.6499316532667682, 1, 0.100094633938321], 
           Hue[0.6499885213023261, 1, 0.10001589358139462`], 
           Hue[0.649999930191259, 1, 0.10000009665825685`], 
           Hue[0.6499999833152275, 1, 0.10000002310199285`], 
           Hue[0.6499999834633291, 1, 0.10000002289692897`], 
           Hue[0.6499999968907343, 1, 0.1000000043051372], 
           Hue[0.6499999726116505, 1, 0.10000003792233012`], 
           Hue[0.6499999714959052, 1, 0.10000003946720826`], 
           Hue[0.6499999988522372, 1, 0.10000000158920994`], 
           Hue[0.6499786432660215, 1, 0.10002957086243186`], 
           Hue[0.6499999459827224, 1, 0.1000000747931536], 
           Hue[0.6499999385497581, 1, 0.10000008508495034`], 
           Hue[0.6499999946476501, 1, 0.10000000741094602`], 
           Hue[0.6499999790874041, 1, 0.10000002895590207`], 
           Hue[0.6499999923535981, 1, 0.10000001058732584`], 
           Hue[0.6499999843722919, 1, 0.10000002163836517`], 
           Hue[0.6499999820241611, 1, 0.10000002488962312`], 
           Hue[0.6499999947460028, 1, 0.10000000727476545`], 
           Hue[0.6499999924343713, 1, 0.10000001047548586`], 
           Hue[0.6499999958851704, 1, 0.10000000569745643`], 
           Hue[0.6499999823388529, 1, 0.10000002445389598`], 
           Hue[0.6499786439810903, 1, 0.10002956987233662`], 
           Hue[0.6499999718281185, 1, 0.1000000390072206], 
           Hue[0.6499999714959052, 1, 0.10000003946720826`], 
           Hue[0.6499999987909204, 1, 0.1000000016741103], 
           Hue[0.6499999924509668, 1, 0.1000000104525075], 
           Hue[0.6499999925396918, 1, 0.10000001032965763`], 
           Hue[0.6499999924509668, 1, 0.1000000104525075], 
           Hue[0.6499872705232843, 1, 0.10001762542929866`], 
           Hue[0.6499999924343713, 1, 0.10000001047548586`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499872761827475, 1, 0.1000176175931189], 
           Hue[0.6499999947460028, 1, 0.10000000727476545`], 
           Hue[0.6499999924343713, 1, 0.10000001047548586`], 
           Hue[0.6499999747414913, 1, 0.10000003497331982`], 
           Hue[0.6499999790874041, 1, 0.10000002895590207`], 
           Hue[0.6499999923535981, 1, 0.10000001058732584`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499872761827474, 1, 0.1000176175931189], 
           Hue[0.6499872705232843, 1, 0.10001762542929865`], 
           Hue[0.6499999987909204, 1, 0.1000000016741103], 
           Hue[0.6499999718281185, 1, 0.1000000390072206], 
           Hue[0.6499998378409675, 1, 0.10000022452789123`], 
           Hue[0.6499999925396918, 1, 0.10000001032965763`], 
           Hue[0.6499999726116505, 1, 0.10000003792233012`], 
           Hue[0.6499998474023537, 1, 0.10000021128904879`], 
           Hue[0.6499987373870405, 1, 0.1000017482333285], 
           Hue[0.6499930394481843, 1, 0.10000963768712945`], 
           Hue[0.6499740840158208, 1, 0.10003588367040199`], 
           Hue[0.6499368000496959, 1, 0.10008750762349808`], 
           Hue[0.6499872851621001, 1, 0.10001760516016904`], 
           Hue[0.6499997694648034, 1, 0.10000031920257986`], 
           Hue[0.6499999846564967, 1, 0.10000002124485077`], 
           Hue[0.6499999947460028, 1, 0.10000000727476545`], 
           Hue[0.6499999946476501, 1, 0.10000000741094602`], 
           Hue[0.6499999328468428, 1, 0.1000000929812946], 
           Hue[0.6499999957862591, 1, 0.10000000583441045`], 
           Hue[0.6499999459827224, 1, 0.1000000747931536], 
           Hue[0.6499996132007059, 1, 0.10000053556825345`], 
           Hue[0.6499999531810358, 1, 0.10000006482625813`], 
           Hue[0.6499997664208694, 1, 0.1000003234172578], 
           Hue[0.6499978004542722, 1, 0.1000030455248539], 
           Hue[0.649990533972543, 1, 0.1000131068072481], 
           Hue[0.6499701121736939, 1, 0.10004138314411615`], 
           Hue[0.6499332456084079, 1, 0.10009242915758908`], 
           Hue[0.6499872728813457, 1, 0.10001762216429065`], 
           Hue[0.6499999988522372, 1, 0.10000000158920994`], 
           Hue[0.6499997205474622, 1, 0.10000038693428308`], 
           Hue[0.6499988198134662, 1, 0.1000016341044314], 
           Hue[0.649997998599588, 1, 0.10000277116980137`], 
           Hue[0.6499925051018157, 1, 0.10001037755133219`], 
           Hue[0.6499899497720244, 1, 0.10001391570027392`], 
           Hue[0.6499658530333119, 1, 0.10004728041541434`], 
           Hue[0.6498899315253245, 1, 0.10015240250339691`], 
           Hue[0.6498257856160936, 1, 0.10024121991617815`], 
           Hue[0.6498206455449007, 1, 0.10024833693782984`], 
           Hue[0.6499999333097417, 1, 0.10000009234035774`], 
           Hue[0.6499999042768432, 1, 0.1000001325397556], 
           Hue[0.6499993878957052, 1, 0.10000084752902356`], 
           Hue[0.6499966175523572, 1, 0.10000468338904392`], 
           Hue[0.6499967448026513, 1, 0.10000450719632889`], 
           Hue[0.6499849888742334, 1, 0.1000207846356768], 
           Hue[0.6499482995199596, 1, 0.10007158528005594`], 
           Hue[0.6498637789166501, 1, 0.10018861380771515`], 
           Hue[0.6498245814294037, 1, 0.10024288725159497`], 
           Hue[0.6498206206758443, 1, 0.10024837137190787`], 
           Hue[0.6499980650680817, 1, 0.10000267913650228`], 
           Hue[0.6499887061646138, 1, 0.10001563761822711`], 
           Hue[0.6499957081322433, 1, 0.10000594258612468`], 
           Hue[0.6499929243432877, 1, 0.10000979706314017`], 
           Hue[0.6499949826603763, 1, 0.10000694708563292`], 
           Hue[0.6499777227220929, 1, 0.10003084546171759`], 
           Hue[0.6499234404741348, 1, 0.1001060054973519], 
           Hue[0.6497919036628964, 1, 0.1002881333898358], 
           Hue[0.6494291374898146, 1, 0.1007904250141029], 
           Hue[0.6499942406207414, 1, 0.10000797452512729`], 
           Hue[0.6499908589738949, 1, 0.10001265680537647`], 
           Hue[0.6499711554269493, 1, 0.10003993863960878`], 
           Hue[0.6499552803098146, 1, 0.10006191957102599`], 
           Hue[0.6499690892099143, 1, 0.10004279955550338`], 
           Hue[0.649886621235013, 1, 0.10015698598228986`], 
           Hue[0.6497011754290651, 1, 0.1004137570982175], 
           Hue[0.6495400008935742, 1, 0.10063692183966653`], 
           Hue[0.6498257856160936, 1, 0.10024121991617815`], 
           Hue[0.6496731893555393, 1, 0.10045250704617642`], 
           Hue[0.6496727141920235, 1, 0.10045316496489053`], 
           Hue[0.6499872705232843, 1, 0.10001762542929866`], 
           Hue[0.6498206455449007, 1, 0.10024833693782982`], 
           Hue[0.6498245814294036, 1, 0.10024288725159507`], 
           Hue[0.6430994341869618, 1, 0.10955462958728375`], 
           Hue[0.6431138697201356, 1, 0.10953464192596608`], 
           Hue[0.6494291374898145, 1, 0.10079042501410311`], 
           Hue[0.649461400807902, 1, 0.10074575272752026`], 
           Hue[0.6498376968729129, 1, 0.10022472740673605`], 
           Hue[0.6499872761827474, 1, 0.1000176175931189], 
           Hue[0.6319953620941587, 1, 0.12492949863885709`], 
           Hue[0.6227153440039706, 1, 0.13777875445604082`], 
           Hue[0.6233200715729882, 1, 0.1369414393604779], 
           Hue[0.6499334584002099, 1, 0.10009213452278638`], 
           Hue[0.6499332456084078, 1, 0.10009242915758913`], 
           Hue[0.6499558704947553, 1, 0.10006110239187734`], 
           Hue[0.6498637789166501, 1, 0.10018861380771525`], 
           Hue[0.6499035776827975, 1, 0.1001335078238189], 
           Hue[0.6499701121736939, 1, 0.10004138314411617`], 
           Hue[0.6499807215560938, 1, 0.10002669323002401`], 
           Hue[0.649791903662896, 1, 0.10028813338983632`], 
           Hue[0.6498491275148004, 1, 0.10020890036412251`], 
           Hue[0.6499482995199596, 1, 0.100071585280056], 
           Hue[0.6499651447615216, 1, 0.10004826109943168`], 
           Hue[0.649990533972543, 1, 0.10001310680724812`], 
           Hue[0.6499941257642842, 1, 0.10000813355714501`], 
           Hue[0.6499978004542722, 1, 0.10000304552485391`], 
           Hue[0.6499997664208694, 1, 0.1000003234172578], 
           Hue[0.6499999113420365, 1, 0.10000012275718022`], 
           Hue[0.649701175429064, 1, 0.10041375709821909`], 
           Hue[0.6497822958439443, 1, 0.10030143652376938`], 
           Hue[0.6499234404741345, 1, 0.10010600549735216`], 
           Hue[0.6499477127625017, 1, 0.10007239771345909`], 
           Hue[0.6499777227220929, 1, 0.1000308454617176], 
           Hue[0.6499849888742334, 1, 0.10002078463567683`], 
           Hue[0.6499904461340845, 1, 0.10001322842972922`], 
           Hue[0.6499966175523572, 1, 0.10000468338904392`], 
           Hue[0.6499987037961257, 1, 0.1000017947438261], 
           Hue[0.6499996132007059, 1, 0.10000053556825345`], 
           Hue[0.6499999459827224, 1, 0.1000000747931536], 
           Hue[0.6499999958851704, 1, 0.10000000569745643`], 
           Hue[0.6499957081322433, 1, 0.1000059425861247], 
           Hue[0.649971155426949, 1, 0.10003993863960904`], 
           Hue[0.6495407493861274, 1, 0.10063588546536209`], 
           Hue[0.6227153440039657, 1, 0.1377787544560476], 
           Hue[0.06744763098817208, 1, 0.9066109724779156], 
           Hue[0.03698777989743762, 1, 0.9487861509112402], 
           Hue[0.02100855953590086, 1, 0.9709112252579835], 
           Hue[0.06747929559368648, 1, 0.9065671291779726], 
           Hue[0.021017919604245705`, 1, 0.9708982651633521], 
           Hue[0.004312626695720967, 1, 0.9940286707290017], 
           Hue[0.06747929559223431, 1, 0.9065671291799833], 
           Hue[0.622715344004319, 1, 0.13777875445555823`], 
           Hue[0.6430994341870176, 1, 0.1095546295872063], 
           Hue[0.649540000893586, 1, 0.10063692183965024`], 
           Hue[0.6496696618168508, 1, 0.10045739133051425`], 
           Hue[0.6496727141920339, 1, 0.10045316496487627`], 
           Hue[0.6498866212350136, 1, 0.10015698598228884`], 
           Hue[0.6499227855829618, 1, 0.10010691226974526`], 
           Hue[0.6499857386104357, 1, 0.10001974653939676`], 
           Hue[0.6499979781484426, 1, 0.10000279948677178`], 
           Hue[0.6499997857288967, 1, 0.10000029668306615`], 
           Hue[0.6499999328468428, 1, 0.1000000929812946], 
           Hue[0.6499999843722919, 1, 0.10000002163836517`], 
           Hue[0.6499999946476501, 1, 0.10000000741094602`], 
           Hue[0.6499999333097417, 1, 0.10000009234035774`], 
           Hue[0.6499999747414913, 1, 0.10000003497331982`], 
           Hue[0.6499995050240461, 1, 0.10000068535132074`], 
           Hue[0.6499956798469451, 1, 0.10000598175038378`], 
           Hue[0.6499710401022167, 1, 0.10004009832000761`], 
           Hue[0.6430994341869646, 1, 0.10955462958727992`], 
           Hue[0.6431138697201368, 1, 0.1095346419259644], 
           Hue[0.6233200715729781, 1, 0.13694143936049186`], 
           Hue[0.004309068890287815, 1, 0.9940335969211399], 
           Hue[0.02101791960398325, 1, 0.9708982651637156], 
           Hue[0.03701244893325295, 1, 0.9487519937847267], 
           Hue[0.021017919602528856`, 1, 0.9708982651657293], 
           Hue[0.004309068888626699, 1, 0.99403359692344], 
           Hue[0.02100855953301084, 1, 0.9709112252619849], 
           Hue[0.06744763098356343, 1, 0.9066109724842968], 
           Hue[0.6233201302809892, 1, 0.13694135807247645`], 
           Hue[0.6496731893555265, 1, 0.10045250704619413`], 
           Hue[0.6499999658355468, 1, 0.10000004730462761`], 
           Hue[0.6499999333097417, 1, 0.10000009234035774`], 
           Hue[0.6499999947460028, 1, 0.10000000727476545`], 
           Hue[0.6499999199446159, 1, 0.10000011084591645`], 
           Hue[0.6499996941293525, 1, 0.10000042351320422`], 
           Hue[0.6499999843722919, 1, 0.10000002163836517`], 
           Hue[0.6499991262252099, 1, 0.10000120984201699`], 
           Hue[0.6499972533523636, 1, 0.1000038030505735], 
           Hue[0.6499928827959313, 1, 0.10000985459024907`], 
           Hue[0.6499817331204784, 1, 0.10002529260241469`], 
           Hue[0.6499551253828276, 1, 0.1000621340853157], 
           Hue[0.021017919602568935`, 1, 0.9708982651656738], 
           Hue[0.03698777989336832, 1, 0.9487861509168746], 
           Hue[0.6499711554269488, 1, 0.10003993863960928`], 
           Hue[0.6499957081322433, 1, 0.1000059425861247], 
           Hue[0.6499999958851704, 1, 0.10000000569745643`], 
           Hue[0.649999454487984, 1, 0.10000075532432992`], 
           Hue[0.6499983016594818, 1, 0.10000235154840982`], 
           Hue[0.6499954680826809, 1, 0.10000627496244185`], 
           Hue[0.6499719284481866, 1, 0.10003886830251078`], 
           Hue[0.6499999113420365, 1, 0.10000012275718022`], 
           Hue[0.6499997694648034, 1, 0.10000031920257986`], 
           Hue[0.6499971342997227, 1, 0.10000396789269159`], 
           Hue[0.6499878647654108, 1, 0.1000168026325082], 
           Hue[0.649981132862961, 1, 0.10002612372820785`], 
           Hue[0.6499931260501088, 1, 0.1000095177767724], 
           Hue[0.6499888903804653, 1, 0.10001538255012504`], 
           Hue[0.6319953620942506, 1, 0.12492949863873], 
           Hue[0.6353293129837486, 1, 0.12031325894557884`], 
           Hue[0.6498245814294037, 1, 0.10024288725159497`], 
           Hue[0.6494291374898146, 1, 0.10079042501410287`], 
           Hue[0.622715344004306, 1, 0.13777875445557644`], 
           Hue[0.6233201302809824, 1, 0.13694135807248597`], 
           Hue[0.6499872761827475, 1, 0.1000176175931189], 
           Hue[0.6498206206758443, 1, 0.10024837137190785`], 
           Hue[0.6430994341870134, 1, 0.10955462958721218`], 
           Hue[0.6498257856160936, 1, 0.1002412199161781], 
           Hue[0.6498401940009914, 1, 0.1002212698447812], 
           Hue[0.6499872705232843, 1, 0.10001762542929865`], 
           Hue[0.6495407493861158, 1, 0.10063588546537817`], 
           Hue[0.6499710401022171, 1, 0.10004009832000711`], 
           Hue[0.6499368000496959, 1, 0.1000875076234981], 
           Hue[0.6499579090308498, 1, 0.10005827980343877`], 
           Hue[0.6499817331204784, 1, 0.10002529260241466`], 
           Hue[0.6499956798469451, 1, 0.10000598175038375`], 
           Hue[0.6499711554269488, 1, 0.10003993863960926`], 
           Hue[0.6498899315253245, 1, 0.10015240250339695`], 
           Hue[0.649920525041201, 1, 0.10011004225064477`], 
           Hue[0.6499740840158208, 1, 0.10003588367040202`], 
           Hue[0.6499830415932077, 1, 0.10002348087094316`], 
           Hue[0.6499930394481843, 1, 0.10000963768712946`], 
           Hue[0.6494291374898145, 1, 0.10079042501410312`], 
           Hue[0.649461400807902, 1, 0.10074575272752026`], 
           Hue[0.6499878647654108, 1, 0.1000168026325082], 
           Hue[0.6499871127135868, 1, 0.10001784393503366`], 
           Hue[0.6499972533523636, 1, 0.1000038030505735], 
           Hue[0.6499995050240461, 1, 0.10000068535132073`], 
           Hue[0.6499957081322433, 1, 0.1000059425861247], 
           Hue[0.6499658530333119, 1, 0.10004728041541437`], 
           Hue[0.649976311639638, 1, 0.10003279926819361`], 
           Hue[0.6499925051018156, 1, 0.1000103775513322], 
           Hue[0.6499955738243941, 1, 0.1000061285508389], 
           Hue[0.6499987373870405, 1, 0.1000017482333285], 
           Hue[0.6499998474023537, 1, 0.10000021128904879`], 
           Hue[0.6498245814294036, 1, 0.10024288725159508`], 
           Hue[0.6498376968729129, 1, 0.10022472740673605`], 
           Hue[0.6499931260501088, 1, 0.1000095177767724], 
           Hue[0.6499983016594818, 1, 0.10000235154840982`], 
           Hue[0.6499981812644314, 1, 0.10000251824924883`], 
           Hue[0.6499996941293525, 1, 0.10000042351320422`], 
           Hue[0.6499999199446159, 1, 0.10000011084591645`], 
           Hue[0.6499999333097417, 1, 0.10000009234035774`], 
           Hue[0.6499999661022928, 1, 0.10000004693528683`], 
           Hue[0.6499334584002099, 1, 0.10009213452278633`], 
           Hue[0.6499560274362279, 1, 0.10006088508829983`], 
           Hue[0.6498257856160936, 1, 0.10024121991617813`], 
           Hue[0.6498401940009914, 1, 0.10022126984478122`], 
           Hue[0.6499942406207414, 1, 0.10000797452512729`], 
           Hue[0.649995048229519, 1, 0.10000685629758907`], 
           Hue[0.6499988198134662, 1, 0.1000016341044314], 
           Hue[0.649999231209965, 1, 0.10000106447851004`], 
           Hue[0.6499998378409675, 1, 0.10000022452789123`], 
           Hue[0.6499999718281185, 1, 0.1000000390072206], 
           Hue[0.6499999988522372, 1, 0.10000000158920994`], 
           Hue[0.6499872728813456, 1, 0.10001762216429065`], 
           Hue[0.649998861931212, 1, 0.10000157578755257`], 
           Hue[0.6499998099007703, 1, 0.10000026321431808`], 
           Hue[0.6499999531810358, 1, 0.10000006482625813`], 
           Hue[0.6499999747414913, 1, 0.10000003497331982`], 
           Hue[0.6499999957862591, 1, 0.10000000583441045`], 
           Hue[0.6499999846564967, 1, 0.10000002124485076`], 
           Hue[0.6499872851621001, 1, 0.10001760516016903`], 
           Hue[0.6499992554553338, 1, 0.10000103090799936`], 
           Hue[0.6499999068044836, 1, 0.10000012903994587`], 
           Hue[0.6499999726116505, 1, 0.10000003792233012`], 
           Hue[0.6499999925396918, 1, 0.10000001032965763`], 
           Hue[0.6499999987909204, 1, 0.1000000016741103], 
           Hue[0.6499182640119672, 1, 0.10011317290650702`], 
           Hue[0.6499998703971854, 1, 0.100000179450051], 
           Hue[0.6499179671599283, 1, 0.10011358393240688`], 
           Hue[0.6499999490745912, 1, 0.10000007051210441`], 
           Hue[0.6499182640119672, 1, 0.10011317290650702`], 
           Hue[0.6499453175635969, 1, 0.10007571414271206`], 
           Hue[0.6463627197888726, 1, 0.10503623413848405`], 
           Hue[0.6458360441378571, 1, 0.10576547734758247`], 
           Hue[0.6499904192577803, 1, 0.1000132656430734], 
           Hue[0.6499855624175456, 1, 0.10001999049878305`], 
           Hue[0.6499947544739892, 1, 0.100007263036015], 
           Hue[0.6499927474735677, 1, 0.10001004195967546`], 
           Hue[0.6499980833227129, 1, 0.10000265386085902`], 
           Hue[0.6499975602665753, 1, 0.10000337809243423`], 
           Hue[0.6499995339718821, 1, 0.10000064526970168`], 
           Hue[0.649999442352031, 1, 0.10000077212795708`], 
           Hue[0.6499998703971854, 1, 0.100000179450051], 
           Hue[0.6499999589602237, 1, 0.1000000568243058], 
           Hue[0.6369343337826544, 1, 0.11809092245478625`], 
           Hue[0.6233200715735031, 1, 0.13694143935976502`], 
           Hue[0.6463627197890695, 1, 0.10503623413821153`], 
           Hue[0.6431138697203481, 1, 0.10953464192567193`], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.649952257675664, 1, 0.100066104756773], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499930428076302, 1, 0.10000963303558903`], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499992118878316, 1, 0.10000109123223314`], 
           Hue[0.646362719788873, 1, 0.10503623413848345`], 
           Hue[0.647195627881372, 1, 0.10388297677963883`], 
           Hue[0.6458360441378573, 1, 0.10576547734758222`], 
           Hue[0.6464975004715674, 1, 0.10484961473167599`], 
           Hue[0.6453822585486565, 1, 0.10639379585570642`], 
           Hue[0.6451837682394977, 1, 0.10666862859146468`], 
           Hue[0.6233200715734802, 1, 0.1369414393597967], 
           Hue[0.6369343337826358, 1, 0.11809092245481205`], 
           Hue[0.6466909526577987, 1, 0.10458175785843253`], 
           Hue[0.6464557249198083, 1, 0.10490745780334242`], 
           Hue[0.6499179671599284, 1, 0.10011358393240688`], 
           Hue[0.6499452554080252, 1, 0.10007580020427294`], 
           Hue[0.6431138697203426, 1, 0.10953464192567951`], 
           Hue[0.6463627197890748, 1, 0.10503623413820415`], 
           Hue[0.6453822585486565, 1, 0.10639379585570649`], 
           Hue[0.6474229577245602, 1, 0.10356821238137827`], 
           Hue[0.6464557249198084, 1, 0.10490745780334221`], 
           Hue[0.646690952657799, 1, 0.10458175785843228`], 
           Hue[0.6474229577245603, 1, 0.10356821238137813`], 
           Hue[0.6499904693183663, 1, 0.1000131963284158], 
           Hue[0.6499857545886895, 1, 0.10001972441566084`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6499949320825263, 1, 0.10000701711650203`], 
           Hue[0.6499931307624713, 1, 0.10000951125196281`], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499982711804069, 1, 0.10000239375020598`], 
           Hue[0.6499978877143096, 1, 0.10000292470326372`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499996319583529, 1, 0.1000005095961268], 
           Hue[0.649999590533435, 1, 0.1000005669537054], 
           Hue[0.6499999490745912, 1, 0.10000007051210441`], 
           Hue[0.6499999853568917, 1, 0.10000002027507307`], 
           Hue[0.6499904192577803, 1, 0.1000132656430734], 
           Hue[0.6499947544739892, 1, 0.100007263036015], 
           Hue[0.6499980833227129, 1, 0.10000265386085902`], 
           Hue[0.6499995339718821, 1, 0.10000064526970168`], 
           Hue[0.6499904693183663, 1, 0.1000131963284158], 
           Hue[0.6499949320825263, 1, 0.10000701711650203`], 
           Hue[0.6499982711804069, 1, 0.10000239375020598`], 
           Hue[0.6499996319583529, 1, 0.1000005095961268], 
           Hue[0.6499996319583529, 1, 0.1000005095961268], 
           Hue[0.649999590533435, 1, 0.1000005669537054], 
           Hue[0.6499982711804069, 1, 0.10000239375020598`], 
           Hue[0.6499978877143096, 1, 0.10000292470326372`], 
           Hue[0.6499949320825263, 1, 0.10000701711650203`], 
           Hue[0.6499931307624713, 1, 0.1000095112519628], 
           Hue[0.6499904693183663, 1, 0.10001319632841578`], 
           Hue[0.6499857545886895, 1, 0.10001972441566084`], 
           Hue[0.649982351773809, 1, 0.10002443600549525`], 
           Hue[0.6499904494586252, 1, 0.10001322382651898`], 
           Hue[0.6499947848408922, 1, 0.10000722098953381`], 
           Hue[0.6499981001297528, 1, 0.10000263058957315`], 
           Hue[0.6499852938294347, 1, 0.10002036239001359`], 
           Hue[0.6499995394710767, 1, 0.10000063765543235`], 
           Hue[0.6499958918832327, 1, 0.10000568816167785`], 
           Hue[0.6499995339718821, 1, 0.10000064526970168`], 
           Hue[0.649999442352031, 1, 0.10000077212795708`], 
           Hue[0.6499980833227129, 1, 0.100002653860859], 
           Hue[0.6499975602665753, 1, 0.10000337809243423`], 
           Hue[0.6499947544739892, 1, 0.100007263036015], 
           Hue[0.6499927474735677, 1, 0.10001004195967544`], 
           Hue[0.6499904192577803, 1, 0.10001326564307339`], 
           Hue[0.6499855624175456, 1, 0.10001999049878303`], 
           Hue[0.649982271892414, 1, 0.10002454661050371`], 
           Hue[0.6499905001789897, 1, 0.10001315359832193`], 
           Hue[0.649994966060422, 1, 0.10000697007018497`], 
           Hue[0.6499652560339055, 1, 0.10004810702997693`], 
           Hue[0.6499982896776413, 1, 0.10000236813865063`], 
           Hue[0.6499874785448396, 1, 0.10001733739945283`], 
           Hue[0.6499999490745912, 1, 0.10000007051210441`], 
           Hue[0.6498401940009914, 1, 0.10022126984478122`], 
           Hue[0.6498965941389109, 1, 0.10014317734612337`], 
           Hue[0.6498307067503871, 1, 0.10023440603792551`], 
           Hue[0.6498376968729129, 1, 0.10022472740673594`], 
           Hue[0.6498948240795815, 1, 0.10014562819750247`], 
           Hue[0.6499575453317327, 1, 0.10005878338683179`], 
           Hue[0.6498475221859048, 1, 0.10021112312720874`], 
           Hue[0.6499996319583529, 1, 0.1000005095961268], 
           Hue[0.6499982711804069, 1, 0.10000239375020598`], 
           Hue[0.6499982896776413, 1, 0.10000236813865063`], 
           Hue[0.64999791089883, 1, 0.10000289260162012`], 
           Hue[0.6499874785448396, 1, 0.10001733739945283`], 
           Hue[0.6499892785262673, 1, 0.10001484511747614`], 
           Hue[0.6499949320825263, 1, 0.10000701711650203`], 
           Hue[0.6499652560339055, 1, 0.10004810702997692`], 
           Hue[0.6499575453317327, 1, 0.10005878338683176`], 
           Hue[0.6498475221859049, 1, 0.10021112312720867`], 
           Hue[0.6498693537502516, 1, 0.10018089480734399`], 
           Hue[0.649994966060422, 1, 0.10000697007018497`], 
           Hue[0.6499931798173987, 1, 0.10000944332975563`], 
           Hue[0.6499728876119557, 1, 0.10003754022959982`], 
           Hue[0.6499904693183663, 1, 0.10001319632841578`], 
           Hue[0.649982351773809, 1, 0.10002443600549525`], 
           Hue[0.6498401940009914, 1, 0.1002212698447812], 
           Hue[0.6474229577245604, 1, 0.10356821238137796`], 
           Hue[0.6499905001789897, 1, 0.10001315359832193`], 
           Hue[0.6499858078426721, 1, 0.10001965067937708`], 
           Hue[0.6466909526577986, 1, 0.10458175785843268`], 
           Hue[0.646455724919808, 1, 0.1049074578033429], 
           Hue[0.645383322492119, 1, 0.1063923227032198], 
           Hue[0.6474229577245602, 1, 0.10356821238137834`], 
           Hue[0.6453822585486587, 1, 0.10639379585570329`], 
           Hue[0.6451837682394984, 1, 0.10666862859146374`], 
           Hue[0.6458367128760315, 1, 0.10576455140241796`], 
           Hue[0.6410145533798334, 1, 0.11244138762792309`], 
           Hue[0.6451760894519943, 1, 0.10667926075877707`], 
           Hue[0.6427222120230419, 1, 0.11007693719886505`], 
           Hue[0.6499904494586252, 1, 0.10001322382651898`], 
           Hue[0.6499856125038711, 1, 0.10001992114848617`], 
           Hue[0.6464557249198024, 1, 0.10490745780335048`], 
           Hue[0.6466909526577906, 1, 0.10458175785844377`], 
           Hue[0.6233201302808182, 1, 0.13694135807271327`], 
           Hue[0.6388748463426085, 1, 0.11540405891023438`], 
           Hue[0.6398576691566518, 1, 0.11404322732155919`], 
           Hue[0.6282755077833603, 1, 0.1300800661461166], 
           Hue[0.6498948240795815, 1, 0.10014562819750256`], 
           Hue[0.649982271892414, 1, 0.10002454661050372`], 
           Hue[0.6499947848408922, 1, 0.10000722098953381`], 
           Hue[0.6499927911642357, 1, 0.10000998146490438`], 
           Hue[0.6498307067503871, 1, 0.10023440603792552`], 
           Hue[0.6498594518723236, 1, 0.10019460509985961`], 
           Hue[0.6453822585486075, 1, 0.10639379585577424`], 
           Hue[0.6453833224920709, 1, 0.1063923227032865], 
           Hue[0.6456533105267098, 1, 0.10601849311686341`], 
           Hue[0.6499852938294347, 1, 0.10002036239001359`], 
           Hue[0.6499879539739198, 1, 0.10001667911303415`], 
           Hue[0.6499981001297528, 1, 0.10000263058957315`], 
           Hue[0.6499975817595002, 1, 0.10000334833299979`], 
           Hue[0.6451760894519326, 1, 0.10667926075886258`], 
           Hue[0.6447422602882784, 1, 0.10727994729315303`], 
           Hue[0.6427222120230224, 1, 0.11007693719889208`], 
           Hue[0.6432412882885953, 1, 0.10935821621579125`], 
           Hue[0.6499958918832327, 1, 0.10000568816167785`], 
           Hue[0.6499964672535286, 1, 0.10000489149511434`], 
           Hue[0.6499995394710767, 1, 0.10000063765543235`], 
           Hue[0.6499994488275219, 1, 0.10000076316189273`], 
           Hue[0.6410145533799854, 1, 0.11244138762771266`], 
           Hue[0.6398576691567839, 1, 0.11404322732137623`], 
           Hue[0.6282755077836939, 1, 0.13008006614565468`], 
           Hue[0.6309334967136163, 1, 0.12639977378114664`], 
           Hue[0.6422329045977426, 1, 0.11075443978774097`], 
           Hue[0.6458367128759976, 1, 0.1057645514024648], 
           Hue[0.6388748463430168, 1, 0.11540405890966907`], 
           Hue[0.6363391370261278, 1, 0.11891504104074618`], 
           Hue[0.6233201302808241, 1, 0.13694135807270516`], 
           Hue[0.6499998703971854, 1, 0.100000179450051], 
           Hue[0.6388748463426072, 1, 0.11540405891023633`], 
           Hue[0.6363391370257134, 1, 0.11891504104131992`], 
           Hue[0.645836712875852, 1, 0.10576455140266648`], 
           Hue[0.6499995339718821, 1, 0.10000064526970168`], 
           Hue[0.6410145533798326, 1, 0.11244138762792409`], 
           Hue[0.6422329045975737, 1, 0.11075443978797506`], 
           Hue[0.6282755077833523, 1, 0.13008006614612758`], 
           Hue[0.6309334967132403, 1, 0.12639977378166728`], 
           Hue[0.6398576691566503, 1, 0.1140432273215611], 
           Hue[0.6499995394710767, 1, 0.10000063765543235`], 
           Hue[0.6499994488275219, 1, 0.10000076316189273`], 
           Hue[0.6499958918832327, 1, 0.10000568816167785`], 
           Hue[0.6499964672535286, 1, 0.10000489149511434`], 
           Hue[0.6499980833227129, 1, 0.100002653860859], 
           Hue[0.6427222120230416, 1, 0.1100769371988655], 
           Hue[0.643241288288611, 1, 0.10935821621576942`], 
           Hue[0.6451760894519946, 1, 0.10667926075877684`], 
           Hue[0.644742260288343, 1, 0.1072799472930636], 
           Hue[0.6499981001297528, 1, 0.10000263058957315`], 
           Hue[0.6499975817595002, 1, 0.10000334833299979`], 
           Hue[0.6499852938294347, 1, 0.10002036239001358`], 
           Hue[0.6499879539739198, 1, 0.10001667911303413`], 
           Hue[0.6499947544739892, 1, 0.100007263036015], 
           Hue[0.6453833224921196, 1, 0.10639232270321906`], 
           Hue[0.6456533105267612, 1, 0.10601849311679216`], 
           Hue[0.6498307067503872, 1, 0.10023440603792542`], 
           Hue[0.6498594518723237, 1, 0.10019460509985952`], 
           Hue[0.6499947848408922, 1, 0.1000072209895338], 
           Hue[0.6499927911642358, 1, 0.10000998146490438`], 
           Hue[0.6499904192577803, 1, 0.10001326564307339`], 
           Hue[0.649982271892414, 1, 0.10002454661050371`], 
           Hue[0.6498376968729129, 1, 0.10022472740673594`], 
           Hue[0.6282755077836376, 1, 0.13008006614573261`], 
           Hue[0.6410145533800203, 1, 0.11244138762766413`], 
           Hue[0.6388748463430075, 1, 0.115404058909682], 
           Hue[0.6499904494586252, 1, 0.10001322382651896`], 
           Hue[0.6499856125038711, 1, 0.10001992114848615`], 
           Hue[0.6427222120230901, 1, 0.1100769371987983], 
           Hue[0.6451760894520181, 1, 0.10667926075874427`], 
           Hue[0.6422329045977838, 1, 0.11075443978768394`], 
           Hue[0.6458367128758516, 1, 0.10576455140266693`], 
           Hue[0.6453833224921226, 1, 0.10639232270321484`], 
           Hue[0.6499905001789897, 1, 0.10001315359832193`], 
           Hue[0.6499858078426721, 1, 0.1000196506793771], 
           Hue[0.6498965941389109, 1, 0.10014317734612337`], 
           Hue[0.649982351773809, 1, 0.10002443600549525`], 
           Hue[0.6499652560339055, 1, 0.10004810702997693`], 
           Hue[0.6499728876119557, 1, 0.10003754022959983`], 
           Hue[0.649994966060422, 1, 0.10000697007018497`], 
           Hue[0.6499931798173987, 1, 0.10000944332975564`], 
           Hue[0.6498475221859048, 1, 0.10021112312720871`], 
           Hue[0.6498693537502516, 1, 0.10018089480734403`], 
           Hue[0.6499575453317327, 1, 0.10005878338683179`], 
           Hue[0.6499874785448396, 1, 0.10001733739945283`], 
           Hue[0.6499892785262672, 1, 0.10001484511747614`], 
           Hue[0.6499982896776413, 1, 0.10000236813865063`], 
           Hue[0.64999791089883, 1, 0.10000289260162012`], 
           Hue[0.6498475221859049, 1, 0.10021112312720867`], 
           Hue[0.6499652560339055, 1, 0.10004810702997692`], 
           Hue[0.6498948240795815, 1, 0.10014562819750256`], 
           Hue[0.6498307067503872, 1, 0.1002344060379254], 
           Hue[0.6498965941389109, 1, 0.10014317734612338`], 
           Hue[0.6499999490745912, 1, 0.10000007051210441`], 
           Hue[0.6499999853568917, 1, 0.10000002027507307`], 
           Hue[0.6499874785448396, 1, 0.10001733739945283`], 
           Hue[0.6499982896776413, 1, 0.10000236813865063`], 
           Hue[0.6499728876119557, 1, 0.10003754022959982`], 
           Hue[0.649994966060422, 1, 0.10000697007018497`], 
           Hue[0.6499905001789897, 1, 0.10001315359832193`], 
           Hue[0.649982271892414, 1, 0.10002454661050372`], 
           Hue[0.6499998703971854, 1, 0.100000179450051], 
           Hue[0.6499999589602237, 1, 0.1000000568243058], 
           Hue[0.6499958918832327, 1, 0.10000568816167785`], 
           Hue[0.6499995394710767, 1, 0.10000063765543235`], 
           Hue[0.6499852938294347, 1, 0.10002036239001358`], 
           Hue[0.6499981001297528, 1, 0.10000263058957315`], 
           Hue[0.6499947848408922, 1, 0.1000072209895338], 
           Hue[0.6499904494586252, 1, 0.10001322382651896`], 
           Hue[0.649982351773809, 1, 0.10002443600549525`], 
           Hue[0.6499998378409675, 1, 0.10000022452789123`], 
           Hue[0.6499999079226575, 1, 0.10000012749170509`], 
           Hue[0.6499999079226575, 1, 0.10000012749170509`], 
           Hue[0.6499999105318043, 1, 0.10000012387904018`], 
           Hue[0.6499988198134662, 1, 0.1000016341044314], 
           Hue[0.649999732409757, 1, 0.10000037050956732`], 
           Hue[0.6499992964406758, 1, 0.10000097415906437`], 
           Hue[0.6499997205474622, 1, 0.10000038693428308`], 
           Hue[0.6499997241332024, 1, 0.10000038196941208`], 
           Hue[0.6499992203039526, 1, 0.10000107957914259`], 
           Hue[0.649999015708746, 1, 0.10000136286481327`], 
           Hue[0.649998333888502, 1, 0.10000230692361262`], 
           Hue[0.6499942406207414, 1, 0.10000797452512729`], 
           Hue[0.6499964646335001, 1, 0.10000489512284605`], 
           Hue[0.6499980650680817, 1, 0.10000267913650228`], 
           Hue[0.6499981753461317, 1, 0.10000252644381777`], 
           Hue[0.6499952966832021, 1, 0.10000651228479705`], 
           Hue[0.6499959630133506, 1, 0.10000558967382225`], 
           Hue[0.6499933017246096, 1, 0.10000927453515605`], 
           Hue[0.6499818743816113, 1, 0.10002509701007671`], 
           Hue[0.6499886776939561, 1, 0.10001567703913772`], 
           Hue[0.6499908589738949, 1, 0.10001265680537647`], 
           Hue[0.6499484530937932, 1, 0.10007137263936332`], 
           Hue[0.6499180307352563, 1, 0.10011349590502969`], 
           Hue[0.6499927911642357, 1, 0.10000998146490438`], 
           Hue[0.6499806446197294, 1, 0.10002679975729786`], 
           Hue[0.6499879539739198, 1, 0.10001667911303415`], 
           Hue[0.6499956092416016, 1, 0.10000607951162864`], 
           Hue[0.6499334584002099, 1, 0.10009213452278638`], 
           Hue[0.6499975817595002, 1, 0.1000033483329998], 
           Hue[0.6499931770229507, 1, 0.10000944719899144`], 
           Hue[0.6499964672535286, 1, 0.10000489149511434`], 
           Hue[0.6499987913150758, 1, 0.10000167356374128`], 
           Hue[0.6499999113420365, 1, 0.10000012275718022`], 
           Hue[0.6499998555397438, 1, 0.10000020002189328`], 
           Hue[0.6499996941293525, 1, 0.10000042351320422`], 
           Hue[0.6499998322292071, 1, 0.10000023229802099`], 
           Hue[0.6499997586209825, 1, 0.10000033421710122`], 
           Hue[0.6499998535240952, 1, 0.10000020281279137`], 
           Hue[0.6499983016594818, 1, 0.10000235154840982`], 
           Hue[0.6499995771839885, 1, 0.10000058543755444`], 
           Hue[0.6499990154332835, 1, 0.10000136324622286`], 
           Hue[0.649999454487984, 1, 0.10000075532432992`], 
           Hue[0.6499995171479255, 1, 0.10000066856441088`], 
           Hue[0.6499985394928872, 1, 0.10000202224061779`], 
           Hue[0.6499987788443321, 1, 0.10000169083092485`], 
           Hue[0.6499978883756586, 1, 0.10000292378754969`], 
           Hue[0.6499931260501088, 1, 0.1000095177767724], 
           Hue[0.6499958515834572, 1, 0.10000574396136695`], 
           Hue[0.6499971342997227, 1, 0.10000396789269159`], 
           Hue[0.6499975148056737, 1, 0.100003441038298], 
           Hue[0.6499955764751569, 1, 0.1000061248805519], 
           Hue[0.6499925770634212, 1, 0.10001027791218614`], 
           Hue[0.6499805463167408, 1, 0.10002693586912803`], 
           Hue[0.6499879519206576, 1, 0.1000166819560126], 
           Hue[0.6499888903804653, 1, 0.10001538255012504`], 
           Hue[0.6499482456526285, 1, 0.10007165986559136`], 
           Hue[0.6499183018776694, 1, 0.10011312047707317`], 
           Hue[0.6499931798173987, 1, 0.10000944332975564`], 
           Hue[0.6499819848662312, 1, 0.10002494403137233`], 
           Hue[0.6499892785262672, 1, 0.10001484511747614`], 
           Hue[0.6499959994335225, 1, 0.10000553924589196`], 
           Hue[0.6499999500040863, 1, 0.10000006922511127`], 
           Hue[0.6499999853568917, 1, 0.10000002027507307`], 
           Hue[0.6499999926512596, 1, 0.10000001017517901`], 
           Hue[0.6499999853568917, 1, 0.10000002027507307`], 
           Hue[0.6499999926512596, 1, 0.10000001017517901`], 
           Hue[0.6499987373870405, 1, 0.1000017482333285], 
           Hue[0.6499997241332024, 1, 0.10000038196941208`], 
           Hue[0.6499992203039526, 1, 0.10000107957914259`], 
           Hue[0.6499998474023537, 1, 0.10000021128904879`], 
           Hue[0.649999590533435, 1, 0.1000005669537054], 
           Hue[0.649999732409757, 1, 0.10000037050956732`], 
           Hue[0.6499992964406758, 1, 0.10000097415906437`], 
           Hue[0.6499999105318043, 1, 0.10000012387904018`], 
           Hue[0.6499925051018157, 1, 0.10001037755133219`], 
           Hue[0.6499979682031483, 1, 0.10000281325717941`], 
           Hue[0.6499951269450512, 1, 0.10000674730685209`], 
           Hue[0.649997998599588, 1, 0.10000277116980137`], 
           Hue[0.6499979682031483, 1, 0.10000281325717941`], 
           Hue[0.6499951269450512, 1, 0.10000674730685209`], 
           Hue[0.6499892997103437, 1, 0.10001481578567803`], 
           Hue[0.6499684714090721, 1, 0.10004365497205403`], 
           Hue[0.6499786307209967, 1, 0.10002958823246613`], 
           Hue[0.6499887061646138, 1, 0.10001563761822711`], 
           Hue[0.64998889575535, 1, 0.10001537510797696`], 
           Hue[0.6499758863201647, 1, 0.1000333881720797], 
           Hue[0.64990986881594, 1, 0.10012479702408313`], 
           Hue[0.6499371615166366, 1, 0.10008700713081094`], 
           Hue[0.6499354525471791, 1, 0.10008937339621354`], 
           Hue[0.6499825790660813, 1, 0.10002412129311823`], 
           Hue[0.6499234644088201, 1, 0.1001059723570184], 
           Hue[0.6499998517472398, 1, 0.1000002052730525], 
           Hue[0.6499995050240461, 1, 0.10000068535132073`], 
           Hue[0.649999724803093, 1, 0.10000038104187135`], 
           Hue[0.6499972533523636, 1, 0.1000038030505735], 
           Hue[0.6499993159067812, 1, 0.10000094720599527`], 
           Hue[0.6499983662639025, 1, 0.10000226209613496`], 
           Hue[0.6499991262252099, 1, 0.10000120984201699`], 
           Hue[0.6499992335415801, 1, 0.10000106125012002`], 
           Hue[0.6499977398917669, 1, 0.10000312938063041`], 
           Hue[0.6499963413007848, 1, 0.1000050658912211], 
           Hue[0.6499878647654108, 1, 0.10001680263250819`], 
           Hue[0.6499923453330904, 1, 0.10001059876956729`], 
           Hue[0.6499954680826809, 1, 0.10000627496244185`], 
           Hue[0.6499959176232237, 1, 0.1000056525216902], 
           Hue[0.6499850753312237, 1, 0.1000206649259979], 
           Hue[0.6499592661856974, 1, 0.1000564006659575], 
           Hue[0.6499729800552231, 1, 0.10003741223122968`], 
           Hue[0.649981132862961, 1, 0.10002612372820784`], 
           Hue[0.649898911013796, 1, 0.10013996936551317`], 
           Hue[0.649930414075084, 1, 0.10009634974219148`], 
           Hue[0.6499366633612995, 1, 0.10008769688435451`], 
           Hue[0.6499394811751557, 1, 0.1000837952959383], 
           Hue[0.6499999500040863, 1, 0.10000006922511127`], 
           Hue[0.6499930394481843, 1, 0.10000963768712945`], 
           Hue[0.6499981753461317, 1, 0.10000252644381777`], 
           Hue[0.6499952966832021, 1, 0.10000651228479705`], 
           Hue[0.649999015708746, 1, 0.10000136286481327`], 
           Hue[0.6499978877143096, 1, 0.10000292470326372`], 
           Hue[0.649998333888502, 1, 0.10000230692361262`], 
           Hue[0.6499964646335001, 1, 0.10000489512284605`], 
           Hue[0.6499658530333119, 1, 0.10004728041541434`], 
           Hue[0.64998889575535, 1, 0.10001537510797696`], 
           Hue[0.6499758863201647, 1, 0.1000333881720797], 
           Hue[0.6499899497720244, 1, 0.10001391570027392`], 
           Hue[0.6499892997103437, 1, 0.10001481578567803`], 
           Hue[0.6499684714090721, 1, 0.10004365497205403`], 
           Hue[0.6498018332354732, 1, 0.10027438475088327`], 
           Hue[0.6499986841176894, 1, 0.10000182199089175`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499992118878316, 1, 0.10000109123223312`], 
           Hue[0.6499992084380691, 1, 0.10000109600882744`], 
           Hue[0.6499956798469451, 1, 0.10000598175038376`], 
           Hue[0.6499974203571485, 1, 0.10000357181317905`], 
           Hue[0.6499817331204784, 1, 0.10002529260241469`], 
           Hue[0.6499944407952419, 1, 0.10000769736043427`], 
           Hue[0.6499883164518722, 1, 0.10001617722048475`], 
           Hue[0.6499928827959313, 1, 0.10000985459024905`], 
           Hue[0.6499937882615862, 1, 0.10000860086857298`], 
           Hue[0.649984029121582, 1, 0.10002211352396337`], 
           Hue[0.6499768388087087, 1, 0.10003206934178795`], 
           Hue[0.6499366088679227, 1, 0.10008777233672245`], 
           Hue[0.6499568986091695, 1, 0.10005967884884229`], 
           Hue[0.6499719284481867, 1, 0.10003886830251077`], 
           Hue[0.6498288316135646, 1, 0.1002370023812183], 
           Hue[0.6498768869650648, 1, 0.10017046420221798`], 
           Hue[0.6498286531654709, 1, 0.10023724946319418`], 
           Hue[0.6499942951189157, 1, 0.10000789906611669`], 
           Hue[0.6499965007467773, 1, 0.10000484511984688`], 
           Hue[0.6499740840158208, 1, 0.10003588367040199`], 
           Hue[0.6499959630133506, 1, 0.10000558967382225`], 
           Hue[0.6499931307624713, 1, 0.1000095112519628], 
           Hue[0.6499818743816113, 1, 0.10002509701007671`], 
           Hue[0.6498899315253245, 1, 0.10015240250339691`], 
           Hue[0.64990986881594, 1, 0.10012479702408313`], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499930428076303, 1, 0.10000963303558898`], 
           Hue[0.649993024783002, 1, 0.10000965799276645`], 
           Hue[0.6499710401022167, 1, 0.1000400983200076], 
           Hue[0.6499815839206784, 1, 0.10002549918675308`], 
           Hue[0.64996575997617, 1, 0.10004740926376463`], 
           Hue[0.6499078273563339, 1, 0.10012762366046074`], 
           Hue[0.6499369681039932, 1, 0.10008727493293267`], 
           Hue[0.6499551253828276, 1, 0.10006213408531567`], 
           Hue[0.6499614584941964, 1, 0.1000533651618819], 
           Hue[0.6497502919378658, 1, 0.10034574962449345`], 
           Hue[0.649818266637786, 1, 0.10025163080921945`], 
           Hue[0.649828653165471, 1, 0.10023724946319411`], 
           Hue[0.6499394811751558, 1, 0.10008379529593828`], 
           Hue[0.6499442388258546, 1, 0.10007720777958594`], 
           Hue[0.6499102360885619, 1, 0.10012428849276052`], 
           Hue[0.6499374484373719, 1, 0.10008660985594665`], 
           Hue[0.6499959994335225, 1, 0.10000553924589196`], 
           Hue[0.6499933578423218, 1, 0.10000919683370825`], 
           Hue[0.6499819848662312, 1, 0.10002494403137231`], 
           Hue[0.649988752611403, 1, 0.10001557330728819`], 
           Hue[0.6499368000496959, 1, 0.10008750762349808`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6499522576756646, 1, 0.10006610475677218`], 
           Hue[0.6499521921357778, 1, 0.10006619550430762`], 
           Hue[0.6498464094443002, 1, 0.10021266384635359`], 
           Hue[0.6498967127539552, 1, 0.10014301310990814`], 
           Hue[0.6496383427872282, 1, 0.10050075614076096`], 
           Hue[0.6497373247140593, 1, 0.10036370424207171`], 
           Hue[0.6499366633612995, 1, 0.10008769688435448`], 
           Hue[0.6499155953597011, 1, 0.10011686796349073`], 
           Hue[0.6499183018776694, 1, 0.10011312047707317`], 
           Hue[0.6499453252164491, 1, 0.10007570354645513`], 
           Hue[0.6499484530937932, 1, 0.10007137263936332`], 
           Hue[0.6466917429014707, 1, 0.10458066367488676`], 
           Hue[0.6499180307352563, 1, 0.10011349590502969`], 
           Hue[0.6499452847292683, 1, 0.10007575960562864`], 
           Hue[0.6499354525471791, 1, 0.10008937339621354`], 
           Hue[0.6499128808040171, 1, 0.10012062657905335`], 
           Hue[0.6450730162623393, 1, 0.10682197748291487`], 
           Hue[0.6451848600758754, 1, 0.10666711681801869`], 
           Hue[0.6439530905198237, 1, 0.10837264389562865`], 
           Hue[0.6466917429014625, 1, 0.10458066367489817`], 
           Hue[0.6465519871630898, 1, 0.1047741716203372], 
           Hue[0.6499179671599283, 1, 0.10011358393240694`], 
           Hue[0.6499482456526284, 1, 0.1000716598655914], 
           Hue[0.6498018332354732, 1, 0.1002743847508833], 
           Hue[0.6369343337822009, 1, 0.11809092245541414`], 
           Hue[0.6313031433718986, 1, 0.12588795533121733`], 
           Hue[0.6423035647750807, 1, 0.11065660261911912`], 
           Hue[0.6370871379712647, 1, 0.11787934742440272`], 
           Hue[0.6451848600758338, 1, 0.10666711681807642`], 
           Hue[0.6439530905197821, 1, 0.10837264389568639`], 
           Hue[0.6441390283451809, 1, 0.10811519152205727`], 
           Hue[0.6499806446197294, 1, 0.10002679975729786`], 
           Hue[0.649988018614091, 1, 0.10001658961125877`], 
           Hue[0.6499956092416016, 1, 0.10000607951162864`], 
           Hue[0.6499926276132632, 1, 0.10001020792009714`], 
           Hue[0.6499234644088201, 1, 0.10010597235701842`], 
           Hue[0.6499334905618971, 1, 0.10009208999121949`], 
           Hue[0.6499825790660813, 1, 0.10002412129311823`], 
           Hue[0.6155593700329793, 1, 0.14768702610818243`], 
           Hue[0.6258195092726606, 1, 0.1334806794686238], 
           Hue[0.5913746289044831, 1, 0.18117359074763875`], 
           Hue[0.6423035647750619, 1, 0.11065660261914508`], 
           Hue[0.6370871379713364, 1, 0.11787934742430345`], 
           Hue[0.6378619063741078, 1, 0.11680659117431233`], 
           Hue[0.649898911013796, 1, 0.10013996936551324`], 
           Hue[0.6499805463167408, 1, 0.10002693586912804`], 
           Hue[0.6499955764751569, 1, 0.10000612488055191`], 
           Hue[0.6499987913150758, 1, 0.10000167356374128`], 
           Hue[0.6499931770229507, 1, 0.10000944719899144`], 
           Hue[0.6499958852039428, 1, 0.10000569740992535`], 
           Hue[0.6499979082329089, 1, 0.10000289629289531`], 
           Hue[0.6319953620941843, 1, 0.12492949863882186`], 
           Hue[0.625819509272948, 1, 0.13348067946822578`], 
           Hue[0.5913746289049686, 1, 0.1811735907469666], 
           Hue[0.5965604897306293, 1, 0.17399316806528264`], 
           Hue[0.6498288316135644, 1, 0.10023700238121848`], 
           Hue[0.6499931260501088, 1, 0.1000095177767724], 
           Hue[0.6499592661856973, 1, 0.10005640066595754`], 
           Hue[0.6499850753312237, 1, 0.10002066492599791`], 
           Hue[0.6499958515834572, 1, 0.10000574396136695`], 
           Hue[0.6499987788443321, 1, 0.10000169083092485`], 
           Hue[0.6155593700336652, 1, 0.14768702610723275`], 
           Hue[0.6090317928650011, 1, 0.15672520987922933`], 
           Hue[0.6497502919378649, 1, 0.10034574962449469`], 
           Hue[0.6499878647654108, 1, 0.1000168026325082], 
           Hue[0.6499366088679226, 1, 0.10008777233672257`], 
           Hue[0.6499768388087087, 1, 0.10003206934178799`], 
           Hue[0.6499983016594818, 1, 0.10000235154840982`], 
           Hue[0.6499975148056737, 1, 0.100003441038298], 
           Hue[0.6499923453330904, 1, 0.10001059876956729`], 
           Hue[0.6499963413007848, 1, 0.10000506589122111`], 
           Hue[0.649998861931212, 1, 0.10000157578755257`], 
           Hue[0.6499990154332835, 1, 0.10000136324622286`], 
           Hue[0.6499995771839885, 1, 0.10000058543755444`], 
           Hue[0.6499997694648034, 1, 0.10000031920257986`], 
           Hue[0.6458360441380219, 1, 0.10576547734735442`], 
           Hue[0.6496383427872298, 1, 0.10050075614075889`], 
           Hue[0.6499817331204782, 1, 0.10002529260241473`], 
           Hue[0.6499078273563338, 1, 0.10012762366046096`], 
           Hue[0.64996575997617, 1, 0.1000474092637646], 
           Hue[0.6499972533523636, 1, 0.1000038030505735], 
           Hue[0.6499959176232237, 1, 0.10000565252169022`], 
           Hue[0.6499871127135868, 1, 0.10001784393503371`], 
           Hue[0.6499883164518722, 1, 0.10001617722048477`], 
           Hue[0.6499944407952419, 1, 0.10000769736043427`], 
           Hue[0.6499996941293525, 1, 0.10000042351320422`], 
           Hue[0.6499985394928872, 1, 0.10000202224061779`], 
           Hue[0.6499995171479255, 1, 0.10000066856441088`], 
           Hue[0.6499981812644314, 1, 0.10000251824924884`], 
           Hue[0.6499983662639025, 1, 0.10000226209613496`], 
           Hue[0.6499993159067812, 1, 0.10000094720599527`], 
           Hue[0.6499998535240952, 1, 0.10000020281279137`], 
           Hue[0.6499998099007703, 1, 0.10000026321431808`], 
           Hue[0.6499998322292071, 1, 0.10000023229802099`], 
           Hue[0.6499998517472398, 1, 0.1000002052730525], 
           Hue[0.6499986841176894, 1, 0.10000182199089175`], 
           Hue[0.6499984977543622, 1, 0.1000020800324216], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499992084380691, 1, 0.10000109600882745`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.649993024783002, 1, 0.10000965799276647`], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.6499521921357778, 1, 0.10006619550430775`], 
           Hue[0.03701244893343003, 1, 0.9487519937844815], 
           Hue[0.021008559536129012`, 1, 0.9709112252576675], 
           Hue[0.010667080107161664`, 1, 0.9852301967746991], 
           Hue[0.018968293162326844`, 1, 0.9737362094675474], 
           Hue[0.0021628179028305716`, 1, 0.9970053290576192], 
           Hue[0.6471956278815293, 1, 0.10388297677942109`], 
           Hue[0.649971040102217, 1, 0.10004009832000738`], 
           Hue[0.6499614584941966, 1, 0.1000533651618817], 
           Hue[0.6499521921357782, 1, 0.10006619550430726`], 
           Hue[0.6499956798469451, 1, 0.10000598175038376`], 
           Hue[0.649984029121582, 1, 0.10002211352396334`], 
           Hue[0.6499937882615862, 1, 0.10000860086857298`], 
           Hue[0.649993024783002, 1, 0.10000965799276644`], 
           Hue[0.6499995050240461, 1, 0.10000068535132073`], 
           Hue[0.6499977398917669, 1, 0.10000312938063043`], 
           Hue[0.64999923354158, 1, 0.10000106125012002`], 
           Hue[0.6499992084380691, 1, 0.10000109600882745`], 
           Hue[0.6499997586209825, 1, 0.10000033421710122`], 
           Hue[0.6499999328468428, 1, 0.1000000929812946], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.6499999042768432, 1, 0.1000001325397556], 
           Hue[0.6499997599027079, 1, 0.10000033244240446`], 
           Hue[0.6499998715320819, 1, 0.10000017787865574`], 
           Hue[0.649999724803093, 1, 0.10000038104187135`], 
           Hue[0.6499989528715463, 1, 0.10000144987016665`], 
           Hue[0.6499975708283137, 1, 0.10000336346848884`], 
           Hue[0.6499986013933341, 1, 0.10000193653230671`], 
           Hue[0.6499974203571485, 1, 0.10000357181317905`], 
           Hue[0.6499913752726683, 1, 0.10001194193015173`], 
           Hue[0.6499815839206784, 1, 0.10002549918675308`], 
           Hue[0.6499445462876953, 1, 0.10007678206319122`], 
           Hue[0.6498464094443002, 1, 0.10021266384635365`], 
           Hue[0.6496727141920234, 1, 0.10045316496489064`], 
           Hue[0.004312626695688215, 1, 0.9940286707290471], 
           Hue[0.01896829316206161, 1, 0.9737362094679147], 
           Hue[0.0021628179027942673`, 1, 0.9970053290576695], 
           Hue[0.02100855953293701, 1, 0.9709112252620872], 
           Hue[0.0021628179019673732`, 1, 0.9970053290588144], 
           Hue[0.01896829315981796, 1, 0.9737362094710214], 
           Hue[0.6499986841176894, 1, 0.10000182199089175`], 
           Hue[0.6499984977543622, 1, 0.1000020800324216], 
           Hue[0.6499999661022928, 1, 0.10000004693528683`], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.6499998517472398, 1, 0.1000002052730525], 
           Hue[0.6499999589602237, 1, 0.1000000568243058], 
           Hue[0.6499999794211159, 1, 0.10000002849383967`], 
           Hue[0.6499996132007059, 1, 0.10000053556825345`], 
           Hue[0.6499997586209825, 1, 0.10000033421710122`], 
           Hue[0.6499998322292071, 1, 0.10000023229802099`], 
           Hue[0.6499966175523572, 1, 0.10000468338904392`], 
           Hue[0.6499992335415801, 1, 0.10000106125012002`], 
           Hue[0.6499977398917669, 1, 0.10000312938063041`], 
           Hue[0.6499993878957052, 1, 0.10000084752902356`], 
           Hue[0.6499993159067812, 1, 0.10000094720599527`], 
           Hue[0.6499983662639025, 1, 0.10000226209613496`], 
           Hue[0.6499777227220929, 1, 0.1000308454617176], 
           Hue[0.6499937882615862, 1, 0.10000860086857298`], 
           Hue[0.649984029121582, 1, 0.10002211352396337`], 
           Hue[0.6499949826603763, 1, 0.10000694708563292`], 
           Hue[0.6499944407952419, 1, 0.10000769736043427`], 
           Hue[0.6499883164518722, 1, 0.10001617722048475`], 
           Hue[0.649886621235013, 1, 0.10015698598228986`], 
           Hue[0.6499614584941964, 1, 0.10005336516188192`], 
           Hue[0.6499690892099143, 1, 0.10004279955550338`], 
           Hue[0.64996575997617, 1, 0.10004740926376463`], 
           Hue[0.6499078273563339, 1, 0.10012762366046075`], 
           Hue[0.6495400008935742, 1, 0.10063692183966651`], 
           Hue[0.6496383427872282, 1, 0.10050075614076094`], 
           Hue[0.64507301626234, 1, 0.10682197748291387`], 
           Hue[0.6369343337821991, 1, 0.11809092245541672`], 
           Hue[0.6155593700329609, 1, 0.14768702610820794`], 
           Hue[0.6090317928642983, 1, 0.15672520988020228`], 
           Hue[0.06747929559215904, 1, 0.9065671291800874], 
           Hue[0.06744763098364448, 1, 0.9066109724841845], 
           Hue[0.6495407493861158, 1, 0.10063588546537816`], 
           Hue[0.6499978004542722, 1, 0.10000304552485391`], 
           Hue[0.6499995171479255, 1, 0.10000066856441088`], 
           Hue[0.6499985394928872, 1, 0.10000202224061779`], 
           Hue[0.6499997664208694, 1, 0.1000003234172578], 
           Hue[0.649999442352031, 1, 0.10000077212795708`], 
           Hue[0.6499995771839885, 1, 0.10000058543755444`], 
           Hue[0.6499990154332835, 1, 0.10000136324622286`], 
           Hue[0.6499998535240952, 1, 0.10000020281279137`], 
           Hue[0.6499849888742334, 1, 0.10002078463567682`], 
           Hue[0.6499959176232237, 1, 0.1000056525216902], 
           Hue[0.6499967448026513, 1, 0.10000450719632889`], 
           Hue[0.6499963413007848, 1, 0.10000506589122111`], 
           Hue[0.6499923453330904, 1, 0.10001059876956729`], 
           Hue[0.6499234404741348, 1, 0.10010600549735192`], 
           Hue[0.6499768388087087, 1, 0.10003206934178796`], 
           Hue[0.6499366088679227, 1, 0.10008777233672247`], 
           Hue[0.6497011754290651, 1, 0.10041375709821751`], 
           Hue[0.6497502919378658, 1, 0.10034574962449351`], 
           Hue[0.5913746289044425, 1, 0.18117359074769507`], 
           Hue[0.5965604897300106, 1, 0.17399316806613918`], 
           Hue[0.6258195092726493, 1, 0.1334806794686394], 
           Hue[0.6499983183666825, 1, 0.1000023284153627], 
           Hue[0.6499990259760979, 1, 0.1000013486484798], 
           Hue[0.649990533972543, 1, 0.1000131068072481], 
           Hue[0.6499975148056737, 1, 0.100003441038298], 
           Hue[0.6499987788443321, 1, 0.10000169083092485`], 
           Hue[0.6499975602665753, 1, 0.10000337809243423`], 
           Hue[0.6499978883756586, 1, 0.10000292378754969`], 
           Hue[0.6499958515834572, 1, 0.10000574396136695`], 
           Hue[0.6499482995199596, 1, 0.10007158528005596`], 
           Hue[0.6499850753312237, 1, 0.1000206649259979], 
           Hue[0.6499592661856973, 1, 0.10005640066595752`], 
           Hue[0.6497919036628963, 1, 0.10028813338983586`], 
           Hue[0.6498288316135645, 1, 0.10023700238121833`], 
           Hue[0.6370871379712585, 1, 0.11787934742441139`], 
           Hue[0.6378619063740117, 1, 0.11680659117444533`], 
           Hue[0.6423035647750802, 1, 0.11065660261911969`], 
           Hue[0.6499825790660813, 1, 0.10002412129311823`], 
           Hue[0.6499234644088201, 1, 0.10010597235701837`], 
           Hue[0.6499334905618971, 1, 0.10009208999121945`], 
           Hue[0.6499987913150758, 1, 0.10000167356374128`], 
           Hue[0.6499979082329089, 1, 0.10000289629289531`], 
           Hue[0.6499931770229507, 1, 0.10000944719899142`], 
           Hue[0.6499958852039428, 1, 0.10000569740992533`], 
           Hue[0.6499701121736939, 1, 0.10004138314411615`], 
           Hue[0.6499955764751569, 1, 0.1000061248805519], 
           Hue[0.6499927474735677, 1, 0.10001004195967544`], 
           Hue[0.6499805463167408, 1, 0.10002693586912803`], 
           Hue[0.6498637789166501, 1, 0.10018861380771518`], 
           Hue[0.649898911013796, 1, 0.10013996936551318`], 
           Hue[0.6439530905198263, 1, 0.1083726438956252], 
           Hue[0.6441390283452353, 1, 0.10811519152198196`], 
           Hue[0.6451848600758766, 1, 0.1066671168180171], 
           Hue[0.6498018332354732, 1, 0.10027438475088318`], 
           Hue[0.6498992374175553, 1, 0.10013951742184662`], 
           Hue[0.6499306690177541, 1, 0.10009599674464822`], 
           Hue[0.6499956092416016, 1, 0.10000607951162864`], 
           Hue[0.6499926276132632, 1, 0.10001020792009714`], 
           Hue[0.6499806446197294, 1, 0.10002679975729785`], 
           Hue[0.649988018614091, 1, 0.10001658961125875`], 
           Hue[0.6499332456084079, 1, 0.10009242915758908`], 
           Hue[0.6466917429014706, 1, 0.10458066367488687`], 
           Hue[0.646551987163097, 1, 0.1047741716203272], 
           Hue[0.5913746289048778, 1, 0.18117359074709227`], 
           Hue[0.6258195092728863, 1, 0.1334806794683113], 
           Hue[0.615559370033591, 1, 0.14768702610733564`], 
           Hue[0.6319953620942502, 1, 0.12492949863873053`], 
           Hue[0.6353293129837483, 1, 0.1203132589455794], 
           Hue[0.6499334584002099, 1, 0.10009213452278633`], 
           Hue[0.6499560274362279, 1, 0.10006088508829984`], 
           Hue[0.6499354525471792, 1, 0.10008937339621347`], 
           Hue[0.6499128808040171, 1, 0.10012062657905328`], 
           Hue[0.6370871379713289, 1, 0.11787934742431384`], 
           Hue[0.6423035647751155, 1, 0.11065660261907082`], 
           Hue[0.6499180307352564, 1, 0.10011349590502963`], 
           Hue[0.6499452847292683, 1, 0.10007575960562862`], 
           Hue[0.6499482456526285, 1, 0.10007165986559136`], 
           Hue[0.643953090519833, 1, 0.10837264389561596`], 
           Hue[0.6451848600758786, 1, 0.10666711681801425`], 
           Hue[0.6499183018776694, 1, 0.10011312047707316`], 
           Hue[0.6499453252164491, 1, 0.10007570354645512`], 
           Hue[0.6499366633612995, 1, 0.1000876968843545], 
           Hue[0.6499155953597011, 1, 0.10011686796349076`], 
           Hue[0.6466917429014706, 1, 0.10458066367488697`], 
           Hue[0.6458360441380555, 1, 0.10576547734730775`], 
           Hue[0.6464975004717023, 1, 0.10484961473148917`], 
           Hue[0.6471956278815415, 1, 0.10388297677940406`], 
           Hue[0.6499182640119672, 1, 0.100113172906507], 
           Hue[0.6499484530937932, 1, 0.1000713726393633], 
           Hue[0.6498286531654709, 1, 0.10023724946319415`], 
           Hue[0.6495400008935912, 1, 0.10063692183964294`], 
           Hue[0.6496696618168546, 1, 0.10045739133050904`], 
           Hue[0.6496731893555265, 1, 0.10045250704619402`], 
           Hue[0.6499819848662312, 1, 0.10002494403137233`], 
           Hue[0.649988752611403, 1, 0.10001557330728819`], 
           Hue[0.6499959994335225, 1, 0.10000553924589196`], 
           Hue[0.6499933578423218, 1, 0.10000919683370825`], 
           Hue[0.6499394811751557, 1, 0.10008379529593829`], 
           Hue[0.6499442388258546, 1, 0.10007720777958597`], 
           Hue[0.6496383427872341, 1, 0.10050075614075284`], 
           Hue[0.6497373247140626, 1, 0.10036370424206716`], 
           Hue[0.6497011754290666, 1, 0.1004137570982155], 
           Hue[0.649782295843946, 1, 0.10030143652376722`], 
           Hue[0.6499521921357784, 1, 0.10006619550430693`], 
           Hue[0.6498866212350147, 1, 0.10015698598228738`], 
           Hue[0.6499227855829625, 1, 0.10010691226974439`], 
           Hue[0.6499614584941968, 1, 0.10005336516188132`], 
           Hue[0.6499522576756641, 1, 0.10006610475677287`], 
           Hue[0.6499446791317119, 1, 0.100076598125322], 
           Hue[0.6498467359396378, 1, 0.10021221177588613`], 
           Hue[0.6499098688159399, 1, 0.10012479702408315`], 
           Hue[0.6499818743816113, 1, 0.10002509701007672`], 
           Hue[0.6499959630133506, 1, 0.10000558967382225`], 
           Hue[0.6497502919378662, 1, 0.1003457496244931], 
           Hue[0.6498182666377861, 1, 0.10025163080921927`], 
           Hue[0.6497919036628964, 1, 0.10028813338983578`], 
           Hue[0.6498491275148006, 1, 0.10020890036412222`], 
           Hue[0.649977722722093, 1, 0.10003084546171745`], 
           Hue[0.6499078273563345, 1, 0.10012762366046009`], 
           Hue[0.6499369681039934, 1, 0.10008727493293235`], 
           Hue[0.6499657599761702, 1, 0.1000474092637643], 
           Hue[0.6499234404741349, 1, 0.10010600549735177`], 
           Hue[0.649947712762502, 1, 0.10007239771345888`], 
           Hue[0.649993024783002, 1, 0.10000965799276641`], 
           Hue[0.6499857386104357, 1, 0.10001974653939667`], 
           Hue[0.6499840291215822, 1, 0.10002211352396323`], 
           Hue[0.6499937882615863, 1, 0.10000860086857295`], 
           Hue[0.6499930428076302, 1, 0.10000963303558902`], 
           Hue[0.6499914127424962, 1, 0.10001189004885144`], 
           Hue[0.6499816678392326, 1, 0.10002538299183177`], 
           Hue[0.6499986841176894, 1, 0.10000182199089175`], 
           Hue[0.6499942406207414, 1, 0.10000797452512729`], 
           Hue[0.6499684714090721, 1, 0.10004365497205404`], 
           Hue[0.6499892997103437, 1, 0.10001481578567803`], 
           Hue[0.6499964646335001, 1, 0.10000489512284606`], 
           Hue[0.649999015708746, 1, 0.10000136286481327`], 
           Hue[0.6498286531654709, 1, 0.10023724946319411`], 
           Hue[0.6498288316135645, 1, 0.10023700238121833`], 
           Hue[0.6498768869650648, 1, 0.10017046420221802`], 
           Hue[0.6498637789166501, 1, 0.10018861380771522`], 
           Hue[0.6499035776827975, 1, 0.10013350782381888`], 
           Hue[0.6499366088679227, 1, 0.10008777233672243`], 
           Hue[0.6499568986091695, 1, 0.10005967884884229`], 
           Hue[0.6499849888742334, 1, 0.1000207846356768], 
           Hue[0.6499768388087087, 1, 0.10003206934178793`], 
           Hue[0.6499482995199596, 1, 0.10007158528005596`], 
           Hue[0.6499651447615216, 1, 0.10004826109943166`], 
           Hue[0.6499966175523572, 1, 0.10000468338904392`], 
           Hue[0.6499883164518722, 1, 0.10001617722048474`], 
           Hue[0.6499944407952419, 1, 0.10000769736043426`], 
           Hue[0.6499904461340845, 1, 0.1000132284297292], 
           Hue[0.6499959176232237, 1, 0.1000056525216902], 
           Hue[0.6499992084380691, 1, 0.10000109600882744`], 
           Hue[0.6499979781484426, 1, 0.10000279948677177`], 
           Hue[0.6499977398917669, 1, 0.10000312938063041`], 
           Hue[0.6499992335415801, 1, 0.10000106125012001`], 
           Hue[0.6499992118878316, 1, 0.10000109123223312`], 
           Hue[0.6499984977543622, 1, 0.1000020800324216], 
           Hue[0.6499974391975304, 1, 0.10000354572649647`], 
           Hue[0.6498018332354732, 1, 0.10027438475088317`], 
           Hue[0.6498899315253245, 1, 0.10015240250339698`], 
           Hue[0.649920525041201, 1, 0.10011004225064478`], 
           Hue[0.6499925051018156, 1, 0.1000103775513322], 
           Hue[0.6499758863201647, 1, 0.10003338817207973`], 
           Hue[0.64998889575535, 1, 0.10001537510797698`], 
           Hue[0.6499658530333119, 1, 0.10004728041541437`], 
           Hue[0.649976311639638, 1, 0.10003279926819361`], 
           Hue[0.6499758863201647, 1, 0.10003338817207973`], 
           Hue[0.64998889575535, 1, 0.10001537510797698`], 
           Hue[0.6499988198134662, 1, 0.1000016341044314], 
           Hue[0.6499952966832021, 1, 0.10000651228479705`], 
           Hue[0.6499981753461317, 1, 0.10000252644381777`], 
           Hue[0.649995048229519, 1, 0.10000685629758907`], 
           Hue[0.6499951269450512, 1, 0.1000067473068521], 
           Hue[0.6499979682031483, 1, 0.10000281325717941`], 
           Hue[0.6499992554553338, 1, 0.10000103090799936`], 
           Hue[0.6499992964406758, 1, 0.10000097415906437`], 
           Hue[0.649999732409757, 1, 0.10000037050956732`], 
           Hue[0.6499999500040863, 1, 0.10000006922511127`], 
           Hue[0.6499394811751558, 1, 0.10008379529593828`], 
           Hue[0.6499575453317327, 1, 0.10005878338683176`], 
           Hue[0.6499102360885619, 1, 0.10012428849276052`], 
           Hue[0.6499366633612995, 1, 0.10008769688435448`], 
           Hue[0.649898911013796, 1, 0.10013996936551324`], 
           Hue[0.6499304140750839, 1, 0.10009634974219153`], 
           Hue[0.6499332456084078, 1, 0.10009242915758913`], 
           Hue[0.6499558704947553, 1, 0.10006110239187734`], 
           Hue[0.6499592661856973, 1, 0.10005640066595753`], 
           Hue[0.649972980055223, 1, 0.10003741223122971`], 
           Hue[0.649990533972543, 1, 0.10001310680724812`], 
           Hue[0.6499850753312237, 1, 0.1000206649259979], 
           Hue[0.6499701121736939, 1, 0.10004138314411617`], 
           Hue[0.6499807215560938, 1, 0.10002669323002401`], 
           Hue[0.6499978004542722, 1, 0.1000030455248539], 
           Hue[0.6499923453330904, 1, 0.10001059876956729`], 
           Hue[0.6499963413007848, 1, 0.1000050658912211], 
           Hue[0.6499941257642842, 1, 0.10000813355714501`], 
           Hue[0.6499975148056737, 1, 0.100003441038298], 
           Hue[0.6499996132007059, 1, 0.10000053556825345`], 
           Hue[0.6499983662639025, 1, 0.10000226209613496`], 
           Hue[0.6499993159067812, 1, 0.10000094720599527`], 
           Hue[0.6499987037961257, 1, 0.1000017947438261], 
           Hue[0.6499985394928872, 1, 0.10000202224061779`], 
           Hue[0.6499995171479255, 1, 0.10000066856441088`], 
           Hue[0.6499997857288967, 1, 0.10000029668306613`], 
           Hue[0.6499997586209825, 1, 0.10000033421710122`], 
           Hue[0.6499998517472398, 1, 0.1000002052730525], 
           Hue[0.6499234644088201, 1, 0.10010597235701836`], 
           Hue[0.6499825790660813, 1, 0.10002412129311822`], 
           Hue[0.6498992374175553, 1, 0.10013951742184661`], 
           Hue[0.6499354525471792, 1, 0.10008937339621347`], 
           Hue[0.6499098688159399, 1, 0.10012479702408318`], 
           Hue[0.6499371615166365, 1, 0.10008700713081096`], 
           Hue[0.6499368000496958, 1, 0.10008750762349812`], 
           Hue[0.6499579090308498, 1, 0.10005827980343879`], 
           Hue[0.6499930394481843, 1, 0.10000963768712946`], 
           Hue[0.6499684714090721, 1, 0.10004365497205406`], 
           Hue[0.6499786307209967, 1, 0.10002958823246615`], 
           Hue[0.6499892997103437, 1, 0.10001481578567803`], 
           Hue[0.6499740840158208, 1, 0.10003588367040202`], 
           Hue[0.6499830415932077, 1, 0.10002348087094316`], 
           Hue[0.6499987373870405, 1, 0.1000017482333285], 
           Hue[0.6499951269450512, 1, 0.1000067473068521], 
           Hue[0.6499979682031483, 1, 0.10000281325717941`], 
           Hue[0.6499955738243941, 1, 0.1000061285508389], 
           Hue[0.6499952966832021, 1, 0.10000651228479705`], 
           Hue[0.6499981753461317, 1, 0.10000252644381777`], 
           Hue[0.6499998378409675, 1, 0.10000022452789123`], 
           Hue[0.6499992203039526, 1, 0.10000107957914259`], 
           Hue[0.6499997241332024, 1, 0.10000038196941208`], 
           Hue[0.649999231209965, 1, 0.10000106447851004`], 
           Hue[0.6499992203039526, 1, 0.10000107957914259`], 
           Hue[0.6499997241332024, 1, 0.10000038196941208`], 
           Hue[0.6499999105318043, 1, 0.10000012387904018`], 
           Hue[0.6499999068044836, 1, 0.10000012903994587`], 
           Hue[0.6499999079226575, 1, 0.10000012749170509`], 
           Hue[0.6499999926512596, 1, 0.10000001017517901`], 
           Hue[0.6499999927381648, 1, 0.10000001005484888`], 
           Hue[0.6499999926512596, 1, 0.10000001017517901`], 
           Hue[0.6499999500040863, 1, 0.10000006922511127`], 
           Hue[0.64999791089883, 1, 0.10000289260162012`], 
           Hue[0.6499942951189157, 1, 0.10000789906611669`], 
           Hue[0.6499892785262673, 1, 0.10001484511747614`], 
           Hue[0.6499959994335225, 1, 0.10000553924589196`], 
           Hue[0.6499931798173987, 1, 0.10000944332975563`], 
           Hue[0.6499819848662312, 1, 0.10002494403137231`], 
           Hue[0.6499183018776694, 1, 0.10011312047707319`], 
           Hue[0.6499179671599283, 1, 0.10011358393240694`], 
           Hue[0.6499452554080251, 1, 0.10007580020427298`], 
           Hue[0.6499482456526284, 1, 0.10007165986559141`], 
           Hue[0.6499805463167408, 1, 0.10002693586912804`], 
           Hue[0.6499927474735677, 1, 0.10001004195967546`], 
           Hue[0.6499955764751569, 1, 0.10000612488055191`], 
           Hue[0.6499925770634212, 1, 0.10001027791218615`], 
           Hue[0.6499975602665753, 1, 0.10000337809243423`], 
           Hue[0.6499987788443321, 1, 0.10000169083092485`], 
           Hue[0.6499958515834572, 1, 0.10000574396136695`], 
           Hue[0.6499978883756586, 1, 0.10000292378754969`], 
           Hue[0.649999442352031, 1, 0.10000077212795708`], 
           Hue[0.6499997664208694, 1, 0.1000003234172578], 
           Hue[0.6499990154332835, 1, 0.10000136324622286`], 
           Hue[0.6499995771839885, 1, 0.10000058543755444`], 
           Hue[0.6499998322292071, 1, 0.10000023229802099`], 
           Hue[0.6499998535240952, 1, 0.10000020281279137`], 
           Hue[0.6499999794211159, 1, 0.10000002849383967`], 
           Hue[0.6499997694648034, 1, 0.10000031920257986`], 
           Hue[0.6499994488275219, 1, 0.10000076316189273`], 
           Hue[0.6499983183666825, 1, 0.1000023284153627], 
           Hue[0.6499999113420365, 1, 0.10000012275718022`], 
           Hue[0.6499998555397438, 1, 0.10000020002189328`], 
           Hue[0.6499987913150758, 1, 0.10000167356374128`], 
           Hue[0.6499975817595002, 1, 0.10000334833299979`], 
           Hue[0.6499964672535286, 1, 0.10000489149511434`], 
           Hue[0.6499979082329089, 1, 0.10000289629289531`], 
           Hue[0.6499931770229507, 1, 0.10000944719899142`], 
           Hue[0.6499879539739198, 1, 0.10001667911303413`], 
           Hue[0.6499956092416016, 1, 0.10000607951162864`], 
           Hue[0.6499927911642358, 1, 0.10000998146490438`], 
           Hue[0.6499806446197294, 1, 0.10002679975729785`], 
           Hue[0.6499180307352564, 1, 0.10011349590502963`], 
           Hue[0.6499182640119672, 1, 0.10011317290650701`], 
           Hue[0.6499453175635969, 1, 0.10007571414271205`], 
           Hue[0.6499484530937932, 1, 0.1000713726393633], 
           Hue[0.6499818743816113, 1, 0.10002509701007672`], 
           Hue[0.6499931307624713, 1, 0.10000951125196281`], 
           Hue[0.6499959630133506, 1, 0.10000558967382225`], 
           Hue[0.6499933017246096, 1, 0.10000927453515607`], 
           Hue[0.6499978877143096, 1, 0.10000292470326372`], 
           Hue[0.649999015708746, 1, 0.10000136286481327`], 
           Hue[0.6499964646335001, 1, 0.10000489512284606`], 
           Hue[0.649998333888502, 1, 0.10000230692361262`], 
           Hue[0.649999590533435, 1, 0.1000005669537054], 
           Hue[0.6499998474023537, 1, 0.10000021128904879`], 
           Hue[0.6499992964406758, 1, 0.10000097415906437`], 
           Hue[0.649999732409757, 1, 0.10000037050956732`], 
           Hue[0.6499999079226575, 1, 0.10000012749170509`], 
           Hue[0.6499999105318043, 1, 0.10000012387904018`], 
           Hue[0.6499983183666825, 1, 0.1000023284153627], 
           Hue[0.6499994488275219, 1, 0.10000076316189273`], 
           Hue[0.6499990259760979, 1, 0.1000013486484798], 
           Hue[0.6499999589602237, 1, 0.1000000568243058], 
           Hue[0.6499999750758687, 1, 0.10000003451033561`], 
           Hue[0.6499999794211159, 1, 0.10000002849383967`], 
           Hue[0.6499999661022928, 1, 0.10000004693528683`], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.64999791089883, 1, 0.10000289260162012`], 
           Hue[0.6499942951189157, 1, 0.10000789906611669`], 
           Hue[0.6499999731984859, 1, 0.10000003710978886`], 
           Hue[0.6498992374175552, 1, 0.10013951742184668`], 
           Hue[0.6499594649681921, 1, 0.10005612542865715`], 
           Hue[0.6499906014956968, 1, 0.10001301331365066`], 
           Hue[0.6499102360885618, 1, 0.10012428849276057`], 
           Hue[0.6499975790673054, 1, 0.10000335206065415`], 
           Hue[0.6499984977543622, 1, 0.1000020800324216], 
           Hue[0.6499974391975304, 1, 0.10000354572649646`], 
           Hue[0.6499812225788024, 1, 0.10002599950627353`], 
           Hue[0.6499816678392328, 1, 0.10002538299183153`], 
           Hue[0.6498467359396423, 1, 0.10021221177587998`], 
           Hue[0.6495407493861327, 1, 0.10063588546535482`], 
           Hue[0.6498992374175552, 1, 0.1001395174218467], 
           Hue[0.6499306690177541, 1, 0.10009599674464828`], 
           Hue[0.6499594649681921, 1, 0.10005612542865716`], 
           Hue[0.6499731279556002, 1, 0.100037207446092], 
           Hue[0.6499906014956968, 1, 0.10001301331365066`], 
           Hue[0.6499996397889839, 1, 0.10000049875371464`], 
           Hue[0.6499983183666825, 1, 0.1000023284153627], 
           Hue[0.6499990259760979, 1, 0.1000013486484798], 
           Hue[0.6499999794211159, 1, 0.10000002849383967`], 
           Hue[0.6499999053015012, 1, 0.10000013112099838`], 
           Hue[0.6499995099093939, 1, 0.10000067858699309`], 
           Hue[0.6499997277891764, 1, 0.10000037690729435`], 
           Hue[0.6499997612218463, 1, 0.10000033061590513`], 
           Hue[0.6499929243432877, 1, 0.10000979706314021`], 
           Hue[0.6499992118878316, 1, 0.10000109123223312`], 
           Hue[0.6499974391975304, 1, 0.10000354572649647`], 
           Hue[0.6499552803098143, 1, 0.10006191957102643`], 
           Hue[0.6499930428076302, 1, 0.10000963303558902`], 
           Hue[0.6499816678392327, 1, 0.10002538299183167`], 
           Hue[0.6499522576756643, 1, 0.10006610475677251`], 
           Hue[0.6498467359396409, 1, 0.10021221177588176`], 
           Hue[0.6498969735437096, 1, 0.10014265201640213`], 
           Hue[0.6496731893555366, 1, 0.10045250704618], 
           Hue[0.0270736379763451, 1, 0.9625134243404452], 
           Hue[0.06744763098777695, 1, 0.9066109724784627], 
           Hue[0.027091472129359362`, 1, 0.9624887308978102], 
           Hue[0.6498464094443034, 1, 0.10021266384634916`], 
           Hue[0.6499811865783439, 1, 0.10002604935306224`], 
           Hue[0.6499815839206784, 1, 0.10002549918675299`], 
           Hue[0.6499975708283137, 1, 0.10000336346848884`], 
           Hue[0.6499974203571485, 1, 0.10000357181317905`], 
           Hue[0.6499986013933341, 1, 0.10000193653230671`], 
           Hue[0.6499997599027079, 1, 0.10000033244240446`], 
           Hue[0.649999724803093, 1, 0.10000038104187135`], 
           Hue[0.6499998715320819, 1, 0.10000017787865574`], 
           Hue[0.06747929559313426, 1, 0.9065671291787372], 
           Hue[0.0106738546460583, 1, 0.9852208166439193], 
           Hue[0.0021628179019727023`, 1, 0.997005329058807], 
           Hue[0.018968293159893457`, 1, 0.9737362094709168], 
           Hue[0.02707363797262352, 1, 0.9625134243455983], 
           Hue[0.6498467359396378, 1, 0.1002122117758862], 
           Hue[0.6498969735437079, 1, 0.10014265201640445`], 
           Hue[0.6499812225788023, 1, 0.10002599950627376`], 
           Hue[0.649977555421589, 1, 0.10003107710856916`], 
           Hue[0.6499816678392326, 1, 0.10002538299183177`], 
           Hue[0.6499975790673054, 1, 0.10000335206065417`], 
           Hue[0.6499969119221585, 1, 0.10000427580008835`], 
           Hue[0.6499974391975304, 1, 0.10000354572649647`], 
           Hue[0.6499997612218463, 1, 0.10000033061590513`], 
           Hue[0.6499995099093939, 1, 0.10000067858699309`], 
           Hue[0.6499998723238989, 1, 0.10000017678229389`], 
           Hue[0.6499997277891764, 1, 0.10000037690729435`], 
           Hue[0.6499998555397438, 1, 0.10000020002189328`], 
           Hue[0.6499906014956968, 1, 0.10001301331365064`], 
           Hue[0.6499594649681921, 1, 0.10005612542865713`], 
           Hue[0.6499731279556002, 1, 0.10003720744609199`], 
           Hue[0.6496727141920364, 1, 0.10045316496487267`], 
           Hue[0.6499102360885618, 1, 0.10012428849276055`], 
           Hue[0.6499374484373719, 1, 0.10008660985594668`], 
           Hue[0.6499445462876963, 1, 0.10007678206318982`], 
           Hue[0.6498464094443047, 1, 0.10021266384634737`], 
           Hue[0.6498967127539578, 1, 0.10014301310990469`], 
           Hue[0.6499552803098139, 1, 0.10006191957102695`], 
           Hue[0.6499942951189157, 1, 0.10000789906611669`], 
           Hue[0.6499965007467773, 1, 0.10000484511984688`], 
           Hue[0.6499913752726683, 1, 0.10001194193015163`], 
           Hue[0.6499815839206785, 1, 0.10002549918675284`], 
           Hue[0.6499929243432876, 1, 0.10000979706314021`], 
           Hue[0.6499989528715463, 1, 0.10000144987016665`], 
           Hue[0.6499974203571485, 1, 0.10000357181317905`], 
           Hue[0.6499975708283137, 1, 0.10000336346848883`], 
           Hue[0.6499999328468428, 1, 0.1000000929812946], 
           Hue[0.649999724803093, 1, 0.10000038104187135`], 
           Hue[0.6499997599027079, 1, 0.10000033244240446`], 
           Hue[0.6499999053015012, 1, 0.10000013112099838`], 
           Hue[0.6499997612218463, 1, 0.10000033061590513`], 
           Hue[0.6499998723238989, 1, 0.10000017678229389`], 
           Hue[0.6499995099093939, 1, 0.10000067858699309`], 
           Hue[0.6499999658355468, 1, 0.10000004730462761`], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.6499906014956968, 1, 0.10001301331365064`], 
           Hue[0.6499594649681921, 1, 0.10005612542865713`], 
           Hue[0.6499999731984859, 1, 0.10000003710978886`], 
           Hue[0.6499999068044836, 1, 0.10000012903994587`], 
           Hue[0.649999746592461, 1, 0.10000035087197716`], 
           Hue[0.649999231209965, 1, 0.10000106447851004`], 
           Hue[0.6499993562029576, 1, 0.1000008914112895], 
           Hue[0.6499985371764694, 1, 0.10000202544796548`], 
           Hue[0.6499955738243941, 1, 0.1000061285508389], 
           Hue[0.6499830415932077, 1, 0.10002348087094315`], 
           Hue[0.6499579090308498, 1, 0.10005827980343876`], 
           Hue[0.6499991746468223, 1, 0.10000114279670756`], 
           Hue[0.6499979082329089, 1, 0.10000289629289531`], 
           Hue[0.6499982700550374, 1, 0.10000239530840976`], 
           Hue[0.6499996397889839, 1, 0.10000049875371464`], 
           Hue[0.6499999658355468, 1, 0.10000004730462761`], 
           Hue[0.6499997857288967, 1, 0.10000029668306613`], 
           Hue[0.6499996352970167, 1, 0.10000050497336162`], 
           Hue[0.6499987037961257, 1, 0.1000017947438261], 
           Hue[0.6499991655407161, 1, 0.1000011554051624], 
           Hue[0.6499982534432173, 1, 0.1000024183093915], 
           Hue[0.6499941257642842, 1, 0.100008133557145], 
           Hue[0.6499807215560938, 1, 0.100026693230024], 
           Hue[0.6499558704947553, 1, 0.1000611023918773], 
           Hue[0.649999637473088, 1, 0.10000050196033976`], 
           Hue[0.6499990284977293, 1, 0.10000134515699023`], 
           Hue[0.6499985546968547, 1, 0.10000200118897033`], 
           Hue[0.6499999927381648, 1, 0.10000001005484888`], 
           Hue[0.6499992554553338, 1, 0.10000103090799936`], 
           Hue[0.649995048229519, 1, 0.10000685629758907`], 
           Hue[0.649976311639638, 1, 0.1000327992681936], 
           Hue[0.649920525041201, 1, 0.10011004225064472`], 
           Hue[0.6498831635659211, 1, 0.10016177352410921`], 
           Hue[0.6499999053015012, 1, 0.10000013112099838`], 
           Hue[0.6499979781484426, 1, 0.10000279948677177`], 
           Hue[0.6499904461340845, 1, 0.1000132284297292], 
           Hue[0.6499651447615216, 1, 0.10004826109943166`], 
           Hue[0.6499035776827975, 1, 0.10013350782381883`], 
           Hue[0.6498822003220268, 1, 0.1001631072464244], 
           Hue[0.6499999731984859, 1, 0.10000003710978886`], 
           Hue[0.6499989602457273, 1, 0.10000143965976213`], 
           Hue[0.6499989528715463, 1, 0.10000144987016665`], 
           Hue[0.6499857386104357, 1, 0.10001974653939674`], 
           Hue[0.6499477127625019, 1, 0.10007239771345894`], 
           Hue[0.6498491275148006, 1, 0.10020890036412224`], 
           Hue[0.6494614008079023, 1, 0.10074575272752002`], 
           Hue[0.649999637473088, 1, 0.10000050196033976`], 
           Hue[0.6499990284977293, 1, 0.10000134515699023`], 
           Hue[0.6499985546968547, 1, 0.10000200118897033`], 
           Hue[0.6499914127424963, 1, 0.10001189004885136`], 
           Hue[0.6499913752726683, 1, 0.10001194193015171`], 
           Hue[0.6499227855829615, 1, 0.10010691226974568`], 
           Hue[0.6497822958439452, 1, 0.10030143652376827`], 
           Hue[0.6499446791317128, 1, 0.10007659812532067`], 
           Hue[0.6499445462876953, 1, 0.10007678206319116`], 
           Hue[0.6496696618168444, 1, 0.1004573913305232], 
           Hue[0.6497907013374782, 1, 0.10028979814810711`], 
           Hue[0.649832150775643, 1, 0.10023240661834047`], 
           Hue[0.6497389422959969, 1, 0.10036146451323512`], 
           Hue[0.649714352432321, 1, 0.10039551201678641`], 
           Hue[0.64973878001104, 1, 0.10036168921548312`], 
           Hue[0.6497140307026751, 1, 0.10039595748860371`], 
           Hue[0.6498206206758443, 1, 0.10024837137190792`], 
           Hue[0.6353293129837054, 1, 0.12031325894563866`], 
           Hue[0.6499560274362279, 1, 0.10006088508829988`], 
           Hue[0.6499991655407161, 1, 0.1000011554051624], 
           Hue[0.6499978883756586, 1, 0.10000292378754969`], 
           Hue[0.6499982534432173, 1, 0.1000024183093915], 
           Hue[0.6499967448026513, 1, 0.10000450719632889`], 
           Hue[0.6499996352970167, 1, 0.10000050497336162`], 
           Hue[0.6499999539215624, 1, 0.1000000638009137], 
           Hue[0.6499690892099143, 1, 0.10004279955550344`], 
           Hue[0.6499949826603763, 1, 0.10000694708563293`], 
           Hue[0.6499993878957052, 1, 0.10000084752902356`], 
           Hue[0.6499999750758687, 1, 0.10000003451033561`], 
           Hue[0.6499991340538082, 1, 0.10000119900241951`], 
           Hue[0.6499996736696589, 1, 0.10000045184201072`], 
           Hue[0.6499997881961503, 1, 0.10000029326686882`], 
           Hue[0.6499998723238989, 1, 0.10000017678229389`], 
           Hue[0.6499994682338144, 1, 0.1000007362916416], 
           Hue[0.6499975790673054, 1, 0.10000335206065417`], 
           Hue[0.6499969119221585, 1, 0.10000427580008835`], 
           Hue[0.6499812225788024, 1, 0.10002599950627365`], 
           Hue[0.6499775554215891, 1, 0.10003107710856897`], 
           Hue[0.07116385446975881, 1, 0.9014654322726416], 
           Hue[0.052429459858746585`, 1, 0.9274053632725047], 
           Hue[0.058101599627731315`, 1, 0.9195516312846796], 
           Hue[0.02707363797620488, 1, 0.9625134243406394], 
           Hue[0.05244141947382608, 1, 0.9273888038054716], 
           Hue[0.05812442404677254, 1, 0.9195200282429303], 
           Hue[0.010673854646939596`, 1, 0.985220816642699], 
           Hue[0.07116385446585682, 1, 0.9014654322780444], 
           Hue[0.05244141947081893, 1, 0.9273888038096353], 
           Hue[0.05812442404452234, 1, 0.9195200282460461], 
           Hue[0.6313031433723827, 1, 0.12588795533054703`], 
           Hue[0.6450730162625566, 1, 0.10682197748261388`], 
           Hue[0.6498321507756426, 1, 0.10023240661834108`], 
           Hue[0.6497387800110438, 1, 0.10036168921547785`], 
           Hue[0.6497140307026826, 1, 0.10039595748859324`], 
           Hue[0.6499445462876959, 1, 0.10007678206319033`], 
           Hue[0.6499913752726683, 1, 0.10001194193015168`], 
           Hue[0.6499989528715463, 1, 0.10000144987016665`], 
           Hue[0.6499999042768432, 1, 0.1000001325397556], 
           Hue[0.6499999661022928, 1, 0.10000004693528683`], 
           Hue[0.6499995599269037, 1, 0.10000060933197948`], 
           Hue[0.6499996708038481, 1, 0.10000045581005648`], 
           Hue[0.6499996266415422, 1, 0.1000005169578647], 
           Hue[0.6499994633943222, 1, 0.10000074299247697`], 
           Hue[0.6499958503661866, 1, 0.10000574564681872`], 
           Hue[0.6499968945489246, 1, 0.1000042998553351], 
           Hue[0.6499964690986961, 1, 0.10000488894026689`], 
           Hue[0.6499952978986884, 1, 0.1000065106018162], 
           Hue[0.6499811865783439, 1, 0.10002604935306235`], 
           Hue[0.6499774815479086, 1, 0.10003117939520355`], 
           Hue[0.010667080107075066`, 1, 0.9852301967748192], 
           Hue[0.027091472129990746`, 1, 0.9624887308969359], 
           Hue[0.010673854646060521`, 1, 0.9852208166439161], 
           Hue[0.010667080104723725`, 1, 0.9852301967780749], 
           Hue[0.05242945985458425, 1, 0.927405363278268], 
           Hue[0.05810159962324535, 1, 0.919551631290891], 
           Hue[0.6497389422959918, 1, 0.10036146451324211`], 
           Hue[0.6497143524323117, 1, 0.10039551201679923`], 
           Hue[0.6499446791317118, 1, 0.10007659812532207`], 
           Hue[0.6499914127424962, 1, 0.10001189004885144`], 
           Hue[0.6499989602457273, 1, 0.10000143965976215`], 
           Hue[0.6499999053015012, 1, 0.10000013112099838`], 
           Hue[0.6499998099007703, 1, 0.10000026321431808`], 
           Hue[0.6499981812644314, 1, 0.10000251824924884`], 
           Hue[0.6499871127135868, 1, 0.10001784393503368`], 
           Hue[0.02709147212931462, 1, 0.9624887308978721], 
           Hue[0.02707363797266582, 1, 0.9625134243455397], 
           Hue[0.6499552803098139, 1, 0.10006191957102697`], 
           Hue[0.6499929243432876, 1, 0.10000979706314023`], 
           Hue[0.649998861931212, 1, 0.10000157578755257`], 
           Hue[0.6499999539215624, 1, 0.1000000638009137], 
           Hue[0.6499996397889839, 1, 0.10000049875371464`], 
           Hue[0.6499993192256, 1, 0.10000094261070784`], 
           Hue[0.6499982700550374, 1, 0.10000239530840976`], 
           Hue[0.6499989057002725, 1, 0.10000151518423804`], 
           Hue[0.6497851328324681, 1, 0.10029750838581342`], 
           Hue[0.6494614008079023, 1, 0.10074575272752002`], 
           Hue[0.6404078578025607, 1, 0.11328142765799296`], 
           Hue[0.6498206455449007, 1, 0.10024833693782975`], 
           Hue[0.6499551253828283, 1, 0.1000621340853147], 
           Hue[0.6499719284481867, 1, 0.1000388683025107], 
           Hue[0.649981186578344, 1, 0.10002604935306213`], 
           Hue[0.6499774815479088, 1, 0.10003117939520317`], 
           Hue[0.6499928827959313, 1, 0.10000985459024901`], 
           Hue[0.6499812225788023, 1, 0.10002599950627371`], 
           Hue[0.649977555421589, 1, 0.10003107710856914`], 
           Hue[0.6499899497720244, 1, 0.10001391570027393`], 
           Hue[0.6499993562029576, 1, 0.1000008914112895], 
           Hue[0.649998333888502, 1, 0.10000230692361262`], 
           Hue[0.6499985371764694, 1, 0.10000202544796548`], 
           Hue[0.649981132862961, 1, 0.10002612372820784`], 
           Hue[0.6499954680826809, 1, 0.10000627496244185`], 
           Hue[0.6499986013933341, 1, 0.1000019365323067], 
           Hue[0.6499968945489247, 1, 0.10000429985533509`], 
           Hue[0.6499991262252099, 1, 0.10000120984201698`], 
           Hue[0.6499975790673054, 1, 0.10000335206065417`], 
           Hue[0.6499969119221585, 1, 0.10000427580008835`], 
           Hue[0.6499887061646138, 1, 0.10001563761822713`], 
           Hue[0.649997998599588, 1, 0.10000277116980137`], 
           Hue[0.649999746592461, 1, 0.10000035087197716`], 
           Hue[0.6499999731984859, 1, 0.10000003710978886`], 
           Hue[0.6498206206758443, 1, 0.10024837137190794`], 
           Hue[0.6499888903804653, 1, 0.10001538255012506`], 
           Hue[0.6499971342997227, 1, 0.10000396789269159`], 
           Hue[0.649999454487984, 1, 0.10000075532432992`], 
           Hue[0.6499997881961503, 1, 0.10000029326686882`], 
           Hue[0.6499998715320819, 1, 0.10000017787865574`], 
           Hue[0.6499996708038481, 1, 0.10000045581005648`], 
           Hue[0.6499998405135435, 1, 0.10000022082740136`], 
           Hue[0.6499997277891764, 1, 0.10000037690729435`], 
           Hue[0.6499996736696589, 1, 0.10000045184201072`], 
           Hue[0.6498206455449007, 1, 0.10024833693782977`], 
           Hue[0.6499908589738947, 1, 0.10001265680537647`], 
           Hue[0.6499980650680817, 1, 0.10000267913650228`], 
           Hue[0.6499997205474622, 1, 0.10000038693428308`], 
           Hue[0.6499999927381648, 1, 0.10000001005484888`], 
           Hue[0.6499999750758687, 1, 0.10000003451033561`], 
           Hue[0.649997537735836, 1, 0.10000340928884255`], 
           Hue[0.6499990259760979, 1, 0.1000013486484798], 
           Hue[0.6499453175635969, 1, 0.10007571414271207`], 
           Hue[0.6499975567721432, 1, 0.10000338293087865`], 
           Hue[0.6499991607215534, 1, 0.10000116207784923`], 
           Hue[0.6499999209879762, 1, 0.10000010940126382`], 
           Hue[0.6499452554080252, 1, 0.10007580020427294`], 
           Hue[0.6499999927381648, 1, 0.10000001005484888`], 
           Hue[0.6499999724303417, 1, 0.10000003817337312`], 
           Hue[0.6483242391402425, 1, 0.10232028426735651`], 
           Hue[0.6431583990632883, 1, 0.1094729859123701], 
           Hue[0.6482530143242407, 1, 0.10241890324335912`], 
           Hue[0.6463635850696269, 1, 0.10503503605743975`], 
           Hue[0.6471956278813717, 1, 0.10388297677963922`], 
           Hue[0.6464975004715672, 1, 0.10484961473167623`], 
           Hue[0.6499975567721432, 1, 0.10000338293087865`], 
           Hue[0.6499991607215534, 1, 0.10000116207784923`], 
           Hue[0.6499996979082646, 1, 0.10000041828086434`], 
           Hue[0.6431583990632911, 1, 0.10947298591236626`], 
           Hue[0.6483242391402418, 1, 0.10232028426735748`], 
           Hue[0.6463635850696212, 1, 0.10503503605744753`], 
           Hue[0.6482530143242377, 1, 0.10241890324336335`], 
           Hue[0.6483242391402463, 1, 0.10232028426735128`], 
           Hue[0.6482524798771888, 1, 0.10241964324696944`], 
           Hue[0.6460888132276699, 1, 0.10541548937707247`], 
           Hue[0.6451751558078836, 1, 0.10668055349677649`], 
           Hue[0.6447410918958293, 1, 0.1072815650673133], 
           Hue[0.6313031433723599, 1, 0.12588795533057862`], 
           Hue[0.6465512173141803, 1, 0.10477523756498112`], 
           Hue[0.6450730162625558, 1, 0.10682197748261514`], 
           Hue[0.6460888132276699, 1, 0.10541548937707258`], 
           Hue[0.6451751558078835, 1, 0.1066805534967767], 
           Hue[0.6451837682394977, 1, 0.10666862859146475`], 
           Hue[0.6479792421191494, 1, 0.10279797245040857`], 
           Hue[0.6476184271540987, 1, 0.10329756240201719`], 
           Hue[0.6475036441269619, 1, 0.10345649274728348`], 
           Hue[0.648324239140247, 1, 0.10232028426735042`], 
           Hue[0.6482524798771917, 1, 0.10241964324696531`], 
           Hue[0.648682976894605, 1, 0.10182357045362386`], 
           Hue[0.6465512173141805, 1, 0.10477523756498087`], 
           Hue[0.6479792421191495, 1, 0.10279797245040849`], 
           Hue[0.6476184271540988, 1, 0.10329756240201703`], 
           Hue[0.6499698377498546, 1, 0.10004176311558596`], 
           Hue[0.6499958626928356, 1, 0.10000572857915081`], 
           Hue[0.6499989602457273, 1, 0.10000143965976215`], 
           Hue[0.6499995620862684, 1, 0.10000060634208989`], 
           Hue[0.6499855624175456, 1, 0.10001999049878305`], 
           Hue[0.6499942635068771, 1, 0.10000794283663174`], 
           Hue[0.6499957594867645, 1, 0.10000587147986459`], 
           Hue[0.6499982534432173, 1, 0.1000024183093915], 
           Hue[0.6499986030712614, 1, 0.10000193420902256`], 
           Hue[0.6499996352970167, 1, 0.10000050497336162`], 
           Hue[0.6499996918089019, 1, 0.10000042672613585`], 
           Hue[0.6499857545886895, 1, 0.10001972441566084`], 
           Hue[0.649994657510819, 1, 0.1000073972927123], 
           Hue[0.6499959545446957, 1, 0.10000560139965206`], 
           Hue[0.6499985371764694, 1, 0.10000202544796548`], 
           Hue[0.6499987724866683, 1, 0.10000169963384406`], 
           Hue[0.649999746592461, 1, 0.10000035087197716`], 
           Hue[0.64999976764185, 1, 0.10000032172666927`], 
           Hue[0.6499856125038711, 1, 0.10001992114848618`], 
           Hue[0.649988018614091, 1, 0.10001658961125877`], 
           Hue[0.6499958852039428, 1, 0.10000569740992535`], 
           Hue[0.6499967008729203, 1, 0.1000045680221105], 
           Hue[0.6499926276132632, 1, 0.10001020792009714`], 
           Hue[0.6499908288660274, 1, 0.10001269849319286`], 
           Hue[0.6499991007478049, 1, 0.10000124511842408`], 
           Hue[0.649997537735836, 1, 0.10000340928884255`], 
           Hue[0.6499858078426721, 1, 0.1000196506793771], 
           Hue[0.649988752611403, 1, 0.1000155733072882], 
           Hue[0.6499728876119557, 1, 0.10003754022959983`], 
           Hue[0.6499965007467773, 1, 0.10000484511984689`], 
           Hue[0.6499970665105199, 1, 0.1000040617546648], 
           Hue[0.6499933578423218, 1, 0.10000919683370825`], 
           Hue[0.6499920691746767, 1, 0.10001098114275549`], 
           Hue[0.6498594518723236, 1, 0.10019460509985961`], 
           Hue[0.6498693537502516, 1, 0.10018089480734406`], 
           Hue[0.6499993562029576, 1, 0.1000008914112895], 
           Hue[0.649997036906219, 1, 0.10000410274523522`], 
           Hue[0.6499886776939561, 1, 0.10001567703913772`], 
           Hue[0.6499857545886895, 1, 0.10001972441566084`], 
           Hue[0.6498965941389109, 1, 0.10014317734612337`], 
           Hue[0.6479792421191494, 1, 0.10279797245040863`], 
           Hue[0.6476184271540988, 1, 0.1032975624020171], 
           Hue[0.6475036441269622, 1, 0.10345649274728327`], 
           Hue[0.6465512173141802, 1, 0.10477523756498137`], 
           Hue[0.645653310526761, 1, 0.1060184931167925], 
           Hue[0.6479792421191491, 1, 0.10279797245040885`], 
           Hue[0.6476184271540985, 1, 0.10329756240201762`], 
           Hue[0.6475036441269617, 1, 0.10345649274728375`], 
           Hue[0.6460888132276827, 1, 0.10541548937705467`], 
           Hue[0.6451751558079051, 1, 0.10668055349674681`], 
           Hue[0.6447410918958457, 1, 0.10728156506729052`], 
           Hue[0.6432319744106683, 1, 0.10937111235445943`], 
           Hue[0.644822685525103, 1, 0.10716858927293434`], 
           Hue[0.642232904597574, 1, 0.1107544397879746], 
           Hue[0.6447422602883427, 1, 0.10727994729306399`], 
           Hue[0.6432412882886112, 1, 0.1093582162157692], 
           Hue[0.6465512173141732, 1, 0.10477523756499099`], 
           Hue[0.6369345841081043, 1, 0.11809057585031717`], 
           Hue[0.6313032801501992, 1, 0.12588776594587803`], 
           Hue[0.5681211260697845, 1, 0.21337074851875992`], 
           Hue[0.6035532562554852, 1, 0.16431087595394364`], 
           Hue[0.6363391370257159, 1, 0.11891504104131655`], 
           Hue[0.6309334967132458, 1, 0.1263997737816596], 
           Hue[0.6451837682394547, 1, 0.10666862859152436`], 
           Hue[0.6460888132276146, 1, 0.10541548937714908`], 
           Hue[0.6451751558078197, 1, 0.10668055349686502`], 
           Hue[0.6447410918957623, 1, 0.10728156506740609`], 
           Hue[0.6432319744106638, 1, 0.10937111235446557`], 
           Hue[0.6448226855250837, 1, 0.10716858927296105`], 
           Hue[0.5681211260697305, 1, 0.21337074851883464`], 
           Hue[0.6035532562554903, 1, 0.16431087595393662`], 
           Hue[0.6175668224059234, 1, 0.1449074766687214], 
           Hue[0.6369345841081185, 1, 0.11809057585029736`], 
           Hue[0.6313032801502132, 1, 0.12588776594585865`], 
           Hue[0.6431583990630713, 1, 0.10947298591267063`], 
           Hue[0.636934584107928, 1, 0.11809057585056115`], 
           Hue[0.6313032801501643, 1, 0.1258877659459263], 
           Hue[0.5681211260708114, 1, 0.21337074851733795`], 
           Hue[0.6035532562559326, 1, 0.16431087595332416`], 
           Hue[0.6175668224060558, 1, 0.14490747666853818`], 
           Hue[0.643231974410409, 1, 0.10937111235481833`], 
           Hue[0.6448226855248737, 1, 0.10716858927325197`], 
           Hue[0.6499991655407161, 1, 0.1000011554051624], 
           Hue[0.6499966739061288, 1, 0.10000460536074483`], 
           Hue[0.6499879519206576, 1, 0.1000166819560126], 
           Hue[0.6499855624175456, 1, 0.10001999049878303`], 
           Hue[0.6498948240795815, 1, 0.10014562819750247`], 
           Hue[0.63093349671357, 1, 0.12639977378121073`], 
           Hue[0.639857669156809, 1, 0.11404322732134148`], 
           Hue[0.6363391370261072, 1, 0.11891504104077469`], 
           Hue[0.5681211260708074, 1, 0.2133707485173436], 
           Hue[0.6035532562559285, 1, 0.16431087595332988`], 
           Hue[0.617566822406053, 1, 0.144907476668542], 
           Hue[0.6431583990630698, 1, 0.10947298591267261`], 
           Hue[0.6369345841079257, 1, 0.11809057585056448`], 
           Hue[0.6432412882886738, 1, 0.10935821621568247`], 
           Hue[0.644742260288362, 1, 0.10727994729303719`], 
           Hue[0.6432319744104082, 1, 0.10937111235481942`], 
           Hue[0.6448226855248731, 1, 0.10716858927325264`], 
           Hue[0.6456533105267654, 1, 0.10601849311678642`], 
           Hue[0.6498693537502516, 1, 0.100180894807344], 
           Hue[0.6499374484373719, 1, 0.10008660985594665`], 
           Hue[0.6498594518723237, 1, 0.1001946050998595], 
           Hue[0.6499933578423218, 1, 0.10000919683370825`], 
           Hue[0.6499920691746767, 1, 0.10001098114275549`], 
           Hue[0.6499965007467773, 1, 0.10000484511984688`], 
           Hue[0.6499970665105199, 1, 0.1000040617546648], 
           Hue[0.649988752611403, 1, 0.10001557330728819`], 
           Hue[0.6499858078426721, 1, 0.10001965067937708`], 
           Hue[0.6499977238559549, 1, 0.10000315158406245`], 
           Hue[0.6499991746468223, 1, 0.10000114279670756`], 
           Hue[0.6499926276132632, 1, 0.10001020792009714`], 
           Hue[0.6499908288660274, 1, 0.10001269849319284`], 
           Hue[0.6499958852039428, 1, 0.10000569740992533`], 
           Hue[0.6499967008729203, 1, 0.10000456802211048`], 
           Hue[0.649988018614091, 1, 0.10001658961125875`], 
           Hue[0.6499856125038711, 1, 0.10001992114848615`], 
           Hue[0.6499999068044836, 1, 0.10000012903994587`], 
           Hue[0.6499992554553338, 1, 0.10000103090799936`], 
           Hue[0.6499452847292683, 1, 0.10007575960562864`], 
           Hue[0.6499560274362279, 1, 0.10006088508829988`], 
           Hue[0.649997310025984, 1, 0.10000372457940669`], 
           Hue[0.6499980905392484, 1, 0.10000264386873307`], 
           Hue[0.6499992600207877, 1, 0.10000102458660165`], 
           Hue[0.6499999539215624, 1, 0.1000000638009137], 
           Hue[0.6499998099007703, 1, 0.10000026321431808`], 
           Hue[0.649998861931212, 1, 0.10000157578755257`], 
           Hue[0.6499453252164491, 1, 0.10007570354645512`], 
           Hue[0.6499927658336027, 1, 0.10001001653808872`], 
           Hue[0.6499970704909728, 1, 0.10000405624326845`], 
           Hue[0.6499999926822643, 1, 0.10000001013224943`], 
           Hue[0.649999231209965, 1, 0.10000106447851004`], 
           Hue[0.649999746592461, 1, 0.10000035087197716`], 
           Hue[0.649995048229519, 1, 0.10000685629758907`], 
           Hue[0.649912880804017, 1, 0.10012062657905337`], 
           Hue[0.6499334905618971, 1, 0.10009208999121949`], 
           Hue[0.6499428471125177, 1, 0.10007913476728314`], 
           Hue[0.6499742829535601, 1, 0.10003560821814764`], 
           Hue[0.6499995099093939, 1, 0.10000067858699309`], 
           Hue[0.6499997612218463, 1, 0.10000033061590513`], 
           Hue[0.6499996736696589, 1, 0.10000045184201072`], 
           Hue[0.6499997277891764, 1, 0.10000037690729435`], 
           Hue[0.6499998723238989, 1, 0.10000017678229389`], 
           Hue[0.6499997599027079, 1, 0.10000033244240446`], 
           Hue[0.6499996708038481, 1, 0.10000045581005648`], 
           Hue[0.6499998715320819, 1, 0.10000017787865574`], 
           Hue[0.6499981812644314, 1, 0.10000251824924884`], 
           Hue[0.6499155953597011, 1, 0.10011686796349077`], 
           Hue[0.6499442388258546, 1, 0.10007720777958598`], 
           Hue[0.6499955738243941, 1, 0.1000061285508389], 
           Hue[0.6499985371764694, 1, 0.10000202544796548`], 
           Hue[0.649976311639638, 1, 0.1000327992681936], 
           Hue[0.6499786307209967, 1, 0.10002958823246613`], 
           Hue[0.649983522105702, 1, 0.10002281554595112`], 
           Hue[0.6499919444905073, 1, 0.10001115378237442`], 
           Hue[0.6499910794886076, 1, 0.1000123514773127], 
           Hue[0.6499975708283137, 1, 0.10000336346848884`], 
           Hue[0.6499968945489246, 1, 0.1000042998553351], 
           Hue[0.6499986013933341, 1, 0.1000019365323067], 
           Hue[0.6499871127135868, 1, 0.10001784393503368`], 
           Hue[0.6499927658336027, 1, 0.10001001653808872`], 
           Hue[0.6499970704909728, 1, 0.10000405624326845`], 
           Hue[0.6499972818328055, 1, 0.10000376361611546`], 
           Hue[0.6499983540750625, 1, 0.10000227897299048`], 
           Hue[0.6499830415932077, 1, 0.10002348087094315`], 
           Hue[0.6499933017246096, 1, 0.10000927453515605`], 
           Hue[0.649920525041201, 1, 0.10011004225064472`], 
           Hue[0.6499371615166366, 1, 0.10008700713081092`], 
           Hue[0.6499811865783439, 1, 0.10002604935306231`], 
           Hue[0.6499774815479086, 1, 0.10003117939520352`], 
           Hue[0.6499579090308498, 1, 0.10005827980343876`], 
           Hue[0.6465824912328809, 1, 0.10473193521601107`], 
           Hue[0.6469518842360068, 1, 0.10422046798091374`], 
           Hue[0.6464981818998694, 1, 0.1048486712155655], 
           Hue[0.6486837082759831, 1, 0.1018225577717157], 
           Hue[0.6471966341309858, 1, 0.1038815835109428], 
           Hue[0.648252479877121, 1, 0.10241964324706332`], 
           Hue[0.6486829768945355, 1, 0.10182357045372016`], 
           Hue[0.6474500234495466, 1, 0.1035307367621662], 
           Hue[0.646551987163097, 1, 0.10477417162032727`], 
           Hue[0.6441390283452341, 1, 0.1081151915219836], 
           Hue[0.6499452554080251, 1, 0.10007580020427298`], 
           Hue[0.6378619063740157, 1, 0.11680659117443976`], 
           Hue[0.6394934187185672, 1, 0.1145475740819838], 
           Hue[0.641618216230081, 1, 0.11160554675834945`], 
           Hue[0.6090317928643224, 1, 0.15672520988016897`], 
           Hue[0.5965604897300457, 1, 0.17399316806609055`], 
           Hue[0.6058778207336497, 1, 0.16109224821494667`], 
           Hue[0.6210502495195851, 1, 0.14008426989595912`], 
           Hue[0.6416182162300761, 1, 0.11160554675835616`], 
           Hue[0.6417543806434738, 1, 0.11141701141672865`], 
           Hue[0.6499304140750839, 1, 0.10009634974219153`], 
           Hue[0.6499879519206576, 1, 0.10001668195601261`], 
           Hue[0.6499925770634212, 1, 0.10001027791218615`], 
           Hue[0.6499982700550374, 1, 0.10000239530840976`], 
           Hue[0.6499428471125177, 1, 0.10007913476728321`], 
           Hue[0.6499742829535601, 1, 0.10003560821814765`], 
           Hue[0.6499770919050559, 1, 0.10003171890069185`], 
           Hue[0.6353293129837174, 1, 0.12031325894562206`], 
           Hue[0.6210502495196695, 1, 0.1400842698958423], 
           Hue[0.6220796274099561, 1, 0.1386589774323685], 
           Hue[0.6498768869650647, 1, 0.10017046420221809`], 
           Hue[0.6499888903804653, 1, 0.10001538255012506`], 
           Hue[0.649972980055223, 1, 0.10003741223122971`], 
           Hue[0.6499980722882938, 1, 0.10000266913928554`], 
           Hue[0.6499992600207877, 1, 0.10000102458660165`], 
           Hue[0.6498182666377854, 1, 0.10025163080922017`], 
           Hue[0.649981132862961, 1, 0.10002612372820786`], 
           Hue[0.6499568986091694, 1, 0.10005967884884236`], 
           Hue[0.6499971342997227, 1, 0.10000396789269159`], 
           Hue[0.6499998555397438, 1, 0.10000020002189328`], 
           Hue[0.6465824912328155, 1, 0.1047319352161016], 
           Hue[0.646951884235956, 1, 0.10422046798098417`], 
           Hue[0.6464981818998243, 1, 0.10484867121562785`], 
           Hue[0.6464975004716572, 1, 0.10484961473155151`], 
           Hue[0.6497373247140598, 1, 0.1003637042420711], 
           Hue[0.6499719284481866, 1, 0.10003886830251084`], 
           Hue[0.6499369681039929, 1, 0.10008727493293283`], 
           Hue[0.6499954680826809, 1, 0.10000627496244185`], 
           Hue[0.649999454487984, 1, 0.10000075532432992`], 
           Hue[0.649983522105702, 1, 0.10002281554595117`], 
           Hue[0.6499919444905073, 1, 0.10001115378237445`], 
           Hue[0.6499910794886075, 1, 0.10001235147731274`], 
           Hue[0.649998606782629, 1, 0.10000192907020604`], 
           Hue[0.6499992903837791, 1, 0.10000098254553669`], 
           Hue[0.6499884844621604, 1, 0.10001594459085487`], 
           Hue[0.6499935635661466, 1, 0.10000891198533556`], 
           Hue[0.6499547241190271, 1, 0.10006268968134718`], 
           Hue[0.6471966341309734, 1, 0.10388158351096], 
           Hue[0.6486837082759777, 1, 0.10182255777172321`], 
           Hue[0.027091472130218897`, 1, 0.96248873089662], 
           Hue[0.6474500234496732, 1, 0.10353073676199107`], 
           Hue[0.649955125382828, 1, 0.10006213408531515`], 
           Hue[0.6499928827959313, 1, 0.10000985459024905`], 
           Hue[0.6499991262252099, 1, 0.10000120984201699`], 
           Hue[0.6499999658355468, 1, 0.10000004730462761`], 
           Hue[0.6498967127539552, 1, 0.1001430131099082], 
           Hue[0.6498321507756425, 1, 0.10023240661834114`], 
           Hue[0.6497387800110396, 1, 0.10036168921548362`], 
           Hue[0.649714030702675, 1, 0.10039595748860397`], 
           Hue[0.010673854646818914`, 1, 0.9852208166428661], 
           Hue[0.010667080104693194`, 1, 0.9852301967781171], 
           Hue[0.649983522105702, 1, 0.10002281554595115`], 
           Hue[0.6499919444905073, 1, 0.10001115378237443`], 
           Hue[0.6499999750758687, 1, 0.10000003451033561`], 
           Hue[0.6499997857288967, 1, 0.10000029668306613`], 
           Hue[0.6499979781484426, 1, 0.10000279948677178`], 
           Hue[0.6499857386104357, 1, 0.10001974653939674`], 
           Hue[0.6499227855829615, 1, 0.10010691226974568`], 
           Hue[0.649936968103993, 1, 0.10008727493293268`], 
           Hue[0.6496696618168444, 1, 0.1004573913305232], 
           Hue[0.6497373247140593, 1, 0.1003637042420717], 
           Hue[0.648252479877121, 1, 0.10241964324706324`], 
           Hue[0.6486829768945355, 1, 0.1018235704537201], 
           Hue[0.647450023449547, 1, 0.10353073676216572`], 
           Hue[0.6313031433718941, 1, 0.12588795533122368`], 
           Hue[0.0711638544660157, 1, 0.9014654322778245], 
           Hue[0.05244141947093095, 1, 0.9273888038094803], 
           Hue[0.05242945985472813, 1, 0.9274053632780688], 
           Hue[0.05810159962336514, 1, 0.9195516312907253], 
           Hue[0.6482530143241786, 1, 0.10241890324344512`], 
           Hue[0.6463635850694541, 1, 0.10503503605767897`], 
           Hue[0.6474507800969185, 1, 0.10352968909657442`], 
           Hue[0.6486837082759177, 1, 0.10182255777180628`], 
           Hue[0.6471966341308304, 1, 0.10388158351115798`], 
           Hue[0.6499910794886075, 1, 0.10001235147731273`], 
           Hue[0.6499938301355157, 1, 0.10000854288928591`], 
           Hue[0.6499987037961257, 1, 0.1000017947438261], 
           Hue[0.6499996352970167, 1, 0.10000050497336162`], 
           Hue[0.6499904461340845, 1, 0.1000132284297292], 
           Hue[0.6499477127625019, 1, 0.10007239771345895`], 
           Hue[0.6499568986091695, 1, 0.1000596788488423], 
           Hue[0.6497822958439452, 1, 0.1003014365237683], 
           Hue[0.649818266637786, 1, 0.10025163080921949`], 
           Hue[0.6465824912328294, 1, 0.10473193521608234`], 
           Hue[0.6469518842359252, 1, 0.10422046798102663`], 
           Hue[0.6499975567721432, 1, 0.10000338293087865`], 
           Hue[0.6499991607215534, 1, 0.10000116207784923`], 
           Hue[0.6499996979082646, 1, 0.10000041828086434`], 
           Hue[0.6499992600207877, 1, 0.10000102458660165`], 
           Hue[0.6499988738287195, 1, 0.10000155931408075`], 
           Hue[0.6499995822700525, 1, 0.1000005783953119], 
           Hue[0.6499941257642842, 1, 0.100008133557145], 
           Hue[0.6499982534432173, 1, 0.1000024183093915], 
           Hue[0.6499651447615216, 1, 0.10004826109943166`], 
           Hue[0.649972980055223, 1, 0.1000374122312297], 
           Hue[0.6498491275148006, 1, 0.10020890036412228`], 
           Hue[0.6498768869650648, 1, 0.10017046420221801`], 
           Hue[0.6058778207335989, 1, 0.161092248215017], 
           Hue[0.6210502495195549, 1, 0.14008426989600098`], 
           Hue[0.6220796274097713, 1, 0.1386589774326244], 
           Hue[0.6499428471125177, 1, 0.10007913476728315`], 
           Hue[0.6499742829535601, 1, 0.10003560821814764`], 
           Hue[0.6499770919050559, 1, 0.10003171890069183`], 
           Hue[0.6499807215560938, 1, 0.100026693230024], 
           Hue[0.6499925770634212, 1, 0.10001027791218614`], 
           Hue[0.6499035776827975, 1, 0.10013350782381886`], 
           Hue[0.649930414075084, 1, 0.10009634974219148`], 
           Hue[0.6394934187185649, 1, 0.11454757408198707`], 
           Hue[0.6416182162300839, 1, 0.11160554675834541`], 
           Hue[0.6417543806434844, 1, 0.11141701141671394`], 
           Hue[0.6499558704947553, 1, 0.1000611023918773], 
           Hue[0.6210502495196204, 1, 0.1400842698959103], 
           Hue[0.6220796274098989, 1, 0.1386589774324477], 
           Hue[0.5965604897305343, 1, 0.17399316806541407`], 
           Hue[0.6090317928649146, 1, 0.156725209879349], 
           Hue[0.6416182162300909, 1, 0.11160554675833581`], 
           Hue[0.6417543806434991, 1, 0.1114170114166936], 
           Hue[0.6378619063741094, 1, 0.11680659117431007`], 
           Hue[0.6441390283452455, 1, 0.10811519152196784`], 
           Hue[0.646551987163097, 1, 0.10477417162032729`], 
           Hue[0.6474500234496774, 1, 0.10353073676198514`], 
           Hue[0.6463635850694534, 1, 0.10503503605767994`], 
           Hue[0.6482530143241784, 1, 0.10241890324344531`], 
           Hue[0.647450780096918, 1, 0.10352968909657513`], 
           Hue[0.64719663413083, 1, 0.10388158351115853`], 
           Hue[0.6486837082759176, 1, 0.10182255777180639`], 
           Hue[0.6465824912328293, 1, 0.10473193521608254`], 
           Hue[0.6469518842359251, 1, 0.10422046798102687`], 
           Hue[0.6464981818997425, 1, 0.10484867121574122`], 
           Hue[0.6499453175635969, 1, 0.10007571414271205`], 
           Hue[0.649832150775643, 1, 0.1002324066183404], 
           Hue[0.6497389422959922, 1, 0.10036146451324161`], 
           Hue[0.6497143524323119, 1, 0.10039551201679897`], 
           Hue[0.649896973543708, 1, 0.10014265201640439`], 
           Hue[0.6499371615166366, 1, 0.10008700713081096`], 
           Hue[0.6499886776939561, 1, 0.10001567703913773`], 
           Hue[0.6499933017246096, 1, 0.10000927453515607`], 
           Hue[0.6499927658336027, 1, 0.10001001653808872`], 
           Hue[0.6499970704909728, 1, 0.10000405624326845`], 
           Hue[0.6499972818328055, 1, 0.10000376361611546`], 
           Hue[0.6499690892099144, 1, 0.10004279955550321`], 
           Hue[0.649983522105702, 1, 0.10002281554595113`], 
           Hue[0.6499919444905073, 1, 0.10001115378237443`], 
           Hue[0.6499910794886075, 1, 0.10001235147731273`], 
           Hue[0.6499908589738947, 1, 0.10001265680537647`], 
           Hue[0.6499786307209967, 1, 0.10002958823246615`], 
           Hue[0.6499984305375945, 1, 0.10000217310179225`], 
           Hue[0.6499949826603763, 1, 0.10000694708563292`], 
           Hue[0.6499983681725562, 1, 0.10000225945338377`], 
           Hue[0.6499887061646138, 1, 0.10001563761822713`], 
           Hue[0.6499980650680817, 1, 0.10000267913650228`], 
           Hue[0.6499442388258546, 1, 0.10007720777958594`], 
           Hue[0.6499155953597011, 1, 0.10011686796349074`], 
           Hue[0.6499967448026513, 1, 0.10000450719632889`], 
           Hue[0.6499993878957052, 1, 0.10000084752902356`], 
           Hue[0.6499428471125177, 1, 0.10007913476728314`], 
           Hue[0.6499742829535601, 1, 0.10003560821814764`], 
           Hue[0.6499770919050559, 1, 0.10003171890069183`], 
           Hue[0.6499334905618971, 1, 0.10009208999121944`], 
           Hue[0.6499306690177541, 1, 0.10009599674464822`], 
           Hue[0.6499128808040171, 1, 0.10012062657905328`], 
           Hue[0.6499899497720244, 1, 0.10001391570027393`], 
           Hue[0.649997998599588, 1, 0.10000277116980137`], 
           Hue[0.6499997205474622, 1, 0.10000038693428308`], 
           Hue[0.6499927658336027, 1, 0.10001001653808872`], 
           Hue[0.6499970704909728, 1, 0.10000405624326845`], 
           Hue[0.6499972818328055, 1, 0.10000376361611546`], 
           Hue[0.649999637473088, 1, 0.10000050196033976`], 
           Hue[0.6499990284977293, 1, 0.10000134515699023`], 
           Hue[0.6499985546968547, 1, 0.10000200118897033`], 
           Hue[0.6499983540750625, 1, 0.10000227897299048`], 
           Hue[0.6499977323549201, 1, 0.10000313981626457`], 
           Hue[0.6499453252164491, 1, 0.10007570354645513`], 
           Hue[0.6499879519206576, 1, 0.10001668195601261`], 
           Hue[0.6499972861634967, 1, 0.10000375761977373`], 
           Hue[0.6499980722882938, 1, 0.10000266913928554`], 
           Hue[0.6499993956352772, 1, 0.10000083681269313`], 
           Hue[0.6499996064912191, 1, 0.10000054485831195`], 
           Hue[0.6499975567721432, 1, 0.10000338293087865`], 
           Hue[0.6499991607215534, 1, 0.10000116207784923`], 
           Hue[0.6499996979082646, 1, 0.10000041828086434`], 
           Hue[0.6499992600207877, 1, 0.10000102458660165`], 
           Hue[0.6499996397889839, 1, 0.10000049875371464`], 
           Hue[0.6499995822700525, 1, 0.1000005783953119], 
           Hue[0.649999402582182, 1, 0.10000082719390185`], 
           Hue[0.6499999539215624, 1, 0.1000000638009137], 
           Hue[0.6499982700550374, 1, 0.10000239530840976`], 
           Hue[0.649997310025984, 1, 0.10000372457940668`], 
           Hue[0.6499452847292683, 1, 0.10007575960562862`], 
           Hue[0.6499886776939561, 1, 0.10001567703913773`], 
           Hue[0.6499977069520597, 1, 0.10000317498945578`], 
           Hue[0.6499984305375945, 1, 0.10000217310179225`], 
           Hue[0.6499995741123579, 1, 0.10000058969058151`], 
           Hue[0.6499997386779457, 1, 0.1000003618305367], 
           Hue[0.6499988738287195, 1, 0.10000155931408075`], 
           Hue[0.6499995822700525, 1, 0.1000005783953119], 
           Hue[0.6499977323549201, 1, 0.10000313981626457`], 
           Hue[0.6499972818328055, 1, 0.10000376361611546`], 
           Hue[0.6499983540750625, 1, 0.10000227897299048`], 
           Hue[0.6499995672298762, 1, 0.10000059922017145`], 
           Hue[0.6499998500410374, 1, 0.10000020763548673`], 
           Hue[0.6499999121863456, 1, 0.10000012158813694`], 
           Hue[0.6499306690177541, 1, 0.10009599674464828`], 
           Hue[0.6499731279556002, 1, 0.10003720744609199`], 
           Hue[0.6499770919050559, 1, 0.10003171890069185`], 
           Hue[0.649985171412803, 1, 0.10002053188996514`], 
           Hue[0.6499374484373719, 1, 0.1000866098559467], 
           Hue[0.6499995672298762, 1, 0.10000059922017145`], 
           Hue[0.6499998500410374, 1, 0.10000020763548673`], 
           Hue[0.6499969119221585, 1, 0.10000427580008833`], 
           Hue[0.6499938301355158, 1, 0.10000854288928589`], 
           Hue[0.6499775554215892, 1, 0.10003107710856879`], 
           Hue[0.6498969735437105, 1, 0.10014265201640095`], 
           Hue[0.649985171412803, 1, 0.10002053188996515`], 
           Hue[0.6499995822700525, 1, 0.1000005783953119], 
           Hue[0.6499998922117048, 1, 0.10000014924533172`], 
           Hue[0.6499997981432292, 1, 0.1000002794939904], 
           Hue[0.6499938301355157, 1, 0.10000854288928591`], 
           Hue[0.6499989602457273, 1, 0.10000143965976215`], 
           Hue[0.6499914127424963, 1, 0.10001189004885142`], 
           Hue[0.6499446791317125, 1, 0.10007659812532119`], 
           Hue[0.6497389422959958, 1, 0.10036146451323662`], 
           Hue[0.6497143524323192, 1, 0.10039551201678877`], 
           Hue[0.07116385446886964, 1, 0.9014654322738728], 
           Hue[0.05242945985811742, 1, 0.9274053632733759], 
           Hue[0.6498967127539569, 1, 0.10014301310990587`], 
           Hue[0.6499774815479087, 1, 0.10003117939520335`], 
           Hue[0.6499968945489246, 1, 0.1000042998553351], 
           Hue[0.6499996708038481, 1, 0.10000045581005648`], 
           Hue[0.05244141947316405, 1, 0.9273888038063882], 
           Hue[0.05812442404615403, 1, 0.9195200282437868], 
           Hue[0.6499996736696589, 1, 0.10000045184201072`], 
           Hue[0.649985171412803, 1, 0.10002053188996514`], 
           Hue[0.6497387800110449, 1, 0.10036168921547634`], 
           Hue[0.6497140307026844, 1, 0.10039595748859087`], 
           Hue[0.649999637473088, 1, 0.10000050196033976`], 
           Hue[0.6499990284977293, 1, 0.10000134515699023`], 
           Hue[0.6499983540750625, 1, 0.10000227897299048`], 
           Hue[0.6499938301355157, 1, 0.10000854288928591`], 
           Hue[0.6499988113356224, 1, 0.10000164584298435`], 
           Hue[0.6499979341247507, 1, 0.10000286044265294`], 
           Hue[0.6499995672298762, 1, 0.10000059922017145`], 
           Hue[0.6499998500410374, 1, 0.10000020763548673`], 
           Hue[0.6499999121863456, 1, 0.10000012158813694`], 
           Hue[0.6499999042768432, 1, 0.1000001325397556], 
           Hue[0.6499998912637305, 1, 0.10000015055791167`], 
           Hue[0.6499997965508454, 1, 0.10000028169882953`], 
           Hue[0.6499998391866144, 1, 0.10000022266468775`], 
           Hue[0.6499997047177185, 1, 0.1000004088523898], 
           Hue[0.649985171412803, 1, 0.10002053188996514`], 
           Hue[0.6499731279556002, 1, 0.10003720744609197`], 
           Hue[0.6499995672298762, 1, 0.10000059922017145`], 
           Hue[0.6499998500410374, 1, 0.10000020763548673`], 
           Hue[0.6499999121863456, 1, 0.10000012158813694`], 
           Hue[0.6499989556520133, 1, 0.10000144602028942`], 
           Hue[0.6499986750923046, 1, 0.10000183448757825`], 
           Hue[0.6499986615165546, 1, 0.10000185328477061`], 
           Hue[0.6361358775823458, 1, 0.11919647719367511`], 
           Hue[0.6305689978315345, 1, 0.12690446454095228`], 
           Hue[0.6499986615165546, 1, 0.10000185328477061`], 
           Hue[0.6499988738287195, 1, 0.10000155931408075`], 
           Hue[0.6499998405135435, 1, 0.10000022082740136`], 
           Hue[0.6499995620862684, 1, 0.10000060634208989`], 
           Hue[0.6499996292674944, 1, 0.10000051332193075`], 
           Hue[0.6499163609929386, 1, 0.10011580785593122`], 
           Hue[0.649953508291059, 1, 0.10006437313545684`], 
           Hue[0.6499778401621346, 1, 0.10003068285242904`], 
           Hue[0.6499484012887502, 1, 0.10007144436942277`], 
           Hue[0.6496729232052973, 1, 0.10045287556189605`], 
           Hue[0.6497922176029923, 1, 0.10028769870354916`], 
           Hue[0.6498869780840074, 1, 0.10015649188368214`], 
           Hue[0.6497661825364089, 1, 0.10032374725728002`], 
           Hue[0.6142939372009442, 1, 0.1494391638756158], 
           Hue[0.5985789422584301, 1, 0.1711983876421737], 
           Hue[0.6125143440885943, 1, 0.151903215877331], 
           Hue[0.6361358775824969, 1, 0.11919647719346589`], 
           Hue[0.6305688882453164, 1, 0.1269046162757158], 
           Hue[0.6465876268599808, 1, 0.10472482434771889`], 
           Hue[0.6451366804176951, 1, 0.10673382711396066`], 
           Hue[0.6499995573613431, 1, 0.10000061288429428`], 
           Hue[0.6499959668971751, 1, 0.10000558429621911`], 
           Hue[0.6499991796688471, 1, 0.10000113584313482`], 
           Hue[0.6499986163812986, 1, 0.10000191577974038`], 
           Hue[0.6499984458205482, 1, 0.1000021519407794], 
           Hue[0.649665854084627, 1, 0.10046266357513191`], 
           Hue[0.6497616318703321, 1, 0.10033004817954015`], 
           Hue[0.6035542763094158, 1, 0.16430946357157808`], 
           Hue[0.598578942259135, 1, 0.1711983876411977], 
           Hue[0.6125143304747075, 1, 0.15190323472732808`], 
           Hue[0.6361358775824881, 1, 0.11919647719347794`], 
           Hue[0.6402282639250334, 1, 0.11353009610379994`], 
           Hue[0.6496729232052978, 1, 0.10045287556189539`], 
           Hue[0.6497922176029911, 1, 0.10028769870355077`], 
           Hue[0.6497661825364055, 1, 0.10032374725728466`], 
           Hue[0.6498869780840066, 1, 0.10015649188368317`], 
           Hue[0.6499163609929388, 1, 0.10011580785593091`], 
           Hue[0.649953508291059, 1, 0.10006437313545678`], 
           Hue[0.6499484012887502, 1, 0.1000714443694229], 
           Hue[0.6499778401621347, 1, 0.10003068285242903`], 
           Hue[0.6499989556520133, 1, 0.10000144602028942`], 
           Hue[0.6499977899595798, 1, 0.10000306005596647`], 
           Hue[0.6499982819147156, 1, 0.10000237888731685`], 
           Hue[0.6499998400120321, 1, 0.10000022152180169`], 
           Hue[0.6499984384726788, 1, 0.10000216211475245`], 
           Hue[0.6499996979082646, 1, 0.10000041828086434`], 
           Hue[0.6474507800970327, 1, 0.10352968909641623`], 
           Hue[0.6449606118130902, 1, 0.10697761441264439`], 
           Hue[0.6474507800970283, 1, 0.10352968909642238`], 
           Hue[0.6404078578025713, 1, 0.11328142765797827`], 
           Hue[0.6464577349439569, 1, 0.10490467469298291`], 
           Hue[0.6486829768945996, 1, 0.10182357045363134`], 
           Hue[0.6446153322487039, 1, 0.10745569380948687`], 
           Hue[0.6447410918958292, 1, 0.10728156506731354`], 
           Hue[0.647503644126962, 1, 0.10345649274728333`], 
           Hue[0.6499893047672064, 1, 0.10001480878386815`], 
           Hue[0.6499911083843236, 1, 0.10001231146785962`], 
           Hue[0.6499896198214707, 1, 0.10001437255488663`], 
           Hue[0.6499914684832315, 1, 0.10001181286937179`], 
           Hue[0.6499999487815362, 1, 0.10000007091787295`], 
           Hue[0.6499999721042841, 1, 0.10000003862483756`], 
           Hue[0.6499895638291427, 1, 0.10001445008272541`], 
           Hue[0.6499914149327589, 1, 0.10001188701617994`], 
           Hue[0.6142939372009378, 1, 0.14943916387562456`], 
           Hue[0.6499998853986138, 1, 0.1000001586788426], 
           Hue[0.6499999311814529, 1, 0.10000009528721902`], 
           Hue[0.6499892543051299, 1, 0.10001487865443559`], 
           Hue[0.6499910605536277, 1, 0.10001237769497713`], 
           Hue[0.6326534458675356, 1, 0.12401830572187386`], 
           Hue[0.6407433486684658, 1, 0.11281690184366276`], 
           Hue[0.6499370372257507, 1, 0.10008717922588375`], 
           Hue[0.6499476195382329, 1, 0.100072526793216], 
           Hue[0.6499896198214709, 1, 0.10001437255488661`], 
           Hue[0.6499914684832315, 1, 0.10001181286937177`], 
           Hue[0.6499893047672064, 1, 0.10001480878386813`], 
           Hue[0.6499911083843236, 1, 0.1000123114678596], 
           Hue[0.6499943020069127, 1, 0.10000788952889027`], 
           Hue[0.6499845467767462, 1, 0.10002139677065916`], 
           Hue[0.6499863220642538, 1, 0.10001893868026403`], 
           Hue[0.6499892412346377, 1, 0.10001489675204013`], 
           Hue[0.6499934844894636, 1, 0.10000902147612738`], 
           Hue[0.6499950367916136, 1, 0.10000687213468888`], 
           Hue[0.6499954637608208, 1, 0.10000628094655577`], 
           Hue[0.6499967513886306, 1, 0.10000449807728083`], 
           Hue[0.6499947006281697, 1, 0.1000073375917652], 
           Hue[0.6499859066827985, 1, 0.10001951382381748`], 
           Hue[0.6499873317975113, 1, 0.1000175405880613], 
           Hue[0.6499902463376951, 1, 0.1000135050708837], 
           Hue[0.6499940295942708, 1, 0.10000826671562513`], 
           Hue[0.6499988353026608, 1, 0.10000161265785429`], 
           Hue[0.6499966447492621, 1, 0.10000464573179094`], 
           Hue[0.6499977585830018, 1, 0.10000310350045905`], 
           Hue[0.649994657510819, 1, 0.1000073972927123], 
           Hue[0.6499858086661352, 1, 0.10001964953919741`], 
           Hue[0.6499872454109917, 1, 0.10001766020016539`], 
           Hue[0.6415728722699721, 1, 0.1116683307031157], 
           Hue[0.6206979778759806, 1, 0.14057203063325774`], 
           Hue[0.6499949966845507, 1, 0.10000692766754513`], 
           Hue[0.6498853473010373, 1, 0.10015874989087152`], 
           Hue[0.6499966447492621, 1, 0.10000464573179095`], 
           Hue[0.03503912140502463, 1, 0.9514842934391966], 
           Hue[0.05053038130689036, 1, 0.9300348566519979], 
           Hue[0.6496729232052978, 1, 0.1004528755618954], 
           Hue[0.6497922176029911, 1, 0.10028769870355077`], 
           Hue[0.6498869780840066, 1, 0.10015649188368317`], 
           Hue[0.6499163609929388, 1, 0.10011580785593092`], 
           Hue[0.649953508291059, 1, 0.10006437313545678`], 
           Hue[0.6499778401621347, 1, 0.10003068285242903`], 
           Hue[0.6476910569498755, 1, 0.10319699806940323`], 
           Hue[0.6499942635068771, 1, 0.10000794283663174`], 
           Hue[0.6499844592214795, 1, 0.10002151800102843`], 
           Hue[0.6499862450977085, 1, 0.10001904524932675`], 
           Hue[0.6499966447492621, 1, 0.10000464573179095`], 
           Hue[0.6499977585830018, 1, 0.10000310350045905`], 
           Hue[0.6499959664758339, 1, 0.10000558487961463`], 
           Hue[0.649998606782629, 1, 0.10000192907020604`], 
           Hue[0.6499283483312326, 1, 0.10009921000290879`], 
           Hue[0.6499327220179499, 1, 0.1000931541289924], 
           Hue[0.6499994416116589, 1, 0.10000077315308772`], 
           Hue[0.6499960082225426, 1, 0.10000552707647957`], 
           Hue[0.6499962429355867, 1, 0.10000520208918776`], 
           Hue[0.6499859066827985, 1, 0.10001951382381748`], 
           Hue[0.6499947006281697, 1, 0.10000733759176518`], 
           Hue[0.6499940295942708, 1, 0.10000826671562513`], 
           Hue[0.6499922175652754, 1, 0.1000107756788496], 
           Hue[0.6499873317975113, 1, 0.10001754058806128`], 
           Hue[0.6499988738287195, 1, 0.10000155931408075`], 
           Hue[0.6499989503600303, 1, 0.10000145334765041`], 
           Hue[0.6499950367916136, 1, 0.10000687213468887`], 
           Hue[0.6499954637608208, 1, 0.10000628094655577`], 
           Hue[0.6499845467767462, 1, 0.10002139677065915`], 
           Hue[0.6499943020069127, 1, 0.10000788952889027`], 
           Hue[0.6499934844894636, 1, 0.10000902147612736`], 
           Hue[0.649991672053883, 1, 0.10001153100231586`], 
           Hue[0.6499863220642538, 1, 0.10001893868026401`], 
           Hue[0.6499960082225426, 1, 0.10000552707647957`], 
           Hue[0.6499962429355867, 1, 0.10000520208918777`], 
           Hue[0.6499999167013311, 1, 0.10000011533661854`], 
           Hue[0.649916360992939, 1, 0.10011580785593062`], 
           Hue[0.6499535082910592, 1, 0.10006437313545645`], 
           Hue[0.6499778401621348, 1, 0.10003068285242887`], 
           Hue[0.6499484012887506, 1, 0.10007144436942225`], 
           Hue[0.6496729232053008, 1, 0.10045287556189123`], 
           Hue[0.6497922176029945, 1, 0.10028769870354609`], 
           Hue[0.6498869780840084, 1, 0.1001564918836807], 
           Hue[0.6497661825364115, 1, 0.1003237472572765], 
           Hue[0.03502800528463057, 1, 0.9514996849905115], 
           Hue[0.05053038130973697, 1, 0.9300348566480565], 
           Hue[0.6494393528554369, 1, 0.10077628066170284`], 
           Hue[0.6496696646085355, 1, 0.10045738746510469`], 
           Hue[0.6497649268362281, 1, 0.10032548591906884`], 
           Hue[0.6499947044858404, 1, 0.10000733225037489`], 
           Hue[0.6499953064467493, 1, 0.10000649876603943`], 
           Hue[0.6499990600199379, 1, 0.10000130151085525`], 
           Hue[0.6499993276345999, 1, 0.10000093096747711`], 
           Hue[0.6499940623865799, 1, 0.10000822131088946`], 
           Hue[0.614294199630169, 1, 0.1494388005120738], 
           Hue[0.649998945518936, 1, 0.10000146005070401`], 
           Hue[0.6499988244681159, 1, 0.10000162765953191`], 
           Hue[0.649999241196809, 1, 0.10000105065057222`], 
           Hue[0.649998945518936, 1, 0.10000146005070401`], 
           Hue[0.6499990565619045, 1, 0.10000130629890147`], 
           Hue[0.6491923510353136, 1, 0.10111828318187353`], 
           Hue[0.6488160455145384, 1, 0.10163932159525459`], 
           Hue[0.6431143057311567, 1, 0.10953403821839845`], 
           Hue[0.6450736851083142, 1, 0.10682105138848809`], 
           Hue[0.6499978209312278, 1, 0.10000301717214612`], 
           Hue[0.6465876268599643, 1, 0.10472482434774179`], 
           Hue[0.6475877606688776, 1, 0.1033400236892465], 
           Hue[0.6365954599072247, 1, 0.11856013243615052`], 
           Hue[0.6491923510353136, 1, 0.10111828318187348`], 
           Hue[0.6488157819929059, 1, 0.10163968647136115`], 
           Hue[0.6462858945624259, 1, 0.1051426075289488], 
           Hue[0.6456956484192908, 1, 0.10595987141944353`], 
           Hue[0.6460003620577588, 1, 0.10553796022771858`], 
           Hue[0.6456223614019657, 1, 0.1060613457511244], 
           Hue[0.6471780107787616, 1, 0.10390736969094559`], 
           Hue[0.6465876268599798, 1, 0.1047248243477203], 
           Hue[0.6475874797640361, 1, 0.10334041263441161`], 
           Hue[0.5614912777433805, 1, 0.22255053850916562`], 
           Hue[0.5849385292515442, 1, 0.19008511334401573`], 
           Hue[0.5781206880423904, 1, 0.19952520117207484`], 
           Hue[0.591348319402325, 1, 0.18121001928908845`], 
           Hue[0.643114305731053, 1, 0.10953403821854209`], 
           Hue[0.6404083161808928, 1, 0.11328079298030237`], 
           Hue[0.649991672053883, 1, 0.10001153100231587`], 
           Hue[0.6499922175652753, 1, 0.10001077567884961`], 
           Hue[0.6499947044858404, 1, 0.10000733225037488`], 
           Hue[0.6499879463772358, 1, 0.10001668963151969`], 
           Hue[0.6499683182643626, 1, 0.10004386701857493`], 
           Hue[0.6499713739907875, 1, 0.10003963601275573`], 
           Hue[0.6499921601348203, 1, 0.10001085519794112`], 
           Hue[0.6361405484872709, 1, 0.11919000978685584`], 
           Hue[0.6304056690287502, 1, 0.12713061211403834`], 
           Hue[0.6499033184273612, 1, 0.10013386679288462`], 
           Hue[0.6499485358404218, 1, 0.10007125806710834`], 
           Hue[0.6499967228926259, 1, 0.10000453753328727`], 
           Hue[0.6499255031609498, 1, 0.10010314946945419`], 
           Hue[0.6499934162037112, 1, 0.10000911602563067`], 
           Hue[0.6499927108076778, 1, 0.10001009272783067`], 
           Hue[0.5848475422716374, 1, 0.19021109531619446`], 
           Hue[0.606443611541854, 1, 0.16030884555743297`], 
           Hue[0.6499916208740619, 1, 0.10001160186668359`], 
           Hue[0.6361405484872588, 1, 0.11919000978687258`], 
           Hue[0.6395664466518229, 1, 0.11444645848209142`], 
           Hue[0.645345147629168, 1, 0.10644518020576754`], 
           Hue[0.6461546244815918, 1, 0.10532436610241147`], 
           Hue[0.6498853473010362, 1, 0.10015874989087303`], 
           Hue[0.6499848149764142, 1, 0.10002102541727263`], 
           Hue[0.6499931061879602, 1, 0.10000954527820886`], 
           Hue[0.649961586942009, 1, 0.10005318731106444`], 
           Hue[0.6499818402890271, 1, 0.10002514421519335`], 
           Hue[0.6499973860644361, 1, 0.1000036192953962], 
           Hue[0.6499988179951584, 1, 0.1000016366220884], 
           Hue[0.6499742521499005, 1, 0.1000356508693687], 
           Hue[0.6499664920844146, 1, 0.10004639557542605`], 
           Hue[0.6499538534713674, 1, 0.10006389519349133`], 
           Hue[0.6499902463376951, 1, 0.10001350507088369`], 
           Hue[0.6499892412346377, 1, 0.10001489675204013`], 
           Hue[0.6499995967086464, 1, 0.10000055840341276`], 
           Hue[0.6499995967086464, 1, 0.10000055840341276`], 
           Hue[0.6499993652334957, 1, 0.10000087890746762`], 
           Hue[0.6499932958795042, 1, 0.10000928262837881`], 
           Hue[0.6499992914358198, 1, 0.10000098108886499`], 
           Hue[0.6499994978653971, 1, 0.10000069526329639`], 
           Hue[0.6499954119884139, 1, 0.10000635263142685`], 
           Hue[0.6494083156717524, 1, 0.10081925522372753`], 
           Hue[0.6496390806277188, 1, 0.10049973451546627`], 
           Hue[0.6498293943271902, 1, 0.10023622323927514`], 
           Hue[0.6499081642305828, 1, 0.100127157219193], 
           Hue[0.6474018333248249, 1, 0.10359746155024246`], 
           Hue[0.6480158984689418, 1, 0.10274721750454217`], 
           Hue[0.647966455917048, 1, 0.10281567642254884`], 
           Hue[0.6477721012453109, 1, 0.10308478289110791`], 
           Hue[0.6481282101836034, 1, 0.1025917089765491], 
           Hue[0.648038233050599, 1, 0.10271629269917062`], 
           Hue[0.6478300313592262, 1, 0.10300457196414828`], 
           Hue[0.6499987450974997, 1, 0.10000173755730814`], 
           Hue[0.6499968555673088, 1, 0.10000435382988013`], 
           Hue[0.6499969315998197, 1, 0.10000424855409581`], 
           Hue[0.644377884125887, 1, 0.1077844681333873], 
           Hue[0.6437589917918137, 1, 0.10864139598056559`], 
           Hue[0.6428975370312371, 1, 0.10983417949521028`], 
           Hue[0.6498293943271902, 1, 0.10023622323927515`], 
           Hue[0.6498124464093857, 1, 0.1002596895870044], 
           Hue[0.649961586942009, 1, 0.10005318731106445`], 
           Hue[0.6499577843531885, 1, 0.10005845243404672`], 
           Hue[0.648306135542982, 1, 0.10234535078664032`], 
           Hue[0.6475476903013399, 1, 0.10339550573660646`], 
           Hue[0.6472851403989724, 1, 0.10375903637065359`], 
           Hue[0.6498258895552936, 1, 0.10024107600036264`], 
           Hue[0.6499995384858683, 1, 0.10000063901956702`], 
           Hue[0.6499995484386257, 1, 0.10000062523882598`], 
           Hue[0.6499997367362648, 1, 0.10000036451901806`], 
           Hue[0.6499997506890729, 1, 0.10000034519974534`], 
           Hue[0.6494809479153911, 1, 0.10071868750176614`], 
           Hue[0.6495779574981979, 1, 0.10058436654095675`], 
           Hue[0.6499879463772358, 1, 0.1000166896315197], 
           Hue[0.6499924023154049, 1, 0.10001051987097787`], 
           Hue[0.6499987539211727, 1, 0.10000172533991486`], 
           Hue[0.6438294336870249, 1, 0.10854386104873467`], 
           Hue[0.6478386059597472, 1, 0.10299269944035015`], 
           Hue[0.6479232892384299, 1, 0.10287544566986638`], 
           Hue[0.6449089059890544, 1, 0.10704920709207866`], 
           Hue[0.6443963651954955, 1, 0.10775887896008324`], 
           Hue[0.6486592591767456, 1, 0.10185641037066004`], 
           Hue[0.6481400490447606, 1, 0.1025753167072545], 
           Hue[0.6499998406376782, 1, 0.10000022065552244`], 
           Hue[0.6499997285869414, 1, 0.10000037580269656`], 
           Hue[0.6499991149582264, 1, 0.10000122544245589`], 
           Hue[0.649990745780477, 1, 0.10001281353472413`], 
           Hue[0.6499872851621001, 1, 0.10001760516016904`], 
           Hue[0.6499928687028823, 1, 0.10000987410370149`], 
           Hue[0.6499902459174384, 1, 0.10001350565277763`], 
           Hue[0.6499993476936773, 1, 0.1000009031933699], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499987762295317, 1, 0.10000169445141764`], 
           Hue[0.649950538320686, 1, 0.10006848540212707`], 
           Hue[0.6499169012778275, 1, 0.10011505976916187`], 
           Hue[0.6499384202733739, 1, 0.10008526423686702`], 
           Hue[0.6499979396020884, 1, 0.10000285285864687`], 
           Hue[0.6499998944694872, 1, 0.10000014611917156`], 
           Hue[0.6499943973499914, 1, 0.10000775751539649`], 
           Hue[0.6496669893384682, 1, 0.1004610916851979], 
           Hue[0.649946398470897, 1, 0.10007421750183501`], 
           Hue[0.649993719165779, 1, 0.10000869653969072`], 
           Hue[0.6497827013349247, 1, 0.10030087507471978`], 
           Hue[0.6496669043016358, 1, 0.10046120942850442`], 
           Hue[0.6497492556366449, 1, 0.10034718450310716`], 
           Hue[0.6499936916833658, 1, 0.10000873459226267`], 
           Hue[0.6499735114284139, 1, 0.10003667648373474`], 
           Hue[0.6497686522347684, 1, 0.10032032767493607`], 
           Hue[0.6493221359730589, 1, 0.10093858096038005`], 
           Hue[0.6491243836319389, 1, 0.10121239189423846`], 
           Hue[0.6493577841898454, 1, 0.10088922189098344`], 
           Hue[0.6497848661512468, 1, 0.10029787763673528`], 
           Hue[0.6499645347886049, 1, 0.10004910567731624`], 
           Hue[0.6493571286681645, 1, 0.10089012953638754`], 
           Hue[0.6491243444061469, 1, 0.10121244620687354`], 
           Hue[0.6493225788760635, 1, 0.10093796771006598`], 
           Hue[0.64975855562808, 1, 0.10033430759188927`], 
           Hue[0.6499720083241632, 1, 0.10003875770500482`], 
           Hue[0.6499179695206531, 1, 0.1001135806637112], 
           Hue[0.6494608701931665, 1, 0.10074648742484656`], 
           Hue[0.6487286338295368, 1, 0.10176035315910295`], 
           Hue[0.648388110556423, 1, 0.10223184692187594`], 
           Hue[0.6486206497020784, 1, 0.10190986964327597`], 
           Hue[0.6493623255583338, 1, 0.10088293384230708`], 
           Hue[0.6498452129760722, 1, 0.10021432049466919`], 
           Hue[0.6486204310728421, 1, 0.10191017236068024`], 
           Hue[0.6483883164107923, 1, 0.10223156189274911`], 
           Hue[0.6487288669092452, 1, 0.10176003043335274`], 
           Hue[0.6494481187205927, 1, 0.10076414330994857`], 
           Hue[0.6498285638060287, 1, 0.1002373731916526], 
           Hue[0.6490732055840215, 1, 0.10128325380673955`], 
           Hue[0.6481845887416958, 1, 0.10251364635765203`], 
           Hue[0.6476640151146047, 1, 0.10323444061054733`], 
           Hue[0.6485080528944321, 1, 0.10206577291540167`], 
           Hue[0.6494626278600282, 1, 0.10074405373226872`], 
           Hue[0.6485074236435951, 1, 0.10206664418579137`], 
           Hue[0.6476644005941146, 1, 0.10323390686968757`], 
           Hue[0.6476782205548369, 1, 0.10321477153945656`], 
           Hue[0.6481847142239625, 1, 0.102513472612975], 
           Hue[0.6497498661728607, 1, 0.10034633914526986`], 
           Hue[0.6487943291253612, 1, 0.10166939044180758`], 
           Hue[0.6477867920179302, 1, 0.1030644418213274], 
           Hue[0.6470649192956859, 1, 0.10406395789828114`], 
           Hue[0.6466285838488329, 1, 0.10466811467084673`], 
           Hue[0.6471334129224622, 1, 0.1039691205688986], 
           Hue[0.6484656021365416, 1, 0.1021245508878656], 
           Hue[0.6471333502188961, 1, 0.10396920738922091`], 
           Hue[0.6466294094583314, 1, 0.10466697151923357`], 
           Hue[0.6470654457983444, 1, 0.10406322889460015`], 
           Hue[0.647787115327827, 1, 0.10306399416147034`], 
           Hue[0.6497201483868429, 1, 0.10038748684898678`], 
           Hue[0.6486615686527496, 1, 0.1018532126346544], 
           Hue[0.6464928403325366, 1, 0.10485606723187232`], 
           Hue[0.6452016973298763, 1, 0.10664380369709445`], 
           Hue[0.6459425149455625, 1, 0.10561805622922109`], 
           Hue[0.6465290067252066, 1, 0.10480599068817552`], 
           Hue[0.6455644065284432, 1, 0.10614159096061725`], 
           Hue[0.6464934559422196, 1, 0.10485521484923437`], 
           Hue[0.6474600972735771, 1, 0.1035167883904317], 
           Hue[0.6497444578897738, 1, 0.10035382753723636`], 
           Hue[0.6486721458807168, 1, 0.10183856724208448`], 
           Hue[0.6472340635887618, 1, 0.10382975810786839`], 
           Hue[0.6459052314226392, 1, 0.10566967956865347`], 
           Hue[0.6421307435745531, 1, 0.11089589351215723`], 
           Hue[0.6384784081121809, 1, 0.1159529733831342], 
           Hue[0.644391249173835, 1, 0.10776596268238246`], 
           Hue[0.6459060748044504, 1, 0.10566851180922257`], 
           Hue[0.6472266389834003, 1, 0.10384003833067652`], 
           Hue[0.6486721421475293, 1, 0.10183857241111328`], 
           Hue[0.6498178986902056, 1, 0.10025214027509997`], 
           Hue[0.6488754715936943, 1, 0.10155703933180799`], 
           Hue[0.6471954778691618, 1, 0.1038831844888529], 
           Hue[0.6343038838830037, 1, 0.12173308385430251`], 
           Hue[0.6131150084106854, 1, 0.151071526815974], 
           Hue[0.599873725624631, 1, 0.16940561067358784`], 
           Hue[0.6427107986431025, 1, 0.11009274034031961`], 
           Hue[0.6453186380741933, 1, 0.10648188574342467`], 
           Hue[0.6471976417124086, 1, 0.10388018839820357`], 
           Hue[0.6488751499378577, 1, 0.10155748470142792`], 
           Hue[0.649904864696231, 1, 0.10013172580521869`], 
           Hue[0.6492211282544359, 1, 0.10107843780155036`], 
           Hue[0.6474440549356896, 1, 0.103539000858276], 
           Hue[0.611318404019485, 1, 0.15355913289609768`], 
           Hue[0.5438542150943828, 1, 0.2469710867923931], 
           Hue[0.5054107485801693, 1, 0.3002005019659194], 
           Hue[0.5442403811389213, 1, 0.2464363953461091], 
           Hue[0.6391838480536877, 1, 0.11497621038720175`], 
           Hue[0.6448183521044771, 1, 0.10717458939380087`], 
           Hue[0.6474700106798146, 1, 0.10350306213564132`], 
           Hue[0.6492205124027042, 1, 0.10107929051933276`], 
           Hue[0.6499637194211009, 1, 0.10005023464770656`], 
           Hue[0.6495635854272803, 1, 0.10060426633145804`], 
           Hue[0.6479727326168065, 1, 0.10280698560749861`], 
           Hue[0.5613439013165955, 1, 0.2227545981770216], 
           Hue[0.420727802056995, 1, 0.4174538125364685], 
           Hue[0.35056984491384907`, 1, 0.5145955993500552], 
           Hue[0.42074601092973296`, 1, 0.41742860025113904`], 
           Hue[0.5603644258502979, 1, 0.2241107949765106], 
           Hue[0.632088131456607, 1, 0.12480104875239027`], 
           Hue[0.644535609635832, 1, 0.10756607896577114`], 
           Hue[0.6479722666001164, 1, 0.10280763086137731`], 
           Hue[0.6499896086305067, 1, 0.10001438805006765`], 
           Hue[0.64980367395518, 1, 0.10027183606205853`], 
           Hue[0.6486308130733798, 1, 0.1018957972830126], 
           Hue[0.4875629896788311, 1, 0.3249127835216185], 
           Hue[0.2794714163728054, 1, 0.6130395773299617], 
           Hue[0.19202572741733248`, 1, 0.7341182235760012], 
           Hue[0.2795012782577532, 1, 0.6129982301046494], 
           Hue[0.6197571630581281, 1, 0.1418746973041303], 
           Hue[0.6445188584206577, 1, 0.10758927295601249`], 
           Hue[0.6486298611368392, 1, 0.10189711534899197`], 
           Hue[0.6499974802341777, 1, 0.10000348890652329`], 
           Hue[0.649939804960482, 1, 0.10008334697779414`], 
           Hue[0.4134396293930329, 1, 0.42754512853272375`], 
           Hue[0.16660070648985764`, 1, 0.7693220987063509], 
           Hue[0.6051860768209053, 1, 0.16205004747874657`], 
           Hue[0.6446747005059876, 1, 0.10737349160709404`], 
           Hue[0.6492984661033738, 1, 0.10097135462609774`], 
           Hue[0.6499996082984593, 1, 0.1000005423559795], 
           Hue[0.6439828956081195, 1, 0.10833137531183465`], 
           Hue[0.5939696963120576, 1, 0.17758042049099715`], 
           Hue[0.3699235753786966, 1, 0.48779812639872777`], 
           Hue[0.10993697241782385`, 1, 0.8477795766522439], 
           Hue[0.5950760330690096, 1, 0.17604856959675602`], 
           Hue[0.6448213068074831, 1, 0.10717049826656197`], 
           Hue[0.37117736989663025`, 1, 0.4860621032200505], 
           Hue[0.10995731693026656`, 1, 0.8477514073273232], 
           Hue[0.36992357538044274`, 1, 0.48779812639631004`], 
           Hue[0.5939696963127171, 1, 0.17758042049008405`], 
           Hue[0.64482178764344, 1, 0.10716983249369852`], 
           Hue[0.6499978738704448, 1, 0.10000294387169176`], 
           Hue[0.6499395617051158, 1, 0.1000836837929167], 
           Hue[0.41486309731247367`, 1, 0.42557417295195954`], 
           Hue[0.16664015272547333`, 1, 0.7692674808416523], 
           Hue[0.41343962939487927`, 1, 0.42754512853016724`], 
           Hue[0.6042150040106968, 1, 0.16339460983134285`], 
           Hue[0.644675413069162, 1, 0.10737250498116035`], 
           Hue[0.6492993957289521, 1, 0.10097006745222023`], 
           Hue[0.6499974802341777, 1, 0.10000348890652329`], 
           Hue[0.6499895375823748, 1, 0.10001448642440418`], 
           Hue[0.6498247725796032, 1, 0.10024262258208785`], 
           Hue[0.6486298611368391, 1, 0.10189711534899205`], 
           Hue[0.48758898573002984`, 1, 0.3248767889891895], 
           Hue[0.2795012782574238, 1, 0.6129982301051055], 
           Hue[0.19202572741537732`, 1, 0.7341182235787083], 
           Hue[0.27947141637247735`, 1, 0.613039577330416], 
           Hue[0.6197500814767575, 1, 0.14188450257064347`], 
           Hue[0.6445187656803512, 1, 0.10758940136566773`], 
           Hue[0.648722707184793, 1, 0.10176855928259446`], 
           Hue[0.6498036739551807, 1, 0.1002718360620575], 
           Hue[0.6499887115763905, 1, 0.10001563012499778`], 
           Hue[0.6499635376940699, 1, 0.10005048626974944`], 
           Hue[0.6495955370911406, 1, 0.10056002556611313`], 
           Hue[0.6479722666001381, 1, 0.10280763086134731`], 
           Hue[0.5613710441027732, 1, 0.22271701585769876`], 
           Hue[0.42074601093061925`, 1, 0.4174286002499118], 
           Hue[0.3505698449147388, 1, 0.5145955993488232], 
           Hue[0.4207278020584655, 1, 0.4174538125344325], 
           Hue[0.6320807432699589, 1, 0.1248112785492878], 
           Hue[0.6445346715615178, 1, 0.10756737783789842`], 
           Hue[0.6479727326168283, 1, 0.1028069856074685], 
           Hue[0.6495635854272815, 1, 0.10060426633145629`], 
           Hue[0.6499045423782823, 1, 0.1001321720916092], 
           Hue[0.6492205124027052, 1, 0.10107929051933137`], 
           Hue[0.6113350077371776, 1, 0.1535361431331387], 
           Hue[0.5442403811399456, 1, 0.24643639534469083`], 
           Hue[0.5054107485816477, 1, 0.3002005019638725], 
           Hue[0.6393231015822665, 1, 0.11478339780916952`], 
           Hue[0.6448171573226971, 1, 0.10717624370703491`], 
           Hue[0.6474440549357099, 1, 0.10353900085824791`], 
           Hue[0.6492211282544369, 1, 0.10107843780154897`], 
           Hue[0.6498175387315117, 1, 0.10025263867944542`], 
           Hue[0.6488751499378581, 1, 0.1015574847014272], 
           Hue[0.6342357357138431, 1, 0.12182744285775579`], 
           Hue[0.6131190636402776, 1, 0.15106591188269267`], 
           Hue[0.6427084326690243, 1, 0.11009601630442792`], 
           Hue[0.6453175862657006, 1, 0.10648334209364542`], 
           Hue[0.6471954778691709, 1, 0.10388318448884043`], 
           Hue[0.6488754715936947, 1, 0.10155703933180728`], 
           Hue[0.6497442349944516, 1, 0.1003541361615287], 
           Hue[0.6486721421475296, 1, 0.1018385724111129], 
           Hue[0.6459060748044588, 1, 0.1056685118092109], 
           Hue[0.6421328552373109, 1, 0.11089296967141571`], 
           Hue[0.6384789975537066, 1, 0.11595215723332938`], 
           Hue[0.64438993383294, 1, 0.1077677839236217], 
           Hue[0.6459052314226476, 1, 0.10566967956864194`], 
           Hue[0.6472260492528706, 1, 0.10384085488064075`], 
           Hue[0.6486721458807171, 1, 0.10183856724208414`], 
           Hue[0.6497201201157684, 1, 0.10038752599355154`], 
           Hue[0.648666544096528, 1, 0.10184632355865361`], 
           Hue[0.6464934559422207, 1, 0.1048552148492328], 
           Hue[0.6452024257205371, 1, 0.10664279515617942`], 
           Hue[0.6459417553417114, 1, 0.10561910798839959`], 
           Hue[0.6455633919912057, 1, 0.10614299570448435`], 
           Hue[0.6464928403325377, 1, 0.10485606723187087`], 
           Hue[0.647459617606195, 1, 0.10351745254526855`], 
           Hue[0.6486615686527497, 1, 0.10185321263465423`], 
           Hue[0.6497500661969323, 1, 0.10034606218886297`], 
           Hue[0.6487973060787215, 1, 0.1016652685063855], 
           Hue[0.6477871153278271, 1, 0.10306399416147022`], 
           Hue[0.6470654457983444, 1, 0.10406322889460012`], 
           Hue[0.6466294094583315, 1, 0.10466697151923335`], 
           Hue[0.6471333502189089, 1, 0.10396920738920298`], 
           Hue[0.6484645052704798, 1, 0.1021260696254895], 
           Hue[0.6491328333766917, 1, 0.10120069224765768`], 
           Hue[0.6471334129224494, 1, 0.10396912056891619`], 
           Hue[0.6466285838488329, 1, 0.10466811467084676`], 
           Hue[0.6470649192956859, 1, 0.10406395789828118`], 
           Hue[0.64778679201793, 1, 0.1030644418213277], 
           Hue[0.6487943291253612, 1, 0.1016693904418076], 
           Hue[0.6498289592233316, 1, 0.10023682569077168`], 
           Hue[0.6490820712669709, 1, 0.10127097824573265`], 
           Hue[0.6481847142239626, 1, 0.1025134726129749], 
           Hue[0.6476782205548369, 1, 0.10321477153945664`], 
           Hue[0.6476644005941143, 1, 0.10323390686968784`], 
           Hue[0.6485074236435971, 1, 0.10206664418578854`], 
           Hue[0.6494782446417824, 1, 0.10072243049599366`], 
           Hue[0.6485080528944301, 1, 0.10206577291540447`], 
           Hue[0.6476640151146049, 1, 0.10323444061054705`], 
           Hue[0.6476673319658688, 1, 0.10322984804725867`], 
           Hue[0.6481845887416956, 1, 0.1025136463576523], 
           Hue[0.6490732055840214, 1, 0.10128325380673972`], 
           Hue[0.6499183291303126, 1, 0.10011308274264412`], 
           Hue[0.6494481187205927, 1, 0.10076414330994854`], 
           Hue[0.6487288669092454, 1, 0.10176003043335265`], 
           Hue[0.6483883164107922, 1, 0.10223156189274928`], 
           Hue[0.6486204310728418, 1, 0.10191017236068052`], 
           Hue[0.6493634059128112, 1, 0.10088143796687682`], 
           Hue[0.649854937980913, 1, 0.1002008551033513], 
           Hue[0.6493623255583336, 1, 0.10088293384230729`], 
           Hue[0.6486206497020787, 1, 0.1019098696432757], 
           Hue[0.6483881105564231, 1, 0.1022318469218758], 
           Hue[0.6487286338295367, 1, 0.10176035315910312`], 
           Hue[0.6499736942470771, 1, 0.10003642335020098`], 
           Hue[0.64975855562808, 1, 0.10033430759188922`], 
           Hue[0.6493225788760636, 1, 0.1009379677100659], 
           Hue[0.6491243444061467, 1, 0.10121244620687374`], 
           Hue[0.6497870627427598, 1, 0.10029483620233268`], 
           Hue[0.6497848661512468, 1, 0.10029787763673526`], 
           Hue[0.6493577841898455, 1, 0.10088922189098319`], 
           Hue[0.649124383631939, 1, 0.10121239189423825`], 
           Hue[0.6493221359730588, 1, 0.10093858096038015`], 
           Hue[0.6499936916833658, 1, 0.10000873459226267`], 
           Hue[0.6499293875019, 1, 0.10009777115121549`], 
           Hue[0.6497492556366449, 1, 0.1003471845031071], 
           Hue[0.6496669043016357, 1, 0.10046120942850455`], 
           Hue[0.6499461593618887, 1, 0.10007454857584651`], 
           Hue[0.649993719165779, 1, 0.10000869653969072`], 
           Hue[0.6497831131736973, 1, 0.10030030483641916`], 
           Hue[0.6496669893384683, 1, 0.10046109168519776`], 
           Hue[0.6497438699910105, 1, 0.10035464155090854`], 
           Hue[0.6499989806170189, 1, 0.10000141145335847`], 
           Hue[0.649985101517905, 1, 0.10002062866751625`], 
           Hue[0.6499903637000147, 1, 0.10001334256921046`], 
           Hue[0.649950695639109, 1, 0.1000682675766184], 
           Hue[0.6499169408087976, 1, 0.10011500503397268`], 
           Hue[0.6499382721143278, 1, 0.1000854693801616], 
           Hue[0.6499998944694872, 1, 0.10000014611917156`], 
           Hue[0.6499979396020884, 1, 0.10000285285864687`], 
           Hue[0.6499988051348664, 1, 0.10000165442864654`], 
           Hue[0.6499928687028823, 1, 0.10000987410370148`], 
           Hue[0.649990745780477, 1, 0.10001281353472413`], 
           Hue[0.6499993476880973, 1, 0.10000090320109607`], 
           Hue[0.6499925368181951, 1, 0.1000103336363452], 
           Hue[0.6499544789815872, 1, 0.10006302910241772`], 
           Hue[0.6499710158419191, 1, 0.10004013191118909`], 
           Hue[0.6499957079341608, 1, 0.10000594286039266`], 
           Hue[0.649956754063224, 1, 0.10005987898938218`], 
           Hue[0.6499973394962008, 1, 0.10000368377449126`], 
           Hue[0.6497967031430824, 1, 0.10028148795573211`], 
           Hue[0.6497422006045632, 1, 0.10035695300906637`], 
           Hue[0.6498543989283845, 1, 0.10020160148377542`], 
           Hue[0.6499796318088381, 1, 0.10002820211083958`], 
           Hue[0.6498201909540229, 1, 0.10024896637135303`], 
           Hue[0.6499821959348161, 1, 0.1000246517825623], 
           Hue[0.6493843083159343, 1, 0.10085249617793718`], 
           Hue[0.6492714389145247, 1, 0.10100877688758132`], 
           Hue[0.6495311358384765, 1, 0.10064919653134018`], 
           Hue[0.6499326287044422, 1, 0.10009328333231075`], 
           Hue[0.6490374185577825, 1, 0.10133280507383961`], 
           Hue[0.6489306887868327, 1, 0.10148058475669318`], 
           Hue[0.6493199214653447, 1, 0.10094164720183046`], 
           Hue[0.6494380510073351, 1, 0.10077808322061302`], 
           Hue[0.6499097362338689, 1, 0.10012498059925846`], 
           Hue[0.6486670765987008, 1, 0.10184558624795277`], 
           Hue[0.6485711159572851, 1, 0.10197845482837456`], 
           Hue[0.6489814055841803, 1, 0.1014103614988274], 
           Hue[0.6496859288220751, 1, 0.10043486778481915`], 
           Hue[0.6498492997424695, 1, 0.10020866189504221`], 
           Hue[0.6492162512642067, 1, 0.10108519055725237`], 
           Hue[0.6484785424654154, 1, 0.10210663350942495`], 
           Hue[0.6485590288669336, 1, 0.10199519079963036`], 
           Hue[0.6486312945647218, 1, 0.10189513060269287`], 
           Hue[0.64964448028359, 1, 0.10049225806887534`], 
           Hue[0.6477258602117325, 1, 0.10314880893760124`], 
           Hue[0.6478481526586202, 1, 0.10297948093421826`], 
           Hue[0.6483894496489135, 1, 0.10222999279381205`], 
           Hue[0.6497669433721043, 1, 0.1003226937924711], 
           Hue[0.6488750409140394, 1, 0.10155763565748402`], 
           Hue[0.6479927325367794, 1, 0.1027792934106133], 
           Hue[0.6475834488846898, 1, 0.103345993851968], 
           Hue[0.647294545382292, 1, 0.10374601408605726`], 
           Hue[0.6488721916036159, 1, 0.10156158085653198`], 
           Hue[0.6466982385822284, 1, 0.10457166965537615`], 
           Hue[0.6472169204860098, 1, 0.10385349471167879`], 
           Hue[0.6479788895815403, 1, 0.10279846057940577`], 
           Hue[0.6497220759135403, 1, 0.1003848179658674], 
           Hue[0.6486943253197311, 1, 0.10180785724960312`], 
           Hue[0.6454301116848207, 1, 0.10632753766717139`], 
           Hue[0.6468897902012749, 1, 0.1043064443366963], 
           Hue[0.6456433109470756, 1, 0.10603233868866456`], 
           Hue[0.6466457526689814, 1, 0.10464434245833346`], 
           Hue[0.6475978994814843, 1, 0.10332598533332953`], 
           Hue[0.6497395116100092, 1, 0.10036067623229504`], 
           Hue[0.648656146199945, 1, 0.10186072064622992`], 
           Hue[0.6425869541067043, 1, 0.11026421739071718`], 
           Hue[0.6412672325871597, 1, 0.1120915241100867], 
           Hue[0.6444863018191666, 1, 0.10763435132730781`], 
           Hue[0.6460978666860328, 1, 0.10540295381933926`], 
           Hue[0.6473189778091596, 1, 0.10371218457193296`], 
           Hue[0.649807523533853, 1, 0.10026650587620367`], 
           Hue[0.6488059954277982, 1, 0.10165323709997189`], 
           Hue[0.6355677813921233, 1, 0.11998307191859846`], 
           Hue[0.6225136803974088, 1, 0.1380579809882031], 
           Hue[0.6428745456415313, 1, 0.10986601372711048`], 
           Hue[0.6454891179706859, 1, 0.10624583665597352`], 
           Hue[0.6471883956275378, 1, 0.1038929906695631], 
           Hue[0.6487415025304522, 1, 0.10174253495783556`], 
           Hue[0.6498948423987034, 1, 0.10014560283256452`], 
           Hue[0.6491243397305968, 1, 0.10121245268071222`], 
           Hue[0.6472376528773863, 1, 0.10382478832361895`], 
           Hue[0.6150728538407592, 1, 0.14836066391279507`], 
           Hue[0.5682104334557555, 1, 0.21324709213818469`], 
           Hue[0.6397468996933341, 1, 0.11419660042461435`], 
           Hue[0.6449758474343685, 1, 0.10695651893702825`], 
           Hue[0.6473203313841579, 1, 0.10371031039116604`], 
           Hue[0.649958109515708, 1, 0.10005800220901968`], 
           Hue[0.6494842522907931, 1, 0.10071411221274804`], 
           Hue[0.6476512819636768, 1, 0.1032520711272168], 
           Hue[0.5687382725777202, 1, 0.2125162379693105], 
           Hue[0.4598365727270398, 1, 0.3633032069933295], 
           Hue[0.6330024607855063, 1, 0.12353505429699133`], 
           Hue[0.6446614119196817, 1, 0.10739189118813307`], 
           Hue[0.6477602551397409, 1, 0.10310118519112803`], 
           Hue[0.6499875975622534, 1, 0.10001717260611061`], 
           Hue[0.6497589618188877, 1, 0.1003337451738478], 
           Hue[0.6483004248350014, 1, 0.10235325792076734`], 
           Hue[0.49721716070323696`, 1, 0.3115454697955181], 
           Hue[0.31803818591272426`, 1, 0.5596394348900742], 
           Hue[0.621196668559564, 1, 0.13988153584060375`], 
           Hue[0.6446057461858452, 1, 0.10746896681959894`], 
           Hue[0.6484128933058226, 1, 0.10219753234578413`], 
           Hue[0.6499971946455725, 1, 0.10000388433689966`], 
           Hue[0.6499119444868917, 1, 0.10012192301814993`], 
           Hue[0.42186155100194733`, 1, 0.4158840063049961], 
           Hue[0.19690139772980203`, 1, 0.7273672954510433], 
           Hue[0.6066857938393704, 1, 0.15997351622241032`], 
           Hue[0.6447269791201125, 1, 0.10730110583369051`], 
           Hue[0.6490601902829536, 1, 0.10130127499283355`], 
           Hue[0.373210137296724, 1, 0.48324750220453605`], 
           Hue[0.12317793669624733`, 1, 0.829445933805196], 
           Hue[0.5959049495707656, 1, 0.1749008390558631], 
           Hue[0.36993896493495954`, 1, 0.4877768177823637], 
           Hue[0.10551553714933015`, 1, 0.8539015639470814], 
           Hue[0.5947857583630186, 1, 0.17645048842043587`], 
           Hue[0.6448143518714223, 1, 0.10718012817803063`], 
           Hue[0.6499983476490149, 1, 0.10000228787059483`], 
           Hue[0.4092648191983703, 1, 0.43332563495610266`], 
           Hue[0.1447215641957238, 1, 0.7996162957289977], 
           Hue[0.37321013729844094`, 1, 0.48324750220215873`], 
           Hue[0.6039331393082457, 1, 0.16378488403473676`], 
           Hue[0.6446386253954931, 1, 0.1074234417600865], 
           Hue[0.649992139261425, 1, 0.10001088409956545`], 
           Hue[0.47992518690075703`, 1, 0.335488202752798], 
           Hue[0.2386766428431551, 1, 0.669524648371016], 
           Hue[0.6189100178908071, 1, 0.1430476675358055], 
           Hue[0.6444502281867965, 1, 0.1076842994336663], 
           Hue[0.6490074389437255, 1, 0.10137431530868783`], 
           Hue[0.6499711752825617, 1, 0.10003991114722234`], 
           Hue[0.5547703620061074, 1, 0.23185642183769747`], 
           Hue[0.3752505842357152, 1, 0.4804222679813174], 
           Hue[0.31803818591257643`, 1, 0.5596394348902788], 
           Hue[0.6314113814489781, 1, 0.12573808722449184`], 
           Hue[0.6444285208655677, 1, 0.10771435572459868`], 
           Hue[0.6483403043967222, 1, 0.10229804006607698`], 
           Hue[0.6497589618188885, 1, 0.10033374517384673`], 
           Hue[0.6499202363144329, 1, 0.10011044202617], 
           Hue[0.6493814166270158, 1, 0.10085650005490128`], 
           Hue[0.607541900540672, 1, 0.1587881377129157], 
           Hue[0.510533983908946, 1, 0.2931067915106903], 
           Hue[0.6389584142500593, 1, 0.11528834949991792`], 
           Hue[0.6476512819636974, 1, 0.10325207112718823`], 
           Hue[0.6494842522907944, 1, 0.10071411221274629`], 
           Hue[0.6498383027784684, 1, 0.10022388846058228`], 
           Hue[0.6490246129733723, 1, 0.10135053588302294`], 
           Hue[0.6327196532762671, 1, 0.12392663392516859`], 
           Hue[0.5972214239241667, 1, 0.17307802841269226`], 
           Hue[0.6425408848188652, 1, 0.11032800563541752`], 
           Hue[0.6472376528774035, 1, 0.10382478832359508`], 
           Hue[0.6491243397305978, 1, 0.10121245268071082`], 
           Hue[0.6497608890911948, 1, 0.10033107664296116`], 
           Hue[0.6487415025304524, 1, 0.10174253495783517`], 
           Hue[0.6416071963746622, 1, 0.1116208050196985], 
           Hue[0.6333039763671718, 1, 0.12311757118391589`], 
           Hue[0.6442963774518267, 1, 0.10789732352824008`], 
           Hue[0.6457420223619781, 1, 0.10589566134495344`], 
           Hue[0.6471779091179248, 1, 0.10390751045210413`], 
           Hue[0.6488059954277986, 1, 0.10165323709997116`], 
           Hue[0.6497216053983531, 1, 0.1003854694484342], 
           Hue[0.6486614185740522, 1, 0.10185342043592767`], 
           Hue[0.6460978666860392, 1, 0.1054029538193304], 
           Hue[0.6449363081982395, 1, 0.10701126557166839`], 
           Hue[0.6443792387298783, 1, 0.10778259252786082`], 
           Hue[0.6454878932078376, 1, 0.10624753248145567`], 
           Hue[0.6463374972854069, 1, 0.10507115760482126`], 
           Hue[0.6486561461999453, 1, 0.1018607206462296], 
           Hue[0.6497446269774029, 1, 0.10035359341590379`], 
           Hue[0.6487385095926335, 1, 0.10174667902558446`], 
           Hue[0.6469167021582983, 1, 0.10426918162697163`], 
           Hue[0.6465464412567904, 1, 0.1047818505675211], 
           Hue[0.6469074083357891, 1, 0.10428204999659982`], 
           Hue[0.6476302589163752, 1, 0.10328117996194215`], 
           Hue[0.6486943253197311, 1, 0.10180785724960303`], 
           Hue[0.6498180333025885, 1, 0.10025195388872371`], 
           Hue[0.6489651538469169, 1, 0.1014328639042689], 
           Hue[0.6479788895815404, 1, 0.10279846057940568`], 
           Hue[0.6483449140191653, 1, 0.10229165751192505`], 
           Hue[0.6492133707832798, 1, 0.10108917891545874`], 
           Hue[0.6472945453822796, 1, 0.10374601408607449`], 
           Hue[0.6475834488846899, 1, 0.10334599385196792`], 
           Hue[0.647992732536779, 1, 0.10277929341061362`], 
           Hue[0.6488750409140392, 1, 0.1015576356574841], 
           Hue[0.6499074536869546, 1, 0.1001281410488322], 
           Hue[0.6493262593973559, 1, 0.10093287160366118`], 
           Hue[0.649261181264013, 1, 0.10102297978828971`], 
           Hue[0.6486312945647198, 1, 0.10189513060269563`], 
           Hue[0.6485590288669338, 1, 0.10199519079963013`], 
           Hue[0.6481847608283471, 1, 0.1025134080838271], 
           Hue[0.6484785424654151, 1, 0.10210663350942521`], 
           Hue[0.6499685517490378, 1, 0.10004354373210153`], 
           Hue[0.6496859288220751, 1, 0.10043486778481911`], 
           Hue[0.649748705671542, 1, 0.10034794599324967`], 
           Hue[0.6494380510073349, 1, 0.10077808322061324`], 
           Hue[0.6493199214653449, 1, 0.10094164720183023`], 
           Hue[0.6489306887868329, 1, 0.10148058475669298`], 
           Hue[0.6490374185577824, 1, 0.10133280507383975`], 
           Hue[0.6499926102537842, 1, 0.10001023195629886`], 
           Hue[0.6498879983365086, 1, 0.10015507922637275`], 
           Hue[0.6499334733653315, 1, 0.10009211380184874`], 
           Hue[0.6497651749073808, 1, 0.10032514243593432`], 
           Hue[0.6495445652662334, 1, 0.10063060193906152`], 
           Hue[0.649577435244752, 1, 0.10058508966111265`], 
           Hue[0.6499987823857478, 1, 0.1000016859274261], 
           Hue[0.6499871546152928, 1, 0.10001778591728701`], 
           Hue[0.6499450533801044, 1, 0.10007607993524002`], 
           Hue[0.6498702683563081, 1, 0.1001796284297273], 
           Hue[0.6499998525302062, 1, 0.10000020418894534`], 
           Hue[0.6499982837325233, 1, 0.10000237637035238`], 
           Hue[0.6499917724184623, 1, 0.1000113920359754], 
           Hue[0.649995513367399, 1, 0.10000621226052449`], 
           Hue[0.6499768211371815, 1, 0.10003209381005643`], 
           Hue[0.6499709311885555, 1, 0.1000402491235386], 
           Hue[0.6499998652875634, 1, 0.10000018652491231`], 
           Hue[0.6499997033584459, 1, 0.10000041073445946`], 
           Hue[0.6499916431084579, 1, 0.10001157108059679`], 
           Hue[0.6499768885403957, 1, 0.10003200048252905`], 
           Hue[0.6499955545015644, 1, 0.10000615530552621`], 
           Hue[0.6499921940479368, 1, 0.1000108082413183], 
           Hue[0.6499724972674363, 1, 0.10003808070662663`], 
           Hue[0.6498762763822666, 1, 0.10017130962455394`], 
           Hue[0.6498541257365453, 1, 0.1002019797493988], 
           Hue[0.6499986685807253, 1, 0.10000184350361113`], 
           Hue[0.6499973236426885, 1, 0.10000370572550824`], 
           Hue[0.6498868726098938, 1, 0.10015663792476255`], 
           Hue[0.6495774352447521, 1, 0.10058508966111257`], 
           Hue[0.6495306842520321, 1, 0.10064982180487866`], 
           Hue[0.6499903486487819, 1, 0.10001336340937898`], 
           Hue[0.6499821551229769, 1, 0.10002470829126286`], 
           Hue[0.6497647458011402, 1, 0.10032573658303667`], 
           Hue[0.6496752830842288, 1, 0.10044960803722157`], 
           Hue[0.6499471992776279, 1, 0.10007310869251525`], 
           Hue[0.6499098804701536, 1, 0.10012478088747968`], 
           Hue[0.6494383119686717, 1, 0.10077772188953145`], 
           Hue[0.6493256084315968, 1, 0.10093377294086603`], 
           Hue[0.649776996090499, 1, 0.10030877464392456`], 
           Hue[0.6496468100677264, 1, 0.10048903221391733`], 
           Hue[0.6498176582689631, 1, 0.10025247316605115`], 
           Hue[0.6472164168884315, 1, 0.10385419200063341`], 
           Hue[0.6492133707832604, 1, 0.10108917891548565`], 
           Hue[0.6488711177040118, 1, 0.10156306779444524`], 
           Hue[0.6475890729501657, 1, 0.10333820668438606`], 
           Hue[0.6476302589163754, 1, 0.10328117996194189`], 
           Hue[0.6475974574857243, 1, 0.10332659732745868`], 
           Hue[0.646907408335789, 1, 0.10428204999659996`], 
           Hue[0.6466451819682595, 1, 0.10464513265933302`], 
           Hue[0.6465464412567904, 1, 0.10478185056752098`], 
           Hue[0.6456423119377144, 1, 0.10603372193239557`], 
           Hue[0.6469167021582841, 1, 0.10426918162699127`], 
           Hue[0.6454307554303607, 1, 0.10632664632719298`], 
           Hue[0.6465472957244994, 1, 0.10478066745838542`], 
           Hue[0.6473386224356839, 1, 0.10368498431982238`], 
           Hue[0.6473184531260547, 1, 0.10371291105623187`], 
           Hue[0.6463374972854046, 1, 0.10507115760482454`], 
           Hue[0.6460736462773837, 1, 0.10543648976977642`], 
           Hue[0.6444850252643294, 1, 0.10763611886477478`], 
           Hue[0.6449354756217992, 1, 0.10701241836981658`], 
           Hue[0.6444510447211438, 1, 0.10768316884764709`], 
           Hue[0.6443792387296079, 1, 0.1077825925282352], 
           Hue[0.6412672295634202, 1, 0.11209152829680277`], 
           Hue[0.6449363081981927, 1, 0.10701126557173327`], 
           Hue[0.6471779091179208, 1, 0.10390751045210966`], 
           Hue[0.6471877544905376, 1, 0.10389387839771733`], 
           Hue[0.6457420223619642, 1, 0.10589566134497266`], 
           Hue[0.6454881245503387, 1, 0.10624721216106962`], 
           Hue[0.642880143347721, 1, 0.10985826305700162`], 
           Hue[0.6416047567880195, 1, 0.11162418290889603`], 
           Hue[0.6334576495991256, 1, 0.12290479286274922`], 
           Hue[0.6333039763666903, 1, 0.12311757118458268`], 
           Hue[0.6225162151465412, 1, 0.13805447133555832`], 
           Hue[0.6471785610476386, 1, 0.10390660778019273`], 
           Hue[0.6497523354002839, 1, 0.10034292021499154`], 
           Hue[0.6498071763115432, 1, 0.10026698664555568`], 
           Hue[0.6449747057502084, 1, 0.1069580997304807], 
           Hue[0.6397424833007522, 1, 0.11420271542972767`], 
           Hue[0.597215256587844, 1, 0.17308656780144682`], 
           Hue[0.6472745253097338, 1, 0.10377373418652247`], 
           Hue[0.6446604067396445, 1, 0.10739328297587684`], 
           Hue[0.6075239849976855, 1, 0.15881294384935868`], 
           Hue[0.5105208513498842, 1, 0.29312497505400636`], 
           Hue[0.6447422602882784, 1, 0.10727994729315306`], 
           Hue[0.649381416627015, 1, 0.10085650005490243`], 
           Hue[0.649486617144909, 1, 0.10071083779935683`], 
           Hue[0.6444285208655705, 1, 0.10771435572459478`], 
           Hue[0.6446054156460019, 1, 0.10746942449015119`], 
           Hue[0.6211894469842812, 1, 0.13989153494484138`], 
           Hue[0.554742913496705, 1, 0.23189442746610078`], 
           Hue[0.6444293000046293, 1, 0.1077132769166672], 
           Hue[0.6496976408126711, 1, 0.10041865118245545`], 
           Hue[0.6497610653711231, 1, 0.10033083256306041`], 
           Hue[0.6444502281869443, 1, 0.10768429943346178`], 
           Hue[0.6066823642767764, 1, 0.15997826484754044`], 
           Hue[0.47990058829306015`, 1, 0.33552226236345517`], 
           Hue[0.6444500571990789, 1, 0.10768453618589077`], 
           Hue[0.6490063830516137, 1, 0.10137577731315026`], 
           Hue[0.6498799412726698, 1, 0.10016623516091878`], 
           Hue[0.649911933583973, 1, 0.10012193811449889`], 
           Hue[0.6494787147610733, 1, 0.10072177956159074`], 
           Hue[0.6499615936668797, 1, 0.10005317799970509`], 
           Hue[0.6499730201144908, 1, 0.10003735676455126`], 
           Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
           Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
           Hue[0.6499730201144907, 1, 0.10003735676455143`], 
           Hue[0.6495118930856678, 1, 0.10067584034292153`], 
           Hue[0.6494787147610555, 1, 0.1007217795616155], 
           Hue[0.6499119335839733, 1, 0.10012193811449864`], 
           Hue[0.6490601902829449, 1, 0.10130127499284557`], 
           Hue[0.6490063830516063, 1, 0.10137577731316062`], 
           Hue[0.6447269791198692, 1, 0.10730110583402727`], 
           Hue[0.6444500571988938, 1, 0.107684536186147], 
           Hue[0.4218615510037922, 1, 0.4158840063024417], 
           Hue[0.47990058829466353`, 1, 0.33552226236123506`], 
           Hue[0.6066823642771331, 1, 0.15997826484704664`], 
           Hue[0.6448226855248735, 1, 0.10716858927325204`], 
           Hue[0.6497610653711238, 1, 0.10033083256305943`], 
           Hue[0.6446057461857632, 1, 0.1074689668197126], 
           Hue[0.6444293000046112, 1, 0.10771327691669216`], 
           Hue[0.5547429134976742, 1, 0.23189442746475877`], 
           Hue[0.6211894469844135, 1, 0.13989153494465828`], 
           Hue[0.6446054156459394, 1, 0.10746942449023777`], 
           Hue[0.64948661714491, 1, 0.10071083779935554`], 
           Hue[0.6446614119197258, 1, 0.10739189118807202`], 
           Hue[0.45983657272859146`, 1, 0.363303206991181], 
           Hue[0.5105208513514403, 1, 0.2931249750518519], 
           Hue[0.6075239849981006, 1, 0.1588129438487838], 
           Hue[0.6446153322487039, 1, 0.1074556938094869], 
           Hue[0.6473203313841712, 1, 0.10371031039114756`], 
           Hue[0.6472745253097465, 1, 0.10377373418650494`], 
           Hue[0.5682104334567644, 1, 0.21324709213678777`], 
           Hue[0.5972152565884311, 1, 0.17308656780063383`], 
           Hue[0.6397424833007788, 1, 0.11420271542969104`], 
           Hue[0.6449747057502664, 1, 0.10695809973040038`], 
           Hue[0.6498071763115433, 1, 0.10026698664555556`], 
           Hue[0.6471883956275423, 1, 0.10389299066955694`], 
           Hue[0.6471785610476427, 1, 0.1039066077801871], 
           Hue[0.6225162151471285, 1, 0.1380544713347452], 
           Hue[0.6225136803974847, 1, 0.13805798098809824`], 
           Hue[0.63345764959897, 1, 0.12290479286296463`], 
           Hue[0.6416047567879692, 1, 0.11162418290896563`], 
           Hue[0.642880143347735, 1, 0.10985826305698226`], 
           Hue[0.6454881245503643, 1, 0.10624721216103408`], 
           Hue[0.6471877544905419, 1, 0.10389387839771125`], 
           Hue[0.6412672295637786, 1, 0.11209152829630659`], 
           Hue[0.6412672325869215, 1, 0.11209152411041637`], 
           Hue[0.6444510447209121, 1, 0.10768316884796794`], 
           Hue[0.6449354756217571, 1, 0.10701241836987481`], 
           Hue[0.6444850252643324, 1, 0.10763611886477062`], 
           Hue[0.6460736462773896, 1, 0.10543648976976822`], 
           Hue[0.6473131697351501, 1, 0.10372022652056141`], 
           Hue[0.6456433109470772, 1, 0.10603233868866238`], 
           Hue[0.6465472957244996, 1, 0.10478066745838509`], 
           Hue[0.645430755430402, 1, 0.10632664632713582`], 
           Hue[0.6456423119377144, 1, 0.10603372193239552`], 
           Hue[0.6466451819682602, 1, 0.10464513265933213`], 
           Hue[0.6475974574857242, 1, 0.10332659732745889`], 
           Hue[0.6466982385822284, 1, 0.10457166965537615`], 
           Hue[0.6475890729501654, 1, 0.10333820668438629`], 
           Hue[0.6488711177040516, 1, 0.1015630677943901], 
           Hue[0.6472164168884315, 1, 0.10385419200063346`], 
           Hue[0.6497585093987792, 1, 0.1003343716016903], 
           Hue[0.6498176582689631, 1, 0.1002524731660512], 
           Hue[0.6496468100677315, 1, 0.1004890322139102], 
           Hue[0.6492162512642066, 1, 0.10108519055725255`], 
           Hue[0.6493256084315967, 1, 0.1009337729408662], 
           Hue[0.6494383119686719, 1, 0.10077772188953124`], 
           Hue[0.649909880470154, 1, 0.10012478088747913`], 
           Hue[0.649589967952851, 1, 0.10056773668066789`], 
           Hue[0.6496752830842288, 1, 0.1004496080372217], 
           Hue[0.6493843083159341, 1, 0.10085249617793741`], 
           Hue[0.6497647458011401, 1, 0.10032573658303681`], 
           Hue[0.6499821551229769, 1, 0.10002470829126284`], 
           Hue[0.6495306842520321, 1, 0.10064982180487875`], 
           Hue[0.6498432245869254, 1, 0.1002170736488725], 
           Hue[0.6498868726098938, 1, 0.1001566379247626], 
           Hue[0.6499973236426885, 1, 0.10000370572550824`], 
           Hue[0.6498541257365453, 1, 0.10020197974939885`], 
           Hue[0.64995742655059, 1, 0.10005894785302934`], 
           Hue[0.6499724972674363, 1, 0.10003808070662665`], 
           Hue[0.6499921940479368, 1, 0.10001080824131829`], 
           Hue[0.6499710158419191, 1, 0.10004013191118907`], 
           Hue[0.6499768885403957, 1, 0.10003200048252905`], 
           Hue[0.6499916431084579, 1, 0.1000115710805968], 
           Hue[0.6499997033584459, 1, 0.10000041073445946`], 
           Hue[0.6499709311885555, 1, 0.10004024912353861`], 
           Hue[0.6499921293089566, 1, 0.10001089787990629`], 
           Hue[0.649995513367399, 1, 0.10000621226052449`], 
           Hue[0.6499998925666856, 1, 0.1000001487538201], 
           Hue[0.6499996894548788, 1, 0.10000042998555234`], 
           Hue[0.6499745865383855, 1, 0.10003518786992782`], 
           Hue[0.6499382721143278, 1, 0.10008546938016159`], 
           Hue[0.6499800978129978, 1, 0.10002755687431077`], 
           Hue[0.6499964589486245, 1, 0.1000049029942124], 
           Hue[0.64999986712212, 1, 0.10000018398475698`], 
           Hue[0.6499999463041645, 1, 0.10000007434808002`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499993787624871, 1, 0.1000008601750178], 
           Hue[0.6499964290356581, 1, 0.10000494441216566`], 
           Hue[0.6499800210545625, 1, 0.10002766315522107`], 
           Hue[0.6499786432660215, 1, 0.10002957086243185`], 
           Hue[0.6499746602037512, 1, 0.10003508587172913`], 
           Hue[0.6499976810908947, 1, 0.10000321079722264`], 
           Hue[0.6499657096233139, 1, 0.10004747898310386`], 
           Hue[0.6498668777824628, 1, 0.1001843230704362], 
           Hue[0.6497438699910105, 1, 0.10035464155090848`], 
           Hue[0.649870268356308, 1, 0.10017962842972737`], 
           Hue[0.6497422679611429, 1, 0.10035685974610997`], 
           Hue[0.6498908903541091, 1, 0.10015107489431062`], 
           Hue[0.6499949427213864, 1, 0.10000700238577273`], 
           Hue[0.6499763529684163, 1, 0.10003274204373135`], 
           Hue[0.6499461593618887, 1, 0.10007454857584648`], 
           Hue[0.6498906156449327, 1, 0.1001514552608625], 
           Hue[0.6498765165910504, 1, 0.10017097702777646`], 
           Hue[0.6498671323084145, 1, 0.10018397064988767`], 
           Hue[0.6499728188455073, 1, 0.10003763544468222`], 
           Hue[0.6499576702370821, 1, 0.10005861044096338`], 
           Hue[0.6499875385469106, 1, 0.10001725431966231`], 
           Hue[0.6498661528906174, 1, 0.10018532676683745`], 
           Hue[0.6495445652662333, 1, 0.10063060193906169`], 
           Hue[0.6492714988092747, 1, 0.10100869395638892`], 
           Hue[0.6497651749073807, 1, 0.10032514243593448`], 
           Hue[0.6493848462505366, 1, 0.10085175134541081`], 
           Hue[0.6499272404251579, 1, 0.10010074402670449`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.649969296003201, 1, 0.10004251322633723`], 
           Hue[0.6498899253776143, 1, 0.10015241101561109`], 
           Hue[0.6497870627427598, 1, 0.10029483620233265`], 
           Hue[0.6493194313649149, 1, 0.10094232580242553`], 
           Hue[0.6495778694437395, 1, 0.10058448846251461`], 
           Hue[0.6498879983365086, 1, 0.10015507922637279`], 
           Hue[0.6498347039214942, 1, 0.1002288714933158], 
           Hue[0.6499510653458983, 1, 0.10006775567491014`], 
           Hue[0.6496322047027856, 1, 0.1005092550269123], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6498549379809121, 1, 0.10020085510335254`], 
           Hue[0.6496196896792598, 1, 0.10052658352102503`], 
           Hue[0.6492611812640128, 1, 0.10102297978828999`], 
           Hue[0.6486346449067906, 1, 0.10189049166752082`], 
           Hue[0.648932730765027, 1, 0.1014777574022703], 
           Hue[0.6490500614364054, 1, 0.10131529954959252`], 
           Hue[0.6499685517490378, 1, 0.10004354373210153`], 
           Hue[0.6499183291303127, 1, 0.10011308274264409`], 
           Hue[0.6498754872667991, 1, 0.10017240224597054`], 
           Hue[0.6499289484739935, 1, 0.10009837903600899`], 
           Hue[0.6499289484739935, 1, 0.10009837903600899`], 
           Hue[0.6494782446417726, 1, 0.10072243049600713`], 
           Hue[0.6485606730077387, 1, 0.10199291429697721`], 
           Hue[0.6481850644702218, 1, 0.10251298765661597`], 
           Hue[0.6484548050697109, 1, 0.10213950067270804`], 
           Hue[0.6493262593973559, 1, 0.10093287160366117`], 
           Hue[0.6492168120882642, 1, 0.10108441403163429`], 
           Hue[0.6489651538469169, 1, 0.1014328639042689], 
           Hue[0.648885852981722, 1, 0.10154266510223119`], 
           Hue[0.6498180333025885, 1, 0.10025195388872368`], 
           Hue[0.6497587426645933, 1, 0.10033404861825539`], 
           Hue[0.6497844884994876, 1, 0.10029840053917118`], 
           Hue[0.6492143200935674, 1, 0.10108786448582988`], 
           Hue[0.6479045331466708, 1, 0.10290141564307125`], 
           Hue[0.6496234965987956, 1, 0.10052131240166762`], 
           Hue[0.6496234965987956, 1, 0.10052131240166765`], 
           Hue[0.6490857182415352, 1, 0.10126592858864364`], 
           Hue[0.6479034511561871, 1, 0.10290291378374103`], 
           Hue[0.6468888344261866, 1, 0.10430776771758775`], 
           Hue[0.6483449140191628, 1, 0.10229165751192838`], 
           Hue[0.6473051809263888, 1, 0.10373128794807714`], 
           Hue[0.6471452171056802, 1, 0.10395277631521214`], 
           Hue[0.6475004150899578, 1, 0.10346096372159684`], 
           Hue[0.6487385095926334, 1, 0.1017466790255846], 
           Hue[0.6486985272829319, 1, 0.10180203914670977`], 
           Hue[0.6497446269774029, 1, 0.10035359341590382`], 
           Hue[0.6497220805506987, 1, 0.10038481154518647`], 
           Hue[0.6462369452811768, 1, 0.1052103834568321], 
           Hue[0.6469079421015003, 1, 0.10428131093638432`], 
           Hue[0.6476306747916084, 1, 0.10328060413469611`], 
           Hue[0.6473382110820148, 1, 0.10368555388644096`], 
           Hue[0.648661418574052, 1, 0.10185342043592796`], 
           Hue[0.6486592242610936, 1, 0.10185645871540887`], 
           Hue[0.6497216634938592, 1, 0.10038538900850272`], 
           Hue[0.6497525816504375, 1, 0.10034257925324044`], 
           Hue[0.6450042018600481, 1, 0.10691725896301033`], 
           Hue[0.6443899338329367, 1, 0.10776778392362601`], 
           Hue[0.6439216662083573, 1, 0.10841615448073602`], 
           Hue[0.6432968085982096, 1, 0.10928134194094055`], 
           Hue[0.6439229159369845, 1, 0.10841442408725224`], 
           Hue[0.6453175862656672, 1, 0.10648334209369166`], 
           Hue[0.6436612706901965, 1, 0.10877670212126647`], 
           Hue[0.6427084326690093, 1, 0.11009601630444861`], 
           Hue[0.6392482971262531, 1, 0.11488697320980351`], 
           Hue[0.6294670107067267, 1, 0.12843029286760918`], 
           Hue[0.6416071963745711, 1, 0.11162080501982463`], 
           Hue[0.645742913475472, 1, 0.10589442749550039`], 
           Hue[0.6451848600758338, 1, 0.10666711681807645`], 
           Hue[0.6497760637592552, 1, 0.10031006556410821`], 
           Hue[0.6498175387315116, 1, 0.10025263867944553`], 
           Hue[0.6448171573226332, 1, 0.10717624370712325`], 
           Hue[0.6413492538797264, 1, 0.11197795616653275`], 
           Hue[0.6393231015822374, 1, 0.11478339780920989`], 
           Hue[0.6255259248970585, 1, 0.13388718091176524`], 
           Hue[0.5591705448255907, 1, 0.22576386101072066`], 
           Hue[0.5591705448255893, 1, 0.22576386101072254`], 
           Hue[0.5972214239234073, 1, 0.1730780284137438], 
           Hue[0.5682182330617682, 1, 0.21323629268370556`], 
           Hue[0.6327196532761413, 1, 0.12392663392534278`], 
           Hue[0.6138281474123832, 1, 0.15008410358285407`], 
           Hue[0.6476889012124133, 1, 0.10319998293665852`], 
           Hue[0.6490246129733719, 1, 0.10135053588302363`], 
           Hue[0.649124059969674, 1, 0.10121284004198979`], 
           Hue[0.6498625824888393, 1, 0.10019027040006866`], 
           Hue[0.6499045423782822, 1, 0.10013217209160925`], 
           Hue[0.6445346715614864, 1, 0.10756737783794197`], 
           Hue[0.6363229297017776, 1, 0.11893748195138483`], 
           Hue[0.6320807432699075, 1, 0.12481127854935892`], 
           Hue[0.5900825238500126, 1, 0.18296265928459798`], 
           Hue[0.42804171263097834`, 1, 0.40732685943403], 
           Hue[0.428041712630976, 1, 0.40732685943403324`], 
           Hue[0.5105339839078467, 1, 0.2931067915122123], 
           Hue[0.4598523370119753, 1, 0.36328137952188033`], 
           Hue[0.6386880733811459, 1, 0.11566266762610583`], 
           Hue[0.6494358636771674, 1, 0.10078111183161441`], 
           Hue[0.6495955370911396, 1, 0.10056002556611444`], 
           Hue[0.649938736749848, 1, 0.10008482603867205`], 
           Hue[0.6499635376940699, 1, 0.10005048626974945`], 
           Hue[0.6445187656804581, 1, 0.10758940136551957`], 
           Hue[0.6264945721377744, 1, 0.13254597704000476`], 
           Hue[0.6197500814766024, 1, 0.14188450257085822`], 
           Hue[0.5262450270724327, 1, 0.2713530394381701], 
           Hue[0.2607299568423358, 1, 0.6389892905259966], 
           Hue[0.2607299568423336, 1, 0.6389892905259997], 
           Hue[0.3752505842350581, 1, 0.4804222679822273], 
           Hue[0.31924359861609497`, 1, 0.5579704019161762], 
           Hue[0.554770362006304, 1, 0.23185642183742522`], 
           Hue[0.4950793034126642, 1, 0.31450557989015726`], 
           Hue[0.4799251869017592, 1, 0.33548820275141034`], 
           Hue[0.42187632618428994`, 1, 0.415863548360214], 
           Hue[0.6483395074792696, 1, 0.10229914349024219`], 
           Hue[0.6483775520143685, 1, 0.10224646644164366`], 
           Hue[0.6497259877549584, 1, 0.10037940157005763`], 
           Hue[0.6498247725796027, 1, 0.10024262258208867`], 
           Hue[0.6499797919710948, 1, 0.10002798034771491`], 
           Hue[0.6499895375823748, 1, 0.10001448642440419`], 
           Hue[0.6490074389437328, 1, 0.10137431530867769`], 
           Hue[0.6490612179653512, 1, 0.10129985204797536`], 
           Hue[0.6123745783732009, 1, 0.15209673763710646`], 
           Hue[0.23864305325650226`, 1, 0.6695711570294584], 
           Hue[0.14468550878839948`, 1, 0.7996662186006775], 
           Hue[0.12170305563956119`, 1, 0.8314880768067614], 
           Hue[0.12170305563955952`, 1, 0.8314880768067637], 
           Hue[0.238676642843565, 1, 0.6695246483704484], 
           Hue[0.19694005227972833`, 1, 0.72731377376653], 
           Hue[0.14472156419557214`, 1, 0.7996162957292078], 
           Hue[0.12320664814156568`, 1, 0.8294061794962936], 
           Hue[0.40926481920002356`, 1, 0.4333256349538136], 
           Hue[0.374774116754797, 1, 0.4810819921856657], 
           Hue[0.6039357705145427, 1, 0.16378124082601786`], 
           Hue[0.6446378483467694, 1, 0.10742451767370392`], 
           Hue[0.6490365748044977, 1, 0.10133397334761854`], 
           Hue[0.6498942532833836, 1, 0.10014641853069964`], 
           Hue[0.6499395617051158, 1, 0.1000836837929167], 
           Hue[0.6499952798767935, 1, 0.100006535555209], 
           Hue[0.6499979498338926, 1, 0.10000283869153345`], 
           Hue[0.6499617603399275, 1, 0.10005294722163892`], 
           Hue[0.6499852500802348, 1, 0.10002042296582875`], 
           Hue[0.6494794345021933, 1, 0.10072078299696322`], 
           Hue[0.6495125444945455, 1, 0.10067493839216769`], 
           Hue[0.6496523580230951, 1, 0.10048135042956073`], 
           Hue[0.649652317451856, 1, 0.10048140660512248`], 
           Hue[0.13133504687157593`, 1, 0.8181514735624333], 
           Hue[0.10550699045289536`, 1, 0.8539133978344525], 
           Hue[0.033059327874931266`, 1, 0.954225546019326], 
           Hue[0.03305932787493049, 1, 0.9542255460193271], 
           Hue[0.008564162898874517, 1, 0.9881419282938662], 
           Hue[0.1313694777268779, 1, 0.8181038000704768], 
           Hue[0.1055155371471872, 1, 0.8539015639500485], 
           Hue[0.10550699045002132`, 1, 0.8539133978384321], 
           Hue[0.36993896493670303`, 1, 0.48777681777994963`], 
           Hue[0.36993665875161313`, 1, 0.4877800109593049], 
           Hue[0.5947858976879443, 1, 0.17645029550900027`], 
           Hue[0.6494921178875066, 1, 0.1007032213865294], 
           Hue[0.6496523174518573, 1, 0.10048140660512081`], 
           Hue[0.6499852320800056, 1, 0.10002044788922304`], 
           Hue[0.6499852500802348, 1, 0.1000204229658288], 
           Hue[0.6499990931632785, 1, 0.10000125562007593`], 
           Hue[0.6496149480433893, 1, 0.10053314886299958`], 
           Hue[0.5947857583623528, 1, 0.1764504884213577], 
           Hue[0.5947858976870672, 1, 0.17645029551021466`], 
           Hue[0.5959049495698923, 1, 0.17490083905707227`], 
           Hue[0.6039357705136676, 1, 0.1637812408272295], 
           Hue[0.36993665874980525`, 1, 0.48778001096180823`], 
           Hue[0.37477411675310107`, 1, 0.48108199218801395`], 
           Hue[0.12320664814257443`, 1, 0.8294061794948969], 
           Hue[0.03305932787187027, 1, 0.9542255460235642], 
           Hue[0.03305932787187105, 1, 0.9542255460235631], 
           Hue[0.12317793669320076`, 1, 0.8294459338094142], 
           Hue[0.14468550878547748`, 1, 0.7996662186047235], 
           Hue[0.6495125444945283, 1, 0.10067493839219155`], 
           Hue[0.6499731374090267, 1, 0.10003719435673222`], 
           Hue[0.6499560132855162, 1, 0.10006090468159291`], 
           Hue[0.6499979498338926, 1, 0.10000283869153345`], 
           Hue[0.6499990931632785, 1, 0.10000125562007593`], 
           Hue[0.6494921178874883, 1, 0.10070322138655469`], 
           Hue[0.6492984661033572, 1, 0.10097135462612092`], 
           Hue[0.6446378483465085, 1, 0.10742451767406523`], 
           Hue[0.6446747005057164, 1, 0.10737349160746958`], 
           Hue[0.606685793838532, 1, 0.1599735162235711], 
           Hue[0.42187632618276033`, 1, 0.41586354836233186`], 
           Hue[0.13136947772739593`, 1, 0.8181038000697596], 
           Hue[0.19694005227927935`, 1, 0.7273137737671517], 
           Hue[0.13133504686846842`, 1, 0.818151473566736], 
           Hue[0.1969013977278607, 1, 0.7273672954537314], 
           Hue[0.23864305325552504`, 1, 0.6695711570308115], 
           Hue[0.6494928049778319, 1, 0.10070227003069428`], 
           Hue[0.6499667588310656, 1, 0.10004602623390928`], 
           Hue[0.6499952798767935, 1, 0.100006535555209], 
           Hue[0.6498942532833839, 1, 0.10014641853069926`], 
           Hue[0.6490365748044896, 1, 0.10133397334762985`], 
           Hue[0.6445188584205228, 1, 0.10758927295619916`], 
           Hue[0.621196668559048, 1, 0.13988153584131827`], 
           Hue[0.495079303411862, 1, 0.31450557989126804`], 
           Hue[0.2153784744288908, 1, 0.7017836507907667], 
           Hue[0.12170305563612915`, 1, 0.8314880768115135], 
           Hue[0.12170305563613082`, 1, 0.8314880768115112], 
           Hue[0.21534157718856928`, 1, 0.7018347392773656], 
           Hue[0.48756298968034184`, 1, 0.32491278351952674`], 
           Hue[0.6123745783734575, 1, 0.15209673763675113`], 
           Hue[0.6490612179653427, 1, 0.10129985204798718`], 
           Hue[0.6499797919710948, 1, 0.1000279803477149], 
           Hue[0.6497259877549593, 1, 0.10037940157005647`], 
           Hue[0.6484128933058365, 1, 0.10219753234576491`], 
           Hue[0.6483395074792844, 1, 0.10229914349022172`], 
           Hue[0.6445356096358542, 1, 0.10756607896574029`], 
           Hue[0.6330024607853297, 1, 0.12353505429723577`], 
           Hue[0.6386880733811164, 1, 0.11566266762614656`], 
           Hue[0.3192435986162432, 1, 0.557970401915971], 
           Hue[0.26072995684176903`, 1, 0.6389892905267813], 
           Hue[0.26072995684177125`, 1, 0.6389892905267783], 
           Hue[0.5262450270736311, 1, 0.27135303943651085`], 
           Hue[0.5613439013174828, 1, 0.22275459817579313`], 
           Hue[0.6264945721378616, 1, 0.1325459770398839], 
           Hue[0.6499875780500365, 1, 0.1000171996230264], 
           Hue[0.649938736749848, 1, 0.10008482603867203`], 
           Hue[0.6477602551397624, 1, 0.10310118519109816`], 
           Hue[0.6476889012124346, 1, 0.10319998293662903`], 
           Hue[0.6474700106798329, 1, 0.1035030621356161], 
           Hue[0.6449758474344257, 1, 0.10695651893694909`], 
           Hue[0.4598523370130185, 1, 0.36328137952043593`], 
           Hue[0.4280417126324515, 1, 0.4073268594319903], 
           Hue[0.4280417126324537, 1, 0.4073268594319872], 
           Hue[0.54385421509572, 1, 0.24697108679054167`], 
           Hue[0.5900825238506199, 1, 0.18296265928375707`], 
           Hue[0.6113184040198553, 1, 0.153559132895585], 
           Hue[0.6363229297018138, 1, 0.11893748195133472`], 
           Hue[0.649904864696231, 1, 0.10013172580521863`], 
           Hue[0.6498625824888394, 1, 0.10019027040006856`], 
           Hue[0.6491240599696747, 1, 0.10121284004198884`], 
           Hue[0.6471976417124166, 1, 0.10388018839819256`], 
           Hue[0.6454891179707115, 1, 0.10624583665593802`], 
           Hue[0.645742913475486, 1, 0.10589442749548107`], 
           Hue[0.5682182330626965, 1, 0.21323629268242025`], 
           Hue[0.5591705448266979, 1, 0.22576386100918752`], 
           Hue[0.5591705448266993, 1, 0.22576386100918563`], 
           Hue[0.6131150084109671, 1, 0.1510715268155841], 
           Hue[0.6255259248972418, 1, 0.13388718091151136`], 
           Hue[0.641349253879749, 1, 0.1119779561665015], 
           Hue[0.6498075235338531, 1, 0.10026650587620355`], 
           Hue[0.6497525816504376, 1, 0.10034257925324029`], 
           Hue[0.6473189778091604, 1, 0.10371218457193178`], 
           Hue[0.6473382110820156, 1, 0.10368555388643992`], 
           Hue[0.6428823803202547, 1, 0.10985516571041662`], 
           Hue[0.6442709715647634, 1, 0.10793250091032752`], 
           Hue[0.639252008962006, 1, 0.11488183374491492`], 
           Hue[0.638478408111949, 1, 0.11595297338345519`], 
           Hue[0.6392482971262289, 1, 0.11488697320983701`], 
           Hue[0.6421307435744987, 1, 0.11089589351223259`], 
           Hue[0.6436612706902044, 1, 0.10877670212125548`], 
           Hue[0.6497395116100093, 1, 0.10036067623229489`], 
           Hue[0.6497216634938593, 1, 0.10038538900850259`], 
           Hue[0.6486592242610939, 1, 0.10185645871540853`], 
           Hue[0.648698527282932, 1, 0.10180203914670959`], 
           Hue[0.6475978994814844, 1, 0.10332598533332933`], 
           Hue[0.6476306747916085, 1, 0.10328060413469593`], 
           Hue[0.6444863018191734, 1, 0.10763435132729843`], 
           Hue[0.6439229159370509, 1, 0.10841442408716043`], 
           Hue[0.643921666208303, 1, 0.10841615448081116`], 
           Hue[0.6450042018600488, 1, 0.10691725896300938`], 
           Hue[0.6497220805506988, 1, 0.10038481154518636`], 
           Hue[0.6497587426645933, 1, 0.10033404861825539`], 
           Hue[0.648885852981722, 1, 0.10154266510223114`], 
           Hue[0.646645752668982, 1, 0.10464434245833251`], 
           Hue[0.6469079421015004, 1, 0.10428131093638407`], 
           Hue[0.6460988378741064, 1, 0.10540160909739126`], 
           Hue[0.6468888344263425, 1, 0.10430776771737202`], 
           Hue[0.6468897902011312, 1, 0.1043064443368952], 
           Hue[0.6479045331465779, 1, 0.10290141564319985`], 
           Hue[0.6488721916035767, 1, 0.10156158085658615`], 
           Hue[0.6492143200935481, 1, 0.10108786448585658`], 
           Hue[0.6492168120882642, 1, 0.10108441403163429`], 
           Hue[0.6472169204860098, 1, 0.10385349471167882`], 
           Hue[0.6475004150899578, 1, 0.10346096372159691`], 
           Hue[0.64714521710568, 1, 0.10395277631521234`], 
           Hue[0.6473051809264003, 1, 0.10373128794806115`], 
           Hue[0.6490857182415612, 1, 0.1012659285886076], 
           Hue[0.6496234965987958, 1, 0.10052131240166731`], 
           Hue[0.6496234965987958, 1, 0.1005213124016673], 
           Hue[0.6497844884994874, 1, 0.10029840053917122`], 
           Hue[0.6498285638060287, 1, 0.10023737319165266`], 
           Hue[0.6483894496489137, 1, 0.10222999279381195`], 
           Hue[0.648454805069711, 1, 0.1021395006727079], 
           Hue[0.6478481526586201, 1, 0.10297948093421838`], 
           Hue[0.6481850644702217, 1, 0.10251298765661612`], 
           Hue[0.6477258602117323, 1, 0.10314880893760156`], 
           Hue[0.6485606730077386, 1, 0.10199291429697746`], 
           Hue[0.6486346449067923, 1, 0.10189049166751832`], 
           Hue[0.6499289484739935, 1, 0.10009837903600897`], 
           Hue[0.6499289484739935, 1, 0.10009837903600897`], 
           Hue[0.6494608701931662, 1, 0.10074648742484672`], 
           Hue[0.649875487266799, 1, 0.10017240224597058`], 
           Hue[0.6499179695206531, 1, 0.10011358066371125`], 
           Hue[0.6489814055841803, 1, 0.10141036149882729`], 
           Hue[0.6490500614364055, 1, 0.1013152995495924], 
           Hue[0.6485711159572849, 1, 0.10197845482837475`], 
           Hue[0.6489327307650269, 1, 0.1014777574022705], 
           Hue[0.6486670765987006, 1, 0.10184558624795306`], 
           Hue[0.6493194313649148, 1, 0.10094232580242575`], 
           Hue[0.6493571286681644, 1, 0.10089012953638776`], 
           Hue[0.6496196896792598, 1, 0.10052658352102502`], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6496322047027855, 1, 0.10050925502691244`], 
           Hue[0.6497686522347683, 1, 0.10032032767493618`], 
           Hue[0.6499510653458982, 1, 0.10006775567491016`], 
           Hue[0.6499735114284139, 1, 0.10003667648373475`], 
           Hue[0.6498347039214942, 1, 0.10022887149331573`], 
           Hue[0.6495311358384767, 1, 0.1006491965313401], 
           Hue[0.6495778694437395, 1, 0.10058448846251451`], 
           Hue[0.6497827013349246, 1, 0.10030087507471992`], 
           Hue[0.6498899253776143, 1, 0.10015241101561112`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6498201909540229, 1, 0.100248966371353], 
           Hue[0.6499272404251579, 1, 0.10010074402670446`], 
           Hue[0.6493848462505368, 1, 0.10085175134541056`], 
           Hue[0.6492714988092748, 1, 0.1010086939563887], 
           Hue[0.6498661528906173, 1, 0.10018532676683752`], 
           Hue[0.6499298416416035, 1, 0.10009714234239514`], 
           Hue[0.6499875385469106, 1, 0.10001725431966232`], 
           Hue[0.6499576702370821, 1, 0.10005861044096336`], 
           Hue[0.6499659179555519, 1, 0.100047190523082], 
           Hue[0.6498543989283845, 1, 0.1002016014837754], 
           Hue[0.6498765165910504, 1, 0.10017097702777641`], 
           Hue[0.6498906156449326, 1, 0.1001514552608626], 
           Hue[0.6499763529684163, 1, 0.10003274204373136`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6497422679611429, 1, 0.10035685974610986`], 
           Hue[0.6498668777824628, 1, 0.10018432307043623`], 
           Hue[0.6499657096233139, 1, 0.10004747898310389`], 
           Hue[0.6499852101793618, 1, 0.10002047821319135`], 
           Hue[0.6499976810908947, 1, 0.10000321079722264`], 
           Hue[0.6499991804292786, 1, 0.10000113479022964`], 
           Hue[0.6499746602037513, 1, 0.10003508587172912`], 
           Hue[0.6499800210545625, 1, 0.1000276631552211], 
           Hue[0.6499964290356581, 1, 0.10000494441216566`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499997070467911, 1, 0.10000040562752005`], 
           Hue[0.64999986712212, 1, 0.10000018398475698`], 
           Hue[0.6499999463041645, 1, 0.10000007434808002`], 
           Hue[0.6499964589486245, 1, 0.1000049029942124], 
           Hue[0.6499800978129978, 1, 0.10002755687431074`], 
           Hue[0.6499452847292683, 1, 0.10007575960562862`], 
           Hue[0.6499745865383855, 1, 0.10003518786992784`], 
           Hue[0.6499996894548788, 1, 0.10000042998555234`], 
           Hue[0.6499998925666856, 1, 0.1000001487538201], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499872761827475, 1, 0.1000176175931189], 
           Hue[0.6499764872407213, 1, 0.10003255612823204`], 
           Hue[0.6499659179555519, 1, 0.10004719052308203`], 
           Hue[0.6496095597971275, 1, 0.10054060951166954`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6495581589251695, 1, 0.10061177994976521`], 
           Hue[0.6498666614359694, 1, 0.10018462262711933`], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.649363405912811, 1, 0.10088143796687704`], 
           Hue[0.6487551382058032, 1, 0.10172365479196484`], 
           Hue[0.6490171435581192, 1, 0.1013608781502964], 
           Hue[0.6499289484739935, 1, 0.10009837903600899`], 
           Hue[0.648157278257873, 1, 0.10255146087371447`], 
           Hue[0.6480091049759613, 1, 0.10275662387943817`], 
           Hue[0.6490820712669709, 1, 0.10127097824573264`], 
           Hue[0.6498289592233316, 1, 0.10023682569077165`], 
           Hue[0.6496234965987956, 1, 0.10052131240166763`], 
           Hue[0.6484645052704197, 1, 0.10212606962557286`], 
           Hue[0.6473537923316893, 1, 0.10366397984843018`], 
           Hue[0.6487973060787215, 1, 0.10166526850638559`], 
           Hue[0.6497500661969323, 1, 0.10034606218886298`], 
           Hue[0.6460988378741057, 1, 0.10540160909739217`], 
           Hue[0.6486665440965278, 1, 0.10184632355865385`], 
           Hue[0.6450053143732752, 1, 0.10691571856008053`], 
           Hue[0.6392520089618975, 1, 0.11488183374506498`], 
           Hue[0.5856239954315853, 1, 0.18913600632549732`], 
           Hue[0.6255368322474695, 1, 0.13387207842658083`], 
           Hue[0.48730850453537505`, 1, 0.3252651475664038], 
           Hue[0.26072995684233463`, 1, 0.6389892905259982], 
           Hue[0.346411220142523, 1, 0.5203536951872758], 
           Hue[0.4875889857309319, 1, 0.3248767889879404], 
           Hue[0.2153415771900969, 1, 0.7018347392752505], 
           Hue[0.1217030556395603, 1, 0.8314880768067627], 
           Hue[0.21537847442945068`, 1, 0.7017836507899914], 
           Hue[0.16664015272578908`, 1, 0.7692674808412151], 
           Hue[0.41486309731408044`, 1, 0.42557417294973476`], 
           Hue[0.6499667588310657, 1, 0.10004602623390908`], 
           Hue[0.6494928049778499, 1, 0.10070227003066942`], 
           Hue[0.649615310956585, 1, 0.10053264636780553`], 
           Hue[0.03305932787493093, 1, 0.9542255460193264], 
           Hue[0.10995731692864064`, 1, 0.8477514073295744], 
           Hue[0.37117736989835204`, 1, 0.4860621032176664], 
           Hue[0.6499817210220852, 1, 0.10002530935403599`], 
           Hue[0.5950760330681312, 1, 0.17604856959797222`], 
           Hue[0.008564162897190308, 1, 0.9881419282961981], 
           Hue[0.10993697241469957`, 1, 0.8477795766565698], 
           Hue[0.6499817845643628, 1, 0.10002522137242076`], 
           Hue[0.605186076820044, 1, 0.16205004747993917`], 
           Hue[0.1666007064873134, 1, 0.7693220987098738], 
           Hue[0.619757163057583, 1, 0.14187469730488508`], 
           Hue[0.12170305563612982`, 1, 0.8314880768115125], 
           Hue[0.648377552014383, 1, 0.10224646644162362`], 
           Hue[0.6320881314564141, 1, 0.12480104875265746`], 
           Hue[0.3464112201429481, 1, 0.5203536951866873], 
           Hue[0.2607299568417701, 1, 0.6389892905267799], 
           Hue[0.6499637194211009, 1, 0.10005023464770654`], 
           Hue[0.6494358636771683, 1, 0.10078111183161315`], 
           Hue[0.6448183521045393, 1, 0.10717458939371491`], 
           Hue[0.4873085045365092, 1, 0.3252651475648335], 
           Hue[0.4280417126324527, 1, 0.40732685943198865`], 
           Hue[0.6453186380742266, 1, 0.10648188574337857`], 
           Hue[0.6255368322476118, 1, 0.13387207842638366`], 
           Hue[0.585623995432426, 1, 0.1891360063243331], 
           Hue[0.5591705448266987, 1, 0.22576386100918638`], 
           Hue[0.6498178986902057, 1, 0.10025214027509986`], 
           Hue[0.6497760637592553, 1, 0.10031006556410807`], 
           Hue[0.6472266389834023, 1, 0.10384003833067385`], 
           Hue[0.6294670107072551, 1, 0.12843029286687765`], 
           Hue[0.6497444578897739, 1, 0.1003538275372362], 
           Hue[0.6474600972735775, 1, 0.10351678839043128`], 
           Hue[0.6450053143732791, 1, 0.10691571856007508`], 
           Hue[0.643296808598523, 1, 0.1092813419405066], 
           Hue[0.646236945281202, 1, 0.10521038345679727`], 
           Hue[0.6484656021364826, 1, 0.1021245508879472], 
           Hue[0.6473537923316893, 1, 0.10366397984843025`], 
           Hue[0.6496234965987958, 1, 0.10052131240166731`], 
           Hue[0.6480091049759613, 1, 0.10275662387943829`], 
           Hue[0.6481572782578727, 1, 0.10255146087371475`], 
           Hue[0.6499289484739935, 1, 0.10009837903600897`], 
           Hue[0.6490171435581193, 1, 0.10136087815029629`], 
           Hue[0.6487551382058031, 1, 0.10172365479196505`], 
           Hue[0.6499892775816672, 1, 0.10001484642538379`], 
           Hue[0.6498666614359694, 1, 0.10018462262711927`], 
           Hue[0.6495581589251697, 1, 0.10061177994976513`], 
           Hue[0.6496095597971278, 1, 0.10054060951166935`], 
           Hue[0.6498671323084145, 1, 0.10018397064988764`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499764872407213, 1, 0.10003255612823203`], 
           Hue[0.6498908903541091, 1, 0.10015107489431052`], 
           Hue[0.6499655367985427, 1, 0.10004771827894093`], 
           Hue[0.6499997961154858, 1, 0.10000028230163507`], 
           Hue[0.649965516562715, 1, 0.10004774629777935`], 
           Hue[0.6495577101050631, 1, 0.10061240139298958`], 
           Hue[0.6496090377308191, 1, 0.10054133237271205`], 
           Hue[0.6490867430856696, 1, 0.1012645095736882], 
           Hue[0.6474954669798254, 1, 0.10346781495101104`], 
           Hue[0.6474944451680356, 1, 0.10346922976733547`], 
           Hue[0.6294650459019114, 1, 0.12843301336658416`], 
           Hue[0.6492993957289686, 1, 0.10097006745219737`], 
           Hue[0.6294650459018397, 1, 0.1284330133666835], 
           Hue[0.6474944451681558, 1, 0.10346922976716888`], 
           Hue[0.6474954669797106, 1, 0.10346781495117001`], 
           Hue[0.6490867430856438, 1, 0.10126450957372388`], 
           Hue[0.6496090377308189, 1, 0.10054133237271225`], 
           Hue[0.649557710105063, 1, 0.10061240139298966`], 
           Hue[0.649965516562715, 1, 0.10004774629777938`], 
           Hue[0.6499997961154859, 1, 0.10000028230163507`], 
           Hue[0.6499655367985427, 1, 0.1000477182789409], 
           Hue[0.649999546284906, 1, 0.10000062822089953`], 
           Hue[0.6499921293089566, 1, 0.10001089787990629`], 
           Hue[0.6499882868309909, 1, 0.10001621823401269`], 
           Hue[0.6499773681890932, 1, 0.10003133635356326`], 
           Hue[0.6499968016948423, 1, 0.10000442842252606`], 
           Hue[0.64995742655059, 1, 0.10005894785302931`], 
           Hue[0.649941550412067, 1, 0.10008093019867641`], 
           Hue[0.6498799739553269, 1, 0.10016618990800887`], 
           Hue[0.6499837977879257, 1, 0.10002243383210294`], 
           Hue[0.6498432245869254, 1, 0.10021707364887242`], 
           Hue[0.6497995501416562, 1, 0.10027754595770676`], 
           Hue[0.6499427464970976, 1, 0.10007927408094187`], 
           Hue[0.6495899679528511, 1, 0.10056773668066774`], 
           Hue[0.649510432152012, 1, 0.10067786317413728`], 
           Hue[0.6498634854226076, 1, 0.10018902018408178`], 
           Hue[0.6435492187576689, 1, 0.10893185095091998`], 
           Hue[0.6383247155518019, 1, 0.11616577846673584`], 
           Hue[0.6228816248504461, 1, 0.13754851943784388`], 
           Hue[0.5843916311222078, 1, 0.19084235690771226`], 
           Hue[0.5180120543224636, 1, 0.2827525401688967], 
           Hue[0.6499987777339871, 1, 0.10000169236832561`], 
           Hue[0.6499615936668796, 1, 0.1000531779997052], 
           Hue[0.6499507438872519, 1, 0.10006820077149743`], 
           Hue[0.649993865184265, 1, 0.10000849436024842`], 
           Hue[0.6498799412726701, 1, 0.10016623516091828`], 
           Hue[0.6498506186895232, 1, 0.10020683566066013`], 
           Hue[0.6139219345410796, 1, 0.14995424448158212`], 
           Hue[0.6499762536549267, 1, 0.10003287955471694`], 
           Hue[0.6496976408126719, 1, 0.1004186511824543], 
           Hue[0.6496397195744826, 1, 0.10049884981994713`], 
           Hue[0.6276537703969356, 1, 0.13094093329655082`], 
           Hue[0.6499307068090907, 1, 0.10009594441818212`], 
           Hue[0.6369354292276367, 1, 0.11808940568481076`], 
           Hue[0.6498518987975389, 1, 0.10020506320340777`], 
           Hue[0.6416037038677828, 1, 0.1116256407984547], 
           Hue[0.6437749675546233, 1, 0.10861927569359858`], 
           Hue[0.6479034511562832, 1, 0.10290291378360782`], 
           Hue[0.6481488635226913, 1, 0.10256311204550442`], 
           Hue[0.649776996090501, 1, 0.10030877464392167`], 
           Hue[0.6498161665378698, 1, 0.10025453863987266`], 
           Hue[0.6496713073131245, 1, 0.1004551129510585], 
           Hue[0.649947199277628, 1, 0.10007310869251507`], 
           Hue[0.6499585389917858, 1, 0.10005740754983512`], 
           Hue[0.6499080428696403, 1, 0.1001273252574212], 
           Hue[0.6499903486487819, 1, 0.10001336340937897`], 
           Hue[0.6499928350255395, 1, 0.10000992073386847`], 
           Hue[0.6499810990463154, 1, 0.10002617055125557`], 
           Hue[0.6499986685807253, 1, 0.10000184350361113`], 
           Hue[0.6499990728488086, 1, 0.10000128374780339`], 
           Hue[0.6498762763822666, 1, 0.10017130962455396`], 
           Hue[0.6499312334274999, 1, 0.10009521525423096`], 
           Hue[0.6499998652875634, 1, 0.10000018652491231`], 
           Hue[0.6499999130990606, 1, 0.10000012032437766`], 
           Hue[0.6499786571222672, 1, 0.10002955167686084`], 
           Hue[0.6499786571222672, 1, 0.10002955167686084`], 
           Hue[0.6499546249480828, 1, 0.10006282699496238`], 
           Hue[0.6499774540762749, 1, 0.10003121743285015`], 
           Hue[0.6499999130990606, 1, 0.10000012032437766`], 
           Hue[0.6499312334274999, 1, 0.10009521525423093`], 
           Hue[0.6499990728488086, 1, 0.10000128374780339`], 
           Hue[0.6499871546152928, 1, 0.100017785917287], 
           Hue[0.6499810990463154, 1, 0.10002617055125557`], 
           Hue[0.6499928350255395, 1, 0.10000992073386847`], 
           Hue[0.6499334733653315, 1, 0.10009211380184871`], 
           Hue[0.6499080428696403, 1, 0.10012732525742117`], 
           Hue[0.6499585389917857, 1, 0.10005740754983526`], 
           Hue[0.649748705671542, 1, 0.10034794599324966`], 
           Hue[0.6496713073131244, 1, 0.10045511295105851`], 
           Hue[0.6498161665378682, 1, 0.1002545386398748], 
           Hue[0.644296377451823, 1, 0.1078973235282451], 
           Hue[0.6437749675546159, 1, 0.10861927569360877`], 
           Hue[0.6355280494073325, 1, 0.12003808543600118`], 
           Hue[0.6425408848188494, 1, 0.11032800563543929`], 
           Hue[0.6416037038677618, 1, 0.11162564079848367`], 
           Hue[0.6498383027784683, 1, 0.10022388846058237`], 
           Hue[0.6498518987975388, 1, 0.10020506320340787`], 
           Hue[0.6389584142500294, 1, 0.11528834949995931`], 
           Hue[0.6369354292276049, 1, 0.1180894056848547], 
           Hue[0.6499202363144327, 1, 0.10011044202617006`], 
           Hue[0.6499307068090907, 1, 0.10009594441818216`], 
           Hue[0.631411381448922, 1, 0.1257380872245697], 
           Hue[0.627653770396862, 1, 0.1309409332966527], 
           Hue[0.6496397195744819, 1, 0.10049884981994829`], 
           Hue[0.6499711752825617, 1, 0.10003991114722235`], 
           Hue[0.6499762536549266, 1, 0.10003287955471696`], 
           Hue[0.6189100178906387, 1, 0.1430476675360388], 
           Hue[0.6139219345408472, 1, 0.14995424448190392`], 
           Hue[0.6498506186895228, 1, 0.10020683566066077`], 
           Hue[0.649992139261425, 1, 0.10001088409956546`], 
           Hue[0.649993865184265, 1, 0.10000849436024842`], 
           Hue[0.6499507438872519, 1, 0.10006820077149738`], 
           Hue[0.6499983476490149, 1, 0.10000228787059483`], 
           Hue[0.6499987777339871, 1, 0.10000169236832561`], 
           Hue[0.49721716070467575`, 1, 0.31154546979352593`], 
           Hue[0.5180120543237592, 1, 0.2827525401671027], 
           Hue[0.5687382725785333, 1, 0.21251623796818472`], 
           Hue[0.5843916311228772, 1, 0.19084235690678542`], 
           Hue[0.6150728538410806, 1, 0.14836066391234995`], 
           Hue[0.6228816248506641, 1, 0.13754851943754204`], 
           Hue[0.6355280494071399, 1, 0.12003808543626789`], 
           Hue[0.635567781392156, 1, 0.11998307191855329`], 
           Hue[0.6383247155517912, 1, 0.11616577846675076`], 
           Hue[0.6425869541066499, 1, 0.11026421739079253`], 
           Hue[0.6435492187576146, 1, 0.10893185095099511`], 
           Hue[0.6498492997424695, 1, 0.10020866189504225`], 
           Hue[0.6498634854226076, 1, 0.10018902018408182`], 
           Hue[0.6495104321520119, 1, 0.10067786317413743`], 
           Hue[0.6499326287044422, 1, 0.10009328333231078`], 
           Hue[0.6499427464970975, 1, 0.1000792740809419], 
           Hue[0.6497995501416562, 1, 0.10027754595770684`], 
           Hue[0.6499796318088381, 1, 0.1000282021108396], 
           Hue[0.6499837977879257, 1, 0.10002243383210295`], 
           Hue[0.6497967031430822, 1, 0.10028148795573225`], 
           Hue[0.6498799739553269, 1, 0.10016618990800896`], 
           Hue[0.649941550412067, 1, 0.10008093019867645`], 
           Hue[0.6499957079341608, 1, 0.10000594286039267`], 
           Hue[0.6499968016948423, 1, 0.10000442842252608`], 
           Hue[0.6499544789815872, 1, 0.10006302910241778`], 
           Hue[0.6499773681890932, 1, 0.10003133635356329`], 
           Hue[0.6499546249480828, 1, 0.10006282699496233`], 
           Hue[0.6499774540762749, 1, 0.10003121743285012`], 
           Hue[0.6499882868309909, 1, 0.1000162182340127], 
           Hue[0.6499993476880973, 1, 0.10000090320109607`], 
           Hue[0.649999546284906, 1, 0.10000062822089954`], 
           Hue[0.6499786571222672, 1, 0.10002955167686085`], 
           Hue[0.6499786571222672, 1, 0.10002955167686085`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499786432660215, 1, 0.10002957086243183`], 
           Hue[0.6481499757638645, 1, 0.10256157201926468`], 
           Hue[0.6481488635226094, 1, 0.10256311204561784`], 
           Hue[0.6481499757637849, 1, 0.10256157201937481`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499786432660215, 1, 0.10002957086243186`], 
           Hue[0.6499786432660215, 1, 0.10002957086243186`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499872761827474, 1, 0.1000176175931189], 
           Hue[0.6499998499361392, 1, 0.10000020778073027`], 
           Hue[0.6499997756993264, 1, 0.10000031057016343`], 
           Hue[0.649998744591033, 1, 0.10000173825856974`], 
           Hue[0.649998257978814, 1, 0.10000241202933446`], 
           Hue[0.6499807313906684, 1, 0.10002667961292076`], 
           Hue[0.6499999454587057, 1, 0.10000007551871525`], 
           Hue[0.6499448820990992, 1, 0.10007631709355502`], 
           Hue[0.6498985097083886, 1, 0.1001405250191543], 
           Hue[0.6499985526901774, 1, 0.10000200396744671`], 
           Hue[0.6499924900042139, 1, 0.10001039845570384`], 
           Hue[0.6499902455567599, 1, 0.10001350615217873`], 
           Hue[0.6499145448836653, 1, 0.10011832246877118`], 
           Hue[0.6498226656875891, 1, 0.1002455398171844], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6498702084125652, 1, 0.10017971142875591`], 
           Hue[0.649822601052624, 1, 0.10024562931175142`], 
           Hue[0.6499915553675152, 1, 0.10001169256805592`], 
           Hue[0.6495444786347687, 1, 0.10063072189032035`], 
           Hue[0.649721605398353, 1, 0.10038546944843432`], 
           Hue[0.6497393167031354, 1, 0.100360946103351], 
           Hue[0.6430994341869618, 1, 0.10955462958728368`], 
           Hue[0.6430994341869617, 1, 0.10955462958728389`], 
           Hue[0.6497442349944514, 1, 0.10035413616152887`], 
           Hue[0.6326369084382304, 1, 0.12404120370091186`], 
           Hue[0.6278460623885441, 1, 0.13067468284663128`], 
           Hue[0.6227153440039708, 1, 0.13777875445604051`], 
           Hue[0.6227153440039702, 1, 0.13777875445604126`], 
           Hue[0.649925810454061, 1, 0.10010272398668485`], 
           Hue[0.6499740052775556, 1, 0.10003599269261546`], 
           Hue[0.6499931350584105, 1, 0.10000950530373938`], 
           Hue[0.6499731374090268, 1, 0.10003719435673206`], 
           Hue[0.6499785845670428, 1, 0.10002965213794066`], 
           Hue[0.6493278398912834, 1, 0.10093068322745373`], 
           Hue[0.645136680417695, 1, 0.10673382711396075`], 
           Hue[0.6493269366654968, 1, 0.10093193384777369`], 
           Hue[0.6495118930856854, 1, 0.10067584034289725`], 
           Hue[0.6496046189157386, 1, 0.10054745073205425`], 
           Hue[0.6499986042640042, 1, 0.10000193255753263`], 
           Hue[0.6499994842091842, 1, 0.10000071417189885`], 
           Hue[0.6499992967751281, 1, 0.10000097369597646`], 
           Hue[0.6499785002992391, 1, 0.10002976881643816`], 
           Hue[0.6448143518714428, 1, 0.10718012817800232`], 
           Hue[0.6448140890407283, 1, 0.10718049209745306`], 
           Hue[0.6448213068073145, 1, 0.1071704982667953], 
           Hue[0.008564162898874295, 1, 0.9881419282938664], 
           Hue[0.6496050201873774, 1, 0.10054689512516983`], 
           Hue[0.6499994103243372, 1, 0.1000008164739948], 
           Hue[0.649997177936394, 1, 0.10000390747268527`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.00856416289719053, 1, 0.9881419282961977], 
           Hue[0.6499785845670427, 1, 0.10002965213794082`], 
           Hue[0.6499968070349429, 1, 0.1000044210285406], 
           Hue[0.6499875143105937, 1, 0.10001728787763953`], 
           Hue[0.6499844331418096, 1, 0.10002155411134056`], 
           Hue[0.6499861817897984, 1, 0.1000191329064331], 
           Hue[0.632957681610334, 1, 0.12359705623184515`], 
           Hue[0.6358099147458792, 1, 0.11964781035185952`], 
           Hue[0.634495825261374, 1, 0.12146731886886677`], 
           Hue[0.6227153440043056, 1, 0.13777875445557686`], 
           Hue[0.6227153440043062, 1, 0.1377787544555762], 
           Hue[0.6430994341870133, 1, 0.1095546295872123], 
           Hue[0.6430994341870135, 1, 0.10955462958721211`], 
           Hue[0.6497220759135403, 1, 0.10038481796586732`], 
           Hue[0.6497444630285241, 1, 0.10035382042204369`], 
           Hue[0.6497498661728607, 1, 0.10034633914526984`], 
           Hue[0.6499766495074196, 1, 0.10003233145126512`], 
           Hue[0.6499380881968962, 1, 0.10008572403506673`], 
           Hue[0.6492714389145244, 1, 0.10100877688758152`], 
           Hue[0.6495444786347686, 1, 0.1006307218903205], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499820089674371, 1, 0.10002491066047177`], 
           Hue[0.6497422006045631, 1, 0.10035695300906648`], 
           Hue[0.6498702084125652, 1, 0.10017971142875598`], 
           Hue[0.6499924815348365, 1, 0.10001041018253413`], 
           Hue[0.649995066268984, 1, 0.10000683131986839`], 
           Hue[0.6499995584935135, 1, 0.10000061131667352`], 
           Hue[0.6498987693663226, 1, 0.10014016549278415`], 
           Hue[0.6499963588136884, 1, 0.10000504164258525`], 
           Hue[0.6499999454587057, 1, 0.10000007551871525`], 
           Hue[0.6499872851621001, 1, 0.10001760516016903`], 
           Hue[0.6499994700011782, 1, 0.10000073384452254`], 
           Hue[0.6459417553415034, 1, 0.10561910798868754`], 
           Hue[0.6447602379007432, 1, 0.10725505521435556`], 
           Hue[0.6499848496426992, 1, 0.10002097741780114`], 
           Hue[0.6499997133311914, 1, 0.10000039692604273`], 
           Hue[0.6447602379004879, 1, 0.10725505521470911`], 
           Hue[0.6445860308483408, 1, 0.10749626497922055`], 
           Hue[0.6450472715451145, 1, 0.10685762401445689`], 
           Hue[0.6451837682394977, 1, 0.10666862859146471`], 
           Hue[0.6451837682394977, 1, 0.1066686285914647], 
           Hue[0.622715344004306, 1, 0.13777875445557644`], 
           Hue[0.6430994341870134, 1, 0.10955462958721218`], 
           Hue[0.6473532864649094, 1, 0.10366468027935616`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.649992836251731, 1, 0.10000991903606476`], 
           Hue[0.6499979189376313, 1, 0.1000028814709721], 
           Hue[0.6499979189376313, 1, 0.1000028814709721], 
           Hue[0.6499892906359471, 1, 0.10001482835022706`], 
           Hue[0.6499987880908246, 1, 0.10000167802808904`], 
           Hue[0.6499982837325233, 1, 0.10000237637035238`], 
           Hue[0.6499972833772172, 1, 0.1000037614776993], 
           Hue[0.649992836251731, 1, 0.10000991903606475`], 
           Hue[0.6499907772481441, 1, 0.1000127699641082], 
           Hue[0.6499851015179049, 1, 0.10002062866751626`], 
           Hue[0.6497831131736972, 1, 0.1003003048364193], 
           Hue[0.6498758963289265, 1, 0.10017183585225567`], 
           Hue[0.649849705083499, 1, 0.10020810065361672`], 
           Hue[0.6498638958591649, 1, 0.10018845188731017`], 
           Hue[0.6473532864649095, 1, 0.10366468027935608`], 
           Hue[0.647459617606195, 1, 0.1035174525452686], 
           Hue[0.6455633919912058, 1, 0.10614299570448421`], 
           Hue[0.6454878932078376, 1, 0.10624753248145562`], 
           Hue[0.6450803703104614, 1, 0.10681179495474584`], 
           Hue[0.6452024257204934, 1, 0.10664279515624006`], 
           Hue[0.6421328552372222, 1, 0.11089296967153851`], 
           Hue[0.6227153440039706, 1, 0.13777875445604082`], 
           Hue[0.6384789975532855, 1, 0.11595215723391242`], 
           Hue[0.6498629460993739, 1, 0.10018976693932855`], 
           Hue[0.649838667427071, 1, 0.10022338356251717`], 
           Hue[0.6498522655918395, 1, 0.10020455533437608`], 
           Hue[0.6450472715450636, 1, 0.10685762401452739`], 
           Hue[0.6450484170872487, 1, 0.10685603787919415`], 
           Hue[0.6446438544073366, 1, 0.10741620158984168`], 
           Hue[0.6447422602882784, 1, 0.10727994729315304`], 
           Hue[0.6265023909906814, 1, 0.13253515093597962`], 
           Hue[0.644586417592622, 1, 0.10749572948713883`], 
           Hue[0.6445864175924405, 1, 0.10749572948739003`], 
           Hue[0.6265023909903279, 1, 0.13253515093646911`], 
           Hue[0.6446438544073931, 1, 0.10741620158976331`], 
           Hue[0.644742260288343, 1, 0.10727994729306359`], 
           Hue[0.644742260288343, 1, 0.10727994729306359`], 
           Hue[0.6450484170872991, 1, 0.10685603787912441`], 
           Hue[0.6498629460993739, 1, 0.10018976693932846`], 
           Hue[0.6498386674270711, 1, 0.10022338356251707`], 
           Hue[0.6498522655918396, 1, 0.10020455533437599`], 
           Hue[0.6459425149453752, 1, 0.1056180562294804], 
           Hue[0.6455644065284449, 1, 0.1061415909606147], 
           Hue[0.6498758963289265, 1, 0.10017183585225571`], 
           Hue[0.649849705083499, 1, 0.10020810065361677`], 
           Hue[0.6498638958591649, 1, 0.10018845188731021`], 
           Hue[0.6499907772481441, 1, 0.1000127699641082], 
           Hue[0.6499902459174384, 1, 0.10001350565277761`], 
           Hue[0.6499987880908246, 1, 0.10000167802808904`], 
           Hue[0.6499971170968787, 1, 0.10000399171201411`], 
           Hue[0.6499941827230284, 1, 0.1000080546911914], 
           Hue[0.6499169408087975, 1, 0.10011500503397273`], 
           Hue[0.6499450533801044, 1, 0.10007607993524008`], 
           Hue[0.6498987693663225, 1, 0.10014016549278425`], 
           Hue[0.649998299585341, 1, 0.10000235442029706`], 
           Hue[0.649997310025984, 1, 0.10000372457940669`], 
           Hue[0.6499954637608208, 1, 0.10000628094655577`], 
           Hue[0.6499999143695201, 1, 0.1000001185652799], 
           Hue[0.6499998973914634, 1, 0.10000014207335849`], 
           Hue[0.6499995584935135, 1, 0.10000061131667352`], 
           Hue[0.6499998069333369, 1, 0.10000026732307205`], 
           Hue[0.6499998959071556, 1, 0.10000014412855386`], 
           Hue[0.6499996498839958, 1, 0.10000048477600589`], 
           Hue[0.6499989198255313, 1, 0.10000149562618747`], 
           Hue[0.6499924815348365, 1, 0.10001041018253413`], 
           Hue[0.649995066268984, 1, 0.10000683131986839`], 
           Hue[0.6499903637000147, 1, 0.10001334256921045`], 
           Hue[0.6499883785355535, 1, 0.10001609125846449`], 
           Hue[0.6499971445555819, 1, 0.1000039536922713], 
           Hue[0.6499872378397605, 1, 0.1000176706834086], 
           Hue[0.6499812127959619, 1, 0.10002601305174516`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499981583263428, 1, 0.10000255000967932`], 
           Hue[0.6499969194200786, 1, 0.10000426541835268`], 
           Hue[0.6499565454836217, 1, 0.10006016779190839`], 
           Hue[0.6499694960336535, 1, 0.10004223626109525`], 
           Hue[0.6499293875018999, 1, 0.10009777115121551`], 
           Hue[0.6499680543081146, 1, 0.10004423249645675`], 
           Hue[0.6499611431173056, 1, 0.10005380183757688`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499766495074196, 1, 0.10003233145126515`], 
           Hue[0.6499870926215222, 1, 0.10001787175481541`], 
           Hue[0.6498198123292014, 1, 0.10024949062110575`], 
           Hue[0.6498658977018641, 1, 0.10018568010511125`], 
           Hue[0.6499070733798012, 1, 0.10012866762796759`], 
           Hue[0.6498941642091621, 1, 0.10014654186423702`], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6498880939419249, 1, 0.1001549468496424], 
           Hue[0.6499317360308979, 1, 0.10009451934183362`], 
           Hue[0.6499513388525884, 1, 0.10006737697333921`], 
           Hue[0.6499329557399242, 1, 0.10009283051395124`], 
           Hue[0.6499430494131799, 1, 0.10007885465867403`], 
           Hue[0.6499074536869546, 1, 0.10012814104883216`], 
           Hue[0.6498945576128976, 1, 0.10014599715137257`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6495806066420229, 1, 0.1005806984956607], 
           Hue[0.6497210465128498, 1, 0.1003862432899004], 
           Hue[0.6454889217763359, 1, 0.10624610830968877`], 
           Hue[0.6450814653729393, 1, 0.10681027871439172`], 
           Hue[0.6342357357137165, 1, 0.12182744285793096`], 
           Hue[0.6451848600758338, 1, 0.10666711681807643`], 
           Hue[0.6499389913540884, 1, 0.10008447350972376`], 
           Hue[0.6499205322569598, 1, 0.10011003225959413`], 
           Hue[0.6499309840236278, 1, 0.10009556058266922`], 
           Hue[0.6131190636396185, 1, 0.15106591188360513`], 
           Hue[0.636329096752552, 1, 0.11892894295800491`], 
           Hue[0.6498945035414182, 1, 0.10014607201957486`], 
           Hue[0.6498817551107648, 1, 0.10016372369278723`], 
           Hue[0.6329576816102909, 1, 0.123597056231905], 
           Hue[0.6358099147458411, 1, 0.11964781035191228`], 
           Hue[0.6314188285392712, 1, 0.12572777586870135`], 
           Hue[0.6276615081560073, 1, 0.13093021947629757`], 
           Hue[0.6499579058346595, 1, 0.10005828422893298`], 
           Hue[0.6499502404150022, 1, 0.1000688978869202], 
           Hue[0.6123798420904445, 1, 0.15208944941323072`], 
           Hue[0.6189168169702053, 1, 0.1430382534258697], 
           Hue[0.613927475741499, 1, 0.14994657205023218`], 
           Hue[0.6498038432915917, 1, 0.10027160159625775`], 
           Hue[0.6499875143105937, 1, 0.10001728787763954`], 
           Hue[0.6499844331418096, 1, 0.10002155411134057`], 
           Hue[0.6445860308485625, 1, 0.10749626497891357`], 
           Hue[0.6499305639619214, 1, 0.10009614220657034`], 
           Hue[0.6499569735915823, 1, 0.10005957502703981`], 
           Hue[0.649997177936394, 1, 0.10000390747268527`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499978738704448, 1, 0.10000294387169176`], 
           Hue[0.6499990165514296, 1, 0.10000136169802062`], 
           Hue[0.6499997433419163, 1, 0.10000035537273123`], 
           Hue[0.6499848496426992, 1, 0.10002097741780114`], 
           Hue[0.008564162898874739, 1, 0.9881419282938658], 
           Hue[0.018968293162327066`, 1, 0.9737362094675472], 
           Hue[0.0021628179028306826`, 1, 0.997005329057619], 
           Hue[0.6499785002992392, 1, 0.100029768816438], 
           Hue[0.6499682293104806, 1, 0.10004399018548843`], 
           Hue[0.6499994806519499, 1, 0.10000071909730011`], 
           Hue[0.6499992967751281, 1, 0.10000097369597646`], 
           Hue[0.6499997221218345, 1, 0.10000038475438296`], 
           Hue[0.6499763120114476, 1, 0.10003279875338035`], 
           Hue[0.6496046189157263, 1, 0.10054745073207125`], 
           Hue[0.008564162897190086, 1, 0.9881419282961984], 
           Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
           Hue[0.6499990165514296, 1, 0.10000136169802062`], 
           Hue[0.6499682293104805, 1, 0.10004399018548858`], 
           Hue[0.6499569735915823, 1, 0.1000595750270399], 
           Hue[0.6499305639619215, 1, 0.10009614220657022`], 
           Hue[0.6493269366654801, 1, 0.10093193384779679`], 
           Hue[0.64507301626234, 1, 0.10682197748291383`], 
           Hue[0.64507301626234, 1, 0.10682197748291383`], 
           Hue[0.6123798420897152, 1, 0.15208944941424052`], 
           Hue[0.618916816969635, 1, 0.14303825342665927`], 
           Hue[0.6139274757407954, 1, 0.14994657205120632`], 
           Hue[0.6494794345021757, 1, 0.10072078299698756`], 
           Hue[0.649327839891267, 1, 0.10093068322747654`], 
           Hue[0.6498038432915922, 1, 0.10027160159625687`], 
           Hue[0.6314188285390578, 1, 0.12572777586899692`], 
           Hue[0.6276615081556767, 1, 0.13093021947675546`], 
           Hue[0.6499579058346595, 1, 0.10005828422893297`], 
           Hue[0.6499502404150022, 1, 0.10006889788692015`], 
           Hue[0.6363290967524697, 1, 0.1189289429581188], 
           Hue[0.6499389913540885, 1, 0.10008447350972371`], 
           Hue[0.6499205322569599, 1, 0.10011003225959408`], 
           Hue[0.6499309840236278, 1, 0.10009556058266918`], 
           Hue[0.6498945035414182, 1, 0.10014607201957479`], 
           Hue[0.6498817551107648, 1, 0.10016372369278714`], 
           Hue[0.6451848600758766, 1, 0.10666711681801709`], 
           Hue[0.6451848600758766, 1, 0.10666711681801709`], 
           Hue[0.6498948423987034, 1, 0.10014560283256446`], 
           Hue[0.6498821047507632, 1, 0.10016323957586633`], 
           Hue[0.6326369084383059, 1, 0.12404120370080722`], 
           Hue[0.6278460623886937, 1, 0.1306746828464241], 
           Hue[0.6343038838830548, 1, 0.12173308385423177`], 
           Hue[0.644391249173842, 1, 0.10776596268237253`], 
           Hue[0.6454889217763379, 1, 0.106246108309686], 
           Hue[0.6450814653729429, 1, 0.10681027871438688`], 
           Hue[0.6499513388525884, 1, 0.10006737697333923`], 
           Hue[0.6499329557399242, 1, 0.10009283051395125`], 
           Hue[0.6499430494131799, 1, 0.10007885465867404`], 
           Hue[0.6495806066420295, 1, 0.10058069849565142`], 
           Hue[0.649721046512853, 1, 0.10038624328989595`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6499070733798011, 1, 0.10012866762796763`], 
           Hue[0.6498941642091621, 1, 0.10014654186423706`], 
           Hue[0.6498880939419255, 1, 0.10015494684964163`], 
           Hue[0.6499317360308982, 1, 0.10009451934183332`], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499680543081146, 1, 0.10004423249645678`], 
           Hue[0.6499611431173056, 1, 0.10005380183757691`], 
           Hue[0.6498198123292014, 1, 0.10024949062110576`], 
           Hue[0.6498658977018641, 1, 0.10018568010511128`], 
           Hue[0.6499870926215222, 1, 0.1000178717548154], 
           Hue[0.6499969194200786, 1, 0.10000426541835268`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499145448836653, 1, 0.10011832246877124`], 
           Hue[0.6499924900042139, 1, 0.10001039845570384`], 
           Hue[0.6499902455567598, 1, 0.10001350615217874`], 
           Hue[0.6499943973499914, 1, 0.10000775751539649`], 
           Hue[0.6499384202733739, 1, 0.100085264236867], 
           Hue[0.6499448820990992, 1, 0.10007631709355508`], 
           Hue[0.6498985097083885, 1, 0.10014052501915438`], 
           Hue[0.6499505383206859, 1, 0.10006848540212712`], 
           Hue[0.6499565454836217, 1, 0.10006016779190842`], 
           Hue[0.6499694960336534, 1, 0.10004223626109526`], 
           Hue[0.6499981583263428, 1, 0.10000255000967932`], 
           Hue[0.6499989198255313, 1, 0.10000149562618747`], 
           Hue[0.6499996498839958, 1, 0.10000048477600589`], 
           Hue[0.649946398470897, 1, 0.10007421750183498`], 
           Hue[0.6499872378397605, 1, 0.1000176706834086], 
           Hue[0.6499812127959619, 1, 0.10002601305174515`], 
           Hue[0.6499807313906684, 1, 0.10002667961292078`], 
           Hue[0.649998744591033, 1, 0.10000173825856974`], 
           Hue[0.649998257978814, 1, 0.10000241202933446`], 
           Hue[0.6499991149582264, 1, 0.10000122544245589`], 
           Hue[0.6499883785355535, 1, 0.10001609125846449`], 
           Hue[0.6499955545015644, 1, 0.1000061553055262], 
           Hue[0.6499971445555819, 1, 0.10000395369227129`], 
           Hue[0.6499169012778275, 1, 0.10011505976916192`], 
           Hue[0.6499452554080251, 1, 0.10007580020427298`], 
           Hue[0.6499452554080251, 1, 0.10007580020427298`], 
           Hue[0.6499972861634967, 1, 0.10000375761977373`], 
           Hue[0.6499998069333369, 1, 0.10000026732307205`], 
           Hue[0.6499998959071556, 1, 0.10000014412855386`], 
           Hue[0.6499999143695201, 1, 0.1000001185652799], 
           Hue[0.6499998973914634, 1, 0.10000014207335849`], 
           Hue[0.649998299585341, 1, 0.10000235442029706`], 
           Hue[0.6499925368181951, 1, 0.10001033363634519`], 
           Hue[0.6499971170968787, 1, 0.10000399171201411`], 
           Hue[0.6499941827230284, 1, 0.1000080546911914], 
           Hue[0.6499998499361392, 1, 0.10000020778073027`], 
           Hue[0.6499997930401497, 1, 0.10000028655979275`], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.6499696557470173, 1, 0.10004201511951462`], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6498821047507631, 1, 0.1001632395758664], 
           Hue[0.6499504648283491, 1, 0.10006858716074747`], 
           Hue[0.6499993034614677, 1, 0.10000096443796776`], 
           Hue[0.6499996952446704, 1, 0.10000042196891794`], 
           Hue[0.6499997231111884, 1, 0.10000038338450845`], 
           Hue[0.6499764116330908, 1, 0.10003266081572036`], 
           Hue[0.6496050201873893, 1, 0.10054689512515333`], 
           Hue[0.6499835735373027, 1, 0.10002274433296544`], 
           Hue[0.6499763120114477, 1, 0.10003279875338018`], 
           Hue[0.6499996718109462, 1, 0.10000045441561291`], 
           Hue[0.6499997221218345, 1, 0.10000038475438296`], 
           Hue[0.0021628179019728133`, 1, 0.9970053290588069], 
           Hue[0.018968293159893457`, 1, 0.9737362094709167], 
           Hue[0.6499836181429695, 1, 0.10002268257127306`], 
           Hue[0.6499764116330907, 1, 0.10003266081572053`], 
           Hue[0.6499996739625998, 1, 0.1000004514364003], 
           Hue[0.6499997231111884, 1, 0.10000038338450845`], 
           Hue[0.6499994854782605, 1, 0.10000071241471627`], 
           Hue[0.6499993034614677, 1, 0.10000096443796776`], 
           Hue[0.6499581095157081, 1, 0.10005800220901966`], 
           Hue[0.6499504648283491, 1, 0.10006858716074744`], 
           Hue[0.6498945576128976, 1, 0.1001459971513726], 
           Hue[0.6499961977161761, 1, 0.10000526470067919`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.6499567540632241, 1, 0.10005987898938216`], 
           Hue[0.6499696557470173, 1, 0.1000420151195146], 
           Hue[0.6499998221998805, 1, 0.10000024618478089`], 
           Hue[0.6499852101793618, 1, 0.10002047821319134`], 
           Hue[0.6499979259072688, 1, 0.10000287182070478`], 
           Hue[0.6499979068548963, 1, 0.10000289820091286`], 
           Hue[0.6499298416416036, 1, 0.1000971423423951], 
           Hue[0.6497773350123875, 1, 0.10030830536746345`], 
           Hue[0.649832150775643, 1, 0.10023240661834047`], 
           Hue[0.649832150775643, 1, 0.10023240661834047`], 
           Hue[0.6497201201157683, 1, 0.10038752599355165`], 
           Hue[0.6499994159454975, 1, 0.1000008086908497], 
           Hue[0.6499994890716042, 1, 0.10000070743931735`], 
           Hue[0.6499995709517367, 1, 0.10000059406682617`], 
           Hue[0.6499836181429696, 1, 0.10002268257127296`], 
           Hue[0.649981784564363, 1, 0.10002522137242062`], 
           Hue[0.07116385446975892, 1, 0.9014654322726414], 
           Hue[0.07116385446975826, 1, 0.9014654322726423], 
           Hue[0.10275085519718585`, 1, 0.8577295851115889], 
           Hue[0.6450730162625566, 1, 0.10682197748261398`], 
           Hue[0.6450730162625566, 1, 0.10682197748261398`], 
           Hue[0.649649578370901, 1, 0.10048519917875254`], 
           Hue[0.6496211353704912, 1, 0.10052458179470464`], 
           Hue[0.6496149480434008, 1, 0.10053314886298349`], 
           Hue[0.6499997099087569, 1, 0.10000040166479822`], 
           Hue[0.649999693272125, 1, 0.10000042470013458`], 
           Hue[0.6499996487226951, 1, 0.10000048638396059`], 
           Hue[0.6499995670990851, 1, 0.10000059940126672`], 
           Hue[0.6499852320800056, 1, 0.1000204478892231], 
           Hue[0.6499835735373027, 1, 0.10002274433296553`], 
           Hue[0.6499817210220851, 1, 0.10002530935403613`], 
           Hue[0.6496523580230942, 1, 0.10048135042956187`], 
           Hue[0.6496214584224937, 1, 0.10052413449193183`], 
           Hue[0.6496153109565737, 1, 0.10053264636782111`], 
           Hue[0.6497703804347833, 1, 0.10031793478260782`], 
           Hue[0.649720148386843, 1, 0.10038748684898668`], 
           Hue[0.649969296003201, 1, 0.10004251322633716`], 
           Hue[0.6499715658257952, 1, 0.1000393703950529], 
           Hue[0.6499949427213864, 1, 0.10000700238577272`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6498226010526239, 1, 0.1002456293117515], 
           Hue[0.6499993787624871, 1, 0.1000008601750178], 
           Hue[0.6499997881961503, 1, 0.10000029326686882`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6498226656875892, 1, 0.10024553981718431`], 
           Hue[0.6499986816144642, 1, 0.10000182545689576`], 
           Hue[0.6499452554080252, 1, 0.10007580020427294`], 
           Hue[0.6499452554080252, 1, 0.10007580020427295`], 
           Hue[0.6483242391402425, 1, 0.1023202842673565], 
           Hue[0.6483242391402425, 1, 0.10232028426735655`], 
           Hue[0.6483242391402425, 1, 0.10232028426735651`], 
           Hue[0.6499906782378703, 1, 0.10001290705525658`], 
           Hue[0.644843834309606, 1, 0.1071393063405455], 
           Hue[0.6447609920664562, 1, 0.10725401098490685`], 
           Hue[0.6446427123917257, 1, 0.10741778284222608`], 
           Hue[0.6447410918958293, 1, 0.10728156506731333`], 
           Hue[0.6447410918958293, 1, 0.10728156506731332`], 
           Hue[0.6454301116847827, 1, 0.10632753766722401`], 
           Hue[0.6469166687904662, 1, 0.10426922782858536`], 
           Hue[0.6452016973298361, 1, 0.10664380369715003`], 
           Hue[0.6450803703104621, 1, 0.10681179495474484`], 
           Hue[0.6473254666988636, 1, 0.10370319995541974`], 
           Hue[0.6473386224356844, 1, 0.10368498431982166`], 
           Hue[0.6474431293251606, 1, 0.10354028247285457`], 
           Hue[0.648324239140247, 1, 0.10232028426735044`], 
           Hue[0.648324239140247, 1, 0.1023202842673504], 
           Hue[0.648324239140247, 1, 0.10232028426735042`], 
           Hue[0.6478300313592262, 1, 0.10300457196414826`], 
           Hue[0.6499979068548963, 1, 0.10000289820091286`], 
           Hue[0.6499768211371815, 1, 0.10003209381005644`], 
           Hue[0.6499892906359471, 1, 0.10001482835022706`], 
           Hue[0.6499998221998805, 1, 0.10000024618478089`], 
           Hue[0.6499893270949103, 1, 0.10001477786858572`], 
           Hue[0.6499965329720212, 1, 0.10000480050027838`], 
           Hue[0.6499942337059641, 1, 0.10000798409943434`], 
           Hue[0.6499906738504719, 1, 0.10001291313011582`], 
           Hue[0.6497970985365656, 1, 0.10028094048783229`], 
           Hue[0.6498802677343509, 1, 0.10016578313705254`], 
           Hue[0.6481847608283471, 1, 0.1025134080838272], 
           Hue[0.647847739448394, 1, 0.10298005307145443`], 
           Hue[0.6476673319658688, 1, 0.10322984804725865`], 
           Hue[0.6475036441269622, 1, 0.10345649274728327`], 
           Hue[0.6475036441269622, 1, 0.10345649274728327`], 
           Hue[0.6473254666988629, 1, 0.10370319995542056`], 
           Hue[0.6474431293251606, 1, 0.1035402824728547], 
           Hue[0.64691666879048, 1, 0.10426922782856618`], 
           Hue[0.643297066847292, 1, 0.10928098436528796`], 
           Hue[0.6450761923628352, 1, 0.10681757980530521`], 
           Hue[0.6425888456319467, 1, 0.11026159835576614`], 
           Hue[0.64355065154183, 1, 0.10892986709592774`], 
           Hue[0.6451837682394547, 1, 0.10666862859152434`], 
           Hue[0.6451837682394547, 1, 0.10666862859152436`], 
           Hue[0.6446427123916647, 1, 0.10741778284231042`], 
           Hue[0.6447410918957623, 1, 0.10728156506740608`], 
           Hue[0.6447410918957623, 1, 0.10728156506740608`], 
           Hue[0.6446754130693809, 1, 0.1073725049808572], 
           Hue[0.6448226855250837, 1, 0.10716858927296101`], 
           Hue[0.6448226855250837, 1, 0.10716858927296102`], 
           Hue[0.5959045810178848, 1, 0.17490134935985185`], 
           Hue[0.5991242399822707, 1, 0.17044336002454824`], 
           Hue[0.6448438343094491, 1, 0.1071393063407628], 
           Hue[0.5959045810185308, 1, 0.1749013493589574], 
           Hue[0.5991242399827919, 1, 0.17044336002382665`], 
           Hue[0.6448226855248735, 1, 0.10716858927325205`], 
           Hue[0.6425888456320292, 1, 0.11026159835565194`], 
           Hue[0.6435506515418995, 1, 0.10892986709583152`], 
           Hue[0.643297066847046, 1, 0.10928098436562861`], 
           Hue[0.6450761923626177, 1, 0.10681757980560624`], 
           Hue[0.6497970985365658, 1, 0.10028094048783215`], 
           Hue[0.649880267734351, 1, 0.10016578313705245`], 
           Hue[0.6499942337059641, 1, 0.10000798409943434`], 
           Hue[0.6499906738504719, 1, 0.10001291313011582`], 
           Hue[0.6499965329720212, 1, 0.10000480050027838`], 
           Hue[0.6499893270949103, 1, 0.10001477786858572`], 
           Hue[0.6499994700011782, 1, 0.10000073384452254`], 
           Hue[0.6499452847292683, 1, 0.10007575960562866`], 
           Hue[0.6499452847292683, 1, 0.10007575960562864`], 
           Hue[0.6499506956391089, 1, 0.10006826757661845`], 
           Hue[0.649997310025984, 1, 0.10000372457940669`], 
           Hue[0.6499963588136884, 1, 0.10000504164258524`], 
           Hue[0.6499996087792145, 1, 0.10000054169031843`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499313963608999, 1, 0.10009498965413857`], 
           Hue[0.6499418600005051, 1, 0.10008050153776214`], 
           Hue[0.6499820089674371, 1, 0.10002491066047176`], 
           Hue[0.6499885678296751, 1, 0.10001582915891155`], 
           Hue[0.649986680500004, 1, 0.10001844238460986`], 
           Hue[0.6499926102537842, 1, 0.10001023195629886`], 
           Hue[0.6499766758185227, 1, 0.100032295020507], 
           Hue[0.6499380881968964, 1, 0.10008572403506669`], 
           Hue[0.6355735873342747, 1, 0.11997503292177353`], 
           Hue[0.6383290297328666, 1, 0.11615980498526153`], 
           Hue[0.607541900540555, 1, 0.15878813771307765`], 
           Hue[0.566628613718335, 1, 0.2154373040823055], 
           Hue[0.6113350077370387, 1, 0.15353614313333103`], 
           Hue[0.6413526165411375, 1, 0.11197330017380966`], 
           Hue[0.649979910447695, 1, 0.10002781630319162`], 
           Hue[0.6499713297183559, 1, 0.1000396973130457], 
           Hue[0.649976389667182, 1, 0.1000326912300558], 
           Hue[0.6344958252613342, 1, 0.1214673188689219], 
           Hue[0.6497842792878252, 1, 0.10029869021685743`], 
           Hue[0.6499861817897983, 1, 0.10001913290643312`], 
           Hue[0.6499223977301634, 1, 0.1001074492966969], 
           Hue[0.6499968070349429, 1, 0.1000044210285406], 
           Hue[0.6499848535204814, 1, 0.10002097204856426`], 
           Hue[0.6499994103243372, 1, 0.1000008164739948], 
           Hue[0.6496495783709008, 1, 0.10048519917875282`], 
           Hue[0.6496211353704804, 1, 0.10052458179471949`], 
           Hue[0.6499986042640042, 1, 0.10000193255753263`], 
           Hue[0.6499223977301635, 1, 0.10010744929669671`], 
           Hue[0.0711638544660157, 1, 0.9014654322778244], 
           Hue[0.07116385446601503, 1, 0.9014654322778253], 
           Hue[0.6447609920662626, 1, 0.10725401098517487`], 
           Hue[0.6499931350584105, 1, 0.10000950530373938`], 
           Hue[0.6497842792878259, 1, 0.1002986902168565], 
           Hue[0.6499971946455725, 1, 0.10000388433689966`], 
           Hue[0.6499906782378703, 1, 0.10001290705525656`], 
           Hue[0.6499740052775556, 1, 0.10003599269261544`], 
           Hue[0.5666286137182638, 1, 0.215437304082404], 
           Hue[0.649979910447695, 1, 0.1000278163031916], 
           Hue[0.6499713297183559, 1, 0.10003969731304568`], 
           Hue[0.649976389667182, 1, 0.10003269123005579`], 
           Hue[0.649925810454061, 1, 0.10010272398668481`], 
           Hue[0.6424451989541748, 1, 0.11046049375575792`], 
           Hue[0.6413526165411441, 1, 0.11197330017380058`], 
           Hue[0.6150881106097981, 1, 0.14833953915566422`], 
           Hue[0.6228939004998529, 1, 0.13753152238481903`], 
           Hue[0.6427107986431155, 1, 0.11009274034030155`], 
           Hue[0.6355735873343954, 1, 0.11997503292160647`], 
           Hue[0.638329029732976, 1, 0.11615980498511017`], 
           Hue[0.649832150775643, 1, 0.1002324066183404], 
           Hue[0.6499766758185227, 1, 0.100032295020507], 
           Hue[0.6499822607431958, 1, 0.10002456204788279`], 
           Hue[0.649988567829675, 1, 0.10001582915891156`], 
           Hue[0.649986680500004, 1, 0.10001844238460987`], 
           Hue[0.6499915553675152, 1, 0.10001169256805592`], 
           Hue[0.6499418600005051, 1, 0.1000805015377621], 
           Hue[0.6499313963608999, 1, 0.10009498965413854`], 
           Hue[0.6499985526901774, 1, 0.10000200396744673`], 
           Hue[0.6499972861634967, 1, 0.10000375761977373`], 
           Hue[0.6499973394962008, 1, 0.10000368377449126`], 
           Hue[0.649998345225296, 1, 0.10000229122651329`], 
           Hue[0.6499993476936773, 1, 0.1000009031933699], 
           Hue[0.6499995636115868, 1, 0.10000060423011056`], 
           Hue[0.6499979259072688, 1, 0.10000287182070478`], 
           Hue[0.649997310025984, 1, 0.10000372457940668`], 
           Hue[0.649997310025984, 1, 0.10000372457940668`], 
           Hue[0.6499452847292683, 1, 0.10007575960562862`], 
           Hue[0.6499997355438514, 1, 0.10000036617005202`], 
           Hue[0.6499996943596676, 1, 0.10000042319430641`], 
           Hue[0.6499998525302062, 1, 0.10000020418894534`], 
           Hue[0.649999779338247, 1, 0.10000030553165791`], 
           Hue[0.6496214584225041, 1, 0.10052413449191748`], 
           Hue[0.10275085519977545`, 1, 0.8577295851080031], 
           Hue[0.6499996049868014, 1, 0.10000054694135192`], 
           Hue[0.6499996082984593, 1, 0.1000005423559795], 
           Hue[0.649832150775643, 1, 0.1002324066183404], 
           Hue[0.6499996709568588, 1, 0.10000045559819547`], 
           Hue[0.649999779338247, 1, 0.10000030553165791`], 
           Hue[0.6361358775823458, 1, 0.1191964771936751], 
           Hue[0.6361358775823456, 1, 0.11919647719367533`], 
           Hue[0.6499997114379519, 1, 0.10000039954745131`], 
           Hue[0.6499996514685767, 1, 0.10000048258197074`], 
           Hue[0.6498691588927477, 1, 0.1001811646100417], 
           Hue[0.6499509547899046, 1, 0.1000679087524398], 
           Hue[0.5936528925793111, 1, 0.17801907181326165`], 
           Hue[0.6448435305234992, 1, 0.10713972696746268`], 
           Hue[0.645136680417695, 1, 0.10673382711396075`], 
           Hue[0.6499996140825955, 1, 0.10000053434717537`], 
           Hue[0.6497253768389183, 1, 0.10038024745380555`], 
           Hue[0.6497432633695928, 1, 0.10035548148825621`], 
           Hue[0.6497376874239058, 1, 0.1003632020284381], 
           Hue[0.598578942259135, 1, 0.17119838764119769`], 
           Hue[0.5985789422591354, 1, 0.17119838764119716`], 
           Hue[0.6361358775824882, 1, 0.11919647719347792`], 
           Hue[0.6361358775824884, 1, 0.11919647719347777`], 
           Hue[0.6496475412721135, 1, 0.10048801977707356`], 
           Hue[0.6497575876165927, 1, 0.10033564791548695`], 
           Hue[0.6497176586044328, 1, 0.10039093424001616`], 
           Hue[0.6499102134211718, 1, 0.10012431987837749`], 
           Hue[0.6499402202393392, 1, 0.1000827719762997], 
           Hue[0.6499302912297339, 1, 0.10009651983575311`], 
           Hue[0.6499977899595798, 1, 0.10000306005596647`], 
           Hue[0.6499977899595798, 1, 0.10000306005596647`], 
           Hue[0.6499997881961503, 1, 0.10000029326686882`], 
           Hue[0.6499997070467911, 1, 0.10000040562752005`], 
           Hue[0.6499995636115868, 1, 0.10000060423011056`], 
           Hue[0.6449606118130902, 1, 0.10697761441264436`], 
           Hue[0.6449606118130902, 1, 0.10697761441264435`], 
           Hue[0.6446153322487039, 1, 0.10745569380948691`], 
           Hue[0.647503644126962, 1, 0.10345649274728334`], 
           Hue[0.647503644126962, 1, 0.10345649274728333`], 
           Hue[0.6499917724184623, 1, 0.10001139203597541`], 
           Hue[0.6499818441000457, 1, 0.10002513893839829`], 
           Hue[0.6499818441000457, 1, 0.10002513893839826`], 
           Hue[0.6499941069072821, 1, 0.10000815966684015`], 
           Hue[0.6499954637608208, 1, 0.10000628094655577`], 
           Hue[0.6425433794512151, 1, 0.1103245515290869], 
           Hue[0.6416068802400501, 1, 0.11162124274454605`], 
           Hue[0.033059327871870714`, 1, 0.9542255460235637], 
           Hue[0.05053038130689047, 1, 0.9300348566519978], 
           Hue[0.6499119444868918, 1, 0.10012192301814975`], 
           Hue[0.6498691588927481, 1, 0.1001811646100411], 
           Hue[0.649939804960482, 1, 0.10008334697779414`], 
           Hue[0.6499941069072821, 1, 0.10000815966684015`], 
           Hue[0.6499954637608208, 1, 0.10000628094655577`], 
           Hue[0.6499954637608208, 1, 0.10000628094655577`], 
           Hue[0.6499402202393393, 1, 0.10008277197629949`], 
           Hue[0.6499302912297341, 1, 0.10009651983575281`], 
           Hue[0.649757587616595, 1, 0.10033564791548386`], 
           Hue[0.649717658604436, 1, 0.1003909342400118], 
           Hue[0.6497282099863698, 1, 0.10037632463425723`], 
           Hue[0.6497476124961666, 1, 0.1003494596206924], 
           Hue[0.6497411112793049, 1, 0.10035846130557781`], 
           Hue[0.6499980775521905, 1, 0.10000266185081316`], 
           Hue[0.6499980775521905, 1, 0.10000266185081316`], 
           Hue[0.6499990826018167, 1, 0.1000012702436384], 
           Hue[0.6491923510353136, 1, 0.10111828318187353`], 
           Hue[0.6491923510353136, 1, 0.10111828318187355`], 
           Hue[0.6430994341869618, 1, 0.10955462958728375`], 
           Hue[0.6448435305234644, 1, 0.1071397269675108], 
           Hue[0.6465876268599798, 1, 0.1047248243477203], 
           Hue[0.6465876268599798, 1, 0.10472482434772026`], 
           Hue[0.5591705448255901, 1, 0.2257638610107214], 
           Hue[0.6051830845544243, 1, 0.1620541906169511], 
           Hue[0.6046239357498318, 1, 0.16282839665407917`], 
           Hue[0.6005020220421993, 1, 0.16853566178772414`], 
           Hue[0.6499949689168733, 1, 0.10000696611509867`], 
           Hue[0.6393277909144052, 1, 0.11477690488774678`], 
           Hue[0.639728945108811, 1, 0.11422146061856951`], 
           Hue[0.6411052738355187, 1, 0.11231577468928183`], 
           Hue[0.649968486457508, 1, 0.10004363413575815`], 
           Hue[0.6499767769522725, 1, 0.10003215498916111`], 
           Hue[0.649972676899105, 1, 0.10003783198585474`], 
           Hue[0.64998086534737, 1, 0.10002649413441077`], 
           Hue[0.6494791005751184, 1, 0.10072124535752844`], 
           Hue[0.6495813893887272, 1, 0.10057961469253159`], 
           Hue[0.6498553820677755, 1, 0.10020024021384928`], 
           Hue[0.6498884717547347, 1, 0.10015442372421353`], 
           Hue[0.6472339664152774, 1, 0.10382989265576983`], 
           Hue[0.6480087375848742, 1, 0.10275713257478956`], 
           Hue[0.6478300313592262, 1, 0.10300457196414828`], 
           Hue[0.6499948524777456, 1, 0.10000712733850615`], 
           Hue[0.6499975641411304, 1, 0.10000337272766563`], 
           Hue[0.643662976523736, 1, 0.1087743401979039], 
           Hue[0.6435436281016695, 1, 0.10893959185922679`], 
           Hue[0.6498946193265016, 1, 0.10014591170176698`], 
           Hue[0.6484137240052498, 1, 0.10219638214657721`], 
           Hue[0.649999065923293, 1, 0.10000129333697895`], 
           Hue[0.6499993569254062, 1, 0.10000089041097601`], 
           Hue[0.6499995531364383, 1, 0.10000061873416236`], 
           Hue[0.6499845305213169, 1, 0.10002141927817669`], 
           Hue[0.6499987610373165, 1, 0.10000171548679268`], 
           Hue[0.6499982793327067, 1, 0.10000238246240618`], 
           Hue[0.644297740872205, 1, 0.10789543571540844`], 
           Hue[0.6437766022656166, 1, 0.10861701224760785`], 
           Hue[0.6499998925666856, 1, 0.1000001487538201], 
           Hue[0.6499720083241632, 1, 0.10003875770500484`], 
           Hue[0.6499989806170189, 1, 0.10000141145335847`], 
           Hue[0.6499979189376313, 1, 0.1000028814709721], 
           Hue[0.6490732055840214, 1, 0.1012832538067396], 
           Hue[0.6487943291253612, 1, 0.10166939044180762`], 
           Hue[0.6486615686527496, 1, 0.1018532126346544], 
           Hue[0.6486721458807169, 1, 0.10183856724208436`], 
           Hue[0.6488754715936946, 1, 0.10155703933180743`], 
           Hue[0.6492211282544369, 1, 0.10107843780154896`], 
           Hue[0.6495635854272818, 1, 0.10060426633145604`], 
           Hue[0.6498036739551811, 1, 0.10027183606205689`], 
           Hue[0.6492205124027053, 1, 0.10107929051933126`], 
           Hue[0.6488751499378582, 1, 0.10155748470142709`], 
           Hue[0.6486721421475297, 1, 0.10183857241111285`], 
           Hue[0.6494481187205927, 1, 0.10076414330994858`], 
           Hue[0.64975855562808, 1, 0.10033430759188922`], 
           Hue[0.6499382721143278, 1, 0.10008546938016159`], 
           Hue[0.6497438699910106, 1, 0.10035464155090847`], 
           Hue[0.6493221359730589, 1, 0.10093858096038001`], 
           Hue[0.6487286338295368, 1, 0.1017603531591029], 
           Hue[0.6481845887416958, 1, 0.10251364635765203`], 
           Hue[0.6477867920179302, 1, 0.1030644418213274], 
           Hue[0.6474596176061952, 1, 0.10351745254526823`], 
           Hue[0.6472340635887639, 1, 0.10382975810786547`], 
           Hue[0.6471954778691708, 1, 0.10388318448884046`], 
           Hue[0.6474440549357112, 1, 0.1035390008582461], 
           Hue[0.6479727326168359, 1, 0.10280698560745806`], 
           Hue[0.6486308130734021, 1, 0.10189579728298169`], 
           Hue[0.6492993957289775, 1, 0.10097006745218497`], 
           Hue[0.6492984661033571, 1, 0.10097135462612099`], 
           Hue[0.6486298611368391, 1, 0.10189711534899212`], 
           Hue[0.6479722666001381, 1, 0.10280763086134728`], 
           Hue[0.6474700106798329, 1, 0.10350306213561597`], 
           Hue[0.6471976417124167, 1, 0.10388018839819235`], 
           Hue[0.6472266389834024, 1, 0.10384003833067365`], 
           Hue[0.6474600972735775, 1, 0.10351678839043123`], 
           Hue[0.647787115327827, 1, 0.10306399416147033`], 
           Hue[0.6481847142239625, 1, 0.102513472612975], 
           Hue[0.6487288669092454, 1, 0.10176003043335265`], 
           Hue[0.6493225788760636, 1, 0.10093796771006586`], 
           Hue[0.6497492556366449, 1, 0.10034718450310709`], 
           Hue[0.6499384202733739, 1, 0.100085264236867], 
           Hue[0.6499907772481441, 1, 0.1000127699641082], 
           Hue[0.6499169408087975, 1, 0.10011500503397273`], 
           Hue[0.6496669893384682, 1, 0.10046109168519789`], 
           Hue[0.6491243836319389, 1, 0.10121239189423845`], 
           Hue[0.6483881105564229, 1, 0.10223184692187601`], 
           Hue[0.6476673319658686, 1, 0.10322984804725902`], 
           Hue[0.6470649192956847, 1, 0.10406395789828284`], 
           Hue[0.646492840332535, 1, 0.10485606723187464`], 
           Hue[0.6459052314226442, 1, 0.10566967956864651`], 
           Hue[0.6453175862656999, 1, 0.10648334209364638`], 
           Hue[0.6448171573227068, 1, 0.10717624370702135`], 
           Hue[0.6445346715615721, 1, 0.10756737783782327`], 
           Hue[0.6445187656805075, 1, 0.10758940136545116`], 
           Hue[0.6446754130693914, 1, 0.10737250498084282`], 
           Hue[0.6448217876435393, 1, 0.10716983249356107`], 
           Hue[0.6448213068073135, 1, 0.10717049826679662`], 
           Hue[0.6446747005057164, 1, 0.1073734916074697], 
           Hue[0.6445188584205228, 1, 0.1075892729561992], 
           Hue[0.6445356096358542, 1, 0.10756607896574033`], 
           Hue[0.6448183521045389, 1, 0.10717458939371549`], 
           Hue[0.6453186380742251, 1, 0.10648188574338074`], 
           Hue[0.6459060748044555, 1, 0.10566851180921547`], 
           Hue[0.646493455942218, 1, 0.10485521484923671`], 
           Hue[0.647065445798343, 1, 0.10406322889460198`], 
           Hue[0.6476782205548365, 1, 0.10321477153945717`], 
           Hue[0.6483883164107922, 1, 0.10223156189274935`], 
           Hue[0.6491243444061467, 1, 0.10121244620687372`], 
           Hue[0.6496669043016357, 1, 0.10046120942850455`], 
           Hue[0.6499169012778275, 1, 0.10011505976916191`], 
           Hue[0.6499872761827474, 1, 0.1000176175931189], 
           Hue[0.6499506956391089, 1, 0.10006826757661845`], 
           Hue[0.6497831131736972, 1, 0.1003003048364193], 
           Hue[0.6493577841898452, 1, 0.10088922189098354`], 
           Hue[0.6486206497020778, 1, 0.1019098696432769], 
           Hue[0.6476640151146004, 1, 0.10323444061055342`], 
           Hue[0.6466285838488163, 1, 0.10466811467086985`], 
           Hue[0.645563391991172, 1, 0.1061429957045311], 
           Hue[0.6443899338329055, 1, 0.10776778392366933`], 
           Hue[0.6427084326690079, 1, 0.11009601630445065`], 
           Hue[0.6393231015822478, 1, 0.11478339780919544`], 
           Hue[0.6320807432698805, 1, 0.1248112785493963], 
           Hue[0.6197500814765424, 1, 0.14188450257094132`], 
           Hue[0.6042150040102856, 1, 0.1633946098319123], 
           Hue[0.595075849977109, 1, 0.1760488231086183], 
           Hue[0.5950760330681816, 1, 0.17604856959790252`], 
           Hue[0.6051860768200773, 1, 0.162050047479893], 
           Hue[0.6197571630575969, 1, 0.14187469730486596`], 
           Hue[0.6320881314564221, 1, 0.12480104875264642`], 
           Hue[0.6393277909144098, 1, 0.11477690488774024`], 
           Hue[0.642710798643102, 1, 0.1100927403403204], 
           Hue[0.6443912491738061, 1, 0.10776596268242239`], 
           Hue[0.6455644065284103, 1, 0.10614159096066272`], 
           Hue[0.6466294094583147, 1, 0.10466697151925652`], 
           Hue[0.64766440059411, 1, 0.10323390686969391`], 
           Hue[0.6486204310728412, 1, 0.10191017236068144`], 
           Hue[0.6493571286681643, 1, 0.10089012953638786`], 
           Hue[0.6497827013349246, 1, 0.10030087507471992`], 
           Hue[0.6499505383206859, 1, 0.10006848540212712`], 
           Hue[0.649992836251731, 1, 0.10000991903606476`], 
           Hue[0.6499987880908246, 1, 0.10000167802808904`], 
           Hue[0.6497848661512465, 1, 0.10029787763673556`], 
           Hue[0.6493623255583317, 1, 0.10088293384231], 
           Hue[0.6485080528944187, 1, 0.10206577291542022`], 
           Hue[0.6471334129224147, 1, 0.1039691205689644], 
           Hue[0.4134396293934205, 1, 0.42754512853218696`], 
           Hue[0.36992357537943527`, 1, 0.48779812639770503`], 
           Hue[0.560364425850268, 1, 0.22411079497655204`], 
           Hue[0.6471333502188614, 1, 0.10396920738926879`], 
           Hue[0.6485074236435838, 1, 0.10206664418580709`], 
           Hue[0.649993719165779, 1, 0.10000869653969073`], 
           Hue[0.6499645347886048, 1, 0.1000491056773164], 
           Hue[0.6498452129760711, 1, 0.10021432049467077`], 
           Hue[0.6494626278600213, 1, 0.10074405373227828`], 
           Hue[0.42072780205667315`, 1, 0.41745381253691416`], 
           Hue[0.2794714163724129, 1, 0.6130395773305052], 
           Hue[0.27950127825763316`, 1, 0.6129982301048157], 
           Hue[0.4207460109307008, 1, 0.4174286002497989], 
           Hue[0.5442403811400227, 1, 0.24643639534458395`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.6498321507756425, 1, 0.10023240661834114`], 
           Hue[0.649132833376689, 1, 0.10120069224766141`], 
           Hue[0.6465876268599643, 1, 0.10472482434774179`], 
           Hue[0.6363436379563803, 1, 0.11890880898347347`], 
           Hue[0.5985789422584301, 1, 0.17119838764217368`], 
           Hue[0.5054107485799124, 1, 0.3002005019662751], 
           Hue[0.35056984491302934`, 1, 0.5145955993511901], 
           Hue[0.1920257274160761, 1, 0.7341182235777408], 
           Hue[0.07116385446886986, 1, 0.9014654322738725], 
           Hue[0.07116385446585693, 1, 0.9014654322780442], 
           Hue[0.19202572741530333`, 1, 0.7341182235788108], 
           Hue[0.35056984491472737`, 1, 0.514595599348839], 
           Hue[0.5054107485816628, 1, 0.3002005019638515], 
           Hue[0.5998737256253059, 1, 0.16940561067265333`], 
           Hue[0.6361358775824969, 1, 0.11919647719346589`], 
           Hue[0.6465876268599808, 1, 0.10472482434771889`], 
           Hue[0.6491923510353136, 1, 0.10111828318187349`], 
           Hue[0.6498321507756426, 1, 0.10023240661834108`], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6498549379809121, 1, 0.10020085510335255`], 
           Hue[0.6494782446417727, 1, 0.1007224304960071], 
           Hue[0.6484645052704198, 1, 0.10212606962557269`], 
           Hue[0.6459417553415037, 1, 0.10561910798868726`], 
           Hue[0.6384789975532839, 1, 0.11595215723391462`], 
           Hue[0.6131190636395967, 1, 0.1510659118836354], 
           Hue[0.5442403811387878, 1, 0.24643639534629383`], 
           Hue[0.4207460109293239, 1, 0.41742860025170536`], 
           Hue[0.27950127825713017`, 1, 0.6129982301055121], 
           Hue[0.1666401527254356, 1, 0.7692674808417046], 
           Hue[0.10995731692870991`, 1, 0.8477514073294786], 
           Hue[0.10993697241483547`, 1, 0.8477795766563816], 
           Hue[0.16660070648733238`, 1, 0.7693220987098475], 
           Hue[0.27947141637245565`, 1, 0.613039577330446], 
           Hue[0.4207278020584586, 1, 0.4174538125344419], 
           Hue[0.5438542150957212, 1, 0.24697108679053995`], 
           Hue[0.6131150084109688, 1, 0.15107152681558167`], 
           Hue[0.63847840811195, 1, 0.11595297338345392`], 
           Hue[0.6459425149453757, 1, 0.10561805622947988`], 
           Hue[0.6484656021364827, 1, 0.10212455088794703`], 
           Hue[0.6494626278600188, 1, 0.10074405373228157`], 
           Hue[0.6498553820677755, 1, 0.1002002402138493], 
           Hue[0.649968486457508, 1, 0.10004363413575816`], 
           Hue[0.6499947516409308, 1, 0.10000726695871127`], 
           Hue[0.6499993476936773, 1, 0.1000009031933699], 
           Hue[0.6499903637000147, 1, 0.10001334256921046`], 
           Hue[0.6499461593618887, 1, 0.1000745485758465], 
           Hue[0.6497870627427598, 1, 0.1002948362023327], 
           Hue[0.6493634059128109, 1, 0.10088143796687715`], 
           Hue[0.648507423643595, 1, 0.10206664418579148`], 
           Hue[0.6471333502188961, 1, 0.10396920738922087`], 
           Hue[0.6452024257204935, 1, 0.1066427951562399], 
           Hue[0.6421328552372216, 1, 0.11089296967153926`], 
           Hue[0.6342357357137098, 1, 0.12182744285794023`], 
           Hue[0.6113350077370074, 1, 0.15353614313337435`], 
           Hue[0.560364425850219, 1, 0.22411079497661998`], 
           Hue[0.48758898573082615`, 1, 0.3248767889880869], 
           Hue[0.4148630973140133, 1, 0.4255741729498278], 
           Hue[0.37117736989834854`, 1, 0.4860621032176713], 
           Hue[0.3699235753804618, 1, 0.4877981263962837], 
           Hue[0.41343962939488754`, 1, 0.4275451285301558], 
           Hue[0.48756298968034234`, 1, 0.324912783519526], 
           Hue[0.5613439013174827, 1, 0.22275459817579318`], 
           Hue[0.6113184040198557, 1, 0.15355913289558448`], 
           Hue[0.6343038838830553, 1, 0.12173308385423123`], 
           Hue[0.642130743574499, 1, 0.11089589351223221`], 
           Hue[0.6452016973298363, 1, 0.10664380369714979`], 
           Hue[0.6471334129224495, 1, 0.10396912056891615`], 
           Hue[0.64850805289443, 1, 0.10206577291540458`], 
           Hue[0.6493623255583336, 1, 0.1008829338423074], 
           Hue[0.6497848661512468, 1, 0.1002978776367353], 
           Hue[0.649946398470897, 1, 0.100074217501835], 
           Hue[0.6499902459174384, 1, 0.10001350565277761`], 
           Hue[0.6499988168962403, 1, 0.10000163814366736`], 
           Hue[0.649992836251731, 1, 0.10000991903606475`], 
           Hue[0.648620431072842, 1, 0.10191017236068038`], 
           Hue[0.6476644005941145, 1, 0.1032339068696878], 
           Hue[0.6466294094583313, 1, 0.10466697151923365`], 
           Hue[0.639183848053694, 1, 0.11497621038719294`], 
           Hue[0.593969696312709, 1, 0.17758042049009526`], 
           Hue[0.6042150040106946, 1, 0.16339460983134596`], 
           Hue[0.6466285838488328, 1, 0.10466811467084695`], 
           Hue[0.6476640151146048, 1, 0.10323444061054728`], 
           Hue[0.6486206497020786, 1, 0.10190986964327584`], 
           Hue[0.6493577841898455, 1, 0.10088922189098325`], 
           Hue[0.649124344406147, 1, 0.1012124462068735], 
           Hue[0.6483883164107923, 1, 0.10223156189274908`], 
           Hue[0.6476782205548369, 1, 0.10321477153945663`], 
           Hue[0.6470654457983444, 1, 0.10406322889460017`], 
           Hue[0.6464934559422207, 1, 0.10485521484923278`], 
           Hue[0.6459060748044588, 1, 0.10566851180921094`], 
           Hue[0.6439828956080353, 1, 0.10833137531195104`], 
           Hue[0.6459052314226476, 1, 0.10566967956864184`], 
           Hue[0.6464928403325377, 1, 0.10485606723187091`], 
           Hue[0.6470649192956857, 1, 0.10406395789828136`], 
           Hue[0.6483881105564231, 1, 0.10223184692187579`], 
           Hue[0.6491243836319391, 1, 0.10121239189423821`], 
           Hue[0.6496669893384683, 1, 0.10046109168519775`], 
           Hue[0.6499907772481441, 1, 0.1000127699641082], 
           Hue[0.6497492556366449, 1, 0.10034718450310712`], 
           Hue[0.6493225788760636, 1, 0.10093796771006587`], 
           Hue[0.6487288669092454, 1, 0.10176003043335262`], 
           Hue[0.6481847142239626, 1, 0.10251347261297492`], 
           Hue[0.6477871153278271, 1, 0.10306399416147023`], 
           Hue[0.6479722666001457, 1, 0.10280763086133675`], 
           Hue[0.6486298611368615, 1, 0.10189711534896101`], 
           Hue[0.64863081307338, 1, 0.10189579728301236`], 
           Hue[0.6479727326168283, 1, 0.10280698560746845`], 
           Hue[0.64744405493571, 1, 0.10353900085824778`], 
           Hue[0.647195477869171, 1, 0.10388318448884022`], 
           Hue[0.647234063588764, 1, 0.10382975810786524`], 
           Hue[0.64778679201793, 1, 0.10306444182132772`], 
           Hue[0.6481845887416956, 1, 0.10251364635765228`], 
           Hue[0.6487286338295367, 1, 0.10176035315910302`], 
           Hue[0.6493221359730589, 1, 0.10093858096038005`], 
           Hue[0.649985101517905, 1, 0.10002062866751625`], 
           Hue[0.6499293875019, 1, 0.1000977711512155], 
           Hue[0.64975855562808, 1, 0.10033430759188924`], 
           Hue[0.6494481187205927, 1, 0.10076414330994854`], 
           Hue[0.6490820712669709, 1, 0.10127097824573265`], 
           Hue[0.6487973060787215, 1, 0.10166526850638562`], 
           Hue[0.6486665440965278, 1, 0.10184632355865385`], 
           Hue[0.6486721421475294, 1, 0.10183857241111316`], 
           Hue[0.648875149937858, 1, 0.10155748470142736`], 
           Hue[0.6492205124027052, 1, 0.10107929051933136`], 
           Hue[0.6495955370911407, 1, 0.10056002556611295`], 
           Hue[0.6498247725796036, 1, 0.10024262258208744`], 
           Hue[0.6499395617051161, 1, 0.10008368379291611`], 
           Hue[0.649939804960482, 1, 0.10008334697779414`], 
           Hue[0.6498036739551808, 1, 0.10027183606205746`], 
           Hue[0.6495635854272817, 1, 0.10060426633145621`], 
           Hue[0.649221128254437, 1, 0.10107843780154885`], 
           Hue[0.6488754715936949, 1, 0.10155703933180717`], 
           Hue[0.6486721458807171, 1, 0.10183856724208408`], 
           Hue[0.6486615686527497, 1, 0.10185321263465427`], 
           Hue[0.6487943291253612, 1, 0.10166939044180771`], 
           Hue[0.6490732055840213, 1, 0.1012832538067398], 
           Hue[0.6494608701931662, 1, 0.10074648742484674`], 
           Hue[0.6497686522347683, 1, 0.10032032767493616`], 
           Hue[0.6499979189376313, 1, 0.1000028814709721], 
           Hue[0.6499989806170189, 1, 0.10000141145335847`], 
           Hue[0.6499936916833658, 1, 0.10000873459226267`], 
           Hue[0.6499720083241632, 1, 0.10003875770500482`], 
           Hue[0.6499210378689576, 1, 0.10010933218144337`], 
           Hue[0.6498289592233316, 1, 0.10023682569077165`], 
           Hue[0.6497500661969323, 1, 0.100346062188863], 
           Hue[0.6497201201157683, 1, 0.10038752599355166`], 
           Hue[0.6497442349944514, 1, 0.10035413616152887`], 
           Hue[0.6498175387315116, 1, 0.10025263867944555`], 
           Hue[0.6499045423782822, 1, 0.10013217209160924`], 
           Hue[0.6499635376940699, 1, 0.10005048626974944`], 
           Hue[0.6499895375823748, 1, 0.10001448642440418`], 
           Hue[0.6499978738704448, 1, 0.10000294387169176`], 
           Hue[0.6499996049868014, 1, 0.10000054694135192`], 
           Hue[0.6499996082984593, 1, 0.1000005423559795], 
           Hue[0.6499977154256198, 1, 0.10000316325683417`], 
           Hue[0.6499887115763905, 1, 0.10001563012499778`], 
           Hue[0.6499637194211009, 1, 0.10005023464770653`], 
           Hue[0.649904864696231, 1, 0.10013172580521862`], 
           Hue[0.6498178986902057, 1, 0.10025214027509985`], 
           Hue[0.6497444578897739, 1, 0.1003538275372362], 
           Hue[0.649720148386843, 1, 0.1003874868489867], 
           Hue[0.6497498661728607, 1, 0.10034633914526989`], 
           Hue[0.6498285638060286, 1, 0.10023737319165268`], 
           Hue[0.649917969520653, 1, 0.10011358066371126`], 
           Hue[0.6499735114284139, 1, 0.10003667648373475`], 
           Hue[0.6499943973499914, 1, 0.10000775751539649`], 
           Hue[0.6499991149582264, 1, 0.10000122544245589`], 
           Hue[0.6499998925666856, 1, 0.1000001487538201], 
           Hue[0.6499993476880973, 1, 0.10000090320109607`], 
           Hue[0.6499796318088381, 1, 0.10002820211083958`], 
           Hue[0.6499326287044422, 1, 0.10009328333231075`], 
           Hue[0.6498492997424695, 1, 0.10020866189504221`], 
           Hue[0.6497585093987792, 1, 0.10033437160169031`], 
           Hue[0.6497220759135403, 1, 0.10038481796586742`], 
           Hue[0.6497395116100092, 1, 0.10036067623229504`], 
           Hue[0.649807523533853, 1, 0.10026650587620367`], 
           Hue[0.6498948423987034, 1, 0.10014560283256452`], 
           Hue[0.6499875975622534, 1, 0.1000171726061106], 
           Hue[0.6499971946455725, 1, 0.10000388433689966`], 
           Hue[0.6499994854782605, 1, 0.10000071241471627`], 
           Hue[0.6499996718109462, 1, 0.10000045441561291`], 
           Hue[0.6499983476490149, 1, 0.10000228787059483`], 
           Hue[0.649992139261425, 1, 0.10001088409956545`], 
           Hue[0.6499711752825617, 1, 0.10003991114722234`], 
           Hue[0.6499202363144329, 1, 0.10011044202616999`], 
           Hue[0.649752335400284, 1, 0.10034292021499139`], 
           Hue[0.6497216053983531, 1, 0.10038546944843423`], 
           Hue[0.6497446269774029, 1, 0.10035359341590382`], 
           Hue[0.6498180333025885, 1, 0.10025195388872375`], 
           Hue[0.6499074536869546, 1, 0.10012814104883222`], 
           Hue[0.6499685517490378, 1, 0.10004354373210154`], 
           Hue[0.6499926102537842, 1, 0.10001023195629886`], 
           Hue[0.6499987684026548, 1, 0.10000170528863186`], 
           Hue[0.6499998525302062, 1, 0.10000020418894534`], 
           Hue[0.6492162512642067, 1, 0.1010851905572524], 
           Hue[0.6488750409140394, 1, 0.10155763565748406`], 
           Hue[0.6486943253197311, 1, 0.10180785724960313`], 
           Hue[0.6486561461999452, 1, 0.10186072064622981`], 
           Hue[0.6488059954277985, 1, 0.10165323709997136`], 
           Hue[0.6491243397305977, 1, 0.10121245268071086`], 
           Hue[0.6497589618188889, 1, 0.10033374517384615`], 
           Hue[0.6493814166270159, 1, 0.10085650005490117`], 
           Hue[0.6487415025304525, 1, 0.10174253495783511`], 
           Hue[0.6487385095926334, 1, 0.10174667902558458`], 
           Hue[0.6489651538469169, 1, 0.10143286390426902`], 
           Hue[0.6493262593973558, 1, 0.10093287160366125`], 
           Hue[0.6496859288220751, 1, 0.10043486778481912`], 
           Hue[0.6498879983365086, 1, 0.10015507922637275`], 
           Hue[0.6499728188455073, 1, 0.10003763544468221`], 
           Hue[0.6484785424654154, 1, 0.10210663350942493`], 
           Hue[0.6472376528774046, 1, 0.10382478832359364`], 
           Hue[0.6483004248350253, 1, 0.10235325792073424`], 
           Hue[0.6485590288669325, 1, 0.10199519079963201`], 
           Hue[0.6499925368181951, 1, 0.1000103336363452], 
           Hue[0.649956754063224, 1, 0.10005987898938219`], 
           Hue[0.6498201909540227, 1, 0.10024896637135326`], 
           Hue[0.6494380510073331, 1, 0.1007780832206157], 
           Hue[0.6486312945647095, 1, 0.10189513060270997`], 
           Hue[0.6472945453822478, 1, 0.10374601408611843`], 
           Hue[0.6454301116847382, 1, 0.10632753766728567`], 
           Hue[0.6425869541066359, 1, 0.11026421739081178`], 
           Hue[0.6355677813921327, 1, 0.11998307191858565`], 
           Hue[0.6150728538407967, 1, 0.14836066391274305`], 
           Hue[0.49721716070329236`, 1, 0.3115454697954414], 
           Hue[0.4218615510022992, 1, 0.41588400630450884`], 
           Hue[0.3732101372974441, 1, 0.48324750220353896`], 
           Hue[0.3699389649357174, 1, 0.48777681778131443`], 
           Hue[0.4092648191988564, 1, 0.43332563495542964`], 
           Hue[0.4799251869009553, 1, 0.3354882027525234], 
           Hue[0.5547703620061858, 1, 0.23185642183758892`], 
           Hue[0.6075419005407393, 1, 0.15878813771282255`], 
           Hue[0.6416071963746115, 1, 0.11162080501976875`], 
           Hue[0.6449363081981523, 1, 0.10701126557178922`], 
           Hue[0.6469167021582444, 1, 0.10426918162704622`], 
           Hue[0.6483449140191484, 1, 0.10229165751194842`], 
           Hue[0.64926118126401, 1, 0.1010229797882938], 
           Hue[0.6497487056715416, 1, 0.10034794599325009`], 
           Hue[0.6499334733653315, 1, 0.10009211380184876`], 
           Hue[0.6499871546152928, 1, 0.10001778591728701`], 
           Hue[0.6499982837325233, 1, 0.10000237637035238`], 
           Hue[0.6499821959348161, 1, 0.10002465178256237`], 
           Hue[0.6499097362338683, 1, 0.10012498059925928`], 
           Hue[0.649644480283586, 1, 0.10049225806888096`], 
           Hue[0.6488721916036004, 1, 0.10156158085655329`], 
           Hue[0.6468897902012477, 1, 0.10430644433673392`], 
           Hue[0.6412672325871528, 1, 0.11209152411009617`], 
           Hue[0.622513680397445, 1, 0.1380579809881531], 
           Hue[0.5682104334557424, 1, 0.2132470921382028], 
           Hue[0.31803818591230487`, 1, 0.5596394348906548], 
           Hue[0.12317793669702404`, 1, 0.8294459338041205], 
           Hue[0.10551553715041861`, 1, 0.8539015639455743], 
           Hue[0.1447215641964955, 1, 0.7996162957279294], 
           Hue[0.23867664284349838`, 1, 0.6695246483705407], 
           Hue[0.3752505842358355, 1, 0.48042226798115084`], 
           Hue[0.5105339839090244, 1, 0.2931067915105816], 
           Hue[0.6333039763672068, 1, 0.12311757118386749`], 
           Hue[0.6492133707832681, 1, 0.10108917891547486`], 
           Hue[0.3180381859125545, 1, 0.5596394348903092], 
           Hue[0.3732101372984604, 1, 0.48324750220213175`], 
           Hue[0.6486312945647198, 1, 0.10189513060269574`], 
           Hue[0.6499544789815872, 1, 0.10006302910241772`], 
           Hue[0.6497967031430824, 1, 0.10028148795573212`], 
           Hue[0.6493843083159343, 1, 0.10085249617793722`], 
           Hue[0.6486670765987007, 1, 0.10184558624795291`], 
           Hue[0.6477258602117323, 1, 0.10314880893760145`], 
           Hue[0.6466982385822283, 1, 0.10457166965537625`], 
           Hue[0.6456433109470764, 1, 0.10603233868866352`], 
           Hue[0.6444863018191712, 1, 0.10763435132730144`], 
           Hue[0.6428823803202537, 1, 0.10985516571041797`], 
           Hue[0.6397468996933413, 1, 0.11419660042460432`], 
           Hue[0.6330024607854741, 1, 0.12353505429703592`], 
           Hue[0.6211966685594903, 1, 0.13988153584070584`], 
           Hue[0.6066857938393038, 1, 0.15997351622250255`], 
           Hue[0.5959049495707341, 1, 0.17490083905590664`], 
           Hue[0.5947857583630093, 1, 0.17645048842044875`], 
           Hue[0.6039331393082432, 1, 0.16378488403474026`], 
           Hue[0.6189100178908061, 1, 0.14304766753580686`], 
           Hue[0.6314113814489777, 1, 0.12573808722449245`], 
           Hue[0.6389584142500591, 1, 0.1152883494999182], 
           Hue[0.6442963774518267, 1, 0.10789732352823997`], 
           Hue[0.6454878932078376, 1, 0.10624753248145569`], 
           Hue[0.6465464412567902, 1, 0.10478185056752126`], 
           Hue[0.6475834488846897, 1, 0.10334599385196813`], 
           Hue[0.6485590288669337, 1, 0.10199519079963026`], 
           Hue[0.6493199214653448, 1, 0.10094164720183028`], 
           Hue[0.6497651749073808, 1, 0.10032514243593434`], 
           Hue[0.6499450533801044, 1, 0.10007607993524002`], 
           Hue[0.6499916808511504, 1, 0.10001151882148406`], 
           Hue[0.6492714389145247, 1, 0.10100877688758128`], 
           Hue[0.6485711159572851, 1, 0.10197845482837452`], 
           Hue[0.6478481526586202, 1, 0.10297948093421831`], 
           Hue[0.6472169204860098, 1, 0.10385349471167885`], 
           Hue[0.646645752668982, 1, 0.10464434245833251`], 
           Hue[0.6460978666860392, 1, 0.10540295381933042`], 
           Hue[0.645489117970712, 1, 0.10624583665593737`], 
           Hue[0.6449758474344328, 1, 0.10695651893693928`], 
           Hue[0.6446057461859066, 1, 0.10746896681951394`], 
           Hue[0.6447269791201302, 1, 0.10730110583366587`], 
           Hue[0.6448143518714197, 1, 0.10718012817803428`], 
           Hue[0.6446386253954922, 1, 0.1074234417600878], 
           Hue[0.6444502281867962, 1, 0.1076842994336668], 
           Hue[0.6444285208655675, 1, 0.10771435572459899`], 
           Hue[0.6457420223619782, 1, 0.10589566134495336`], 
           Hue[0.646907408335789, 1, 0.10428204999659998`], 
           Hue[0.6481847608283471, 1, 0.10251340808382711`], 
           Hue[0.6489306887868329, 1, 0.10148058475669296`], 
           Hue[0.6495445652662334, 1, 0.1006306019390615], 
           Hue[0.6498702683563081, 1, 0.10017962842972729`], 
           Hue[0.6499710158419191, 1, 0.10004013191118907`], 
           Hue[0.6495311358384767, 1, 0.1006491965313401], 
           Hue[0.6483894496489137, 1, 0.10222999279381192`], 
           Hue[0.6479788895815404, 1, 0.10279846057940568`], 
           Hue[0.6475978994814844, 1, 0.10332598533332932`], 
           Hue[0.6473189778091604, 1, 0.10371218457193178`], 
           Hue[0.6471883956275422, 1, 0.10389299066955707`], 
           Hue[0.6473203313841714, 1, 0.10371031039114721`], 
           Hue[0.6484128933058474, 1, 0.10219753234574976`], 
           Hue[0.6490074389437255, 1, 0.1013743153086879], 
           Hue[0.6483004248350057, 1, 0.10235325792076135`], 
           Hue[0.6476512819636975, 1, 0.10325207112718815`], 
           Hue[0.647177909117925, 1, 0.10390751045210388`], 
           Hue[0.6476302589163752, 1, 0.1032811799619421], 
           Hue[0.6484785424654151, 1, 0.10210663350942516`], 
           Hue[0.6490374185577825, 1, 0.10133280507383965`], 
           Hue[0.6495774352447521, 1, 0.10058508966111258`], 
           Hue[0.6487415025304523, 1, 0.10174253495783539`], 
           Hue[0.6497589618188885, 1, 0.10033374517384669`], 
           Hue[0.6494842522907944, 1, 0.10071411221274619`], 
           Hue[0.6488059954277987, 1, 0.10165323709997108`], 
           Hue[0.6486943253197311, 1, 0.10180785724960309`], 
           Hue[0.6498071763115433, 1, 0.10026698664555554`], 
           Hue[0.649995513367399, 1, 0.10000621226052449`], 
           Hue[0.6499724972674363, 1, 0.10003808070662663`], 
           Hue[0.6498868726098938, 1, 0.10015663792476255`], 
           Hue[0.649675283084229, 1, 0.10044960803722157`], 
           Hue[0.6493256084315968, 1, 0.10093377294086604`], 
           Hue[0.6499730201144907, 1, 0.10003735676455142`], 
           Hue[0.6499119335839733, 1, 0.10012193811449863`], 
           Hue[0.6497610653711238, 1, 0.10033083256305937`], 
           Hue[0.64948661714491, 1, 0.10071083779935544`], 
           Hue[0.6499921940479368, 1, 0.10001080824131829`], 
           Hue[0.6499768211371815, 1, 0.10003209381005643`], 
           Hue[0.6499709311885555, 1, 0.1000402491235386], 
           Hue[0.6498762763822666, 1, 0.10017130962455392`], 
           Hue[0.6498541257365453, 1, 0.1002019797493988], 
           Hue[0.6495774352447521, 1, 0.10058508966111254`], 
           Hue[0.6495306842520321, 1, 0.10064982180487864`], 
           Hue[0.6476302589163754, 1, 0.10328117996194178`], 
           Hue[0.6475974574857244, 1, 0.10332659732745854`], 
           Hue[0.6473386224356845, 1, 0.10368498431982145`], 
           Hue[0.6473184531260556, 1, 0.10371291105623075`], 
           Hue[0.6471779091179248, 1, 0.10390751045210418`], 
           Hue[0.6471877544905419, 1, 0.1038938783977113], 
           Hue[0.6495118930856678, 1, 0.1006758403429215], 
           Hue[0.6494787147610555, 1, 0.1007217795616155], 
           Hue[0.6490601902829448, 1, 0.10130127499284564`], 
           Hue[0.6490063830516062, 1, 0.10137577731316069`], 
           Hue[0.6473203313841713, 1, 0.10371031039114739`], 
           Hue[0.6472745253097466, 1, 0.10377373418650476`], 
           Hue[0.6471883956275424, 1, 0.10389299066955672`], 
           Hue[0.6471785610476428, 1, 0.1039066077801869], 
           Hue[0.6499710158419191, 1, 0.10004013191118907`], 
           Hue[0.6499768885403957, 1, 0.10003200048252905`], 
           Hue[0.6472164168884309, 1, 0.10385419200063425`], 
           Hue[0.6469074083357877, 1, 0.10428204999660161`], 
           Hue[0.6466451819682585, 1, 0.10464513265933437`], 
           Hue[0.6460736462773871, 1, 0.10543648976977178`], 
           Hue[0.6457420223619759, 1, 0.10589566134495648`], 
           Hue[0.6454881245503626, 1, 0.10624721216103636`], 
           Hue[0.6449747057502719, 1, 0.10695809973039276`], 
           Hue[0.6446604067397317, 1, 0.10739328297575611`], 
           Hue[0.6444285208656477, 1, 0.10771435572448775`], 
           Hue[0.6446054156460634, 1, 0.10746942449006598`], 
           Hue[0.6444502281869823, 1, 0.10768429943340925`], 
           Hue[0.6444500571988938, 1, 0.10768453618614703`], 
           Hue[0.6446057461857632, 1, 0.10746896681971264`], 
           Hue[0.6444293000046112, 1, 0.10771327691669219`], 
           Hue[0.6446614119197257, 1, 0.10739189118807217`], 
           Hue[0.6499916808511504, 1, 0.10001151882148407`], 
           Hue[0.6465464412567721, 1, 0.10478185056754641`], 
           Hue[0.645642311937682, 1, 0.1060337219324404], 
           Hue[0.6444850252642972, 1, 0.10763611886481932`], 
           Hue[0.6428801433477171, 1, 0.10985826305700704`], 
           Hue[0.6397424833007631, 1, 0.11420271542971269`], 
           Hue[0.6211894469842212, 1, 0.13989153494492462`], 
           Hue[0.6456433109470441, 1, 0.10603233868870826`], 
           Hue[0.6465472957244812, 1, 0.10478066745841058`], 
           Hue[0.6466982385822131, 1, 0.10457166965539727`], 
           Hue[0.6493843083159341, 1, 0.10085249617793748`], 
           Hue[0.6497647458011401, 1, 0.10032573658303683`], 
           Hue[0.6499916431084579, 1, 0.1000115710805968], 
           Hue[0.6416047567879677, 1, 0.11162418290896782`], 
           Hue[0.6075239849977159, 1, 0.15881294384931657`], 
           Hue[0.5547429134967014, 1, 0.23189442746610583`], 
           Hue[0.479900588293155, 1, 0.33552226236332383`], 
           Hue[0.6454307554303194, 1, 0.10632664632725011`], 
           Hue[0.6444510447211244, 1, 0.10768316884767408`], 
           Hue[0.6334576495991543, 1, 0.12290479286270953`], 
           Hue[0.5972152565878802, 1, 0.1730865678013966], 
           Hue[0.510520851349772, 1, 0.2931249750541619], 
           Hue[0.6225162151471804, 1, 0.1380544713346734], 
           Hue[0.6412672295637734, 1, 0.11209152829631382`], 
           Hue[0.6488711177040362, 1, 0.10156306779441146`], 
           Hue[0.6496468100677274, 1, 0.10048903221391596`], 
           Hue[0.6499821551229769, 1, 0.1000247082912629], 
           Hue[0.6499973236426885, 1, 0.10000370572550824`], 
           Hue[0.6499997033584459, 1, 0.10000041073445946`], 
           Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
           Hue[0.6499998652875634, 1, 0.10000018652491231`], 
           Hue[0.6499997033584459, 1, 0.10000041073445946`], 
           Hue[0.6499986685807253, 1, 0.10000184350361113`], 
           Hue[0.6499973236426885, 1, 0.10000370572550824`], 
           Hue[0.6499903486487819, 1, 0.10001336340937898`], 
           Hue[0.6499821551229769, 1, 0.10002470829126286`], 
           Hue[0.6499471992776279, 1, 0.10007310869251526`], 
           Hue[0.649776996090499, 1, 0.10030877464392456`], 
           Hue[0.6496468100677264, 1, 0.10048903221391733`], 
           Hue[0.6488711177040118, 1, 0.10156306779444513`], 
           Hue[0.644379238729608, 1, 0.10778259252823516`], 
           Hue[0.6412672295634195, 1, 0.11209152829680384`], 
           Hue[0.633303976366686, 1, 0.12311757118458871`], 
           Hue[0.6225162151465272, 1, 0.13805447133557772`], 
           Hue[0.45983657272858763`, 1, 0.36330320699118634`], 
           Hue[0.5105208513514405, 1, 0.2931249750518516], 
           Hue[0.5682104334567659, 1, 0.21324709213678578`], 
           Hue[0.597215256588433, 1, 0.17308656780063125`], 
           Hue[0.6225136803974861, 1, 0.13805798098809613`], 
           Hue[0.6334576495989711, 1, 0.12290479286296306`], 
           Hue[0.6412672325869223, 1, 0.11209152411041531`], 
           Hue[0.6444510447209125, 1, 0.10768316884796729`], 
           Hue[0.6469167021582841, 1, 0.1042691816269912], 
           Hue[0.6454307554303608, 1, 0.10632664632719284`], 
           Hue[0.47990058829466425`, 1, 0.33552226236123417`], 
           Hue[0.5547429134976741, 1, 0.23189442746475897`], 
           Hue[0.6075239849981009, 1, 0.15881294384878336`], 
           Hue[0.6416047567879696, 1, 0.11162418290896522`], 
           Hue[0.6497647458011402, 1, 0.10032573658303669`], 
           Hue[0.6465472957244994, 1, 0.10478066745838548`], 
           Hue[0.6211894469844126, 1, 0.1398915349446595], 
           Hue[0.6397424833007785, 1, 0.11420271542969126`], 
           Hue[0.642880143347735, 1, 0.10985826305698225`], 
           Hue[0.6444850252643324, 1, 0.10763611886477051`], 
           Hue[0.6456423119377144, 1, 0.10603372193239556`], 
           Hue[0.644742260288362, 1, 0.10727994729303722`], 
           Hue[0.6444293000047064, 1, 0.10771327691656032`], 
           Hue[0.6444500571991165, 1, 0.10768453618583873`], 
           Hue[0.6446054156459392, 1, 0.10746942449023812`], 
           Hue[0.6446604067396938, 1, 0.10739328297580855`], 
           Hue[0.6449747057502663, 1, 0.10695809973040055`], 
           Hue[0.6454881245503643, 1, 0.10624721216103405`], 
           Hue[0.6460736462773897, 1, 0.10543648976976815`], 
           Hue[0.64664518196826, 1, 0.10464513265933222`], 
           Hue[0.6472164168884312, 1, 0.10385419200063364`], 
           Hue[0.6499768885403957, 1, 0.10003200048252905`], 
           Hue[0.6471785610476426, 1, 0.10390660778018722`], 
           Hue[0.6472745253097466, 1, 0.10377373418650467`], 
           Hue[0.6490063830516288, 1, 0.1013757773131294], 
           Hue[0.6494787147610784, 1, 0.1007217795615837], 
           Hue[0.6471877544905421, 1, 0.103893878397711], 
           Hue[0.6473184531260556, 1, 0.10371291105623072`], 
           Hue[0.6475974574857242, 1, 0.10332659732745883`], 
           Hue[0.6495306842520321, 1, 0.10064982180487868`], 
           Hue[0.6498541257365453, 1, 0.10020197974939882`], 
           Hue[0.6499709311885555, 1, 0.1000402491235386], 
           Hue[0.6499955545015644, 1, 0.10000615530552621`], 
           Hue[0.6499921940479368, 1, 0.10001080824131829`], 
           Hue[0.6493814166270158, 1, 0.10085650005490124`], 
           Hue[0.64948661714491, 1, 0.1007108377993554], 
           Hue[0.6496976408126721, 1, 0.10041865118245408`], 
           Hue[0.649761065371124, 1, 0.10033083256305912`], 
           Hue[0.6498799412726705, 1, 0.10016623516091785`], 
           Hue[0.6499119335839736, 1, 0.10012193811449815`], 
           Hue[0.64996159366688, 1, 0.10005317799970473`], 
           Hue[0.649973020114491, 1, 0.10003735676455103`], 
           Hue[0.6492162512642065, 1, 0.10108519055725261`], 
           Hue[0.6493256084315966, 1, 0.10093377294086624`], 
           Hue[0.6496752830842288, 1, 0.10044960803722168`], 
           Hue[0.6498432245869254, 1, 0.10021707364887249`], 
           Hue[0.6498868726098938, 1, 0.10015663792476259`], 
           Hue[0.64995742655059, 1, 0.10005894785302934`], 
           Hue[0.6499724972674363, 1, 0.10003808070662665`], 
           Hue[0.6499921293089566, 1, 0.10001089787990629`], 
           Hue[0.649995513367399, 1, 0.10000621226052449`], 
           Hue[0.6497523354002839, 1, 0.10034292021499154`], 
           Hue[0.6498071763115432, 1, 0.10026698664555568`], 
           Hue[0.6497585093987792, 1, 0.10033437160169033`], 
           Hue[0.6499996894548788, 1, 0.10000042998555234`], 
           Hue[0.6499976810908947, 1, 0.10000321079722264`], 
           Hue[0.6499735114284139, 1, 0.10003667648373474`], 
           Hue[0.6499875385469106, 1, 0.10001725431966231`], 
           Hue[0.6499179695206531, 1, 0.10011358066371122`], 
           Hue[0.6499510653458983, 1, 0.10006775567491014`], 
           Hue[0.6498285638060287, 1, 0.10023737319165262`], 
           Hue[0.6498754872667991, 1, 0.10017240224597054`], 
           Hue[0.6497844884994874, 1, 0.10029840053917119`], 
           Hue[0.6497525816504375, 1, 0.10034257925324044`], 
           Hue[0.6498178986902056, 1, 0.10025214027509997`], 
           Hue[0.6499979498338926, 1, 0.10000283869153345`], 
           Hue[0.6499990931632785, 1, 0.10000125562007593`], 
           Hue[0.6499895375823748, 1, 0.10001448642440418`], 
           Hue[0.6499952798767935, 1, 0.100006535555209], 
           Hue[0.6499635376940699, 1, 0.10005048626974943`], 
           Hue[0.6499797919710948, 1, 0.1000279803477149], 
           Hue[0.6499045423782823, 1, 0.10013217209160918`], 
           Hue[0.649938736749848, 1, 0.10008482603867201`], 
           Hue[0.6498175387315117, 1, 0.10025263867944541`], 
           Hue[0.6498625824888394, 1, 0.10019027040006855`], 
           Hue[0.6497220805506988, 1, 0.10038481154518639`], 
           Hue[0.6497587426645933, 1, 0.10033404861825541`], 
           Hue[0.6498289592233316, 1, 0.10023682569077172`], 
           Hue[0.6499991804292786, 1, 0.10000113479022964`], 
           Hue[0.6499617603399277, 1, 0.10005294722163856`], 
           Hue[0.6491240599696748, 1, 0.10121284004198873`], 
           Hue[0.6499852101793618, 1, 0.10002047821319134`], 
           Hue[0.6499298416416036, 1, 0.1000971423423951], 
           Hue[0.6499657096233139, 1, 0.10004747898310386`], 
           Hue[0.6497686522347684, 1, 0.10032032767493607`], 
           Hue[0.6498661528906174, 1, 0.10018532676683745`], 
           Hue[0.6494608701931663, 1, 0.10074648742484657`], 
           Hue[0.6496322047027856, 1, 0.1005092550269123], 
           Hue[0.6499817210220851, 1, 0.10002530935403611`], 
           Hue[0.6499395617051158, 1, 0.1000836837929167], 
           Hue[0.6498247725796032, 1, 0.10024262258208783`], 
           Hue[0.6498942532833839, 1, 0.10014641853069925`], 
           Hue[0.6495955370911406, 1, 0.10056002556611304`], 
           Hue[0.6497259877549593, 1, 0.1003794015700564], 
           Hue[0.6486592242610939, 1, 0.10185645871540853`], 
           Hue[0.6486985272829319, 1, 0.10180203914670968`], 
           Hue[0.6488858529817219, 1, 0.10154266510223128`], 
           Hue[0.6492168120882641, 1, 0.10108441403163439`], 
           Hue[0.6498347039214942, 1, 0.10022887149331575`], 
           Hue[0.6499576702370821, 1, 0.10005861044096336`], 
           Hue[0.6499659179555519, 1, 0.100047190523082], 
           Hue[0.6499745865383855, 1, 0.10003518786992782`], 
           Hue[0.6498668777824628, 1, 0.10018432307043619`], 
           Hue[0.6494794345021984, 1, 0.10072078299695619`], 
           Hue[0.64951254449455, 1, 0.1006749383921616], 
           Hue[0.6494921178874883, 1, 0.10070322138655469`], 
           Hue[0.6490365748044895, 1, 0.10133397334762992`], 
           Hue[0.6484128933058365, 1, 0.10219753234576491`], 
           Hue[0.6483395074792844, 1, 0.10229914349022172`], 
           Hue[0.6489814055841804, 1, 0.10141036149882726`], 
           Hue[0.6490500614364055, 1, 0.10131529954959236`], 
           Hue[0.6495311358384767, 1, 0.10064919653134007`], 
           Hue[0.6495778694437395, 1, 0.1005844884625145], 
           Hue[0.6498543989283845, 1, 0.10020160148377538`], 
           Hue[0.6498765165910504, 1, 0.10017097702777641`], 
           Hue[0.6499746602037513, 1, 0.10003508587172912`], 
           Hue[0.6490074389437478, 1, 0.10137431530865688`], 
           Hue[0.6490612179653654, 1, 0.1012998520479556], 
           Hue[0.6496523174518567, 1, 0.1004814066051215], 
           Hue[0.6477602551397625, 1, 0.10310118519109808`], 
           Hue[0.6476889012124347, 1, 0.10319998293662894`], 
           Hue[0.6473189778091605, 1, 0.10371218457193164`], 
           Hue[0.6473382110820157, 1, 0.1036855538864398], 
           Hue[0.6475978994814844, 1, 0.10332598533332936`], 
           Hue[0.6476306747916085, 1, 0.10328060413469597`], 
           Hue[0.6483894496489135, 1, 0.10222999279381198`], 
           Hue[0.648454805069711, 1, 0.10213950067270793`], 
           Hue[0.6472169204860091, 1, 0.10385349471167978`], 
           Hue[0.64784815265862, 1, 0.10297948093421863`], 
           Hue[0.6481850644702216, 1, 0.10251298765661626`], 
           Hue[0.6489327307650269, 1, 0.1014777574022705], 
           Hue[0.649870268356308, 1, 0.10017962842972737`], 
           Hue[0.6497422679611429, 1, 0.10035685974610997`], 
           Hue[0.6495445652662333, 1, 0.10063060193906168`], 
           Hue[0.6492714988092747, 1, 0.1010086939563889], 
           Hue[0.6446378483465082, 1, 0.1074245176740656], 
           Hue[0.6449758474344249, 1, 0.10695651893695021`], 
           Hue[0.6454891179707094, 1, 0.10624583665594087`], 
           Hue[0.6457429134754836, 1, 0.10589442749548424`], 
           Hue[0.6466457526689804, 1, 0.1046443424583349], 
           Hue[0.6469079421014989, 1, 0.10428131093638608`], 
           Hue[0.6499800978129978, 1, 0.10002755687431077`], 
           Hue[0.6498908903541091, 1, 0.10015107489431062`], 
           Hue[0.6497651749073807, 1, 0.10032514243593448`], 
           Hue[0.6493848462505366, 1, 0.10085175134541088`], 
           Hue[0.6450042018600114, 1, 0.10691725896306116`], 
           Hue[0.6436612706901785, 1, 0.10877670212129127`], 
           Hue[0.6413492538797367, 1, 0.11197795616651847`], 
           Hue[0.6363229297017741, 1, 0.11893748195138976`], 
           Hue[0.6264945721377247, 1, 0.13254597704007343`], 
           Hue[0.6123745783731487, 1, 0.15209673763717874`], 
           Hue[0.6444863018191366, 1, 0.10763435132734933`], 
           Hue[0.6460988378740803, 1, 0.10540160909742732`], 
           Hue[0.6471452171056709, 1, 0.10395277631522504`], 
           Hue[0.6477258602117284, 1, 0.10314880893760692`], 
           Hue[0.6485606730077377, 1, 0.1019929142969787], 
           Hue[0.6498906156449326, 1, 0.10015145526086258`], 
           Hue[0.6499800210545625, 1, 0.10002766315522109`], 
           Hue[0.6499272404251578, 1, 0.10010074402670452`], 
           Hue[0.5947858976871175, 1, 0.17645029551014493`], 
           Hue[0.5959049495699404, 1, 0.1749008390570056], 
           Hue[0.6039357705137042, 1, 0.16378124082717888`], 
           Hue[0.6211966685590604, 1, 0.13988153584130092`], 
           Hue[0.6386880733811215, 1, 0.11566266762613948`], 
           Hue[0.6428823803202386, 1, 0.10985516571043896`], 
           Hue[0.6442709715647295, 1, 0.10793250091037464`], 
           Hue[0.647305180926357, 1, 0.10373128794812109`], 
           Hue[0.6493194313649147, 1, 0.10094232580242588`], 
           Hue[0.6499964589486245, 1, 0.1000049029942124], 
           Hue[0.6421307435744927, 1, 0.11089589351224086`], 
           Hue[0.6439216662082725, 1, 0.10841615448085354`], 
           Hue[0.6392482971262327, 1, 0.11488697320983171`], 
           Hue[0.6113184040195201, 1, 0.1535591328960491], 
           Hue[0.6255259248970978, 1, 0.1338871809117108], 
           Hue[0.561343901316591, 1, 0.22275459817702792`], 
           Hue[0.5900825238500264, 1, 0.18296265928457897`], 
           Hue[0.487562989678903, 1, 0.324912783521519], 
           Hue[0.5262450270724396, 1, 0.2713530394381607], 
           Hue[0.3747741167538307, 1, 0.48108199218700365`], 
           Hue[0.49507930341202766`, 1, 0.3145055798910387], 
           Hue[0.6392520089619881, 1, 0.11488183374493961`], 
           Hue[0.643922915936966, 1, 0.1084144240872778], 
           Hue[0.6486346449067806, 1, 0.10189049166753458`], 
           Hue[0.649363405912809, 1, 0.10088143796687978`], 
           Hue[0.6497870627427595, 1, 0.10029483620233297`], 
           Hue[0.6496196896792591, 1, 0.10052658352102598`], 
           Hue[0.6499461593618886, 1, 0.10007454857584652`], 
           Hue[0.6498899253776141, 1, 0.1001524110156112], 
           Hue[0.6499763529684163, 1, 0.10003274204373136`], 
           Hue[0.6499964290356581, 1, 0.10000494441216566`], 
           Hue[0.64999986712212, 1, 0.10000018398475698`], 
           Hue[0.4598523370130971, 1, 0.36328137952032713`], 
           Hue[0.5682182330627773, 1, 0.21323629268230834`], 
           Hue[0.6479045331466449, 1, 0.10290141564310716`], 
           Hue[0.638478408112191, 1, 0.11595297338312012`], 
           Hue[0.6131150084107319, 1, 0.15107152681590974`], 
           Hue[0.5438542150943324, 1, 0.24697108679246285`], 
           Hue[0.23864305325628815`, 1, 0.6695711570297549], 
           Hue[0.14468550878889286`, 1, 0.7996662185999945], 
           Hue[0.12320664814348603`, 1, 0.8294061794936347], 
           Hue[0.1969400522797311, 1, 0.7273137737665262], 
           Hue[0.31924359861640145`, 1, 0.5579704019157519], 
           Hue[0.6468888344263154, 1, 0.10430776771740956`], 
           Hue[0.6484645052704583, 1, 0.10212606962551937`], 
           Hue[0.6494782446417755, 1, 0.10072243049600321`], 
           Hue[0.6490857182415478, 1, 0.1012659285886261], 
           Hue[0.6498549379809119, 1, 0.10020085510335289`], 
           Hue[0.6499692960032009, 1, 0.1000425132263373], 
           Hue[0.6499949427213864, 1, 0.10000700238577273`], 
           Hue[0.6499993787624871, 1, 0.1000008601750178], 
           Hue[0.6499999454587057, 1, 0.10000007551871525`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.6499289484739933, 1, 0.10009837903600931`], 
           Hue[0.6499289484739933, 1, 0.10009837903600931`], 
           Hue[0.6496234965987948, 1, 0.10052131240166877`], 
           Hue[0.6496234965987948, 1, 0.10052131240166878`], 
           Hue[0.26072995684113986`, 1, 0.6389892905276525], 
           Hue[0.26072995684113764`, 1, 0.6389892905276556], 
           Hue[0.12170305563831885`, 1, 0.8314880768084816], 
           Hue[0.12170305563831718`, 1, 0.8314880768084838], 
           Hue[0.033059327874478295`, 1, 0.9542255460199531], 
           Hue[0.03305932787447752, 1, 0.9542255460199542], 
           Hue[0.03305932787175303, 1, 0.9542255460237266], 
           Hue[0.03305932787175392, 1, 0.9542255460237254], 
           Hue[0.1217030556359836, 1, 0.831488076811715], 
           Hue[0.12170305563598527`, 1, 0.8314880768117127], 
           Hue[0.2607299568417166, 1, 0.6389892905268539], 
           Hue[0.26072995684171885`, 1, 0.6389892905268508], 
           Hue[0.4280417126324534, 1, 0.40732685943198765`], 
           Hue[0.4280417126324556, 1, 0.40732685943198454`], 
           Hue[0.559170544826714, 1, 0.22576386100916526`], 
           Hue[0.5591705448267154, 1, 0.22576386100916337`], 
           Hue[0.649623496598795, 1, 0.10052131240166846`], 
           Hue[0.649623496598795, 1, 0.10052131240166845`], 
           Hue[0.6499289484739933, 1, 0.1000983790360093], 
           Hue[0.6499289484739933, 1, 0.1000983790360093], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.5591705448254742, 1, 0.22576386101088186`], 
           Hue[0.5591705448254729, 1, 0.22576386101088372`], 
           Hue[0.42804171263043833`, 1, 0.40732685943477775`], 
           Hue[0.42804171263043606`, 1, 0.40732685943478086`], 
           Hue[0.6490857182415353, 1, 0.10126592858864356`], 
           Hue[0.6432968085982096, 1, 0.10928134194094068`], 
           Hue[0.6294670107067198, 1, 0.12843029286761867`], 
           Hue[0.5972214239233667, 1, 0.17307802841379993`], 
           Hue[0.5682182330616764, 1, 0.21323629268383273`], 
           Hue[0.510533983907657, 1, 0.2931067915124749], 
           Hue[0.45985233701165773`, 1, 0.3632813795223201], 
           Hue[0.3752505842345883, 1, 0.4804222679828778], 
           Hue[0.3192435986155256, 1, 0.5579704019169646], 
           Hue[0.2386766428429961, 1, 0.6695246483712362], 
           Hue[0.14472156419534377`, 1, 0.7996162957295241], 
           Hue[0.12320664814153293`, 1, 0.829406179496339], 
           Hue[0.12317793669330279`, 1, 0.8294459338092731], 
           Hue[0.14468550878552755`, 1, 0.7996662186046541], 
           Hue[0.23864305325551322`, 1, 0.6695711570308279], 
           Hue[0.6499999454587057, 1, 0.10000007551871525`], 
           Hue[0.6479034511561872, 1, 0.10290291378374081`], 
           Hue[0.6468888344261868, 1, 0.10430776771758747`], 
           Hue[0.10550699045016398`, 1, 0.8539133978382344], 
           Hue[0.6468897902011316, 1, 0.10430644433689479`], 
           Hue[0.6479045331465781, 1, 0.1029014156431996], 
           Hue[0.6488721916035768, 1, 0.10156158085658602`], 
           Hue[0.6499997070467911, 1, 0.10000040562752005`], 
           Hue[0.64999986712212, 1, 0.10000018398475698`], 
           Hue[0.6499964290356581, 1, 0.10000494441216566`], 
           Hue[0.6499763529684163, 1, 0.10003274204373135`], 
           Hue[0.6498899253776143, 1, 0.10015241101561112`], 
           Hue[0.6496196896792596, 1, 0.10052658352102511`], 
           Hue[0.6462369452811769, 1, 0.10521038345683198`], 
           Hue[0.6439229159369845, 1, 0.10841442408725223`], 
           Hue[0.6416071963745702, 1, 0.11162080501982595`], 
           Hue[0.6327196532761324, 1, 0.12392663392535516`], 
           Hue[0.5262450270736306, 1, 0.27135303943651146`], 
           Hue[0.5900825238506201, 1, 0.18296265928375688`], 
           Hue[0.6255259248972422, 1, 0.13388718091151078`], 
           Hue[0.6392482971262292, 1, 0.11488697320983655`], 
           Hue[0.6439216662083033, 1, 0.10841615448081084`], 
           Hue[0.6499964589486245, 1, 0.1000049029942124], 
           Hue[0.6492611812640128, 1, 0.1010229797882901], 
           Hue[0.6486346449067905, 1, 0.10189049166752093`], 
           Hue[0.6473051809263888, 1, 0.10373128794807712`], 
           Hue[0.6442709715647609, 1, 0.10793250091033112`], 
           Hue[0.5547703620062218, 1, 0.23185642183753913`], 
           Hue[0.49507930341255957`, 1, 0.31450557989030214`], 
           Hue[0.47992518690165575`, 1, 0.33548820275155355`], 
           Hue[0.4092648191999626, 1, 0.433325634953898], 
           Hue[0.37477411675478794`, 1, 0.48108199218567826`], 
           Hue[0.36993665875162945`, 1, 0.48778001095928225`], 
           Hue[0.6498201909540229, 1, 0.10024896637135305`], 
           Hue[0.6499272404251579, 1, 0.10010074402670448`], 
           Hue[0.6493848462505368, 1, 0.10085175134541062`], 
           Hue[0.6499800210545625, 1, 0.10002766315522107`], 
           Hue[0.6497827013349247, 1, 0.1003008750747198], 
           Hue[0.6498906156449327, 1, 0.10015145526086251`], 
           Hue[0.6493194313649149, 1, 0.10094232580242558`], 
           Hue[0.6485606730077386, 1, 0.10199291429697735`], 
           Hue[0.64714521710568, 1, 0.10395277631521234`], 
           Hue[0.6386880733811489, 1, 0.11566266762610168`], 
           Hue[0.6039357705144809, 1, 0.16378124082610337`], 
           Hue[0.6197500814767566, 1, 0.14188450257064478`], 
           Hue[0.6123745783734561, 1, 0.15209673763675313`], 
           Hue[0.6320807432699584, 1, 0.12481127854928835`], 
           Hue[0.626494572137861, 1, 0.1325459770398848], 
           Hue[0.6393231015822664, 1, 0.11478339780916977`], 
           Hue[0.6363229297018136, 1, 0.1189374819513351], 
           Hue[0.6427084326690243, 1, 0.11009601630442789`], 
           Hue[0.6413492538797488, 1, 0.1119779561665016], 
           Hue[0.64438993383294, 1, 0.10776778392362159`], 
           Hue[0.6436612706902045, 1, 0.10877670212125537`], 
           Hue[0.6450042018600488, 1, 0.10691725896300931`], 
           Hue[0.6499800978129978, 1, 0.10002755687431074`], 
           Hue[0.6481850644702218, 1, 0.10251298765661598`], 
           Hue[0.6469079421015004, 1, 0.10428131093638413`], 
           Hue[0.6492714988092749, 1, 0.10100869395638867`], 
           Hue[0.6497422679611429, 1, 0.10035685974610985`], 
           Hue[0.6499452847292683, 1, 0.10007575960562862`], 
           Hue[0.6499786432660215, 1, 0.10002957086243183`], 
           Hue[0.6489327307650271, 1, 0.10147775740227026`], 
           Hue[0.645742913475486, 1, 0.10589442749548096`], 
           Hue[0.6451848600758786, 1, 0.10666711681801426`], 
           Hue[0.6448183521045512, 1, 0.10717458939369848`], 
           Hue[0.6445356096359176, 1, 0.10756607896565253`], 
           Hue[0.6445188584207069, 1, 0.10758927295594438`], 
           Hue[0.6446378483467755, 1, 0.10742451767369551`], 
           Hue[0.6445187656803508, 1, 0.10758940136566814`], 
           Hue[0.6445346715615177, 1, 0.1075673778378987], 
           Hue[0.6448171573226968, 1, 0.1071762437070351], 
           Hue[0.6453175862657006, 1, 0.10648334209364543`], 
           Hue[0.6499872851621001, 1, 0.10001760516016903`], 
           Hue[0.6498765165910504, 1, 0.10017097702777644`], 
           Hue[0.6495778694437395, 1, 0.10058448846251454`], 
           Hue[0.6490500614364055, 1, 0.10131529954959238`], 
           Hue[0.648454805069711, 1, 0.1021395006727079], 
           Hue[0.6495125444945283, 1, 0.10067493839219152`], 
           Hue[0.6490612179653426, 1, 0.10129985204798726`], 
           Hue[0.6499746602037512, 1, 0.10003508587172912`], 
           Hue[0.6498671323084145, 1, 0.10018397064988765`], 
           Hue[0.6476306747916085, 1, 0.10328060413469592`], 
           Hue[0.6473382110820156, 1, 0.10368555388643992`], 
           Hue[0.6472266389834022, 1, 0.10384003833067391`], 
           Hue[0.6471976417124164, 1, 0.10388018839819263`], 
           Hue[0.6476889012124372, 1, 0.10319998293662551`], 
           Hue[0.6483395074792947, 1, 0.10229914349020733`], 
           Hue[0.6483775520143936, 1, 0.10224646644160888`], 
           Hue[0.6492984661033829, 1, 0.10097135462608528`], 
           Hue[0.6490365748045124, 1, 0.10133397334759822`], 
           Hue[0.6494921178875113, 1, 0.10070322138652285`], 
           Hue[0.6496153109565739, 1, 0.10053264636782082`], 
           Hue[0.6497438699910105, 1, 0.1003546415509085], 
           Hue[0.6499382721143278, 1, 0.10008546938016159`], 
           Hue[0.6498668777824628, 1, 0.10018432307043622`], 
           Hue[0.6499745865383855, 1, 0.10003518786992784`], 
           Hue[0.6499728188455073, 1, 0.10003763544468222`], 
           Hue[0.6499576702370821, 1, 0.10005861044096337`], 
           Hue[0.6498879983365086, 1, 0.10015507922637276`], 
           Hue[0.6498347039214942, 1, 0.10022887149331577`], 
           Hue[0.6494358636771683, 1, 0.10078111183161306`], 
           Hue[0.6497259877549595, 1, 0.10037940157005618`], 
           Hue[0.6498942532833842, 1, 0.10014641853069874`], 
           Hue[0.6499731374090267, 1, 0.10003719435673221`], 
           Hue[0.6499617603399274, 1, 0.10005294722163902`], 
           Hue[0.6496322047027855, 1, 0.10050925502691242`], 
           Hue[0.6498661528906173, 1, 0.1001853267668375], 
           Hue[0.6499657096233139, 1, 0.10004747898310387`], 
           Hue[0.6493262593973559, 1, 0.10093287160366116`], 
           Hue[0.6492168120882642, 1, 0.10108441403163429`], 
           Hue[0.648885852981722, 1, 0.10154266510223121`], 
           Hue[0.6487385095926334, 1, 0.10174667902558462`], 
           Hue[0.6486985272829319, 1, 0.10180203914670978`], 
           Hue[0.648661418574052, 1, 0.10185342043592793`], 
           Hue[0.6486592242610937, 1, 0.10185645871540881`], 
           Hue[0.6490246129733722, 1, 0.10135053588302306`], 
           Hue[0.6491240599696747, 1, 0.1012128400419889], 
           Hue[0.6499852500802348, 1, 0.10002042296582875`], 
           Hue[0.6497760637592552, 1, 0.10031006556410822`], 
           Hue[0.6498625824888393, 1, 0.10019027040006864`], 
           Hue[0.649938736749848, 1, 0.10008482603867204`], 
           Hue[0.6499797919710948, 1, 0.1000279803477149], 
           Hue[0.6499952798767935, 1, 0.100006535555209], 
           Hue[0.6499990931632785, 1, 0.10000125562007593`], 
           Hue[0.6497844884994874, 1, 0.10029840053917125`], 
           Hue[0.649875487266799, 1, 0.10017240224597061`], 
           Hue[0.6499510653458982, 1, 0.10006775567491018`], 
           Hue[0.6499875385469106, 1, 0.10001725431966232`], 
           Hue[0.6499976810908947, 1, 0.10000321079722264`], 
           Hue[0.6499996894548788, 1, 0.10000042998555234`], 
           Hue[0.6499991804292786, 1, 0.10000113479022964`], 
           Hue[0.6499685517490378, 1, 0.10004354373210152`], 
           Hue[0.6497587426645933, 1, 0.1003340486182554], 
           Hue[0.6497446269774028, 1, 0.10035359341590383`], 
           Hue[0.6497220805506987, 1, 0.10038481154518647`], 
           Hue[0.6499875780500365, 1, 0.1000171996230264], 
           Hue[0.6498075235338531, 1, 0.10026650587620353`], 
           Hue[0.6497525816504376, 1, 0.10034257925324029`], 
           Hue[0.6497395116100093, 1, 0.10036067623229489`], 
           Hue[0.6497444578897738, 1, 0.10035382753723637`], 
           Hue[0.649904864696231, 1, 0.10013172580521867`], 
           Hue[0.6499637194211009, 1, 0.10005023464770654`], 
           Hue[0.6497760637592553, 1, 0.10031006556410807`], 
           Hue[0.6497500661969323, 1, 0.100346062188863], 
           Hue[0.6499183291303126, 1, 0.10011308274264415`], 
           Hue[0.6499817845643631, 1, 0.10002522137242048`], 
           Hue[0.6499667588310659, 1, 0.10004602623390876`], 
           Hue[0.6494358636771684, 1, 0.10078111183161303`], 
           Hue[0.6486665440965279, 1, 0.10184632355865368`], 
           Hue[0.6487973060787215, 1, 0.10166526850638564`], 
           Hue[0.6490820712669708, 1, 0.10127097824573278`], 
           Hue[0.6498666614359694, 1, 0.10018462262711927`], 
           Hue[0.6494928049778546, 1, 0.10070227003066289`], 
           Hue[0.648377552014383, 1, 0.10224646644162362`], 
           Hue[0.6490171435581193, 1, 0.10136087815029625`], 
           Hue[0.6495581589251697, 1, 0.1006117799497651], 
           Hue[0.6498671323084145, 1, 0.10018397064988763`], 
           Hue[0.6473537923316887, 1, 0.10366397984843105`], 
           Hue[0.6480091049759611, 1, 0.10275662387943847`], 
           Hue[0.648755138205803, 1, 0.10172365479196505`], 
           Hue[0.6496095597971275, 1, 0.10054060951166957`], 
           Hue[0.6450053143732403, 1, 0.10691571856012894`], 
           Hue[0.6481572782578708, 1, 0.10255146087371726`], 
           Hue[0.6499764872407213, 1, 0.10003255612823204`], 
           Hue[0.3711773698973812, 1, 0.48606210321901067`], 
           Hue[0.41486309731293136`, 1, 0.42557417295132594`], 
           Hue[0.4875889857302076, 1, 0.32487678898894345`], 
           Hue[0.6255368322476673, 1, 0.13387207842630677`], 
           Hue[0.646236945281131, 1, 0.10521038345689565`], 
           Hue[0.64846560213652, 1, 0.10212455088789542`], 
           Hue[0.16660070649009112`, 1, 0.7693220987060277], 
           Hue[0.2153415771899569, 1, 0.7018347392754444], 
           Hue[0.10993697241880118`, 1, 0.8477795766508907], 
           Hue[0.13133504687222974`, 1, 0.8181514735615281], 
           Hue[0.10995731693131072`, 1, 0.8477514073258775], 
           Hue[0.1666401527260788, 1, 0.769267480840814], 
           Hue[0.1313694777282427, 1, 0.818103800068587], 
           Hue[0.2153784744292791, 1, 0.701783650790229], 
           Hue[0.3464112201430799, 1, 0.5203536951865048], 
           Hue[0.4873085045365856, 1, 0.32526514756472774`], 
           Hue[0.585623995432508, 1, 0.18913600632421984`], 
           Hue[0.6294670107072995, 1, 0.12843029286681606`], 
           Hue[0.6432968085985096, 1, 0.10928134194052527`], 
           Hue[0.6496234965987948, 1, 0.10052131240166877`], 
           Hue[0.2607299568411387, 1, 0.6389892905276541], 
           Hue[0.12170305563831796`, 1, 0.8314880768084828], 
           Hue[0.033059327871753474`, 1, 0.954225546023726], 
           Hue[0.12170305563598438`, 1, 0.831488076811714], 
           Hue[0.2607299568417177, 1, 0.6389892905268524], 
           Hue[0.4280417126324546, 1, 0.407326859431986], 
           Hue[0.5591705448267148, 1, 0.22576386100916412`], 
           Hue[0.649623496598795, 1, 0.10052131240166845`], 
           Hue[0.6499289484739933, 1, 0.1000983790360093], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.5856239954315277, 1, 0.18913600632557717`], 
           Hue[0.48730850453512964`, 1, 0.32526514756674363`], 
           Hue[0.3464112201419854, 1, 0.5203536951880203], 
           Hue[0.21537847442891117`, 1, 0.7017836507907383], 
           Hue[0.13136947772675878`, 1, 0.8181038000706417], 
           Hue[0.1313350468685427, 1, 0.8181514735666332], 
           Hue[0.2153415771885579, 1, 0.7018347392773814], 
           Hue[0.6392520089618953, 1, 0.11488183374506818`], 
           Hue[0.6255368322474537, 1, 0.1338720784266026], 
           Hue[0.6499764872407213, 1, 0.10003255612823203`], 
           Hue[0.6493571286681645, 1, 0.1008901295363876], 
           Hue[0.6481572782578727, 1, 0.10255146087371465`], 
           Hue[0.6460988378741058, 1, 0.10540160909739191`], 
           Hue[0.6450053143732773, 1, 0.10691571856007749`], 
           Hue[0.6320881314565716, 1, 0.12480104875243928`], 
           Hue[0.6197571630580532, 1, 0.14187469730423413`], 
           Hue[0.6051860768208408, 1, 0.16205004747883583`], 
           Hue[0.5950760330689806, 1, 0.17604856959679616`], 
           Hue[0.6496095597971278, 1, 0.10054060951166938`], 
           Hue[0.6498908903541091, 1, 0.10015107489431052`], 
           Hue[0.6487551382058032, 1, 0.1017236547919648], 
           Hue[0.6480091049759613, 1, 0.10275662387943818`], 
           Hue[0.6473537923316892, 1, 0.10366397984843027`], 
           Hue[0.6453186380742276, 1, 0.10648188574337719`], 
           Hue[0.6446747005059975, 1, 0.10737349160708046`], 
           Hue[0.6495581589251697, 1, 0.10061177994976514`], 
           Hue[0.6490171435581193, 1, 0.10136087815029626`], 
           Hue[0.6474600972735775, 1, 0.10351678839043126`], 
           Hue[0.6474700106798338, 1, 0.10350306213561476`], 
           Hue[0.6496149480434029, 1, 0.10053314886298056`], 
           Hue[0.6494928049778319, 1, 0.10070227003069426`], 
           Hue[0.6499659179555519, 1, 0.10004719052308203`], 
           Hue[0.6498666614359694, 1, 0.1001846226271193], 
           Hue[0.6499667588310656, 1, 0.10004602623390928`], 
           Hue[0.6499998944694872, 1, 0.10000014611917156`], 
           Hue[0.6495577101050631, 1, 0.10061240139298953`], 
           Hue[0.6499655367985427, 1, 0.10004771827894092`], 
           Hue[0.649965516562715, 1, 0.10004774629777938`], 
           Hue[0.6496090377308189, 1, 0.10054133237271227`], 
           Hue[0.6499997961154858, 1, 0.10000028230163507`], 
           Hue[0.6490867430856564, 1, 0.10126450957370664`], 
           Hue[0.6474954669797973, 1, 0.10346781495104992`], 
           Hue[0.6294650459019475, 1, 0.12843301336653418`], 
           Hue[0.6474944451681277, 1, 0.10346922976720777`], 
           Hue[0.6474944451680357, 1, 0.10346922976733522`], 
           Hue[0.629465045901841, 1, 0.12843301336668167`], 
           Hue[0.6474954669797108, 1, 0.1034678149511697], 
           Hue[0.649086743085644, 1, 0.1012645095737238], 
           Hue[0.6499997961154859, 1, 0.10000028230163507`], 
           Hue[0.6496090377308191, 1, 0.10054133237271208`], 
           Hue[0.649965516562715, 1, 0.10004774629777935`], 
           Hue[0.6499655367985427, 1, 0.1000477182789409], 
           Hue[0.649299395728952, 1, 0.1009700674522203], 
           Hue[0.6495577101050631, 1, 0.10061240139298959`], 
           Hue[0.649999546284906, 1, 0.10000062822089953`], 
           Hue[0.6499968016948423, 1, 0.10000442842252606`], 
           Hue[0.6499837977879257, 1, 0.10002243383210294`], 
           Hue[0.6499427464970976, 1, 0.10007927408094187`], 
           Hue[0.6498634854226076, 1, 0.10018902018408178`], 
           Hue[0.6499987777339871, 1, 0.10000169236832561`], 
           Hue[0.649993865184265, 1, 0.1000084943602484], 
           Hue[0.6499762536549267, 1, 0.10003287955471693`], 
           Hue[0.6499307068090907, 1, 0.1000959444181821], 
           Hue[0.6498518987975389, 1, 0.10020506320340776`], 
           Hue[0.6499921293089566, 1, 0.10001089787990629`], 
           Hue[0.6499882868309909, 1, 0.10001621823401269`], 
           Hue[0.64995742655059, 1, 0.10005894785302931`], 
           Hue[0.6498432245869256, 1, 0.10021707364887242`], 
           Hue[0.6497995501416562, 1, 0.10027754595770674`], 
           Hue[0.649510432152012, 1, 0.1006778631741373], 
           Hue[0.6499615936668796, 1, 0.1000531779997052], 
           Hue[0.6499507438872519, 1, 0.10006820077149742`], 
           Hue[0.6498799412726701, 1, 0.10016623516091826`], 
           Hue[0.6498506186895233, 1, 0.1002068356606601], 
           Hue[0.649697640812672, 1, 0.10041865118245424`], 
           Hue[0.6496397195744827, 1, 0.10049884981994704`], 
           Hue[0.6435492187575874, 1, 0.1089318509510328], 
           Hue[0.638324715551791, 1, 0.1161657784667509], 
           Hue[0.6228816248504861, 1, 0.1375485194377885], 
           Hue[0.584391631122217, 1, 0.1908423569076996], 
           Hue[0.5180120543224829, 1, 0.28275254016886997`], 
           Hue[0.649671307313124, 1, 0.10045511295105926`], 
           Hue[0.6499080428696402, 1, 0.10012732525742125`], 
           Hue[0.6499810990463154, 1, 0.10002617055125558`], 
           Hue[0.6479034511562572, 1, 0.10290291378364377`], 
           Hue[0.6481488635226674, 1, 0.10256311204553752`], 
           Hue[0.6497769960904989, 1, 0.10030877464392474`], 
           Hue[0.6498161665378681, 1, 0.10025453863987495`], 
           Hue[0.6499471992776278, 1, 0.10007310869251541`], 
           Hue[0.6499585389917856, 1, 0.10005740754983537`], 
           Hue[0.6499903486487819, 1, 0.100013363409379], 
           Hue[0.6499928350255395, 1, 0.10000992073386848`], 
           Hue[0.6499986685807253, 1, 0.10000184350361113`], 
           Hue[0.6499990728488086, 1, 0.10000128374780339`], 
           Hue[0.6499998652875634, 1, 0.10000018652491231`], 
           Hue[0.6499999130990606, 1, 0.10000012032437766`], 
           Hue[0.6499773681890932, 1, 0.10003133635356326`], 
           Hue[0.6498799739553269, 1, 0.10016618990800887`], 
           Hue[0.6139219345410782, 1, 0.14995424448158404`], 
           Hue[0.6276537703969349, 1, 0.13094093329655168`], 
           Hue[0.6369354292276365, 1, 0.11808940568481112`], 
           Hue[0.6416037038677826, 1, 0.11162564079845479`], 
           Hue[0.6437749675546234, 1, 0.10861927569359847`], 
           Hue[0.6499786571222672, 1, 0.10002955167686084`], 
           Hue[0.6499786571222672, 1, 0.10002955167686084`], 
           Hue[0.6498762763822666, 1, 0.10017130962455395`], 
           Hue[0.6499312334274999, 1, 0.10009521525423094`], 
           Hue[0.6499312334274999, 1, 0.10009521525423093`], 
           Hue[0.6499546249480828, 1, 0.10006282699496238`], 
           Hue[0.6499774540762749, 1, 0.10003121743285015`], 
           Hue[0.6442963774517934, 1, 0.1078973235282862], 
           Hue[0.6437749675545958, 1, 0.10861927569363655`], 
           Hue[0.6416037038677707, 1, 0.11162564079847141`], 
           Hue[0.6389584142500377, 1, 0.11528834949994783`], 
           Hue[0.6369354292276032, 1, 0.11808940568485717`], 
           Hue[0.6314113814488912, 1, 0.12573808722461224`], 
           Hue[0.6276537703968138, 1, 0.13094093329671944`], 
           Hue[0.6189100178905788, 1, 0.14304766753612178`], 
           Hue[0.6139219345407914, 1, 0.1499542444819813], 
           Hue[0.6498799739553269, 1, 0.10016618990800895`], 
           Hue[0.6499544789815872, 1, 0.10006302910241778`], 
           Hue[0.6499773681890932, 1, 0.10003133635356329`], 
           Hue[0.6355280494073535, 1, 0.12003808543597211`], 
           Hue[0.6499999130990606, 1, 0.10000012032437766`], 
           Hue[0.6499990728488086, 1, 0.10000128374780339`], 
           Hue[0.6499928350255395, 1, 0.10000992073386847`], 
           Hue[0.6499585389917857, 1, 0.10005740754983528`], 
           Hue[0.6498161665378682, 1, 0.1002545386398748], 
           Hue[0.6355280494071409, 1, 0.12003808543626643`], 
           Hue[0.6499871546152928, 1, 0.100017785917287], 
           Hue[0.6499810990463154, 1, 0.10002617055125557`], 
           Hue[0.6499334733653315, 1, 0.10009211380184872`], 
           Hue[0.6499080428696403, 1, 0.1001273252574212], 
           Hue[0.6497487056715419, 1, 0.10034794599324971`], 
           Hue[0.6496713073131244, 1, 0.10045511295105859`], 
           Hue[0.49721716070467614`, 1, 0.31154546979352543`], 
           Hue[0.518012054323759, 1, 0.28275254016710305`], 
           Hue[0.5843916311228773, 1, 0.1908423569067853], 
           Hue[0.615072853841081, 1, 0.14836066391234937`], 
           Hue[0.6228816248506646, 1, 0.13754851943754146`], 
           Hue[0.6355677813921563, 1, 0.11998307191855279`], 
           Hue[0.6383247155517915, 1, 0.11616577846675029`], 
           Hue[0.6425869541066501, 1, 0.11026421739079217`], 
           Hue[0.643549218757615, 1, 0.10893185095099478`], 
           Hue[0.6499546249480828, 1, 0.10006282699496233`], 
           Hue[0.6499774540762749, 1, 0.10003121743285012`], 
           Hue[0.6496397195744829, 1, 0.10049884981994692`], 
           Hue[0.6498506186895235, 1, 0.10020683566065973`], 
           Hue[0.6499507438872523, 1, 0.10006820077149693`], 
           Hue[0.6495104321520119, 1, 0.10067786317413745`], 
           Hue[0.6497995501416562, 1, 0.10027754595770683`], 
           Hue[0.6499882868309909, 1, 0.10001621823401269`], 
           Hue[0.6498383027784683, 1, 0.10022388846058239`], 
           Hue[0.6498518987975388, 1, 0.10020506320340787`], 
           Hue[0.6499202363144327, 1, 0.10011044202617005`], 
           Hue[0.6499307068090907, 1, 0.10009594441818215`], 
           Hue[0.6499711752825617, 1, 0.10003991114722235`], 
           Hue[0.6499762536549267, 1, 0.10003287955471694`], 
           Hue[0.649992139261425, 1, 0.10001088409956545`], 
           Hue[0.649993865184265, 1, 0.1000084943602484], 
           Hue[0.6499983476490149, 1, 0.10000228787059483`], 
           Hue[0.6499987777339871, 1, 0.10000169236832561`], 
           Hue[0.6498492997424695, 1, 0.10020866189504228`], 
           Hue[0.6498634854226075, 1, 0.10018902018408185`], 
           Hue[0.6499326287044422, 1, 0.1000932833323108], 
           Hue[0.6499427464970975, 1, 0.10007927408094192`], 
           Hue[0.6499796318088381, 1, 0.1000282021108396], 
           Hue[0.6499837977879257, 1, 0.10002243383210295`], 
           Hue[0.6499968016948423, 1, 0.10000442842252608`], 
           Hue[0.6499993476880973, 1, 0.10000090320109607`], 
           Hue[0.649999546284906, 1, 0.10000062822089954`], 
           Hue[0.6499786571222672, 1, 0.10002955167686085`], 
           Hue[0.6499786571222672, 1, 0.10002955167686085`], 
           Hue[0.6499872851621001, 1, 0.10001760516016904`], 
           Hue[0.6499786432660215, 1, 0.10002957086243185`], 
           Hue[0.6499786432660215, 1, 0.10002957086243186`], 
           Hue[0.6481499757638406, 1, 0.10256157201929773`], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499999994667391, 1, 0.10000000073836127`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6499999860214585, 1, 0.10000001935490364`], 
           Hue[0.6481488635226095, 1, 0.10256311204561763`], 
           Hue[0.6481499757637851, 1, 0.10256157201937459`], 
           Hue[0.6499786432660215, 1, 0.10002957086243183`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.6499999936474662, 1, 0.10000000879581607`], 
           Hue[0.649744463028524, 1, 0.10035382042204373`], 
           Hue[0.6497201483868429, 1, 0.1003874868489868], 
           Hue[0.6497393167031356, 1, 0.10036094610335085`], 
           Hue[0.6497201201157683, 1, 0.10038752599355157`], 
           Hue[0.6499731374090271, 1, 0.10003719435673182`], 
           Hue[0.649978584567043, 1, 0.10002965213794048`], 
           Hue[0.64932693666548, 1, 0.10093193384779686`], 
           Hue[0.6496050201873916, 1, 0.10054689512515011`], 
           Hue[0.6496046189157265, 1, 0.10054745073207098`], 
           Hue[0.6498226656875891, 1, 0.1002455398171844], 
           Hue[0.6497422006045631, 1, 0.10035695300906647`], 
           Hue[0.6498702084125652, 1, 0.10017971142875598`], 
           Hue[0.6448140890407267, 1, 0.10718049209745545`], 
           Hue[0.6492714389145245, 1, 0.1010087768875815], 
           Hue[0.6495444786347686, 1, 0.10063072189032049`], 
           Hue[0.635809914745834, 1, 0.11964781035192219`], 
           Hue[0.6499450533801044, 1, 0.10007607993524008`], 
           Hue[0.6498987693663225, 1, 0.10014016549278425`], 
           Hue[0.6499448820990992, 1, 0.10007631709355506`], 
           Hue[0.6498985097083886, 1, 0.10014052501915438`], 
           Hue[0.6499999143695201, 1, 0.1000001185652799], 
           Hue[0.6227153440039659, 1, 0.13777875445604731`], 
           Hue[0.6227153440039653, 1, 0.13777875445604798`], 
           Hue[0.00856416289874995, 1, 0.9881419282940385], 
           Hue[0.008564162897155558, 1, 0.9881419282962461], 
           Hue[0.6227153440043187, 1, 0.13777875445555868`], 
           Hue[0.6227153440043193, 1, 0.13777875445555793`], 
           Hue[0.6430994341870176, 1, 0.10955462958720644`], 
           Hue[0.6430994341870178, 1, 0.10955462958720621`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6430994341869646, 1, 0.10955462958727985`], 
           Hue[0.6430994341869645, 1, 0.10955462958728006`], 
           Hue[0.008564162898749617, 1, 0.988141928294039], 
           Hue[0.008564162897156002, 1, 0.9881419282962455], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.6499995584935135, 1, 0.10000061131667352`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499766495074196, 1, 0.10003233145126517`], 
           Hue[0.6499993787624871, 1, 0.1000008601750178], 
           Hue[0.6499949427213864, 1, 0.10000700238577273`], 
           Hue[0.649969296003201, 1, 0.10004251322633723`], 
           Hue[0.6499999143695201, 1, 0.1000001185652799], 
           Hue[0.6499924815348365, 1, 0.10001041018253413`], 
           Hue[0.649995066268984, 1, 0.10000683131986839`], 
           Hue[0.6326369084383063, 1, 0.12404120370080668`], 
           Hue[0.6278460623886941, 1, 0.13067468284642353`], 
           Hue[0.6498702084125652, 1, 0.10017971142875591`], 
           Hue[0.6495444786347687, 1, 0.10063072189032032`], 
           Hue[0.6499872761827475, 1, 0.1000176175931189], 
           Hue[0.649822601052624, 1, 0.1002456293117514], 
           Hue[0.6494794345021757, 1, 0.10072078299698756`], 
           Hue[0.649327839891267, 1, 0.10093068322747661`], 
           Hue[0.6499785002992394, 1, 0.10002976881643783`], 
           Hue[0.6499785845670428, 1, 0.10002965213794081`], 
           Hue[0.6499145448836653, 1, 0.10011832246877123`], 
           Hue[0.6499298416416035, 1, 0.10009714234239513`], 
           Hue[0.6499807313906684, 1, 0.10002667961292078`], 
           Hue[0.6499852101793618, 1, 0.10002047821319135`], 
           Hue[0.6499875143105937, 1, 0.10001728787763953`], 
           Hue[0.6499844331418096, 1, 0.10002155411134056`], 
           Hue[0.649997177936394, 1, 0.10000390747268527`], 
           Hue[0.6499994806519499, 1, 0.10000071909730011`], 
           Hue[0.6499992967751281, 1, 0.10000097369597646`], 
           Hue[0.6499924900042139, 1, 0.10001039845570384`], 
           Hue[0.6499902455567598, 1, 0.10001350615217874`], 
           Hue[0.649998744591033, 1, 0.10000173825856974`], 
           Hue[0.649998257978814, 1, 0.10000241202933446`], 
           Hue[0.6499998499361392, 1, 0.10000020778073027`], 
           Hue[0.6499997756993264, 1, 0.10000031057016343`], 
           Hue[0.6497393167031354, 1, 0.100360946103351], 
           Hue[0.6497220759135403, 1, 0.10038481796586733`], 
           Hue[0.649744463028524, 1, 0.10035382042204372`], 
           Hue[0.6447602379004875, 1, 0.10725505521470961`], 
           Hue[0.6445860308483407, 1, 0.1074962649792206], 
           Hue[0.6499987762295317, 1, 0.10000169445141766`], 
           Hue[0.6499972833772172, 1, 0.1000037614776993], 
           Hue[0.622715344004319, 1, 0.1377787544555582], 
           Hue[0.6430994341870176, 1, 0.1095546295872063], 
           Hue[0.6455633919912057, 1, 0.10614299570448438`], 
           Hue[0.6499169012778275, 1, 0.10011505976916187`], 
           Hue[0.6499452554080252, 1, 0.10007580020427294`], 
           Hue[0.6499452554080252, 1, 0.10007580020427294`], 
           Hue[0.6448213068074805, 1, 0.10717049826656548`], 
           Hue[0.6447602379007439, 1, 0.10725505521435462`], 
           Hue[0.6450472715451144, 1, 0.106857624014457], 
           Hue[0.6473532864649093, 1, 0.10366468027935632`], 
           Hue[0.6474596176061951, 1, 0.10351745254526841`], 
           Hue[0.649990745780477, 1, 0.10001281353472413`], 
           Hue[0.6499768211371815, 1, 0.10003209381005643`], 
           Hue[0.6499892906359471, 1, 0.10001482835022706`], 
           Hue[0.6499848496426992, 1, 0.10002097741780107`], 
           Hue[0.6499997433419163, 1, 0.10000035537273122`], 
           Hue[0.6497498661728607, 1, 0.10034633914526987`], 
           Hue[0.6498629460993739, 1, 0.10018976693932853`], 
           Hue[0.6497442349944516, 1, 0.10035413616152872`], 
           Hue[0.6498758963289264, 1, 0.10017183585225574`], 
           Hue[0.6499979396020884, 1, 0.10000285285864687`], 
           Hue[0.649985101517905, 1, 0.10002062866751625`], 
           Hue[0.6499883785355535, 1, 0.10001609125846449`], 
           Hue[0.649990745780477, 1, 0.10001281353472413`], 
           Hue[0.6499893270949103, 1, 0.10001477786858572`], 
           Hue[0.6450484170872981, 1, 0.1068560378791257], 
           Hue[0.647353286464909, 1, 0.10366468027935681`], 
           Hue[0.645047271545117, 1, 0.10685762401445344`], 
           Hue[0.6451837682394984, 1, 0.10666862859146373`], 
           Hue[0.6451837682394984, 1, 0.10666862859146374`], 
           Hue[0.644586417592649, 1, 0.10749572948710148`], 
           Hue[0.644643854407393, 1, 0.1074162015897635], 
           Hue[0.6265023909903372, 1, 0.13253515093645618`], 
           Hue[0.6499928687028823, 1, 0.10000987410370149`], 
           Hue[0.6498802677343509, 1, 0.10016578313705254`], 
           Hue[0.6499902459174384, 1, 0.10001350565277763`], 
           Hue[0.649998299585341, 1, 0.10000235442029706`], 
           Hue[0.649997307226403, 1, 0.10000372845574963`], 
           Hue[0.6452024257204503, 1, 0.10664279515629968`], 
           Hue[0.6421328552372512, 1, 0.11089296967149839`], 
           Hue[0.6425888456319614, 1, 0.11026159835574584`], 
           Hue[0.6435506515418182, 1, 0.10892986709594407`], 
           Hue[0.6459425149455353, 1, 0.10561805622925885`], 
           Hue[0.6384789975537194, 1, 0.11595215723331168`], 
           Hue[0.6227153440039657, 1, 0.13777875445604756`], 
           Hue[0.6499987762295317, 1, 0.10000169445141764`], 
           Hue[0.6425888456319463, 1, 0.11026159835576668`], 
           Hue[0.6435506515418299, 1, 0.10892986709592786`], 
           Hue[0.649997307226403, 1, 0.10000372845574962`], 
           Hue[0.6455644065284439, 1, 0.10614159096061612`], 
           Hue[0.6497831131736973, 1, 0.10030030483641918`], 
           Hue[0.649880267734351, 1, 0.10016578313705246`], 
           Hue[0.6499928687028823, 1, 0.10000987410370148`], 
           Hue[0.6265023909906217, 1, 0.13253515093606227`], 
           Hue[0.6446438544074229, 1, 0.1074162015897222], 
           Hue[0.6445864175924402, 1, 0.10749572948739058`], 
           Hue[0.645048417087303, 1, 0.10685603787911896`], 
           Hue[0.6499893270949103, 1, 0.10001477786858572`], 
           Hue[0.6499883785355535, 1, 0.10001609125846449`], 
           Hue[0.6499979396020884, 1, 0.10000285285864687`], 
           Hue[0.6498758963289265, 1, 0.10017183585225567`], 
           Hue[0.6498629460993739, 1, 0.10018976693932845`], 
           Hue[0.649998744591033, 1, 0.10000173825856974`], 
           Hue[0.649998257978814, 1, 0.10000241202933446`], 
           Hue[0.6499998499361392, 1, 0.10000020778073027`], 
           Hue[0.6499997756993264, 1, 0.10000031057016343`], 
           Hue[0.6499924900042139, 1, 0.10001039845570384`], 
           Hue[0.6499902455567599, 1, 0.10001350615217873`], 
           Hue[0.6499985526901774, 1, 0.10000200396744671`], 
           Hue[0.6499680543081146, 1, 0.10004423249645675`], 
           Hue[0.6499611431173056, 1, 0.1000538018375769], 
           Hue[0.6499915553675152, 1, 0.10001169256805592`], 
           Hue[0.6499070733798012, 1, 0.10012866762796759`], 
           Hue[0.6498941642091621, 1, 0.10014654186423702`], 
           Hue[0.6499389913540884, 1, 0.10008447350972374`], 
           Hue[0.6499994806519499, 1, 0.10000071909730011`], 
           Hue[0.6499992967751281, 1, 0.10000097369597646`], 
           Hue[0.649997177936394, 1, 0.10000390747268527`], 
           Hue[0.6499994103243372, 1, 0.1000008164739948], 
           Hue[0.6499875143105937, 1, 0.10001728787763953`], 
           Hue[0.6499844331418096, 1, 0.10002155411134056`], 
           Hue[0.6499968070349429, 1, 0.1000044210285406], 
           Hue[0.6499579058346595, 1, 0.10005828422893295`], 
           Hue[0.6499502404150022, 1, 0.10006889788692015`], 
           Hue[0.6499861817897984, 1, 0.1000191329064331], 
           Hue[0.6498945035414182, 1, 0.10014607201957478`], 
           Hue[0.6498817551107648, 1, 0.10016372369278713`], 
           Hue[0.6499513388525884, 1, 0.10006737697333923`], 
           Hue[0.6499990165514296, 1, 0.10000136169802062`], 
           Hue[0.6499997133311914, 1, 0.10000039692604273`], 
           Hue[0.6499807313906684, 1, 0.10002667961292076`], 
           Hue[0.6499971170968787, 1, 0.10000399171201411`], 
           Hue[0.6499145448836653, 1, 0.10011832246877118`], 
           Hue[0.6499785002992391, 1, 0.10002976881643814`], 
           Hue[0.6499763120114476, 1, 0.10003279875338034`], 
           Hue[0.6499569735915823, 1, 0.1000595750270399], 
           Hue[0.6499305639619215, 1, 0.1000961422065702], 
           Hue[0.6499223977301635, 1, 0.1001074492966967], 
           Hue[0.6499682293104805, 1, 0.10004399018548857`], 
           Hue[0.6498038432915924, 1, 0.10027160159625682`], 
           Hue[0.6497842792878259, 1, 0.10029869021685645`], 
           Hue[0.6499293875019, 1, 0.10009777115121549`], 
           Hue[0.6499955545015644, 1, 0.1000061553055262], 
           Hue[0.6499971445555819, 1, 0.10000395369227129`], 
           Hue[0.6499942337059641, 1, 0.10000798409943434`], 
           Hue[0.6499848496426992, 1, 0.10002097741780107`], 
           Hue[0.6499313963608999, 1, 0.10009498965413854`], 
           Hue[0.6499452847292683, 1, 0.10007575960562864`], 
           Hue[0.6499452847292683, 1, 0.10007575960562864`], 
           Hue[0.6450730162623394, 1, 0.10682197748291483`], 
           Hue[0.6450730162623393, 1, 0.10682197748291483`], 
           Hue[0.6451848600758754, 1, 0.10666711681801869`], 
           Hue[0.6451848600758754, 1, 0.10666711681801869`], 
           Hue[0.6363290967524772, 1, 0.11892894295810859`], 
           Hue[0.6454889217763025, 1, 0.10624610830973502`], 
           Hue[0.649946398470897, 1, 0.10007421750183504`], 
           Hue[0.6499872378397605, 1, 0.10001767068340861`], 
           Hue[0.6499812127959619, 1, 0.10002601305174517`], 
           Hue[0.6123798420897374, 1, 0.15208944941420982`], 
           Hue[0.6314188285390657, 1, 0.1257277758689859], 
           Hue[0.6276615081556854, 1, 0.13093021947674333`], 
           Hue[0.6342357357138686, 1, 0.12182744285772036`], 
           Hue[0.6355735873344104, 1, 0.1199750329215857], 
           Hue[0.6383290297329686, 1, 0.11615980498512041`], 
           Hue[0.6499951048581283, 1, 0.10000677788874544`], 
           Hue[0.6326369084382553, 1, 0.12404120370087737`], 
           Hue[0.6278460623885795, 1, 0.1306746828465822], 
           Hue[0.6498198123292013, 1, 0.10024949062110598`], 
           Hue[0.649865897701864, 1, 0.10018568010511139`], 
           Hue[0.6499924815348365, 1, 0.10001041018253413`], 
           Hue[0.649995066268984, 1, 0.10000683131986839`], 
           Hue[0.6499694960336534, 1, 0.10004223626109528`], 
           Hue[0.6131190636403478, 1, 0.15106591188259538`], 
           Hue[0.6459417553416843, 1, 0.10561910798843711`], 
           Hue[0.6495806066420243, 1, 0.10058069849565873`], 
           Hue[0.6499766495074196, 1, 0.10003233145126522`], 
           Hue[0.6498880939419247, 1, 0.10015494684964274`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499969194200786, 1, 0.10000426541835268`], 
           Hue[0.6499870926215222, 1, 0.10001787175481543`], 
           Hue[0.6499995584935135, 1, 0.10000061131667352`], 
           Hue[0.6499989198255313, 1, 0.10000149562618747`], 
           Hue[0.6499996498839958, 1, 0.10000048477600589`], 
           Hue[0.6499981583263428, 1, 0.10000255000967932`], 
           Hue[0.6499998959071556, 1, 0.10000014412855386`], 
           Hue[0.6499998069333369, 1, 0.10000026732307205`], 
           Hue[1.1102230246251565`*^-16, 1, 0.9999999999999999], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.018968293162061722`, 1, 0.9737362094679146], 
           Hue[0.0021628179027943784`, 1, 0.9970053290576693], 
           Hue[0.0021628179019673732`, 1, 0.9970053290588143], 
           Hue[0.01896829315981796, 1, 0.9737362094710212], 
           Hue[0.6499999419197341, 1, 0.1000000804188298], 
           Hue[0.6499998069333369, 1, 0.10000026732307205`], 
           Hue[0.6499981583263428, 1, 0.10000255000967932`], 
           Hue[0.6499870926215222, 1, 0.10001787175481541`], 
           Hue[0.6498880939419249, 1, 0.10015494684964242`], 
           Hue[0.6495806066420229, 1, 0.10058069849566069`], 
           Hue[0.6499996498839958, 1, 0.10000048477600589`], 
           Hue[0.6499989198255313, 1, 0.10000149562618747`], 
           Hue[0.6499998959071556, 1, 0.10000014412855386`], 
           Hue[0.6499969194200786, 1, 0.10000426541835268`], 
           Hue[0.6499982837325233, 1, 0.10000237637035238`], 
           Hue[0.6499972833772172, 1, 0.1000037614776993], 
           Hue[0.6499694960336535, 1, 0.10004223626109526`], 
           Hue[0.6498198123292014, 1, 0.10024949062110579`], 
           Hue[0.6498658977018641, 1, 0.10018568010511128`], 
           Hue[0.6355735873342693, 1, 0.11997503292178105`], 
           Hue[0.6383290297328634, 1, 0.11615980498526599`], 
           Hue[0.6499872378397605, 1, 0.1000176706834086], 
           Hue[0.6499812127959619, 1, 0.10002601305174516`], 
           Hue[0.6499925368181951, 1, 0.10001033363634519`], 
           Hue[0.6499951048581283, 1, 0.10000677788874544`], 
           Hue[0.6443912491738397, 1, 0.10776596268237587`], 
           Hue[0.6450814653729413, 1, 0.10681027871438892`], 
           Hue[0.6499448820990992, 1, 0.10007631709355502`], 
           Hue[0.6498985097083886, 1, 0.1001405250191543], 
           Hue[0.6314188285392321, 1, 0.12572777586875555`], 
           Hue[0.6276615081559497, 1, 0.1309302194763774], 
           Hue[0.6123798420903684, 1, 0.15208944941333602`], 
           Hue[0.635809914745879, 1, 0.11964781035185994`], 
           Hue[0.6344958252613736, 1, 0.12146731886886732`], 
           Hue[0.6498987693663226, 1, 0.10014016549278415`], 
           Hue[0.649950695639109, 1, 0.1000682675766184], 
           Hue[0.6363290967525409, 1, 0.11892894295802031`], 
           Hue[0.6499169408087976, 1, 0.10011500503397268`], 
           Hue[0.6499452847292683, 1, 0.10007575960562862`], 
           Hue[0.6451848600758786, 1, 0.10666711681801425`], 
           Hue[0.6499384202733739, 1, 0.10008526423686702`], 
           Hue[0.6499313963608999, 1, 0.10009498965413856`], 
           Hue[0.644586030848589, 1, 0.10749626497887677`], 
           Hue[0.6493269366655053, 1, 0.10093193384776192`], 
           Hue[0.6496050201873775, 1, 0.10054689512516958`], 
           Hue[0.6499971445555819, 1, 0.1000039536922713], 
           Hue[0.6499942337059641, 1, 0.10000798409943434`], 
           Hue[0.6499682293104808, 1, 0.10004399018548812`], 
           Hue[0.6499971170968787, 1, 0.10000399171201411`], 
           Hue[0.6498038432915926, 1, 0.10027160159625655`], 
           Hue[0.6497842792878261, 1, 0.10029869021685618`], 
           Hue[0.6499305639619218, 1, 0.10009614220656972`], 
           Hue[0.6499223977301639, 1, 0.10010744929669622`], 
           Hue[0.6499569735915827, 1, 0.10005957502703941`], 
           Hue[0.6499764116330907, 1, 0.10003266081572051`], 
           Hue[0.649999101927029, 1, 0.10000124348565209`], 
           Hue[0.649925810454061, 1, 0.10010272398668485`], 
           Hue[0.6499740052775556, 1, 0.10003599269261544`], 
           Hue[0.6499931350584105, 1, 0.10000950530373938`], 
           Hue[0.6499986042640042, 1, 0.10000193255753263`], 
           Hue[0.6499380881968962, 1, 0.10008572403506673`], 
           Hue[0.6499820089674371, 1, 0.10002491066047177`], 
           Hue[0.6499963588136884, 1, 0.10000504164258525`], 
           Hue[0.6499994700011782, 1, 0.10000073384452254`], 
           Hue[0.6499513388525884, 1, 0.10006737697333921`], 
           Hue[0.6499074536869546, 1, 0.10012814104883216`], 
           Hue[0.6498945576128976, 1, 0.10014599715137257`], 
           Hue[0.6498945035414182, 1, 0.10014607201957484`], 
           Hue[0.6498817551107648, 1, 0.10016372369278721`], 
           Hue[0.6499579058346595, 1, 0.10005828422893297`], 
           Hue[0.6499502404150022, 1, 0.10006889788692018`], 
           Hue[0.6499389913540885, 1, 0.10008447350972371`], 
           Hue[0.6498948423987034, 1, 0.10014560283256445`], 
           Hue[0.6498821047507632, 1, 0.10016323957586631`], 
           Hue[0.6499070733798011, 1, 0.10012866762796764`], 
           Hue[0.6498941642091621, 1, 0.10014654186423709`], 
           Hue[0.6499680543081146, 1, 0.10004423249645678`], 
           Hue[0.6499611431173056, 1, 0.10005380183757692`], 
           Hue[0.6498821047507631, 1, 0.1001632395758664], 
           Hue[0.6499504648283491, 1, 0.10006858716074746`], 
           Hue[0.6498945576128976, 1, 0.10014599715137261`], 
           Hue[0.6499836181429697, 1, 0.10002268257127285`], 
           Hue[0.6499764116330911, 1, 0.10003266081572015`], 
           Hue[0.649327839891292, 1, 0.100930683227442], 
           Hue[0.6499696557470173, 1, 0.10004201511951463`], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499998973914634, 1, 0.10000014207335849`], 
           Hue[0.6499696557470173, 1, 0.1000420151195146], 
           Hue[0.6495118930856898, 1, 0.10067584034289113`], 
           Hue[0.649604618915741, 1, 0.10054745073205101`], 
           Hue[0.6499763120114478, 1, 0.10003279875337998`], 
           Hue[0.6499996718109462, 1, 0.10000045441561291`], 
           Hue[0.6499997221218345, 1, 0.10000038475438296`], 
           Hue[0.6499996739625998, 1, 0.1000004514364003], 
           Hue[0.6499997231111884, 1, 0.10000038338450845`], 
           Hue[0.6499994854782605, 1, 0.10000071241471627`], 
           Hue[0.6499993034614677, 1, 0.10000096443796776`], 
           Hue[0.6499581095157081, 1, 0.10005800220901964`], 
           Hue[0.6499504648283491, 1, 0.10006858716074744`], 
           Hue[0.6499994700011782, 1, 0.10000073384452254`], 
           Hue[0.6499963588136884, 1, 0.10000504164258524`], 
           Hue[0.6499820089674371, 1, 0.10002491066047176`], 
           Hue[0.6499380881968964, 1, 0.10008572403506669`], 
           Hue[0.6499986042640042, 1, 0.10000193255753263`], 
           Hue[0.6499931350584105, 1, 0.10000950530373937`], 
           Hue[0.6499740052775556, 1, 0.10003599269261543`], 
           Hue[0.6499258104540611, 1, 0.1001027239866848], 
           Hue[0.6496495783709015, 1, 0.10048519917875173`], 
           Hue[0.649621458422506, 1, 0.10052413449191479`], 
           Hue[0.649615310956587, 1, 0.10053264636780261`], 
           Hue[0.6496211353704806, 1, 0.10052458179471914`], 
           Hue[0.6496149480433895, 1, 0.10053314886299929`], 
           Hue[0.6498226010526239, 1, 0.1002456293117515], 
           Hue[0.6344958252613189, 1, 0.12146731886894314`], 
           Hue[0.6499979068548963, 1, 0.10000289820091286`], 
           Hue[0.6499999463041645, 1, 0.10000007434808002`], 
           Hue[0.6499997881961503, 1, 0.10000029326686882`], 
           Hue[0.6499998875844862, 1, 0.10000015565224989`], 
           Hue[0.6499961977161761, 1, 0.1000052647006792], 
           Hue[0.6499715658257951, 1, 0.10003937039505302`], 
           Hue[0.10275085520088534`, 1, 0.8577295851064664], 
           Hue[0.07116385446585627, 1, 0.9014654322780451], 
           Hue[0.6498321507756426, 1, 0.10023240661834108`], 
           Hue[0.6499999706508989, 1, 0.1000000406372169], 
           Hue[0.008564162898749839, 1, 0.9881419282940387], 
           Hue[0.00856416289715578, 1, 0.9881419282962458], 
           Hue[0.6499999463041645, 1, 0.10000007434808002`], 
           Hue[0.6499979259072688, 1, 0.10000287182070478`], 
           Hue[0.6498226656875892, 1, 0.1002455398171843], 
           Hue[0.6499835735373029, 1, 0.10002274433296532`], 
           Hue[0.6499817210220853, 1, 0.10002530935403585`], 
           Hue[0.6499836181429695, 1, 0.10002268257127303`], 
           Hue[0.6499817845643628, 1, 0.10002522137242074`], 
           Hue[0.6499861817897984, 1, 0.1000191329064331], 
           Hue[0.6499968070349429, 1, 0.1000044210285406], 
           Hue[0.6499994103243372, 1, 0.1000008164739948], 
           Hue[0.6499915553675152, 1, 0.10001169256805592`], 
           Hue[0.6499985526901774, 1, 0.10000200396744673`], 
           Hue[0.6499998221998805, 1, 0.10000024618478089`], 
           Hue[0.6499906782378703, 1, 0.10001290705525656`], 
           Hue[0.6446386253957014, 1, 0.10742344175979816`], 
           Hue[0.6447609920664576, 1, 0.10725401098490486`], 
           Hue[0.649998345225296, 1, 0.1000022912265133], 
           Hue[0.6499993476936773, 1, 0.1000009031933699], 
           Hue[0.6499997070467911, 1, 0.10000040562752005`], 
           Hue[0.6499995636115868, 1, 0.10000060423011056`], 
           Hue[0.6483242391402418, 1, 0.10232028426735747`], 
           Hue[0.6483242391402418, 1, 0.10232028426735751`], 
           Hue[0.6483242391402418, 1, 0.10232028426735748`], 
           Hue[0.6483242391402463, 1, 0.1023202842673513], 
           Hue[0.6483242391402464, 1, 0.10232028426735125`], 
           Hue[0.6483242391402463, 1, 0.10232028426735128`], 
           Hue[0.6469166687904662, 1, 0.10426922782858529`], 
           Hue[0.6450730162625556, 1, 0.10682197748261522`], 
           Hue[0.6450730162625556, 1, 0.10682197748261522`], 
           Hue[0.6446427123917254, 1, 0.10741778284222633`], 
           Hue[0.6451837682394976, 1, 0.10666862859146478`], 
           Hue[0.6451837682394977, 1, 0.10666862859146477`], 
           Hue[0.647847739448394, 1, 0.10298005307145448`], 
           Hue[0.6476673319658687, 1, 0.1032298480472588], 
           Hue[0.6475036441269619, 1, 0.1034564927472835], 
           Hue[0.6475036441269619, 1, 0.10345649274728348`], 
           Hue[0.6473254666988637, 1, 0.10370319995541953`], 
           Hue[0.6499997114379519, 1, 0.10000039954745131`], 
           Hue[0.649838667427071, 1, 0.10022338356251717`], 
           Hue[0.6498522655918395, 1, 0.10020455533437608`], 
           Hue[0.649849705083499, 1, 0.1002081006536168], 
           Hue[0.6498638958591648, 1, 0.10018845188731024`], 
           Hue[0.6499964999597848, 1, 0.10000484620952874`], 
           Hue[0.6499892906359471, 1, 0.10001482835022706`], 
           Hue[0.6473254666988637, 1, 0.10370319995541954`], 
           Hue[0.648184760828347, 1, 0.10251340808382732`], 
           Hue[0.6478477394483939, 1, 0.10298005307145464`], 
           Hue[0.6475036441269618, 1, 0.10345649274728375`], 
           Hue[0.6475036441269617, 1, 0.10345649274728376`], 
           Hue[0.644642712391751, 1, 0.10741778284219103`], 
           Hue[0.6447410918958458, 1, 0.1072815650672905], 
           Hue[0.6447410918958458, 1, 0.1072815650672905], 
           Hue[0.644822685525103, 1, 0.1071685892729343], 
           Hue[0.644822685525103, 1, 0.10716858927293431`], 
           Hue[0.6447422602883427, 1, 0.10727994729306398`], 
           Hue[0.6447422602883427, 1, 0.10727994729306398`], 
           Hue[0.6039331393078194, 1, 0.16378488403532698`], 
           Hue[0.599124239982273, 1, 0.17044336002454505`], 
           Hue[0.6450803703104249, 1, 0.10681179495479633`], 
           Hue[0.6469166687904262, 1, 0.10426922782864076`], 
           Hue[0.6452016973297894, 1, 0.10664380369721467`], 
           Hue[0.6432970668472778, 1, 0.10928098436530766`], 
           Hue[0.6432970668470466, 1, 0.10928098436562779`], 
           Hue[0.6450761923626182, 1, 0.10681757980560565`], 
           Hue[0.5959045810185231, 1, 0.17490134935896817`], 
           Hue[0.5991242399827877, 1, 0.17044336002383234`], 
           Hue[0.6448438343094479, 1, 0.10713930634076449`], 
           Hue[0.644742260288362, 1, 0.1072799472930372], 
           Hue[0.6446754130691614, 1, 0.1073725049811612], 
           Hue[0.6448226855248731, 1, 0.1071685892732527], 
           Hue[0.649849705083499, 1, 0.10020810065361674`], 
           Hue[0.6498638958591649, 1, 0.10018845188731017`], 
           Hue[0.6498386674270711, 1, 0.10022338356251706`], 
           Hue[0.6498522655918396, 1, 0.10020455533437599`], 
           Hue[0.6499766758185227, 1, 0.10003229502050702`], 
           Hue[0.6499991149582264, 1, 0.10000122544245589`], 
           Hue[0.6499998221998805, 1, 0.10000024618478089`], 
           Hue[0.6499943973499914, 1, 0.10000775751539649`], 
           Hue[0.6499205322569598, 1, 0.10011003225959411`], 
           Hue[0.6499309840236278, 1, 0.10009556058266922`], 
           Hue[0.649979910447695, 1, 0.1000278163031916], 
           Hue[0.6499993034614677, 1, 0.10000096443796776`], 
           Hue[0.6499996739625998, 1, 0.1000004514364003], 
           Hue[0.6499997231111884, 1, 0.10000038338450845`], 
           Hue[0.6499996082984593, 1, 0.1000005423559795], 
           Hue[0.6499997221218345, 1, 0.10000038475438296`], 
           Hue[0.6499996049868014, 1, 0.10000054694135192`], 
           Hue[0.6499978738704448, 1, 0.10000294387169176`], 
           Hue[0.6499329557399242, 1, 0.10009283051395126`], 
           Hue[0.6499430494131798, 1, 0.10007885465867405`], 
           Hue[0.6499941827230284, 1, 0.1000080546911914], 
           Hue[0.6499852320800056, 1, 0.10002044788922305`], 
           Hue[0.6499835735373027, 1, 0.1000227443329655], 
           Hue[0.6499452554080251, 1, 0.10007580020427298`], 
           Hue[0.6499452554080251, 1, 0.10007580020427298`], 
           Hue[0.6397468996933219, 1, 0.1141966004246313], 
           Hue[0.6413526165411418, 1, 0.1119733001738037], 
           Hue[0.6189168169696497, 1, 0.14303825342663892`], 
           Hue[0.6139274757408153, 1, 0.14994657205117884`], 
           Hue[0.5666286137183364, 1, 0.21543730408230344`], 
           Hue[0.6499979259072688, 1, 0.10000287182070478`], 
           Hue[0.634303883883022, 1, 0.12173308385427735`], 
           Hue[0.6113350077372445, 1, 0.15353614313304617`], 
           Hue[0.615088110609863, 1, 0.14833953915557424`], 
           Hue[0.6228939004999126, 1, 0.13753152238473657`], 
           Hue[0.6499903637000147, 1, 0.10001334256921046`], 
           Hue[0.6499998973914634, 1, 0.10000014207335849`], 
           Hue[0.6497210465128499, 1, 0.10038624328990012`], 
           Hue[0.6499317360308978, 1, 0.10009451934183383`], 
           Hue[0.649988567829675, 1, 0.10001582915891158`], 
           Hue[0.649986680500004, 1, 0.1000184423846099], 
           Hue[0.6499987371330672, 1, 0.10000174858498384`], 
           Hue[0.6499992903837791, 1, 0.10000098254553669`], 
           Hue[0.6499892775816672, 1, 0.10001484642538383`], 
           Hue[0.6499935635661466, 1, 0.10000891198533556`], 
           Hue[0.6499547241190271, 1, 0.10006268968134718`], 
           Hue[0.6499821959348161, 1, 0.10002465178256234`], 
           Hue[0.6499904136321839, 1, 0.10001327343236079`], 
           Hue[0.649986680500004, 1, 0.10001844238460987`], 
           Hue[0.6499317360308979, 1, 0.10009451934183364`], 
           Hue[0.6497210465128498, 1, 0.1003862432899004], 
           Hue[0.10275085519733629`, 1, 0.8577295851113805], 
           Hue[0.6499973394962008, 1, 0.10000368377449126`], 
           Hue[0.649998345225296, 1, 0.1000022912265133], 
           Hue[0.6499995636115868, 1, 0.10000060423011056`], 
           Hue[0.6499979068548963, 1, 0.10000289820091286`], 
           Hue[0.6150881106096312, 1, 0.14833953915589532`], 
           Hue[0.6228939004996968, 1, 0.1375315223850352], 
           Hue[0.6424451989541747, 1, 0.11046049375575805`], 
           Hue[0.6427107986431146, 1, 0.1100927403403028], 
           Hue[0.649950538320686, 1, 0.10006848540212708`], 
           Hue[0.6189168169701293, 1, 0.1430382534259747], 
           Hue[0.6139274757414217, 1, 0.14994657205033926`], 
           Hue[0.6413526165411501, 1, 0.11197330017379226`], 
           Hue[0.6447609920662616, 1, 0.10725401098517635`], 
           Hue[0.6496495783709018, 1, 0.10048519917875146`], 
           Hue[0.649652358023095, 1, 0.10048135042956088`], 
           Hue[0.649621458422494, 1, 0.10052413449193147`], 
           Hue[0.6499941827230284, 1, 0.1000080546911914], 
           Hue[0.6499329557399242, 1, 0.10009283051395124`], 
           Hue[0.6499430494131799, 1, 0.10007885465867403`], 
           Hue[0.649979910447695, 1, 0.10002781630319159`], 
           Hue[0.6499713297183559, 1, 0.10003969731304567`], 
           Hue[0.649976389667182, 1, 0.10003269123005579`], 
           Hue[0.6499205322569599, 1, 0.10011003225959407`], 
           Hue[0.6499309840236278, 1, 0.10009556058266918`], 
           Hue[0.6499926102537842, 1, 0.10001023195629886`], 
           Hue[0.6499766758185227, 1, 0.100032295020507], 
           Hue[0.6499906782378703, 1, 0.10001290705525656`], 
           Hue[0.6499713297183559, 1, 0.10003969731304568`], 
           Hue[0.649976389667182, 1, 0.10003269123005579`], 
           Hue[0.6499996709568588, 1, 0.10000045559819547`], 
           Hue[0.649999779338247, 1, 0.10000030553165791`], 
           Hue[0.6498321507756425, 1, 0.10023240661834114`], 
           Hue[0.07116385446886919, 1, 0.9014654322738734], 
           Hue[0.649621135370493, 1, 0.10052458179470194`], 
           Hue[0.6499996709568588, 1, 0.10000045559819547`], 
           Hue[0.6499998525302062, 1, 0.10000020418894534`], 
           Hue[0.649999779338247, 1, 0.10000030553165791`], 
           Hue[0.6499997881961503, 1, 0.10000029326686882`], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.649940220239339, 1, 0.1000827719762999], 
           Hue[0.6499302912297338, 1, 0.10009651983575332`], 
           Hue[0.6497575876165925, 1, 0.10033564791548731`], 
           Hue[0.649717658604433, 1, 0.10039093424001597`], 
           Hue[0.5985789422584306, 1, 0.17119838764217316`], 
           Hue[0.6361358775824967, 1, 0.11919647719346611`], 
           Hue[0.6465876268599808, 1, 0.10472482434771894`], 
           Hue[0.6499984458205482, 1, 0.1000021519407794], 
           Hue[0.6499984458205482, 1, 0.1000021519407794], 
           Hue[0.6496628369321749, 1, 0.10046684117083483`], 
           Hue[0.5991253617568926, 1, 0.17044180679814872`], 
           Hue[0.5936528925800798, 1, 0.17801907181219717`], 
           Hue[0.6499122626117608, 1, 0.10012148253756195`], 
           Hue[0.6498691588927481, 1, 0.10018116461004108`], 
           Hue[0.6499509547899046, 1, 0.10006790875243984`], 
           Hue[0.6449129383762623, 1, 0.10704362378671385`], 
           Hue[0.6447410918958291, 1, 0.10728156506731357`], 
           Hue[0.6447410918958292, 1, 0.10728156506731355`], 
           Hue[0.6474431293251607, 1, 0.10354028247285443`], 
           Hue[0.6499917352412674, 1, 0.10001144351209136`], 
           Hue[0.6499817734807857, 1, 0.10002523671891218`], 
           Hue[0.6416068802400537, 1, 0.11162124274454101`], 
           Hue[0.6499940613673298, 1, 0.10000822272215877`], 
           Hue[0.6498321507756425, 1, 0.10023240661834114`], 
           Hue[0.6496444802835842, 1, 0.10049225806888334`], 
           Hue[0.6497775656083637, 1, 0.10030798608072715`], 
           Hue[0.6497176586044328, 1, 0.10039093424001616`], 
           Hue[0.649947428513126, 1, 0.10007279128951778`], 
           Hue[0.6499302912297339, 1, 0.10009651983575313`], 
           Hue[0.6499999025254264, 1, 0.10000013496479421`], 
           Hue[0.6498691588927484, 1, 0.10018116461004063`], 
           Hue[0.6499398049604824, 1, 0.10008334697779356`], 
           Hue[0.6499509547899049, 1, 0.10006790875243936`], 
           Hue[0.03305932787447796, 1, 0.9542255460199536], 
           Hue[0.05053038130973697, 1, 0.9300348566480564], 
           Hue[0.6499983626934944, 1, 0.10000226703977699`], 
           Hue[0.6499987893805093, 1, 0.10000167624237187`], 
           Hue[0.6499977154256198, 1, 0.10000316325683417`], 
           Hue[0.6450736851083142, 1, 0.10682105138848805`], 
           Hue[0.6450736851083142, 1, 0.10682105138848805`], 
           Hue[0.6465876268599643, 1, 0.10472482434774175`], 
           Hue[0.6491923510353136, 1, 0.1011182831818735], 
           Hue[0.646236624228737, 1, 0.10521082799097971`], 
           Hue[0.6454530964615557, 1, 0.10629571259169222`], 
           Hue[0.6459907714908584, 1, 0.10555123947419615`], 
           Hue[0.6448435305234965, 1, 0.10713972696746633`], 
           Hue[0.5961398668207601, 1, 0.1745755690174091], 
           Hue[0.5988995745045004, 1, 0.170754435301461], 
           Hue[0.5856170866541521, 1, 0.18914557232502022`], 
           Hue[0.6499896086305067, 1, 0.10001438805006765`], 
           Hue[0.6499845305213169, 1, 0.10002141927817668`], 
           Hue[0.6498891968769868, 1, 0.10015341970878756`], 
           Hue[0.6499289484739933, 1, 0.10009837903600931`], 
           Hue[0.6499928871566862, 1, 0.10000984855228068`], 
           Hue[0.5901051118871274, 1, 0.1829313835409005], 
           Hue[0.6072701026756729, 1, 0.159164473218299], 
           Hue[0.595645576906745, 1, 0.17525997043681454`], 
           Hue[0.6444958224282412, 1, 0.1076211689455122], 
           Hue[0.6490376229975539, 1, 0.10133252200338695`], 
           Hue[0.6498946193265016, 1, 0.10014591170176697`], 
           Hue[0.6499308362608209, 1, 0.1000957651773249], 
           Hue[0.6499948524777456, 1, 0.10000712733850615`], 
           Hue[0.649994143903924, 1, 0.10000810844072064`], 
           Hue[0.6498166833888368, 1, 0.1002538230000721], 
           Hue[0.6499587350003936, 1, 0.10005713615330115`], 
           Hue[0.6499998252030462, 1, 0.10000024202655138`], 
           Hue[0.6476127536334878, 1, 0.10330541804594007`], 
           Hue[0.6499581095157081, 1, 0.10005800220901967`], 
           Hue[0.6498383027784684, 1, 0.10022388846058226`], 
           Hue[0.6494842522907945, 1, 0.10071411221274607`], 
           Hue[0.6499119444868923, 1, 0.10012192301814919`], 
           Hue[0.6490246129733724, 1, 0.10135053588302283`], 
           Hue[0.6486614185740522, 1, 0.1018534204359277], 
           Hue[0.6490374185577825, 1, 0.10133280507383957`], 
           Hue[0.6476512819637038, 1, 0.10325207112717934`], 
           Hue[0.6479788895815403, 1, 0.10279846057940577`], 
           Hue[0.6489306887868327, 1, 0.1014805847566932], 
           Hue[0.6460978666860362, 1, 0.10540295381933454`], 
           Hue[0.6493199214653446, 1, 0.10094164720183067`], 
           Hue[0.6475834488846838, 1, 0.10334599385197639`], 
           Hue[0.6327196532763, 1, 0.12392663392512315`], 
           Hue[0.6499973394962008, 1, 0.10000368377449126`], 
           Hue[0.45983657272680345`, 1, 0.3633032069936568], 
           Hue[0.5972214239242457, 1, 0.1730780284125829], 
           Hue[0.6443792387298601, 1, 0.10778259252788604`], 
           Hue[0.6472945453822796, 1, 0.10374601408607448`], 
           Hue[0.6494380510073349, 1, 0.10077808322061334`], 
           Hue[0.6497422006045632, 1, 0.10035695300906636`], 
           Hue[0.6446614119197689, 1, 0.1073918911880123], 
           Hue[0.6498543989283845, 1, 0.1002016014837754], 
           Hue[0.6489814055841804, 1, 0.10141036149882726`], 
           Hue[0.6477602551397652, 1, 0.10310118519109432`], 
           Hue[0.6490601902829679, 1, 0.10130127499281374`], 
           Hue[0.6472376528774036, 1, 0.10382478832359494`], 
           Hue[0.6496859288220751, 1, 0.10043486778481911`], 
           Hue[0.6491243397305978, 1, 0.1012124526807107], 
           Hue[0.6486561461999454, 1, 0.10186072064622959`], 
           Hue[0.6488750409140392, 1, 0.1015576356574842], 
           Hue[0.6499987823857478, 1, 0.1000016859274261], 
           Hue[0.6498176582689631, 1, 0.10025247316605117`], 
           Hue[0.6447269791198692, 1, 0.10730110583402737`], 
           Hue[0.6066823642767425, 1, 0.15997826484758743`], 
           Hue[0.6475890729501602, 1, 0.1033382066843936], 
           Hue[0.6449354756217119, 1, 0.1070124183699374], 
           Hue[0.6494383119686701, 1, 0.10077772188953373`], 
           Hue[0.6499098804701534, 1, 0.10012478088747992`], 
           Hue[0.6499098804701535, 1, 0.1001247808874797], 
           Hue[0.6492133707832605, 1, 0.10108917891548559`], 
           Hue[0.6494383119686716, 1, 0.10077772188953155`], 
           Hue[0.6449363081981928, 1, 0.10701126557173313`], 
           Hue[0.42186155100379946`, 1, 0.4158840063024316], 
           Hue[0.6475890729501655, 1, 0.10333820668438627`], 
           Hue[0.6066823642771308, 1, 0.1599782648470497], 
           Hue[0.6448226855248731, 1, 0.1071685892732527], 
           Hue[0.649817658268963, 1, 0.10025247316605124`], 
           Hue[0.6497216634938592, 1, 0.10038538900850273`], 
           Hue[0.6499852500802349, 1, 0.10002042296582866`], 
           Hue[0.649652358023096, 1, 0.1004813504295595], 
           Hue[0.6475004150899573, 1, 0.1034609637215976], 
           Hue[0.6485711159572849, 1, 0.10197845482837478`], 
           Hue[0.5947857583623852, 1, 0.17645048842131275`], 
           Hue[0.6066857938385622, 1, 0.15997351622352923`], 
           Hue[0.6330024607853376, 1, 0.12353505429722485`], 
           Hue[0.6486670765987, 1, 0.10184558624795385`], 
           Hue[0.369936658750547, 1, 0.48778001096078116`], 
           Hue[0.4218763261831908, 1, 0.4158635483617358], 
           Hue[0.6492143200935557, 1, 0.10108786448584597`], 
           Hue[0.10550699045395528`, 1, 0.853913397832985], 
           Hue[0.19694005227927658`, 1, 0.7273137737671554], 
           Hue[0.10551553714730144`, 1, 0.8539015639498903], 
           Hue[0.6492143200935481, 1, 0.10108786448585651`], 
           Hue[0.6483449140191628, 1, 0.10229165751192848`], 
           Hue[0.42187632618421733`, 1, 0.41586354836031447`], 
           Hue[0.3699389649367029, 1, 0.48777681777994986`], 
           Hue[0.594785897687917, 1, 0.176450295509038], 
           Hue[0.6475004150899578, 1, 0.10346096372159692`], 
           Hue[0.6496523174518581, 1, 0.10048140660511957`], 
           Hue[0.6489651538469169, 1, 0.10143286390426892`], 
           Hue[0.6499852320800057, 1, 0.10002044788922296`], 
           Hue[0.6498180333025885, 1, 0.1002519538887237], 
           Hue[0.6497216634938593, 1, 0.10038538900850262`], 
           Hue[0.649941550412067, 1, 0.10008093019867641`], 
           Hue[0.6497967031430822, 1, 0.10028148795573225`], 
           Hue[0.649941550412067, 1, 0.10008093019867643`], 
           Hue[0.6448143518714418, 1, 0.10718012817800371`], 
           Hue[0.6329576816102662, 1, 0.12359705623193912`], 
           Hue[0.6448140890408159, 1, 0.10718049209733183`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.649721605398353, 1, 0.10038546944843434`], 
           Hue[0.6450803703104622, 1, 0.10681179495474478`], 
           Hue[0.6497970985365656, 1, 0.10028094048783229`], 
           Hue[0.6497970985365656, 1, 0.10028094048783216`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499418600005051, 1, 0.1000805015377621], 
           Hue[0.6450814653729043, 1, 0.10681027871444017`], 
           Hue[0.6499565454836217, 1, 0.10006016779190843`], 
           Hue[0.6499565454836217, 1, 0.1000601677919084], 
           Hue[0.6454889217763369, 1, 0.1062461083096875], 
           Hue[0.6329576816103337, 1, 0.12359705623184569`], 
           Hue[0.6499418600005051, 1, 0.10008050153776213`], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499996087792145, 1, 0.10000054169031844`], 
           Hue[0.6499567540632241, 1, 0.10005987898938218`], 
           Hue[0.6474431293251608, 1, 0.10354028247285428`], 
           Hue[0.6454878932078032, 1, 0.10624753248150337`], 
           Hue[0.6450761923628122, 1, 0.10681757980533695`], 
           Hue[0.5666286137182623, 1, 0.21543730408240602`], 
           Hue[0.6499971946455725, 1, 0.10000388433689966`], 
           Hue[0.6442370654339595, 1, 0.10797944786067142`], 
           Hue[0.6473386224356845, 1, 0.10368498431982147`], 
           Hue[0.6425433794512151, 1, 0.1103245515290868], 
           Hue[0.6499097362338684, 1, 0.10012498059925916`], 
           Hue[0.6497911224533827, 1, 0.10028921506454719`], 
           Hue[0.6497234483054741, 1, 0.10038291773088195`], 
           Hue[0.649995891364032, 1, 0.10000568888057104`], 
           Hue[0.6499997133311914, 1, 0.10000039692604273`], 
           Hue[0.6497233765288313, 1, 0.10038301711392589`], 
           Hue[0.6497943170473904, 1, 0.10028479178053641`], 
           Hue[0.6499458125596493, 1, 0.10007502876356245`], 
           Hue[0.6489344903150339, 1, 0.10147532110226072`], 
           Hue[0.6486593996716279, 1, 0.10185621583928456`], 
           Hue[0.6489003584073849, 1, 0.10152258066669777`], 
           Hue[0.6499848496426992, 1, 0.10002097741780107`], 
           Hue[0.648945328630618, 1, 0.10146031420375959`], 
           Hue[0.6495908047814821, 1, 0.10056657799487091`], 
           Hue[0.6472015028703471, 1, 0.10387484217951948`], 
           Hue[0.6495371410484513, 1, 0.10064088162522138`], 
           Hue[0.6479012991383333, 1, 0.10290589350076933`], 
           Hue[0.6445975391505655, 1, 0.10748033040690941`], 
           Hue[0.4363713103250134, 1, 0.39579357031921225`], 
           Hue[0.3699378118431322, 1, 0.48777841437104774`], 
           Hue[0.4363885413626311, 1, 0.3957697119594339], 
           Hue[0.6479116918971519, 1, 0.10289150352702038`], 
           Hue[0.649559230442396, 1, 0.10061029631052858`], 
           Hue[0.6491292687549561, 1, 0.10120562787775308`], 
           Hue[0.10275085520088556`, 1, 0.8577295851064661], 
           Hue[0.6489000604437772, 1, 0.10152299323169314`], 
           Hue[0.6472086250834637, 1, 0.10386498065366576`], 
           Hue[0.5936528925800799, 1, 0.17801907181219712`], 
           Hue[0.6099350580464594, 1, 0.1554745350125947], 
           Hue[0.647201502870347, 1, 0.10387484217951967`], 
           Hue[0.648900358407385, 1, 0.10152258066669763`], 
           Hue[0.6473904480212564, 1, 0.10361322581672193`], 
           Hue[0.6463615928568269, 1, 0.105037794505932], 
           Hue[0.6448435305234965, 1, 0.10713972696746633`], 
           Hue[0.6447636185417649, 1, 0.10725037432678715`], 
           Hue[0.648659399671628, 1, 0.10185621583928438`], 
           Hue[0.6480246283909675, 1, 0.10273512992019884`], 
           Hue[0.6496495783709018, 1, 0.10048519917875146`], 
           Hue[0.6479012991383548, 1, 0.1029058935007395], 
           Hue[0.6489344903150339, 1, 0.10147532110226079`], 
           Hue[0.6495371410484526, 1, 0.10064088162521953`], 
           Hue[0.6495371410484527, 1, 0.10064088162521938`], 
           Hue[0.648934490315034, 1, 0.10147532110226068`], 
           Hue[0.647901299138362, 1, 0.10290589350072946`], 
           Hue[0.6480246283909674, 1, 0.10273512992019894`], 
           Hue[0.6486593996716278, 1, 0.1018562158392846], 
           Hue[0.6447636185419895, 1, 0.1072503743264761], 
           Hue[0.6448142204560843, 1, 0.10718031013772958`], 
           Hue[0.646361592856824, 1, 0.10503779450593599`], 
           Hue[0.6473904480212559, 1, 0.1036132258167227], 
           Hue[0.6489003584073845, 1, 0.1015225806666984], 
           Hue[0.6472015028703367, 1, 0.10387484217953377`], 
           Hue[0.6099350580461176, 1, 0.15547453501306802`], 
           Hue[0.5947858280247514, 1, 0.17645039196572884`], 
           Hue[0.647208625083455, 1, 0.1038649806536777], 
           Hue[0.6489000604437767, 1, 0.10152299323169388`], 
           Hue[0.19694005227927797`, 1, 0.7273137737671536], 
           Hue[0.6491292687549454, 1, 0.10120562787776805`], 
           Hue[0.649559230442397, 1, 0.10061029631052726`], 
           Hue[0.6479116918971736, 1, 0.1028915035269904], 
           Hue[0.5666286137182632, 1, 0.2154373040824048], 
           Hue[0.43638854136357774`, 1, 0.39576971195812316`], 
           Hue[0.36993781184416613`, 1, 0.4877784143696161], 
           Hue[0.4363713103265153, 1, 0.3957935703171326], 
           Hue[0.6479012991383548, 1, 0.10290589350073955`], 
           Hue[0.6495371410484525, 1, 0.10064088162521961`], 
           Hue[0.6472015028703471, 1, 0.10387484217951946`], 
           Hue[0.6495908047814821, 1, 0.10056657799487088`], 
           Hue[0.6489453286306182, 1, 0.10146031420375949`], 
           Hue[0.6489003584073851, 1, 0.10152258066669752`], 
           Hue[0.648659399671628, 1, 0.10185621583928439`], 
           Hue[0.6489344903150338, 1, 0.10147532110226089`], 
           Hue[0.6499948664608386, 1, 0.10000710797730039`], 
           Hue[0.6499458125596493, 1, 0.10007502876356242`], 
           Hue[0.6497943170473904, 1, 0.10028479178053637`], 
           Hue[0.6497233765288313, 1, 0.100383017113926], 
           Hue[0.649995891364032, 1, 0.10000568888057104`], 
           Hue[0.6497234483054742, 1, 0.10038291773088184`], 
           Hue[0.6497911224533826, 1, 0.10028921506454724`], 
           Hue[0.6499455194466978, 1, 0.10007543461226463`], 
           Hue[0.6473908758804227, 1, 0.10361263339633786`], 
           Hue[0.649128269088777, 1, 0.1012070120309243], 
           Hue[0.64459851077779, 1, 0.10747898507690626`], 
           Hue[0.4363713103247258, 1, 0.3957935703196105], 
           Hue[0.6446917420522249, 1, 0.10734989561999628`], 
           Hue[0.6446917420519871, 1, 0.10734989562032558`], 
           Hue[0.4363713103265097, 1, 0.39579357031714046`], 
           Hue[0.6445985107778432, 1, 0.10747898507683241`], 
           Hue[0.6491282690888007, 1, 0.10120701203089132`], 
           Hue[0.6473908758804227, 1, 0.10361263339633796`], 
           Hue[0.6499455194466978, 1, 0.10007543461226466`], 
           Hue[0.649824821602494, 1, 0.10024255470423904`], 
           Hue[0.6499597831211297, 1, 0.1000556849092051], 
           Hue[0.6489000604437772, 1, 0.10152299323169305`], 
           Hue[0.649559230442397, 1, 0.10061029631052716`], 
           Hue[0.6486631270815442, 1, 0.10185105481016969`], 
           Hue[0.6489453286306182, 1, 0.10146031420375946`], 
           Hue[0.6497943170473904, 1, 0.10028479178053637`], 
           Hue[0.6497911224533827, 1, 0.10028921506454717`], 
           Hue[0.6479116918971737, 1, 0.10289150352699036`], 
           Hue[0.6472086250834638, 1, 0.10386498065366556`], 
           Hue[0.6497234483054741, 1, 0.10038291773088194`], 
           Hue[0.6445975391506519, 1, 0.10748033040678968`], 
           Hue[0.645284131759114, 1, 0.10652966371814983`], 
           Hue[0.6498244600804971, 1, 0.10024305527315781`], 
           Hue[0.6334776944950843, 1, 0.12287703839142183`], 
           Hue[0.6445985107777569, 1, 0.1074789850769521], 
           Hue[0.4363885413636581, 1, 0.3957697119580119], 
           Hue[0.6099395356971271, 1, 0.15546833518859332`], 
           Hue[0.609935058046162, 1, 0.15547453501300657`], 
           Hue[0.649128269088788, 1, 0.10120701203090902`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6496495783709008, 1, 0.10048519917875282`], 
           Hue[0.10275085519718585`, 1, 0.8577295851115888], 
           Hue[0.3699378118441581, 1, 0.4877784143696273], 
           Hue[0.5947858280254814, 1, 0.17645039196471807`], 
           Hue[0.6499848496426992, 1, 0.10002097741780114`], 
           Hue[0.6499997133311914, 1, 0.10000039692604273`], 
           Hue[0.5936528925793111, 1, 0.17801907181326163`], 
           Hue[0.3699378118423824, 1, 0.4877784143720859], 
           Hue[0.649128269088777, 1, 0.10120701203092423`], 
           Hue[0.609939535696351, 1, 0.155468335189668], 
           Hue[0.4363885413622587, 1, 0.3957697119599496], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6099350580464612, 1, 0.15547453501259223`], 
           Hue[0.6445985107777901, 1, 0.10747898507690615`], 
           Hue[0.6334776944949212, 1, 0.12287703839164765`], 
           Hue[0.6498244600804972, 1, 0.1002430552731577], 
           Hue[0.6452841317591499, 1, 0.10652966371810024`], 
           Hue[0.6497234483054742, 1, 0.10038291773088183`], 
           Hue[0.6445975391506057, 1, 0.10748033040685363`], 
           Hue[0.6497943170473904, 1, 0.10028479178053638`], 
           Hue[0.6489453286306182, 1, 0.10146031420375946`], 
           Hue[0.6472086250834637, 1, 0.10386498065366578`], 
           Hue[0.6479116918971799, 1, 0.10289150352698177`], 
           Hue[0.6497911224533826, 1, 0.10028921506454722`], 
           Hue[0.6486631270815439, 1, 0.10185105481016991`], 
           Hue[0.6489000604437771, 1, 0.10152299323169331`], 
           Hue[0.6495592304423972, 1, 0.10061029631052709`], 
           Hue[0.6499597831211297, 1, 0.10005568490920513`], 
           Hue[0.6473904480212564, 1, 0.10361322581672185`], 
           Hue[0.6486631270815439, 1, 0.10185105481016993`], 
           Hue[0.6452851935746376, 1, 0.10652819351204024`], 
           Hue[0.6499599794841723, 1, 0.10005541302191531`], 
           Hue[0.19694005227972972`, 1, 0.7273137737665281], 
           Hue[0.6499599794841723, 1, 0.10005541302191528`], 
           Hue[0.6486631270815442, 1, 0.10185105481016965`], 
           Hue[0.6452851935746403, 1, 0.10652819351203645`], 
           Hue[0.6473904480212564, 1, 0.10361322581672192`], 
           Hue[0.6498248216024941, 1, 0.10024255470423891`], 
           Hue[0.6491292687549689, 1, 0.10120562787773542`], 
           Hue[0.6491292687549453, 1, 0.10120562787776811`], 
           Hue[0.6499455194466978, 1, 0.10007543461226463`], 
           Hue[0.6498244600804972, 1, 0.10024305527315769`], 
           Hue[0.6498244600804971, 1, 0.10024305527315783`], 
           Hue[0.6499455194466978, 1, 0.10007543461226467`], 
           Hue[0.6497233765288313, 1, 0.100383017113926], 
           Hue[0.6334703961606172, 1, 0.12288714377760701`], 
           Hue[0.6448435305234644, 1, 0.1071397269675108], 
           Hue[0.6334703961606807, 1, 0.12288714377751916`], 
           Hue[0.6497223596864661, 1, 0.10038442504950848`], 
           Hue[0.6446917420519871, 1, 0.10734989562032567`], 
           Hue[0.6452841317591496, 1, 0.10652966371810071`], 
           Hue[0.6498248216024941, 1, 0.10024255470423904`], 
           Hue[0.6498248216024941, 1, 0.10024255470423893`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499171656570684, 1, 0.10011469370559767`], 
           Hue[0.6499458125596493, 1, 0.10007502876356242`], 
           Hue[0.633477694494929, 1, 0.12287703839163683`], 
           Hue[0.6452851935746035, 1, 0.1065281935120876], 
           Hue[0.6099395356963766, 1, 0.15546833518963252`], 
           Hue[0.6499597831211297, 1, 0.10005568490920515`], 
           Hue[0.6499597831211297, 1, 0.10005568490920512`], 
           Hue[0.6452851935746391, 1, 0.1065281935120382], 
           Hue[0.6099395356970551, 1, 0.15546833518869302`], 
           Hue[0.6334703961606802, 1, 0.1228871437775197], 
           Hue[0.6334776944950551, 1, 0.12287703839146225`], 
           Hue[0.6446917420522449, 1, 0.10734989561996859`], 
           Hue[0.6499458125596493, 1, 0.10007502876356243`], 
           Hue[0.6499171656570687, 1, 0.1001146937055972], 
           Hue[0.6499599794841723, 1, 0.1000554130219153], 
           Hue[0.6499599794841723, 1, 0.10005541302191527`], 
           Hue[0.6496495783709015, 1, 0.10048519917875173`], 
           Hue[0.6499997433419163, 1, 0.10000035537273123`], 
           Hue[0.6499848496426992, 1, 0.10002097741780114`], 
           Hue[0.649649578370901, 1, 0.10048519917875254`], 
           Hue[0.6499848496426992, 1, 0.10002097741780107`], 
           Hue[0.6499962816736484, 1, 0.10000514845187147`], 
           Hue[0.6499997433419163, 1, 0.10000035537273122`], 
           Hue[0.649995891364032, 1, 0.10000568888057104`], 
           Hue[0.6452841317591498, 1, 0.10652966371810027`], 
           Hue[0.6473908758804225, 1, 0.10361263339633812`], 
           Hue[0.6473908758804222, 1, 0.10361263339633854`], 
           Hue[0.6447636185419683, 1, 0.10725037432650547`], 
           Hue[0.6447636185417653, 1, 0.10725037432678652`], 
           Hue[0.5666286137183357, 1, 0.21543730408230438`], 
           Hue[0.6334703961606387, 1, 0.12288714377757717`], 
           Hue[0.6499171656570683, 1, 0.10011469370559789`], 
           Hue[0.6499171656570684, 1, 0.10011469370559768`], 
           Hue[0.10275085519733629`, 1, 0.8577295851113804], 
           Hue[0.6499963043540927, 1, 0.10000511704817927`], 
           Hue[0.6424451989541748, 1, 0.11046049375575796`], 
           Hue[0.10275085519977556`, 1, 0.857729585108003], 
           Hue[0.6499165878991569, 1, 0.10011549367809063`], 
           Hue[0.6448435305234992, 1, 0.10713972696746267`], 
           Hue[0.6499169060240259, 1, 0.10011505319750269`], 
           Hue[0.6445750019051109, 1, 0.10751153582369267`], 
           Hue[0.6425433794512151, 1, 0.11032455152908685`], 
           Hue[0.6499165878991569, 1, 0.10011549367809049`], 
           Hue[0.6499165878991573, 1, 0.10011549367808992`], 
           Hue[0.6499948524777456, 1, 0.10000712733850615`]},
         VertexNormals->CompressedData["
1:eJw8XHc8le//lhFlyx4hq6JBkpFzkyIqK1JShIQyiqhEkUoUH0KkpGWGJC3q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          "]],
        Axes->True,
        BoxRatios->{1, 1, 0.4},
        DisplayFunction->((Print[#]; #)& ),
        FormatType->OutputForm,
        Lighting->"Neutral",
        Method->{"RotationControl" -> "Globe"},
        PlotLabel->"Surface Intensity",
        PlotRange->All,
        PlotRangePadding->{Automatic, Automatic, Automatic}]}]}], "}"}]}], 
   ",", 
   RowBox[{"FrequencyCutoff", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"52.699602136444376`", ",", "52.699602136444376`"}], "}"}]}], 
   ",", 
   RowBox[{"NumberOfPoints", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"14", ",", "14"}], "}"}]}], ",", 
   RowBox[{"ImageSampleSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.008078610347551418`", ",", "0.008078610347551418`"}], "}"}]}],
    ",", 
   RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
   RowBox[{"Energy", "\[Rule]", "99.25836042132417`"}], ",", 
   RowBox[{"Full3D", "\[Rule]", "True"}], ",", 
   RowBox[{
   "IntensityFunction", 
    "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
   RowBox[{"NumberOfRays", "\[Rule]", "956"}], ",", 
   RowBox[{"RayBoundary", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.05251096725908422`"}], ",", "0.05251096725908422`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.05251096725908422`"}], ",", "0.05251096725908422`"}], 
       "}"}]}], "}"}]}], ",", 
   RowBox[{"SmoothKernelSize", "\[Rule]", "0.009487737662714256`"}], ",", 
   RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
   RowBox[{"WaveFrontID", "\[Rule]", "1.`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563367607129251*^9, 3.5660870586381817`*^9, 
  3.566101844764213*^9, 3.566139290742056*^9, 3.614707874446836*^9},
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"},
 
 CellLabel->"Out[73]=",ExpressionUUID->"8b30f9f8-5631-422e-a696-d65c329e250a"]
}, Open  ]],

Cell[TextData[{
 StyleBox["ModulationTransferFunction", "Input"],
 " works equally well for both point sources and planar sources, as long as \
the described imaging system contains a focus. If a one-dimensional light \
source is used (ie. ",
 StyleBox["WedgeOfRays", "Input"],
 " or ",
 StyleBox["LineOfRays", "Input"],
 "), then a one-dimensional modulation transfer function is calculated. If a \
two-dimensional light source is used (ie. ",
 StyleBox["PointOfRays", "Input"],
 " or ",
 StyleBox["GridOfRays", "Input"],
 "), then the optical transfer function calculations are carried out in \
two-dimensions."
}], "Text",
 CellTags->{
  "ModulationTransferFunction", "FindIntensity", "RG17.", 
   "RG17.4"},ExpressionUUID->"97450984-6a0c-4acf-9174-51e10e28d20a"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "FindIntensity", "ModulationTransferFunction", 
   "RG17."},ExpressionUUID->"8381b864-31bc-46c1-8f73-17774d620556"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1-D Calculations with FindIntensity", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", 
   "17.5"},ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0"],

Cell[TextData[{
 "Next we will examine a light-sheet intensity calculation of the same \
optical system. This is accomplished by setting ",
 StyleBox["FullForm -> False", "Input"],
 " in ",
 StyleBox["GaussianBeam", "Input"],
 ". An initial trace of the optical system with ",
 StyleBox["TurboPlot", "Input"],
 " reveals that the rays occupy a two-dimensional plane."
}], "Text",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", 
   "RG17.5"},ExpressionUUID->"34623c4b-fe27-43e8-bd53-4b5427b399dd"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{GaussianBeam[5,.05,NumberOfRays->32, FullForm->False, \
SpotSizeFactor->2],
\tMove[ApertureStop[50,15],49],
\tMove[PlanoConvexLens[100,50,10],50],
\tMove[Screen[50],focalpoint]}, PlotType->Full3D];\
\>", "Input",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->"In[74]:=",ExpressionUUID->"fb3f9c9b-3e34-4d0e-ab34-9367873467c2"],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyVmX9o1HUYx8fMkNK5cc0ttQv3A1tSWKY0OLtvFnUzS/EP7Q/7J+iX/wSN
iGpsR1oEaUUZJSsqLY0xnZrOmbv2aRaFFKtQNEb+2naMtsg4PQ63WOs+7+fs
nu/e++5zMO54eHjt4fm8vx9euy14/Nm1T0wrKCiIjf9MH//573P2FY959kPY
K/j/a7zekn3d6qsn6546Oqu7xms+9PGKhubrPalXLTnx3Oor871HWlPHh4rG
okF81s/4/dFLc0rKF2Kuubn6ue9/rQ2N3OiNZV+zAudh/Ywf39DVcntvhdeE
d6kXx8ri25aVerPxHsRn/YzfijkuYC6pF2Y/FHln8XuC+Kyf8Xdg73IOUl+H
PVZir0F81s/4p5Z/tvKjwr8jebkbr7/zXSZ1saIvkpejSfgPzunrOfaG8fXP
vP+FlujGn3z89+08Rs+z0vK7qqbIZ/2Mv9vu3/Sr/Y/a3Jhzap+Mz/oZHzkz
cZU35MYUq/wwPutnfMxhyPNr9PPC+GfQfy1yJ3Xk2OxTfOzd7FD3CXJj1qv7
gfFZP+MjZ8bm7veI1JEbY3P0cySIz/oZX+b5ELmTOnJj1iBHQfxq9N+r+gfB
f0vx5Xx3IXdSP499jiBHQXzWz/jImZHcSb0E+ZEcBfFD6Jup+l8Bt0Hx92MO
yZ3UZ9jcGMlREJ/1M/4B7H0A5yD1p7HHCuw1iM/6Gb9905qHHyorTkjupH7b
tivtd80tTEiOgvjPfHri8Oe/nO7U/TPqf+tqm53s1Pw38VwNqnmieE6qp8hn
/Yz/Ce6RpNr/ZdxTfWqfjM/6Gf8l3Juvqbxdh3uwTOWH8YvQX6L6G8GPK754
wH71fCE3uRwF8Vk/4yNn3kF1nyA33kZ1PzA+62d88QDrHSUJqSM38I5piSA+
82RbXuKrh5cfOPPipju9149fWP3NqZAndea9rh7O+MNbm2Krti/GXJW5OvNe
Vw9n/MwN9aWheYu8NN6lzrzX1cMZvxVzDGGuvPoE3uvq4Yy/BXu/Cecgdea9
rh7O+APlq+Z112ciebmbxKsZn3nyYMer3Y9VnfTxN9t5TFjNw7zX1cMZ/wu7
fzOs9s+819XDGR85MxmVN+a9rh7O+JjDkOfX59WMzzz5D/D3Kj5yZrZOfF/5
vNfVwxkfOTM2dwNT9t6pejjjI2cG96fRfO3VjM88WfhNii/nuxu50+ervdfV
wxkfOTOSO6kzr2Z85smj4KYUvw1zSO6kzrzX1cMZ/wPsfT7OQerMe109nPHX
JSqjDQvKEpI7qTOvZnzmyRve+2Hnlva/OjW/Ec9VWM3DvNfVwxl/J+6RP9X+
mfe6ejjjX5R7szQ/b8yrGZ958mXwMyrPyFkud1Jn3uvq4YyPnHnb1X3CvNfV
wxlfPMB6R3kirz6BV0/q4RN4sv1Q66vHTu47O1x9t7fiq+cbvz1/9fso5r2M
z/oZPzmyefrbu5bie91bcnXmva4ezvgdT4bMy3vu8A7jXerMe109nPHt97o1
3gDmkjrzXlcPZ/wY9i7nIHXmva4ezvipVGoo2T+G73Vrc3Xm1YzPPPnHnp62
5nd7ffx77DxGz8O819XDGf8fmzOTVPtn3uvq4YyPnJkOlTfmva4ezviYw5Dn
1+fVjM88uR/8a7KFq39fYO+mTt0nzHtdPZzxkTNjczcU6L2uHs74Ms99yJ3U
mVczPvPkOvCXKb6c7yhyp89Xe6+rhzP+EeRNcid15tWMzzz5KLiHFN/+f6LG
SO6kzrzX1cMZfz32/gDOQerMe109nPHT6fTiPYvCCcmd1JlXMz7z5NO9vccO
7r3UqflL8VzVqXmY97p6OOOncU8Nqv0z73X1cMb/Evfm1ypvzKsZn3lyO/hH
FB85y+VO6sx7XT2c8ZEz71F1nzDvdfVwxkfO4B035/vzBF6t+f8CqZwNCQ==

    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[Line3DBox[CompressedData["
1:eJxdkj9IwkEUx8UwGsoMqRAiqBRyjEoSJM9JbShoyOagqJYgaArCoa0lqK2p
oab+DYUmQgcGQQ1WGAhCKpYEtlUEadgv7/t+5Ts47vjw7t3n3buemaXJ2QaD
wWDUpk2bv/vaCAeE2nQLw/+hcftganniq0uMH7xdl8xVL/Hc1b3bWraJam20
COKWQGd429UuWrESN9Y2ZpHFOeJTyNuHe4j7OwrJxIb01HlpfEzFX9hZfEV5
yBzLDw9pYT6PKk42wos4PGSI1QsPqbxuPcQdiPfBi3ge+cvwIm6FTzNW4k3K
Q5IX8Xnk7cU9xBd2U5G9u3ScvIh74e1g8R/oU4HlN+Nd2pgPPHQv4vAQi6xe
6pN6n1y8nruxYmg88HCSfXWMCF9sZe0y/9evYnndtLk/jH/Vr/PonFWuHg6I
CFbi6l85xTPOEfcjL91D/CaZPN7ZynjqvDQ+quIlj/9WHrLI8sNDRpnPk4qT
JnixemWQ1QsPqbxK+r8KIt4FL/Y+sgIv4jH4nGElrv63UxZwjngIef24h3g6
k0mcHr3HyYv4ELyDLP4TfXph+alP58wHHrqX3i+8+zSrl/qk3qcc/wF7JKCY

      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
    EdgeForm[None], Polygon3DBox[CompressedData["
1:eJyNkr9Lw0AYhk+Kmzg76qhQ7CQGTjhwaUQ6OIijFMTR2b+gaVbdXB2kig7+
2AJBtwYpOAnZKri4ObgU1Pbue1Mu8hI/CISHj4e7996l9tHOQU0pNTf+Zsff
5D883tusrW0bZSdIlTetgmeDwc3ZyUiDX/Um00hX6vVkZvSlo3Dhfn5/y1wK
h4H52T7z+3wxjeK4f9j+1KtvD7cbu2HBq/xsn/n9HFTybHP40D92mkaVhvnZ
fsmvMvGD95zHuPMMi/teCK/ys33m93nDdC1/Kd4XvMrP9sv+WPzg7h7r5jXP
n+6uz4Om9OdbeJXf7xsGvWsZP98pdz171+gd/B17vkeNHjE/22d+cOSOviDP
juRS9JH42T7zg7se55KDStCfzOeK+dm+n/NfHokHvfP9Q40e/e88033mB+9K
bugL8lyWdwFnfrYPf1zyg7senwboNfrclx6i18z/C6rAGhY=
     "]], 
    {GrayLevel[0.], AbsoluteThickness[0.5], 
     StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYAADywMMUNDhKbGVL8HLYfUqEDCA
i+s/3rbZNszTYQ1YXAEu/h8MPKDmfNiDrn4FRL0DTLwdaj5E3AAu7gF1zz+w
eRZwcQjwg7kTQ3w1mjkw8TVo9qKa88EGXXwFmr9QxQ0wxKHuhIvjCk8ASLtW
ow==
        "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPasjHBmNvNxYEABlgc6PCW28iV4wcVXrwIBgwP6
j7dttg3zhIuvAYsrHPgPBh5o5nzYg65+BUS9Qzua+RBxAwcPNPf8A5trAeX7
obsTQxzqTgxxqDtxmPPBBl0c6s4D2MUNMMSh7jyAKzwBioVWow==
        "], {{
        56.421974580955585`, 25., 0.}, {60., 25., 0.}, {60., 
        24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 
        24.148145657226706`, 6.4704761275630185`}, {56.421974580955585`, 25., 
        0.}}, {{56.421974580955585`, 24.148145657226706`, 
        6.4704761275630185`}, {60., 24.148145657226706`, 
        6.4704761275630185`}, {60., 21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, 24.148145657226706`, 6.4704761275630185`}}, {{
        56.421974580955585`, 21.65063509461097, 12.499999999999998`}, {60., 
        21.65063509461097, 12.499999999999998`}, {60., 17.67766952966369, 
        17.677669529663685`}, {56.421974580955585`, 17.67766952966369, 
        17.677669529663685`}, {56.421974580955585`, 21.65063509461097, 
        12.499999999999998`}}, {{56.421974580955585`, 17.67766952966369, 
        17.677669529663685`}, {60., 17.67766952966369, 17.677669529663685`}, {
        60., 12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
        12.500000000000004`, 21.650635094610966`}, {56.421974580955585`, 
        17.67766952966369, 17.677669529663685`}}, {{56.421974580955585`, 
        12.500000000000004`, 21.650635094610966`}, {60., 12.500000000000004`, 
        21.650635094610966`}, {60., 6.470476127563024, 24.148145657226706`}, {
        56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {
        56.421974580955585`, 12.500000000000004`, 21.650635094610966`}}, {{
        56.421974580955585`, 6.470476127563024, 24.148145657226706`}, {60., 
        6.470476127563024, 24.148145657226706`}, {60., 
        7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
        7.0819236220599744`*^-15, 25.}, {56.421974580955585`, 
        6.470476127563024, 24.148145657226706`}}, {{56.421974580955585`, 
        1.5308084989341915`*^-15, 25.}, {60., 1.5308084989341915`*^-15, 
        25.}, {60., -6.470476127563016, 24.148145657226706`}, {
        56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
        56.421974580955585`, 1.5308084989341915`*^-15, 25.}}, {{
        56.421974580955585`, -6.470476127563016, 24.148145657226706`}, {
        60., -6.470476127563016, 24.148145657226706`}, {
        60., -12.499999999999995`, 21.65063509461097}, {
        56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
        56.421974580955585`, -6.470476127563016, 24.148145657226706`}}, {{
        56.421974580955585`, -12.499999999999995`, 21.65063509461097}, {
        60., -12.499999999999995`, 21.65063509461097}, {
        60., -17.677669529663685`, 17.67766952966369}, {
        56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
        56.421974580955585`, -12.499999999999995`, 21.65063509461097}}, {{
        56.421974580955585`, -17.677669529663685`, 17.67766952966369}, {
        60., -17.677669529663685`, 17.67766952966369}, {
        60., -21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, -21.65063509461097, 12.499999999999998`}, {
        56.421974580955585`, -17.677669529663685`, 17.67766952966369}}, {{
        56.42197458095559, -21.650635094610962`, 12.500000000000009`}, {
        60., -21.650635094610962`, 12.500000000000009`}, {
        60., -24.148145657226706`, 6.470476127563026}, {
        56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
        56.42197458095559, -21.650635094610962`, 12.500000000000009`}}, {{
        56.421974580955585`, -24.148145657226706`, 6.470476127563026}, {
        60., -24.148145657226706`, 6.470476127563026}, {60., -25., 
        3.061616997868383*^-15}, {56.421974580955585`, -25., 
        3.061616997868383*^-15}, {56.421974580955585`, -24.148145657226706`, 
        6.470476127563026}}, {{56.421974580955585`, -25., 
        3.061616997868383*^-15}, {60., -25., 3.061616997868383*^-15}, {
        60., -24.148145657226706`, -6.47047612756302}, {
        56.421974580955585`, -24.148145657226706`, -6.47047612756302}, {
        56.421974580955585`, -25., 3.061616997868383*^-15}}, {{
        56.421974580955585`, -24.14814565722671, -6.470476127563009}, {
        60., -24.14814565722671, -6.470476127563009}, {
        60., -21.65063509461097, -12.499999999999993`}, {
        56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
        56.421974580955585`, -24.14814565722671, -6.470476127563009}}, {{
        56.421974580955585`, -21.65063509461097, -12.499999999999993`}, {
        60., -21.65063509461097, -12.499999999999993`}, {
        60., -17.677669529663692`, -17.677669529663685`}, {
        56.421974580955585`, -17.677669529663692`, -17.677669529663685`}, {
        56.421974580955585`, -21.65063509461097, -12.499999999999993`}}, {{
        56.421974580955585`, -17.677669529663696`, -17.677669529663678`}, {
        60., -17.677669529663696`, -17.677669529663678`}, {
        60., -12.50000000000001, -21.65063509461096}, {
        56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
        56.421974580955585`, -17.677669529663696`, -17.677669529663678`}}, {{
        56.421974580955585`, -12.50000000000001, -21.65063509461096}, {
        60., -12.50000000000001, -21.65063509461096}, {
        60., -6.470476127563038, -24.148145657226703`}, {
        56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
        56.421974580955585`, -12.50000000000001, -21.65063509461096}}, {{
        56.421974580955585`, -6.470476127563038, -24.148145657226703`}, {
        60., -6.470476127563038, -24.148145657226703`}, {
        60., -2.6796885989305705`*^-14, -25.}, {
        56.421974580955585`, -2.6796885989305705`*^-14, -25.}, {
        56.421974580955585`, -6.470476127563038, -24.148145657226703`}}, {{
        56.421974580955585`, -4.592425496802574*^-15, -25.}, {
        60., -4.592425496802574*^-15, -25.}, {60., 
        6.470476127563007, -24.14814565722671}, {56.421974580955585`, 
        6.470476127563007, -24.14814565722671}, {
        56.421974580955585`, -4.592425496802574*^-15, -25.}}, {{
        56.421974580955585`, 6.470476127563007, -24.14814565722671}, {60., 
        6.470476127563007, -24.14814565722671}, {60., 
        12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
        12.499999999999984`, -21.650635094610976`}, {56.421974580955585`, 
        6.470476127563007, -24.14814565722671}}, {{56.421974580955585`, 
        12.499999999999984`, -21.650635094610976`}, {60., 
        12.499999999999984`, -21.650635094610976`}, {60., 
        17.67766952966367, -17.67766952966371}, {56.42197458095559, 
        17.67766952966367, -17.67766952966371}, {56.421974580955585`, 
        12.499999999999984`, -21.650635094610976`}}, {{56.421974580955585`, 
        17.677669529663685`, -17.677669529663692`}, {60., 
        17.677669529663685`, -17.677669529663692`}, {60., 
        21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
        21.65063509461096, -12.50000000000001}, {56.421974580955585`, 
        17.677669529663685`, -17.677669529663692`}}, {{56.421974580955585`, 
        21.65063509461096, -12.50000000000001}, {60., 
        21.65063509461096, -12.50000000000001}, {60., 
        24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
        24.148145657226703`, -6.470476127563039}, {56.421974580955585`, 
        21.65063509461096, -12.50000000000001}}, {{56.421974580955585`, 
        24.148145657226703`, -6.470476127563039}, {60., 
        24.148145657226703`, -6.470476127563039}, {60., 
        25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
        25., -2.8327694488239898`*^-14}, {56.421974580955585`, 
        24.148145657226703`, -6.470476127563039}}}],
      FontColor->GrayLevel[0.]]}, 
    {GrayLevel[0.], AbsoluteThickness[0.5], 
     StyleBox[Line3DBox[{CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPatEq/dHJDtwAAGlgcYoAAmvnoVCBhgiK8Biytg
iEN4H/agi6+AqHfALm6AIf7vPwhYYIhD3YkhvhqHOWtw2At1pw0Od2L4awWO
cIC6E0c4IMITACprZwg=
        "], CompressedData["
1:eJxTTMoPSmViYGDgB2JmIPatEq/dHJDtwIACLA+gi69eBQIGGOJrwOIKGOIQ
8GEPuvgKiHoH7OIGGOL//oOABYY41J0Y4qtxmLMGh71Qd9rgcCeGv1bgCAeo
O3GEg+UBAGw1Zwg=
        "], CompressedData["
1:eJxTTMoPSmViYGCQBGJmIPatEq/dHJDtwAAGllAaIe5xdcP9N6oWDo67SuuO
PJR0gIk/+93COmGZqcN/MNCAi+9IEz5QvdbQYTuUhokzgU3VdHgK1QcTd4ea
C7MHJn76/Pn1syfftoG5CyZuB1F/AF39X4g7DjxDMx/qjgM70NzzBKLuACvU
XWj+PeCJ5l+oOw5A3PXaBibuCVVvBnUXWvgc+AN1F0x8F9Q9W6E0TJwN4o4D
j6H6YOLhUHPdofbAxG/cvn14y7ove2DugombQN3tiab+OzSeXqCZD4unnWju
gboD7i54fEHDPQLNv7B4goTP7z0AiT0Lhw==
        "]}],
      FontColor->GrayLevel[0.]]}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJyFk38slHEcxx/yI9KQk9/imP7Ij8gKyX3zV0+pLm1XMalcs9wlqYTDjuQ2
05JW1yJDkdaYGFPNHlaNVqMWIb+21mILE8bOxsJz34/1ffbdPdtzu7322rPP
5/t9vz0vXIm+uIlhmPDV13j1XfuvDZhTdD3q4Mxqxq8F1bq1M/rHaO1HfQg1
1lVr5Bli4M1qlY/T6TbO09v78meRC3BG76snu8Xeox7Ao7cNZ58wa+U05zJ3
BOQ6Cvxy2Yyq87Y7zUcUHziex4OfR+Dr5wGO9zXh9wWO923g9wWeNv5KGRPe
xOl6Fjrjp+xhzmSTjNarYSzqKSxO9k3fOAev+tdFVfN1XKnXs+qEM3bAd5tt
Vyn8WDTQuvm+LGzjHP44GUVWqGs4HzuZTvLBBrizKxqyFrNIFe9x9vqyCPiB
hXvPh1wruJO6ccv581bAI7K4oRhHFn37W7tP3mELvE2q7VssecBdaitw8Q81
B658IXdhbViU57Zkamm1FXiCaKKvwLmQs5TL60NsjIHvFUu+9FuwqCptTKR8
aAZ82o6NC32ayYnL88vDu3Uc5rNfW96ZmLIoeMa6v86TAX+sJa98xS+Bk+Yk
+9UsToNfWaM63m3Eov26LGv32Dng9dGK5VyrQC7N6pNmZ3UvcLXmYOwehkWp
0o7x7O5Bmi+h+MDxPIifBzieJ5CfBzixL3BiX0Q5T+DEeQLH95XI3xdwfF9q
/r6AE3kATuQBOJE34ETegOM8P+bzDBzn+TufZ+BEX4ATfaHxdua/5xjKu2mH
ipOcgdN6hP3UdNuGH4cdgNN6hH2JpGyk2XeD03qE/UH7KMWE9Qan9Qj7bd6i
pBsTW4DTeoT93Epzi6lGU+C0HmF/dDrEp3R5xWCPsK9xLZPFaWcN9gj7EUGR
T9iPAzRfQvEN9gj72fw8BntE7As+rUfY158ncFqPsP+Wvy/gtB5hX58H4LQe
YV+fN+C0HmE/hc8zcFqPsK/vC423Y3I00yG7SapA6pfDvQm/qgX3QvYI+8yu
n+Hvc0oEPtkj8JnA2VOhRwQ+2aMo7Mu6LILT8gU5JHsE31dGDDeU3hX4ZI/A
12oni34XC3yyR+CnSN9E2d4x2CM4z1auaCnxlsEewfdH3JFFgILmSyi+wR7B
PA3r8wh8skfEvgKf7BFxngKf7BH4Sev3RcsD+EQeaHkTfp/Pm+A8yR6B77+e
Z4FP9ojoC/j/AO1J0h8=
      "]], 
     {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCwAWJmIGYEYoYGD4dNa5e2p1QqHWBABkDxhjfnlFTuKWCI
zwv7UH28VQ6XuAMOc+DiMHs3QOyFi+exVO4otPJ0ON81IU+nQhpuvgGbWHW2
rqfDjR0ck8OsJODiUjIOt/mVPB2q4xXiSv6KwMXtavbfjpLwdLj8cYV5ykFB
uHjOyhRpTwFPhybZX6xcPLxwcTMl+wvXOT0dFpXdF8mZxgYX/3Rx22EWVk8H
kw/819cqMsDFFy6r9j/H6Olg/bOGXy768364V9sdo40ZPB2KAg4+rz13E5e4
Pbo5hhBz7HHYCw8fNHfCxWH+aoD4Cy6OFg5wcbRwg4vDwvkaJJxxxQtcHAL8
HJrKhR0mZEkdQBcvqhDccMtLHEPc3n7O3a06IhjiN0V9sl/wC2KI71URySp9
wY0h3riQnfPtJlYM8XvvLNRm//23H128XWZOWOz0TxjidkZOcz1P3sAlbo8u
XgsxB0Mcai+GONSdDujiuyH+whCHhgOGODTcMMQLIOGMIQ6NF7i4b5V47eaA
bIeG1XeuJD9Zao8uzqD9yOZI3SRMcQbDT+GW3nBxH5h42AlOk7KW/Rjqc+zu
bJjdjyk+ffqbnmcTMMULAnb5CPZiiDfs2N/zK70ZU/1dOQdO/Wxc4hjub9gA
NgfTXxB7McUh7sQUzwL7C1c44Ao3THfqgcMZ07+QeIGLAwBe6Faz
       "]]}}}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367607962241*^9, 3.566087059510504*^9, 
  3.566101846018343*^9, 3.566139292100926*^9, 3.61470787549505*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "During evaluation of \
In[74]:=",ExpressionUUID->"73e948d6-1694-44b4-ae7d-aa818ce26431"]
}, Open  ]],

Cell[TextData[{
 "We will now apply ",
 StyleBox["FindIntensity", "Input"],
 " to this system. This time, however, we use ",
 StyleBox["NumberOfRays->1024", "Input"],
 " with ",
 StyleBox["GaussianBeam", "Input"],
 ". With such a large number of rays, ",
 StyleBox["FindIntensity", "Input"],
 " can accurately model the geometric intensity properties of the light flux. \
 In addition, we will use the ",
 StyleBox["ReportedSurfaces", "Input"],
 " option to specify the optical surfaces that we are interested in measuring \
intensity. In this case, we specify ",
 StyleBox["ReportedSurfaces -> {{1,1},{3,1}}", "Input"],
 " to examine the first and third components. In this case, each surface is \
specified with a list of two ordered numbers where the first number gives the \
component list order and the second number indicates a particular surface \
within the component-grouping of surfaces."
}], "Text",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", 
   "RG17.5"},ExpressionUUID->"f8f0bdcf-fab1-40be-95b1-7e144ffe3c6c"],

Cell[CellGroupData[{

Cell["\<\
intensity = FindIntensity[{GaussianBeam[5, .05, NumberOfRays->1024, \
FullForm->False, SpotSizeFactor->2],
\tMove[ApertureStop[50,15, InterceptHole -> True],49],
\tMove[PlanoConvexLens[100,50,10],50],
\tMove[Screen[{.6,.6}],focalpoint]}, 
\tReportedSurfaces->{{1,1},{3,1}}]\
\>", "Input",
 CellChangeTimes->{{3.56613907953789*^9, 3.566139108742313*^9}, {
  3.61471010729319*^9, 3.614710108366911*^9}},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "In[355]:=",ExpressionUUID->"5edc0363-6e09-425e-a719-e41a4ce3275a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1024"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.02434017156009105`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 1., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 1024, Optica`Optica`SmoothKernelSize -> 
    0.02434017156009105}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563367609587453*^9, 3.5660870606060963`*^9, 
  3.5661018480466537`*^9, 3.566139119047*^9, 3.566139297759424*^9, 
  3.614707881345689*^9, 3.614710113713161*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "During evaluation of \
In[355]:=",ExpressionUUID->"2838a744-8620-4e26-a900-a8328ac1c274"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwtl3c419/7x62sZO/t7T2pqKgo7iNCSyEJJZXUR1ZWKg3Klh2yN9EQslKv
kz1ClJCSVVEhsqL4vX/X9f3rXOe6znWdcd/n+Xw8lc64mp1jY2FhWWRlYfn/
sfaxZbrZGh3zoUP65otcUGL9eaHvGA0bZQ9HX74eBDtzrH8VhlJweUE8sriX
AZu9ZSpXPirjbwqDDfNGZZDZawPVO0j4dvQl6YDqRnjwPvJCvYsi7k8/dP/f
9n4wqBHGScFy+PNWhyOTmeNgxzk5q/9TCmdzeQXvubYI3q6NOc124ngkcfe5
iLMcyGlC5fd+YRGsr3HDWLJSAEnrTPK2LPHjC6LzUd55EkiuJenCoiE3TivJ
qmj4rICEYw3rP5az4s02DSpZX5VRdZ7f4WG1eWJ9VdGY1kUaMioKIa0mfCZ0
l0TWtx5hoEfRN6tFOT+APY/jCbmLDFRX8WUiOXcONMtPH70aQEPt2TelBr+z
oEPV28HdiozOzOuUE0LciPvjSYa2kCLaTvkqlfeSHy03eW13+CGBrKc/L2/+
J4y89X2pOusEkeKj9v/UQsXRtZoEzeAf7GidtfrurR+kkOXAUxO5ukXAbUWt
qZfkUEX+J+cS/gkwETcZXOegiK6/Uns3EdsPUNEo0clLQnb+fnL8D5shqfrA
k4NvldEj/4PVbx6VQYBmmM+B6xTU5Xlj5zehTBgQ7k1f3U9Db1g7V8eowfC/
eqIN/6tn9R2ZNjFVOs6J5b5YYOILXmspv1+5UXHdv+Qn8r9iYduGXUfflpLx
Wfuh+ArVQhjPe75izauMNT1+dKRlvARK77w5mCvh+R2S0cFSXdCmcb9ZaJsC
bghe2jvQNAxmwzetXKtl8CLvit8mtRn4Ud1/IJAqibvImzgi9Nbg0sOltpAq
Udx3Wdi6PZ8H/a07UmNpJITDNSQKbseIIMnHbuLfVzmw+fC98eYFJeTqwOXU
bvKXsJMJUH7cSUHhQuS+IbFJomuRM3V9NB1dcKBn5BrlEV1bn5uNZzLQ5pQA
SSXaD0BFlarvSujo8U13/oc6K0Aa297LJUxFia8Hv5nc4EARoXtnJw1IaPnW
BLveZiHEa21bfbpFBOl0HNv6pE4U7fWm1kQF8KAY9rVu9a2SKKN4AQXyrsGI
sAv7eK4MGhIpFNjjMgOb/2bXvZNXQBvk68jRgiPQ6MB7zXGnEvqT+Of+n+9d
8HNnyOiGaRIymjB2USRhEPT5IXKwgIxeKJgLpnQUgjp5Cx/FnoqiX+QoGd+O
gw67hHQ6hY7S0kasNcp94eV9LU2Ne3TcqfWiiv+tF4hu0vVqH6Xibye1Tf89
joDyvv0kUKDgs1lRPn5DORAW8cOqyEMZ68uP0A6tVMLZ3oIW3wYlzLHxrgH6
3QZBO13yqByK+LPay8aTrIPQZtLCF5Api39U87ZZqk5Cnt1ZhXM8UpjtZJ7o
e/oKzN09tZNxVwyraep6JP3kRGXvX1h2bRTGHKbhO1QKhVDS8wDiVxYnfmWr
VbU4p4j2G+6/qj+4RgSZhDBkRskI97Z8uvBphnB9ffSTGg8d8Z4wunhFvYt4
u3Dyb14IA/mXjFSLiY2BNyVC+po8A1XKbPybPbMIJncjzja/p6KtO5/cii9j
Q29Oy2tcOaqMWve5cLcaCiIWXf/NTzrF0GvbZHHXIRGk1zuXJl3Eh6yOO8ir
20ogZakpqaNprMhze6fCBiyNDppLy8ecn4PFUZqRlrE8GvN6Yjpu+gVCdR9u
3NmpiGo2CYqlePaA+FL+9SlfEirw9PL1YqkHi/vJp1/rkJGDFX+i3pNi+LDR
dk/lLwr6MPWMOzA4Cd5pVaSLVNLQ9fCHOe8f+EO56z+7RUzD5heeDmrt9Yf3
XSuXyv9RcEVNwuUdzfehWE818LwxGYvkb/964GgxGBBhqbyZJPz7vknux5Ja
+PZ+zyDrsCJuodKEz3a9g+AlC4P3J+XxiAHf4aqlMej32J5n9VYav1Kf0A0g
z4G62BGffH0JvPmgpOGWL6zoXoaN86g1Oza0fX0k6zcJxQXWn7Qklgi93nPb
ugqY/e9RNjft9pWg8dy/NfWPjobuXOVU1GmCsO6tCRqJDDS5R3RXvOwMlHOJ
17xh0JFKpf1ahZgwUmybZpnsF0KPdYRNpvPE0EtqPPtiEid6/TghaAunFPqI
Jn8nbV8B02m+b7VhsojauLc+O3MSzokqIrd5BfR6YDa85PIgsEVeaEnJVEKl
q3G7P7W1Q90Vx32bTiuj7LmqHMsvVdB6bFdjmzAFHRJfNo1yzYVAGY730b1U
lB3IZigYGQnNQZfTdWLoqHIHW/uzv16Acowd9Vvp+Dxpn2EAyQNG6/i3m8vR
sJtX0N/uj6Fw+aUZz/xRCtYX2M9Zm5oFJ/zZQ8wLlPHQJvr7fQHl4G/pfyd5
VQnXuyd83a/VAolcN4O8tBQxW0XuvviAAQhe5/JVQEwO7201N17p/g63t9FD
3l2VwsJ1jBDXvX/g2WrM1NKCGE5sCwgSyVqHBO08KRHpwrhdkCCaCEF0Yo+g
6JwnFw4MopSweSgi2YFnaK2bBV95uvG833ky0iFyxXMDfxNT3XfT02toqOD2
eOMu+z5CzTRsgM+dgR7qCPEJhg9BcYC+XLkxA72c4P6dfmABMkpVLj5XpyEW
F4lD1Z2sKOfm951+/cro3InTYnJ5Aqh3VFiP9FEcieS/4O50EUEpWyV3rrPg
RzVs0vVqc+Ko92ns48CXbGh389ojhUPSKEbaQ2eeawE+9k4E//goh2J2t/v5
K34DJ5Xr69KTmP96wzOeL669UGhZ0TqoT0IJN4KaVLUbYemBR3A4NxnN3ijP
PhJfAupPPT+xVlCQqVlYZ5FsGhynNimE+NGQPF9eDdYJgJ1X+eI5F2h4VdqZ
0SF+C/IuvN66ewcVtyTYLt4ojgd32jZnuRtkfCs6mOoJj0C8NPt1SQ8JWxwy
p3JNYeC0lL2vKK2Ep32SBbyGu6Ew/jKnZ7M8nml0S/hqOgrxKgM3xwxl8HLn
dR7f1FngHxcdEX8mgU/zEG5VNSzoGO3rq68bOfDDfbzxp7xJyH/hi71w0DJR
knL5BpsuFcXscXK4UDdBdJXq5FJa6cjwolva9qKnkHFQwILIYCAOIcsmavEU
fArk3vHdnY5iZPP9/mYKIUP3uYn2dmG0EKCBDmuKoa2Hv8J+bm6kZnVg05YU
ScS+UfTRNdF/IO2n49UjKYtMpoO27BX7xVwz4kcKVUBawvG7sxOHYOyqVha7
sxLa3HIzIer4GzjefyVejq6M0JpwP2mqBpzPi0yGfSIj96Kmc3l/82EgXfrS
QCoVZQ75el1gjYEDnkEKpTZ0xPZC9Vgw+QrsjlRhodjR8SvVKZ3MQR8wiHcu
Myqk4tmDhrLfb0XD3OyeXSETZGzn6523ejYfqpPeqrCDMobnytq2j56DgWUn
v224Ei7hMO88PdMBP7urQ5+kKuB8deP4+5ZDwJ9I3ra8SRZbTSw/ki+eBv1f
kzkbNX4RGZbmVbVH6Kj3wkEFlz91hIEjSzVPMgMdp5X9J5P2DXgPWFawTdJR
UU5a9PJWGZSk+9Ev6fMsCP86ty6oVB7Z3pbQJWePQoHZgHkXuxKKrs0khae9
Bb/ERPXVZyT06s5mG5XlV1ASXKfN58HUZzdBXb6fjyCgwCjfRYWKCgUtEkqP
J4DpoXyFtCkaUl7pmD9x+hZonJtSHQ+jYVMVoi2m+g5w7VJ9ql5PwY+1s4t7
9VJh2kY5/akwGf+n2KP0VLME3Ns8XM44kfDH8cn2nox6SMv5639ZfpTgzyyp
9ldlIH7HQVuz7m74+DFq3cgd5v3++QpLDc9CfcjJ56ofaWiztM3f3UnKSPb7
rMl/9AqgG55NX29MQbb2ofiYcjaoJ0xqGwvRkF20pk1yehjsTT6v0NxMR0pU
uZrjGh7gx3jD0TZGZ/KslaYr1QX2C1wWF9emYd+Hp0s3KITA8afv/3a6UvAd
53VaDTGZsNc3MiO/VhnPm88UEaeeQYzE9LCKDAlrLETEfZxpAkVXriXZo4r4
LtVDYPn4B/hqh8x7TORw1zLnYFLZBMym8OqGl0phbqNpwv7EEohXPGwZUhXH
ttqihdqs69DLnMPhP/uE8ZvvN5+EHBJENQEWL+c/cWFxXeeo2C2KSGLHDbYp
A1bc7imQjWlk9LdEZJu+zRzhKbtjNC+OhnwkquZkVweIuvhG7bunmf7Pafqf
dOQnKDf5dlDVmoHwkctTqT7zYHCkPr/Qhoa+Bh/YdvAkK0o2N5dMkCKjDpyd
cHqrAKrTDUleOSOBtrd1sK5piiC3jzp/Tm8WQFO9v+PVCHF0cb3R2SBzdqQo
JDlfICKN6lpuRE0ML0BHV+sDg3w5pJnVsFQvMg4nM75cMruliNpjA3LTffvA
kwtmjtFIyGwsmsvoYhPsK/mc/HNSGWGLDU04uRSsf68VUpMoiOPZts5q7gxI
ku38rO9AQ8bJ77wc8gPhylqseoQgHX9IUxd1VbsB/GUaImvmVNxRxPVjl+E9
MJOusFtKJOP3hxqs7IuKYO2h2hjnLxIO6DTMd5PGIC4RsvBkuxLmzlp/U+RP
F1SfC/5W+08e1/gF6fqHjMBcwKOfD27J4PXaPxeEx2bA13QxvmNSAtuzj6xM
bGRBFY6qTuP3ODD56Ize6+0k5PPYe3zacYWQO/UmZAM3FQmoGKfnOP0gbJsi
N9g8piPjITetSLlQeOC/ImOezUD3j01NZ//4CaXeLTVGsXTUaNJcK39BCH0P
Om5euF8ESRfu1br5VxQFepBkOxu4kd1mCsuW85Lo86i3YTrfKqy2WNTYfpZB
9OQrIcLEL9jNVpd17agCynBW3aVhOgw9vzL5K8yU0Phh173Fcl1ACmF9cW+9
Moog7xa8H/ESXrreZPlZS0bjjq/dq048AM6RXF0WPyriXD21iHfGQrhj5Gdn
xOR6brZPq4NX4bpoSdLDq3TMmtNv8f7gZXg43BPH20TF20fPG1icjYKeL42b
7TkoeO90ycSMVB5kxZ3aY2mljNMNG3qiD1bDUYndTpMFShhkjwSV/9cO/zLb
Lq52K+A0cXf9EdPP4PR7IZ04L4ubXym3nrowBWxjNq9auWeImUjq1MtNdOQd
NXlVfVMb4ay6VhMdy+QnpwMxif1f4Nf19d0snAwUNVned/uPNIrbPav0M/03
cHw3pA5dl0euhSvHn3uPwf1mfXxnQhGVPZ17Tgp4BweNFS2975PQvLHdrqSF
WuCIVjNxOk5GVXVGJgpJT6D4e7dn7AYqmueu5ykdTYQY/Sefj7+loY23r4ku
+PqB13evRtc8GhaquLGU6H0bXAJjo38PUbDS7UPtCz7J8MYkPyZ8ExnXCowe
0IOnYNOwFlAeSMLH6k8Y3MupA5nwvuelTWPEvs2sykViDHTjocyZEbcO4Nu0
q8M3koFIGc15vaszcNxMfzSXnY6WWkZIz64ro0SNv+T8G5VwxaSz5OImCvrP
wuBEvl4O2PT7cDvPUZH5tVHXD8F3ITDa9bP/Izri1D88shTuCWvyrzqfP6Fj
bV+/vRJunuDrk2cRxULD/mGhLX0V4dA/LXHfuvUd8dQsZ4frTQaSWLoyGnNk
BA7fOPLBTJOBxNWJUx0pNLThZsHi3YnbsDh3Z+XGAA2LrXs7mUbxA105e7Mr
0lS89Y+M+qhaIojZRG3aKD1OHK1prSgao6M9J/sLT/JgiOH0GVlJYaDik5HZ
5dVUpJP0JX3fQBTw3rh5asmbjvLtLVZN71yGS/7HgizDqgj3m4aCLWkMpPRC
cf8ur2Gi9/GbCE1goMF/j8O3Ob2HUo7bbM1XmLyQe+rUBuY+dhq8O54suADp
p0g3/ywdi8k9Ca5rNoVVjaLAy8Y0zLJN9CHvgWBoLkz01rlOwfbhXzY4CmeC
9hWLh12dylh1arZApbsMki7nRrkzSNh9cd0XtaNNMJZ1oNjttCLu5Xz17XFj
P9yLeMBTeVEO+5yK3T3JmIAHXdckxzulcCLnGclP3xfBMFar4qihOBZsSmes
POVAYkYviOR5YUww/SxBVBA50XxivYW5cQm34YtXgopI9NyZs1+us2JTm4yk
bVxkNPBwv15MwxzxV9aiVfkW07dOZ4ZtaPtEJGdrntppxUCSB8ejE1oHIELw
zomGMwy0587mn7IC8yASLXmizI2GrOPPUcXIrOirbl26oxYZsf2u77u9xI8O
8IvnNOZJIOOTlqvxUiLojnXdxo/JAiio1u7Wkxxx9COv310lnR3FaOYkTi5I
Ifz7z+1O00VoMtmlfSlcDu37dTLZMGocjg1I0TcyOTvZjOIzxdkP1p/9OUSk
mHqe3xDawdMM7uX3clOGlJHqzKPfdOUycItrEKoKo6D6NNnFuLAMqJZ4C5nH
aagqZE/KWfsgkK7t/dclR8ec7mUHr++6DrX9F27bnaFiN7PT8cGJcVArcuXD
uTwyvihyYlxiohDmHsxPq/8j4U+h5LuuFwiQvwy5iwZKWOizjp90cBfsaRc8
7iipgMsVqtkGaSOQXSqeHZ4qg7u/jKbyhsyARuCFSyq8kjis+lFj5Os1uMBn
ovdfKwe2CnIo7REnIU9eKBz8uELkvZkf1f5JQR1y5c/36P0kPu9KMp9Ip6OH
JxKzb9+KJIwdQk3EmXpu/0frzhmen6CbgtQFs5l579vxUbUDQoj9wLIma6gI
2ri7Q1NiSBS5Fb895UzhQX8kYyaKD0qi+stsOwdDV8FtavhUdq0M0rY+aftW
bAY0b27bVqClgNpx2Qm+4mHoUH1fH7VXCeU47T1z6HYXcJ3e+8b0HwldOm69
z9eBgG8emrwpz8jo1uM+8bMihSBz+2JujDsVsXwY2GMzEAuPzsVC21Y6Sr6Z
GtvXeA3ke+fP/wqi4+DKFnOOu95gx8W7zqmHio1Wc0rsyyPB8HNwQZcQBccd
87NQuZYL8dEUEz8HZbwuVN+CO6sKTlyeldasUMIS0SP3yA9fQyDP0Y+5kwqY
GnF/mrNgEGSV7I5l3ZHFPJesUrSbJ2H4U0ynlMcM8Sh/KT9Lho72kl8WCDV1
ELK7xP8WRDBQpUAC1XJxDLwEbL7vE2YgNmF93+aP0sjScdConW0OVh0qyvnO
yqMRi+Iqi9ExiGH38bb9qIgy99ZvebHyDrYo2jtuDSMhB803iS1X6mDjvS+W
sgfI6EPMv6AXu4uhISxxgLJGQfr+P+T6Su5DqW4plDfQ0ETlPEET8gfxR1Wx
paU0zDY8VZI14A+kh02sFtMUPDbVwlOSmgTI+D++ZW0yvjtgqGXbXAxHahui
h2JJmH4oPtBJpQ4+3DTsM035QuTP20Sw8zLQE8kDGqy9rcC+vOXGsTgGCr40
9av87gxMoHBHLE5Hg5nU7ZdclRFfnLbKc7UqyDILqJFRpCBCNzo05X0OuF3V
dV37QkXsJHitFRwB+eEeMMTsu5Hkwc+jel6QMcyRulZDxw6HJ2xfNnqAetqH
hhl+Gj4V5sjf0xgGWItF/UDCe6IgZPjBIaY+jiQ1XDZ1GYbz3utDnJn6uUO1
jlCNpKF7gqG72aPvQGJFc3PtODPPV0+JbU65BbN7Ems/0Kn4Xuwiq5FzArwz
Wd3XOjVObPF5diayl46+xAgtLw1Wgn9wrVsPU58bV4/y7ntIRWp6Zs3yTtGg
cuU2YfEfHcFS3V1DUx/g7rk2E34KE8dV97uppzLQUHGEQ/++EUJidpWUxfSX
hdLG+T3p78B+p9ynGKb/kDPOEo7v6ejcbaN0H393GHII3xHUS8eiixYaLS7u
ENX+5uTGLR+ImMYYvdn/mDyAq1Cq+Wf42nG+6bYpAx0OSgsYn8oBnvwnlS5Z
DJT3V/bQ4dgmwm2aztOXwEBUxYWm0+u6YEdlVP3mUAZyiL94k/Kcjhyi9rt9
+OQBs7lqbI7/ugn9vsOvS5h5Q2jmQZ9udh0keRS3zCcxULf1M9V7liVEH2/d
dgtmXm00SlAma/VBIEnmzKo7A40+sFl7MkNHBiV1E519ZuDe/qyyeImOfd03
58UqbYM+owbdgsM07NDzx755JAhu5V/ZNnebgu9x5EF6dwaUXd5Z4vBeGQe6
D1pV3C2DtHyWC/HqJNxB5XJJ4mqCxhrncOkLirhlt0qz2vV+cKIM2jOuyuG4
TROMpC/jwOFUtk58UApffdqpaFe6CLasLI8jzMXx0+X8cf4wDoQkPa1+s4vg
H/rWhXwzAsjAh2e1fCM3ftYVej5jTQGJ+L4TOZ3EzBfIr59YVEatDIfmquU5
4nwg59UxTxo6GijWG/B0kLgSMAFuFsz+mtpGPTb+AQR1n66qnWf+X3neiyc+
zIHsi5vfTX1pSDR1Nv0KFys68KpixHk/GcmGW/yJG+BHWzijKjRaJZBpXvLf
M+tFUAFZkcvqnQB6t0PCyzVBHH2/clVIp54dvTZy/B45LoWuld0NORyyCAZ3
Pfy5bsqhD9aiV9g6xqF7aRv7fSdF9HZh9d56k3442EbmnxEiIa2plBAW62YI
rHQrnOtXRo1j1TB6vgyW7el7/e9Q0J0N6tNu7RmwX6xnutOUhnSt3zpU1QWB
Y/aVMQ8yHe/Ld/AZqfWFlJ/+u6L/o2IZVmsDN4M4uCponSD7iIxXhVPc+UIL
waWgb76BXRmf7Z+aOryOAFJ+kq/MQSWsl22f3H+kCzhZLQRfUhSwstva7ODC
MFzdf2D1X5EMlvl4ML7SZgaiFDNtj0tK4vc/HPTOB68BOvm56MEYB44u9XAR
4yIh953K69+L/SWCf29SUflEQY8kJluii34Sbm/PhQol0lHsdf6QRloa4dl6
sEmX2e8trac69BJ/gHDKhe8KD+nIWSPTo3K3EEpkNblVWiCCNAKENUa7RBHw
xLJVH+VBhhHGg24gidLOLs3ON6/CA5aCp3vLZBCXulV08Z4ZKHlx8ZruRgV0
cvd/GTmfh2H/vl/p/3SVUMg9SY2Z8i5YPvitX22BhL4XGogZvifgr5egwNxj
Mtopdib3mmsh5Jl39NlcpCK98qGkArU40D17b/qPKh3dG3CZZgNfcKlMMImJ
oGOtACunU+reoC1NfpHykYrjJVXWv90aCasD/50LlqRgqc0m+j825YJgFPdR
cWdlvFWQlfPnwSqwyz80e/ylEm6r/FYUc+Q17NdJjPuzrIDrvp2q7rMYhLmK
uKcisbLYSnIp8uvVSXhj/fiYXsEM4a9NvqQgQkfiO94qsO5/QxxRZhtxv8tA
csM1btsDx2DM+cyWLVIMtIvM0+HYIY34sn8POmvOwdXc6dUsC3n0Z/v6/87L
fAF+pRjTth5FlCA+/9xxRw+Q+Tg9Be+QkH6uJqvhizpACfiEpwEZcYYn6nN6
M/3jxAr/9CIFiem4K3HLJYHB7mfTYy9piLc9UrvlhD84RNhctaim4cupjxKL
ovzh78vhqoAFCvaP3Hri0pYkWDLY31KsR8YdG5Qc9t8thlZckOCVxNSH/OnE
kslaqLpy/WsG51ciVOcwix4HAzV3nEkV5G2BzmfseZL3GEzOYI2nWszAljek
1gglOnpztxkOX1BGsfzlWfmhVVB+1O6VhxQFGRyrdwhSzoWV/ZlZzYNUdHG7
xpM9vJGwM9Rrmv8+HdUlbsGv0rzgV23e7cw6Ov4qtnLA1tMDeJ/OXSeJ0zBj
b8X6+iNhUGbrea3uei+xq+v51wxPBjJy+vFK/d8Q9HPVF+TpM89Hb3C1Dqah
S/5vRmO/3YHxRMcn9tM0nL71lYCz1S14bVFydb06Fas0yHnz8ydAqbHmcSmr
CYLGfSmc3s2s3xp6LbH3Gbzd99bhN1OPj3RW6AjnUplc3POu+lk0VHsHuN45
Q0f/Ub+O8Vf5wC95++DrG2sJt/H+rWHJDEQUNnjSy0aI0ImywMNqTP2KNCts
rXwLXBtXOZf9Gags9Zzr/U46irs7Tzk77A7qxpvlGYN0rBP+tFQ57hLcmTV4
kCMxQKQWLDS0OTB55uy6HptLg1ByjHSfbMlAp4ll84PeycBfJRPyI5OBIgzX
jYFdC3EtcubwPyYfbF3x852QfwMuYpdSs5n9txDrrHa0jI6km3YMVWh6wtfW
7EMjo2+Jt82+xv/8GEgl/5WeyftXwPLFj0eHmaeypgKsvGeeERfksk+PMe/f
TVLuKzLrBY+T+js1vBjIM//kk8HvdNTA3ntLgu8cdPO6/3D6QccXV7gTJgXs
IWomtaArzILQUio1F2Lqh+2HHiGl5dfEr/YM3bhoBoo/s61tJvs1Mydb7Api
zl+Lho91F/cQz+9N5JpcY74PdYT2wacGeuy2nCClMxASpz3bSXlBvDFP2pjG
5IPvfdp6zwN6wGlnXMsuXwaKyzotsPsTHeG7eqbadZcgKuD7kS9vmDwj4578
9o07TD2G4ULSQ9jTeKK1gvleL0s0ym0bGwj+D+xcuxMZaEk7xlXNrQG+tAn+
KGfOOSNaVs5fe0SIn2nZx8M8v9lDq8N+S3TUWW316OS/bfB/ktu60g==
   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1WWUEFUYBuClG6U7lg7pVrqUhkU6lC5haVA67cIWsMWW7u7ubrBRDCxs
fb7jj2e/973DYe/MnTmb2Dc5aUSKhISEm37EnO5HHq6xTr9ojuVH7tMPmQNI
z+36MrMF1+VXKMJ8vSon5Qc5Lg8lC5307WZ3/pYXk5IZel7Wy8M5LA8kA3fo
y82WfCu/SlEW6NU4JT/ECXkYWems7zB78I+8hFTM1POxQR5BXVborfhOfo1E
FurVOS0/TBd26j35V15Kambp+dkoJ1OPlXprvpdfp1g8G70GZ+RH6MouvVc8
dJYZaZgtF2CTPJL6rNLb8IP8BsXjGeg1OSs/SjfSMsdaQTbLo2jAar0tN+Q3
KRH3qdfinPwY3UnHXGuF2CKPpiFr9HbxDshvUTLuS6/NeflxepA+zttaYbbK
Y2hEqdi3tTpckJ+gJxni3KwVYZs8lsaUJmM8d+tF2S6PowllyETmeI6uJbJD
Hk9TysY9xrvJRflJepElnpO1YuyUJ9CMcnFP8Y5xSX6K3mSN52KtOLvkiTRn
rd6en+S3KR9Tr8tl+WlOxrfCLdyj7zZ7x/fFcv2cOYqc8W/i+Zkl2C1fMsdx
v3zEHBTvPBn5jEnc6do6swPf8LN+1ZwYmUX6WXNkvIPk4Aum8Cu3ub7IrMfX
XNGvmBPivpinnzKHxzfBrXzOZH7hXtf3xL1xnZR8EntmhWvnzdHxvpKLL5ka
/0+cvVmSPfJlczwPyEfNwWTiLn29mRS/T36HCjH1+lyVn6EPe2M/pGKlni3O
XC7FXnkSLahI9jhf66XZJ0+mJZXIQc44P9fKsF+eQisq8661BnGf8rP0JRfz
rJXlgDyV1lThPWsN+VR+jn7kjn1bK8dBeRptqMr71hrFGcvP05888busleeQ
PJ22bNA7xlnGvqjGB3rjOCf5BQaQN353nDeH5Rm0Y6N+Nzdjn1TnQ71JvCfy
iwwkX+zFWgWOyDNpzya9E7/FvqnBR3rTOGv5JQaRP/ZirSJH5Vl0YLPemd9j
39TkY70ZX8kvM5h9eh9Ss0ovEHuTK3FMnk0SW/Qu/BH3QS0W6825Js9nCPv1
vqRhtV4w9ipX5rg8h45s1bvyZ9wXtVkS3118L/ICTsvxhzMbQ/UDZj/SskYv
FPchV+GEPJdj8hAyx/PXt5nd+Cvunzosjfc/vmt5IWfkZLIzTD9o9iddvFvx
7bDW+gVzDDfIHc+RaSn+/7te2PX/ABkY+sg=
      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.65, 1, 0.1], 
     Hue[0.6494207291151731, 1, 0.1008020673789911], 
     Hue[0.6483599788274689, 1, 0.10227079854658155`], 
     Hue[0.6459852201968237, 1, 0.10555892588132101`], 
     Hue[0.6409985648914213, 1, 0.11246352553495513`], 
     Hue[0.6300250241010613, 1, 0.12765765893699202`], 
     Hue[0.6109703924263565, 1, 0.15404099510196786`], 
     Hue[0.5755862811077844, 1, 0.20303438000460622`], 
     Hue[0.5207719417881722, 1, 0.2789311575240694], 
     Hue[0.4489578486886055, 1, 0.3783660556619308], 
     Hue[0.35019884226963294`, 1, 0.5151092953189698], 
     Hue[0.24594863957126922`, 1, 0.6594557298243965], 
     Hue[0.14545260567613372`, 1, 0.7986040844484303], 
     Hue[0.056261934593322294`, 1, 0.9220988597938614], 
     Hue[0.008173938274651182, 1, 0.9886822393120214], 
     Hue[0.00556678247483644, 1, 0.9922921473425341], 
     Hue[0.05366208318546595, 1, 0.9256986540508932], 
     Hue[0.13408205829263364`, 1, 0.8143479192871227], 
     Hue[0.2426466933727217, 1, 0.6640276553300776], 
     Hue[0.3467852798121602, 1, 0.5198357664139321], 
     Hue[0.4469181406755143, 1, 0.3811902667569803], 
     Hue[0.5237436058962835, 1, 0.2748165456820689], 
     Hue[0.5746967614881886, 1, 0.2042660225548158], 
     Hue[0.6102971366499449, 1, 0.1549731954077686], 
     Hue[0.6297374411047794, 1, 0.12805585077799783`], 
     Hue[0.6402286639346562, 1, 0.11352954224432228`], 
     Hue[0.6459064132235023, 1, 0.10566804322899684`], 
     Hue[0.648311787911976, 1, 0.10233752442957175`], 
     Hue[0.6494043430446556, 1, 0.10082475578432318`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6496518898476994, 1, 0.10048199867241626`], 
     Hue[0.6490150342682998, 1, 0.1013637987054312], 
     Hue[0.647410481848161, 1, 0.10358548667177721`], 
     Hue[0.6439359118437823, 1, 0.10839642975476306`], 
     Hue[0.636454463637649, 1, 0.11875535804017828`], 
     Hue[0.6218275983185867, 1, 0.13900794078964923`], 
     Hue[0.5955429566057608, 1, 0.17540206008433118`], 
     Hue[0.5509475435046666, 1, 0.23714955514738473`], 
     Hue[0.4873908802620105, 1, 0.3251510888679855], 
     Hue[0.4018928555258338, 1, 0.44353296927192243`], 
     Hue[0.19455923984596663`, 1, 0.7306102832902001], 
     Hue[0.09701960143856403, 1, 0.8656651672389114], 
     Hue[0.02716339324549677, 1, 0.9623891478139276], 
     Hue[0.00014034654871986074`, 1, 0.9998056740094649], 
     Hue[0.023817633701099572`, 1, 0.9670217379523237], 
     Hue[0.0904485547617806, 1, 0.8747635395606115], 
     Hue[0.1868201403418519, 1, 0.7413259595266666], 
     Hue[0.3991759412895396, 1, 0.447294850522176], 
     Hue[0.4882385447693514, 1, 0.32397739955012883`], 
     Hue[0.5516287881307232, 1, 0.23620629335746016`], 
     Hue[0.594762057920179, 1, 0.1764833044182137], 
     Hue[0.6213775410773189, 1, 0.13963109696986614`], 
     Hue[0.6358062713392225, 1, 0.11965285506876888`], 
     Hue[0.6436112354568084, 1, 0.10884598167518836`], 
     Hue[0.6473474656665777, 1, 0.10367273984627695`], 
     Hue[0.6489865689245254, 1, 0.10140321225834946`], 
     Hue[0.6496468826235906, 1, 0.10048893175195155`], 
     Hue[0.6497321434595643, 1, 0.10037087828675707`], 
     Hue[0.6492426274089493, 1, 0.10104866974145481`], 
     Hue[0.6479347555815825, 1, 0.10285956919473198`], 
     Hue[0.6450541768827651, 1, 0.10684806277770983`], 
     Hue[0.6389300669131007, 1, 0.11532759965878363`], 
     Hue[0.6262295627386543, 1, 0.1329129131310941], 
     Hue[0.603781552454058, 1, 0.16399477352515052`], 
     Hue[0.5639300922070762, 1, 0.21917371848250988`], 
     Hue[0.5047022616014935, 1, 0.3011814839363937], 
     Hue[0.4260748244094891, 1, 0.4100502431253229], 
     Hue[0.22009229518519086`, 1, 0.6952568220512743], 
     Hue[0.12044884487286078`, 1, 0.8332246763298852], 
     Hue[0.040618200928714376`, 1, 0.9437594140987032], 
     Hue[0.0025424754563085905`, 1, 0.996479649368188], 
     Hue[0.013156253001414875`, 1, 0.9817836496903487], 
     Hue[0.07096310266323758, 1, 0.9017433963124403], 
     Hue[0.15992763971104007`, 1, 0.7785617296308676], 
     Hue[0.3735107579215473, 1, 0.482831258262473], 
     Hue[0.4682943093220293, 1, 0.3515924947848825], 
     Hue[0.5383316269063101, 1, 0.2546177473604938], 
     Hue[0.5853374320724352, 1, 0.1895327863612437], 
     Hue[0.6162193961507102, 1, 0.14677314379132433`], 
     Hue[0.6330034585506575, 1, 0.12353367277601272`], 
     Hue[0.6420787655123184, 1, 0.11096786313678998`], 
     Hue[0.6466975826093497, 1, 0.10457257792551576`], 
     Hue[0.6486884484260262, 1, 0.10181599448704068`], 
     Hue[0.6495402321737841, 1, 0.1006366016055297], 
     Hue[0.6495499628395041, 1, 0.10062312837607137`], 
     Hue[0.6487256461124465, 1, 0.10176448999815103`], 
     Hue[0.6467679595336518, 1, 0.10447513295340517`], 
     Hue[0.6425949836076611, 1, 0.11025309962016161`], 
     Hue[0.6335086099958211, 1, 0.12283423231347851`], 
     Hue[0.616771417915035, 1, 0.14600880596379773`], 
     Hue[0.5861674770607089, 1, 0.18838349330055693`], 
     Hue[0.53657711461306, 1, 0.2570470720742247], 
     Hue[0.16951818137176838`, 1, 0.7652825181006284], 
     Hue[0.0755153279825469, 1, 0.895440315101089], 
     Hue[0.01637978258736461, 1, 0.9773203010328798], 
     Hue[0.0011011971854738567`, 1, 0.9984752654354977], 
     Hue[0.03738683022823286, 1, 0.9482336196839852], 
     Hue[0.4237098121695827, 1, 0.41332487545750096`], 
     Hue[0.5067235376586576, 1, 0.2983827940110895], 
     Hue[0.5637596392896171, 1, 0.21940973021437638`], 
     Hue[0.6030493285054798, 1, 0.1650086220693358], 
     Hue[0.6258633443702754, 1, 0.13341998471808025`], 
     Hue[0.638198731076733, 1, 0.116340218509139], 
     Hue[0.6448730958620779, 1, 0.10709879034481526`], 
     Hue[0.6478794125152932, 1, 0.10293619805574789`], 
     Hue[0.6492209562258624, 1, 0.10107867599495976`], 
     Hue[0.6497301292549986, 1, 0.10037366718538653`], 
     Hue[0.6497654391708975, 1, 0.10032477653260362`], 
     Hue[0.6493372300669759, 1, 0.10091768144572576`], 
     Hue[0.6481586485398694, 1, 0.10254956356018093`], 
     Hue[0.6455416274010782, 1, 0.10617313129081478`], 
     Hue[0.6400101088613751, 1, 0.11383215696117292`], 
     Hue[0.6281972106634922, 1, 0.13018847754285692`], 
     Hue[0.6074976215084973, 1, 0.15884944714208066`], 
     Hue[0.5699143209564721, 1, 0.21088786329103873`], 
     Hue[0.5128857413931552, 1, 0.28985051191716976`], 
     Hue[0.4376810276555959, 1, 0.3939801155537903], 
     Hue[0.2329626690112277, 1, 0.6774363044459925], 
     Hue[0.13268969765867134`, 1, 0.8162758032418397], 
     Hue[0.04820070185165759, 1, 0.9332605666669356], 
     Hue[0.004879918246886494, 1, 0.9932431901196955], 
     Hue[0.008973932162907317, 1, 0.9875745554667438], 
     Hue[0.062054922844122506`, 1, 0.9140777991389073], 
     Hue[0.14675281245542726`, 1, 0.7968037981386392], 
     Hue[0.3602177389129965, 1, 0.5012369768896972], 
     Hue[0.45774909551489484`, 1, 0.36619356005629944`], 
     Hue[0.5311961770561315, 1, 0.2644976009992026], 
     Hue[0.5801827913638135, 1, 0.196669981188566], 
     Hue[0.6133560172484914, 1, 0.15073782227131954`], 
     Hue[0.6314334824307528, 1, 0.12570748586511157`], 
     Hue[0.6411971758777634, 1, 0.11218852570771237`], 
     Hue[0.6463207379036616, 1, 0.10509436290262239`], 
     Hue[0.648511239134409, 1, 0.10206136119851061`], 
     Hue[0.6494764089575185, 1, 0.10072497221266673`], 
     Hue[0.6496039701558861, 1, 0.100548349014927], 
     Hue[0.6488787876705218, 1, 0.10155244784081602`], 
     Hue[0.6471057400263723, 1, 0.10400743688656136`], 
     Hue[0.643295712528503, 1, 0.10928285957591889`], 
     Hue[0.6350434431835659, 1, 0.12070907866890887`], 
     Hue[0.6193885747968867, 1, 0.1423850502812338], 
     Hue[0.5910082837683867, 1, 0.181680837859157], 
     Hue[0.5439173332541719, 1, 0.2468836924173004], 
     Hue[0.18192343711704412`, 1, 0.7481060101456312], 
     Hue[0.08609305995467531, 1, 0.880794224678142], 
     Hue[0.021508297474848614`, 1, 0.9702192804194403], 
     Hue[0.0002552397160495712, 1, 0.999646591162393], 
     Hue[0.030147379495666704`, 1, 0.9582574745444614], 
     Hue[0.4116334914816121, 1, 0.430045934871614], 
     Hue[0.4976784957028324, 1, 0.3109066982576167], 
     Hue[0.557843778982504, 1, 0.22760092140884056`], 
     Hue[0.5990328135710151, 1, 0.1705699504401329], 
     Hue[0.623704438506664, 1, 0.13640923899077298`], 
     Hue[0.6370516746455246, 1, 0.11792845049081221`], 
     Hue[0.6442720788272625, 1, 0.10793096777763664`], 
     Hue[0.6476267611864202, 1, 0.10328602297264908`], 
     Hue[0.6491107257652587, 1, 0.10123130278656486`], 
     Hue[0.6496910652325488, 1, 0.10042775583185544`], 
     Hue[0.6496944455314316, 1, 0.10042307541801772`], 
     Hue[0.6491355801136436, 1, 0.10119688907341665`], 
     Hue[0.647685817024253, 1, 0.10320425335103431`], 
     Hue[0.6445202618977596, 1, 0.10758732968002531`], 
     Hue[0.6377445326942796, 1, 0.1169691085771514], 
     Hue[0.6241070036511778, 1, 0.1358518410983693], 
     Hue[0.5997905636800137, 1, 0.1695207579815195], 
     Hue[0.033529864836120415`, 1, 0.9535740333038332], 
     Hue[0.000820672883857565, 1, 0.9988636836992741], 
     Hue[0.018055566676949852`, 1, 0.9749999846011463], 
     Hue[0.5901897672143893, 1, 0.18281416847238408`], 
     Hue[0.6188857168052098, 1, 0.14308131519278652`], 
     Hue[0.6344582356475255, 1, 0.12151936602650318`], 
     Hue[0.6428807884467144, 1, 0.10985736984301096`], 
     Hue[0.6470389706958329, 1, 0.10409988672884671`], 
     Hue[0.6488462518757435, 1, 0.10159749740281673`], 
     Hue[0.6495967593437255, 1, 0.10055833321638016`], 
     Hue[0.6494890958976763, 1, 0.10070740568014047`], 
     Hue[0.6485535668794812, 1, 0.10200275355148768`], 
     Hue[0.6463954966321691, 1, 0.10499085081699659`], 
     Hue[0.6418305944838195, 1, 0.11131148456086531`], 
     Hue[0.01186584114103939, 1, 0.9835703738047147], 
     Hue[0.003014814598248705, 1, 0.9958256413255018], 
     Hue[0.04507639842031019, 1, 0.937586525264186], 
     Hue[0.6454154167285172, 1, 0.10634788452974545`], 
     Hue[0.6481069717370723, 1, 0.10262111605636147`], 
     Hue[0.6493183917789869, 1, 0.10094376522909522`], 
     Hue[0.6497645771548026, 1, 0.10032597009335024`], 
     Hue[0.6498156969640339, 1, 0.1002551888190301], 
     Hue[0.6493803424997586, 1, 0.10085798730802652`], 
     Hue[0.6482619346671442, 1, 0.10240655199933883`], 
     Hue[0.6457687434921986, 1, 0.10585866285695587`], 
     Hue[0.6405167853575846, 1, 0.11313060488949822`], 
     Hue[0.6291275574117453, 1, 0.1289003051221988], 
     Hue[0.6092702127459539, 1, 0.15639509004406382`], 
     Hue[0.5727992522753718, 1, 0.2068933430033315], 
     Hue[0.5168681364555202, 1, 0.28433642644620283`], 
     Hue[0.4433380575771747, 1, 0.38614730489314275`], 
     Hue[0.2394429704349363, 1, 0.6684635793977806], 
     Hue[0.13900350889158708`, 1, 0.8075336030731871], 
     Hue[0.05215931269827989, 1, 0.927779413186997], 
     Hue[0.006513860538898464, 1, 0.9909808084846021], 
     Hue[0.007244993874565342, 1, 0.9899684700198327], 
     Hue[0.05780288016688462, 1, 0.9199652428458521], 
     Hue[0.14040607708495845`, 1, 0.8055915855746729], 
     Hue[0.3535403161828563, 1, 0.5104826391314298], 
     Hue[0.4523674474604524, 1, 0.37364507274706593`], 
     Hue[0.5275070353930483, 1, 0.26960564330193315`], 
     Hue[0.5774846378411919, 1, 0.2004058860660421], 
     Hue[0.611850308152146, 1, 0.15282265025087474`], 
     Hue[0.6306018039211293, 1, 0.1268590407245902], 
     Hue[0.6407250449747978, 1, 0.1128422454195108], 
     Hue[0.6461184593559964, 1, 0.10537444089169724`], 
     Hue[0.6484143722698229, 1, 0.10219548454947601`], 
     Hue[0.6494414324568076, 1, 0.10077340121365107`], 
     Hue[0.6496286408698813, 1, 0.10051418956477975`], 
     Hue[0.648948859543617, 1, 0.10145542524729959`], 
     Hue[0.6472620543442131, 1, 0.10379100167724335`], 
     Hue[0.6436231299801387, 1, 0.10882951233519264`], 
     Hue[0.6357626302459535, 1, 0.11971328119791055`], 
     Hue[0.6206289451465506, 1, 0.1406676144124684], 
     Hue[0.5933035613524025, 1, 0.1785027612043659], 
     Hue[0.5474779173861639, 1, 0.24195365284992695`], 
     Hue[0.18821967048573568`, 1, 0.7393881485582121], 
     Hue[0.0914367058553921, 1, 0.8733953303540725], 
     Hue[0.024260631147992595`, 1, 0.9664083568720102], 
     Hue[0., 1, 1.], 
     Hue[0.026942062744802597`, 1, 0.9626956054302733], 
     Hue[0.4054506548224489, 1, 0.4386067856304554], 
     Hue[0.492986217531469, 1, 0.31740369880258146`], 
     Hue[0.5547719561572144, 1, 0.2318542145515494], 
     Hue[0.596930758218039, 1, 0.17348048862117688`], 
     Hue[0.6225620241788583, 1, 0.1379910434446577], 
     Hue[0.6364416041977556, 1, 0.11877316341849226`], 
     Hue[0.6439498560776629, 1, 0.10837712235400523`], 
     Hue[0.6474905585472978, 1, 0.10347461124220309`], 
     Hue[0.6490505025450081, 1, 0.10131468878383505`], 
     Hue[0.6496696689649388, 1, 0.10045738143316166`], 
     Hue[0.6497138750931621, 1, 0.10039617294792937`], 
     Hue[0.6491908197746583, 1, 0.10112040338893463`], 
     Hue[0.6478134992570235, 1, 0.10302746256719827`], 
     Hue[0.6447932273372816, 1, 0.10720937753299468`], 
     Hue[0.6383506132048501, 1, 0.11612992017789997`], 
     Hue[0.6251880880245785, 1, 0.13435495504289144`], 
     Hue[0.6018192177236514, 1, 0.16671185238263647`], 
     Hue[0.0369975758984048, 1, 0.9487725872175934], 
     Hue[0.0015603399530835782`, 1, 0.9978395292957305], 
     Hue[0.015580411852772591`, 1, 0.9784271220500071], 
     Hue[0.5878089673845414, 1, 0.18611066054448117`], 
     Hue[0.617576032279718, 1, 0.144894724535775], 
     Hue[0.6337445971590395, 1, 0.12250748085671459`], 
     Hue[0.6424901598078436, 1, 0.11039824026606268`], 
     Hue[0.646872593150577, 1, 0.10433025563766264`], 
     Hue[0.648769847931607, 1, 0.1017032874793134], 
     Hue[0.64956933132633, 1, 0.10059631047123539`], 
     Hue[0.6495204290247414, 1, 0.10066402135035817`], 
     Hue[0.6486419403172279, 1, 0.10188039032999226`], 
     Hue[0.6465861685402597, 1, 0.10472684355964035`], 
     Hue[0.6422209369787532, 1, 0.11077101033711102`], 
     Hue[0.01402899081839215, 1, 0.9805752434822262], 
     Hue[0.0019645800268670577`, 1, 0.9972798122704918], 
     Hue[0.041166755940964084`, 1, 0.9429998763894343], 
     Hue[0.6451506192900185, 1, 0.10671452713689752`], 
     Hue[0.6479962086715645, 1, 0.1027744803009107], 
     Hue[0.6492710746147498, 1, 0.10100928130265428`], 
     Hue[0.6497479120296296, 1, 0.10034904488205142`], 
     Hue[0.6497493086481195, 1, 0.1003471111026037], 
     Hue[0.6492912885439144, 1, 0.10098129278534936`], 
     Hue[0.0035544051781553065`, 1, 0.9950785159071696], 
     Hue[0.010894007250408011`, 1, 0.9849159899609735], 
     Hue[0.6495093110277149, 1, 0.10067941550008708`], 
     Hue[0.6495777784024127, 1, 0.1005846145197363], 
     Hue[0.6488046287281491, 1, 0.10165512945333201`], 
     Hue[0.0188815068198126, 1, 0.9738563751725671], 
     Hue[0.0006279566818909732, 1, 0.9991305215173818], 
     Hue[0.6491676171198596, 1, 0.10115253014173296`], 
     Hue[0.6497111920892122, 1, 0.10039988787647545`], 
     Hue[0.0004495461399424139, 1, 0.9993775514985412], 
     Hue[0.009914984936253313, 1, 0.9862715593190339], 
     Hue[0.004114268310746683, 1, 0.9943033208005047], 
     Hue[0.6498106617708848, 1, 0.10026216062492885`], 
     Hue[0.6499472781505811, 1, 0.1000729994838108], 
     Hue[0.6494008470929418, 1, 0.10082959633284996`], 
     Hue[0.6483115902011757, 1, 0.10233779818298751`], 
     Hue[0.6458782876770499, 1, 0.10570698629331549`], 
     Hue[0.6407607757100968, 1, 0.11279277209371208`], 
     Hue[0.6295803155774846, 1, 0.12827340920040597`], 
     Hue[0.6101285923156383, 1, 0.15520656448603928`], 
     Hue[0.5742046889706088, 1, 0.2049473537330032], 
     Hue[0.5188302296570365, 1, 0.2816196820133341], 
     Hue[0.4461578536446471, 1, 0.3822429718766426], 
     Hue[0.24269327962235782`, 1, 0.6639631512921199], 
     Hue[0.1422272054254795, 1, 0.8030700232570285], 
     Hue[0.05419073918477313, 1, 0.9249666688210834], 
     Hue[0.007338972590791415, 1, 0.9898383456435196], 
     Hue[0.006393110003040325, 1, 0.9911480015342519], 
     Hue[0.05571937986692099, 1, 0.9228500894150325], 
     Hue[0.1372541441290115, 1, 0.8099558004367533], 
     Hue[0.35018335351510504`, 1, 0.5151307412867776], 
     Hue[0.4496569107195147, 1, 0.3773981236191335], 
     Hue[0.5256343489265491, 1, 0.27219859379400885`], 
     Hue[0.576099400109148, 1, 0.20232390754117982`], 
     Hue[0.6110796484191652, 1, 0.15388971757346367`], 
     Hue[0.630173760297467, 1, 0.1274517165111997], 
     Hue[0.6404797318909642, 1, 0.11318190968943431`], 
     Hue[0.6460136929745678, 1, 0.10551950203521387`], 
     Hue[0.6483637511221076, 1, 0.10226557536938952`], 
     Hue[0.6494231545152241, 1, 0.10079870913276658`], 
     Hue[0.6496404373382797, 1, 0.10049785599315118`], 
     Hue[0.6489824582187333, 1, 0.10140890400483074`], 
     Hue[0.6473372202226221, 1, 0.10368692584560026`], 
     Hue[0.6437813116580096, 1, 0.10861049155044838`], 
     Hue[0.6361122647233287, 1, 0.11922917192154484`], 
     Hue[0.6212333189693434, 1, 0.13983078911937072`], 
     Hue[0.5944304941520718, 1, 0.17694239271251588`], 
     Hue[0.5492267161181235, 1, 0.2395322392210598], 
     Hue[0.19138515419200874`, 1, 0.7350051711187572], 
     Hue[0.0941921558085057, 1, 0.8695800919574537], 
     Hue[0.025691124446994063`, 1, 0.9644276738426236], 
     Hue[0.00002352190768362128, 1, 0.9999674312047457], 
     Hue[0.025378983840851466`, 1, 0.9648598685280517], 
     Hue[0.4023142295964459, 1, 0.4429495282510749], 
     Hue[0.49061881730950774`, 1, 0.3206816375714508], 
     Hue[0.5532091028278686, 1, 0.23401816531525887`], 
     Hue[0.5958568015038151, 1, 0.17496750561010216`], 
     Hue[0.6219749647112339, 1, 0.1388038950152146], 
     Hue[0.6361271239328453, 1, 0.11920859763144505`], 
     Hue[0.6437828205982312, 1, 0.10860840224860291`], 
     Hue[0.6474198941222414, 1, 0.10357245429228114`], 
     Hue[0.649019050502882, 1, 0.10135823776524042`], 
     Hue[0.6496584573287741, 1, 0.10047290523708198`], 
     Hue[0.6497231509861959, 1, 0.1003833294037288], 
     Hue[0.6492171524702315, 1, 0.10108394273352567`], 
     Hue[0.6478749243426648, 1, 0.10294241244861796`], 
     Hue[0.6449251744727204, 1, 0.10702668149931029`], 
     Hue[0.6386439596714024, 1, 0.11572374814728895`], 
     Hue[0.6257137709194589, 1, 0.13362708641921076`], 
     Hue[0.6028104719305954, 1, 0.16533934655763707`], 
     Hue[0.03879115345498241, 1, 0.9462891721392552], 
     Hue[0.00204652452762899, 1, 0.9971663506540522], 
     Hue[0.014363708186627133`, 1, 0.9801117886646701], 
     Hue[0.5865848946423438, 1, 0.18780553049521637`], 
     Hue[0.6169038098323398, 1, 0.14582549407829865`], 
     Hue[0.6333775363363702, 1, 0.12301571891887214`], 
     Hue[0.642287160157943, 1, 0.11067931670438669`], 
     Hue[0.646786185262447, 1, 0.10444989732891957`], 
     Hue[0.6487297801613743, 1, 0.10175876593040492`], 
     Hue[0.6495549988329647, 1, 0.1006161554620489], 
     Hue[0.6495354160787383, 1, 0.10064327004482393`], 
     Hue[0.6486843531732213, 1, 0.10182166483707836`], 
     Hue[0.6466781532044529, 1, 0.10459948017844993`], 
     Hue[0.6424099697197947, 1, 0.11050927269566892`], 
     Hue[0.015183211454569023`, 1, 0.9789770918321352], 
     Hue[0.0014842239231870336`, 1, 0.997944920721741], 
     Hue[0.03927481818696199, 1, 0.9456194825103603], 
     Hue[0.6450136112163736, 1, 0.10690423062348285`], 
     Hue[0.6479385832492244, 1, 0.10285426934722787`], 
     Hue[0.6492463764208792, 1, 0.10104347880185952`], 
     Hue[0.6497391633466383, 1, 0.10036115844311631`], 
     Hue[0.6497574978063524, 1, 0.10033577226812748`], 
     Hue[0.6493145981195542, 1, 0.10094901798830959`], 
     Hue[0.004161598864771188, 1, 0.9942377861872398], 
     Hue[0.009893329634630965, 1, 0.9863015435828187], 
     Hue[0.6494931154227351, 1, 0.10070184018390524`], 
     Hue[0.6495910709039227, 1, 0.10056620951764557`], 
     Hue[0.6488422719152992, 1, 0.10160300811727811`], 
     Hue[0.020179929261305962`, 1, 0.9720585594843455], 
     Hue[0.0004447580458434297, 1, 0.9993841811672938], 
     Hue[0.6491396023196859, 1, 0.10119131986505031`], 
     Hue[0.6497012810259416, 1, 0.10041361088715776`], 
     Hue[0.0006076257760387893, 1, 0.9991586720024079], 
     Hue[0.010863335672152807`, 1, 0.9849584583000961], 
     Hue[0.0035406151092213234`, 1, 0.9950976098487704], 
     Hue[0.6497731787114491, 1, 0.10031406024568582`], 
     Hue[0.6497741306336647, 1, 0.10031274219954121`], 
     Hue[0.005682493436892422, 1, 0.9921319321643027], 
     Hue[0.008102085038400042, 1, 0.9887817284083692], 
     Hue[0.00008835356944913997, 1, 0.999877664288455], 
     Hue[0.0011370027215367173`, 1, 0.9984256885394106], 
     Hue[0.0024899471578471166`, 1, 0.9965523808583655], 
     Hue[0.6497563802890647, 1, 0.10033731959975656`], 
     Hue[0.0030330834221558023`, 1, 0.9958003460308612], 
     Hue[0.0008283863278639725, 1, 0.9988530035460345], 
     Hue[0.00029629239912853933`, 1, 0.9995897489858221], 
     Hue[0.004786482237717937, 1, 0.9933725630554675], 
     Hue[0.6499439892769909, 1, 0.10007755330878182`], 
     Hue[0.6499875158019874, 1, 0.10001728581263288`], 
     Hue[0.6494109304278011, 1, 0.10081563479227552`], 
     Hue[0.6483362686977471, 1, 0.10230362795696565`], 
     Hue[0.645931248801914, 1, 0.10563365550504224`], 
     Hue[0.6408792838612916, 1, 0.11262868388436562`], 
     Hue[0.6298077772069661, 1, 0.1279584623288161], 
     Hue[0.6105515018934207, 1, 0.1546209973783407], 
     Hue[0.5748916012783756, 1, 0.20399624438378777`], 
     Hue[0.5197939163059443, 1, 0.2802853466533079], 
     Hue[0.44754771602512905`, 1, 0.3803185470421291], 
     Hue[0.2443712885139241, 1, 0.6616397543653358], 
     Hue[0.14375751879040655`, 1, 0.8009511278286678], 
     Hue[0.05530462336751485, 1, 0.9234243676449794], 
     Hue[0.007713497974169203, 1, 0.9893197720357657], 
     Hue[0.005955715920358595, 1, 0.9917536241102728], 
     Hue[0.05456903723928208, 1, 0.9244428715148402], 
     Hue[0.13556927841037536`, 1, 0.812288691431788], 
     Hue[0.3484289399052678, 1, 0.517559929361937], 
     Hue[0.4482583382570699, 1, 0.3793346085671341], 
     Hue[0.5247164695108618, 1, 0.2734695037541913], 
     Hue[0.5754123400842259, 1, 0.20327522142184107`], 
     Hue[0.6106975331333079, 1, 0.1544188002769583], 
     Hue[0.6299536732217466, 1, 0.12775645246219708`], 
     Hue[0.6403556352766222, 1, 0.11335373577083081`], 
     Hue[0.6459605173004334, 1, 0.10559312989170767`], 
     Hue[0.6483382729738123, 1, 0.10230085280549063`], 
     Hue[0.6494139342377792, 1, 0.10081147567076743`], 
     Hue[0.64964626944774, 1, 0.1004897807646678], 
     Hue[0.6489987246110026, 1, 0.10138638130784262`], 
     Hue[0.6473739890057328, 1, 0.10363601522283153`], 
     Hue[0.6438580050086173, 1, 0.10850430075729914`], 
     Hue[0.6362832666054539, 1, 0.11899240008475619`], 
     Hue[0.6215365925790378, 1, 0.13941087181364004`], 
     Hue[0.5949915357171516, 1, 0.17616556593009788`], 
     Hue[0.5500704775640917, 1, 0.23836395414202688`], 
     Hue[0.1929450679411877, 1, 0.7328452905429709], 
     Hue[0.09568415918495587, 1, 0.8675142411285226], 
     Hue[0.026467851560574962`, 1, 0.9633522055315116], 
     Hue[0.00010690064698370971`, 1, 0.9998519837195611], 
     Hue[0.024481579918917862`, 1, 0.9661024278045753], 
     Hue[0.40079421020510353`, 1, 0.4450541704852413], 
     Hue[0.48944773808491393`, 1, 0.322303131882427], 
     Hue[0.5524404299590473, 1, 0.2350824815951653], 
     Hue[0.595301409533224, 1, 0.1757365098770745], 
     Hue[0.6216803663083569, 1, 0.13921180049612134`], 
     Hue[0.6359673055967633, 1, 0.11942988455832777`], 
     Hue[0.6436963283321748, 1, 0.10872816077083482`], 
     Hue[0.6473842661202932, 1, 0.10362178537190173`], 
     Hue[0.6490027440471332, 1, 0.10138081593473859`], 
     Hue[0.6496526464644884, 1, 0.10048095104916999`], 
     Hue[0.6497276309973763, 1, 0.10037712631132514`], 
     Hue[0.649229877081093, 1, 0.10106632404156347`], 
     Hue[0.6479048076830476, 1, 0.10290103551578034`], 
     Hue[0.6449910258134631, 1, 0.10693550271982026`], 
     Hue[0.6387856578107423, 1, 0.11552755072358767`], 
     Hue[0.6259681080796479, 1, 0.1332749272743338], 
     Hue[0.6032891125775806, 1, 0.16467661335411932`], 
     Hue[0.039634198867282255`, 1, 0.9451218784914552], 
     Hue[0.0021664897704308794`, 1, 0.9970002449332495], 
     Hue[0.013680023596948754`, 1, 0.9810584288657632], 
     Hue[0.585958156906592, 1, 0.18867332120625724`], 
     Hue[0.6165567578884068, 1, 0.14630602753912902`], 
     Hue[0.6331928416082957, 1, 0.12327145008082141`], 
     Hue[0.6421827303387263, 1, 0.11082391183868667`], 
     Hue[0.6467418636819257, 1, 0.10451126567117984`], 
     Hue[0.6487092404340385, 1, 0.10178720555286977`], 
     Hue[0.6495476842490884, 1, 0.10062628334741618`], 
     Hue[0.6495426662960367, 1, 0.10063323128241067`], 
     Hue[0.6487052923493286, 1, 0.10179267213169886`], 
     Hue[0.6467238623098338, 1, 0.10453619064792248`], 
     Hue[0.6425039393981814, 1, 0.11037916083328733`], 
     Hue[0.0157536541123644, 1, 0.9781872481521109], 
     Hue[0.001409113389190697, 1, 0.9980489199226591], 
     Hue[0.03820462581271267, 1, 0.947101287336244], 
     Hue[0.6449432621701837, 1, 0.10700163699513031`], 
     Hue[0.6479088271652306, 1, 0.10289547007891149`], 
     Hue[0.6492338001939328, 1, 0.10106089203917001`], 
     Hue[0.6497346725736763, 1, 0.10036737643644822`], 
     Hue[0.6497614812439392, 1, 0.10033025673916116`], 
     Hue[0.6493260168430828, 1, 0.10093320744803931`], 
     Hue[0.0046245753686967594`, 1, 0.993596741797189], 
     Hue[0.009475088710300783, 1, 0.986880646401122], 
     Hue[0.6494847433371672, 1, 0.1007134323023839], 
     Hue[0.6495975269758446, 1, 0.1005572703411383], 
     Hue[0.6488606903732348, 1, 0.10157750563705954`], 
     Hue[0.020714890159022392`, 1, 0.9713178443951997], 
     Hue[0.0002350962778671084, 1, 0.9996744820767993], 
     Hue[0.6491253641122945, 1, 0.10121103430605378`], 
     Hue[0.6496962623919074, 1, 0.10042055976505135`], 
     Hue[0.0007705856393003252, 1, 0.9989330352686611], 
     Hue[0.011489507332325122`, 1, 0.9840914513860114], 
     Hue[0.0032035989159662215`, 1, 0.9955642476548161], 
     Hue[0.6497685888346124, 1, 0.10032041545976744`], 
     Hue[0.6497847037639711, 1, 0.10029810248065545`], 
     Hue[0.005994487399738291, 1, 0.9916999405234393], 
     Hue[0.007544693262716229, 1, 0.989553501636239], 
     Hue[0.00013910380359172247`, 1, 0.9998073947334883], 
     Hue[0.0014196886095609873`, 1, 0.9980342773098387], 
     Hue[0.00214763736679513, 1, 0.9970263482613606], 
     Hue[0.6497521313849934, 1, 0.10034320269770144`], 
     Hue[0.003301374897856535, 1, 0.9954288655260448], 
     Hue[0.0007017874763388665, 1, 0.9990282942635309], 
     Hue[0.00024090698097967156`, 1, 0.9996664364878742], 
     Hue[0.0045675841076652235`, 1, 0.9936756527740019], 
     Hue[0.6498720413752287, 1, 0.10017717348045255`], 
     Hue[0.649878138339922, 1, 0.1001687315293388], 
     Hue[0.00012448392649988538`, 1, 0.9998276376402309], 
     Hue[0.0017574413987969661`, 1, 0.9975666196016658], 
     Hue[0.0017624755242880985`, 1, 0.9975596492740627], 
     Hue[0.0039631469495643445`, 1, 0.9945125657621418], 
     Hue[0.00041500109620495884`, 1, 0.9994253830975623], 
     Hue[0.00046613820630114766`, 1, 0.9993545778681984], 
     Hue[0.003871407817266803, 1, 0.9946395891760922], 
     Hue[0.6497824267040314, 1, 0.10030125533287967`], 
     Hue[0.6497693896639003, 1, 0.10031930661921502`], 
     Hue[0.0001591217855548832, 1, 0.9997796775276931], 
     Hue[0.001098320209868997, 1, 0.9984792489401814], 
     Hue[0.0010507789699376602`, 1, 0.998545075272394], 
     Hue[0.000127593766992673, 1, 0.9998233317072409], 
     Hue[0.6499868515278004, 1, 0.10001820557689171`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563367609587453*^9, 3.5660870606060963`*^9, 
  3.5661018480466537`*^9, 3.566139119047*^9, 3.566139297759424*^9, 
  3.614707881345689*^9, 3.614710113811861*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "During evaluation of \
In[355]:=",ExpressionUUID->"2f268b14-14d8-48a5-a7eb-687acda3458f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Information : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "616"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.0017135135482782005`"}]}], 
    "}"}]}],
  SequenceForm[
  "Surface Information : ", {
   Optica`Optica`ComponentNumber -> 3., Optica`Optica`SurfaceNumber -> 1., 
    Optica`Optica`NumberOfRays -> 616, Optica`Optica`SmoothKernelSize -> 
    0.0017135135482782005`}],
  Editable->False]], "Print",
 CellChangeTimes->{3.563367609587453*^9, 3.5660870606060963`*^9, 
  3.5661018480466537`*^9, 3.566139119047*^9, 3.566139297759424*^9, 
  3.614707881345689*^9, 3.614710114228346*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "During evaluation of \
In[355]:=",ExpressionUUID->"3e3c72dd-d769-434f-b710-2079c05b91f7"],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJw1l3c41W/cx82iFElI2ZU9MzPujy0Zx5bsmZURQhnZJPM4KB3HnumcYyT1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   "], {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1ne8UGMcx/GbSmkopb33TkNpqhRJQ4uSBre9995Di6amkKJFixSiZUV7
ICoiDaNFtMP79/LHp+/n+/xe977uOed5zilfYu+mvZIkJCQsuiMhIXKbf3Kg
vf6mXka+oE+QHfVk8hl9oLyoN5Ar9emyiv4bfwTd9a/1B+VL+kyekw/hKZBH
Pyor4jM+BunNe+g3+RO4ypvhJK9ttpi/wgvzcXysvEe2lZulSNguc6KD8pZe
Vk7TO/Hk/Fl+iTfkq3hV/rusi2/4LOTFMf0BfM7H4kkkjevHDuu5sJp3RjXk
i9+Pj63nxhreBdWRH3fik7hurOVd496gAFLgU+t5sY53Qw0UREp8Zj0f1vPu
qIlCuAufW8+Pt3kP1Ir7g+PWKmEnH4cWSIWd1grgHd4TD6EIvrdWGV/w8WiJ
a3pz/MxfRWp8oRfEBl7OPZzOe8X18UQ+SP6hN4r9o8+QtfVz/FH00I/E9clF
+hQ5W88lh+ojZUr5lNwo58mi5j/wKvEc9S/1SnKO/pycoN8je+pD5C29uVyv
z5JP6df5E+ijn9LryNf0xXH9fDzPgHb8Q5nG+peyEN7lveM5mbXX/+SPx/7i
dfh5WQ89rX0bz0e+rE+VL+q55TB9lLxLtpKb5HxZzPxE7EN01nfpleXcuDae
gccBvc1b4QZ/Eqf5w2ZL+Gu8aNwHnhHP8I9kWuu7ZGFs5OWtz4h7EPuKd+CX
4/fgAn8M3/E5yGM+XE+F4vqPshp284nIaN5b/4c/jZu8Bc7wJbgbu/Ui2MT7
xn6Nd4j+F38EF3l9HOVzUQI/6dWxh0/CvX6mj/4vb41bvCXO8qUoZv6cfi/S
6XtkUbzH7zebyfvF3ued+N+8MV8dZ55fkg1iD1s7FudHvqI/L+fFu0CO0EfL
1PJp+Z5cIEuan+QPoou+V68SP6dPlJP1TLKvPjReTrEH5dtytmxj6XbsdfTV
f4n7Ipfqr/PifCLPhPT6XlkM7/P+cR7NO+tX+KP4gzfEcT4/3knmI2Mvo5T+
s6yBfXwKMpv305Ogrf5P7E38yt+IM4V98fzxAR+ANH6mi36V18OfvBG+5wvi
XWc+KvYeSuunZE3s51ORxby/fkecNf3fuKf4jdc1e50vi73AJ/HMcS71/bIE
NvMKZrP4QJ6Wd+XXeBO+JvYxvywfxw98IQqYjdbvRmv+vrzP+mlZC12tHdCr
yvn6JPm8nlUO0IfJpHH25DvyxfgOmsdHp3XsMfl7PAf5hr6cl4w9wLPEudQP
yJL4kFeM9x4fFGeFd+OD5XW9qVyrz5T19b94Y/TWT8Q7W76qvxDfVr2gHKOP
kelkG/mBXCjLmJ/hD6GbflCvJhfok+PbrmeTA/XhMlmcY7lBzonvZWzb2Kt6
f3kunrtcpq/gpfgUnjXOoH4w9ho+4oPRAGVx1lptHOLTkBhnA4din2ALH4KG
KBd7E4fjGWErH4pG8Q6LPYSvrJfBNj4s3sdx3uN54WvrZbGdD4/zHnsmrhPf
WC+HHXxE7Jl4FsiOI9bL42M+Mp4DHkAO5MS3ZvfjEz4KzfC33gQ/8kWohF/0
OjjMp8fvdo8G6cnRPraM3paf54/x5XwlL82n8nEym3xWbpEvyVzm3/EK6Kh/
Gn9bfF/i3cTT8e78RvxdfB1vzq/IpviJv4xCZmPjfYLK+q/yYXzFq5st5DPi
mvlgPkLeKVvKd+Xc+G6YJ5Xt9AHygl5frtCnyVX6fXF+9PEyu0yUW5P8///M
3Ob/AduQMtI=
      "],
      VertexColors->Automatic]}},
   VertexColors->{
     Hue[0.65, 1, 0.1], 
     Hue[0.647841944435557, 1, 0.10298807693538273`], 
     Hue[0.6474201627834378, 1, 0.1035720822998553], 
     Hue[0.6470698640892572, 1, 0.10405711126102864`], 
     Hue[0.6466653256913921, 1, 0.10461724135038022`], 
     Hue[0.6461412415484118, 1, 0.10534289631758371`], 
     Hue[0.6455511626054383, 1, 0.10615992870016233`], 
     Hue[0.6447695780113137, 1, 0.1072421227535656], 
     Hue[0.64381311158964, 1, 0.108566460875883], 
     Hue[0.64269412464696, 1, 0.11011582741190167`], 
     Hue[0.6411380654883876, 1, 0.11227037086223263`], 
     Hue[0.38025688304412886`, 1, 0.4734904696312062], 
     Hue[0.2352485085445823, 1, 0.6742712958613476], 
     Hue[0.35337841233293976`, 1, 0.5107068136928526], 
     Hue[0.37838992105894487`, 1, 0.4760754939183841], 
     Hue[0.3794650235845607, 1, 0.4745868904213776], 
     Hue[0.3551132502872627, 1, 0.5083047303714824], 
     Hue[0.2638673660130045, 1, 0.6346451855204553], 
     Hue[0.34094921839636816`, 1, 0.527916466835798], 
     Hue[0.641080372255058, 1, 0.11235025380068897`], 
     Hue[0.6426627931012374, 1, 0.11015920955213278`], 
     Hue[0.6438616704840883, 1, 0.10849922548357019`], 
     Hue[0.6447525439465047, 1, 0.10726570838176268`], 
     Hue[0.6455336703896868, 1, 0.10618414869120293`], 
     Hue[0.6461302049908273, 1, 0.10535817770500845`], 
     Hue[0.6466180584628825, 1, 0.10468268828216282`], 
     Hue[0.6470612928697839, 1, 0.10406897910337623`], 
     Hue[0.6474100876912793, 1, 0.10358603242745948`], 
     Hue[0.6478120216762575, 1, 0.10302950844825881`], 
     Hue[0.65, 1, 0.1], 
     Hue[0.6492510749991883, 1, 0.10103697307804693`], 
     Hue[0.6475861172572024, 1, 0.10334229918233523`], 
     Hue[0.6468759741642778, 1, 0.10432557423407691`], 
     Hue[0.6464156602295401, 1, 0.1049629319898676], 
     Hue[0.6458599403347861, 1, 0.10573239030568078`], 
     Hue[0.6451813230420759, 1, 0.1066720142494335], 
     Hue[0.644318332575237, 1, 0.10786692412659503`], 
     Hue[0.6432853600533706, 1, 0.10929719377225616`], 
     Hue[0.6419687969695976, 1, 0.1111201272728649], 
     Hue[0.6363871657773628, 1, 0.11884853969288234`], 
     Hue[0.01207041855174018, 1, 0.9832871127745135], 
     Hue[0.3195379250004577, 1, 0.5575628730762894], 
     Hue[0.3697889226588154, 1, 0.4879845686262556], 
     Hue[0.38165101567767706`, 1, 0.47156013213860104`], 
     Hue[0.3714417301277565, 1, 0.4856960659769526], 
     Hue[0.32632909032755975`, 1, 0.5481597210849173], 
     Hue[0.043122720581715845`, 1, 0.9402916176560857], 
     Hue[0.6344939611974703, 1, 0.12146989988042585`], 
     Hue[0.6419263159558217, 1, 0.11117894713809298`], 
     Hue[0.6432987158113112, 1, 0.10927870118433843`], 
     Hue[0.6443305762621209, 1, 0.10784997132937121`], 
     Hue[0.645163967019711, 1, 0.10669604566501562`], 
     Hue[0.6458459340822901, 1, 0.10575178357836766`], 
     Hue[0.6463847751291885, 1, 0.10500569597496986`], 
     Hue[0.6468496535577393, 1, 0.10436201815082259`], 
     Hue[0.6475773368614992, 1, 0.10335445665330875`], 
     Hue[0.6492032299672812, 1, 0.10110322004530294`], 
     Hue[0.6498467376282827, 1, 0.10021220943776243`], 
     Hue[0.6476698163255933, 1, 0.10322640816456323`], 
     Hue[0.6469749049334255, 1, 0.10418859316910324`], 
     Hue[0.6465434026476174, 1, 0.10478605787252974`], 
     Hue[0.6460038217769912, 1, 0.10553316984724291`], 
     Hue[0.6453711210439219, 1, 0.10640921701610817`], 
     Hue[0.6445502100420205, 1, 0.10754586301874092`], 
     Hue[0.6435565831922334, 1, 0.10892165404152306`], 
     Hue[0.6423433340601732, 1, 0.11060153745514488`], 
     Hue[0.6405977666002967, 1, 0.11301847701497397`], 
     Hue[0.07893217658252427, 1, 0.8907092939626587], 
     Hue[0.289110719483175, 1, 0.5996928499463731], 
     Hue[0.3628157930429748, 1, 0.49763967117126573`], 
     Hue[0.3807207781641537, 1, 0.4728481533111719], 
     Hue[0.3762780143495482, 1, 0.47899967243908714`], 
     Hue[0.3430265989598573, 1, 0.52504009374789], 
     Hue[0.183056004115081, 1, 0.7465378404560418], 
     Hue[0.5743881902269216, 1, 0.20469327507041635`], 
     Hue[0.6415191983780358, 1, 0.11174264839964267`], 
     Hue[0.6429906383958948, 1, 0.10970526991337654`], 
     Hue[0.6441024090943088, 1, 0.10816589510018787`], 
     Hue[0.6449638435688024, 1, 0.10697313967396593`], 
     Hue[0.6456935187781464, 1, 0.10596282015333577`], 
     Hue[0.646260303236936, 1, 0.10517804167193492`], 
     Hue[0.6467364965443202, 1, 0.1045186970924797], 
     Hue[0.6474954391993177, 1, 0.10346785341632928`], 
     Hue[0.6483028914100524, 1, 0.10234984266300445`], 
     Hue[0.6483664762749782, 1, 0.10226180208079946`], 
     Hue[0.6475048232627859, 1, 0.10345486009768101`], 
     Hue[0.642998295658093, 1, 0.10969466755033291`], 
     Hue[0.6415682862188112, 1, 0.11167468062010752`], 
     Hue[0.5893374359847668, 1, 0.18399431940570754`], 
     Hue[0.1363481587220977, 1, 0.8112102417694032], 
     Hue[0.33945778962439377`, 1, 0.5299815220585318], 
     Hue[0.37486241892537, 1, 0.4809597276417955], 
     Hue[0.3812412721236268, 1, 0.472127469367286], 
     Hue[0.36458819992860125`, 1, 0.4951855693296291], 
     Hue[0.3022055273510652, 1, 0.5815615775139097], 
     Hue[0.03730323269888414, 1, 0.9483493701092373], 
     Hue[0.6404606090742285, 1, 0.11320838743568365`], 
     Hue[0.6423067429473579, 1, 0.11065220207288902`], 
     Hue[0.6476598567080419, 1, 0.1032401984042497], 
     Hue[0.6498374284337827, 1, 0.10022509909168564`], 
     Hue[0.6499581728339957, 1, 0.10005791453754442`], 
     Hue[0.6477300434339123, 1, 0.10314301678381378`], 
     Hue[0.6470228681205462, 1, 0.1041221826023206], 
     Hue[0.6466050700784813, 1, 0.10470067219902593`], 
     Hue[0.6460733156080187, 1, 0.10543694761966639`], 
     Hue[0.6454623197851636, 1, 0.10628294183592744`], 
     Hue[0.6446614011489763, 1, 0.1073919061014175], 
     Hue[0.6436866167751415, 1, 0.10874160754211187`], 
     Hue[0.6425215683170452, 1, 0.11035475156101436`], 
     Hue[0.6409151691529743, 1, 0.1125789965574202], 
     Hue[0.21990148847099106`, 1, 0.6955210159632431], 
     Hue[0.26665762677698296`, 1, 0.6307817475395621], 
     Hue[0.3584520666538548, 1, 0.5036817538638934], 
     Hue[0.37973780285679853`, 1, 0.4742091960444328], 
     Hue[0.3780611750645979, 1, 0.47653068067978754`], 
     Hue[0.3495359307856646, 1, 0.5160271727583106], 
     Hue[0.23105775466403222`, 1, 0.6800738781574939], 
     Hue[0.4834112057939145, 1, 0.3306614073622723], 
     Hue[0.6413046846317061, 1, 0.11203966743302235`], 
     Hue[0.6428292912886842, 1, 0.10992867360028355`], 
     Hue[0.6439836677132607, 1, 0.10833030624317759`], 
     Hue[0.6448596412801813, 1, 0.10711741976590297`], 
     Hue[0.6456145526687179, 1, 0.10607215784331375`], 
     Hue[0.64619597750554, 1, 0.10526710806925224`], 
     Hue[0.6466779570273902, 1, 0.10459975180822897`], 
     Hue[0.647453215021432, 1, 0.10352631766263258`], 
     Hue[0.6479921727887358, 1, 0.10278006844636586`], 
     Hue[0.6487994751990962, 1, 0.10166226510894383`], 
     Hue[0.6475458476797549, 1, 0.10339805705880104`], 
     Hue[0.6431438842642752, 1, 0.10949308332638825`], 
     Hue[0.641771937809, 1, 0.11139270149523076`], 
     Hue[0.6242842059450261, 1, 0.13560648407611778`], 
     Hue[0.06822948605536505, 1, 0.9055284039233407], 
     Hue[0.33044189608077557`, 1, 0.54246506696508], 
     Hue[0.3725372292595075, 1, 0.4841792210252974], 
     Hue[0.3816132743967913, 1, 0.47161238929675053`], 
     Hue[0.3682978863682762, 1, 0.4900490804131561], 
     Hue[0.31546832417427345`, 1, 0.5631977049894675], 
     Hue[0.0005580575393121512, 1, 0.9992273049455678], 
     Hue[0.6392479699506525, 1, 0.11488742622217347`], 
     Hue[0.6421197147725407, 1, 0.11091116416109749`], 
     Hue[0.6476175259538101, 1, 0.10329881021780146`], 
     Hue[0.6495914694859791, 1, 0.10056565763479819`], 
     Hue[0.6496170873491579, 1, 0.10053018674731985`], 
     Hue[0.6476262842734921, 1, 0.10328668331362627`], 
     Hue[0.6397392139335129, 1, 0.11420724224590525`], 
     Hue[0.006087728884321408, 1, 0.9915708369294011], 
     Hue[0.3061092406819378, 1, 0.5761564359788555], 
     Hue[0.36656886671409894`, 1, 0.49244310762663235`], 
     Hue[0.38135509296799963`, 1, 0.4719698712750775], 
     Hue[0.3740847936421225, 1, 0.4820364395724458], 
     Hue[0.33538339805936535`, 1, 0.5356229873024172], 
     Hue[0.11656122458585594`, 1, 0.8386075351888149], 
     Hue[0.61824520832143, 1, 0.14396817309340457`], 
     Hue[0.6475367884161247, 1, 0.10341060065459654`], 
     Hue[0.6487353633784194, 1, 0.10175103532218857`], 
     Hue[0.6480404278048842, 1, 0.10271325380862188`], 
     Hue[0.6413574544540437, 1, 0.11196660152517039`], 
     Hue[0.5115157716663759, 1, 0.29174739307732583`], 
     Hue[0.19365906650280168`, 1, 0.7318566771499669], 
     Hue[0.3470057505879175, 1, 0.5195304991859605], 
     Hue[0.37680312833763036`, 1, 0.4782725915325119], 
     Hue[0.3805290456538039, 1, 0.4731136290947331], 
     Hue[0.3602292659378309, 1, 0.5012210163937726], 
     Hue[0.28557233803441784`, 1, 0.60459214733696], 
     Hue[0.16640775217120796`, 1, 0.7695892662244813], 
     Hue[0.6408464601647084, 1, 0.1126741320796346], 
     Hue[0.647714737234125, 1, 0.10316420998351937`], 
     Hue[0.6499562360426159, 1, 0.10006059624868577`], 
     Hue[0.6499848223087802, 1, 0.100021015264766], 
     Hue[0.6477762716147145, 1, 0.10307900853347221`], 
     Hue[0.6470464854289739, 1, 0.10408948171372846`], 
     Hue[0.6466353717342468, 1, 0.10465871606027378`], 
     Hue[0.6461074716385428, 1, 0.10538965465432543`], 
     Hue[0.6455070305961457, 1, 0.10622103455918297`], 
     Hue[0.6447158595798154, 1, 0.10731650212025569`], 
     Hue[0.6437502984547747, 1, 0.10865343290877351`], 
     Hue[0.6426085408584401, 1, 0.11023432804215993`], 
     Hue[0.6410305947019551, 1, 0.11241917656652367`], 
     Hue[0.30128497309574775`, 1, 0.5828361910981955], 
     Hue[0.25237717729913084`, 1, 0.6505546775858189], 
     Hue[0.3560112216401759, 1, 0.507061385421295], 
     Hue[0.37911074166822273`, 1, 0.47507743461323004`], 
     Hue[0.3788088982669653, 1, 0.4754953716303557], 
     Hue[0.35243067051884114`, 1, 0.5120190715892969], 
     Hue[0.24897780447029128`, 1, 0.6552615015026736], 
     Hue[0.41763361437427604`, 1, 0.4217380724048486], 
     Hue[0.6411941698355383, 1, 0.11219268792002388`], 
     Hue[0.6427466996030242, 1, 0.11004303131888954`], 
     Hue[0.6439230835949402, 1, 0.10841419194546749`], 
     Hue[0.6448064608889793, 1, 0.10719105415372107`], 
     Hue[0.6455743549772814, 1, 0.10612781618530273`], 
     Hue[0.6461632747843697, 1, 0.10531238876010351`], 
     Hue[0.6466481801903821, 1, 0.10464098127485566`], 
     Hue[0.6474317658398112, 1, 0.10355601652949213`], 
     Hue[0.6478879229520123, 1, 0.10292441437413687`], 
     Hue[0.6490300317457053, 1, 0.10134303296748501`], 
     Hue[0.6475660608170084, 1, 0.10337006963798845`], 
     Hue[0.6432151264420423, 1, 0.1093944403110185], 
     Hue[0.6418711969447461, 1, 0.111255265768813], 
     Hue[0.6320986402943807, 1, 0.12478649805393455`], 
     Hue[0.03644216332371397, 1, 0.9495416200133191], 
     Hue[0.32525911465802454`, 1, 0.5496412258581199], 
     Hue[0.371218744117217, 1, 0.4860048158376996], 
     Hue[0.3816737668408649, 1, 0.4715286305280333], 
     Hue[0.36993609973875996`, 1, 0.48778078497710164`], 
     Hue[0.3211556561396788, 1, 0.5553229376527524], 
     Hue[0.014736696131138483`, 1, 0.9795953438184236], 
     Hue[0.637640299085083, 1, 0.11711343203603891`], 
     Hue[0.6420238296870006, 1, 0.11104392812569162`], 
     Hue[0.6475974073525281, 1, 0.1033266667426534], 
     Hue[0.6494131672613718, 1, 0.10081253763810064`], 
     Hue[0.6497491308871379, 1, 0.10034735723319362`], 
     Hue[0.6476471566488412, 1, 0.10325778310160456`], 
     Hue[0.640299717393958, 1, 0.1134311605314429], 
     Hue[0.03219673023613534, 1, 0.9554199119807356], 
     Hue[0.2981467937855202, 1, 0.5871813624508182], 
     Hue[0.36476337445165513`, 1, 0.494943019990016], 
     Hue[0.38108074273194, 1, 0.47234974083269854`], 
     Hue[0.3752349161569031, 1, 0.4804439622442881], 
     Hue[0.33936191163223156`, 1, 0.5301142762015255], 
     Hue[0.15194020570130495`, 1, 0.789621253644347], 
     Hue[0.601059315454513, 1, 0.1677640247552898], 
     Hue[0.6475162208019584, 1, 0.10343907888959622`], 
     Hue[0.6485076831784036, 1, 0.10206628482990278`], 
     Hue[0.6481870464620803, 1, 0.10251024336019664`], 
     Hue[0.6414638132380861, 1, 0.11181933551649628`], 
     Hue[0.5569486598638416, 1, 0.228840317111604], 
     Hue[0.16698257867568234`, 1, 0.7687933526029014], 
     Hue[0.34339465700424576`, 1, 0.5245304749171982], 
     Hue[0.37587875312508096`, 1, 0.4795524956729649], 
     Hue[0.3809282756398977, 1, 0.4725608491139879], 
     Hue[0.36249596698367426`, 1, 0.4980825072533742], 
     Hue[0.2943933925299845, 1, 0.5923783795738677], 
     Hue[0.09199027503470403, 1, 0.8726288499519482], 
     Hue[0.6406918559699197, 1, 0.11288819942626498`], 
     Hue[0.6476844723331723, 1, 0.10320611523099228`], 
     Hue[0.6499096685020481, 1, 0.1001250743817796], 
     Hue[0.64991432666725, 1, 0.100118624614577], 
     Hue[0.6476962973797613, 1, 0.10318974208956128`], 
     Hue[0.6407804470098292, 1, 0.11276553490946727`], 
     Hue[0.14337969314864707`, 1, 0.8014742710249503], 
     Hue[0.27873621061488574`, 1, 0.6140575545332351], 
     Hue[0.3607158823315621, 1, 0.5005472398486064], 
     Hue[0.3802737406916196, 1, 0.4734671282731421], 
     Hue[0.3772187384325073, 1, 0.4776971314011438], 
     Hue[0.346408965563676, 1, 0.5203568169118332], 
     Hue[0.20932289898514306`, 1, 0.7101682937128788], 
     Hue[0.5357108964729269, 1, 0.2582464510374859], 
     Hue[0.6481299321039763, 1, 0.10258932477910974`], 
     Hue[0.6485738612202632, 1, 0.10197465369502028`], 
     Hue[0.6108826734819043, 1, 0.15416245210197868`], 
     Hue[0.10271003410979429`, 1, 0.8577861066172079], 
     Hue[0.3351558551538955, 1, 0.5359380467099909], 
     Hue[0.3737500907774236, 1, 0.48249987430818275`], 
     Hue[0.38146930112490524`, 1, 0.4718117369039774], 
     Hue[0.3665184951952671, 1, 0.4925128528065533], 
     Hue[0.3091859477208205, 1, 0.571896380078864], 
     Hue[0.0068029033348432355`, 1, 0.9905805953825247], 
     Hue[0.6400505247767917, 1, 0.11377619646290384`], 
     Hue[0.6476380714113716, 1, 0.10327036266117784`], 
     Hue[0.6497328282004667, 1, 0.10036993018396917`], 
     Hue[0.6494497505526287, 1, 0.10076188385020655`], 
     Hue[0.6386192928472071, 1, 0.1157579022115595], 
     Hue[0.00037381556225446477`, 1, 0.9994824092214938], 
     Hue[0.3131914947868242, 1, 0.5663502379874742], 
     Hue[0.3815449307868381, 1, 0.4717070189105319], 
     Hue[0.3728223855473097, 1, 0.4837843892421866], 
     Hue[0.33105388959987747`, 1, 0.5416176913232466], 
     Hue[0.0789770250237829, 1, 0.8906471961209159], 
     Hue[0.6286157720423665, 1, 0.1296089310182618], 
     Hue[0.6489724241104419, 1, 0.10142279738554204`], 
     Hue[0.6479266323033612, 1, 0.10287081681073063`], 
     Hue[0.4521834851184777, 1, 0.37389978983595396`], 
     Hue[0.21628272099485957`, 1, 0.7005316170840407], 
     Hue[0.37763912883855794`, 1, 0.4771150523773814], 
     Hue[0.3800419637547178, 1, 0.4737880501857754], 
     Hue[0.27550400093547933`, 1, 0.618532921781644], 
     Hue[0.25257581374153454`, 1, 0.6502796425117214], 
     Hue[0.6409697416369212, 1, 0.11250343465657067`], 
     Hue[0.6477551404235918, 1, 0.1031082671057959], 
     Hue[0.6499842576459908, 1, 0.1000217971055513], 
     Hue[0.6499935369873423, 1, 0.10000894878675691`], 
     Hue[0.6478061886512861, 1, 0.10303758494437311`], 
     Hue[0.6470582043976613, 1, 0.10407325544939205`], 
     Hue[0.6466503919073493, 1, 0.10463791889751643`], 
     Hue[0.6461244045038788, 1, 0.10536620914847566`], 
     Hue[0.6455291682902691, 1, 0.10619038236731972`], 
     Hue[0.6447428105981272, 1, 0.10727918532567], 
     Hue[0.6437818127672839, 1, 0.1086097977068378], 
     Hue[0.6426515045494097, 1, 0.11017483985466352`], 
     Hue[0.641084964839814, 1, 0.11234389483718056`], 
     Hue[0.34148827442185814`, 1, 0.527170081569735], 
     Hue[0.24421472356964785`, 1, 0.6618565365958722], 
     Hue[0.35471982420810494`, 1, 0.5088494741733932], 
     Hue[0.3787622329221311, 1, 0.47555998518474163`], 
     Hue[0.3791482332211376, 1, 0.4750255232322711], 
     Hue[0.35379733298612837`, 1, 0.5101267697115146], 
     Hue[0.256755247150171, 1, 0.6444927347151479], 
     Hue[0.3803905001114415, 1, 0.47330546138415797`], 
     Hue[0.6411378000148994, 1, 0.1122707384409086], 
     Hue[0.6427049124699269, 1, 0.11010089042625511`], 
     Hue[0.6438924814896402, 1, 0.10845656409126748`], 
     Hue[0.6447795952954335, 1, 0.1072282526678614], 
     Hue[0.6455540740539325, 1, 0.10615589746378587`], 
     Hue[0.6461467861044199, 1, 0.10533521924003406`], 
     Hue[0.6466331627293468, 1, 0.10466177468244298`], 
     Hue[0.6474209556394511, 1, 0.10357098449922161`], 
     Hue[0.6478468331429933, 1, 0.10298130795585547`], 
     Hue[0.6491426146114839, 1, 0.10118714899948379`], 
     Hue[0.6475761046214532, 1, 0.10335616283183406`], 
     Hue[0.6432503680667216, 1, 0.10934564421530855`], 
     Hue[0.6419202021479861, 1, 0.11118741241048094`], 
     Hue[0.6345781678699118, 1, 0.12135330602627592`], 
     Hue[0.023002390553546692`, 1, 0.9681505361566277], 
     Hue[0.3224707813968581, 1, 0.5535019949889658], 
     Hue[0.3705181322390198, 1, 0.4869748938228957], 
     Hue[0.3816727944373508, 1, 0.471529976932899], 
     Hue[0.37070499075779123`, 1, 0.4867161666430583], 
     Hue[0.32380221420584177`, 1, 0.5516584726380652], 
     Hue[0.02758358059264765, 1, 0.9618073499486417], 
     Hue[0.6363216839227952, 1, 0.11893920687612974`], 
     Hue[0.641975278853964, 1, 0.11111115235604985`], 
     Hue[0.6475873795366663, 1, 0.10334055141076971`], 
     Hue[0.6493115966598032, 1, 0.10095317385565707`], 
     Hue[0.6498020268363591, 1, 0.1002741166881182], 
     Hue[0.64765816350094, 1, 0.10324254284485238`], 
     Hue[0.640469831557593, 1, 0.11319561784333293`], 
     Hue[0.053095414974536737`, 1, 0.9264832715737183], 
     Hue[0.2937775229538639, 1, 0.5932311220638807], 
     Hue[0.36380795476788824`, 1, 0.496265908782924], 
     Hue[0.3809115464846316, 1, 0.4725840125597409], 
     Hue[0.3757695391921508, 1, 0.4797037149647143], 
     Hue[0.34123139565086097`, 1, 0.5275257598680387], 
     Hue[0.1680955405753658, 1, 0.767252328434109], 
     Hue[0.5890782708894421, 1, 0.18435316338384944`], 
     Hue[0.6475058571236003, 1, 0.1034534285980919], 
     Hue[0.6484017404908186, 1, 0.10221297470502046`], 
     Hue[0.6482728432221546, 1, 0.10239144784624746`], 
     Hue[0.6415162746924804, 1, 0.11174669657964248`], 
     Hue[0.5746570670435877, 1, 0.204320984093494], 
     Hue[0.15212512768728487`, 1, 0.7893652078176056], 
     Hue[0.34146924164569514`, 1, 0.5271964346444221], 
     Hue[0.3753823220434434, 1, 0.4802398617860014], 
     Hue[0.381095466081764, 1, 0.4723293546560192], 
     Hue[0.36356307126962834`, 1, 0.4966049782420532], 
     Hue[0.2984132965501234, 1, 0.5868123586229061], 
     Hue[0.06180261033034873, 1, 0.9144271549272094], 
     Hue[0.6405903720591232, 1, 0.11302871561044481`], 
     Hue[0.6476716689942535, 1, 0.10322384293103352`], 
     Hue[0.6498772055976212, 1, 0.10017002301867842`], 
     Hue[0.6499387991595433, 1, 0.10008473962524779`], 
     Hue[0.647711980210203, 1, 0.1031680274012573], 
     Hue[0.6408514256755156, 1, 0.1126672567569785], 
     Hue[0.1805622982289819, 1, 0.7499906639906405], 
     Hue[0.272937615482054, 1, 0.62208637856331], 
     Hue[0.3596052437199455, 1, 0.5020850471569985], 
     Hue[0.3800170143856705, 1, 0.4738225954659948], 
     Hue[0.37765200838209034`, 1, 0.47709721916325953`], 
     Hue[0.3480028449774822, 1, 0.5181499069542554], 
     Hue[0.2207165817220899, 1, 0.6943924253078755], 
     Hue[0.5113056557553535, 1, 0.29203832280027986`], 
     Hue[0.6480566545633474, 1, 0.1026907859892113], 
     Hue[0.6486851606187373, 1, 0.10182054683559458`], 
     Hue[0.6184326981908573, 1, 0.14370857173573598`], 
     Hue[0.08538621640617505, 1, 0.8817729311299114], 
     Hue[0.3328536690480612, 1, 0.5391256890103768], 
     Hue[0.3731565303114125, 1, 0.4833217272611212], 
     Hue[0.381551751017208, 1, 0.4716975755146351], 
     Hue[0.36742641744618565`, 1, 0.49125572968989684`], 
     Hue[0.3124073552416683, 1, 0.5674359696653825], 
     Hue[0.0008108373857433904, 1, 0.9988773020812785], 
     Hue[0.6397181552135163, 1, 0.11423640047359296`], 
     Hue[0.6476277080547851, 1, 0.10328471192414378`], 
     Hue[0.6496668739863564, 1, 0.10046125140350655`], 
     Hue[0.6495377048552845, 1, 0.10064010096960617`], 
     Hue[0.6392762469686378, 1, 0.11484827342803991`], 
     Hue[0.0008130022291620298, 1, 0.9988743046057756], 
     Hue[0.3097504296626705, 1, 0.5711147896978409], 
     Hue[0.38146052116252466`, 1, 0.4718238937749659], 
     Hue[0.3734679810307418, 1, 0.48289048780358834`], 
     Hue[0.3332650988308083, 1, 0.5385560170034962], 
     Hue[0.09784508202434783, 1, 0.8645221941201338], 
     Hue[0.6241253044334616, 1, 0.13582650155366863`], 
     Hue[0.6488536844316216, 1, 0.10158720617160093`], 
     Hue[0.6479795903190804, 1, 0.10279749032742715`], 
     Hue[0.48356404020727456`, 1, 0.3304497904822352], 
     Hue[0.20546034077517616`, 1, 0.7155164512343715], 
     Hue[0.3772319674606537, 1, 0.4776788142852487], 
     Hue[0.3802966019413012, 1, 0.47343547423512145`], 
     Hue[0.28071194207894223`, 1, 0.6113219263522338], 
     Hue[0.2086104453986254, 1, 0.7111547679095956], 
     Hue[0.640910456730638, 1, 0.11258552144988587`], 
     Hue[0.6477333175580109, 1, 0.10313848338121578`], 
     Hue[0.6499721428384544, 1, 0.10003857145444787`], 
     Hue[0.6499732614030632, 1, 0.10003702267268175`], 
     Hue[0.6477511984491767, 1, 0.10311372522421691`], 
     Hue[0.6409743372221424, 1, 0.11249707153857208`], 
     Hue[0.25982958300143405`, 1, 0.6402359619980144], 
     Hue[0.37943581873116927`, 1, 0.47462732791068873`], 
     Hue[0.24044451896167252`, 1, 0.6670768198992227], 
     Hue[0.452108314660046, 1, 0.3740038720091672], 
     Hue[0.6479361232176774, 1, 0.10285767554475454`], 
     Hue[0.6287471974731521, 1, 0.12942695734486637`], 
     Hue[0.05172656740694248, 1, 0.9283785989750027], 
     Hue[0.3816539322653797, 1, 0.4715560937863974], 
     Hue[0.005449067389554529, 1, 0.9924551374606169], 
     Hue[0.6385814771299597, 1, 0.11581026243544047`], 
     Hue[0.6495067405047459, 1, 0.10068297468573646`], 
     Hue[0.6496875691775329, 1, 0.10043259652341596`], 
     Hue[0.640066258520201, 1, 0.1137544112797216], 
     Hue[0.01650549635380627, 1, 0.9771462358178067], 
     Hue[0.38122854276186463`, 1, 0.47214509463741827`], 
     Hue[0.6106672767117577, 1, 0.15446069378372015`], 
     Hue[0.6481095303510259, 1, 0.10261757336011793`], 
     Hue[0.5359581783182419, 1, 0.2579040607901266], 
     Hue[0.18083709800705727`, 1, 0.7496101719902284], 
     Hue[0.3807395314866615, 1, 0.47282218717231483`], 
     Hue[0.29012220565596974`, 1, 0.5982923306301957], 
     Hue[0.12716790401549416`, 1, 0.8239213636708542], 
     Hue[0.640775022239965, 1, 0.11277304612927933`], 
     Hue[0.6476986613684864, 1, 0.10318646887440339`], 
     Hue[0.6499357076566109, 1, 0.10008902016776956`], 
     Hue[0.649883915313537, 1, 0.10016073264279496`], 
     Hue[0.6476824023768215, 1, 0.10320898132440101`], 
     Hue[0.6406980452172157, 1, 0.11287962969923983`], 
     Hue[0.10924101803722908`, 1, 0.8487432057946059], 
     Hue[0.38050824896707036`, 1, 0.4731424245071334], 
     Hue[0.19679031465913066`, 1, 0.7275211027796653], 
     Hue[0.5566826724150964, 1, 0.2292086074252512], 
     Hue[0.6482120907471283, 1, 0.10247556665782248`], 
     Hue[0.6012995667246119, 1, 0.1674313691505373], 
     Hue[0.381365842473292, 1, 0.47195498734467256`], 
     Hue[0.018921921639997286`, 1, 0.973800416190773], 
     Hue[0.640287813042803, 1, 0.11344764347919592`], 
     Hue[0.64978952568855, 1, 0.10029142596970014`], 
     Hue[0.6376903953015312, 1, 0.11704406804403375`], 
     Hue[0.004315051868158615, 1, 0.9940253127979343], 
     Hue[0.381608407723495, 1, 0.4716191277674685], 
     Hue[0.060511758960156925`, 1, 0.9162144875936288], 
     Hue[0.6319923525188912, 1, 0.12493366574307371`], 
     Hue[0.6478809834661905, 1, 0.10293402289296705`], 
     Hue[0.4176121842926089, 1, 0.4217677448256185], 
     Hue[0.22618779618360946`, 1, 0.6868168975919254], 
     Hue[0.6477810586552248, 1, 0.1030723803235349], 
     Hue[0.6499933267595368, 1, 0.10000923987141068`], 
     Hue[0.6499970163196434, 1, 0.10000413124972468`], 
     Hue[0.6478232729120852, 1, 0.10301392981403586`], 
     Hue[0.6470640416290279, 1, 0.1040651731290383], 
     Hue[0.6466578696144224, 1, 0.1046275651492613], 
     Hue[0.646132834959245, 1, 0.1053545362102762], 
     Hue[0.6455401832469215, 1, 0.10617513088887792`], 
     Hue[0.6447562171898352, 1, 0.10726062235253585`], 
     Hue[0.6437974890435859, 1, 0.1085880920934964], 
     Hue[0.6426728572868414, 1, 0.11014527452591193`], 
     Hue[0.6411116464410211, 1, 0.112306951081663], 
     Hue[0.36109810369216205`, 1, 0.500018010272391], 
     Hue[0.23983818902296655`, 1, 0.6679163536605078], 
     Hue[0.35405550444152406`, 1, 0.5097693015425052], 
     Hue[0.37857907864778306`, 1, 0.47581358341076196`], 
     Hue[0.3793094265850243, 1, 0.47480233242073555`], 
     Hue[0.35446149915222736`, 1, 0.5092071550199929], 
     Hue[0.26038915833366566`, 1, 0.6394611653841552], 
     Hue[0.3609027185417658, 1, 0.5002885435575551], 
     Hue[0.6411092418920743, 1, 0.11231028045712799`], 
     Hue[0.6426838945350473, 1, 0.11012999218224234`], 
     Hue[0.643877102234287, 1, 0.10847785844483343`], 
     Hue[0.6447660929059521, 1, 0.10724694828406638`], 
     Hue[0.6455438877090798, 1, 0.10617000163358187`], 
     Hue[0.6461385071356945, 1, 0.10534668242749995`], 
     Hue[0.6466256214869525, 1, 0.10467221640268129`], 
     Hue[0.6474155288456078, 1, 0.10357849852146615`], 
     Hue[0.6478286966510214, 1, 0.10300642002166271`], 
     Hue[0.6491974611155251, 1, 0.10111120768619601`], 
     Hue[0.6475811141041401, 1, 0.1033492266250368], 
     Hue[0.6432678951271881, 1, 0.10932137597773964`], 
     Hue[0.6419445505148927, 1, 0.1111536992870716], 
     Hue[0.6355553599995162, 1, 0.12000027076990066`], 
     Hue[0.017180850359676758`, 1, 0.9762111302712168], 
     Hue[0.3210231017133451, 1, 0.555506474550753], 
     Hue[0.370157152806383, 1, 0.48747471149885435`], 
     Hue[0.38166450566940696`, 1, 0.4715414536885134], 
     Hue[0.371077320445518, 1, 0.48620063322928275`], 
     Hue[0.3250801137537439, 1, 0.5498890732640469], 
     Hue[0.03507041742265482, 1, 0.9514409604917088], 
     Hue[0.6354809404426636, 1, 0.12010331323323514`], 
     Hue[0.6419508491724394, 1, 0.11114497806893013`], 
     Hue[0.647582361161548, 1, 0.10334749993016436`], 
     Hue[0.6492581748008386, 1, 0.10102714258345431`], 
     Hue[0.6498253679747368, 1, 0.1002417981888261], 
     Hue[0.6476638931176063, 1, 0.10323460952946815`], 
     Hue[0.640538032181676, 1, 0.113101186209987], 
     Hue[0.06542122801116801, 1, 0.9094167612153059], 
     Hue[0.291483396206419, 1, 0.5964076052526507], 
     Hue[0.3633165465676629, 1, 0.4969463201370822], 
     Hue[0.3808188686489983, 1, 0.4727123357167716], 
     Hue[0.37602700900499064`, 1, 0.4793472183007822], 
     Hue[0.3421380403109728, 1, 0.5262704057232686], 
     Hue[0.17572860918712135`, 1, 0.7566834642024474], 
     Hue[0.5820919924329802, 1, 0.1940264720158737], 
     Hue[0.6475006549776722, 1, 0.10346063156937706`], 
     Hue[0.6483513611984884, 1, 0.10228273064824689`], 
     Hue[0.6483187206479724, 1, 0.10232792525665373`], 
     Hue[0.6415423363881246, 1, 0.11171061115490444`], 
     Hue[0.5823573762570875, 1, 0.1936590174901865], 
     Hue[0.14434392867359425`, 1, 0.8001391756827156], 
     Hue[0.34047457800758013`, 1, 0.5285736612202737], 
     Hue[0.375125336319523, 1, 0.48059568817296827`], 
     Hue[0.3811710313387338, 1, 0.47222472583867625`], 
     Hue[0.3640807845895362, 1, 0.49588814441448836`], 
     Hue[0.30033652759354046`, 1, 0.5841494233320209], 
     Hue[0.04880841709660222, 1, 0.9324191147893199], 
     Hue[0.6405298150479166, 1, 0.11311256377980783`], 
     Hue[0.6476656598701731, 1, 0.10323216325668338`], 
     Hue[0.6498582845766097, 1, 0.10019622135546362`], 
     Hue[0.6499490714673521, 1, 0.10007051642982008`], 
     Hue[0.6477206726010396, 1, 0.10315599178317603`], 
     Hue[0.640884006924622, 1, 0.11262214425821568`], 
     Hue[0.20002044408219155`, 1, 0.7230486158861963], 
     Hue[0.2698617389416875, 1, 0.6263452845422788], 
     Hue[0.3590340752319815, 1, 0.502875895832641], 
     Hue[0.37988023501053336`, 1, 0.4740119822931077], 
     Hue[0.3778595771913997, 1, 0.4768098161965235], 
     Hue[0.34877680890052953`, 1, 0.5170782645992669], 
     Hue[0.22601275600244347`, 1, 0.6870592609196937], 
     Hue[0.49779299545258127`, 1, 0.31074816014257983`], 
     Hue[0.6480233310665235, 1, 0.10273692621558289`], 
     Hue[0.6487420482172002, 1, 0.10174177939156911`], 
     Hue[0.6215506944298316, 1, 0.1393913461740794], 
     Hue[0.07675851359014008, 1, 0.893718981182883], 
     Hue[0.3316619272473327, 1, 0.5407757930421547], 
     Hue[0.37285013741567197`, 1, 0.48374596357830046`], 
     Hue[0.3815851255651423, 1, 0.47165136460211066`], 
     Hue[0.3678666342549145, 1, 0.49064619872396464`], 
     Hue[0.3139571104664536, 1, 0.5652901547387565], 
     Hue[0., 1, 1.], 
     Hue[0.6395035308232891, 1, 0.11453357270621511`], 
     Hue[0.6476226001250611, 1, 0.10329178444222314`], 
     Hue[0.6496303531394666, 1, 0.10051181872996941`], 
     Hue[0.6495784957322788, 1, 0.10058362129376792`], 
     Hue[0.63952793565504, 1, 0.11449978140071398`], 
     Hue[0.002822855804947122, 1, 0.9960914304239193], 
     Hue[0.3079559846469445, 1, 0.5735994058734615], 
     Hue[0.38141044166442906`, 1, 0.47189323461848287`], 
     Hue[0.37377994069928616`, 1, 0.48245854364714225`], 
     Hue[0.3343355218711832, 1, 0.5370738927937464], 
     Hue[0.10725192499174563`, 1, 0.8514973346268138], 
     Hue[0.6213775393698034, 1, 0.13963109933411832`], 
     Hue[0.6487943468374456, 1, 0.10166936591738293`], 
     Hue[0.6480089950573397, 1, 0.10275677607445276`], 
     Hue[0.4979770385924479, 1, 0.3104933311796875], 
     Hue[0.19968525186784097`, 1, 0.7235127281829894], 
     Hue[0.37702028392416714`, 1, 0.47797191456653787`], 
     Hue[0.38041558315284907`, 1, 0.4732707310191321], 
     Hue[0.2831831412078147, 1, 0.6079002660199488], 
     Hue[0.18721227976361604`, 1, 0.7407829972503778], 
     Hue[0.6408791887697111, 1, 0.11262881554963085`], 
     Hue[0.647723671018987, 1, 0.10315184012755647`], 
     Hue[0.64996471356087, 1, 0.10004885814648774`], 
     Hue[0.6499794382744005, 1, 0.10002847008159933`], 
     Hue[0.6477631894612831, 1, 0.10309712228437731`], 
     Hue[0.6410027547492178, 1, 0.1124577241933909], 
     Hue[0.25618656980891125`, 1, 0.6452801341107383], 
     Hue[0.3792761862101766, 1, 0.4748483575551401], 
     Hue[0.24481161205962187`, 1, 0.6610300756097544], 
     Hue[0.43524619457335245`, 1, 0.39735142289843506`], 
     Hue[0.6479110851962315, 1, 0.10289234357444867`], 
     Hue[0.6305459855748341, 1, 0.1269363276656144], 
     Hue[0.04389410910524871, 1, 0.9392235412388863], 
     Hue[0.38166645070553323`, 1, 0.4715387605615694], 
     Hue[0.009594254825146642, 1, 0.9867156471651817], 
     Hue[0.6381510201407081, 1, 0.11640627980517346`], 
     Hue[0.6494610150703892, 1, 0.10074628682561489`], 
     Hue[0.6497194550590032, 1, 0.10038844684138021`], 
     Hue[0.6401925506713226, 1, 0.11357954522432259`], 
     Hue[0.023691304568577376`, 1, 0.967196655212739], 
     Hue[0.3811573075532821, 1, 0.47224372800314796`], 
     Hue[0.6061384223843497, 1, 0.16073141516013123`], 
     Hue[0.6481472380468648, 1, 0.10256536270434104`], 
     Hue[0.5468766055081582, 1, 0.24278623852716563`], 
     Hue[0.1740381715441902, 1, 0.7590240701695828], 
     Hue[0.3808366080101783, 1, 0.4726877735243685], 
     Hue[0.2922908245553984, 1, 0.5952896275386792], 
     Hue[0.10900854852292985`, 1, 0.8490650866605587], 
     Hue[0.6407352517759252, 1, 0.11282811292564214`], 
     Hue[0.6476913649468607, 1, 0.10319657161203893`], 
     Hue[0.6499234339708698, 1, 0.10010601450187252`], 
     Hue[0.6498999158910808, 1, 0.10013857799696516`], 
     Hue[0.647689158882889, 1, 0.10319962616215365`], 
     Hue[0.6407410131382987, 1, 0.11282013565466335`], 
     Hue[0.1258778345738436, 1, 0.8257076136669858], 
     Hue[0.38039375688790367`, 1, 0.47330095200136413`], 
     Hue[0.20320360944253912`, 1, 0.7186411561564843], 
     Hue[0.5466178103377806, 1, 0.2431445703015346], 
     Hue[0.648169908158964, 1, 0.1025339733183575], 
     Hue[0.6063667976093324, 1, 0.16041520331015513`], 
     Hue[0.38142020547147815`, 1, 0.47187971550103025`], 
     Hue[0.012081754707547243`, 1, 0.9832714165587807], 
     Hue[0.6401788954607293, 1, 0.11359845243899036`], 
     Hue[0.6497623107684638, 1, 0.1003291081667424], 
     Hue[0.6381946085840514, 1, 0.11634592657592888`], 
     Hue[0.001830128986839763, 1, 0.997465975248991], 
     Hue[0.3815792812806719, 1, 0.47165945668830045`], 
     Hue[0.06965458206126518, 1, 0.9035551940690174], 
     Hue[0.6304274771234769, 1, 0.12710041629057042`], 
     Hue[0.6479029355746326, 1, 0.10290362766589324`], 
     Hue[0.4352752681834741, 1, 0.39731116713057435`], 
     Hue[0.2213455433902511, 1, 0.6935215553058062], 
     Hue[0.6477675302360363, 1, 0.10309111198087288`], 
     Hue[0.6499891299519429, 1, 0.10001505083577135`], 
     Hue[0.6499894961587154, 1, 0.10001454378024031`], 
     Hue[0.6477905636018336, 1, 0.10305921962823035`], 
     Hue[0.6478665397678468, 1, 0.10295402185990452`], 
     Hue[0.6334339194522445, 1, 0.12293764998920002`], 
     Hue[0.029450781223752553`, 1, 0.9592219952286504], 
     Hue[0.38167587893283167`, 1, 0.4715257060930024], 
     Hue[0.020769402944883608`, 1, 0.9712423651532381], 
     Hue[0.6370356710114344, 1, 0.1179506093687831], 
     Hue[0.6497766367262287, 1, 0.10030927222522196`], 
     Hue[0.6403911890476606, 1, 0.11330450747247003`], 
     Hue[0.042007221780410275`, 1, 0.9418361544578934], 
     Hue[0.3809988286182713, 1, 0.4724631603747014], 
     Hue[0.5953868334528627, 1, 0.1756182306037286], 
     Hue[0.5661988796455623, 1, 0.21603232049076004`], 
     Hue[0.3810145520498247, 1, 0.47244138946947356`], 
     Hue[0.07622311351109479, 1, 0.8944603043692533], 
     Hue[0.6406439316913151, 1, 0.1129545561197176], 
     Hue[0.6498942968307041, 1, 0.10014635823440968`], 
     Hue[0.6499272526083334, 1, 0.10010072715769222`], 
     Hue[0.6408170603999431, 1, 0.11271483944623266`], 
     Hue[0.5239438703436952, 1, 0.27453925644719135`], 
     Hue[0.6148904654278435, 1, 0.14861320171529357`], 
     Hue[0.38151314808405634`, 1, 0.4717510257297681], 
     Hue[0.0030597650064418946`, 1, 0.9957634022987727], 
     Hue[0.6398985720452087, 1, 0.11398659255278802`], 
     Hue[0.6497010272369832, 1, 0.1004139622872541], 
     Hue[0.6389763735377612, 1, 0.11526348279386915`], 
     Hue[0.000014352248194238193`, 1, 0.9999801276563465], 
     Hue[0.38150534871354935`, 1, 0.4717618248581624], 
     Hue[0.6265261767808014, 1, 0.13250221676504426`], 
     Hue[0.6479521583403359, 1, 0.10283547306722725`], 
     Hue[0.6477437729150449, 1, 0.10312400673301478`], 
     Hue[0.649978625441746, 1, 0.10002959554219783`], 
     Hue[0.6499662038211845, 1, 0.10004679470912908`], 
     Hue[0.626671111801424, 1, 0.13230153750572063`], 
     Hue[0.3816362084602943, 1, 0.4715806344395925], 
     Hue[0.0024044432674100724`, 1, 0.996670770860509], 
     Hue[0.6389436428864329, 1, 0.11530880215724684`], 
     Hue[0.6399167574390738, 1, 0.11396141277666709`], 
     Hue[0.01064114698672669, 1, 0.9852661041722245], 
     Hue[0.3812944654221777, 1, 0.47205381710775396`], 
     Hue[0.6146888019428256, 1, 0.14889242807916464`], 
     Hue[0.6499466040787308, 1, 0.10007393281406504`], 
     Hue[0.6498662222180652, 1, 0.10018523077498667`], 
     Hue[0.640650659615757, 1, 0.11294524053202887`], 
     Hue[0.5659296628288217, 1, 0.21640508223701613`], 
     Hue[0.5956374816469338, 1, 0.1752711792580917], 
     Hue[0.3813062032509241, 1, 0.47203756472948966`], 
     Hue[0.027332071192527008`, 1, 0.9621555937334241], 
     Hue[0.6403807498030206, 1, 0.11331896181120223`], 
     Hue[0.6498145386785963, 1, 0.10025679259886666`], 
     Hue[0.6370930532814012, 1, 0.11787115699498295`], 
     Hue[0.007754622020254676, 1, 0.9892628310488782], 
     Hue[0.381632316477498, 1, 0.4715860233388489], 
     Hue[0.6333390816732671, 1, 0.1230689638370148], 
     Hue[0.6477958473267951, 1, 0.10305190370136064`], 
     Hue[0.6499969261842111, 1, 0.10000425605263076`]}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->((Print[#]; #)& ),
  FormatType->OutputForm,
  Method->{},
  PlotLabel->"Surface Intensity",
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.563367609587453*^9, 3.5660870606060963`*^9, 
  3.5661018480466537`*^9, 3.566139119047*^9, 3.566139297759424*^9, 
  3.614707881345689*^9, 3.614710114326498*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "During evaluation of \
In[355]:=",ExpressionUUID->"a296cdfd-0141-441f-98aa-ef27a78ddd7c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "IntensityFunction", 
      "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
     RowBox[{"OutputGraphics", "\[Rule]", 
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJwtl3c419/7x62sZO/t7T2pqKgo7iNCSyEJJZXUR1ZWKg3Klh2yN9EQslKv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        
        "], {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1WWUEFUYBuClG6U7lg7pVrqUhkU6lC5haVA67cIWsMWW7u7ubrBRDCxs
fb7jj2e/973DYe/MnTmb2Dc5aUSKhISEm37EnO5HHq6xTr9ojuVH7tMPmQNI
z+36MrMF1+VXKMJ8vSon5Qc5Lg8lC5307WZ3/pYXk5IZel7Wy8M5LA8kA3fo
y82WfCu/SlEW6NU4JT/ECXkYWems7zB78I+8hFTM1POxQR5BXVborfhOfo1E
FurVOS0/TBd26j35V15Kambp+dkoJ1OPlXprvpdfp1g8G70GZ+RH6MouvVc8
dJYZaZgtF2CTPJL6rNLb8IP8BsXjGeg1OSs/SjfSMsdaQTbLo2jAar0tN+Q3
KRH3qdfinPwY3UnHXGuF2CKPpiFr9HbxDshvUTLuS6/NeflxepA+zttaYbbK
Y2hEqdi3tTpckJ+gJxni3KwVYZs8lsaUJmM8d+tF2S6PowllyETmeI6uJbJD
Hk9TysY9xrvJRflJepElnpO1YuyUJ9CMcnFP8Y5xSX6K3mSN52KtOLvkiTRn
rd6en+S3KR9Tr8tl+WlOxrfCLdyj7zZ7x/fFcv2cOYqc8W/i+Zkl2C1fMsdx
v3zEHBTvPBn5jEnc6do6swPf8LN+1ZwYmUX6WXNkvIPk4Aum8Cu3ub7IrMfX
XNGvmBPivpinnzKHxzfBrXzOZH7hXtf3xL1xnZR8EntmhWvnzdHxvpKLL5ka
/0+cvVmSPfJlczwPyEfNwWTiLn29mRS/T36HCjH1+lyVn6EPe2M/pGKlni3O
XC7FXnkSLahI9jhf66XZJ0+mJZXIQc44P9fKsF+eQisq8661BnGf8rP0JRfz
rJXlgDyV1lThPWsN+VR+jn7kjn1bK8dBeRptqMr71hrFGcvP05888busleeQ
PJ22bNA7xlnGvqjGB3rjOCf5BQaQN353nDeH5Rm0Y6N+Nzdjn1TnQ71JvCfy
iwwkX+zFWgWOyDNpzya9E7/FvqnBR3rTOGv5JQaRP/ZirSJH5Vl0YLPemd9j
39TkY70ZX8kvM5h9eh9Ss0ovEHuTK3FMnk0SW/Qu/BH3QS0W6825Js9nCPv1
vqRhtV4w9ipX5rg8h45s1bvyZ9wXtVkS3118L/ICTsvxhzMbQ/UDZj/SskYv
FPchV+GEPJdj8hAyx/PXt5nd+Cvunzosjfc/vmt5IWfkZLIzTD9o9iddvFvx
7bDW+gVzDDfIHc+RaSn+/7te2PX/ABkY+sg=
           "],
           VertexColors->Automatic]}},
        VertexColors->{
          Hue[0.65, 1, 0.1], 
          Hue[0.6494207291151731, 1, 0.1008020673789911], 
          Hue[0.6483599788274689, 1, 0.10227079854658155`], 
          Hue[0.6459852201968237, 1, 0.10555892588132101`], 
          Hue[0.6409985648914213, 1, 0.11246352553495513`], 
          Hue[0.6300250241010613, 1, 0.12765765893699202`], 
          Hue[0.6109703924263565, 1, 0.15404099510196786`], 
          Hue[0.5755862811077844, 1, 0.20303438000460622`], 
          Hue[0.5207719417881722, 1, 0.2789311575240694], 
          Hue[0.4489578486886055, 1, 0.3783660556619308], 
          Hue[0.35019884226963294`, 1, 0.5151092953189698], 
          Hue[0.24594863957126922`, 1, 0.6594557298243965], 
          Hue[0.14545260567613372`, 1, 0.7986040844484303], 
          Hue[0.056261934593322294`, 1, 0.9220988597938614], 
          Hue[0.008173938274651182, 1, 0.9886822393120214], 
          Hue[0.00556678247483644, 1, 0.9922921473425341], 
          Hue[0.05366208318546595, 1, 0.9256986540508932], 
          Hue[0.13408205829263364`, 1, 0.8143479192871227], 
          Hue[0.2426466933727217, 1, 0.6640276553300776], 
          Hue[0.3467852798121602, 1, 0.5198357664139321], 
          Hue[0.4469181406755143, 1, 0.3811902667569803], 
          Hue[0.5237436058962835, 1, 0.2748165456820689], 
          Hue[0.5746967614881886, 1, 0.2042660225548158], 
          Hue[0.6102971366499449, 1, 0.1549731954077686], 
          Hue[0.6297374411047794, 1, 0.12805585077799783`], 
          Hue[0.6402286639346562, 1, 0.11352954224432228`], 
          Hue[0.6459064132235023, 1, 0.10566804322899684`], 
          Hue[0.648311787911976, 1, 0.10233752442957175`], 
          Hue[0.6494043430446556, 1, 0.10082475578432318`], 
          Hue[0.65, 1, 0.1], 
          Hue[0.6496518898476994, 1, 0.10048199867241626`], 
          Hue[0.6490150342682998, 1, 0.1013637987054312], 
          Hue[0.647410481848161, 1, 0.10358548667177721`], 
          Hue[0.6439359118437823, 1, 0.10839642975476306`], 
          Hue[0.636454463637649, 1, 0.11875535804017828`], 
          Hue[0.6218275983185867, 1, 0.13900794078964923`], 
          Hue[0.5955429566057608, 1, 0.17540206008433118`], 
          Hue[0.5509475435046666, 1, 0.23714955514738473`], 
          Hue[0.4873908802620105, 1, 0.3251510888679855], 
          Hue[0.4018928555258338, 1, 0.44353296927192243`], 
          Hue[0.19455923984596663`, 1, 0.7306102832902001], 
          Hue[0.09701960143856403, 1, 0.8656651672389114], 
          Hue[0.02716339324549677, 1, 0.9623891478139276], 
          Hue[0.00014034654871986074`, 1, 0.9998056740094649], 
          Hue[0.023817633701099572`, 1, 0.9670217379523237], 
          Hue[0.0904485547617806, 1, 0.8747635395606115], 
          Hue[0.1868201403418519, 1, 0.7413259595266666], 
          Hue[0.3991759412895396, 1, 0.447294850522176], 
          Hue[0.4882385447693514, 1, 0.32397739955012883`], 
          Hue[0.5516287881307232, 1, 0.23620629335746016`], 
          Hue[0.594762057920179, 1, 0.1764833044182137], 
          Hue[0.6213775410773189, 1, 0.13963109696986614`], 
          Hue[0.6358062713392225, 1, 0.11965285506876888`], 
          Hue[0.6436112354568084, 1, 0.10884598167518836`], 
          Hue[0.6473474656665777, 1, 0.10367273984627695`], 
          Hue[0.6489865689245254, 1, 0.10140321225834946`], 
          Hue[0.6496468826235906, 1, 0.10048893175195155`], 
          Hue[0.6497321434595643, 1, 0.10037087828675707`], 
          Hue[0.6492426274089493, 1, 0.10104866974145481`], 
          Hue[0.6479347555815825, 1, 0.10285956919473198`], 
          Hue[0.6450541768827651, 1, 0.10684806277770983`], 
          Hue[0.6389300669131007, 1, 0.11532759965878363`], 
          Hue[0.6262295627386543, 1, 0.1329129131310941], 
          Hue[0.603781552454058, 1, 0.16399477352515052`], 
          Hue[0.5639300922070762, 1, 0.21917371848250988`], 
          Hue[0.5047022616014935, 1, 0.3011814839363937], 
          Hue[0.4260748244094891, 1, 0.4100502431253229], 
          Hue[0.22009229518519086`, 1, 0.6952568220512743], 
          Hue[0.12044884487286078`, 1, 0.8332246763298852], 
          Hue[0.040618200928714376`, 1, 0.9437594140987032], 
          Hue[0.0025424754563085905`, 1, 0.996479649368188], 
          Hue[0.013156253001414875`, 1, 0.9817836496903487], 
          Hue[0.07096310266323758, 1, 0.9017433963124403], 
          Hue[0.15992763971104007`, 1, 0.7785617296308676], 
          Hue[0.3735107579215473, 1, 0.482831258262473], 
          Hue[0.4682943093220293, 1, 0.3515924947848825], 
          Hue[0.5383316269063101, 1, 0.2546177473604938], 
          Hue[0.5853374320724352, 1, 0.1895327863612437], 
          Hue[0.6162193961507102, 1, 0.14677314379132433`], 
          Hue[0.6330034585506575, 1, 0.12353367277601272`], 
          Hue[0.6420787655123184, 1, 0.11096786313678998`], 
          Hue[0.6466975826093497, 1, 0.10457257792551576`], 
          Hue[0.6486884484260262, 1, 0.10181599448704068`], 
          Hue[0.6495402321737841, 1, 0.1006366016055297], 
          Hue[0.6495499628395041, 1, 0.10062312837607137`], 
          Hue[0.6487256461124465, 1, 0.10176448999815103`], 
          Hue[0.6467679595336518, 1, 0.10447513295340517`], 
          Hue[0.6425949836076611, 1, 0.11025309962016161`], 
          Hue[0.6335086099958211, 1, 0.12283423231347851`], 
          Hue[0.616771417915035, 1, 0.14600880596379773`], 
          Hue[0.5861674770607089, 1, 0.18838349330055693`], 
          Hue[0.53657711461306, 1, 0.2570470720742247], 
          Hue[0.16951818137176838`, 1, 0.7652825181006284], 
          Hue[0.0755153279825469, 1, 0.895440315101089], 
          Hue[0.01637978258736461, 1, 0.9773203010328798], 
          Hue[0.0011011971854738567`, 1, 0.9984752654354977], 
          Hue[0.03738683022823286, 1, 0.9482336196839852], 
          Hue[0.4237098121695827, 1, 0.41332487545750096`], 
          Hue[0.5067235376586576, 1, 0.2983827940110895], 
          Hue[0.5637596392896171, 1, 0.21940973021437638`], 
          Hue[0.6030493285054798, 1, 0.1650086220693358], 
          Hue[0.6258633443702754, 1, 0.13341998471808025`], 
          Hue[0.638198731076733, 1, 0.116340218509139], 
          Hue[0.6448730958620779, 1, 0.10709879034481526`], 
          Hue[0.6478794125152932, 1, 0.10293619805574789`], 
          Hue[0.6492209562258624, 1, 0.10107867599495976`], 
          Hue[0.6497301292549986, 1, 0.10037366718538653`], 
          Hue[0.6497654391708975, 1, 0.10032477653260362`], 
          Hue[0.6493372300669759, 1, 0.10091768144572576`], 
          Hue[0.6481586485398694, 1, 0.10254956356018093`], 
          Hue[0.6455416274010782, 1, 0.10617313129081478`], 
          Hue[0.6400101088613751, 1, 0.11383215696117292`], 
          Hue[0.6281972106634922, 1, 0.13018847754285692`], 
          Hue[0.6074976215084973, 1, 0.15884944714208066`], 
          Hue[0.5699143209564721, 1, 0.21088786329103873`], 
          Hue[0.5128857413931552, 1, 0.28985051191716976`], 
          Hue[0.4376810276555959, 1, 0.3939801155537903], 
          Hue[0.2329626690112277, 1, 0.6774363044459925], 
          Hue[0.13268969765867134`, 1, 0.8162758032418397], 
          Hue[0.04820070185165759, 1, 0.9332605666669356], 
          Hue[0.004879918246886494, 1, 0.9932431901196955], 
          Hue[0.008973932162907317, 1, 0.9875745554667438], 
          Hue[0.062054922844122506`, 1, 0.9140777991389073], 
          Hue[0.14675281245542726`, 1, 0.7968037981386392], 
          Hue[0.3602177389129965, 1, 0.5012369768896972], 
          Hue[0.45774909551489484`, 1, 0.36619356005629944`], 
          Hue[0.5311961770561315, 1, 0.2644976009992026], 
          Hue[0.5801827913638135, 1, 0.196669981188566], 
          Hue[0.6133560172484914, 1, 0.15073782227131954`], 
          Hue[0.6314334824307528, 1, 0.12570748586511157`], 
          Hue[0.6411971758777634, 1, 0.11218852570771237`], 
          Hue[0.6463207379036616, 1, 0.10509436290262239`], 
          Hue[0.648511239134409, 1, 0.10206136119851061`], 
          Hue[0.6494764089575185, 1, 0.10072497221266673`], 
          Hue[0.6496039701558861, 1, 0.100548349014927], 
          Hue[0.6488787876705218, 1, 0.10155244784081602`], 
          Hue[0.6471057400263723, 1, 0.10400743688656136`], 
          Hue[0.643295712528503, 1, 0.10928285957591889`], 
          Hue[0.6350434431835659, 1, 0.12070907866890887`], 
          Hue[0.6193885747968867, 1, 0.1423850502812338], 
          Hue[0.5910082837683867, 1, 0.181680837859157], 
          Hue[0.5439173332541719, 1, 0.2468836924173004], 
          Hue[0.18192343711704412`, 1, 0.7481060101456312], 
          Hue[0.08609305995467531, 1, 0.880794224678142], 
          Hue[0.021508297474848614`, 1, 0.9702192804194403], 
          Hue[0.0002552397160495712, 1, 0.999646591162393], 
          Hue[0.030147379495666704`, 1, 0.9582574745444614], 
          Hue[0.4116334914816121, 1, 0.430045934871614], 
          Hue[0.4976784957028324, 1, 0.3109066982576167], 
          Hue[0.557843778982504, 1, 0.22760092140884056`], 
          Hue[0.5990328135710151, 1, 0.1705699504401329], 
          Hue[0.623704438506664, 1, 0.13640923899077298`], 
          Hue[0.6370516746455246, 1, 0.11792845049081221`], 
          Hue[0.6442720788272625, 1, 0.10793096777763664`], 
          Hue[0.6476267611864202, 1, 0.10328602297264908`], 
          Hue[0.6491107257652587, 1, 0.10123130278656486`], 
          Hue[0.6496910652325488, 1, 0.10042775583185544`], 
          Hue[0.6496944455314316, 1, 0.10042307541801772`], 
          Hue[0.6491355801136436, 1, 0.10119688907341665`], 
          Hue[0.647685817024253, 1, 0.10320425335103431`], 
          Hue[0.6445202618977596, 1, 0.10758732968002531`], 
          Hue[0.6377445326942796, 1, 0.1169691085771514], 
          Hue[0.6241070036511778, 1, 0.1358518410983693], 
          Hue[0.5997905636800137, 1, 0.1695207579815195], 
          Hue[0.033529864836120415`, 1, 0.9535740333038332], 
          Hue[0.000820672883857565, 1, 0.9988636836992741], 
          Hue[0.018055566676949852`, 1, 0.9749999846011463], 
          Hue[0.5901897672143893, 1, 0.18281416847238408`], 
          Hue[0.6188857168052098, 1, 0.14308131519278652`], 
          Hue[0.6344582356475255, 1, 0.12151936602650318`], 
          Hue[0.6428807884467144, 1, 0.10985736984301096`], 
          Hue[0.6470389706958329, 1, 0.10409988672884671`], 
          Hue[0.6488462518757435, 1, 0.10159749740281673`], 
          Hue[0.6495967593437255, 1, 0.10055833321638016`], 
          Hue[0.6494890958976763, 1, 0.10070740568014047`], 
          Hue[0.6485535668794812, 1, 0.10200275355148768`], 
          Hue[0.6463954966321691, 1, 0.10499085081699659`], 
          Hue[0.6418305944838195, 1, 0.11131148456086531`], 
          Hue[0.01186584114103939, 1, 0.9835703738047147], 
          Hue[0.003014814598248705, 1, 0.9958256413255018], 
          Hue[0.04507639842031019, 1, 0.937586525264186], 
          Hue[0.6454154167285172, 1, 0.10634788452974545`], 
          Hue[0.6481069717370723, 1, 0.10262111605636147`], 
          Hue[0.6493183917789869, 1, 0.10094376522909522`], 
          Hue[0.6497645771548026, 1, 0.10032597009335024`], 
          Hue[0.6498156969640339, 1, 0.1002551888190301], 
          Hue[0.6493803424997586, 1, 0.10085798730802652`], 
          Hue[0.6482619346671442, 1, 0.10240655199933883`], 
          Hue[0.6457687434921986, 1, 0.10585866285695587`], 
          Hue[0.6405167853575846, 1, 0.11313060488949822`], 
          Hue[0.6291275574117453, 1, 0.1289003051221988], 
          Hue[0.6092702127459539, 1, 0.15639509004406382`], 
          Hue[0.5727992522753718, 1, 0.2068933430033315], 
          Hue[0.5168681364555202, 1, 0.28433642644620283`], 
          Hue[0.4433380575771747, 1, 0.38614730489314275`], 
          Hue[0.2394429704349363, 1, 0.6684635793977806], 
          Hue[0.13900350889158708`, 1, 0.8075336030731871], 
          Hue[0.05215931269827989, 1, 0.927779413186997], 
          Hue[0.006513860538898464, 1, 0.9909808084846021], 
          Hue[0.007244993874565342, 1, 0.9899684700198327], 
          Hue[0.05780288016688462, 1, 0.9199652428458521], 
          Hue[0.14040607708495845`, 1, 0.8055915855746729], 
          Hue[0.3535403161828563, 1, 0.5104826391314298], 
          Hue[0.4523674474604524, 1, 0.37364507274706593`], 
          Hue[0.5275070353930483, 1, 0.26960564330193315`], 
          Hue[0.5774846378411919, 1, 0.2004058860660421], 
          Hue[0.611850308152146, 1, 0.15282265025087474`], 
          Hue[0.6306018039211293, 1, 0.1268590407245902], 
          Hue[0.6407250449747978, 1, 0.1128422454195108], 
          Hue[0.6461184593559964, 1, 0.10537444089169724`], 
          Hue[0.6484143722698229, 1, 0.10219548454947601`], 
          Hue[0.6494414324568076, 1, 0.10077340121365107`], 
          Hue[0.6496286408698813, 1, 0.10051418956477975`], 
          Hue[0.648948859543617, 1, 0.10145542524729959`], 
          Hue[0.6472620543442131, 1, 0.10379100167724335`], 
          Hue[0.6436231299801387, 1, 0.10882951233519264`], 
          Hue[0.6357626302459535, 1, 0.11971328119791055`], 
          Hue[0.6206289451465506, 1, 0.1406676144124684], 
          Hue[0.5933035613524025, 1, 0.1785027612043659], 
          Hue[0.5474779173861639, 1, 0.24195365284992695`], 
          Hue[0.18821967048573568`, 1, 0.7393881485582121], 
          Hue[0.0914367058553921, 1, 0.8733953303540725], 
          Hue[0.024260631147992595`, 1, 0.9664083568720102], 
          Hue[0., 1, 1.], 
          Hue[0.026942062744802597`, 1, 0.9626956054302733], 
          Hue[0.4054506548224489, 1, 0.4386067856304554], 
          Hue[0.492986217531469, 1, 0.31740369880258146`], 
          Hue[0.5547719561572144, 1, 0.2318542145515494], 
          Hue[0.596930758218039, 1, 0.17348048862117688`], 
          Hue[0.6225620241788583, 1, 0.1379910434446577], 
          Hue[0.6364416041977556, 1, 0.11877316341849226`], 
          Hue[0.6439498560776629, 1, 0.10837712235400523`], 
          Hue[0.6474905585472978, 1, 0.10347461124220309`], 
          Hue[0.6490505025450081, 1, 0.10131468878383505`], 
          Hue[0.6496696689649388, 1, 0.10045738143316166`], 
          Hue[0.6497138750931621, 1, 0.10039617294792937`], 
          Hue[0.6491908197746583, 1, 0.10112040338893463`], 
          Hue[0.6478134992570235, 1, 0.10302746256719827`], 
          Hue[0.6447932273372816, 1, 0.10720937753299468`], 
          Hue[0.6383506132048501, 1, 0.11612992017789997`], 
          Hue[0.6251880880245785, 1, 0.13435495504289144`], 
          Hue[0.6018192177236514, 1, 0.16671185238263647`], 
          Hue[0.0369975758984048, 1, 0.9487725872175934], 
          Hue[0.0015603399530835782`, 1, 0.9978395292957305], 
          Hue[0.015580411852772591`, 1, 0.9784271220500071], 
          Hue[0.5878089673845414, 1, 0.18611066054448117`], 
          Hue[0.617576032279718, 1, 0.144894724535775], 
          Hue[0.6337445971590395, 1, 0.12250748085671459`], 
          Hue[0.6424901598078436, 1, 0.11039824026606268`], 
          Hue[0.646872593150577, 1, 0.10433025563766264`], 
          Hue[0.648769847931607, 1, 0.1017032874793134], 
          Hue[0.64956933132633, 1, 0.10059631047123539`], 
          Hue[0.6495204290247414, 1, 0.10066402135035817`], 
          Hue[0.6486419403172279, 1, 0.10188039032999226`], 
          Hue[0.6465861685402597, 1, 0.10472684355964035`], 
          Hue[0.6422209369787532, 1, 0.11077101033711102`], 
          Hue[0.01402899081839215, 1, 0.9805752434822262], 
          Hue[0.0019645800268670577`, 1, 0.9972798122704918], 
          Hue[0.041166755940964084`, 1, 0.9429998763894343], 
          Hue[0.6451506192900185, 1, 0.10671452713689752`], 
          Hue[0.6479962086715645, 1, 0.1027744803009107], 
          Hue[0.6492710746147498, 1, 0.10100928130265428`], 
          Hue[0.6497479120296296, 1, 0.10034904488205142`], 
          Hue[0.6497493086481195, 1, 0.1003471111026037], 
          Hue[0.6492912885439144, 1, 0.10098129278534936`], 
          Hue[0.0035544051781553065`, 1, 0.9950785159071696], 
          Hue[0.010894007250408011`, 1, 0.9849159899609735], 
          Hue[0.6495093110277149, 1, 0.10067941550008708`], 
          Hue[0.6495777784024127, 1, 0.1005846145197363], 
          Hue[0.6488046287281491, 1, 0.10165512945333201`], 
          Hue[0.0188815068198126, 1, 0.9738563751725671], 
          Hue[0.0006279566818909732, 1, 0.9991305215173818], 
          Hue[0.6491676171198596, 1, 0.10115253014173296`], 
          Hue[0.6497111920892122, 1, 0.10039988787647545`], 
          Hue[0.0004495461399424139, 1, 0.9993775514985412], 
          Hue[0.009914984936253313, 1, 0.9862715593190339], 
          Hue[0.004114268310746683, 1, 0.9943033208005047], 
          Hue[0.6498106617708848, 1, 0.10026216062492885`], 
          Hue[0.6499472781505811, 1, 0.1000729994838108], 
          Hue[0.6494008470929418, 1, 0.10082959633284996`], 
          Hue[0.6483115902011757, 1, 0.10233779818298751`], 
          Hue[0.6458782876770499, 1, 0.10570698629331549`], 
          Hue[0.6407607757100968, 1, 0.11279277209371208`], 
          Hue[0.6295803155774846, 1, 0.12827340920040597`], 
          Hue[0.6101285923156383, 1, 0.15520656448603928`], 
          Hue[0.5742046889706088, 1, 0.2049473537330032], 
          Hue[0.5188302296570365, 1, 0.2816196820133341], 
          Hue[0.4461578536446471, 1, 0.3822429718766426], 
          Hue[0.24269327962235782`, 1, 0.6639631512921199], 
          Hue[0.1422272054254795, 1, 0.8030700232570285], 
          Hue[0.05419073918477313, 1, 0.9249666688210834], 
          Hue[0.007338972590791415, 1, 0.9898383456435196], 
          Hue[0.006393110003040325, 1, 0.9911480015342519], 
          Hue[0.05571937986692099, 1, 0.9228500894150325], 
          Hue[0.1372541441290115, 1, 0.8099558004367533], 
          Hue[0.35018335351510504`, 1, 0.5151307412867776], 
          Hue[0.4496569107195147, 1, 0.3773981236191335], 
          Hue[0.5256343489265491, 1, 0.27219859379400885`], 
          Hue[0.576099400109148, 1, 0.20232390754117982`], 
          Hue[0.6110796484191652, 1, 0.15388971757346367`], 
          Hue[0.630173760297467, 1, 0.1274517165111997], 
          Hue[0.6404797318909642, 1, 0.11318190968943431`], 
          Hue[0.6460136929745678, 1, 0.10551950203521387`], 
          Hue[0.6483637511221076, 1, 0.10226557536938952`], 
          Hue[0.6494231545152241, 1, 0.10079870913276658`], 
          Hue[0.6496404373382797, 1, 0.10049785599315118`], 
          Hue[0.6489824582187333, 1, 0.10140890400483074`], 
          Hue[0.6473372202226221, 1, 0.10368692584560026`], 
          Hue[0.6437813116580096, 1, 0.10861049155044838`], 
          Hue[0.6361122647233287, 1, 0.11922917192154484`], 
          Hue[0.6212333189693434, 1, 0.13983078911937072`], 
          Hue[0.5944304941520718, 1, 0.17694239271251588`], 
          Hue[0.5492267161181235, 1, 0.2395322392210598], 
          Hue[0.19138515419200874`, 1, 0.7350051711187572], 
          Hue[0.0941921558085057, 1, 0.8695800919574537], 
          Hue[0.025691124446994063`, 1, 0.9644276738426236], 
          Hue[0.00002352190768362128, 1, 0.9999674312047457], 
          Hue[0.025378983840851466`, 1, 0.9648598685280517], 
          Hue[0.4023142295964459, 1, 0.4429495282510749], 
          Hue[0.49061881730950774`, 1, 0.3206816375714508], 
          Hue[0.5532091028278686, 1, 0.23401816531525887`], 
          Hue[0.5958568015038151, 1, 0.17496750561010216`], 
          Hue[0.6219749647112339, 1, 0.1388038950152146], 
          Hue[0.6361271239328453, 1, 0.11920859763144505`], 
          Hue[0.6437828205982312, 1, 0.10860840224860291`], 
          Hue[0.6474198941222414, 1, 0.10357245429228114`], 
          Hue[0.649019050502882, 1, 0.10135823776524042`], 
          Hue[0.6496584573287741, 1, 0.10047290523708198`], 
          Hue[0.6497231509861959, 1, 0.1003833294037288], 
          Hue[0.6492171524702315, 1, 0.10108394273352567`], 
          Hue[0.6478749243426648, 1, 0.10294241244861796`], 
          Hue[0.6449251744727204, 1, 0.10702668149931029`], 
          Hue[0.6386439596714024, 1, 0.11572374814728895`], 
          Hue[0.6257137709194589, 1, 0.13362708641921076`], 
          Hue[0.6028104719305954, 1, 0.16533934655763707`], 
          Hue[0.03879115345498241, 1, 0.9462891721392552], 
          Hue[0.00204652452762899, 1, 0.9971663506540522], 
          Hue[0.014363708186627133`, 1, 0.9801117886646701], 
          Hue[0.5865848946423438, 1, 0.18780553049521637`], 
          Hue[0.6169038098323398, 1, 0.14582549407829865`], 
          Hue[0.6333775363363702, 1, 0.12301571891887214`], 
          Hue[0.642287160157943, 1, 0.11067931670438669`], 
          Hue[0.646786185262447, 1, 0.10444989732891957`], 
          Hue[0.6487297801613743, 1, 0.10175876593040492`], 
          Hue[0.6495549988329647, 1, 0.1006161554620489], 
          Hue[0.6495354160787383, 1, 0.10064327004482393`], 
          Hue[0.6486843531732213, 1, 0.10182166483707836`], 
          Hue[0.6466781532044529, 1, 0.10459948017844993`], 
          Hue[0.6424099697197947, 1, 0.11050927269566892`], 
          Hue[0.015183211454569023`, 1, 0.9789770918321352], 
          Hue[0.0014842239231870336`, 1, 0.997944920721741], 
          Hue[0.03927481818696199, 1, 0.9456194825103603], 
          Hue[0.6450136112163736, 1, 0.10690423062348285`], 
          Hue[0.6479385832492244, 1, 0.10285426934722787`], 
          Hue[0.6492463764208792, 1, 0.10104347880185952`], 
          Hue[0.6497391633466383, 1, 0.10036115844311631`], 
          Hue[0.6497574978063524, 1, 0.10033577226812748`], 
          Hue[0.6493145981195542, 1, 0.10094901798830959`], 
          Hue[0.004161598864771188, 1, 0.9942377861872398], 
          Hue[0.009893329634630965, 1, 0.9863015435828187], 
          Hue[0.6494931154227351, 1, 0.10070184018390524`], 
          Hue[0.6495910709039227, 1, 0.10056620951764557`], 
          Hue[0.6488422719152992, 1, 0.10160300811727811`], 
          Hue[0.020179929261305962`, 1, 0.9720585594843455], 
          Hue[0.0004447580458434297, 1, 0.9993841811672938], 
          Hue[0.6491396023196859, 1, 0.10119131986505031`], 
          Hue[0.6497012810259416, 1, 0.10041361088715776`], 
          Hue[0.0006076257760387893, 1, 0.9991586720024079], 
          Hue[0.010863335672152807`, 1, 0.9849584583000961], 
          Hue[0.0035406151092213234`, 1, 0.9950976098487704], 
          Hue[0.6497731787114491, 1, 0.10031406024568582`], 
          Hue[0.6497741306336647, 1, 0.10031274219954121`], 
          Hue[0.005682493436892422, 1, 0.9921319321643027], 
          Hue[0.008102085038400042, 1, 0.9887817284083692], 
          Hue[0.00008835356944913997, 1, 0.999877664288455], 
          Hue[0.0011370027215367173`, 1, 0.9984256885394106], 
          Hue[0.0024899471578471166`, 1, 0.9965523808583655], 
          Hue[0.6497563802890647, 1, 0.10033731959975656`], 
          Hue[0.0030330834221558023`, 1, 0.9958003460308612], 
          Hue[0.0008283863278639725, 1, 0.9988530035460345], 
          Hue[0.00029629239912853933`, 1, 0.9995897489858221], 
          Hue[0.004786482237717937, 1, 0.9933725630554675], 
          Hue[0.6499439892769909, 1, 0.10007755330878182`], 
          Hue[0.6499875158019874, 1, 0.10001728581263288`], 
          Hue[0.6494109304278011, 1, 0.10081563479227552`], 
          Hue[0.6483362686977471, 1, 0.10230362795696565`], 
          Hue[0.645931248801914, 1, 0.10563365550504224`], 
          Hue[0.6408792838612916, 1, 0.11262868388436562`], 
          Hue[0.6298077772069661, 1, 0.1279584623288161], 
          Hue[0.6105515018934207, 1, 0.1546209973783407], 
          Hue[0.5748916012783756, 1, 0.20399624438378777`], 
          Hue[0.5197939163059443, 1, 0.2802853466533079], 
          Hue[0.44754771602512905`, 1, 0.3803185470421291], 
          Hue[0.2443712885139241, 1, 0.6616397543653358], 
          Hue[0.14375751879040655`, 1, 0.8009511278286678], 
          Hue[0.05530462336751485, 1, 0.9234243676449794], 
          Hue[0.007713497974169203, 1, 0.9893197720357657], 
          Hue[0.005955715920358595, 1, 0.9917536241102728], 
          Hue[0.05456903723928208, 1, 0.9244428715148402], 
          Hue[0.13556927841037536`, 1, 0.812288691431788], 
          Hue[0.3484289399052678, 1, 0.517559929361937], 
          Hue[0.4482583382570699, 1, 0.3793346085671341], 
          Hue[0.5247164695108618, 1, 0.2734695037541913], 
          Hue[0.5754123400842259, 1, 0.20327522142184107`], 
          Hue[0.6106975331333079, 1, 0.1544188002769583], 
          Hue[0.6299536732217466, 1, 0.12775645246219708`], 
          Hue[0.6403556352766222, 1, 0.11335373577083081`], 
          Hue[0.6459605173004334, 1, 0.10559312989170767`], 
          Hue[0.6483382729738123, 1, 0.10230085280549063`], 
          Hue[0.6494139342377792, 1, 0.10081147567076743`], 
          Hue[0.64964626944774, 1, 0.1004897807646678], 
          Hue[0.6489987246110026, 1, 0.10138638130784262`], 
          Hue[0.6473739890057328, 1, 0.10363601522283153`], 
          Hue[0.6438580050086173, 1, 0.10850430075729914`], 
          Hue[0.6362832666054539, 1, 0.11899240008475619`], 
          Hue[0.6215365925790378, 1, 0.13941087181364004`], 
          Hue[0.5949915357171516, 1, 0.17616556593009788`], 
          Hue[0.5500704775640917, 1, 0.23836395414202688`], 
          Hue[0.1929450679411877, 1, 0.7328452905429709], 
          Hue[0.09568415918495587, 1, 0.8675142411285226], 
          Hue[0.026467851560574962`, 1, 0.9633522055315116], 
          Hue[0.00010690064698370971`, 1, 0.9998519837195611], 
          Hue[0.024481579918917862`, 1, 0.9661024278045753], 
          Hue[0.40079421020510353`, 1, 0.4450541704852413], 
          Hue[0.48944773808491393`, 1, 0.322303131882427], 
          Hue[0.5524404299590473, 1, 0.2350824815951653], 
          Hue[0.595301409533224, 1, 0.1757365098770745], 
          Hue[0.6216803663083569, 1, 0.13921180049612134`], 
          Hue[0.6359673055967633, 1, 0.11942988455832777`], 
          Hue[0.6436963283321748, 1, 0.10872816077083482`], 
          Hue[0.6473842661202932, 1, 0.10362178537190173`], 
          Hue[0.6490027440471332, 1, 0.10138081593473859`], 
          Hue[0.6496526464644884, 1, 0.10048095104916999`], 
          Hue[0.6497276309973763, 1, 0.10037712631132514`], 
          Hue[0.649229877081093, 1, 0.10106632404156347`], 
          Hue[0.6479048076830476, 1, 0.10290103551578034`], 
          Hue[0.6449910258134631, 1, 0.10693550271982026`], 
          Hue[0.6387856578107423, 1, 0.11552755072358767`], 
          Hue[0.6259681080796479, 1, 0.1332749272743338], 
          Hue[0.6032891125775806, 1, 0.16467661335411932`], 
          Hue[0.039634198867282255`, 1, 0.9451218784914552], 
          Hue[0.0021664897704308794`, 1, 0.9970002449332495], 
          Hue[0.013680023596948754`, 1, 0.9810584288657632], 
          Hue[0.585958156906592, 1, 0.18867332120625724`], 
          Hue[0.6165567578884068, 1, 0.14630602753912902`], 
          Hue[0.6331928416082957, 1, 0.12327145008082141`], 
          Hue[0.6421827303387263, 1, 0.11082391183868667`], 
          Hue[0.6467418636819257, 1, 0.10451126567117984`], 
          Hue[0.6487092404340385, 1, 0.10178720555286977`], 
          Hue[0.6495476842490884, 1, 0.10062628334741618`], 
          Hue[0.6495426662960367, 1, 0.10063323128241067`], 
          Hue[0.6487052923493286, 1, 0.10179267213169886`], 
          Hue[0.6467238623098338, 1, 0.10453619064792248`], 
          Hue[0.6425039393981814, 1, 0.11037916083328733`], 
          Hue[0.0157536541123644, 1, 0.9781872481521109], 
          Hue[0.001409113389190697, 1, 0.9980489199226591], 
          Hue[0.03820462581271267, 1, 0.947101287336244], 
          Hue[0.6449432621701837, 1, 0.10700163699513031`], 
          Hue[0.6479088271652306, 1, 0.10289547007891149`], 
          Hue[0.6492338001939328, 1, 0.10106089203917001`], 
          Hue[0.6497346725736763, 1, 0.10036737643644822`], 
          Hue[0.6497614812439392, 1, 0.10033025673916116`], 
          Hue[0.6493260168430828, 1, 0.10093320744803931`], 
          Hue[0.0046245753686967594`, 1, 0.993596741797189], 
          Hue[0.009475088710300783, 1, 0.986880646401122], 
          Hue[0.6494847433371672, 1, 0.1007134323023839], 
          Hue[0.6495975269758446, 1, 0.1005572703411383], 
          Hue[0.6488606903732348, 1, 0.10157750563705954`], 
          Hue[0.020714890159022392`, 1, 0.9713178443951997], 
          Hue[0.0002350962778671084, 1, 0.9996744820767993], 
          Hue[0.6491253641122945, 1, 0.10121103430605378`], 
          Hue[0.6496962623919074, 1, 0.10042055976505135`], 
          Hue[0.0007705856393003252, 1, 0.9989330352686611], 
          Hue[0.011489507332325122`, 1, 0.9840914513860114], 
          Hue[0.0032035989159662215`, 1, 0.9955642476548161], 
          Hue[0.6497685888346124, 1, 0.10032041545976744`], 
          Hue[0.6497847037639711, 1, 0.10029810248065545`], 
          Hue[0.005994487399738291, 1, 0.9916999405234393], 
          Hue[0.007544693262716229, 1, 0.989553501636239], 
          Hue[0.00013910380359172247`, 1, 0.9998073947334883], 
          Hue[0.0014196886095609873`, 1, 0.9980342773098387], 
          Hue[0.00214763736679513, 1, 0.9970263482613606], 
          Hue[0.6497521313849934, 1, 0.10034320269770144`], 
          Hue[0.003301374897856535, 1, 0.9954288655260448], 
          Hue[0.0007017874763388665, 1, 0.9990282942635309], 
          Hue[0.00024090698097967156`, 1, 0.9996664364878742], 
          Hue[0.0045675841076652235`, 1, 0.9936756527740019], 
          Hue[0.6498720413752287, 1, 0.10017717348045255`], 
          Hue[0.649878138339922, 1, 0.1001687315293388], 
          Hue[0.00012448392649988538`, 1, 0.9998276376402309], 
          Hue[0.0017574413987969661`, 1, 0.9975666196016658], 
          Hue[0.0017624755242880985`, 1, 0.9975596492740627], 
          Hue[0.0039631469495643445`, 1, 0.9945125657621418], 
          Hue[0.00041500109620495884`, 1, 0.9994253830975623], 
          Hue[0.00046613820630114766`, 1, 0.9993545778681984], 
          Hue[0.003871407817266803, 1, 0.9946395891760922], 
          Hue[0.6497824267040314, 1, 0.10030125533287967`], 
          Hue[0.6497693896639003, 1, 0.10031930661921502`], 
          Hue[0.0001591217855548832, 1, 0.9997796775276931], 
          Hue[0.001098320209868997, 1, 0.9984792489401814], 
          Hue[0.0010507789699376602`, 1, 0.998545075272394], 
          Hue[0.000127593766992673, 1, 0.9998233317072409], 
          Hue[0.6499868515278004, 1, 0.10001820557689171`]}],
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{None, None},
       AxesOrigin->{0., 0.},
       DisplayFunction->((Print[#]; #)& ),
       FormatType->OutputForm,
       Method->{},
       PlotLabel->"Surface Intensity",
       PlotRange->All,
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}]}], ",", 
     RowBox[{"ComponentNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.02434017156009105`"}], ",", 
     RowBox[{"RayBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "12.449997752986043`"}], ",", "12.449997752986043`"}], 
       "}"}]}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "1024"}], ",", 
     RowBox[{"Full3D", "\[Rule]", "False"}], ",", 
     RowBox[{"Energy", "\[Rule]", "99.99999999999996`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "IntensityFunction", 
      "\[Rule]", "\<\"CompiledFunction[-intensity data-]\"\>"}], ",", 
     RowBox[{"OutputGraphics", "\[Rule]", 
      GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJw1l3c41W/cx82iFElI2ZU9MzPujy0Zx5bsmZURQhnZJPM4KB3HnumcYyT1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        "], {{}, {}, 
         {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1ne8UGMcx/GbSmkopb33TkNpqhRJQ4uSBre9995Di6amkKJFixSiZUV7
ICoiDaNFtMP79/LHp+/n+/xe977uOed5zilfYu+mvZIkJCQsuiMhIXKbf3Kg
vf6mXka+oE+QHfVk8hl9oLyoN5Ar9emyiv4bfwTd9a/1B+VL+kyekw/hKZBH
Pyor4jM+BunNe+g3+RO4ypvhJK9ttpi/wgvzcXysvEe2lZulSNguc6KD8pZe
Vk7TO/Hk/Fl+iTfkq3hV/rusi2/4LOTFMf0BfM7H4kkkjevHDuu5sJp3RjXk
i9+Pj63nxhreBdWRH3fik7hurOVd496gAFLgU+t5sY53Qw0UREp8Zj0f1vPu
qIlCuAufW8+Pt3kP1Ir7g+PWKmEnH4cWSIWd1grgHd4TD6EIvrdWGV/w8WiJ
a3pz/MxfRWp8oRfEBl7OPZzOe8X18UQ+SP6hN4r9o8+QtfVz/FH00I/E9clF
+hQ5W88lh+ojZUr5lNwo58mi5j/wKvEc9S/1SnKO/pycoN8je+pD5C29uVyv
z5JP6df5E+ijn9LryNf0xXH9fDzPgHb8Q5nG+peyEN7lveM5mbXX/+SPx/7i
dfh5WQ89rX0bz0e+rE+VL+q55TB9lLxLtpKb5HxZzPxE7EN01nfpleXcuDae
gccBvc1b4QZ/Eqf5w2ZL+Gu8aNwHnhHP8I9kWuu7ZGFs5OWtz4h7EPuKd+CX
4/fgAn8M3/E5yGM+XE+F4vqPshp284nIaN5b/4c/jZu8Bc7wJbgbu/Ui2MT7
xn6Nd4j+F38EF3l9HOVzUQI/6dWxh0/CvX6mj/4vb41bvCXO8qUoZv6cfi/S
6XtkUbzH7zebyfvF3ued+N+8MV8dZ55fkg1iD1s7FudHvqI/L+fFu0CO0EfL
1PJp+Z5cIEuan+QPoou+V68SP6dPlJP1TLKvPjReTrEH5dtytmxj6XbsdfTV
f4n7Ipfqr/PifCLPhPT6XlkM7/P+cR7NO+tX+KP4gzfEcT4/3knmI2Mvo5T+
s6yBfXwKMpv305Ogrf5P7E38yt+IM4V98fzxAR+ANH6mi36V18OfvBG+5wvi
XWc+KvYeSuunZE3s51ORxby/fkecNf3fuKf4jdc1e50vi73AJ/HMcS71/bIE
NvMKZrP4QJ6Wd+XXeBO+JvYxvywfxw98IQqYjdbvRmv+vrzP+mlZC12tHdCr
yvn6JPm8nlUO0IfJpHH25DvyxfgOmsdHp3XsMfl7PAf5hr6cl4w9wLPEudQP
yJL4kFeM9x4fFGeFd+OD5XW9qVyrz5T19b94Y/TWT8Q7W76qvxDfVr2gHKOP
kelkG/mBXCjLmJ/hD6GbflCvJhfok+PbrmeTA/XhMlmcY7lBzonvZWzb2Kt6
f3kunrtcpq/gpfgUnjXOoH4w9ho+4oPRAGVx1lptHOLTkBhnA4din2ALH4KG
KBd7E4fjGWErH4pG8Q6LPYSvrJfBNj4s3sdx3uN54WvrZbGdD4/zHnsmrhPf
WC+HHXxE7Jl4FsiOI9bL42M+Mp4DHkAO5MS3ZvfjEz4KzfC33gQ/8kWohF/0
OjjMp8fvdo8G6cnRPraM3paf54/x5XwlL82n8nEym3xWbpEvyVzm3/EK6Kh/
Gn9bfF/i3cTT8e78RvxdfB1vzq/IpviJv4xCZmPjfYLK+q/yYXzFq5st5DPi
mvlgPkLeKVvKd+Xc+G6YJ5Xt9AHygl5frtCnyVX6fXF+9PEyu0yUW5P8///M
3Ob/AduQMtI=
           "],
           VertexColors->Automatic]}},
        VertexColors->{
          Hue[0.65, 1, 0.1], 
          Hue[0.647841944435557, 1, 0.10298807693538273`], 
          Hue[0.6474201627834378, 1, 0.1035720822998553], 
          Hue[0.6470698640892572, 1, 0.10405711126102864`], 
          Hue[0.6466653256913921, 1, 0.10461724135038022`], 
          Hue[0.6461412415484118, 1, 0.10534289631758371`], 
          Hue[0.6455511626054383, 1, 0.10615992870016233`], 
          Hue[0.6447695780113137, 1, 0.1072421227535656], 
          Hue[0.64381311158964, 1, 0.108566460875883], 
          Hue[0.64269412464696, 1, 0.11011582741190167`], 
          Hue[0.6411380654883876, 1, 0.11227037086223263`], 
          Hue[0.38025688304412886`, 1, 0.4734904696312062], 
          Hue[0.2352485085445823, 1, 0.6742712958613476], 
          Hue[0.35337841233293976`, 1, 0.5107068136928526], 
          Hue[0.37838992105894487`, 1, 0.4760754939183841], 
          Hue[0.3794650235845607, 1, 0.4745868904213776], 
          Hue[0.3551132502872627, 1, 0.5083047303714824], 
          Hue[0.2638673660130045, 1, 0.6346451855204553], 
          Hue[0.34094921839636816`, 1, 0.527916466835798], 
          Hue[0.641080372255058, 1, 0.11235025380068897`], 
          Hue[0.6426627931012374, 1, 0.11015920955213278`], 
          Hue[0.6438616704840883, 1, 0.10849922548357019`], 
          Hue[0.6447525439465047, 1, 0.10726570838176268`], 
          Hue[0.6455336703896868, 1, 0.10618414869120293`], 
          Hue[0.6461302049908273, 1, 0.10535817770500845`], 
          Hue[0.6466180584628825, 1, 0.10468268828216282`], 
          Hue[0.6470612928697839, 1, 0.10406897910337623`], 
          Hue[0.6474100876912793, 1, 0.10358603242745948`], 
          Hue[0.6478120216762575, 1, 0.10302950844825881`], 
          Hue[0.65, 1, 0.1], 
          Hue[0.6492510749991883, 1, 0.10103697307804693`], 
          Hue[0.6475861172572024, 1, 0.10334229918233523`], 
          Hue[0.6468759741642778, 1, 0.10432557423407691`], 
          Hue[0.6464156602295401, 1, 0.1049629319898676], 
          Hue[0.6458599403347861, 1, 0.10573239030568078`], 
          Hue[0.6451813230420759, 1, 0.1066720142494335], 
          Hue[0.644318332575237, 1, 0.10786692412659503`], 
          Hue[0.6432853600533706, 1, 0.10929719377225616`], 
          Hue[0.6419687969695976, 1, 0.1111201272728649], 
          Hue[0.6363871657773628, 1, 0.11884853969288234`], 
          Hue[0.01207041855174018, 1, 0.9832871127745135], 
          Hue[0.3195379250004577, 1, 0.5575628730762894], 
          Hue[0.3697889226588154, 1, 0.4879845686262556], 
          Hue[0.38165101567767706`, 1, 0.47156013213860104`], 
          Hue[0.3714417301277565, 1, 0.4856960659769526], 
          Hue[0.32632909032755975`, 1, 0.5481597210849173], 
          Hue[0.043122720581715845`, 1, 0.9402916176560857], 
          Hue[0.6344939611974703, 1, 0.12146989988042585`], 
          Hue[0.6419263159558217, 1, 0.11117894713809298`], 
          Hue[0.6432987158113112, 1, 0.10927870118433843`], 
          Hue[0.6443305762621209, 1, 0.10784997132937121`], 
          Hue[0.645163967019711, 1, 0.10669604566501562`], 
          Hue[0.6458459340822901, 1, 0.10575178357836766`], 
          Hue[0.6463847751291885, 1, 0.10500569597496986`], 
          Hue[0.6468496535577393, 1, 0.10436201815082259`], 
          Hue[0.6475773368614992, 1, 0.10335445665330875`], 
          Hue[0.6492032299672812, 1, 0.10110322004530294`], 
          Hue[0.6498467376282827, 1, 0.10021220943776243`], 
          Hue[0.6476698163255933, 1, 0.10322640816456323`], 
          Hue[0.6469749049334255, 1, 0.10418859316910324`], 
          Hue[0.6465434026476174, 1, 0.10478605787252974`], 
          Hue[0.6460038217769912, 1, 0.10553316984724291`], 
          Hue[0.6453711210439219, 1, 0.10640921701610817`], 
          Hue[0.6445502100420205, 1, 0.10754586301874092`], 
          Hue[0.6435565831922334, 1, 0.10892165404152306`], 
          Hue[0.6423433340601732, 1, 0.11060153745514488`], 
          Hue[0.6405977666002967, 1, 0.11301847701497397`], 
          Hue[0.07893217658252427, 1, 0.8907092939626587], 
          Hue[0.289110719483175, 1, 0.5996928499463731], 
          Hue[0.3628157930429748, 1, 0.49763967117126573`], 
          Hue[0.3807207781641537, 1, 0.4728481533111719], 
          Hue[0.3762780143495482, 1, 0.47899967243908714`], 
          Hue[0.3430265989598573, 1, 0.52504009374789], 
          Hue[0.183056004115081, 1, 0.7465378404560418], 
          Hue[0.5743881902269216, 1, 0.20469327507041635`], 
          Hue[0.6415191983780358, 1, 0.11174264839964267`], 
          Hue[0.6429906383958948, 1, 0.10970526991337654`], 
          Hue[0.6441024090943088, 1, 0.10816589510018787`], 
          Hue[0.6449638435688024, 1, 0.10697313967396593`], 
          Hue[0.6456935187781464, 1, 0.10596282015333577`], 
          Hue[0.646260303236936, 1, 0.10517804167193492`], 
          Hue[0.6467364965443202, 1, 0.1045186970924797], 
          Hue[0.6474954391993177, 1, 0.10346785341632928`], 
          Hue[0.6483028914100524, 1, 0.10234984266300445`], 
          Hue[0.6483664762749782, 1, 0.10226180208079946`], 
          Hue[0.6475048232627859, 1, 0.10345486009768101`], 
          Hue[0.642998295658093, 1, 0.10969466755033291`], 
          Hue[0.6415682862188112, 1, 0.11167468062010752`], 
          Hue[0.5893374359847668, 1, 0.18399431940570754`], 
          Hue[0.1363481587220977, 1, 0.8112102417694032], 
          Hue[0.33945778962439377`, 1, 0.5299815220585318], 
          Hue[0.37486241892537, 1, 0.4809597276417955], 
          Hue[0.3812412721236268, 1, 0.472127469367286], 
          Hue[0.36458819992860125`, 1, 0.4951855693296291], 
          Hue[0.3022055273510652, 1, 0.5815615775139097], 
          Hue[0.03730323269888414, 1, 0.9483493701092373], 
          Hue[0.6404606090742285, 1, 0.11320838743568365`], 
          Hue[0.6423067429473579, 1, 0.11065220207288902`], 
          Hue[0.6476598567080419, 1, 0.1032401984042497], 
          Hue[0.6498374284337827, 1, 0.10022509909168564`], 
          Hue[0.6499581728339957, 1, 0.10005791453754442`], 
          Hue[0.6477300434339123, 1, 0.10314301678381378`], 
          Hue[0.6470228681205462, 1, 0.1041221826023206], 
          Hue[0.6466050700784813, 1, 0.10470067219902593`], 
          Hue[0.6460733156080187, 1, 0.10543694761966639`], 
          Hue[0.6454623197851636, 1, 0.10628294183592744`], 
          Hue[0.6446614011489763, 1, 0.1073919061014175], 
          Hue[0.6436866167751415, 1, 0.10874160754211187`], 
          Hue[0.6425215683170452, 1, 0.11035475156101436`], 
          Hue[0.6409151691529743, 1, 0.1125789965574202], 
          Hue[0.21990148847099106`, 1, 0.6955210159632431], 
          Hue[0.26665762677698296`, 1, 0.6307817475395621], 
          Hue[0.3584520666538548, 1, 0.5036817538638934], 
          Hue[0.37973780285679853`, 1, 0.4742091960444328], 
          Hue[0.3780611750645979, 1, 0.47653068067978754`], 
          Hue[0.3495359307856646, 1, 0.5160271727583106], 
          Hue[0.23105775466403222`, 1, 0.6800738781574939], 
          Hue[0.4834112057939145, 1, 0.3306614073622723], 
          Hue[0.6413046846317061, 1, 0.11203966743302235`], 
          Hue[0.6428292912886842, 1, 0.10992867360028355`], 
          Hue[0.6439836677132607, 1, 0.10833030624317759`], 
          Hue[0.6448596412801813, 1, 0.10711741976590297`], 
          Hue[0.6456145526687179, 1, 0.10607215784331375`], 
          Hue[0.64619597750554, 1, 0.10526710806925224`], 
          Hue[0.6466779570273902, 1, 0.10459975180822897`], 
          Hue[0.647453215021432, 1, 0.10352631766263258`], 
          Hue[0.6479921727887358, 1, 0.10278006844636586`], 
          Hue[0.6487994751990962, 1, 0.10166226510894383`], 
          Hue[0.6475458476797549, 1, 0.10339805705880104`], 
          Hue[0.6431438842642752, 1, 0.10949308332638825`], 
          Hue[0.641771937809, 1, 0.11139270149523076`], 
          Hue[0.6242842059450261, 1, 0.13560648407611778`], 
          Hue[0.06822948605536505, 1, 0.9055284039233407], 
          Hue[0.33044189608077557`, 1, 0.54246506696508], 
          Hue[0.3725372292595075, 1, 0.4841792210252974], 
          Hue[0.3816132743967913, 1, 0.47161238929675053`], 
          Hue[0.3682978863682762, 1, 0.4900490804131561], 
          Hue[0.31546832417427345`, 1, 0.5631977049894675], 
          Hue[0.0005580575393121512, 1, 0.9992273049455678], 
          Hue[0.6392479699506525, 1, 0.11488742622217347`], 
          Hue[0.6421197147725407, 1, 0.11091116416109749`], 
          Hue[0.6476175259538101, 1, 0.10329881021780146`], 
          Hue[0.6495914694859791, 1, 0.10056565763479819`], 
          Hue[0.6496170873491579, 1, 0.10053018674731985`], 
          Hue[0.6476262842734921, 1, 0.10328668331362627`], 
          Hue[0.6397392139335129, 1, 0.11420724224590525`], 
          Hue[0.006087728884321408, 1, 0.9915708369294011], 
          Hue[0.3061092406819378, 1, 0.5761564359788555], 
          Hue[0.36656886671409894`, 1, 0.49244310762663235`], 
          Hue[0.38135509296799963`, 1, 0.4719698712750775], 
          Hue[0.3740847936421225, 1, 0.4820364395724458], 
          Hue[0.33538339805936535`, 1, 0.5356229873024172], 
          Hue[0.11656122458585594`, 1, 0.8386075351888149], 
          Hue[0.61824520832143, 1, 0.14396817309340457`], 
          Hue[0.6475367884161247, 1, 0.10341060065459654`], 
          Hue[0.6487353633784194, 1, 0.10175103532218857`], 
          Hue[0.6480404278048842, 1, 0.10271325380862188`], 
          Hue[0.6413574544540437, 1, 0.11196660152517039`], 
          Hue[0.5115157716663759, 1, 0.29174739307732583`], 
          Hue[0.19365906650280168`, 1, 0.7318566771499669], 
          Hue[0.3470057505879175, 1, 0.5195304991859605], 
          Hue[0.37680312833763036`, 1, 0.4782725915325119], 
          Hue[0.3805290456538039, 1, 0.4731136290947331], 
          Hue[0.3602292659378309, 1, 0.5012210163937726], 
          Hue[0.28557233803441784`, 1, 0.60459214733696], 
          Hue[0.16640775217120796`, 1, 0.7695892662244813], 
          Hue[0.6408464601647084, 1, 0.1126741320796346], 
          Hue[0.647714737234125, 1, 0.10316420998351937`], 
          Hue[0.6499562360426159, 1, 0.10006059624868577`], 
          Hue[0.6499848223087802, 1, 0.100021015264766], 
          Hue[0.6477762716147145, 1, 0.10307900853347221`], 
          Hue[0.6470464854289739, 1, 0.10408948171372846`], 
          Hue[0.6466353717342468, 1, 0.10465871606027378`], 
          Hue[0.6461074716385428, 1, 0.10538965465432543`], 
          Hue[0.6455070305961457, 1, 0.10622103455918297`], 
          Hue[0.6447158595798154, 1, 0.10731650212025569`], 
          Hue[0.6437502984547747, 1, 0.10865343290877351`], 
          Hue[0.6426085408584401, 1, 0.11023432804215993`], 
          Hue[0.6410305947019551, 1, 0.11241917656652367`], 
          Hue[0.30128497309574775`, 1, 0.5828361910981955], 
          Hue[0.25237717729913084`, 1, 0.6505546775858189], 
          Hue[0.3560112216401759, 1, 0.507061385421295], 
          Hue[0.37911074166822273`, 1, 0.47507743461323004`], 
          Hue[0.3788088982669653, 1, 0.4754953716303557], 
          Hue[0.35243067051884114`, 1, 0.5120190715892969], 
          Hue[0.24897780447029128`, 1, 0.6552615015026736], 
          Hue[0.41763361437427604`, 1, 0.4217380724048486], 
          Hue[0.6411941698355383, 1, 0.11219268792002388`], 
          Hue[0.6427466996030242, 1, 0.11004303131888954`], 
          Hue[0.6439230835949402, 1, 0.10841419194546749`], 
          Hue[0.6448064608889793, 1, 0.10719105415372107`], 
          Hue[0.6455743549772814, 1, 0.10612781618530273`], 
          Hue[0.6461632747843697, 1, 0.10531238876010351`], 
          Hue[0.6466481801903821, 1, 0.10464098127485566`], 
          Hue[0.6474317658398112, 1, 0.10355601652949213`], 
          Hue[0.6478879229520123, 1, 0.10292441437413687`], 
          Hue[0.6490300317457053, 1, 0.10134303296748501`], 
          Hue[0.6475660608170084, 1, 0.10337006963798845`], 
          Hue[0.6432151264420423, 1, 0.1093944403110185], 
          Hue[0.6418711969447461, 1, 0.111255265768813], 
          Hue[0.6320986402943807, 1, 0.12478649805393455`], 
          Hue[0.03644216332371397, 1, 0.9495416200133191], 
          Hue[0.32525911465802454`, 1, 0.5496412258581199], 
          Hue[0.371218744117217, 1, 0.4860048158376996], 
          Hue[0.3816737668408649, 1, 0.4715286305280333], 
          Hue[0.36993609973875996`, 1, 0.48778078497710164`], 
          Hue[0.3211556561396788, 1, 0.5553229376527524], 
          Hue[0.014736696131138483`, 1, 0.9795953438184236], 
          Hue[0.637640299085083, 1, 0.11711343203603891`], 
          Hue[0.6420238296870006, 1, 0.11104392812569162`], 
          Hue[0.6475974073525281, 1, 0.1033266667426534], 
          Hue[0.6494131672613718, 1, 0.10081253763810064`], 
          Hue[0.6497491308871379, 1, 0.10034735723319362`], 
          Hue[0.6476471566488412, 1, 0.10325778310160456`], 
          Hue[0.640299717393958, 1, 0.1134311605314429], 
          Hue[0.03219673023613534, 1, 0.9554199119807356], 
          Hue[0.2981467937855202, 1, 0.5871813624508182], 
          Hue[0.36476337445165513`, 1, 0.494943019990016], 
          Hue[0.38108074273194, 1, 0.47234974083269854`], 
          Hue[0.3752349161569031, 1, 0.4804439622442881], 
          Hue[0.33936191163223156`, 1, 0.5301142762015255], 
          Hue[0.15194020570130495`, 1, 0.789621253644347], 
          Hue[0.601059315454513, 1, 0.1677640247552898], 
          Hue[0.6475162208019584, 1, 0.10343907888959622`], 
          Hue[0.6485076831784036, 1, 0.10206628482990278`], 
          Hue[0.6481870464620803, 1, 0.10251024336019664`], 
          Hue[0.6414638132380861, 1, 0.11181933551649628`], 
          Hue[0.5569486598638416, 1, 0.228840317111604], 
          Hue[0.16698257867568234`, 1, 0.7687933526029014], 
          Hue[0.34339465700424576`, 1, 0.5245304749171982], 
          Hue[0.37587875312508096`, 1, 0.4795524956729649], 
          Hue[0.3809282756398977, 1, 0.4725608491139879], 
          Hue[0.36249596698367426`, 1, 0.4980825072533742], 
          Hue[0.2943933925299845, 1, 0.5923783795738677], 
          Hue[0.09199027503470403, 1, 0.8726288499519482], 
          Hue[0.6406918559699197, 1, 0.11288819942626498`], 
          Hue[0.6476844723331723, 1, 0.10320611523099228`], 
          Hue[0.6499096685020481, 1, 0.1001250743817796], 
          Hue[0.64991432666725, 1, 0.100118624614577], 
          Hue[0.6476962973797613, 1, 0.10318974208956128`], 
          Hue[0.6407804470098292, 1, 0.11276553490946727`], 
          Hue[0.14337969314864707`, 1, 0.8014742710249503], 
          Hue[0.27873621061488574`, 1, 0.6140575545332351], 
          Hue[0.3607158823315621, 1, 0.5005472398486064], 
          Hue[0.3802737406916196, 1, 0.4734671282731421], 
          Hue[0.3772187384325073, 1, 0.4776971314011438], 
          Hue[0.346408965563676, 1, 0.5203568169118332], 
          Hue[0.20932289898514306`, 1, 0.7101682937128788], 
          Hue[0.5357108964729269, 1, 0.2582464510374859], 
          Hue[0.6481299321039763, 1, 0.10258932477910974`], 
          Hue[0.6485738612202632, 1, 0.10197465369502028`], 
          Hue[0.6108826734819043, 1, 0.15416245210197868`], 
          Hue[0.10271003410979429`, 1, 0.8577861066172079], 
          Hue[0.3351558551538955, 1, 0.5359380467099909], 
          Hue[0.3737500907774236, 1, 0.48249987430818275`], 
          Hue[0.38146930112490524`, 1, 0.4718117369039774], 
          Hue[0.3665184951952671, 1, 0.4925128528065533], 
          Hue[0.3091859477208205, 1, 0.571896380078864], 
          Hue[0.0068029033348432355`, 1, 0.9905805953825247], 
          Hue[0.6400505247767917, 1, 0.11377619646290384`], 
          Hue[0.6476380714113716, 1, 0.10327036266117784`], 
          Hue[0.6497328282004667, 1, 0.10036993018396917`], 
          Hue[0.6494497505526287, 1, 0.10076188385020655`], 
          Hue[0.6386192928472071, 1, 0.1157579022115595], 
          Hue[0.00037381556225446477`, 1, 0.9994824092214938], 
          Hue[0.3131914947868242, 1, 0.5663502379874742], 
          Hue[0.3815449307868381, 1, 0.4717070189105319], 
          Hue[0.3728223855473097, 1, 0.4837843892421866], 
          Hue[0.33105388959987747`, 1, 0.5416176913232466], 
          Hue[0.0789770250237829, 1, 0.8906471961209159], 
          Hue[0.6286157720423665, 1, 0.1296089310182618], 
          Hue[0.6489724241104419, 1, 0.10142279738554204`], 
          Hue[0.6479266323033612, 1, 0.10287081681073063`], 
          Hue[0.4521834851184777, 1, 0.37389978983595396`], 
          Hue[0.21628272099485957`, 1, 0.7005316170840407], 
          Hue[0.37763912883855794`, 1, 0.4771150523773814], 
          Hue[0.3800419637547178, 1, 0.4737880501857754], 
          Hue[0.27550400093547933`, 1, 0.618532921781644], 
          Hue[0.25257581374153454`, 1, 0.6502796425117214], 
          Hue[0.6409697416369212, 1, 0.11250343465657067`], 
          Hue[0.6477551404235918, 1, 0.1031082671057959], 
          Hue[0.6499842576459908, 1, 0.1000217971055513], 
          Hue[0.6499935369873423, 1, 0.10000894878675691`], 
          Hue[0.6478061886512861, 1, 0.10303758494437311`], 
          Hue[0.6470582043976613, 1, 0.10407325544939205`], 
          Hue[0.6466503919073493, 1, 0.10463791889751643`], 
          Hue[0.6461244045038788, 1, 0.10536620914847566`], 
          Hue[0.6455291682902691, 1, 0.10619038236731972`], 
          Hue[0.6447428105981272, 1, 0.10727918532567], 
          Hue[0.6437818127672839, 1, 0.1086097977068378], 
          Hue[0.6426515045494097, 1, 0.11017483985466352`], 
          Hue[0.641084964839814, 1, 0.11234389483718056`], 
          Hue[0.34148827442185814`, 1, 0.527170081569735], 
          Hue[0.24421472356964785`, 1, 0.6618565365958722], 
          Hue[0.35471982420810494`, 1, 0.5088494741733932], 
          Hue[0.3787622329221311, 1, 0.47555998518474163`], 
          Hue[0.3791482332211376, 1, 0.4750255232322711], 
          Hue[0.35379733298612837`, 1, 0.5101267697115146], 
          Hue[0.256755247150171, 1, 0.6444927347151479], 
          Hue[0.3803905001114415, 1, 0.47330546138415797`], 
          Hue[0.6411378000148994, 1, 0.1122707384409086], 
          Hue[0.6427049124699269, 1, 0.11010089042625511`], 
          Hue[0.6438924814896402, 1, 0.10845656409126748`], 
          Hue[0.6447795952954335, 1, 0.1072282526678614], 
          Hue[0.6455540740539325, 1, 0.10615589746378587`], 
          Hue[0.6461467861044199, 1, 0.10533521924003406`], 
          Hue[0.6466331627293468, 1, 0.10466177468244298`], 
          Hue[0.6474209556394511, 1, 0.10357098449922161`], 
          Hue[0.6478468331429933, 1, 0.10298130795585547`], 
          Hue[0.6491426146114839, 1, 0.10118714899948379`], 
          Hue[0.6475761046214532, 1, 0.10335616283183406`], 
          Hue[0.6432503680667216, 1, 0.10934564421530855`], 
          Hue[0.6419202021479861, 1, 0.11118741241048094`], 
          Hue[0.6345781678699118, 1, 0.12135330602627592`], 
          Hue[0.023002390553546692`, 1, 0.9681505361566277], 
          Hue[0.3224707813968581, 1, 0.5535019949889658], 
          Hue[0.3705181322390198, 1, 0.4869748938228957], 
          Hue[0.3816727944373508, 1, 0.471529976932899], 
          Hue[0.37070499075779123`, 1, 0.4867161666430583], 
          Hue[0.32380221420584177`, 1, 0.5516584726380652], 
          Hue[0.02758358059264765, 1, 0.9618073499486417], 
          Hue[0.6363216839227952, 1, 0.11893920687612974`], 
          Hue[0.641975278853964, 1, 0.11111115235604985`], 
          Hue[0.6475873795366663, 1, 0.10334055141076971`], 
          Hue[0.6493115966598032, 1, 0.10095317385565707`], 
          Hue[0.6498020268363591, 1, 0.1002741166881182], 
          Hue[0.64765816350094, 1, 0.10324254284485238`], 
          Hue[0.640469831557593, 1, 0.11319561784333293`], 
          Hue[0.053095414974536737`, 1, 0.9264832715737183], 
          Hue[0.2937775229538639, 1, 0.5932311220638807], 
          Hue[0.36380795476788824`, 1, 0.496265908782924], 
          Hue[0.3809115464846316, 1, 0.4725840125597409], 
          Hue[0.3757695391921508, 1, 0.4797037149647143], 
          Hue[0.34123139565086097`, 1, 0.5275257598680387], 
          Hue[0.1680955405753658, 1, 0.767252328434109], 
          Hue[0.5890782708894421, 1, 0.18435316338384944`], 
          Hue[0.6475058571236003, 1, 0.1034534285980919], 
          Hue[0.6484017404908186, 1, 0.10221297470502046`], 
          Hue[0.6482728432221546, 1, 0.10239144784624746`], 
          Hue[0.6415162746924804, 1, 0.11174669657964248`], 
          Hue[0.5746570670435877, 1, 0.204320984093494], 
          Hue[0.15212512768728487`, 1, 0.7893652078176056], 
          Hue[0.34146924164569514`, 1, 0.5271964346444221], 
          Hue[0.3753823220434434, 1, 0.4802398617860014], 
          Hue[0.381095466081764, 1, 0.4723293546560192], 
          Hue[0.36356307126962834`, 1, 0.4966049782420532], 
          Hue[0.2984132965501234, 1, 0.5868123586229061], 
          Hue[0.06180261033034873, 1, 0.9144271549272094], 
          Hue[0.6405903720591232, 1, 0.11302871561044481`], 
          Hue[0.6476716689942535, 1, 0.10322384293103352`], 
          Hue[0.6498772055976212, 1, 0.10017002301867842`], 
          Hue[0.6499387991595433, 1, 0.10008473962524779`], 
          Hue[0.647711980210203, 1, 0.1031680274012573], 
          Hue[0.6408514256755156, 1, 0.1126672567569785], 
          Hue[0.1805622982289819, 1, 0.7499906639906405], 
          Hue[0.272937615482054, 1, 0.62208637856331], 
          Hue[0.3596052437199455, 1, 0.5020850471569985], 
          Hue[0.3800170143856705, 1, 0.4738225954659948], 
          Hue[0.37765200838209034`, 1, 0.47709721916325953`], 
          Hue[0.3480028449774822, 1, 0.5181499069542554], 
          Hue[0.2207165817220899, 1, 0.6943924253078755], 
          Hue[0.5113056557553535, 1, 0.29203832280027986`], 
          Hue[0.6480566545633474, 1, 0.1026907859892113], 
          Hue[0.6486851606187373, 1, 0.10182054683559458`], 
          Hue[0.6184326981908573, 1, 0.14370857173573598`], 
          Hue[0.08538621640617505, 1, 0.8817729311299114], 
          Hue[0.3328536690480612, 1, 0.5391256890103768], 
          Hue[0.3731565303114125, 1, 0.4833217272611212], 
          Hue[0.381551751017208, 1, 0.4716975755146351], 
          Hue[0.36742641744618565`, 1, 0.49125572968989684`], 
          Hue[0.3124073552416683, 1, 0.5674359696653825], 
          Hue[0.0008108373857433904, 1, 0.9988773020812785], 
          Hue[0.6397181552135163, 1, 0.11423640047359296`], 
          Hue[0.6476277080547851, 1, 0.10328471192414378`], 
          Hue[0.6496668739863564, 1, 0.10046125140350655`], 
          Hue[0.6495377048552845, 1, 0.10064010096960617`], 
          Hue[0.6392762469686378, 1, 0.11484827342803991`], 
          Hue[0.0008130022291620298, 1, 0.9988743046057756], 
          Hue[0.3097504296626705, 1, 0.5711147896978409], 
          Hue[0.38146052116252466`, 1, 0.4718238937749659], 
          Hue[0.3734679810307418, 1, 0.48289048780358834`], 
          Hue[0.3332650988308083, 1, 0.5385560170034962], 
          Hue[0.09784508202434783, 1, 0.8645221941201338], 
          Hue[0.6241253044334616, 1, 0.13582650155366863`], 
          Hue[0.6488536844316216, 1, 0.10158720617160093`], 
          Hue[0.6479795903190804, 1, 0.10279749032742715`], 
          Hue[0.48356404020727456`, 1, 0.3304497904822352], 
          Hue[0.20546034077517616`, 1, 0.7155164512343715], 
          Hue[0.3772319674606537, 1, 0.4776788142852487], 
          Hue[0.3802966019413012, 1, 0.47343547423512145`], 
          Hue[0.28071194207894223`, 1, 0.6113219263522338], 
          Hue[0.2086104453986254, 1, 0.7111547679095956], 
          Hue[0.640910456730638, 1, 0.11258552144988587`], 
          Hue[0.6477333175580109, 1, 0.10313848338121578`], 
          Hue[0.6499721428384544, 1, 0.10003857145444787`], 
          Hue[0.6499732614030632, 1, 0.10003702267268175`], 
          Hue[0.6477511984491767, 1, 0.10311372522421691`], 
          Hue[0.6409743372221424, 1, 0.11249707153857208`], 
          Hue[0.25982958300143405`, 1, 0.6402359619980144], 
          Hue[0.37943581873116927`, 1, 0.47462732791068873`], 
          Hue[0.24044451896167252`, 1, 0.6670768198992227], 
          Hue[0.452108314660046, 1, 0.3740038720091672], 
          Hue[0.6479361232176774, 1, 0.10285767554475454`], 
          Hue[0.6287471974731521, 1, 0.12942695734486637`], 
          Hue[0.05172656740694248, 1, 0.9283785989750027], 
          Hue[0.3816539322653797, 1, 0.4715560937863974], 
          Hue[0.005449067389554529, 1, 0.9924551374606169], 
          Hue[0.6385814771299597, 1, 0.11581026243544047`], 
          Hue[0.6495067405047459, 1, 0.10068297468573646`], 
          Hue[0.6496875691775329, 1, 0.10043259652341596`], 
          Hue[0.640066258520201, 1, 0.1137544112797216], 
          Hue[0.01650549635380627, 1, 0.9771462358178067], 
          Hue[0.38122854276186463`, 1, 0.47214509463741827`], 
          Hue[0.6106672767117577, 1, 0.15446069378372015`], 
          Hue[0.6481095303510259, 1, 0.10261757336011793`], 
          Hue[0.5359581783182419, 1, 0.2579040607901266], 
          Hue[0.18083709800705727`, 1, 0.7496101719902284], 
          Hue[0.3807395314866615, 1, 0.47282218717231483`], 
          Hue[0.29012220565596974`, 1, 0.5982923306301957], 
          Hue[0.12716790401549416`, 1, 0.8239213636708542], 
          Hue[0.640775022239965, 1, 0.11277304612927933`], 
          Hue[0.6476986613684864, 1, 0.10318646887440339`], 
          Hue[0.6499357076566109, 1, 0.10008902016776956`], 
          Hue[0.649883915313537, 1, 0.10016073264279496`], 
          Hue[0.6476824023768215, 1, 0.10320898132440101`], 
          Hue[0.6406980452172157, 1, 0.11287962969923983`], 
          Hue[0.10924101803722908`, 1, 0.8487432057946059], 
          Hue[0.38050824896707036`, 1, 0.4731424245071334], 
          Hue[0.19679031465913066`, 1, 0.7275211027796653], 
          Hue[0.5566826724150964, 1, 0.2292086074252512], 
          Hue[0.6482120907471283, 1, 0.10247556665782248`], 
          Hue[0.6012995667246119, 1, 0.1674313691505373], 
          Hue[0.381365842473292, 1, 0.47195498734467256`], 
          Hue[0.018921921639997286`, 1, 0.973800416190773], 
          Hue[0.640287813042803, 1, 0.11344764347919592`], 
          Hue[0.64978952568855, 1, 0.10029142596970014`], 
          Hue[0.6376903953015312, 1, 0.11704406804403375`], 
          Hue[0.004315051868158615, 1, 0.9940253127979343], 
          Hue[0.381608407723495, 1, 0.4716191277674685], 
          Hue[0.060511758960156925`, 1, 0.9162144875936288], 
          Hue[0.6319923525188912, 1, 0.12493366574307371`], 
          Hue[0.6478809834661905, 1, 0.10293402289296705`], 
          Hue[0.4176121842926089, 1, 0.4217677448256185], 
          Hue[0.22618779618360946`, 1, 0.6868168975919254], 
          Hue[0.6477810586552248, 1, 0.1030723803235349], 
          Hue[0.6499933267595368, 1, 0.10000923987141068`], 
          Hue[0.6499970163196434, 1, 0.10000413124972468`], 
          Hue[0.6478232729120852, 1, 0.10301392981403586`], 
          Hue[0.6470640416290279, 1, 0.1040651731290383], 
          Hue[0.6466578696144224, 1, 0.1046275651492613], 
          Hue[0.646132834959245, 1, 0.1053545362102762], 
          Hue[0.6455401832469215, 1, 0.10617513088887792`], 
          Hue[0.6447562171898352, 1, 0.10726062235253585`], 
          Hue[0.6437974890435859, 1, 0.1085880920934964], 
          Hue[0.6426728572868414, 1, 0.11014527452591193`], 
          Hue[0.6411116464410211, 1, 0.112306951081663], 
          Hue[0.36109810369216205`, 1, 0.500018010272391], 
          Hue[0.23983818902296655`, 1, 0.6679163536605078], 
          Hue[0.35405550444152406`, 1, 0.5097693015425052], 
          Hue[0.37857907864778306`, 1, 0.47581358341076196`], 
          Hue[0.3793094265850243, 1, 0.47480233242073555`], 
          Hue[0.35446149915222736`, 1, 0.5092071550199929], 
          Hue[0.26038915833366566`, 1, 0.6394611653841552], 
          Hue[0.3609027185417658, 1, 0.5002885435575551], 
          Hue[0.6411092418920743, 1, 0.11231028045712799`], 
          Hue[0.6426838945350473, 1, 0.11012999218224234`], 
          Hue[0.643877102234287, 1, 0.10847785844483343`], 
          Hue[0.6447660929059521, 1, 0.10724694828406638`], 
          Hue[0.6455438877090798, 1, 0.10617000163358187`], 
          Hue[0.6461385071356945, 1, 0.10534668242749995`], 
          Hue[0.6466256214869525, 1, 0.10467221640268129`], 
          Hue[0.6474155288456078, 1, 0.10357849852146615`], 
          Hue[0.6478286966510214, 1, 0.10300642002166271`], 
          Hue[0.6491974611155251, 1, 0.10111120768619601`], 
          Hue[0.6475811141041401, 1, 0.1033492266250368], 
          Hue[0.6432678951271881, 1, 0.10932137597773964`], 
          Hue[0.6419445505148927, 1, 0.1111536992870716], 
          Hue[0.6355553599995162, 1, 0.12000027076990066`], 
          Hue[0.017180850359676758`, 1, 0.9762111302712168], 
          Hue[0.3210231017133451, 1, 0.555506474550753], 
          Hue[0.370157152806383, 1, 0.48747471149885435`], 
          Hue[0.38166450566940696`, 1, 0.4715414536885134], 
          Hue[0.371077320445518, 1, 0.48620063322928275`], 
          Hue[0.3250801137537439, 1, 0.5498890732640469], 
          Hue[0.03507041742265482, 1, 0.9514409604917088], 
          Hue[0.6354809404426636, 1, 0.12010331323323514`], 
          Hue[0.6419508491724394, 1, 0.11114497806893013`], 
          Hue[0.647582361161548, 1, 0.10334749993016436`], 
          Hue[0.6492581748008386, 1, 0.10102714258345431`], 
          Hue[0.6498253679747368, 1, 0.1002417981888261], 
          Hue[0.6476638931176063, 1, 0.10323460952946815`], 
          Hue[0.640538032181676, 1, 0.113101186209987], 
          Hue[0.06542122801116801, 1, 0.9094167612153059], 
          Hue[0.291483396206419, 1, 0.5964076052526507], 
          Hue[0.3633165465676629, 1, 0.4969463201370822], 
          Hue[0.3808188686489983, 1, 0.4727123357167716], 
          Hue[0.37602700900499064`, 1, 0.4793472183007822], 
          Hue[0.3421380403109728, 1, 0.5262704057232686], 
          Hue[0.17572860918712135`, 1, 0.7566834642024474], 
          Hue[0.5820919924329802, 1, 0.1940264720158737], 
          Hue[0.6475006549776722, 1, 0.10346063156937706`], 
          Hue[0.6483513611984884, 1, 0.10228273064824689`], 
          Hue[0.6483187206479724, 1, 0.10232792525665373`], 
          Hue[0.6415423363881246, 1, 0.11171061115490444`], 
          Hue[0.5823573762570875, 1, 0.1936590174901865], 
          Hue[0.14434392867359425`, 1, 0.8001391756827156], 
          Hue[0.34047457800758013`, 1, 0.5285736612202737], 
          Hue[0.375125336319523, 1, 0.48059568817296827`], 
          Hue[0.3811710313387338, 1, 0.47222472583867625`], 
          Hue[0.3640807845895362, 1, 0.49588814441448836`], 
          Hue[0.30033652759354046`, 1, 0.5841494233320209], 
          Hue[0.04880841709660222, 1, 0.9324191147893199], 
          Hue[0.6405298150479166, 1, 0.11311256377980783`], 
          Hue[0.6476656598701731, 1, 0.10323216325668338`], 
          Hue[0.6498582845766097, 1, 0.10019622135546362`], 
          Hue[0.6499490714673521, 1, 0.10007051642982008`], 
          Hue[0.6477206726010396, 1, 0.10315599178317603`], 
          Hue[0.640884006924622, 1, 0.11262214425821568`], 
          Hue[0.20002044408219155`, 1, 0.7230486158861963], 
          Hue[0.2698617389416875, 1, 0.6263452845422788], 
          Hue[0.3590340752319815, 1, 0.502875895832641], 
          Hue[0.37988023501053336`, 1, 0.4740119822931077], 
          Hue[0.3778595771913997, 1, 0.4768098161965235], 
          Hue[0.34877680890052953`, 1, 0.5170782645992669], 
          Hue[0.22601275600244347`, 1, 0.6870592609196937], 
          Hue[0.49779299545258127`, 1, 0.31074816014257983`], 
          Hue[0.6480233310665235, 1, 0.10273692621558289`], 
          Hue[0.6487420482172002, 1, 0.10174177939156911`], 
          Hue[0.6215506944298316, 1, 0.1393913461740794], 
          Hue[0.07675851359014008, 1, 0.893718981182883], 
          Hue[0.3316619272473327, 1, 0.5407757930421547], 
          Hue[0.37285013741567197`, 1, 0.48374596357830046`], 
          Hue[0.3815851255651423, 1, 0.47165136460211066`], 
          Hue[0.3678666342549145, 1, 0.49064619872396464`], 
          Hue[0.3139571104664536, 1, 0.5652901547387565], 
          Hue[0., 1, 1.], 
          Hue[0.6395035308232891, 1, 0.11453357270621511`], 
          Hue[0.6476226001250611, 1, 0.10329178444222314`], 
          Hue[0.6496303531394666, 1, 0.10051181872996941`], 
          Hue[0.6495784957322788, 1, 0.10058362129376792`], 
          Hue[0.63952793565504, 1, 0.11449978140071398`], 
          Hue[0.002822855804947122, 1, 0.9960914304239193], 
          Hue[0.3079559846469445, 1, 0.5735994058734615], 
          Hue[0.38141044166442906`, 1, 0.47189323461848287`], 
          Hue[0.37377994069928616`, 1, 0.48245854364714225`], 
          Hue[0.3343355218711832, 1, 0.5370738927937464], 
          Hue[0.10725192499174563`, 1, 0.8514973346268138], 
          Hue[0.6213775393698034, 1, 0.13963109933411832`], 
          Hue[0.6487943468374456, 1, 0.10166936591738293`], 
          Hue[0.6480089950573397, 1, 0.10275677607445276`], 
          Hue[0.4979770385924479, 1, 0.3104933311796875], 
          Hue[0.19968525186784097`, 1, 0.7235127281829894], 
          Hue[0.37702028392416714`, 1, 0.47797191456653787`], 
          Hue[0.38041558315284907`, 1, 0.4732707310191321], 
          Hue[0.2831831412078147, 1, 0.6079002660199488], 
          Hue[0.18721227976361604`, 1, 0.7407829972503778], 
          Hue[0.6408791887697111, 1, 0.11262881554963085`], 
          Hue[0.647723671018987, 1, 0.10315184012755647`], 
          Hue[0.64996471356087, 1, 0.10004885814648774`], 
          Hue[0.6499794382744005, 1, 0.10002847008159933`], 
          Hue[0.6477631894612831, 1, 0.10309712228437731`], 
          Hue[0.6410027547492178, 1, 0.1124577241933909], 
          Hue[0.25618656980891125`, 1, 0.6452801341107383], 
          Hue[0.3792761862101766, 1, 0.4748483575551401], 
          Hue[0.24481161205962187`, 1, 0.6610300756097544], 
          Hue[0.43524619457335245`, 1, 0.39735142289843506`], 
          Hue[0.6479110851962315, 1, 0.10289234357444867`], 
          Hue[0.6305459855748341, 1, 0.1269363276656144], 
          Hue[0.04389410910524871, 1, 0.9392235412388863], 
          Hue[0.38166645070553323`, 1, 0.4715387605615694], 
          Hue[0.009594254825146642, 1, 0.9867156471651817], 
          Hue[0.6381510201407081, 1, 0.11640627980517346`], 
          Hue[0.6494610150703892, 1, 0.10074628682561489`], 
          Hue[0.6497194550590032, 1, 0.10038844684138021`], 
          Hue[0.6401925506713226, 1, 0.11357954522432259`], 
          Hue[0.023691304568577376`, 1, 0.967196655212739], 
          Hue[0.3811573075532821, 1, 0.47224372800314796`], 
          Hue[0.6061384223843497, 1, 0.16073141516013123`], 
          Hue[0.6481472380468648, 1, 0.10256536270434104`], 
          Hue[0.5468766055081582, 1, 0.24278623852716563`], 
          Hue[0.1740381715441902, 1, 0.7590240701695828], 
          Hue[0.3808366080101783, 1, 0.4726877735243685], 
          Hue[0.2922908245553984, 1, 0.5952896275386792], 
          Hue[0.10900854852292985`, 1, 0.8490650866605587], 
          Hue[0.6407352517759252, 1, 0.11282811292564214`], 
          Hue[0.6476913649468607, 1, 0.10319657161203893`], 
          Hue[0.6499234339708698, 1, 0.10010601450187252`], 
          Hue[0.6498999158910808, 1, 0.10013857799696516`], 
          Hue[0.647689158882889, 1, 0.10319962616215365`], 
          Hue[0.6407410131382987, 1, 0.11282013565466335`], 
          Hue[0.1258778345738436, 1, 0.8257076136669858], 
          Hue[0.38039375688790367`, 1, 0.47330095200136413`], 
          Hue[0.20320360944253912`, 1, 0.7186411561564843], 
          Hue[0.5466178103377806, 1, 0.2431445703015346], 
          Hue[0.648169908158964, 1, 0.1025339733183575], 
          Hue[0.6063667976093324, 1, 0.16041520331015513`], 
          Hue[0.38142020547147815`, 1, 0.47187971550103025`], 
          Hue[0.012081754707547243`, 1, 0.9832714165587807], 
          Hue[0.6401788954607293, 1, 0.11359845243899036`], 
          Hue[0.6497623107684638, 1, 0.1003291081667424], 
          Hue[0.6381946085840514, 1, 0.11634592657592888`], 
          Hue[0.001830128986839763, 1, 0.997465975248991], 
          Hue[0.3815792812806719, 1, 0.47165945668830045`], 
          Hue[0.06965458206126518, 1, 0.9035551940690174], 
          Hue[0.6304274771234769, 1, 0.12710041629057042`], 
          Hue[0.6479029355746326, 1, 0.10290362766589324`], 
          Hue[0.4352752681834741, 1, 0.39731116713057435`], 
          Hue[0.2213455433902511, 1, 0.6935215553058062], 
          Hue[0.6477675302360363, 1, 0.10309111198087288`], 
          Hue[0.6499891299519429, 1, 0.10001505083577135`], 
          Hue[0.6499894961587154, 1, 0.10001454378024031`], 
          Hue[0.6477905636018336, 1, 0.10305921962823035`], 
          Hue[0.6478665397678468, 1, 0.10295402185990452`], 
          Hue[0.6334339194522445, 1, 0.12293764998920002`], 
          Hue[0.029450781223752553`, 1, 0.9592219952286504], 
          Hue[0.38167587893283167`, 1, 0.4715257060930024], 
          Hue[0.020769402944883608`, 1, 0.9712423651532381], 
          Hue[0.6370356710114344, 1, 0.1179506093687831], 
          Hue[0.6497766367262287, 1, 0.10030927222522196`], 
          Hue[0.6403911890476606, 1, 0.11330450747247003`], 
          Hue[0.042007221780410275`, 1, 0.9418361544578934], 
          Hue[0.3809988286182713, 1, 0.4724631603747014], 
          Hue[0.5953868334528627, 1, 0.1756182306037286], 
          Hue[0.5661988796455623, 1, 0.21603232049076004`], 
          Hue[0.3810145520498247, 1, 0.47244138946947356`], 
          Hue[0.07622311351109479, 1, 0.8944603043692533], 
          Hue[0.6406439316913151, 1, 0.1129545561197176], 
          Hue[0.6498942968307041, 1, 0.10014635823440968`], 
          Hue[0.6499272526083334, 1, 0.10010072715769222`], 
          Hue[0.6408170603999431, 1, 0.11271483944623266`], 
          Hue[0.5239438703436952, 1, 0.27453925644719135`], 
          Hue[0.6148904654278435, 1, 0.14861320171529357`], 
          Hue[0.38151314808405634`, 1, 0.4717510257297681], 
          Hue[0.0030597650064418946`, 1, 0.9957634022987727], 
          Hue[0.6398985720452087, 1, 0.11398659255278802`], 
          Hue[0.6497010272369832, 1, 0.1004139622872541], 
          Hue[0.6389763735377612, 1, 0.11526348279386915`], 
          Hue[0.000014352248194238193`, 1, 0.9999801276563465], 
          Hue[0.38150534871354935`, 1, 0.4717618248581624], 
          Hue[0.6265261767808014, 1, 0.13250221676504426`], 
          Hue[0.6479521583403359, 1, 0.10283547306722725`], 
          Hue[0.6477437729150449, 1, 0.10312400673301478`], 
          Hue[0.649978625441746, 1, 0.10002959554219783`], 
          Hue[0.6499662038211845, 1, 0.10004679470912908`], 
          Hue[0.626671111801424, 1, 0.13230153750572063`], 
          Hue[0.3816362084602943, 1, 0.4715806344395925], 
          Hue[0.0024044432674100724`, 1, 0.996670770860509], 
          Hue[0.6389436428864329, 1, 0.11530880215724684`], 
          Hue[0.6399167574390738, 1, 0.11396141277666709`], 
          Hue[0.01064114698672669, 1, 0.9852661041722245], 
          Hue[0.3812944654221777, 1, 0.47205381710775396`], 
          Hue[0.6146888019428256, 1, 0.14889242807916464`], 
          Hue[0.6499466040787308, 1, 0.10007393281406504`], 
          Hue[0.6498662222180652, 1, 0.10018523077498667`], 
          Hue[0.640650659615757, 1, 0.11294524053202887`], 
          Hue[0.5659296628288217, 1, 0.21640508223701613`], 
          Hue[0.5956374816469338, 1, 0.1752711792580917], 
          Hue[0.3813062032509241, 1, 0.47203756472948966`], 
          Hue[0.027332071192527008`, 1, 0.9621555937334241], 
          Hue[0.6403807498030206, 1, 0.11331896181120223`], 
          Hue[0.6498145386785963, 1, 0.10025679259886666`], 
          Hue[0.6370930532814012, 1, 0.11787115699498295`], 
          Hue[0.007754622020254676, 1, 0.9892628310488782], 
          Hue[0.381632316477498, 1, 0.4715860233388489], 
          Hue[0.6333390816732671, 1, 0.1230689638370148], 
          Hue[0.6477958473267951, 1, 0.10305190370136064`], 
          Hue[0.6499969261842111, 1, 0.10000425605263076`]}],
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesLabel->{None, None},
       AxesOrigin->{0., 0.},
       DisplayFunction->((Print[#]; #)& ),
       FormatType->OutputForm,
       Method->{},
       PlotLabel->"Surface Intensity",
       PlotRange->All,
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}]}], ",", 
     RowBox[{"ComponentNumber", "\[Rule]", "3.`"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1.`"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1.`"}], ",", 
     RowBox[{"SmoothKernelSize", "\[Rule]", "0.0017135135482782005`"}], ",", 
     RowBox[{"RayBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.06927633997056581`"}], ",", "0.06927633997056581`"}], 
       "}"}]}], ",", 
     RowBox[{"NumberOfRays", "\[Rule]", "616"}], ",", 
     RowBox[{"Full3D", "\[Rule]", "False"}], ",", 
     RowBox[{"Energy", "\[Rule]", "98.40108297887393`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367610243134*^9, 3.566087061216064*^9, 
  3.5661018487510977`*^9, 3.566139119263756*^9, 3.566139297781248*^9, 
  3.614707881489233*^9, 3.614710114379311*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "Out[355]=",ExpressionUUID->"a1a52898-e5e7-40a2-bad0-b10bb386556d"]
}, Open  ]],

Cell[TextData[{
 "Here we see that reported ",
 StyleBox["Energy", "Input"],
 " information shows a decrease in the transmitted energy between the first \
and last reported surface. In particular, there is a slight loss as a result \
of the aperture stop. With this particular system, the Fresnel losses \
associated with refractive lens surfaces are not taken into account. However, \
you could use the ",
 StyleBox["FresnelReflections -> True", "Input"],
 " option with ",
 StyleBox["PlanoConvexLens", "Input"],
 " to include this effect as well. (The ",
 StyleBox["FresnelReflections", "Input"],
 " option is examined in ",
 ButtonBox["Section 3.4.2",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"3.4"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " discussion. )"
}], "Text",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", 
   "RG17.5"},ExpressionUUID->"3dd53550-bd89-4434-8178-b4bdb23c4c00"],

Cell[TextData[{
 "We can again use ",
 StyleBox["ModulationTransferFunction", "Input"],
 " with our ",
 StyleBox["FindIntensity", "Input"],
 " result. This time, however, we need to pass only the information from the \
focal surface. In addition, we can abbreviate the ",
 StyleBox["ModulationTransferFunction", "Input"],
 " command with ",
 StyleBox["MTF", "Input"],
 "."
}], "Text",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", 
   "RG17.5"},ExpressionUUID->"d70a31c8-3057-42e4-ad73-12b52a878b1c"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["MTF", "Input"],
 "[intensity[[2]]]"
}], "Input",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->"In[76]:=",ExpressionUUID->"9588485b-e6e9-491f-baef-c7d69029eba3"],

Cell[BoxData["\<\"A light source has not been indicated for the \
system.\"\>"], "Print",
 CellChangeTimes->{3.5633676105561934`*^9, 3.566087061463953*^9, 
  3.566101848974448*^9, 3.566139298055071*^9, 3.6147078816173487`*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->
  "During evaluation of \
In[76]:=",ExpressionUUID->"409ae0e2-9603-42ba-980c-4a24dcf7d5df"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.563367610571467*^9, 3.566087061483489*^9, 
  3.566101848998817*^9, 3.566139298059101*^9, 3.614707881619339*^9},
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"},
 CellLabel->"Out[76]=",ExpressionUUID->"de6bc496-b575-462e-bc44-25ac8b5a9211"]
}, Open  ]],

Cell["\<\
This example demonstrates one of the great pitfalls in using a \
two-dimensional result to model a three-dimensional system. In particular, it \
is a strong temptation to assume that one can use the results from a \
two-dimensional ray trace to gauge the performance of a three-dimensional \
system. Unfortunately, this can be an erroneous assumption. As illustrated by \
this example, such intensity calculations can be very different from a \
three-dimensional ray-trace. This is particularly evident at the focal plane \
in this example, where both the point spread function and modulation transfer \
function looks very different from the previous three-dimensional example. \
This is because the energy density from the three-dimensional trace through a \
radially symmetric lens system is much more concentrated along optical axis. \
This last result actually depicts the behavior of a cylindrical lens system \
better than a plano-convex lens in three dimensions. However, because the ray \
density is far greater in this recent example, it has a much better spatial \
resolution than the previous example and quite accurately depicts the \
geometric light flux behavior of the two-dimensional system.\
\>", "Text",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", "RG17.", 
   "RG17.5"},ExpressionUUID->"f22e5175-9749-47ac-b69b-4446723b94d5"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",
 CellTags->{
  "FindIntensity", "1-D Calculations with FindIntensity", 
   "RG17."},ExpressionUUID->"c605f174-ab57-4738-8b7a-88a1e288edac"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "18. The ",
 StyleBox["Resonate",
  FontFamily->"Courier New"],
 " Function"
}], "Section",
 CellTags->{
  "Resonate", "18.", 
   "RG18."},ExpressionUUID->"6ac6bfd3-1a3d-49c7-95bf-3feeaabfa8cd"],

Cell[TextData[{
 StyleBox["Resonate", "Input"],
 " is used to create non-sequential behavior between formerly distinct \
optical elements. ",
 StyleBox["Resonate", "Input"],
 " is routinely used by many built-in component functions of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " to describe complex optical elements, such as multi-faceted prisms. Since \
many optical systems do require non-sequential ray interactions between \
multiple component surfaces, ",
 StyleBox["Resonate", "Input"],
 " is one of the most important functions in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". Here we define ",
 StyleBox["Resonate", "Input"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "Resonate", 
   "RG18."},ExpressionUUID->"8d722c0e-fc4f-44f3-9c41-5eab67bf2242"],

Cell[TextData[{
 StyleBox["Resonate[", "Input"],
 StyleBox["listofcomponents",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " causes a ray to be nonsequentially traced within all of the surfaces \
defined by ",
 StyleBox["listofcomponents",
  FontSlant->"Italic"],
 "."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Resonate", "RG18."},ExpressionUUID->"2a3a4728-f479-438e-ac36-9372ed3ae683"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " always traces rays between distinct optical components in a sequential \
fashion. This means that the ray-trace is always occurring in the same \
sequence as the component list order. However, anytime the ray trace occurs \
within the surfaces of an optical component (such as a ",
 StyleBox["Prism", "Input"],
 ") then non-sequential ray-tracing becomes possible. In some cases, however, \
it becomes necessary for rays to travel non-sequentially between one or more \
components. For this purpose, you can use ",
 StyleBox["Resonate", "Input"],
 ". Lets take, for an example, the case of a lens-mirror combination. Here, \
the rays might travel through a lens, reflect off a mirror, and then travel \
back through the same lens for a second pass. In its normal mode of \
operation, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " does not see the lens on the second pass when the components are listed \
separately."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->{
  "ray tracing", "Resonate", 
   "RG18."},ExpressionUUID->"f385f2b0-9078-4098-94f4-63d776aa23db"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tLineOfRays[45],
\tMove[PlanoConvexLens[100,50,10],50],
\tMove[Mirror[50,5],75],
\tBoundary[100]},PlotType->TopView];\
\>", "Input",
 CellTags->{"Resonate", "RG18."},
 CellLabel->"In[77]:=",ExpressionUUID->"0c140923-69b9-470b-a77f-5008c14dc1d6"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{75., -25.}, {80., -25.}, {80., -16.66666666666667}, {
      75., -16.666666666666668`}, {75., -25.}}], 
     PolygonBox[{{75., -16.666666666666668`}, {80., -16.66666666666667}, {
      80., -8.333333333333336}, {75., -8.333333333333336}, {
      75., -16.666666666666668`}}], 
     PolygonBox[{{75., -8.333333333333336}, {80., -8.333333333333336}, {
      80., -7.105427357601002*^-15}, {75., 0.}, {75., -8.333333333333336}}], 
     PolygonBox[{{75., 0.}, {80., 0.}, {80., 8.333333333333332}, {75., 
      8.333333333333329}, {75., 0.}}], 
     PolygonBox[{{75., 8.333333333333329}, {80., 8.333333333333332}, {80., 
      16.666666666666664`}, {75., 16.666666666666664`}, {75., 
      8.333333333333329}}], 
     PolygonBox[{{75., 16.666666666666664`}, {80., 16.666666666666664`}, {80.,
       24.999999999999996`}, {75., 24.999999999999993`}, {75., 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., -25.}, {75., -16.666666666666668`}, {
       75., -8.333333333333336}, {75., -3.552713678800501*^-15}, {75., 
       8.333333333333329}, {75., 16.666666666666657`}, {75., 
       24.999999999999993`}, {80., 25.}, {80., 16.666666666666668`}, {80., 
       8.333333333333336}, {80., 3.552713678800501*^-15}, {
       80., -8.333333333333329}, {80., -16.666666666666657`}, {
       80., -24.999999999999993`}, {75., -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{75., 0.}, {80., 3.061616997868383*^-15}, {80., 
        2.551347498223653*^-15}, {75., 5.102694996447305*^-16}, {75., 0.}}], 
       PolygonBox[{{75., 5.102694996447305*^-16}, {80., 
        2.551347498223653*^-15}, {80., 2.0410779985789223`*^-15}, {75., 
        1.020538999289461*^-15}, {75., 5.102694996447305*^-16}}], 
       PolygonBox[{{75., 1.020538999289461*^-15}, {80., 
        2.0410779985789223`*^-15}, {80., 1.530808498934192*^-15}, {75., 
        1.5308084989341915`*^-15}, {75., 1.020538999289461*^-15}}], 
       PolygonBox[{{75., 1.5308084989341915`*^-15}, {80., 
        1.5308084989341915`*^-15}, {80., 1.0205389992894611`*^-15}, {75., 
        2.041077998578922*^-15}, {75., 1.5308084989341915`*^-15}}], 
       PolygonBox[{{75., 2.041077998578922*^-15}, {80., 
        1.0205389992894611`*^-15}, {80., 5.102694996447307*^-16}, {75., 
        2.5513474982236525`*^-15}, {75., 2.041077998578922*^-15}}], 
       PolygonBox[{{75., 2.5513474982236525`*^-15}, {80., 
        5.102694996447308*^-16}, {80., 2.5493082627129206`*^-31}, {75., 
        3.0616169978683826`*^-15}, {75., 2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 
         0.}, {75., 0.}, {80., 0.}, {80., 0.}, {80., 0.}, {80., 0.}, {80., 
         0.}, {80., 0.}, {80., 0.}, {75., 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{75., 0.}, {75., 8.333333333333332}, {75., 
      8.049381885742235}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 8.333333333333332}, {75., 16.666666666666664`}, {75., 
      16.09876377148447}, {75., 8.049381885742235}, {75., 
      8.333333333333332}}], 
     PolygonBox[{{75., 16.666666666666664`}, {75., 25.}, {75., 
      24.148145657226706`}, {75., 16.09876377148447}, {75., 
      16.666666666666664`}}], 
     PolygonBox[{{75., 0.}, {75., 8.049381885742235}, {75., 
      7.216878364870323}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 8.049381885742235}, {75., 16.09876377148447}, {75., 
      14.433756729740645`}, {75., 7.216878364870323}, {75., 
      8.049381885742235}}], 
     PolygonBox[{{75., 16.09876377148447}, {75., 24.148145657226706`}, {75., 
      21.65063509461097}, {75., 14.433756729740645`}, {75., 
      16.09876377148447}}], 
     PolygonBox[{{75., 0.}, {75., 7.216878364870323}, {75., 
      5.892556509887896}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 7.216878364870323}, {75., 14.433756729740645`}, {75., 
      11.785113019775793`}, {75., 5.892556509887896}, {75., 
      7.216878364870323}}], 
     PolygonBox[{{75., 14.433756729740645`}, {75., 21.65063509461097}, {75., 
      17.67766952966369}, {75., 11.785113019775793`}, {75., 
      14.433756729740645`}}], 
     PolygonBox[{{75., 0.}, {75., 5.892556509887896}, {75., 
      4.166666666666668}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 5.892556509887896}, {75., 11.785113019775793`}, {75., 
      8.333333333333336}, {75., 4.166666666666668}, {75., 
      5.892556509887896}}], 
     PolygonBox[{{75., 11.785113019775793`}, {75., 17.67766952966369}, {75., 
      12.500000000000004`}, {75., 8.333333333333336}, {75., 
      11.785113019775793`}}], 
     PolygonBox[{{75., 0.}, {75., 4.166666666666668}, {75., 
      2.156825375854341}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 4.166666666666668}, {75., 8.333333333333336}, {75., 
      4.313650751708682}, {75., 2.156825375854341}, {75., 
      4.166666666666668}}], 
     PolygonBox[{{75., 8.333333333333336}, {75., 12.500000000000004`}, {75., 
      6.470476127563024}, {75., 4.313650751708682}, {75., 
      8.333333333333336}}], 
     PolygonBox[{{75., 0.}, {75., 2.156825375854341}, {75., 
      2.3606412073533245`*^-15}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 2.156825375854341}, {75., 4.313650751708682}, {75., 
      4.721282414706649*^-15}, {75., 2.3606412073533245`*^-15}, {75., 
      2.156825375854341}}], 
     PolygonBox[{{75., 4.313650751708682}, {75., 6.470476127563024}, {75., 
      7.0819236220599744`*^-15}, {75., 4.721282414706649*^-15}, {75., 
      4.313650751708682}}], 
     PolygonBox[{{75., 0.}, {75., 5.102694996447305*^-16}, {
      75., -2.1568253758543383`}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 5.102694996447305*^-16}, {75., 
      1.020538999289461*^-15}, {75., -4.313650751708677}, {
      75., -2.1568253758543383`}, {75., 5.102694996447305*^-16}}], 
     PolygonBox[{{75., 1.020538999289461*^-15}, {75., 
      1.5308084989341915`*^-15}, {75., -6.470476127563016}, {
      75., -4.313650751708677}, {75., 1.020538999289461*^-15}}], 
     PolygonBox[{{75., 0.}, {75., -2.1568253758543383`}, {
      75., -4.166666666666664}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -2.1568253758543383`}, {75., -4.313650751708677}, {
      75., -8.333333333333329}, {75., -4.166666666666664}, {
      75., -2.1568253758543383`}}], 
     PolygonBox[{{75., -4.313650751708677}, {75., -6.470476127563016}, {
      75., -12.499999999999995`}, {75., -8.333333333333329}, {
      75., -4.313650751708677}}], 
     PolygonBox[{{75., 0.}, {75., -4.166666666666664}, {
      75., -5.8925565098878945`}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -4.166666666666664}, {75., -8.333333333333329}, {
      75., -11.785113019775789`}, {75., -5.8925565098878945`}, {
      75., -4.166666666666664}}], 
     PolygonBox[{{75., -8.333333333333329}, {75., -12.499999999999995`}, {
      75., -17.677669529663685`}, {75., -11.785113019775789`}, {
      75., -8.333333333333329}}], 
     PolygonBox[{{75., 0.}, {75., -5.8925565098878945`}, {
      75., -7.216878364870323}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -5.8925565098878945`}, {75., -11.785113019775789`}, {
      75., -14.433756729740645`}, {75., -7.216878364870323}, {
      75., -5.8925565098878945`}}], 
     PolygonBox[{{75., -11.785113019775789`}, {75., -17.677669529663685`}, {
      75., -21.65063509461097}, {75., -14.433756729740645`}, {
      75., -11.785113019775789`}}], 
     PolygonBox[{{75., 0.}, {75., -7.21687836487032}, {
      75., -8.049381885742235}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -7.21687836487032}, {75., -14.43375672974064}, {
      75., -16.09876377148447}, {75., -8.049381885742235}, {
      75., -7.21687836487032}}], 
     PolygonBox[{{75., -14.43375672974064}, {75., -21.650635094610962`}, {
      75., -24.148145657226706`}, {75., -16.09876377148447}, {
      75., -14.43375672974064}}], 
     PolygonBox[{{75., 0.}, {75., -8.049381885742235}, {
      75., -8.333333333333332}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -8.049381885742235}, {75., -16.09876377148447}, {
      75., -16.666666666666664`}, {75., -8.333333333333332}, {
      75., -8.049381885742235}}], 
     PolygonBox[{{75., -16.09876377148447}, {75., -24.148145657226706`}, {
      75., -25.}, {75., -16.666666666666664`}, {75., -16.09876377148447}}], 
     PolygonBox[{{75., 0.}, {75., -8.333333333333332}, {
      75., -8.049381885742235}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -8.333333333333332}, {75., -16.666666666666664`}, {
      75., -16.09876377148447}, {75., -8.049381885742235}, {
      75., -8.333333333333332}}], 
     PolygonBox[{{75., -16.666666666666664`}, {75., -25.}, {
      75., -24.148145657226706`}, {75., -16.09876377148447}, {
      75., -16.666666666666664`}}], 
     PolygonBox[{{75., 0.}, {75., -8.049381885742235}, {
      75., -7.216878364870323}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -8.049381885742235}, {75., -16.09876377148447}, {
      75., -14.433756729740645`}, {75., -7.216878364870323}, {
      75., -8.049381885742235}}], 
     PolygonBox[{{75., -16.09876377148447}, {75., -24.14814565722671}, {
      75., -21.65063509461097}, {75., -14.433756729740645`}, {
      75., -16.09876377148447}}], 
     PolygonBox[{{75., 0.}, {75., -7.216878364870323}, {
      75., -5.892556509887897}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -7.216878364870323}, {75., -14.433756729740645`}, {
      75., -11.785113019775794`}, {75., -5.892556509887897}, {
      75., -7.216878364870323}}], 
     PolygonBox[{{75., -14.433756729740645`}, {75., -21.65063509461097}, {
      75., -17.677669529663692`}, {75., -11.785113019775794`}, {
      75., -14.433756729740645`}}], 
     PolygonBox[{{75., 0.}, {75., -5.892556509887898}, {
      75., -4.16666666666667}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -5.892556509887898}, {75., -11.785113019775796`}, {
      75., -8.33333333333334}, {75., -4.16666666666667}, {
      75., -5.892556509887898}}], 
     PolygonBox[{{75., -11.785113019775796`}, {75., -17.677669529663696`}, {
      75., -12.50000000000001}, {75., -8.33333333333334}, {
      75., -11.785113019775796`}}], 
     PolygonBox[{{75., 0.}, {75., -4.16666666666667}, {
      75., -2.156825375854346}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -4.16666666666667}, {75., -8.33333333333334}, {
      75., -4.313650751708692}, {75., -2.156825375854346}, {
      75., -4.16666666666667}}], 
     PolygonBox[{{75., -8.33333333333334}, {75., -12.50000000000001}, {
      75., -6.470476127563038}, {75., -4.313650751708692}, {
      75., -8.33333333333334}}], 
     PolygonBox[{{75., 0.}, {75., -2.156825375854346}, {
      75., -8.932295329768568*^-15}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -2.156825375854346}, {75., -4.313650751708692}, {
      75., -1.7864590659537137`*^-14}, {75., -8.932295329768568*^-15}, {
      75., -2.156825375854346}}], 
     PolygonBox[{{75., -4.313650751708692}, {75., -6.470476127563038}, {
      75., -2.6796885989305705`*^-14}, {75., -1.7864590659537137`*^-14}, {
      75., -4.313650751708692}}], 
     PolygonBox[{{75., 0.}, {75., -1.5308084989341913`*^-15}, {75., 
      2.1568253758543356`}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., -1.5308084989341913`*^-15}, {
      75., -3.0616169978683826`*^-15}, {75., 4.313650751708671}, {75., 
      2.1568253758543356`}, {75., -1.5308084989341913`*^-15}}], 
     PolygonBox[{{75., -3.0616169978683826`*^-15}, {
      75., -4.592425496802574*^-15}, {75., 6.470476127563007}, {75., 
      4.313650751708671}, {75., -3.0616169978683826`*^-15}}], 
     PolygonBox[{{75., 0.}, {75., 2.1568253758543356`}, {75., 
      4.166666666666661}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 2.1568253758543356`}, {75., 4.313650751708671}, {75., 
      8.333333333333321}, {75., 4.166666666666661}, {75., 
      2.1568253758543356`}}], 
     PolygonBox[{{75., 4.313650751708671}, {75., 6.470476127563007}, {75., 
      12.499999999999984`}, {75., 8.333333333333321}, {75., 
      4.313650751708671}}], 
     PolygonBox[{{75., 0.}, {75., 4.166666666666661}, {75., 
      5.89255650988789}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 4.166666666666661}, {75., 8.333333333333321}, {75., 
      11.78511301977578}, {75., 5.89255650988789}, {75., 4.166666666666661}}],
      PolygonBox[{{75., 8.333333333333321}, {75., 12.499999999999984`}, {75., 
      17.67766952966367}, {75., 11.78511301977578}, {75., 
      8.333333333333321}}], 
     PolygonBox[{{75., 0.}, {75., 5.8925565098878945`}, {75., 
      7.216878364870319}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 5.8925565098878945`}, {75., 11.785113019775789`}, {75.,
       14.433756729740638`}, {75., 7.216878364870319}, {75., 
      5.8925565098878945`}}], 
     PolygonBox[{{75., 11.785113019775789`}, {75., 17.677669529663685`}, {75.,
       21.65063509461096}, {75., 14.433756729740638`}, {75., 
      11.785113019775789`}}], 
     PolygonBox[{{75., 0.}, {75., 7.216878364870319}, {75., 
      8.049381885742234}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 7.216878364870319}, {75., 14.433756729740638`}, {75., 
      16.098763771484467`}, {75., 8.049381885742234}, {75., 
      7.216878364870319}}], 
     PolygonBox[{{75., 14.433756729740638`}, {75., 21.65063509461096}, {75., 
      24.148145657226703`}, {75., 16.098763771484467`}, {75., 
      14.433756729740638`}}], 
     PolygonBox[{{75., 0.}, {75., 8.049381885742234}, {75., 
      8.333333333333332}, {75., 0.}, {75., 0.}}], 
     PolygonBox[{{75., 8.049381885742234}, {75., 16.098763771484467`}, {75., 
      16.666666666666664`}, {75., 8.333333333333332}, {75., 
      8.049381885742234}}], 
     PolygonBox[{{75., 16.098763771484467`}, {75., 24.148145657226703`}, {75.,
       25.}, {75., 16.666666666666664`}, {75., 16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHghwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAFhNgg8=
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEhDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AoKBvgQ==
       "]]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{75., 25.}, {80., 25.}, {80., 24.148145657226706`}, {75., 
       24.148145657226706`}, {75., 25.}}], 
      LineBox[{{75., 24.148145657226706`}, {80., 24.148145657226706`}, {80., 
       21.65063509461097}, {75., 21.65063509461097}, {75., 
       24.148145657226706`}}], 
      LineBox[{{75., 21.65063509461097}, {80., 21.65063509461097}, {80., 
       17.67766952966369}, {75., 17.67766952966369}, {75., 
       21.65063509461097}}], 
      LineBox[{{75., 17.67766952966369}, {80., 17.67766952966369}, {80., 
       12.500000000000004`}, {75., 12.500000000000004`}, {75., 
       17.67766952966369}}], 
      LineBox[{{75., 12.500000000000004`}, {80., 12.500000000000004`}, {80., 
       6.470476127563024}, {75., 6.470476127563024}, {75., 
       12.500000000000004`}}], 
      LineBox[{{75., 6.470476127563024}, {80., 6.470476127563024}, {80., 
       7.0819236220599744`*^-15}, {75., 7.0819236220599744`*^-15}, {75., 
       6.470476127563024}}], 
      LineBox[{{75., 1.5308084989341915`*^-15}, {80., 
       1.5308084989341915`*^-15}, {80., -6.470476127563016}, {
       75., -6.470476127563016}, {75., 1.5308084989341915`*^-15}}], 
      LineBox[{{75., -6.470476127563016}, {80., -6.470476127563016}, {
       80., -12.499999999999995`}, {75., -12.499999999999995`}, {
       75., -6.470476127563016}}], 
      LineBox[{{75., -12.499999999999995`}, {80., -12.499999999999995`}, {
       80., -17.677669529663685`}, {75., -17.677669529663685`}, {
       75., -12.499999999999995`}}], 
      LineBox[{{75., -17.677669529663685`}, {80., -17.677669529663685`}, {
       80., -21.65063509461097}, {75., -21.65063509461097}, {
       75., -17.677669529663685`}}], 
      LineBox[{{75., -21.650635094610962`}, {80., -21.650635094610962`}, {
       80., -24.148145657226706`}, {75., -24.148145657226706`}, {
       75., -21.650635094610962`}}], 
      LineBox[{{75., -24.148145657226706`}, {80., -24.148145657226706`}, {
       80., -25.}, {75., -25.}, {75., -24.148145657226706`}}], 
      LineBox[{{75., -25.}, {80., -25.}, {80., -24.148145657226706`}, {
       75., -24.148145657226706`}, {75., -25.}}], 
      LineBox[{{75., -24.14814565722671}, {80., -24.14814565722671}, {
       80., -21.65063509461097}, {75., -21.65063509461097}, {
       75., -24.14814565722671}}], 
      LineBox[{{75., -21.65063509461097}, {80., -21.65063509461097}, {
       80., -17.677669529663692`}, {75., -17.677669529663692`}, {
       75., -21.65063509461097}}], 
      LineBox[{{75., -17.677669529663696`}, {80., -17.677669529663696`}, {
       80., -12.50000000000001}, {75., -12.50000000000001}, {
       75., -17.677669529663696`}}], 
      LineBox[{{75., -12.50000000000001}, {80., -12.50000000000001}, {
       80., -6.470476127563038}, {75., -6.470476127563038}, {
       75., -12.50000000000001}}], 
      LineBox[{{75., -6.470476127563038}, {80., -6.470476127563038}, {
       80., -2.6796885989305705`*^-14}, {75., -2.6796885989305705`*^-14}, {
       75., -6.470476127563038}}], 
      LineBox[{{75., -4.592425496802574*^-15}, {
       80., -4.592425496802574*^-15}, {80., 6.470476127563007}, {75., 
       6.470476127563007}, {75., -4.592425496802574*^-15}}], 
      LineBox[{{75., 6.470476127563007}, {80., 6.470476127563007}, {80., 
       12.499999999999984`}, {75., 12.499999999999984`}, {75., 
       6.470476127563007}}], 
      LineBox[{{75., 12.499999999999984`}, {80., 12.499999999999984`}, {80., 
       17.67766952966367}, {75., 17.67766952966367}, {75., 
       12.499999999999984`}}], 
      LineBox[{{75., 17.677669529663685`}, {80., 17.677669529663685`}, {80., 
       21.65063509461096}, {75., 21.65063509461096}, {75., 
       17.677669529663685`}}], 
      LineBox[{{75., 21.65063509461096}, {80., 21.65063509461096}, {80., 
       24.148145657226703`}, {75., 24.148145657226703`}, {75., 
       21.65063509461096}}], 
      LineBox[{{75., 24.148145657226703`}, {80., 24.148145657226703`}, {80., 
       25.}, {75., 25.}, {75., 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {60., -21.7192607925394}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {60., 21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -21.7192607925394}, {75., -18.00029403050644}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {75., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.7192607925394}, {75., 18.00029403050644}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{75., -18.00029403050644}, {-1.4210854715202004`*^-14, 
       0.5945397796583798}}]}, 
     {Arrowheads[Small], ArrowBox[{{75., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{75., 
       18.00029403050644}, {-1.4210854715202004`*^-14, \
-0.5945397796583798}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{55.13384936237171, -22.5}, {50.00000000000001, 0.}, {
      55.13384936237171, 22.5}, {60., -21.7192607925394}, {60., 0.}, {60., 
      21.7192607925394}, {75., -18.00029403050644}, {75., 0.}, {75., 
      18.00029403050644}, {-1.4210854715202004`*^-14, 0.5945397796583798}, {
      0., 0.}, {-1.4210854715202004`*^-14, -0.5945397796583798}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"M\"\>", {77.5, -27.4}, {0., 0.}], 
    InsetBox["\<\"L\"\>", {55., -27.4}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367611240995*^9, 3.566087061996242*^9, 
  3.566101850072308*^9, 3.5661392994085293`*^9, 3.614707882326723*^9},
 CellTags->{"Resonate", "RG18."},
 CellLabel->
  "During evaluation of \
In[77]:=",ExpressionUUID->"6917394b-82e0-453f-9725-1fbfafe6fde5"]
}, Open  ]],

Cell[TextData[{
 "We can instead combine the lens and mirror with ",
 StyleBox["Resonate", "Input"],
 " to create a self-contained non-sequential aggregate of the surfaces \
present."
}], "Text",
 CellTags->{
  "Resonate", "RG18."},ExpressionUUID->"b9ce648b-21ea-45df-ab34-f82451a785f1"],

Cell[CellGroupData[{

Cell["\<\
lensMirror = 
\tResonate[{
\t\tMove[PlanoConvexLens[100,50,10],50],
\t\tMove[Mirror[50,5],75]
\t}]\
\>", "Input",
 CellTags->{"Resonate", "RG18."},
 CellLabel->"In[78]:=",ExpressionUUID->"5a9a8588-177e-4de2-83fb-261ce5be10d2"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"Resonate", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"PlanoConvexLens", "[", 
          RowBox[{"100", ",", "50", ",", "10"}], "]"}], ",", "50.`"}], "]"}], 
       ",", 
       RowBox[{"Move", "[", 
        RowBox[{
         RowBox[{"Mirror", "[", 
          RowBox[{"50", ",", "5"}], "]"}], ",", "75.`"}], "]"}]}], "}"}], 
     "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367611510777*^9, 3.56608706223201*^9, 
  3.566101850672521*^9, 3.566139300201404*^9, 3.614707882576632*^9},
 CellTags->{"Resonate", "RG18."},
 CellLabel->"Out[78]=",ExpressionUUID->"510cfad9-5bec-4894-a87f-08e0b2a1190d"]
}, Open  ]],

Cell[TextData[{
 "Although the lens and mirror are still identified in the output as \
independent elements, in fact, ",
 StyleBox["Resonate", "Input"],
 " has melded their information into a single ",
 StyleBox["Component", "Input"],
 " object. This can be observed if we examine the ",
 StyleBox["Head", "Input"],
 " of the ",
 StyleBox["lensMirror", "Input"],
 " variable assignment:"
}], "Text",
 CellTags->{
  "Resonate", "RG18."},ExpressionUUID->"e6647d4c-317d-40ec-9b89-be6bce0d6eb8"],

Cell[CellGroupData[{

Cell["Head[lensMirror]", "Input",
 CellTags->{"Resonate", "RG18."},
 CellLabel->"In[79]:=",ExpressionUUID->"33cb3d49-cf10-4fa5-baa7-e84bbc9e5d2d"],

Cell[BoxData["Component"], "Output",
 CellChangeTimes->{3.563367611932901*^9, 3.5660870622671328`*^9, 
  3.566101850718799*^9, 3.566139300260919*^9, 3.614707882688311*^9},
 CellTags->{"Resonate", "RG18."},
 CellLabel->"Out[79]=",ExpressionUUID->"17d11535-b739-4885-9703-239044fb0481"]
}, Open  ]],

Cell[TextData[{
 "This indicates that the lens and mirror surfaces have been joined together \
under a single ",
 StyleBox["Component", "Input"],
 " roof! The rays now correctly trace through this new arrangement."
}], "Text",
 CellTags->{
  "Resonate", "RG18."},ExpressionUUID->"71d16563-1462-43f1-98d8-24d033a3d5be"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tLineOfRays[45],
\tlensMirror,
\tBoundary[100]},PlotType->TopView];\
\>", "Input",
 CellTags->{"Resonate", "RG18."},
 CellLabel->"In[80]:=",ExpressionUUID->"b4f7d976-188c-4529-9899-687a2e0498f3"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}], 
        {GrayLevel[0.5], EdgeForm[None], 
         PolygonBox[{{75., -25.}, {80., -25.}, {80., -16.66666666666667}, {
          75., -16.666666666666668`}, {75., -25.}}], 
         PolygonBox[{{75., -16.666666666666668`}, {80., -16.66666666666667}, {
          80., -8.333333333333336}, {75., -8.333333333333336}, {
          75., -16.666666666666668`}}], 
         PolygonBox[{{75., -8.333333333333336}, {80., -8.333333333333336}, {
          80., -7.105427357601002*^-15}, {75., 0.}, {
          75., -8.333333333333336}}], 
         PolygonBox[{{75., 0.}, {80., 0.}, {80., 8.333333333333332}, {75., 
          8.333333333333329}, {75., 0.}}], 
         PolygonBox[{{75., 8.333333333333329}, {80., 8.333333333333332}, {80.,
           16.666666666666664`}, {75., 16.666666666666664`}, {75., 
          8.333333333333329}}], 
         PolygonBox[{{75., 16.666666666666664`}, {80., 16.666666666666664`}, {
          80., 24.999999999999996`}, {75., 24.999999999999993`}, {75., 
          16.666666666666664`}}], 
         {GrayLevel[0], AbsoluteThickness[0.5], 
          LineBox[{{75., -25.}, {75., -16.666666666666668`}, {
           75., -8.333333333333336}, {75., -3.552713678800501*^-15}, {75., 
           8.333333333333329}, {75., 16.666666666666657`}, {75., 
           24.999999999999993`}, {80., 25.}, {80., 16.666666666666668`}, {80.,
            8.333333333333336}, {80., 3.552713678800501*^-15}, {
           80., -8.333333333333329}, {80., -16.666666666666657`}, {
           80., -24.999999999999993`}, {75., -25.}}], 
          {GrayLevel[0.5], EdgeForm[None], 
           PolygonBox[{{75., 0.}, {80., 3.061616997868383*^-15}, {80., 
            2.551347498223653*^-15}, {75., 5.102694996447305*^-16}, {75., 
            0.}}], PolygonBox[{{75., 5.102694996447305*^-16}, {80., 
            2.551347498223653*^-15}, {80., 2.0410779985789223`*^-15}, {75., 
            1.020538999289461*^-15}, {75., 5.102694996447305*^-16}}], 
           PolygonBox[{{75., 1.020538999289461*^-15}, {80., 
            2.0410779985789223`*^-15}, {80., 1.530808498934192*^-15}, {75., 
            1.5308084989341915`*^-15}, {75., 1.020538999289461*^-15}}], 
           PolygonBox[{{75., 1.5308084989341915`*^-15}, {80., 
            1.5308084989341915`*^-15}, {80., 1.0205389992894611`*^-15}, {75., 
            2.041077998578922*^-15}, {75., 1.5308084989341915`*^-15}}], 
           PolygonBox[{{75., 2.041077998578922*^-15}, {80., 
            1.0205389992894611`*^-15}, {80., 5.102694996447307*^-16}, {75., 
            2.5513474982236525`*^-15}, {75., 2.041077998578922*^-15}}], 
           PolygonBox[{{75., 2.5513474982236525`*^-15}, {80., 
            5.102694996447308*^-16}, {80., 2.5493082627129206`*^-31}, {75., 
            3.0616169978683826`*^-15}, {75., 2.5513474982236525`*^-15}}], 
           {GrayLevel[0], AbsoluteThickness[0.5], 
            LineBox[{{75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {
             75., 0.}, {75., 0.}, {80., 0.}, {80., 0.}, {80., 0.}, {80., 
             0.}, {80., 0.}, {80., 0.}, {80., 0.}, {75., 
             0.}}]}}}}}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{75., 0.}, {75., 8.333333333333332}, {75., 
        8.049381885742235}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 8.333333333333332}, {75., 16.666666666666664`}, {75.,
         16.09876377148447}, {75., 8.049381885742235}, {75., 
        8.333333333333332}}], 
       PolygonBox[{{75., 16.666666666666664`}, {75., 25.}, {75., 
        24.148145657226706`}, {75., 16.09876377148447}, {75., 
        16.666666666666664`}}], 
       PolygonBox[{{75., 0.}, {75., 8.049381885742235}, {75., 
        7.216878364870323}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 8.049381885742235}, {75., 16.09876377148447}, {75., 
        14.433756729740645`}, {75., 7.216878364870323}, {75., 
        8.049381885742235}}], 
       PolygonBox[{{75., 16.09876377148447}, {75., 24.148145657226706`}, {75.,
         21.65063509461097}, {75., 14.433756729740645`}, {75., 
        16.09876377148447}}], 
       PolygonBox[{{75., 0.}, {75., 7.216878364870323}, {75., 
        5.892556509887896}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 7.216878364870323}, {75., 14.433756729740645`}, {75.,
         11.785113019775793`}, {75., 5.892556509887896}, {75., 
        7.216878364870323}}], 
       PolygonBox[{{75., 14.433756729740645`}, {75., 21.65063509461097}, {75.,
         17.67766952966369}, {75., 11.785113019775793`}, {75., 
        14.433756729740645`}}], 
       PolygonBox[{{75., 0.}, {75., 5.892556509887896}, {75., 
        4.166666666666668}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 5.892556509887896}, {75., 11.785113019775793`}, {75.,
         8.333333333333336}, {75., 4.166666666666668}, {75., 
        5.892556509887896}}], 
       PolygonBox[{{75., 11.785113019775793`}, {75., 17.67766952966369}, {75.,
         12.500000000000004`}, {75., 8.333333333333336}, {75., 
        11.785113019775793`}}], 
       PolygonBox[{{75., 0.}, {75., 4.166666666666668}, {75., 
        2.156825375854341}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 4.166666666666668}, {75., 8.333333333333336}, {75., 
        4.313650751708682}, {75., 2.156825375854341}, {75., 
        4.166666666666668}}], 
       PolygonBox[{{75., 8.333333333333336}, {75., 12.500000000000004`}, {75.,
         6.470476127563024}, {75., 4.313650751708682}, {75., 
        8.333333333333336}}], 
       PolygonBox[{{75., 0.}, {75., 2.156825375854341}, {75., 
        2.3606412073533245`*^-15}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 2.156825375854341}, {75., 4.313650751708682}, {75., 
        4.721282414706649*^-15}, {75., 2.3606412073533245`*^-15}, {75., 
        2.156825375854341}}], 
       PolygonBox[{{75., 4.313650751708682}, {75., 6.470476127563024}, {75., 
        7.0819236220599744`*^-15}, {75., 4.721282414706649*^-15}, {75., 
        4.313650751708682}}], 
       PolygonBox[{{75., 0.}, {75., 5.102694996447305*^-16}, {
        75., -2.1568253758543383`}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 5.102694996447305*^-16}, {75., 
        1.020538999289461*^-15}, {75., -4.313650751708677}, {
        75., -2.1568253758543383`}, {75., 5.102694996447305*^-16}}], 
       PolygonBox[{{75., 1.020538999289461*^-15}, {75., 
        1.5308084989341915`*^-15}, {75., -6.470476127563016}, {
        75., -4.313650751708677}, {75., 1.020538999289461*^-15}}], 
       PolygonBox[{{75., 0.}, {75., -2.1568253758543383`}, {
        75., -4.166666666666664}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -2.1568253758543383`}, {75., -4.313650751708677}, {
        75., -8.333333333333329}, {75., -4.166666666666664}, {
        75., -2.1568253758543383`}}], 
       PolygonBox[{{75., -4.313650751708677}, {75., -6.470476127563016}, {
        75., -12.499999999999995`}, {75., -8.333333333333329}, {
        75., -4.313650751708677}}], 
       PolygonBox[{{75., 0.}, {75., -4.166666666666664}, {
        75., -5.8925565098878945`}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -4.166666666666664}, {75., -8.333333333333329}, {
        75., -11.785113019775789`}, {75., -5.8925565098878945`}, {
        75., -4.166666666666664}}], 
       PolygonBox[{{75., -8.333333333333329}, {75., -12.499999999999995`}, {
        75., -17.677669529663685`}, {75., -11.785113019775789`}, {
        75., -8.333333333333329}}], 
       PolygonBox[{{75., 0.}, {75., -5.8925565098878945`}, {
        75., -7.216878364870323}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -5.8925565098878945`}, {75., -11.785113019775789`}, {
        75., -14.433756729740645`}, {75., -7.216878364870323}, {
        75., -5.8925565098878945`}}], 
       PolygonBox[{{75., -11.785113019775789`}, {75., -17.677669529663685`}, {
        75., -21.65063509461097}, {75., -14.433756729740645`}, {
        75., -11.785113019775789`}}], 
       PolygonBox[{{75., 0.}, {75., -7.21687836487032}, {
        75., -8.049381885742235}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -7.21687836487032}, {75., -14.43375672974064}, {
        75., -16.09876377148447}, {75., -8.049381885742235}, {
        75., -7.21687836487032}}], 
       PolygonBox[{{75., -14.43375672974064}, {75., -21.650635094610962`}, {
        75., -24.148145657226706`}, {75., -16.09876377148447}, {
        75., -14.43375672974064}}], 
       PolygonBox[{{75., 0.}, {75., -8.049381885742235}, {
        75., -8.333333333333332}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -8.049381885742235}, {75., -16.09876377148447}, {
        75., -16.666666666666664`}, {75., -8.333333333333332}, {
        75., -8.049381885742235}}], 
       PolygonBox[{{75., -16.09876377148447}, {75., -24.148145657226706`}, {
        75., -25.}, {75., -16.666666666666664`}, {75., -16.09876377148447}}], 
       PolygonBox[{{75., 0.}, {75., -8.333333333333332}, {
        75., -8.049381885742235}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -8.333333333333332}, {75., -16.666666666666664`}, {
        75., -16.09876377148447}, {75., -8.049381885742235}, {
        75., -8.333333333333332}}], 
       PolygonBox[{{75., -16.666666666666664`}, {75., -25.}, {
        75., -24.148145657226706`}, {75., -16.09876377148447}, {
        75., -16.666666666666664`}}], 
       PolygonBox[{{75., 0.}, {75., -8.049381885742235}, {
        75., -7.216878364870323}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -8.049381885742235}, {75., -16.09876377148447}, {
        75., -14.433756729740645`}, {75., -7.216878364870323}, {
        75., -8.049381885742235}}], 
       PolygonBox[{{75., -16.09876377148447}, {75., -24.14814565722671}, {
        75., -21.65063509461097}, {75., -14.433756729740645`}, {
        75., -16.09876377148447}}], 
       PolygonBox[{{75., 0.}, {75., -7.216878364870323}, {
        75., -5.892556509887897}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -7.216878364870323}, {75., -14.433756729740645`}, {
        75., -11.785113019775794`}, {75., -5.892556509887897}, {
        75., -7.216878364870323}}], 
       PolygonBox[{{75., -14.433756729740645`}, {75., -21.65063509461097}, {
        75., -17.677669529663692`}, {75., -11.785113019775794`}, {
        75., -14.433756729740645`}}], 
       PolygonBox[{{75., 0.}, {75., -5.892556509887898}, {
        75., -4.16666666666667}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -5.892556509887898}, {75., -11.785113019775796`}, {
        75., -8.33333333333334}, {75., -4.16666666666667}, {
        75., -5.892556509887898}}], 
       PolygonBox[{{75., -11.785113019775796`}, {75., -17.677669529663696`}, {
        75., -12.50000000000001}, {75., -8.33333333333334}, {
        75., -11.785113019775796`}}], 
       PolygonBox[{{75., 0.}, {75., -4.16666666666667}, {
        75., -2.156825375854346}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -4.16666666666667}, {75., -8.33333333333334}, {
        75., -4.313650751708692}, {75., -2.156825375854346}, {
        75., -4.16666666666667}}], 
       PolygonBox[{{75., -8.33333333333334}, {75., -12.50000000000001}, {
        75., -6.470476127563038}, {75., -4.313650751708692}, {
        75., -8.33333333333334}}], 
       PolygonBox[{{75., 0.}, {75., -2.156825375854346}, {
        75., -8.932295329768568*^-15}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -2.156825375854346}, {75., -4.313650751708692}, {
        75., -1.7864590659537137`*^-14}, {75., -8.932295329768568*^-15}, {
        75., -2.156825375854346}}], 
       PolygonBox[{{75., -4.313650751708692}, {75., -6.470476127563038}, {
        75., -2.6796885989305705`*^-14}, {75., -1.7864590659537137`*^-14}, {
        75., -4.313650751708692}}], 
       PolygonBox[{{75., 0.}, {75., -1.5308084989341913`*^-15}, {75., 
        2.1568253758543356`}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., -1.5308084989341913`*^-15}, {
        75., -3.0616169978683826`*^-15}, {75., 4.313650751708671}, {75., 
        2.1568253758543356`}, {75., -1.5308084989341913`*^-15}}], 
       PolygonBox[{{75., -3.0616169978683826`*^-15}, {
        75., -4.592425496802574*^-15}, {75., 6.470476127563007}, {75., 
        4.313650751708671}, {75., -3.0616169978683826`*^-15}}], 
       PolygonBox[{{75., 0.}, {75., 2.1568253758543356`}, {75., 
        4.166666666666661}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 2.1568253758543356`}, {75., 4.313650751708671}, {75.,
         8.333333333333321}, {75., 4.166666666666661}, {75., 
        2.1568253758543356`}}], 
       PolygonBox[{{75., 4.313650751708671}, {75., 6.470476127563007}, {75., 
        12.499999999999984`}, {75., 8.333333333333321}, {75., 
        4.313650751708671}}], 
       PolygonBox[{{75., 0.}, {75., 4.166666666666661}, {75., 
        5.89255650988789}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 4.166666666666661}, {75., 8.333333333333321}, {75., 
        11.78511301977578}, {75., 5.89255650988789}, {75., 
        4.166666666666661}}], 
       PolygonBox[{{75., 8.333333333333321}, {75., 12.499999999999984`}, {75.,
         17.67766952966367}, {75., 11.78511301977578}, {75., 
        8.333333333333321}}], 
       PolygonBox[{{75., 0.}, {75., 5.8925565098878945`}, {75., 
        7.216878364870319}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 5.8925565098878945`}, {75., 11.785113019775789`}, {
        75., 14.433756729740638`}, {75., 7.216878364870319}, {75., 
        5.8925565098878945`}}], 
       PolygonBox[{{75., 11.785113019775789`}, {75., 17.677669529663685`}, {
        75., 21.65063509461096}, {75., 14.433756729740638`}, {75., 
        11.785113019775789`}}], 
       PolygonBox[{{75., 0.}, {75., 7.216878364870319}, {75., 
        8.049381885742234}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 7.216878364870319}, {75., 14.433756729740638`}, {75.,
         16.098763771484467`}, {75., 8.049381885742234}, {75., 
        7.216878364870319}}], 
       PolygonBox[{{75., 14.433756729740638`}, {75., 21.65063509461096}, {75.,
         24.148145657226703`}, {75., 16.098763771484467`}, {75., 
        14.433756729740638`}}], 
       PolygonBox[{{75., 0.}, {75., 8.049381885742234}, {75., 
        8.333333333333332}, {75., 0.}, {75., 0.}}], 
       PolygonBox[{{75., 8.049381885742234}, {75., 16.098763771484467`}, {75.,
         16.666666666666664`}, {75., 8.333333333333332}, {75., 
        8.049381885742234}}], 
       PolygonBox[{{75., 16.098763771484467`}, {75., 24.148145657226703`}, {
        75., 25.}, {75., 16.666666666666664`}, {75., 16.098763771484467`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHghwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAFhNgg8=
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEhDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AoKBvgQ==
         "]]}, 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{75., 25.}, {80., 25.}, {80., 24.148145657226706`}, {75., 
         24.148145657226706`}, {75., 25.}}], 
        LineBox[{{75., 24.148145657226706`}, {80., 24.148145657226706`}, {80.,
          21.65063509461097}, {75., 21.65063509461097}, {75., 
         24.148145657226706`}}], 
        LineBox[{{75., 21.65063509461097}, {80., 21.65063509461097}, {80., 
         17.67766952966369}, {75., 17.67766952966369}, {75., 
         21.65063509461097}}], 
        LineBox[{{75., 17.67766952966369}, {80., 17.67766952966369}, {80., 
         12.500000000000004`}, {75., 12.500000000000004`}, {75., 
         17.67766952966369}}], 
        LineBox[{{75., 12.500000000000004`}, {80., 12.500000000000004`}, {80.,
          6.470476127563024}, {75., 6.470476127563024}, {75., 
         12.500000000000004`}}], 
        LineBox[{{75., 6.470476127563024}, {80., 6.470476127563024}, {80., 
         7.0819236220599744`*^-15}, {75., 7.0819236220599744`*^-15}, {75., 
         6.470476127563024}}], 
        LineBox[{{75., 1.5308084989341915`*^-15}, {80., 
         1.5308084989341915`*^-15}, {80., -6.470476127563016}, {
         75., -6.470476127563016}, {75., 1.5308084989341915`*^-15}}], 
        LineBox[{{75., -6.470476127563016}, {80., -6.470476127563016}, {
         80., -12.499999999999995`}, {75., -12.499999999999995`}, {
         75., -6.470476127563016}}], 
        LineBox[{{75., -12.499999999999995`}, {80., -12.499999999999995`}, {
         80., -17.677669529663685`}, {75., -17.677669529663685`}, {
         75., -12.499999999999995`}}], 
        LineBox[{{75., -17.677669529663685`}, {80., -17.677669529663685`}, {
         80., -21.65063509461097}, {75., -21.65063509461097}, {
         75., -17.677669529663685`}}], 
        LineBox[{{75., -21.650635094610962`}, {80., -21.650635094610962`}, {
         80., -24.148145657226706`}, {75., -24.148145657226706`}, {
         75., -21.650635094610962`}}], 
        LineBox[{{75., -24.148145657226706`}, {80., -24.148145657226706`}, {
         80., -25.}, {75., -25.}, {75., -24.148145657226706`}}], 
        LineBox[{{75., -25.}, {80., -25.}, {80., -24.148145657226706`}, {
         75., -24.148145657226706`}, {75., -25.}}], 
        LineBox[{{75., -24.14814565722671}, {80., -24.14814565722671}, {
         80., -21.65063509461097}, {75., -21.65063509461097}, {
         75., -24.14814565722671}}], 
        LineBox[{{75., -21.65063509461097}, {80., -21.65063509461097}, {
         80., -17.677669529663692`}, {75., -17.677669529663692`}, {
         75., -21.65063509461097}}], 
        LineBox[{{75., -17.677669529663696`}, {80., -17.677669529663696`}, {
         80., -12.50000000000001}, {75., -12.50000000000001}, {
         75., -17.677669529663696`}}], 
        LineBox[{{75., -12.50000000000001}, {80., -12.50000000000001}, {
         80., -6.470476127563038}, {75., -6.470476127563038}, {
         75., -12.50000000000001}}], 
        LineBox[{{75., -6.470476127563038}, {80., -6.470476127563038}, {
         80., -2.6796885989305705`*^-14}, {75., -2.6796885989305705`*^-14}, {
         75., -6.470476127563038}}], 
        LineBox[{{75., -4.592425496802574*^-15}, {
         80., -4.592425496802574*^-15}, {80., 6.470476127563007}, {75., 
         6.470476127563007}, {75., -4.592425496802574*^-15}}], 
        LineBox[{{75., 6.470476127563007}, {80., 6.470476127563007}, {80., 
         12.499999999999984`}, {75., 12.499999999999984`}, {75., 
         6.470476127563007}}], 
        LineBox[{{75., 12.499999999999984`}, {80., 12.499999999999984`}, {80.,
          17.67766952966367}, {75., 17.67766952966367}, {75., 
         12.499999999999984`}}], 
        LineBox[{{75., 17.677669529663685`}, {80., 17.677669529663685`}, {80.,
          21.65063509461096}, {75., 21.65063509461096}, {75., 
         17.677669529663685`}}], 
        LineBox[{{75., 21.65063509461096}, {80., 21.65063509461096}, {80., 
         24.148145657226703`}, {75., 24.148145657226703`}, {75., 
         21.65063509461096}}], 
        LineBox[{{75., 24.148145657226703`}, {80., 24.148145657226703`}, {80.,
          25.}, {75., 25.}, {75., 24.148145657226703`}}]}}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {100., -50.}, {100., 50.}, {100., 
       50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {0., -50.}, {0., -50.}, {100., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -50}, {0, 50}, {0, 50}, {0, -50}, {0, -50}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 50.}, {100., 50.}, {100., 50.}, {0., 50.}, {0., 50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., -50.}, {100., 50.}, {0., 50.}, {0., -50.}, {
       100., -50.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{100., 50.}, {100., -50.}, {0., -50.}, {0., 50.}, {100., 
       50.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {60., -21.7192607925394}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {60., 21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -21.7192607925394}, {75., -18.00029403050644}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {75., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.7192607925394}, {75., 18.00029403050644}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{75., -18.00029403050644}, {60., -14.281327268473476`}}]}, 
     {Arrowheads[Small], ArrowBox[{{75., 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{75., 18.00029403050644}, {60., 14.281327268473476`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -14.281327268473476`}, {
       51.63993327251762, -12.940014112102814`}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 14.281327268473476`}, {51.63993327251762, 
       12.940014112102814`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{
       51.63993327251762, -12.940014112102814`}, {-7.105427357601002*^-15, 
       8.917738508470569}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.63993327251762, 
       12.940014112102814`}, {-7.105427357601002*^-15, \
-8.917738508470569}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], 
     PointBox[{{55.13384936237171, -22.5}, {50.00000000000001, 0.}, {
      55.13384936237171, 22.5}, {60., -21.7192607925394}, {60., 0.}, {60., 
      21.7192607925394}, {75., -18.00029403050644}, {75., 0.}, {75., 
      18.00029403050644}, {60., -14.281327268473476`}, {60., 0.}, {60., 
      14.281327268473476`}, {51.63993327251762, -12.940014112102814`}, {50., 
      0.}, {51.63993327251762, 12.940014112102814`}, {-7.105427357601002*^-15,
       8.917738508470569}, {0., 
      0.}, {-7.105427357601002*^-15, -8.917738508470569}}]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    InsetBox["\<\"L\"\>", {55., -27.4}, {0., 0.}], 
    InsetBox["\<\"M\"\>", {77.5, -27.4}, {0., 0.}]}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367612389699*^9, 3.566087062817499*^9, 
  3.5661018513903847`*^9, 3.566139300998644*^9, 3.614707883196745*^9},
 CellTags->{"Resonate", "RG18."},
 CellLabel->
  "During evaluation of \
In[80]:=",ExpressionUUID->"e96c081c-a9aa-41f5-99a6-34254acef2b3"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Resonate", "Input"],
 " works independently from whether ",
 StyleBox["AnalyzeSystem", "Input"],
 " or ",
 StyleBox["TurboPlot", "Input"],
 " is used for tracing. Here, the same system is traced with ",
 StyleBox["TurboPlot", "Input"],
 ":"
}], "Text",
 CellTags->{
  "Resonate", "RG18."},ExpressionUUID->"286d46df-c400-4cf9-8232-126cf5763f8b"],

Cell[CellGroupData[{

Cell["\<\
TurboPlot[{
\tLineOfRays[45],
\tlensMirror,
\tBoundary[100]},PlotType->TopView];\
\>", "Input",
 CellTags->{"Resonate", "RG18."},
 CellLabel->"In[81]:=",ExpressionUUID->"08e221a1-ddb4-4fe2-96bc-4448f258c60d"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJyVmEtoE1EUhuNzKYqKFlTqQrRqacQHDUSJKNiKD5D4WLgQQV12JSiCuBCs
XfhAXYhYfASpVaviWwwEddUiYkHQBhXT2k3dVSsoPsbceyfeLzmeSSC0h3u/
/z//zNyZyZ29s2XTrjGxWGxH8B0XfEcH3+b921aNWbYuFSt+Ejnzd0NZfb3z
7yeea22efm/CjrWpa7Ymz3Hyfl2ba+i/f2f5luawJs9x8n6/sezv4qfJ1THy
HAcf1p1mfsrxHbaW9N04eb+Op1w+V5PnOHlXmz4aU032+P+yNXn//JTy9bx8
efPcqaGkq+fX12dH/RhMOv5IW1v3np1Pk+Q5Tt7VrcXxQtLlM/N7y/Q5Tt7V
L4r95pPu+PfYmjzH/bx56PeCLyj6hTLe1UdtHpevzh4P8hx3fBuO55t8/tnd
rtMJd3677fmqyOc22fPj1mu6rPbWXzD/GmpvPsfJh3VtOJ819f31mi6r7eWV
9fuxnwr63niJD2tv/QXzO1BT31+/4MM6HvKsqe+v13RZ7davm/8LNfWZz1+/
aX/9BfO99Vkhr79+wQe1t/7C+b2ivr9+wQf1i3/XXzC/BzX1/fWaLqtbK/ZT
UPQLlfmgPoo8XF/Ur8PxasPxdOvXze/+93xV0Of54fUbP1Z7pqlGvn41nteT
0WPN+TJvjBJh3fT61ofPcxpF/f9ezxX83228vX3q+xmR85Knv9FbKOprPPMN
/jg87sSVpaI+efZL/wuLWzZ/Pzktcl7y9Dd6c0V9jWe+h7sn5w7cWCTqk2e/
9Df384mR85Kn/3Vcr9TXeOYbXfynTtQnz37pf/jV5av1K0dFzkue/kZvkqiv
8cy35vHeg88/1oj65Nkv/detX39+9apP4v1N4+lv9L4m/bqkr/HMNzw8PDQ4
8Dsp6ZNnv3z+HTT+Ocw/FJXn88/oTcr5dUlf4/n8W2Hy5yR98uyf/uZ9Z6KW
V+Tp34H3O+prPPP9LL5PzRP1ybNf+reb+0fkvOTpb/Tmivoaz3wPzP1L1CfP
fulvnw+R85Knv30+iPoaz3z2+STqk2e/ffC3z//Iecn3wd8+/0V9jR9APvv+
IeqTZ7/071SuB42nv32/E/U1nvmMfULUJ89+NX8tL3nNXzu+5JlPO7+Vefn8
VLt+tfOjrV+Nb0Y+bf1q55f+F6u8P5On/0XcP6iv8cz3CPcv6pNnv5fg31Xl
85f8Jfh34XqlvsY/Rr7xxX/qRH3y7Jf+x6O9X4k8/Y/j+U99jWe+rXj/oD55
9kv/TCZTO2vmWO6HiXnJ09/oTcn6dUlf45lvZGQkfmPBrKykT579mv2Q/BNX
74v2+0jk7f4K9Erv79TXeLN/8yWsl+D3A/XJs3/6Z/D7TMgr8vTP4PcZ9TWe
+b6Z90tRnzz7pf/ZKvc3yNP/LH5/U1/jme8Ofv9Tnzz7bYf/2yr3r8i3w/8t
9leor/EPkK8f+zvUJ89+6d9Q5f4kefo3YP+M+hrPfGuwf0d98uyX/p3K9aDx
9Lfvd6K+xjOfMU6I+o7/A97w0mI=
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[
     LineBox[{{{56.421974580955585`, -25.}, {
       52.75044883428478, -16.666666666666668`}, {
       50.67375799589205, -8.333333333333336}, {
       49.99999999999999, -3.552713678800501*^-15}, {50.67375799589205, 
       8.333333333333329}, {52.750448834284775`, 16.666666666666657`}, {
       56.42197458095558, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.421974580955585`, -25.}}, {{56.421974580955585`, 0.}, {
       52.75044883428478, 0.}, {50.67375799589205, 0.}, {49.99999999999999, 
       0.}, {50.67375799589205, 0.}, {52.750448834284775`, 0.}, {
       56.42197458095558, 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
       60., 0.}, {60., 0.}, {60., 0.}, {56.421974580955585`, 0.}}, {{
       75., -25.}, {75., -16.666666666666668`}, {75., -8.333333333333336}, {
       75., -3.552713678800501*^-15}, {75., 8.333333333333329}, {75., 
       16.666666666666657`}, {75., 24.999999999999993`}, {80., 25.}, {80., 
       16.666666666666668`}, {80., 8.333333333333336}, {80., 
       3.552713678800501*^-15}, {80., -8.333333333333329}, {
       80., -16.666666666666657`}, {80., -24.999999999999993`}, {
       75., -25.}}, {{75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {75., 0.}, {
       75., 0.}, {75., 0.}, {80., 0.}, {80., 0.}, {80., 0.}, {80., 0.}, {80., 
       0.}, {80., 0.}, {80., 0.}, {75., 0.}}, {{56.421974580955585`, 25.}, {
       60., 25.}, {60., 24.148145657226706`}, {56.421974580955585`, 
       24.148145657226706`}, {56.421974580955585`, 25.}}, {{
       56.421974580955585`, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.421974580955585`, 
       21.65063509461097}, {56.421974580955585`, 24.148145657226706`}}, {{
       56.421974580955585`, 21.65063509461097}, {60., 21.65063509461097}, {
       60., 17.67766952966369}, {56.421974580955585`, 17.67766952966369}, {
       56.421974580955585`, 21.65063509461097}}, {{56.421974580955585`, 
       17.67766952966369}, {60., 17.67766952966369}, {60., 
       12.500000000000004`}, {56.421974580955585`, 12.500000000000004`}, {
       56.421974580955585`, 17.67766952966369}}, {{56.421974580955585`, 
       12.500000000000004`}, {60., 12.500000000000004`}, {60., 
       6.470476127563024}, {56.421974580955585`, 6.470476127563024}, {
       56.421974580955585`, 12.500000000000004`}}, {{56.421974580955585`, 
       6.470476127563024}, {60., 6.470476127563024}, {60., 
       7.0819236220599744`*^-15}, {56.421974580955585`, 
       7.0819236220599744`*^-15}, {56.421974580955585`, 
       6.470476127563024}}, {{56.421974580955585`, 
       1.5308084989341915`*^-15}, {60., 1.5308084989341915`*^-15}, {
       60., -6.470476127563016}, {56.421974580955585`, -6.470476127563016}, {
       56.421974580955585`, 1.5308084989341915`*^-15}}, {{
       56.421974580955585`, -6.470476127563016}, {60., -6.470476127563016}, {
       60., -12.499999999999995`}, {
       56.421974580955585`, -12.499999999999995`}, {
       56.421974580955585`, -6.470476127563016}}, {{
       56.421974580955585`, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.421974580955585`, -17.677669529663685`}, {
       56.421974580955585`, -12.499999999999995`}}, {{
       56.421974580955585`, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.421974580955585`, -21.65063509461097}, {
       56.421974580955585`, -17.677669529663685`}}, {{
       56.42197458095559, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.421974580955585`, -24.148145657226706`}, {
       56.42197458095559, -21.650635094610962`}}, {{
       56.421974580955585`, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.421974580955585`, -25.}, {
       56.421974580955585`, -24.148145657226706`}}, {{
       56.421974580955585`, -25.}, {60., -25.}, {60., -24.148145657226706`}, {
       56.421974580955585`, -24.148145657226706`}, {
       56.421974580955585`, -25.}}, {{
       56.421974580955585`, -24.14814565722671}, {60., -24.14814565722671}, {
       60., -21.65063509461097}, {56.421974580955585`, -21.65063509461097}, {
       56.421974580955585`, -24.14814565722671}}, {{
       56.421974580955585`, -21.65063509461097}, {60., -21.65063509461097}, {
       60., -17.677669529663692`}, {
       56.421974580955585`, -17.677669529663692`}, {
       56.421974580955585`, -21.65063509461097}}, {{
       56.421974580955585`, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.421974580955585`, -12.50000000000001}, {
       56.421974580955585`, -17.677669529663696`}}, {{
       56.421974580955585`, -12.50000000000001}, {60., -12.50000000000001}, {
       60., -6.470476127563038}, {56.421974580955585`, -6.470476127563038}, {
       56.421974580955585`, -12.50000000000001}}, {{
       56.421974580955585`, -6.470476127563038}, {60., -6.470476127563038}, {
       60., -2.6796885989305705`*^-14}, {
       56.421974580955585`, -2.6796885989305705`*^-14}, {
       56.421974580955585`, -6.470476127563038}}, {{
       56.421974580955585`, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.421974580955585`, 6.470476127563007}, {
       56.421974580955585`, -4.592425496802574*^-15}}, {{56.421974580955585`, 
       6.470476127563007}, {60., 6.470476127563007}, {60., 
       12.499999999999984`}, {56.421974580955585`, 12.499999999999984`}, {
       56.421974580955585`, 6.470476127563007}}, {{56.421974580955585`, 
       12.499999999999984`}, {60., 12.499999999999984`}, {60., 
       17.67766952966367}, {56.42197458095559, 17.67766952966367}, {
       56.421974580955585`, 12.499999999999984`}}, {{56.421974580955585`, 
       17.677669529663685`}, {60., 17.677669529663685`}, {60., 
       21.65063509461096}, {56.421974580955585`, 21.65063509461096}, {
       56.421974580955585`, 17.677669529663685`}}, {{56.421974580955585`, 
       21.65063509461096}, {60., 21.65063509461096}, {60., 
       24.148145657226703`}, {56.421974580955585`, 24.148145657226703`}, {
       56.421974580955585`, 21.65063509461096}}, {{56.421974580955585`, 
       24.148145657226703`}, {60., 24.148145657226703`}, {60., 25.}, {
       56.421974580955585`, 25.}, {56.421974580955585`, 
       24.148145657226703`}}, CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQYHghwgDEsHGN/j6ob7b1Qt4Pxnv1tYJywzhfN3
pAkfqF5rCOdDzNKE8913ldYdeSgJ558+f3797Mm3bWB8O4j8ARj/738Q0IDz
t0PMh/OfQOyH86Hug/Oh7ofzPdHkn6Hp34VmPhvE/XB+OJr7bty+fXjLui97
YHwTNP99h7gfzt+OFj6P0cLPHS18YeEPAFhNgg8=
       "], CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQEhDhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AoKBvgQ==
       "], {{75., 25.}, {80., 25.}, {
       80., 24.148145657226706`}, {75., 24.148145657226706`}, {75., 25.}}, {{
       75., 24.148145657226706`}, {80., 24.148145657226706`}, {80., 
       21.65063509461097}, {75., 21.65063509461097}, {75., 
       24.148145657226706`}}, {{75., 21.65063509461097}, {80., 
       21.65063509461097}, {80., 17.67766952966369}, {75., 
       17.67766952966369}, {75., 21.65063509461097}}, {{75., 
       17.67766952966369}, {80., 17.67766952966369}, {80., 
       12.500000000000004`}, {75., 12.500000000000004`}, {75., 
       17.67766952966369}}, {{75., 12.500000000000004`}, {80., 
       12.500000000000004`}, {80., 6.470476127563024}, {75., 
       6.470476127563024}, {75., 12.500000000000004`}}, {{75., 
       6.470476127563024}, {80., 6.470476127563024}, {80., 
       7.0819236220599744`*^-15}, {75., 7.0819236220599744`*^-15}, {75., 
       6.470476127563024}}, {{75., 1.5308084989341915`*^-15}, {80., 
       1.5308084989341915`*^-15}, {80., -6.470476127563016}, {
       75., -6.470476127563016}, {75., 1.5308084989341915`*^-15}}, {{
       75., -6.470476127563016}, {80., -6.470476127563016}, {
       80., -12.499999999999995`}, {75., -12.499999999999995`}, {
       75., -6.470476127563016}}, {{75., -12.499999999999995`}, {
       80., -12.499999999999995`}, {80., -17.677669529663685`}, {
       75., -17.677669529663685`}, {75., -12.499999999999995`}}, {{
       75., -17.677669529663685`}, {80., -17.677669529663685`}, {
       80., -21.65063509461097}, {75., -21.65063509461097}, {
       75., -17.677669529663685`}}, {{75., -21.650635094610962`}, {
       80., -21.650635094610962`}, {80., -24.148145657226706`}, {
       75., -24.148145657226706`}, {75., -21.650635094610962`}}, {{
       75., -24.148145657226706`}, {80., -24.148145657226706`}, {80., -25.}, {
       75., -25.}, {75., -24.148145657226706`}}, {{75., -25.}, {80., -25.}, {
       80., -24.148145657226706`}, {75., -24.148145657226706`}, {
       75., -25.}}, {{75., -24.14814565722671}, {80., -24.14814565722671}, {
       80., -21.65063509461097}, {75., -21.65063509461097}, {
       75., -24.14814565722671}}, {{75., -21.65063509461097}, {
       80., -21.65063509461097}, {80., -17.677669529663692`}, {
       75., -17.677669529663692`}, {75., -21.65063509461097}}, {{
       75., -17.677669529663696`}, {80., -17.677669529663696`}, {
       80., -12.50000000000001}, {75., -12.50000000000001}, {
       75., -17.677669529663696`}}, {{75., -12.50000000000001}, {
       80., -12.50000000000001}, {80., -6.470476127563038}, {
       75., -6.470476127563038}, {75., -12.50000000000001}}, {{
       75., -6.470476127563038}, {80., -6.470476127563038}, {
       80., -2.6796885989305705`*^-14}, {75., -2.6796885989305705`*^-14}, {
       75., -6.470476127563038}}, {{75., -4.592425496802574*^-15}, {
       80., -4.592425496802574*^-15}, {80., 6.470476127563007}, {75., 
       6.470476127563007}, {75., -4.592425496802574*^-15}}, {{75., 
       6.470476127563007}, {80., 6.470476127563007}, {80., 
       12.499999999999984`}, {75., 12.499999999999984`}, {75., 
       6.470476127563007}}, {{75., 12.499999999999984`}, {80., 
       12.499999999999984`}, {80., 17.67766952966367}, {75., 
       17.67766952966367}, {75., 12.499999999999984`}}, {{75., 
       17.677669529663685`}, {80., 17.677669529663685`}, {80., 
       21.65063509461096}, {75., 21.65063509461096}, {75., 
       17.677669529663685`}}, {{75., 21.65063509461096}, {80., 
       21.65063509461096}, {80., 24.148145657226703`}, {75., 
       24.148145657226703`}, {75., 21.65063509461096}}, {{75., 
       24.148145657226703`}, {80., 24.148145657226703`}, {80., 25.}, {75., 
       25.}, {75., 24.148145657226703`}}}],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIFIBwjt6YDGP0CAj64eh34YwMUnZB9O/Q4E
+ETqJ+QfQvYRCh9C7iM6fA9g14/TPQ4AY+ki2A==
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmVmYGAQAmImKEYBDWYHeP9e+ak40dsBxkdXwggmPR3QxaHqHdD0
o/Oh5vk5lDqsrVTcYXoAu3l+cD66eWj60fkQ8w8EOZzKYHYVZjA6gG4eTB7d
PhTzEPrR+XDzbJQ2K3BN0DmAyzx0+1DMQ+hH5x/41BUX+vKip0N066x2z4ea
2N2PJbxg5qHpR+cfgOn4HJhw6eFVRQfs5iEAunlo+g8AAAmUdT8=
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], 
     PointBox[{{55.13384936237171, -22.5}, {50.00000000000001, 0.}, {
      55.13384936237171, 22.5}, {60., -21.719260792539405`}, {60., 0.}, {60., 
      21.719260792539405`}, {75., -18.000294030506474`}, {75., 0.}, {75., 
      18.000294030506474`}, {60., -14.28132726847354}, {60., 0.}, {60., 
      14.28132726847354}, {51.63993327251764, -12.940014112102906`}, {50., 
      0.}, {51.63993327251764, 12.940014112102906`}, {0., 8.91773850847037}, {
      0., 0.}, {0., -8.91773850847037}}]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367613478372*^9, 3.566087063758762*^9, 
  3.566101853247958*^9, 3.566139306135825*^9, 3.614707885212973*^9},
 CellTags->{"Resonate", "RG18."},
 CellLabel->
  "During evaluation of \
In[81]:=",ExpressionUUID->"89ed0fca-2e01-49aa-b26c-a77ffe90711d"]
}, Open  ]],

Cell[TextData[{
 "You can learn more about ",
 StyleBox["Resonate", "Input"],
 " and non-sequential tracing in ",
 ButtonBox["Section 3.3",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"3.3"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide."
}], "Text",
 CellTags->{
  "Resonate", "RG18."},ExpressionUUID->"8f92118e-8f6c-40ba-8b88-df844e2ec576"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"531e7d13-ed42-4ebb-\
9a61-a12438db75a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "19. ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s Database"
}], "Section",
 CellTags->{
  "Database", "19.", 
   "RG19."},ExpressionUUID->"2ad8be42-a103-45bc-b5e7-11647de00c94"],

Cell[TextData[{
 StyleBox["Optica",
  FontSlant->"Italic"],
 " now supports a database system that contains information on a wide variety \
of optical materials and components. These items represent the manufactured \
products of many different companies. This information is initially stored on \
the computer's hard disk, but once loaded, the entire database contents is \
held in the computer's memory. ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database is not initially loaded into the computer's memory until it is \
accessed for the first time. After this point, all of the database contents \
stay in the computer's memory for the remaining duration of the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " session. ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has a suite of functions for managing the database information. The most \
important are: ",
 StyleBox["DataToOptica", "Input"],
 ", ",
 StyleBox["SearchData", "Input"],
 ", and ",
 StyleBox["ReadData", "Input"],
 ". (For the full listing of database-related functions, see ",
 ButtonBox["Section 5.2",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"Data Handling 5.2"],
 " of the Principles of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " Guide.)"
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"320ecd25-a05c-4d82-a030-825895be5acc"],

Cell[TextData[{
 StyleBox["DataToOptica[", "Input"],
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is used to build models in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " of optical components, light sources, coatings, and materials from the \
information given in databaselist. ",
 StyleBox["DataToOptica", "Input"],
 " first calls ",
 StyleBox["SearchData", "Input"],
 " to select for specific data items.\n\n",
 StyleBox["SearchData[", "Input"],
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " uses the internally loaded catalog database to give a selected listing of \
catalog entries.\n\n",
 StyleBox["ReadData[", "Input"],
 StyleBox["parameters",
  FontSlant->"Italic"],
 ", ",
 StyleBox["selectionproperties",
  FontSlant->"Italic"],
 ", ",
 StyleBox["options",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " uses the internally loaded database to give a selected listing of the \
specified data-related parameters."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"f62bd2bd-7199-4214-9b20-7dd6e400011e"],

Cell[TextData[{
 "Of these three functions, ",
 StyleBox["DataToOptica", "Input"],
 " operates at the highest level and converts the database information into a \
functioning optical component or material model for use with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". ",
 StyleBox["DataToOptica", "Input"],
 ", however, usually retrieves only a single item from the database listing. \
Very often, therefore, you will want to use ",
 StyleBox["SearchData", "Input"],
 " and ",
 StyleBox["ReadData", "Input"],
 " first, to survey which of the neighboring database items also have a close \
match to your specifications, in order to make the best choice for ",
 StyleBox["DataToOptica", "Input"],
 "."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"5f9a3aef-feca-426c-93d6-6be218e4b1f3"],

Cell[TextData[{
 "In essence, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database contains an array of information that is stored in the form of \
lists of rules. Each rule describes a particular data attribute, given by ",
 StyleBox["parametername->value",
  FontSlant->"Italic"],
 ". As an example, the following database entry describes the BK7 optical \
glass."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"63bb1f15-1c8d-4b3b-97b4-013c42c4f946"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SearchData[OpticalMedium -> BK7]", "Input"]], "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[82]:=",ExpressionUUID->"c6e33c49-eca9-475d-8690-8d1296cfea33"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"AcidResistance", "\[Rule]", "1.`"}], ",", 
    RowBox[{"AlkaliResistance", "\[Rule]", "2.`"}], ",", 
    RowBox[{"BubbleClass", "\[Rule]", "0"}], ",", 
    RowBox[{"ClimaticResistance", "\[Rule]", "2"}], ",", 
    RowBox[{"ColorCode", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"330", ",", "300"}], "}"}]}], ",", 
    RowBox[{"CompanyName", "\[Rule]", "\<\"Schott\"\>"}], ",", 
    RowBox[{"ComponentLabel", "\[Rule]", "\<\"glass\"\>"}], ",", 
    RowBox[{"Date", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
    RowBox[{"Dispersion", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1.5168`", ",", "64.16999999999997`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"63.95999999999999`", ",", "0.`"}], "}"}], ",", "0.008054`", 
       ",", "0.00811`"}], "}"}]}], ",", 
    RowBox[{"ElasticModulus", "\[Rule]", "81999.99999999997`"}], ",", 
    RowBox[{"FileName", "\[Rule]", "\<\"Schott.m\"\>"}], ",", 
    RowBox[{"GlassCodeNumber", "\[Rule]", "517642"}], ",", 
    RowBox[{"IndexCoefficients", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "1.03961212`", ",", "0.231792344`", ",", "1.01046945`", ",", 
       "0.0060006987`", ",", "0.0200179144`", ",", "103.560653`"}], "}"}]}], 
    ",", 
    RowBox[{"InternalTransmittance", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2325.`", ",", "0.0976501`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1960.`", ",", "0.0282324`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1530.`", ",", "0.0026255`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1060.`", ",", "0.0003478`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"700.`", ",", "0.0003478`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"659.9999999999995`", ",", "0.0005219`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"620.`", ",", "0.0005219`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"579.9999999999998`", ",", "0.0006963`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"545.9999999999999`", ",", "0.0006963`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"500.`", ",", "0.0006963`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"459.9999999999996`", ",", "0.0010454`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"436.`", ",", "0.0010454`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"420.`", ",", "0.0012203`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"404.9999999999998`", ",", "0.0012203`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"400.`", ",", "0.0015705`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"390.`", ",", "0.0019215`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"379.9999999999998`", ",", "0.0035096`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"370.`", ",", "0.0045764`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"364.99999999999966`", ",", "0.0054705`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"350.`", ",", "0.0126068`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"333.9999999999997`", ",", "0.0454037`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"320.`", ",", "0.1823728`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"310.`", ",", "0.4619608`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"300.`", ",", "0.6091515`"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"KnoopHardness", "\[Rule]", "609.9999999999995`"}], ",", 
    RowBox[{"MassDensity", "\[Rule]", "2.51`"}], ",", 
    RowBox[{"OpticaFunction", "\[Rule]", "SellmeierFunction"}], ",", 
    RowBox[{"OpticalMedium", "\[Rule]", "BK7"}], ",", 
    RowBox[{"PhosphateResistance", "\[Rule]", "2.3`"}], ",", 
    RowBox[{"PoissonRatio", "\[Rule]", "0.206`"}], ",", 
    RowBox[{"SpecificHeat", "\[Rule]", "8.58`*^6"}], ",", 
    RowBox[{"SpectralIndex", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"none", ",", "2325.4`", ",", "1.48921`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"none", ",", "1970.1`", ",", "1.49495`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"none", ",", "1529.599999999998`", ",", "1.50091`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"none", ",", "1060.`", ",", "1.50669`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "1014.`", ",", "1.50731`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", "852.1`", ",", "1.5098`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "706.5`", ",", "1.51289`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"C", ",", "656.3`", ",", "1.51432`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Cprime", ",", "643.8`", ",", "1.51472`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"HeNe", ",", "632.8`", ",", "1.51509`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"D", ",", "589.2999999999998`", ",", "1.51673`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", "587.6`", ",", "1.5168`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"e", ",", "546.1`", ",", "1.51872`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"F", ",", "486.0999999999997`", ",", "1.52238`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"Fprime", ",", "479.9999999999998`", ",", "1.52283`"}], "}"}],
        ",", 
       RowBox[{"{", 
        RowBox[{"g", ",", "435.7999999999996`", ",", "1.52668`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"h", ",", "404.6999999999998`", ",", "1.53024`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "364.99999999999966`", ",", "1.53627`"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"none", ",", "334.1`", ",", "1.54272`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"none", ",", "312.6`", ",", "1.54862`"}], "}"}]}], "}"}]}], 
    ",", 
    RowBox[{"StainResistance", "\[Rule]", "0"}], ",", 
    RowBox[{"TemperatureCoefficientIndex", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1.86`*^-6", ",", "1.31`*^-8", ",", 
       RowBox[{"-", "1.37`*^-11"}], ",", "4.34`*^-7", ",", "6.27`*^-10", ",", 
       "0.17`"}], "}"}]}], ",", 
    RowBox[{"ThermalConductivity", "\[Rule]", "1114.`"}], ",", 
    RowBox[{"ThermalExpansion", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "30"}], ",", "70", ",", 
         RowBox[{"{", "7.1`*^-6", "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"20", ",", "300", ",", 
         RowBox[{"{", "8.3`*^-6", "}"}]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"TransformationTemperature", "\[Rule]", "557.`"}], ",", 
    RowBox[{"ViscousTemperature1", "\[Rule]", "557.`"}], ",", 
    RowBox[{"ViscousTemperature2", "\[Rule]", "719.`"}], ",", 
    RowBox[{"WaveLengthRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0.3`", ",", "2.325`"}], "}"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.563367613728681*^9, 3.566087064031275*^9, 
  3.566101853623686*^9, 3.566139307091462*^9, 3.614707885387542*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[82]=",ExpressionUUID->"071c5fc1-692c-44bc-b0de-d41e4f3dded6"]
}, Open  ]],

Cell[TextData[{
 "In this entry, all of these listed rules describe some aspect of the BK7 \
glass material. ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database is made up of thousands of entries that are formatted in the \
same fashion. In order to get an item from the database, you must specify one \
or more of the properties that you require. In this example, we had specified \
",
 StyleBox["OpticalMedium -> BK7", "Input"],
 " to recover the database entry for BK7 glass. When you first begin to use \
",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database, you will need to have some idea of the information that you \
are searching for. In particular, you must decide whether you are searching \
for a particular type of optical component or optical glass, for example. The \
problem is that ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database can contain many different types of information for each \
database entry. In order to gain a listing of all database ",
 StyleBox["parameternames",
  FontSlant->"Italic"],
 " that are available, you can call ",
 StyleBox["SearchData[]", "Input"],
 " without specification:"
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"cae6081d-4799-4ecd-8bff-afa8022ea3e3"],

Cell[CellGroupData[{

Cell["SearchData[]", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[83]:=",ExpressionUUID->"eb683a7c-4ae2-4920-870b-9af074c17cfb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "A", ",", "AcidResistance", ",", "AlkaliResistance", ",", "AngleTolerance", 
   ",", "BackFocalLength", ",", "Baffled", ",", "BubbleClass", ",", 
   "CatalogFocalLength", ",", "CatalogNumber", ",", "Centered", ",", 
   "CenterThickness", ",", "ClearAperture", ",", "ClimaticResistance", ",", 
   "ColorCode", ",", "CompanyAddress", ",", "CompanyName", ",", 
   "ComponentBoundary", ",", "ComponentLabel", ",", "ComponentMedium", ",", 
   "Country", ",", "CurvatureTolerance", ",", "D", ",", "DataComments", ",", 
   "DataSource", ",", "Date", ",", "DefaultAngleSetting", ",", 
   "DesignRefractiveIndex", ",", "DesignWaveLength", ",", 
   "DiffractionLimitedRange", ",", "DimensionalTolerance", ",", "Dispersion", 
   ",", "EdgeThickness", ",", "ElasticModulus", ",", "EntrancePupilDiameter", 
   ",", "EquivalentMagnification", ",", "EvenFunction", ",", "FaxNumber", ",",
    "FieldOfView", ",", "FieldStopLocation", ",", "FileName", ",", 
   "FlatSubstrate", ",", "FNumber", ",", "FocalLength", ",", 
   "FrontFocalLength", ",", "FullForm", ",", "GlassCatalogs", ",", 
   "GlassCodeNumber", ",", "Hole", ",", "HousingBoundary", ",", 
   "IndexCoefficients", ",", "InputEdgeThickness", ",", 
   "InternalTransmittance", ",", "KnoopHardness", ",", "Magnification", ",", 
   "MassDensity", ",", "MeltingPoint", ",", "Mirrored", ",", "ModelIntensity",
    ",", "NA", ",", "NumberElements", ",", "NumberOfElementGroups", ",", 
   "NumberOfSurfaces", ",", "OffAxis", ",", "OpticaFunction", ",", 
   "OpticalMedium", ",", "OpticaVersion", ",", "PhosphateResistance", ",", 
   "PoissonRatio", ",", "PrinciplePointSeparation", ",", "RadiusOfCurvature", 
   ",", "ReferenceWaveLengthNumber", ",", "Reflectance", ",", 
   "RefractiveIndex", ",", "SAY", ",", "ScratchDig", ",", "Solubility", ",", 
   "SpecificHeat", ",", "SpectralIndex", ",", "SplitRays", ",", 
   "StainResistance", ",", "StopPosition", ",", "SurfaceAccuracy", ",", 
   "SurfaceBoundary", ",", "SurfaceCoating", ",", "SurfaceCurvature", ",", 
   "SurfaceFunction", ",", "SurfaceLabel", ",", "SurfaceSeparation", ",", 
   "SurfaceShape", ",", "SurfaceValue", ",", "TelephoneNumber", ",", 
   "TemperatureCoefficientIndex", ",", "ThermalConductivity", ",", 
   "ThermalExpansion", ",", "ThicknessTolerance", ",", 
   "TransformationTemperature", ",", "TransmissionRange", ",", 
   "Transmittance", ",", "Units", ",", "V1H1", ",", "V2H2", ",", 
   "ViscousTemperature1", ",", "ViscousTemperature2", ",", 
   "WaveFrontFlatness", ",", "WaveLengthRange", ",", "WebSiteAddress", ",", 
   "WindowParameters", ",", "WorkingDistance"}], "}"}]], "Output",
 CellChangeTimes->{3.563367614239121*^9, 3.56608706418156*^9, 
  3.566101853921604*^9, 3.5661393080491743`*^9, 3.614707885626852*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[83]=",ExpressionUUID->"ee141b33-8d36-4733-b715-5e5c09ae6fe6"]
}, Open  ]],

Cell[TextData[{
 "Of these many ",
 StyleBox["parameternames",
  FontSlant->"Italic"],
 ", only a few are really useful for conducting searches. The most useful ",
 StyleBox["parameternames",
  FontSlant->"Italic"],
 " include ",
 StyleBox["CatalogNumber", "Input"],
 ", ",
 StyleBox["ComponentBoundary", "Input"],
 ", ",
 StyleBox["CompanyName", "Input"],
 ", ",
 StyleBox["FocalLength", "Input"],
 ", ",
 StyleBox["OpticaFunction", "Input"],
 ", and ",
 StyleBox["OpticalMedium", "Input"],
 ". These are defined below."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"80f30a0e-4f8b-4c98-ab07-102c54d63d5f"],

Cell[TextData[{
 StyleBox["CatalogNumber -> ", "Input"],
 StyleBox["string",
  FontSlant->"Italic"],
 " specifies the catalog identification number for a component.",
 StyleBox["\nComponentBoundary -> ", "Input"],
 StyleBox["boundary",
  FontSlant->"Italic"],
 " specifies the entrance dimensions for a lens and the overall dimensions \
for a prism.\n",
 StyleBox["CompanyName -> ", "Input"],
 StyleBox["name",
  FontSlant->"Italic"],
 " gives the name of a component manufacturer.\n",
 StyleBox["FocalLength -> ", "Input"],
 StyleBox["focallength",
  FontSlant->"Italic"],
 " specifies the effective focal length of a lens.\n",
 StyleBox["OpticaFunction -> ", "Input"],
 StyleBox["functionhead",
  FontSlant->"Italic"],
 " specifies the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " function used to create a model representation of the database item in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ".\n",
 StyleBox["OpticalMedium -> ", "Input"],
 StyleBox["symbol",
  FontSlant->"Italic"],
 " identifies the optical material medium traversed by each ray segment."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "Plot2D", "Database", 
   "RG19."},ExpressionUUID->"3c2399ec-fba3-40b1-99e9-e62ae314b455"],

Cell["Some important database parameters.", "Commentary",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"fff5d2ab-950e-4d33-b925-b247ae539596"],

Cell[TextData[{
 "Of these different database parameters, the ",
 StyleBox["OpticaFunction", "Input"],
 " is of particular importance because it declares the purpose of the \
database entry to ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". As such, every database entry usually contains ",
 StyleBox["OpticaFunction", "Input"],
 " as a ",
 StyleBox["parametername",
  FontSlant->"Italic"],
 ". We can use ",
 StyleBox["ReadData", "Input"],
 " with ",
 StyleBox["OpticaFunction", "Input"],
 " to list the declared types of database entries that are present in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"a9b043b8-f5ec-4fde-aaa6-6f19e94a2bd2"],

Cell[CellGroupData[{

Cell[TextData[{
 "ReadData[",
 StyleBox["OpticaFunction", "Input"],
 ", ReportedInterval->All, Union -> True]"
}], "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[84]:=",ExpressionUUID->"f6a296c6-c0a2-4830-810f-ef9a52a1baf7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "AnamorphicPrisms", ",", "AsphericLens", ",", "BallLens", ",", 
   "BeamSplitter", ",", "BeamSplitterCube", ",", "BiConcaveLens", ",", 
   "BiConvexLens", ",", "CompoundLens", ",", "CustomMirror", ",", 
   "CylindricalLens", ",", "DirectVisionPrism", ",", "DovePrism", ",", 
   "FresnelRhomb", ",", "HerzbergerFunction", ",", "HollowCornerCube", ",", 
   "IndexFunction", ",", "IndexInterpolationFunction", ",", 
   "JonesMatrixOptic", ",", "LensDoublet", ",", "LensTriplet", ",", 
   "LinearPolarizer", ",", "Mirror", ",", "ModelRefractiveIndex", ",", 
   "ParabolicMirror", ",", "PechanPrism", ",", "PentaPrism", ",", 
   "PlanoConcaveCylindricalLens", ",", "PlanoConcaveLens", ",", 
   "PlanoConvexCylindricalLens", ",", "PlanoConvexLens", ",", 
   "PolarizingBeamSplitterCube", ",", "PorroPrism", ",", "Prism", ",", 
   "RetardationPlate", ",", "ReversionPrism", ",", "RhomboidPrism", ",", 
   "RoofPrism", ",", "SellmeierFunction", ",", "SolidCornerCube", ",", 
   "SphericalLens", ",", "SphericalMirror", ",", "WedgeBeamSplitter", ",", 
   "WedgePrism", ",", "Window", ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.56336761435133*^9, 3.566087064258288*^9, 
  3.566101854261524*^9, 3.566139313110609*^9, 3.614707885734189*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[84]=",ExpressionUUID->"45a7ee28-fa3e-4b6a-a4ef-38c7acfefa88"]
}, Open  ]],

Cell[TextData[{
 "Here, we used ",
 StyleBox["ReportedInterval -> All", "Input"],
 " to retain all of the valid elements from the database search. (Otherwise, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " truncates the search result to the first 1000 elements.) The ",
 StyleBox["Union -> True", "Input"],
 " option is then used to generate a logical union of the results. From this, \
we see that most of the database items are used with component function \
entries, such as ",
 StyleBox["PlanoConvexLens", "Input"],
 ", ",
 StyleBox["Prism", "Input"],
 ", and ",
 StyleBox["Mirror", "Input"],
 ". The remaining items, such as ",
 StyleBox["IndexFunction", "Input"],
 ", are used with optical material entries. When you wish to search for a \
particular optical component, often a good starting point is to use the \
official name of the component function in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", such as ",
 StyleBox["PlanoConvexLens", "Input"],
 ". You can then use ",
 StyleBox["SearchData", "Input"],
 " to do a search for this name to discover which other attributes are listed \
with it. You can then narrow your search further with some of these \
attributes. It is good idea to first limit the total number of reported \
elements with ",
 StyleBox["ReportedInterval", "Input"],
 ". Otherwise, the reported number of entries can be overwhelming. Here is a \
description of ",
 StyleBox["ReportedInterval", "Input"],
 "."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"fe197e53-825d-43bd-a771-59588321771f"],

Cell[TextData[{
 StyleBox["ReportedInterval", "Input"],
 " is an option that restricts the total number of items getting reported by \
a function."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->{
  "ReportedInterval", "Database", 
   "RG19."},ExpressionUUID->"8267d24e-83d6-4a31-a9ba-c281cfb392d2"],

Cell[TextData[{
 "In general, ",
 StyleBox["ReportedInterval", "Input"],
 " can take several different formats. ",
 StyleBox["ReportedInterval -> ", "Input"],
 StyleBox["reportednumber",
  FontSlant->"Italic"],
 " indicates an upper limit to the number of items getting reported. ",
 StyleBox["ReportedInterval -> {", "Input"],
 "startnumber, endnumber",
 StyleBox["}", "Input"],
 " gives both lower and upper bounds to the number of items getting reported. \
",
 StyleBox["ReportedInterval -> Interval[", "Input"],
 "{min, max}",
 StyleBox["]", "Input"],
 " can also be used. In the next example, we use ",
 StyleBox["ReportedInterval->3", "Input"],
 " to limit the length of the result to 3 elements. In this particular \
search, we will use ",
 StyleBox["PlanoConvexLens", "Input"],
 " to seek out database entries that relate to plano-convex lenses."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"4a8f756b-f7ad-431a-8619-9ad2af5c1d54"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["SearchData[PlanoConvexLens, ReportedInterval->3]", \
"Input"]], "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[85]:=",ExpressionUUID->"a58dda43-82da-49df-9870-1d174d20e15e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"34-2949\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "3.4`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"Coherent-Ealing\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "12.7`"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"plano-convex lens\"\>"}], ",", 
     
     RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.45843123806879`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.5876`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"CoherentEaling.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "25.36999999999999`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"11.63`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12.7`", ",", "12.7`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"3.4`", ",", "0"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"34-2964\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "2.7`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"Coherent-Ealing\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "12.7`"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"plano-convex lens\"\>"}], ",", 
     
     RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.45843123806879`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.5876`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"CoherentEaling.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "38.06`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"17.44999999999998`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"12.7`", ",", "12.7`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2.7`", ",", "0"}], "}"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"34-2972\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "7.`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"Coherent-Ealing\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "25.4`"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"plano-convex lens\"\>"}], ",", 
     
     RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.45843123806879`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.5876`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"CoherentEaling.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "38.06`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"17.44999999999998`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"25.4`", ",", "25.4`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"7.`", ",", "0"}], "}"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5633676146916103`*^9, 3.566087064375312*^9, 
  3.5661018544932423`*^9, 3.566139313787506*^9, 3.6147078858850718`*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[85]=",ExpressionUUID->"d8592e33-4ed9-48fa-8902-17393762762e"]
}, Open  ]],

Cell[TextData[{
 "In general, you can use many different formats for conducting a search in \
the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database. Such formats include: strings, rules, lists of numbers, and \
symbols. In this past example, we have searched for the ",
 StyleBox["PlanoConvexLens", "Input"],
 " symbol. We could have instead searched for ",
 StyleBox["OpticaFunction -> PlanoConvexLens", "Input"],
 ". However, this turns out to be unnecessary since ",
 StyleBox["PlanoConvexLens", "Input"],
 " is only used with the ",
 StyleBox["OpticaFunction", "Input"],
 " in the database. From this result, we can see that there are about 15 \
separate ",
 StyleBox["parametername",
  FontSlant->"Italic"],
 "s available for the ",
 StyleBox["PlanoConvexLens", "Input"],
 " entry. We can now decide on the top 2 or 3 most important ",
 StyleBox["parameternames",
  FontSlant->"Italic"],
 " for a more specialized search. For example, we can search for specific \
values of ",
 StyleBox["ComponentBoundary", "Input"],
 " and ",
 StyleBox["FocalLength", "Input"],
 ":"
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"68ffe976-6bf7-4c62-894d-ffb512688a4b"],

Cell[CellGroupData[{

Cell["\<\
SearchData[PlanoConvexLens, ComponentBoundary->50, FocalLength->65]\
\>", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[86]:=",ExpressionUUID->"3ac515bc-d8ce-4f77-83a8-d8ca5a9f623f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"BackFocalLength", "\[Rule]", "53.89999999999997`"}], ",", 
    RowBox[{"CatalogFocalLength", "\[Rule]", "65.`"}], ",", 
    RowBox[{"CatalogNumber", "\[Rule]", "\<\"FPX11700/000\"\>"}], ",", 
    RowBox[{"CenterThickness", "\[Rule]", "16.19999999999998`"}], ",", 
    RowBox[{"CompanyName", "\[Rule]", "JML"}], ",", 
    RowBox[{"ComponentBoundary", "\[Rule]", "50.`"}], ",", 
    RowBox[{"ComponentLabel", "\[Rule]", "\<\"PlanoConvexLens\"\>"}], ",", 
    RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
    RowBox[{"Date", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
    RowBox[{"DesignWaveLength", "\[Rule]", "587.6`"}], ",", 
    RowBox[{"EdgeThickness", "\[Rule]", "2.6`"}], ",", 
    RowBox[{"FileName", "\[Rule]", "\<\"JML.m\"\>"}], ",", 
    RowBox[{"FNumber", "\[Rule]", "1.3`"}], ",", 
    RowBox[{"FocalLength", "\[Rule]", "65.`"}], ",", 
    RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
    RowBox[{"RadiusOfCurvature", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"29.8`", ",", "\[Infinity]"}], "}"}]}], ",", 
    RowBox[{"SurfaceBoundary", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"50.`", ",", "50.`"}], "}"}]}], ",", 
    RowBox[{"SurfaceSeparation", "\[Rule]", 
     RowBox[{"{", "16.19999999999998`", "}"}]}], ",", 
    RowBox[{"V1H1", "\[Rule]", "0"}], ",", 
    RowBox[{"V2H2", "\[Rule]", 
     RowBox[{"-", "11.09999999999998`"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.563367615779566*^9, 3.56608706449631*^9, 
  3.566101854728229*^9, 3.566139314086906*^9, 3.614707886084239*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[86]=",ExpressionUUID->"0e8c1c8d-9eb9-41e0-82c9-cc8ebd31f04b"]
}, Open  ]],

Cell[TextData[{
 "In this particular case, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " has isolated a single database entry that perfectly matches the desired \
parameters. At this point, we can call ",
 StyleBox["DataToOptica", "Input"],
 " to create the chosen component in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"28e8b3b1-19f9-4ac0-bfd5-de2db6cf2ecc"],

Cell[CellGroupData[{

Cell["\<\
lens  = DataToOptica[PlanoConvexLens, ComponentBoundary->50, FocalLength->65]
ShowSystem[lens];\
\>", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[87]:=",ExpressionUUID->"8a9c311d-9b1b-4b3e-bbe8-f14f92da05ec"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"PlanoConvexLens", "[", 
     RowBox[{"65.`", ",", "50.`", ",", "16.19999999999998`", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
        RowBox[{"DesignWaveLength", "\[Rule]", "0.5876`"}]}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367616514786*^9, 3.566087064826823*^9, 
  3.566101855270857*^9, 3.5661393149713917`*^9, 3.6147078864917192`*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[87]=",ExpressionUUID->"61b98bbe-fb27-457b-910b-4bd19dcbdfa8"],

Cell[BoxData[
 Graphics3DBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     Polygon3DBox[{{13.583141632498673`, -25., 0.}, {16.19999999999998, -25., 
      6.123233995736766*^-15}, {16.19999999999998, -16.66666666666667, 
      5.102694996447306*^-15}, {5.096920329788624, -16.666666666666668`, 
      0.}, {13.583141632498673`, -25., 0.}}], 
     Polygon3DBox[{{5.096920329788624, -16.666666666666668`, 0.}, {
      16.19999999999998, -16.66666666666667, 5.102694996447306*^-15}, {
      16.19999999999998, -8.333333333333336, 4.0821559971578446`*^-15}, {
      1.1889728927704226`, -8.333333333333336, 0.}, {
      5.096920329788624, -16.666666666666668`, 0.}}], 
     Polygon3DBox[{{1.1889728927704226`, -8.333333333333336, 0.}, {
      16.19999999999998, -8.333333333333336, 4.0821559971578446`*^-15}, {
      16.19999999999998, -7.105427357601002*^-15, 3.061616997868384*^-15}, {
      0., 0., 0.}, {1.1889728927704226`, -8.333333333333336, 0.}}], 
     Polygon3DBox[{{0., 0., 0.}, {16.19999999999998, 0., 
      3.061616997868383*^-15}, {16.19999999999998, 8.333333333333332, 
      2.0410779985789223`*^-15}, {1.188972892770419, 8.333333333333329, 0.}, {
      0., 0., 0.}}], 
     Polygon3DBox[{{1.188972892770419, 8.333333333333329, 0.}, {
      16.19999999999998, 8.333333333333332, 2.0410779985789223`*^-15}, {
      16.19999999999998, 16.666666666666664`, 1.0205389992894613`*^-15}, {
      5.09692032978862, 16.666666666666664`, 0.}, {1.188972892770419, 
      8.333333333333329, 0.}}], 
     Polygon3DBox[{{5.09692032978862, 16.666666666666664`, 0.}, {
      16.19999999999998, 16.666666666666664`, 1.0205389992894615`*^-15}, {
      16.19999999999998, 24.999999999999996`, 5.098616525425841*^-31}, {
      13.583141632498663`, 24.999999999999993`, 0.}, {5.09692032978862, 
      16.666666666666664`, 0.}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbhdOyaqKXtwAAGlgcYoOAFp7WofbKIw+pVIGAA
Fz9QsaSAg+2z/RqwuAJcHBV82ANjbYCqXwFR7wATfwA1HyJuABeXg7rn338Q
sICL6xmDAEydJYb4ajRzYOJr0OxFNeeDDbr4CjR/oYobYIhD3QkXxxWeAF5/
Vo4=
       "]], 
      {GrayLevel[0.5], EdgeForm[None], 
       Polygon3DBox[{{13.583141632498673`, 0., -25.}, {16.19999999999998, 
        3.061616997868383*^-15, -25.}, {16.19999999999998, 
        2.551347498223653*^-15, -16.66666666666667}, {5.096920329788624, 
        5.102694996447305*^-16, -16.666666666666668`}, {13.583141632498673`, 
        0., -25.}}], 
       Polygon3DBox[{{5.096920329788624, 
        5.102694996447305*^-16, -16.666666666666668`}, {16.19999999999998, 
        2.551347498223653*^-15, -16.66666666666667}, {16.19999999999998, 
        2.0410779985789223`*^-15, -8.333333333333336}, {1.1889728927704226`, 
        1.020538999289461*^-15, -8.333333333333336}, {5.096920329788624, 
        5.102694996447305*^-16, -16.666666666666668`}}], 
       Polygon3DBox[{{1.1889728927704226`, 
        1.020538999289461*^-15, -8.333333333333336}, {16.19999999999998, 
        2.0410779985789223`*^-15, -8.333333333333336}, {16.19999999999998, 
        1.530808498934192*^-15, -7.105427357601002*^-15}, {0., 
        1.5308084989341915`*^-15, 0.}, {1.1889728927704226`, 
        1.020538999289461*^-15, -8.333333333333336}}], 
       Polygon3DBox[{{0., 1.5308084989341915`*^-15, 0.}, {16.19999999999998, 
        1.5308084989341915`*^-15, 0.}, {16.19999999999998, 
        1.0205389992894611`*^-15, 8.333333333333332}, {1.188972892770419, 
        2.041077998578922*^-15, 8.333333333333329}, {0., 
        1.5308084989341915`*^-15, 0.}}], 
       Polygon3DBox[{{1.188972892770419, 2.041077998578922*^-15, 
        8.333333333333329}, {16.19999999999998, 1.0205389992894611`*^-15, 
        8.333333333333332}, {16.19999999999998, 5.102694996447307*^-16, 
        16.666666666666664`}, {5.09692032978862, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {1.188972892770419, 2.041077998578922*^-15, 
        8.333333333333329}}], 
       Polygon3DBox[{{5.09692032978862, 2.5513474982236525`*^-15, 
        16.666666666666664`}, {16.19999999999998, 5.102694996447308*^-16, 
        16.666666666666664`}, {16.19999999999998, 2.5493082627129206`*^-31, 
        24.999999999999996`}, {13.583141632498663`, 3.0616169978683826`*^-15, 
        24.999999999999993`}, {5.09692032978862, 2.5513474982236525`*^-15, 
        16.666666666666664`}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], Line3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIFbhdOyaqKXtwIACLA+84LQWtU8WgYuvXgUCBgcO
VCwp4GD7bA8TXwMWVzjAgBV82LMBTf0KiHqHB2jmQ8QNHOTQ3PPvPwhYOOgZ
g4ABujsxxKHuxBCHuhOHOR9s0MWh7jyAXdwAQxzqzgO4whMAoElWjg==
         
         "]]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      Line3DBox[{{13.583141632498673`, 25., 0.}, {16.19999999999998, 25., 
       0.}, {16.19999999999998, 24.148145657226706`, 6.4704761275630185`}, {
       13.583141632498673`, 24.148145657226706`, 6.4704761275630185`}, {
       13.583141632498673`, 25., 0.}}], 
      Line3DBox[{{13.583141632498673`, 24.148145657226706`, 
       6.4704761275630185`}, {16.19999999999998, 24.148145657226706`, 
       6.4704761275630185`}, {16.19999999999998, 21.65063509461097, 
       12.499999999999998`}, {13.583141632498677`, 21.65063509461097, 
       12.499999999999998`}, {13.583141632498673`, 24.148145657226706`, 
       6.4704761275630185`}}], 
      Line3DBox[{{13.583141632498677`, 21.65063509461097, 
       12.499999999999998`}, {16.19999999999998, 21.65063509461097, 
       12.499999999999998`}, {16.19999999999998, 17.67766952966369, 
       17.677669529663685`}, {13.58314163249867, 17.67766952966369, 
       17.677669529663685`}, {13.583141632498677`, 21.65063509461097, 
       12.499999999999998`}}], 
      Line3DBox[{{13.58314163249867, 17.67766952966369, 
       17.677669529663685`}, {16.19999999999998, 17.67766952966369, 
       17.677669529663685`}, {16.19999999999998, 12.500000000000004`, 
       21.650635094610966`}, {13.583141632498677`, 12.500000000000004`, 
       21.650635094610966`}, {13.58314163249867, 17.67766952966369, 
       17.677669529663685`}}], 
      Line3DBox[{{13.583141632498677`, 12.500000000000004`, 
       21.650635094610966`}, {16.19999999999998, 12.500000000000004`, 
       21.650635094610966`}, {16.19999999999998, 6.470476127563024, 
       24.148145657226706`}, {13.583141632498673`, 6.470476127563024, 
       24.148145657226706`}, {13.583141632498677`, 12.500000000000004`, 
       21.650635094610966`}}], 
      Line3DBox[{{13.583141632498673`, 6.470476127563024, 
       24.148145657226706`}, {16.19999999999998, 6.470476127563024, 
       24.148145657226706`}, {16.19999999999998, 7.0819236220599744`*^-15, 
       25.}, {13.583141632498673`, 7.0819236220599744`*^-15, 25.}, {
       13.583141632498673`, 6.470476127563024, 24.148145657226706`}}], 
      Line3DBox[{{13.583141632498673`, 1.5308084989341915`*^-15, 25.}, {
       16.19999999999998, 1.5308084989341915`*^-15, 25.}, {
       16.19999999999998, -6.470476127563016, 24.148145657226706`}, {
       13.58314163249867, -6.470476127563016, 24.148145657226706`}, {
       13.583141632498673`, 1.5308084989341915`*^-15, 25.}}], 
      Line3DBox[{{13.58314163249867, -6.470476127563016, 
       24.148145657226706`}, {16.19999999999998, -6.470476127563016, 
       24.148145657226706`}, {16.19999999999998, -12.499999999999995`, 
       21.65063509461097}, {13.583141632498673`, -12.499999999999995`, 
       21.65063509461097}, {13.58314163249867, -6.470476127563016, 
       24.148145657226706`}}], 
      Line3DBox[{{13.583141632498673`, -12.499999999999995`, 
       21.65063509461097}, {16.19999999999998, -12.499999999999995`, 
       21.65063509461097}, {16.19999999999998, -17.677669529663685`, 
       17.67766952966369}, {13.58314163249867, -17.677669529663685`, 
       17.67766952966369}, {13.583141632498673`, -12.499999999999995`, 
       21.65063509461097}}], 
      Line3DBox[{{13.58314163249867, -17.677669529663685`, 
       17.67766952966369}, {16.19999999999998, -17.677669529663685`, 
       17.67766952966369}, {16.19999999999998, -21.65063509461097, 
       12.499999999999998`}, {13.583141632498677`, -21.65063509461097, 
       12.499999999999998`}, {13.58314163249867, -17.677669529663685`, 
       17.67766952966369}}], 
      Line3DBox[{{13.583141632498677`, -21.650635094610962`, 
       12.500000000000009`}, {16.19999999999998, -21.650635094610962`, 
       12.500000000000009`}, {16.19999999999998, -24.148145657226706`, 
       6.470476127563026}, {13.583141632498673`, -24.148145657226706`, 
       6.470476127563026}, {13.583141632498677`, -21.650635094610962`, 
       12.500000000000009`}}], 
      Line3DBox[{{13.583141632498673`, -24.148145657226706`, 
       6.470476127563026}, {16.19999999999998, -24.148145657226706`, 
       6.470476127563026}, {16.19999999999998, -25., 
       3.061616997868383*^-15}, {13.583141632498673`, -25., 
       3.061616997868383*^-15}, {13.583141632498673`, -24.148145657226706`, 
       6.470476127563026}}], 
      Line3DBox[{{13.583141632498673`, -25., 3.061616997868383*^-15}, {
       16.19999999999998, -25., 3.061616997868383*^-15}, {
       16.19999999999998, -24.148145657226706`, -6.47047612756302}, {
       13.583141632498673`, -24.148145657226706`, -6.47047612756302}, {
       13.583141632498673`, -25., 3.061616997868383*^-15}}], 
      Line3DBox[{{
       13.583141632498677`, -24.14814565722671, -6.470476127563009}, {
       16.19999999999998, -24.14814565722671, -6.470476127563009}, {
       16.19999999999998, -21.65063509461097, -12.499999999999993`}, {
       13.583141632498673`, -21.65063509461097, -12.499999999999993`}, {
       13.583141632498677`, -24.14814565722671, -6.470476127563009}}], 
      Line3DBox[{{
       13.583141632498673`, -21.65063509461097, -12.499999999999993`}, {
       16.19999999999998, -21.65063509461097, -12.499999999999993`}, {
       16.19999999999998, -17.677669529663692`, -17.677669529663685`}, {
       13.583141632498673`, -17.677669529663692`, -17.677669529663685`}, {
       13.583141632498673`, -21.65063509461097, -12.499999999999993`}}], 
      Line3DBox[{{
       13.583141632498673`, -17.677669529663696`, -17.677669529663678`}, {
       16.19999999999998, -17.677669529663696`, -17.677669529663678`}, {
       16.19999999999998, -12.50000000000001, -21.65063509461096}, {
       13.58314163249867, -12.50000000000001, -21.65063509461096}, {
       13.583141632498673`, -17.677669529663696`, -17.677669529663678`}}], 
      Line3DBox[{{
       13.58314163249867, -12.50000000000001, -21.65063509461096}, {
       16.19999999999998, -12.50000000000001, -21.65063509461096}, {
       16.19999999999998, -6.470476127563038, -24.148145657226703`}, {
       13.583141632498677`, -6.470476127563038, -24.148145657226703`}, {
       13.58314163249867, -12.50000000000001, -21.65063509461096}}], 
      Line3DBox[{{
       13.583141632498677`, -6.470476127563038, -24.148145657226703`}, {
       16.19999999999998, -6.470476127563038, -24.148145657226703`}, {
       16.19999999999998, -2.6796885989305705`*^-14, -25.}, {
       13.583141632498673`, -2.6796885989305705`*^-14, -25.}, {
       13.583141632498677`, -6.470476127563038, -24.148145657226703`}}], 
      Line3DBox[{{13.583141632498673`, -4.592425496802574*^-15, -25.}, {
       16.19999999999998, -4.592425496802574*^-15, -25.}, {16.19999999999998, 
       6.470476127563007, -24.14814565722671}, {13.583141632498673`, 
       6.470476127563007, -24.14814565722671}, {
       13.583141632498673`, -4.592425496802574*^-15, -25.}}], 
      Line3DBox[{{13.583141632498673`, 
       6.470476127563007, -24.14814565722671}, {16.19999999999998, 
       6.470476127563007, -24.14814565722671}, {16.19999999999998, 
       12.499999999999984`, -21.650635094610976`}, {13.583141632498677`, 
       12.499999999999984`, -21.650635094610976`}, {13.583141632498673`, 
       6.470476127563007, -24.14814565722671}}], 
      Line3DBox[{{13.583141632498677`, 
       12.499999999999984`, -21.650635094610976`}, {16.19999999999998, 
       12.499999999999984`, -21.650635094610976`}, {16.19999999999998, 
       17.67766952966367, -17.67766952966371}, {13.58314163249868, 
       17.67766952966367, -17.67766952966371}, {13.583141632498677`, 
       12.499999999999984`, -21.650635094610976`}}], 
      Line3DBox[{{13.583141632498677`, 
       17.677669529663685`, -17.677669529663692`}, {16.19999999999998, 
       17.677669529663685`, -17.677669529663692`}, {16.19999999999998, 
       21.65063509461096, -12.50000000000001}, {13.58314163249867, 
       21.65063509461096, -12.50000000000001}, {13.583141632498677`, 
       17.677669529663685`, -17.677669529663692`}}], 
      Line3DBox[{{13.58314163249867, 21.65063509461096, -12.50000000000001}, {
       16.19999999999998, 21.65063509461096, -12.50000000000001}, {
       16.19999999999998, 24.148145657226703`, -6.470476127563039}, {
       13.583141632498677`, 24.148145657226703`, -6.470476127563039}, {
       13.58314163249867, 21.65063509461096, -12.50000000000001}}], 
      Line3DBox[{{13.583141632498677`, 
       24.148145657226703`, -6.470476127563039}, {16.19999999999998, 
       24.148145657226703`, -6.470476127563039}, {16.19999999999998, 
       25., -2.8327694488239898`*^-14}, {13.583141632498673`, 
       25., -2.8327694488239898`*^-14}, {13.583141632498677`, 
       24.148145657226703`, -6.470476127563039}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  Boxed:>False,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.56336761658689*^9, 3.5660870648802032`*^9, 
  3.566101855316402*^9, 3.5661393159199133`*^9, 3.614707886518627*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->
  "During evaluation of \
In[87]:=",ExpressionUUID->"1c5e58ca-393f-4ec5-beab-2f1a1949f8ab"]
}, Open  ]],

Cell[TextData[{
 "In other cases, when more than one match exists, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will recover the closest matches that fit within a certain tolerance. In \
this next example, ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " finds six close candidates."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"105f563c-551c-40db-8444-64442de81d48"],

Cell[CellGroupData[{

Cell["\<\
SearchData[PlanoConvexLens, ComponentBoundary->50, FocalLength->75]\
\>", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[89]:=",ExpressionUUID->"c89563a2-51fd-4b4c-9315-c4a0710dcb74"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"LQF066\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "13.8`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"MellesGriot\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "50.`"}], ",", 
     RowBox[{
     "ComponentLabel", "\[Rule]", "\<\"OpticalQualityPlanoConvex\"\>"}], ",", 
     
     RowBox[{"ComponentMedium", "\[Rule]", "FusedSilica"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.46007860370064`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.5461`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"Melles.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "75.00892178514421`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"34.50999999999999`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"50.`", ",", "50.`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", "13.8`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"LQP005\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "13.8`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"MellesGriot\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "50.`"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"UVGradePlanoConvex\"\>"}], ",", 
     RowBox[{"ComponentMedium", "\[Rule]", "FusedSilica"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.46007860370064`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.5461`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"Melles.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "75.00892178514421`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"34.50999999999999`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"50.`", ",", "50.`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", "13.8`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"PCX45246\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "11.`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"EdmundScientific\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "50.`"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"PlanoConvex\"\>"}], ",", 
     RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.5167817368085`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.588`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"Edmund.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "75.00265051812983`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"38.75999999999999`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"50.`", ",", "50.`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", "11.`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"BackFocalLength", "\[Rule]", "66.29999999999998`"}], ",", 
     RowBox[{"CatalogFocalLength", "\[Rule]", "75.`"}], ",", 
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"FPX11730/000\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "12.7`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "JML"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "50.`"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"PlanoConvexLens\"\>"}], ",", 
     RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "587.6`"}], ",", 
     RowBox[{"EdgeThickness", "\[Rule]", "1.9`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"JML.m\"\>"}], ",", 
     RowBox[{"FNumber", "\[Rule]", "1.5`"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "75.`"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"34.38`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"50.`", ",", "50.`"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", 
      RowBox[{"{", "12.7`", "}"}]}], ",", 
     RowBox[{"V1H1", "\[Rule]", "0"}], ",", 
     RowBox[{"V2H2", "\[Rule]", 
      RowBox[{"-", "8.7`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"BackFocalLength", "\[Rule]", "67.5`"}], ",", 
     RowBox[{"CatalogFocalLength", "\[Rule]", "75"}], ",", 
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"CPX10195/100\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "11.4`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "JML"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "50"}], ",", 
     RowBox[{"ComponentLabel", "\[Rule]", "\<\"PlanoConvexLens\"\>"}], ",", 
     RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "632.8`"}], ",", 
     RowBox[{"EdgeThickness", "\[Rule]", "2.2`"}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"JML.m\"\>"}], ",", 
     RowBox[{"FNumber", "\[Rule]", "1.5`"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "75"}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"38.63`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"50", ",", "50"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", 
      RowBox[{"{", "11.4`", "}"}]}], ",", 
     RowBox[{"V1H1", "\[Rule]", "0"}], ",", 
     RowBox[{"V2H2", "\[Rule]", 
      RowBox[{"-", "7.5`"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"CatalogNumber", "\[Rule]", "\<\"43-0462\"\>"}], ",", 
     RowBox[{"CenterThickness", "\[Rule]", "11.59999999999999`"}], ",", 
     RowBox[{"CompanyName", "\[Rule]", "\<\"Coherent-Ealing\"\>"}], ",", 
     RowBox[{"ComponentBoundary", "\[Rule]", "50.`"}], ",", 
     RowBox[{
     "ComponentLabel", 
      "\[Rule]", "\<\"43-0462 PLANO-CONVEX PlanoConvexLens\"\>"}], ",", 
     RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
     RowBox[{"Date", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1999", ",", "4", ",", "18"}], "}"}]}], ",", 
     RowBox[{"DesignRefractiveIndex", "\[Rule]", "1.51679809896657`"}], ",", 
     RowBox[{"DesignWaveLength", "\[Rule]", "0.5876`"}], ",", 
     RowBox[{"EntrancePupilDiameter", "\[Rule]", 
      RowBox[{"{", "45.`", "}"}]}], ",", 
     RowBox[{"FileName", "\[Rule]", "\<\"CoherentEaling.m\"\>"}], ",", 
     RowBox[{"FocalLength", "\[Rule]", "75.00027588628387`"}], ",", 
     RowBox[{"GlassCatalogs", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"SCHOTT", ",", "MISC", ",", "INFRARED"}], "}"}]}], ",", 
     RowBox[{"OpticaFunction", "\[Rule]", "PlanoConvexLens"}], ",", 
     RowBox[{"RadiusOfCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"38.75999999999997`", ",", "\[Infinity]"}], "}"}]}], ",", 
     RowBox[{"StopPosition", "\[Rule]", "1"}], ",", 
     RowBox[{"SurfaceBoundary", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"50.`", ",", "50.`"}], "}"}]}], ",", 
     RowBox[{"SurfaceCurvature", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0.02579979360165`", ",", "0.`"}], "}"}]}], ",", 
     RowBox[{"SurfaceLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"SphericalShape", ",", "SphericalShape"}], "}"}]}], ",", 
     RowBox[{"SurfaceSeparation", "\[Rule]", "11.59999999999999`"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5633676167988997`*^9, 3.566087065194199*^9, 
  3.566101855766177*^9, 3.566139316526313*^9, 3.6147078867546463`*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[89]=",ExpressionUUID->"7b2d3ae9-a8b2-4e33-b74b-d7478c7126a5"]
}, Open  ]],

Cell[TextData[{
 "With so many reported entries, the ",
 StyleBox["SearchData", "Input"],
 " results can get to be confusing. In order to clarify the important \
information, you can use ",
 StyleBox["ReadData", "Input"],
 ", instead of ",
 StyleBox["SearchData", "Input"],
 ", in order to view isolated parameters from the data base search. We will \
now use ",
 StyleBox["ReadData", "Input"],
 " with the same parameter search as before:"
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"06ec706d-fdd8-44c8-b609-6bd53f59f9a3"],

Cell[CellGroupData[{

Cell["\<\
ReadData[{ComponentBoundary, FocalLength, CatalogNumber}, PlanoConvexLens, \
ComponentBoundary->50, FocalLength->75]\
\>", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[90]:=",ExpressionUUID->"86e32bc2-274e-45c2-8206-2161f148fa42"],

Cell[BoxData[
 TagBox[GridBox[{
    {"ComponentBoundary", "FocalLength", "CatalogNumber"},
    {"50.", "75.0089", "LQF066"},
    {"50.", "75.0089", "LQP005"},
    {"50.", "75.0027", "PCX45246"},
    {"50.", "75.", 
     RowBox[{"FPX11730", "/", "000"}]},
    {"50", "75", 
     RowBox[{"CPX10195", "/", "100"}]},
    {"50.", "75.0003", 
     RowBox[{"43", "-", "0462"}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {False, {True}, False}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}],
  DisplayForm]], "Output",
 CellChangeTimes->{3.5633676174505243`*^9, 3.566087065317793*^9, 
  3.5661018560007267`*^9, 3.566139316838616*^9, 3.614707886887382*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->
  "Out[90]//DisplayForm=",ExpressionUUID->"8d38c99c-2568-4708-b441-\
e9f560629304"]
}, Open  ]],

Cell[TextData[{
 "From this information, we can see that two items actually match up \
perfectly with the desired parameters. We can now place the ",
 StyleBox["CatalogNumber", "Input"],
 " from our favorite result in ",
 StyleBox["DataToOptica", "Input"],
 " to define an actual lens in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"a0f07990-74b7-4276-b78d-161863b82f07"],

Cell[CellGroupData[{

Cell["lens = DataToOptica[\"FPX11730/000\"]", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[91]:=",ExpressionUUID->"993138d5-d0c0-4851-bdd3-336bef7e015c"],

Cell[BoxData[
 TagBox[
  StyleBox[
   TagBox[
    RowBox[{"PlanoConvexLens", "[", 
     RowBox[{"75.`", ",", "50.`", ",", "12.7`", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"ComponentMedium", "\[Rule]", "Quartz"}], ",", 
        RowBox[{"DesignWaveLength", "\[Rule]", "0.5876`"}]}], "}"}]}], "]"}],
    HoldForm],
   FontColor->RGBColor[0., 0.392193, 0.]],
  DisplayForm]], "Output",
 CellChangeTimes->{3.563367617702282*^9, 3.5660870655231733`*^9, 
  3.5661018563971987`*^9, 3.5661393172948933`*^9, 3.614707887172225*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[91]=",ExpressionUUID->"4fa51032-9c32-4056-aeb8-d8f07e45872a"]
}, Open  ]],

Cell["\<\
In some instances, there may not be any suitable match with a database entry. \
In such cases, an empty list is returned.\
\>", "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"80e078d0-8e72-4024-814d-fdde7d9e7cf6"],

Cell[CellGroupData[{

Cell["SearchData[\"nothing\"]", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[92]:=",ExpressionUUID->"f1dd3ebf-70de-4799-9372-7f56ef9939da"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.563367618369419*^9, 3.566087066077324*^9, 
  3.566101857580418*^9, 3.5661393208599663`*^9, 3.6147078878611794`*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[92]=",ExpressionUUID->"b71c509f-7fac-4f76-a1bc-eaa33bc4fce5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["DataToOptica[\"nothing\"]", "Input",
 CellTags->{"Database", "RG19."},
 CellLabel->"In[93]:=",ExpressionUUID->"696fbf67-6d6e-4a36-ab5f-875ee48f709c"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.563367621178749*^9, 3.566087067367466*^9, 
  3.566101859749576*^9, 3.566139323397683*^9, 3.6147078891681633`*^9},
 CellTags->{"Database", "RG19."},
 CellLabel->"Out[93]=",ExpressionUUID->"f0508462-a5a9-4d2c-b14c-0c1ef10d3b94"]
}, Open  ]],

Cell[TextData[{
 "You can learn more about ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s database system in Chapter 5."
}], "Text",
 CellTags->{
  "Database", "RG19."},ExpressionUUID->"d1a9bf02-f552-4374-b7d1-5e1ecf461f62"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"b2806b3a-4d9b-442f-\
b745-e4ce07d6e2ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "20. The ",
 StyleBox["TransferTraits",
  FontFamily->"Courier New"],
 " Function"
}], "Section",
 CellTags->{
  "20.", "RG20."},ExpressionUUID->"362a1439-c548-49a1-877f-7518d0f44c3a"],

Cell[TextData[{
 "One of the most recent additions to ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s constellation of high-level functions is ",
 StyleBox["TransferTraits", "Input"],
 ".  ",
 StyleBox["TransferTraits", "Input"],
 " offers the user a powerful way to quickly customize a built-in optical \
component by transferring some of the characteristics from a second component."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"RG20.",ExpressionUUID->"af54b50b-178f-46d4-bc93-5db03cb0f378"],

Cell[TextData[{
 StyleBox["TransferTraits[", "Input"],
 StyleBox["donor-component",
  FontSlant->"Italic"],
 ", ",
 StyleBox["recipient-component",
  FontSlant->"Italic"],
 ", ",
 StyleBox["surfacenumbers",
  FontSlant->"Italic"],
 ", ",
 StyleBox["opts",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 " is a function that transfers the surface traits of a donor component \
surface into the surfaces (specified by ",
 StyleBox["surfacenumbers",
  FontSlant->"Italic"],
 ") of a recipient component."
}], "FramedBox",
 PageWidth->WindowWidth,
 CellFrame->True,
 CellMargins->{{20, 20}, {Inherited, Inherited}},
 Evaluatable->False,
 PageBreakWithin->False,
 CellFrameMargins->15,
 AspectRatioFixed->True,
 CellTags->"RG20.",ExpressionUUID->"8edeb40e-fa64-4139-91ba-af1d10908acf"],

Cell["\<\
As an example, lets change the behavior of a plano-convex lens.\
\>", "Text",
 CellTags->"RG20.",ExpressionUUID->"c2d38fbb-66f4-4c9e-a3f7-d552593812ff"],

Cell[CellGroupData[{

Cell["\<\
lens = Move[PlanoConvexLens[100,50,10],50];
AnalyzeSystem[{
\tLineOfRays[45,NumberOfRays->11],
\tlens,
\tBoundary[150]},PlotType->TopView];\
\>", "Input",
 CellTags->"RG20.",
 CellLabel->"In[94]:=",ExpressionUUID->"e22c50c9-d05f-40fd-94b8-485e8ad37cd1"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, {}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {150., -75.}, {150., 75.}, {150., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {0., -75.}, {0., -75.}, {150., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -75}, {0, 75}, {0, 75}, {0, -75}, {0, -75}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 75.}, {150., 75.}, {150., 75.}, {0., 75.}, {0., 75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {150., 75.}, {0., 75.}, {0., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {0., -75.}, {0., 75.}, {150., 
       75.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., -18.}, {53.223211750877866`, -18.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.5}, {51.787526330610106`, -13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -9.}, {50.78673366752143, -9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -4.5}, {50.19556052328608, -4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 4.5}, {50.19556052328608, 4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 9.}, {50.78673366752143, 9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 13.5}, {51.787526330610106`, 13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 18.}, {53.223211750877866`, 18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {60., -21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, -18.}, {60., -17.155974562461154`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, -13.5}, {
       60., -12.749674310000062`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, -9.}, {60., -8.44728950710319}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, -4.5}, {60., -4.208514513218614}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, 4.5}, {60., 4.208514513218614}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, 9.}, {60., 8.44728950710319}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, 13.5}, {60., 12.749674310000062`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, 18.}, {60., 17.155974562461154`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {60., 21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -21.7192607925394}, {150., 0.5945397796583762}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -17.155974562461154`}, {150., 0.046840736404153205`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -12.749674310000062`}, {150., -0.19003184740570234`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -8.44728950710319}, {150., -0.2262513887515336}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -4.208514513218614}, {150., -0.14161353118127717`}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {150., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 4.208514513218614}, {150., 0.14161353118127717`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 8.44728950710319}, {150., 0.2262513887515336}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 12.749674310000062`}, {150., 0.19003184740570234`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 17.155974562461154`}, {150., -0.046840736404153205`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.7192607925394}, {150., -0.5945397796583762}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQzfv3yk/Fid4ODCDQYHbAiveh8aQ5XhA+g9GBU1Fr
V5594gnlax8ICw3bsDkFxlc60Ph5ogKHJIwvdIARTMP4DAxo8g5o+h3QzHdA
s98BzX1QcT+HEoe1lYo7TA/A+AHH33x6q24I53OarPC/Wq8J5/ttiVRkfqoA
56/ll7nSclUAzmdAAXB5BzT9cD7UfDgfaj+6+yD8A0kODTt2elawPbaH8Rle
ffZt+r0czm/QfL7mW9CJ/TD+geR1pue+noHzH8j2pKUoHILzUZyLkLdH049u
Prr9cPOg7tsPAOqtk/k=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367624995881*^9, 3.5660870678419867`*^9, 
  3.566101860633246*^9, 3.56613932456177*^9, 3.614707889700788*^9},
 CellTags->"RG20.",
 CellLabel->
  "During evaluation of \
In[94]:=",ExpressionUUID->"45130692-f163-4cee-8376-a5ce459d6f14"]
}, Open  ]],

Cell[TextData[{
 "We can now use ",
 StyleBox["TransferTraits", "Input"],
 " add a reflective surface onto the first surface of the lens by \
transferring these traits from a simple mirror."
}], "Text",
 CellTags->"RG20.",ExpressionUUID->"2f734fe7-0a8c-49f2-855c-ea313f7db36a"],

Cell[CellGroupData[{

Cell["\<\
mirror = Mirror[50];
AnalyzeSystem[{
\tLineOfRays[45,NumberOfRays->11],
\tTransferTraits[mirror,lens,{1}],
\tBoundary[150]},PlotType->TopView];\
\>", "Input",
 CellTags->"RG20.",
 CellLabel->"In[96]:=",ExpressionUUID->"9048fd1a-1edd-4643-bb43-4e8ad7584667"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 8.333333333333332}, {
      50.67375799589206, 8.049381885742235}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333332}, {52.75044883428479, 
      16.666666666666664`}, {52.75044883428479, 16.09876377148447}, {
      50.67375799589206, 8.049381885742235}, {50.67375799589206, 
      8.333333333333332}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {56.42197458095559,
       25.}, {56.42197458095559, 24.148145657226706`}, {52.75044883428479, 
      16.09876377148447}, {52.75044883428479, 16.666666666666664`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 8.049381885742235}, {
      50.67375799589207, 7.216878364870323}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.049381885742235}, {52.75044883428479, 
      16.09876377148447}, {52.75044883428479, 14.433756729740645`}, {
      50.67375799589207, 7.216878364870323}, {50.67375799589206, 
      8.049381885742235}}], 
     PolygonBox[{{52.75044883428479, 16.09876377148447}, {56.42197458095559, 
      24.148145657226706`}, {56.42197458095559, 21.65063509461097}, {
      52.75044883428479, 14.433756729740645`}, {52.75044883428479, 
      16.09876377148447}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, 7.216878364870323}, {
      50.67375799589206, 5.892556509887896}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, 7.216878364870323}, {52.75044883428479, 
      14.433756729740645`}, {52.75044883428478, 11.785113019775793`}, {
      50.67375799589206, 5.892556509887896}, {50.67375799589207, 
      7.216878364870323}}], 
     PolygonBox[{{52.75044883428479, 14.433756729740645`}, {56.42197458095559,
       21.65063509461097}, {56.42197458095559, 17.67766952966369}, {
      52.75044883428478, 11.785113019775793`}, {52.75044883428479, 
      14.433756729740645`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 5.892556509887896}, {
      50.67375799589207, 4.166666666666668}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 5.892556509887896}, {52.75044883428478, 
      11.785113019775793`}, {52.75044883428479, 8.333333333333336}, {
      50.67375799589207, 4.166666666666668}, {50.67375799589206, 
      5.892556509887896}}], 
     PolygonBox[{{52.75044883428478, 11.785113019775793`}, {56.42197458095559,
       17.67766952966369}, {56.42197458095559, 12.500000000000004`}, {
      52.75044883428479, 8.333333333333336}, {52.75044883428478, 
      11.785113019775793`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, 4.166666666666668}, {
      50.67375799589206, 2.156825375854341}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, 4.166666666666668}, {52.75044883428479, 
      8.333333333333336}, {52.75044883428479, 4.313650751708682}, {
      50.67375799589206, 2.156825375854341}, {50.67375799589207, 
      4.166666666666668}}], 
     PolygonBox[{{52.75044883428479, 8.333333333333336}, {56.42197458095559, 
      12.500000000000004`}, {56.42197458095559, 6.470476127563024}, {
      52.75044883428479, 4.313650751708682}, {52.75044883428479, 
      8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 2.156825375854341}, {
      50.67375799589206, 2.3606412073533245`*^-15}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 2.156825375854341}, {52.75044883428479, 
      4.313650751708682}, {52.75044883428479, 4.721282414706649*^-15}, {
      50.67375799589206, 2.3606412073533245`*^-15}, {50.67375799589206, 
      2.156825375854341}}], 
     PolygonBox[{{52.75044883428479, 4.313650751708682}, {56.42197458095559, 
      6.470476127563024}, {56.42197458095559, 7.0819236220599744`*^-15}, {
      52.75044883428479, 4.721282414706649*^-15}, {52.75044883428479, 
      4.313650751708682}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 5.102694996447305*^-16}, {
      50.67375799589206, -2.1568253758543383`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 5.102694996447305*^-16}, {
      52.75044883428479, 1.020538999289461*^-15}, {
      52.75044883428479, -4.313650751708677}, {
      50.67375799589206, -2.1568253758543383`}, {50.67375799589206, 
      5.102694996447305*^-16}}], 
     PolygonBox[{{52.75044883428479, 1.020538999289461*^-15}, {
      56.42197458095559, 1.5308084989341915`*^-15}, {
      56.42197458095559, -6.470476127563016}, {
      52.75044883428479, -4.313650751708677}, {52.75044883428479, 
      1.020538999289461*^-15}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -2.1568253758543383`}, {
      50.67375799589207, -4.166666666666664}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -2.1568253758543383`}, {
      52.75044883428479, -4.313650751708677}, {
      52.75044883428479, -8.333333333333329}, {
      50.67375799589207, -4.166666666666664}, {
      50.67375799589206, -2.1568253758543383`}}], 
     PolygonBox[{{52.75044883428479, -4.313650751708677}, {
      56.42197458095559, -6.470476127563016}, {
      56.42197458095559, -12.499999999999995`}, {
      52.75044883428479, -8.333333333333329}, {
      52.75044883428479, -4.313650751708677}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, -4.166666666666664}, {
      50.67375799589206, -5.8925565098878945`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, -4.166666666666664}, {
      52.75044883428479, -8.333333333333329}, {
      52.75044883428478, -11.785113019775789`}, {
      50.67375799589206, -5.8925565098878945`}, {
      50.67375799589207, -4.166666666666664}}], 
     PolygonBox[{{52.75044883428479, -8.333333333333329}, {
      56.42197458095559, -12.499999999999995`}, {
      56.42197458095559, -17.677669529663685`}, {
      52.75044883428478, -11.785113019775789`}, {
      52.75044883428479, -8.333333333333329}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -5.8925565098878945`}, {
      50.67375799589207, -7.216878364870323}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -5.8925565098878945`}, {
      52.75044883428478, -11.785113019775789`}, {
      52.75044883428479, -14.433756729740645`}, {
      50.67375799589207, -7.216878364870323}, {
      50.67375799589206, -5.8925565098878945`}}], 
     PolygonBox[{{52.75044883428478, -11.785113019775789`}, {
      56.42197458095559, -17.677669529663685`}, {
      56.42197458095559, -21.65063509461097}, {
      52.75044883428479, -14.433756729740645`}, {
      52.75044883428478, -11.785113019775789`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, -7.21687836487032}, {
      50.67375799589206, -8.049381885742235}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, -7.21687836487032}, {
      52.75044883428478, -14.43375672974064}, {
      52.75044883428479, -16.09876377148447}, {
      50.67375799589206, -8.049381885742235}, {
      50.67375799589207, -7.21687836487032}}], 
     PolygonBox[{{52.75044883428478, -14.43375672974064}, {
      56.4219745809556, -21.650635094610962`}, {
      56.42197458095559, -24.148145657226706`}, {
      52.75044883428479, -16.09876377148447}, {
      52.75044883428478, -14.43375672974064}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -8.049381885742235}, {
      50.67375799589206, -8.333333333333332}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -8.049381885742235}, {
      52.75044883428479, -16.09876377148447}, {
      52.75044883428479, -16.666666666666664`}, {
      50.67375799589206, -8.333333333333332}, {
      50.67375799589206, -8.049381885742235}}], 
     PolygonBox[{{52.75044883428479, -16.09876377148447}, {
      56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}, {
      52.75044883428479, -16.666666666666664`}, {
      52.75044883428479, -16.09876377148447}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -8.333333333333332}, {
      50.67375799589206, -8.049381885742235}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333332}, {
      52.75044883428479, -16.666666666666664`}, {
      52.75044883428479, -16.09876377148447}, {
      50.67375799589206, -8.049381885742235}, {
      50.67375799589206, -8.333333333333332}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666664`}, {
      56.42197458095559, -25.}, {56.42197458095559, -24.148145657226706`}, {
      52.75044883428479, -16.09876377148447}, {
      52.75044883428479, -16.666666666666664`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -8.049381885742235}, {
      50.67375799589207, -7.216878364870323}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -8.049381885742235}, {
      52.75044883428479, -16.09876377148447}, {
      52.75044883428479, -14.433756729740645`}, {
      50.67375799589207, -7.216878364870323}, {
      50.67375799589206, -8.049381885742235}}], 
     PolygonBox[{{52.75044883428479, -16.09876377148447}, {
      56.42197458095559, -24.14814565722671}, {
      56.42197458095559, -21.65063509461097}, {
      52.75044883428479, -14.433756729740645`}, {
      52.75044883428479, -16.09876377148447}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, -7.216878364870323}, {
      50.67375799589206, -5.892556509887897}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, -7.216878364870323}, {
      52.75044883428479, -14.433756729740645`}, {
      52.75044883428479, -11.785113019775794`}, {
      50.67375799589206, -5.892556509887897}, {
      50.67375799589207, -7.216878364870323}}], 
     PolygonBox[{{52.75044883428479, -14.433756729740645`}, {
      56.42197458095559, -21.65063509461097}, {
      56.42197458095559, -17.677669529663692`}, {
      52.75044883428479, -11.785113019775794`}, {
      52.75044883428479, -14.433756729740645`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -5.892556509887898}, {
      50.67375799589207, -4.16666666666667}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -5.892556509887898}, {
      52.75044883428479, -11.785113019775796`}, {
      52.75044883428478, -8.33333333333334}, {
      50.67375799589207, -4.16666666666667}, {
      50.67375799589206, -5.892556509887898}}], 
     PolygonBox[{{52.75044883428479, -11.785113019775796`}, {
      56.42197458095559, -17.677669529663696`}, {
      56.42197458095559, -12.50000000000001}, {
      52.75044883428478, -8.33333333333334}, {
      52.75044883428479, -11.785113019775796`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, -4.16666666666667}, {
      50.67375799589206, -2.156825375854346}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, -4.16666666666667}, {
      52.75044883428478, -8.33333333333334}, {
      52.75044883428479, -4.313650751708692}, {
      50.67375799589206, -2.156825375854346}, {
      50.67375799589207, -4.16666666666667}}], 
     PolygonBox[{{52.75044883428478, -8.33333333333334}, {
      56.42197458095559, -12.50000000000001}, {
      56.42197458095559, -6.470476127563038}, {
      52.75044883428479, -4.313650751708692}, {
      52.75044883428478, -8.33333333333334}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -2.156825375854346}, {
      50.67375799589206, -8.932295329768568*^-15}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -2.156825375854346}, {
      52.75044883428479, -4.313650751708692}, {
      52.75044883428479, -1.7864590659537137`*^-14}, {
      50.67375799589206, -8.932295329768568*^-15}, {
      50.67375799589206, -2.156825375854346}}], 
     PolygonBox[{{52.75044883428479, -4.313650751708692}, {
      56.42197458095559, -6.470476127563038}, {
      56.42197458095559, -2.6796885989305705`*^-14}, {
      52.75044883428479, -1.7864590659537137`*^-14}, {
      52.75044883428479, -4.313650751708692}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, -1.5308084989341913`*^-15}, {
      50.67375799589206, 2.1568253758543356`}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, -1.5308084989341913`*^-15}, {
      52.75044883428479, -3.0616169978683826`*^-15}, {52.75044883428479, 
      4.313650751708671}, {50.67375799589206, 2.1568253758543356`}, {
      50.67375799589206, -1.5308084989341913`*^-15}}], 
     PolygonBox[{{52.75044883428479, -3.0616169978683826`*^-15}, {
      56.42197458095559, -4.592425496802574*^-15}, {56.42197458095559, 
      6.470476127563007}, {52.75044883428479, 4.313650751708671}, {
      52.75044883428479, -3.0616169978683826`*^-15}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 2.1568253758543356`}, {
      50.67375799589206, 4.166666666666661}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 2.1568253758543356`}, {52.75044883428479,
       4.313650751708671}, {52.75044883428479, 8.333333333333321}, {
      50.67375799589206, 4.166666666666661}, {50.67375799589206, 
      2.1568253758543356`}}], 
     PolygonBox[{{52.75044883428479, 4.313650751708671}, {56.42197458095559, 
      6.470476127563007}, {56.42197458095559, 12.499999999999984`}, {
      52.75044883428479, 8.333333333333321}, {52.75044883428479, 
      4.313650751708671}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 4.166666666666661}, {
      50.67375799589206, 5.89255650988789}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 4.166666666666661}, {52.75044883428479, 
      8.333333333333321}, {52.75044883428479, 11.78511301977578}, {
      50.67375799589206, 5.89255650988789}, {50.67375799589206, 
      4.166666666666661}}], 
     PolygonBox[{{52.75044883428479, 8.333333333333321}, {56.42197458095559, 
      12.499999999999984`}, {56.4219745809556, 17.67766952966367}, {
      52.75044883428479, 11.78511301977578}, {52.75044883428479, 
      8.333333333333321}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 5.8925565098878945`}, {
      50.67375799589207, 7.216878364870319}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 5.8925565098878945`}, {52.75044883428479,
       11.785113019775789`}, {52.75044883428478, 14.433756729740638`}, {
      50.67375799589207, 7.216878364870319}, {50.67375799589206, 
      5.8925565098878945`}}], 
     PolygonBox[{{52.75044883428479, 11.785113019775789`}, {56.42197458095559,
       17.677669529663685`}, {56.42197458095559, 21.65063509461096}, {
      52.75044883428478, 14.433756729740638`}, {52.75044883428479, 
      11.785113019775789`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589207, 7.216878364870319}, {
      50.67375799589206, 8.049381885742234}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589207, 7.216878364870319}, {52.75044883428478, 
      14.433756729740638`}, {52.75044883428479, 16.098763771484467`}, {
      50.67375799589206, 8.049381885742234}, {50.67375799589207, 
      7.216878364870319}}], 
     PolygonBox[{{52.75044883428478, 14.433756729740638`}, {56.42197458095559,
       21.65063509461096}, {56.42197458095559, 24.148145657226703`}, {
      52.75044883428479, 16.098763771484467`}, {52.75044883428478, 
      14.433756729740638`}}], 
     PolygonBox[{{50., 0.}, {50.67375799589206, 8.049381885742234}, {
      50.67375799589206, 8.333333333333332}, {50., 0.}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.049381885742234}, {52.75044883428479, 
      16.098763771484467`}, {52.75044883428479, 16.666666666666664`}, {
      50.67375799589206, 8.333333333333332}, {50.67375799589206, 
      8.049381885742234}}], 
     PolygonBox[{{52.75044883428479, 16.098763771484467`}, {56.42197458095559,
       24.148145657226703`}, {56.42197458095559, 25.}, {52.75044883428479, 
      16.666666666666664`}, {52.75044883428479, 16.098763771484467`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQ7VUZ4cxs5uPAAAaWDjC+x9UN99+oWsD5z363sE5Y
Zgrn70gTPlC91hDOZwLr14Tz3XeV1h15KAnnnz5/fv3sybdtYHw7iPwBGP/v
fxDQgPO3Q8w/4A3lP4HYfwDNfQfQ3A/ne6LJP0PTvwtqPozPBnE/nB+O5r4b
t28f3rLuyx4Y3wTNf98h7ndAcz+c/xgt/NzRwhcW/gAEpJZ5
       "]], {}}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
       24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
       56.42197458095559, 25.}}], 
      LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
       24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
       21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
      LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
       21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
       17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
      LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
       17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
       12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
      LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
       12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
       6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
      LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
       6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
       56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
       6.470476127563024}}], 
      LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       56.42197458095559, -6.470476127563016}, {56.42197458095559, 
       1.5308084989341915`*^-15}}], 
      LineBox[{{56.42197458095559, -6.470476127563016}, {
       60., -6.470476127563016}, {60., -12.499999999999995`}, {
       56.42197458095559, -12.499999999999995`}, {
       56.42197458095559, -6.470476127563016}}], 
      LineBox[{{56.42197458095559, -12.499999999999995`}, {
       60., -12.499999999999995`}, {60., -17.677669529663685`}, {
       56.42197458095559, -17.677669529663685`}, {
       56.42197458095559, -12.499999999999995`}}], 
      LineBox[{{56.42197458095559, -17.677669529663685`}, {
       60., -17.677669529663685`}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -17.677669529663685`}}], 
      LineBox[{{56.4219745809556, -21.650635094610962`}, {
       60., -21.650635094610962`}, {60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {
       56.4219745809556, -21.650635094610962`}}], 
      LineBox[{{56.42197458095559, -24.148145657226706`}, {
       60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
       56.42197458095559, -24.148145657226706`}}], 
      LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
       60., -24.148145657226706`}, {
       56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}], 
      LineBox[{{56.42197458095559, -24.14814565722671}, {
       60., -24.14814565722671}, {60., -21.65063509461097}, {
       56.42197458095559, -21.65063509461097}, {
       56.42197458095559, -24.14814565722671}}], 
      LineBox[{{56.42197458095559, -21.65063509461097}, {
       60., -21.65063509461097}, {60., -17.677669529663692`}, {
       56.42197458095559, -17.677669529663692`}, {
       56.42197458095559, -21.65063509461097}}], 
      LineBox[{{56.42197458095559, -17.677669529663696`}, {
       60., -17.677669529663696`}, {60., -12.50000000000001}, {
       56.42197458095559, -12.50000000000001}, {
       56.42197458095559, -17.677669529663696`}}], 
      LineBox[{{56.42197458095559, -12.50000000000001}, {
       60., -12.50000000000001}, {60., -6.470476127563038}, {
       56.42197458095559, -6.470476127563038}, {
       56.42197458095559, -12.50000000000001}}], 
      LineBox[{{56.42197458095559, -6.470476127563038}, {
       60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
       56.42197458095559, -2.6796885989305705`*^-14}, {
       56.42197458095559, -6.470476127563038}}], 
      LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
       56.42197458095559, 6.470476127563007}, {
       56.42197458095559, -4.592425496802574*^-15}}], 
      LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
       6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
       12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
      LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
       12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
       17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
      LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
       17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
       21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
      LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
       21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
       24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
      LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
       24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
       56.42197458095559, 24.148145657226703`}}]}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {150., -75.}, {150., 75.}, {150., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {0., -75.}, {0., -75.}, {150., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -75}, {0, 75}, {0, 75}, {0, -75}, {0, -75}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 75.}, {150., 75.}, {150., 75.}, {0., 75.}, {0., 75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {150., 75.}, {0., 75.}, {0., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {0., -75.}, {0., 75.}, {150., 
       75.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., -18.}, {53.223211750877866`, -18.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.5}, {51.787526330610106`, -13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -9.}, {50.78673366752143, -9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -4.5}, {50.19556052328608, -4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 4.5}, {50.19556052328608, 4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 9.}, {50.78673366752143, 9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 13.5}, {51.787526330610106`, 13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 18.}, {53.223211750877866`, 18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {13.242852038111415`, -75.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{
       53.223211750877866`, -18.}, {-7.105427357601002*^-15, \
-63.63201530129004}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, -13.5}, {0., -43.60535968352995}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, -9.}, {0., -27.46800903375247}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, -4.5}, {0., -13.308881081455137`}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, 4.5}, {0., 13.308881081455137`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, 9.}, {0., 27.46800903375247}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, 13.5}, {0., 43.60535968352995}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, 18.}, {-7.105427357601002*^-15, 
       63.63201530129004}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {13.242852038111415`, 75.}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQzfv3yk/Fid4ODCDQYHbAiveh8aQ5XhA+g9GBU1Fr
V5594gnlax8ICw3bsDkFxlc60Ph5ogKHJIwvdIARTMP4DAxo8g5o+h3QzHdA
s98BzX0OJi+NpMJrtCD8A0EHoNbsTTg358HTC/4wPsPfTtHcmrOucD6v8bKC
8+XWcP6zdLuVqvO04Hx0AJWH+wOqH86Hmg/jw+xHd58DAJS7WDQ=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367625642058*^9, 3.566087068206744*^9, 
  3.5661018612979393`*^9, 3.566139325568569*^9, 3.614707890112914*^9},
 CellTags->"RG20.",
 CellLabel->
  "During evaluation of \
In[96]:=",ExpressionUUID->"1f94aaa2-ade9-4bec-bfc7-f25f81cef97f"]
}, Open  ]],

Cell[TextData[{
 "We can instead add the reflective behavior of a mirror onto the second \
surface of the lens by using ",
 StyleBox["{2}", "Input"],
 " instead of ",
 StyleBox["{1}", "Input"],
 " for the surface number specification."
}], "Text",
 CellTags->"RG20.",ExpressionUUID->"903c2994-bd9a-4764-aaef-410e2d6aafb0"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tLineOfRays[45,NumberOfRays->11],
\tTransferTraits[mirror,lens,{2}],
\tBoundary[150]},PlotType->TopView];\
\>", "Input",
 CellTags->"RG20.",
 CellLabel->"In[98]:=",ExpressionUUID->"abbf1530-e66c-40fe-b97e-867ec8f43908"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {60., -25.}, {
      60., -16.66666666666667}, {52.75044883428479, -16.666666666666668`}, {
      56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      60., -16.66666666666667}, {60., -8.333333333333336}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60., -8.333333333333336}, {60., -7.105427357601002*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {60., 8.333333333333332}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {60., 
      8.333333333333332}, {60., 16.666666666666664`}, {52.75044883428479, 
      16.666666666666664`}, {50.67375799589206, 8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {60., 
      16.666666666666664`}, {60., 24.999999999999996`}, {56.42197458095559, 
      24.999999999999993`}, {52.75044883428479, 16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {60., 25.}, {60., 
       16.666666666666668`}, {60., 8.333333333333336}, {60., 
       3.552713678800501*^-15}, {60., -8.333333333333329}, {
       60., -16.666666666666657`}, {60., -24.999999999999993`}, {
       56.42197458095559, -25.}}], 
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.061616997868383*^-15}, {
        60., 2.551347498223653*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.551347498223653*^-15}, {60., 2.0410779985789223`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0410779985789223`*^-15}, {60., 1.530808498934192*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., 1.0205389992894611`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0205389992894611`*^-15}, {60., 5.102694996447307*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.102694996447308*^-16}, {60., 2.5493082627129206`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{60., 0.}, {60., 8.333333333333332}, {60., 
       8.049381885742235}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 8.333333333333332}, {60., 16.666666666666664`}, {60., 
       16.09876377148447}, {60., 8.049381885742235}, {60., 
       8.333333333333332}}], 
      PolygonBox[{{60., 16.666666666666664`}, {60., 25.}, {60., 
       24.148145657226706`}, {60., 16.09876377148447}, {60., 
       16.666666666666664`}}], 
      PolygonBox[{{60., 0.}, {60., 8.049381885742235}, {60., 
       7.216878364870323}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 8.049381885742235}, {60., 16.09876377148447}, {60., 
       14.433756729740645`}, {60., 7.216878364870323}, {60., 
       8.049381885742235}}], 
      PolygonBox[{{60., 16.09876377148447}, {60., 24.148145657226706`}, {60., 
       21.65063509461097}, {60., 14.433756729740645`}, {60., 
       16.09876377148447}}], 
      PolygonBox[{{60., 0.}, {60., 7.216878364870323}, {60., 
       5.892556509887896}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 7.216878364870323}, {60., 14.433756729740645`}, {60., 
       11.785113019775793`}, {60., 5.892556509887896}, {60., 
       7.216878364870323}}], 
      PolygonBox[{{60., 14.433756729740645`}, {60., 21.65063509461097}, {60., 
       17.67766952966369}, {60., 11.785113019775793`}, {60., 
       14.433756729740645`}}], 
      PolygonBox[{{60., 0.}, {60., 5.892556509887896}, {60., 
       4.166666666666668}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 5.892556509887896}, {60., 11.785113019775793`}, {60., 
       8.333333333333336}, {60., 4.166666666666668}, {60., 
       5.892556509887896}}], 
      PolygonBox[{{60., 11.785113019775793`}, {60., 17.67766952966369}, {60., 
       12.500000000000004`}, {60., 8.333333333333336}, {60., 
       11.785113019775793`}}], 
      PolygonBox[{{60., 0.}, {60., 4.166666666666668}, {60., 
       2.156825375854341}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 4.166666666666668}, {60., 8.333333333333336}, {60., 
       4.313650751708682}, {60., 2.156825375854341}, {60., 
       4.166666666666668}}], 
      PolygonBox[{{60., 8.333333333333336}, {60., 12.500000000000004`}, {60., 
       6.470476127563024}, {60., 4.313650751708682}, {60., 
       8.333333333333336}}], 
      PolygonBox[{{60., 0.}, {60., 2.156825375854341}, {60., 
       2.3606412073533245`*^-15}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 2.156825375854341}, {60., 4.313650751708682}, {60., 
       4.721282414706649*^-15}, {60., 2.3606412073533245`*^-15}, {60., 
       2.156825375854341}}], 
      PolygonBox[{{60., 4.313650751708682}, {60., 6.470476127563024}, {60., 
       7.0819236220599744`*^-15}, {60., 4.721282414706649*^-15}, {60., 
       4.313650751708682}}], 
      PolygonBox[{{60., 0.}, {60., 5.102694996447305*^-16}, {
       60., -2.1568253758543383`}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 5.102694996447305*^-16}, {60., 
       1.020538999289461*^-15}, {60., -4.313650751708677}, {
       60., -2.1568253758543383`}, {60., 5.102694996447305*^-16}}], 
      PolygonBox[{{60., 1.020538999289461*^-15}, {60., 
       1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
       60., -4.313650751708677}, {60., 1.020538999289461*^-15}}], 
      PolygonBox[{{60., 0.}, {60., -2.1568253758543383`}, {
       60., -4.166666666666664}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -2.1568253758543383`}, {60., -4.313650751708677}, {
       60., -8.333333333333329}, {60., -4.166666666666664}, {
       60., -2.1568253758543383`}}], 
      PolygonBox[{{60., -4.313650751708677}, {60., -6.470476127563016}, {
       60., -12.499999999999995`}, {60., -8.333333333333329}, {
       60., -4.313650751708677}}], 
      PolygonBox[{{60., 0.}, {60., -4.166666666666664}, {
       60., -5.8925565098878945`}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -4.166666666666664}, {60., -8.333333333333329}, {
       60., -11.785113019775789`}, {60., -5.8925565098878945`}, {
       60., -4.166666666666664}}], 
      PolygonBox[{{60., -8.333333333333329}, {60., -12.499999999999995`}, {
       60., -17.677669529663685`}, {60., -11.785113019775789`}, {
       60., -8.333333333333329}}], 
      PolygonBox[{{60., 0.}, {60., -5.8925565098878945`}, {
       60., -7.216878364870323}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -5.8925565098878945`}, {60., -11.785113019775789`}, {
       60., -14.433756729740645`}, {60., -7.216878364870323}, {
       60., -5.8925565098878945`}}], 
      PolygonBox[{{60., -11.785113019775789`}, {60., -17.677669529663685`}, {
       60., -21.65063509461097}, {60., -14.433756729740645`}, {
       60., -11.785113019775789`}}], 
      PolygonBox[{{60., 0.}, {60., -7.21687836487032}, {
       60., -8.049381885742235}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -7.21687836487032}, {60., -14.43375672974064}, {
       60., -16.09876377148447}, {60., -8.049381885742235}, {
       60., -7.21687836487032}}], 
      PolygonBox[{{60., -14.43375672974064}, {60., -21.650635094610962`}, {
       60., -24.148145657226706`}, {60., -16.09876377148447}, {
       60., -14.43375672974064}}], 
      PolygonBox[{{60., 0.}, {60., -8.049381885742235}, {
       60., -8.333333333333332}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -8.049381885742235}, {60., -16.09876377148447}, {
       60., -16.666666666666664`}, {60., -8.333333333333332}, {
       60., -8.049381885742235}}], 
      PolygonBox[{{60., -16.09876377148447}, {60., -24.148145657226706`}, {
       60., -25.}, {60., -16.666666666666664`}, {60., -16.09876377148447}}], 
      PolygonBox[{{60., 0.}, {60., -8.333333333333332}, {
       60., -8.049381885742235}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -8.333333333333332}, {60., -16.666666666666664`}, {
       60., -16.09876377148447}, {60., -8.049381885742235}, {
       60., -8.333333333333332}}], 
      PolygonBox[{{60., -16.666666666666664`}, {60., -25.}, {
       60., -24.148145657226706`}, {60., -16.09876377148447}, {
       60., -16.666666666666664`}}], 
      PolygonBox[{{60., 0.}, {60., -8.049381885742235}, {
       60., -7.216878364870323}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -8.049381885742235}, {60., -16.09876377148447}, {
       60., -14.433756729740645`}, {60., -7.216878364870323}, {
       60., -8.049381885742235}}], 
      PolygonBox[{{60., -16.09876377148447}, {60., -24.14814565722671}, {
       60., -21.65063509461097}, {60., -14.433756729740645`}, {
       60., -16.09876377148447}}], 
      PolygonBox[{{60., 0.}, {60., -7.216878364870323}, {
       60., -5.892556509887897}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -7.216878364870323}, {60., -14.433756729740645`}, {
       60., -11.785113019775794`}, {60., -5.892556509887897}, {
       60., -7.216878364870323}}], 
      PolygonBox[{{60., -14.433756729740645`}, {60., -21.65063509461097}, {
       60., -17.677669529663692`}, {60., -11.785113019775794`}, {
       60., -14.433756729740645`}}], 
      PolygonBox[{{60., 0.}, {60., -5.892556509887898}, {
       60., -4.16666666666667}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -5.892556509887898}, {60., -11.785113019775796`}, {
       60., -8.33333333333334}, {60., -4.16666666666667}, {
       60., -5.892556509887898}}], 
      PolygonBox[{{60., -11.785113019775796`}, {60., -17.677669529663696`}, {
       60., -12.50000000000001}, {60., -8.33333333333334}, {
       60., -11.785113019775796`}}], 
      PolygonBox[{{60., 0.}, {60., -4.16666666666667}, {
       60., -2.156825375854346}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -4.16666666666667}, {60., -8.33333333333334}, {
       60., -4.313650751708692}, {60., -2.156825375854346}, {
       60., -4.16666666666667}}], 
      PolygonBox[{{60., -8.33333333333334}, {60., -12.50000000000001}, {
       60., -6.470476127563038}, {60., -4.313650751708692}, {
       60., -8.33333333333334}}], 
      PolygonBox[{{60., 0.}, {60., -2.156825375854346}, {
       60., -8.932295329768568*^-15}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -2.156825375854346}, {60., -4.313650751708692}, {
       60., -1.7864590659537137`*^-14}, {60., -8.932295329768568*^-15}, {
       60., -2.156825375854346}}], 
      PolygonBox[{{60., -4.313650751708692}, {60., -6.470476127563038}, {
       60., -2.6796885989305705`*^-14}, {60., -1.7864590659537137`*^-14}, {
       60., -4.313650751708692}}], 
      PolygonBox[{{60., 0.}, {60., -1.5308084989341913`*^-15}, {60., 
       2.1568253758543356`}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -1.5308084989341913`*^-15}, {
       60., -3.0616169978683826`*^-15}, {60., 4.313650751708671}, {60., 
       2.1568253758543356`}, {60., -1.5308084989341913`*^-15}}], 
      PolygonBox[{{60., -3.0616169978683826`*^-15}, {
       60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {60., 
       4.313650751708671}, {60., -3.0616169978683826`*^-15}}], 
      PolygonBox[{{60., 0.}, {60., 2.1568253758543356`}, {60., 
       4.166666666666661}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 2.1568253758543356`}, {60., 4.313650751708671}, {60., 
       8.333333333333321}, {60., 4.166666666666661}, {60., 
       2.1568253758543356`}}], 
      PolygonBox[{{60., 4.313650751708671}, {60., 6.470476127563007}, {60., 
       12.499999999999984`}, {60., 8.333333333333321}, {60., 
       4.313650751708671}}], 
      PolygonBox[{{60., 0.}, {60., 4.166666666666661}, {60., 
       5.89255650988789}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 4.166666666666661}, {60., 8.333333333333321}, {60., 
       11.78511301977578}, {60., 5.89255650988789}, {60., 
       4.166666666666661}}], 
      PolygonBox[{{60., 8.333333333333321}, {60., 12.499999999999984`}, {60., 
       17.67766952966367}, {60., 11.78511301977578}, {60., 
       8.333333333333321}}], 
      PolygonBox[{{60., 0.}, {60., 5.8925565098878945`}, {60., 
       7.216878364870319}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 5.8925565098878945`}, {60., 11.785113019775789`}, {
       60., 14.433756729740638`}, {60., 7.216878364870319}, {60., 
       5.8925565098878945`}}], 
      PolygonBox[{{60., 11.785113019775789`}, {60., 17.677669529663685`}, {
       60., 21.65063509461096}, {60., 14.433756729740638`}, {60., 
       11.785113019775789`}}], 
      PolygonBox[{{60., 0.}, {60., 7.216878364870319}, {60., 
       8.049381885742234}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 7.216878364870319}, {60., 14.433756729740638`}, {60., 
       16.098763771484467`}, {60., 8.049381885742234}, {60., 
       7.216878364870319}}], 
      PolygonBox[{{60., 14.433756729740638`}, {60., 21.65063509461096}, {60., 
       24.148145657226703`}, {60., 16.098763771484467`}, {60., 
       14.433756729740638`}}], 
      PolygonBox[{{60., 0.}, {60., 8.049381885742234}, {60., 
       8.333333333333332}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 8.049381885742234}, {60., 16.098763771484467`}, {60., 
       16.666666666666664`}, {60., 8.333333333333332}, {60., 
       8.049381885742234}}], 
      PolygonBox[{{60., 16.098763771484467`}, {60., 24.148145657226703`}, {
       60., 25.}, {60., 16.666666666666664`}, {60., 16.098763771484467`}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQF+DhDa0gHG97i64f4bVQs4/9nvFtYJy0zh/B1p
wgeq1xrC+RCzNOF8912ldUceSsL5p8+fXz978m0bGN8OIn8Axv/7HwQ04Pzt
EPPh/CcQ++F8qPvgfKj74XxPNPlnaPp3oZnPBnE/nB+O5r4bt28f3rLuyx4Y
3wTNf98h7ofzt6OFz2O08HNHC1+o+x0AKkRu6w==
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{56.42197458095559, 25.}, {60., 25.}, {60., 
        24.148145657226706`}, {56.42197458095559, 24.148145657226706`}, {
        56.42197458095559, 25.}}], 
       LineBox[{{56.42197458095559, 24.148145657226706`}, {60., 
        24.148145657226706`}, {60., 21.65063509461097}, {56.42197458095559, 
        21.65063509461097}, {56.42197458095559, 24.148145657226706`}}], 
       LineBox[{{56.42197458095559, 21.65063509461097}, {60., 
        21.65063509461097}, {60., 17.67766952966369}, {56.42197458095559, 
        17.67766952966369}, {56.42197458095559, 21.65063509461097}}], 
       LineBox[{{56.42197458095559, 17.67766952966369}, {60., 
        17.67766952966369}, {60., 12.500000000000004`}, {56.42197458095559, 
        12.500000000000004`}, {56.42197458095559, 17.67766952966369}}], 
       LineBox[{{56.42197458095559, 12.500000000000004`}, {60., 
        12.500000000000004`}, {60., 6.470476127563024}, {56.42197458095559, 
        6.470476127563024}, {56.42197458095559, 12.500000000000004`}}], 
       LineBox[{{56.42197458095559, 6.470476127563024}, {60., 
        6.470476127563024}, {60., 7.0819236220599744`*^-15}, {
        56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
        6.470476127563024}}], 
       LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
        1.5308084989341915`*^-15}, {60., -6.470476127563016}, {
        56.42197458095559, -6.470476127563016}, {56.42197458095559, 
        1.5308084989341915`*^-15}}], 
       LineBox[{{56.42197458095559, -6.470476127563016}, {
        60., -6.470476127563016}, {60., -12.499999999999995`}, {
        56.42197458095559, -12.499999999999995`}, {
        56.42197458095559, -6.470476127563016}}], 
       LineBox[{{56.42197458095559, -12.499999999999995`}, {
        60., -12.499999999999995`}, {60., -17.677669529663685`}, {
        56.42197458095559, -17.677669529663685`}, {
        56.42197458095559, -12.499999999999995`}}], 
       LineBox[{{56.42197458095559, -17.677669529663685`}, {
        60., -17.677669529663685`}, {60., -21.65063509461097}, {
        56.42197458095559, -21.65063509461097}, {
        56.42197458095559, -17.677669529663685`}}], 
       LineBox[{{56.4219745809556, -21.650635094610962`}, {
        60., -21.650635094610962`}, {60., -24.148145657226706`}, {
        56.42197458095559, -24.148145657226706`}, {
        56.4219745809556, -21.650635094610962`}}], 
       LineBox[{{56.42197458095559, -24.148145657226706`}, {
        60., -24.148145657226706`}, {60., -25.}, {56.42197458095559, -25.}, {
        56.42197458095559, -24.148145657226706`}}], 
       LineBox[{{56.42197458095559, -25.}, {60., -25.}, {
        60., -24.148145657226706`}, {
        56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}],
        LineBox[{{56.42197458095559, -24.14814565722671}, {
        60., -24.14814565722671}, {60., -21.65063509461097}, {
        56.42197458095559, -21.65063509461097}, {
        56.42197458095559, -24.14814565722671}}], 
       LineBox[{{56.42197458095559, -21.65063509461097}, {
        60., -21.65063509461097}, {60., -17.677669529663692`}, {
        56.42197458095559, -17.677669529663692`}, {
        56.42197458095559, -21.65063509461097}}], 
       LineBox[{{56.42197458095559, -17.677669529663696`}, {
        60., -17.677669529663696`}, {60., -12.50000000000001}, {
        56.42197458095559, -12.50000000000001}, {
        56.42197458095559, -17.677669529663696`}}], 
       LineBox[{{56.42197458095559, -12.50000000000001}, {
        60., -12.50000000000001}, {60., -6.470476127563038}, {
        56.42197458095559, -6.470476127563038}, {
        56.42197458095559, -12.50000000000001}}], 
       LineBox[{{56.42197458095559, -6.470476127563038}, {
        60., -6.470476127563038}, {60., -2.6796885989305705`*^-14}, {
        56.42197458095559, -2.6796885989305705`*^-14}, {
        56.42197458095559, -6.470476127563038}}], 
       LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
        60., -4.592425496802574*^-15}, {60., 6.470476127563007}, {
        56.42197458095559, 6.470476127563007}, {
        56.42197458095559, -4.592425496802574*^-15}}], 
       LineBox[{{56.42197458095559, 6.470476127563007}, {60., 
        6.470476127563007}, {60., 12.499999999999984`}, {56.42197458095559, 
        12.499999999999984`}, {56.42197458095559, 6.470476127563007}}], 
       LineBox[{{56.42197458095559, 12.499999999999984`}, {60., 
        12.499999999999984`}, {60., 17.67766952966367}, {56.4219745809556, 
        17.67766952966367}, {56.42197458095559, 12.499999999999984`}}], 
       LineBox[{{56.42197458095559, 17.677669529663685`}, {60., 
        17.677669529663685`}, {60., 21.65063509461096}, {56.42197458095559, 
        21.65063509461096}, {56.42197458095559, 17.677669529663685`}}], 
       LineBox[{{56.42197458095559, 21.65063509461096}, {60., 
        21.65063509461096}, {60., 24.148145657226703`}, {56.42197458095559, 
        24.148145657226703`}, {56.42197458095559, 21.65063509461096}}], 
       LineBox[{{56.42197458095559, 24.148145657226703`}, {60., 
        24.148145657226703`}, {60., 25.}, {56.42197458095559, 25.}, {
        56.42197458095559, 24.148145657226703`}}]}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {150., -75.}, {150., 75.}, {150., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {0., -75.}, {0., -75.}, {150., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -75}, {0, 75}, {0, 75}, {0, -75}, {0, -75}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 75.}, {150., 75.}, {150., 75.}, {0., 75.}, {0., 75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {150., 75.}, {0., 75.}, {0., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {0., -75.}, {0., 75.}, {150., 
       75.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., -18.}, {53.223211750877866`, -18.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.5}, {51.787526330610106`, -13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -9.}, {50.78673366752143, -9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -4.5}, {50.19556052328608, -4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 4.5}, {50.19556052328608, 4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 9.}, {50.78673366752143, 9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 13.5}, {51.787526330610106`, 13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 18.}, {53.223211750877866`, 18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {60., -21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, -18.}, {60., -17.155974562461154`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, -13.5}, {
       60., -12.749674310000062`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, -9.}, {60., -8.44728950710319}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, -4.5}, {60., -4.208514513218614}}]}, 
     {Arrowheads[Small], ArrowBox[{{50.00000000000001, 0.}, {60., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, 4.5}, {60., 4.208514513218614}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, 9.}, {60., 8.44728950710319}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, 13.5}, {60., 12.749674310000062`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, 18.}, {60., 17.155974562461154`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {60., 21.7192607925394}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -21.7192607925394}, {
       54.35913041950905, -20.81422344913986}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -17.155974562461154`}, {
       52.60612638434527, -16.23509328594077}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -12.749674310000062`}, {
       51.398523985331096`, -11.963807750722092`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -8.44728950710319}, {
       50.60257086616028, -7.8835309549144466`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., -4.208514513218614}, {
       50.1479982892435, -3.915615003639165}}]}, 
     {Arrowheads[Small], ArrowBox[{{60., 0.}, {50., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 4.208514513218614}, {50.1479982892435, 
       3.915615003639165}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 8.44728950710319}, {50.60257086616028, 
       7.8835309549144466`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 12.749674310000062`}, {51.398523985331096`, 
       11.963807750722092`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 17.155974562461154`}, {52.60612638434527, 
       16.23509328594077}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 21.7192607925394}, {54.35913041950905, 
       20.81422344913986}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{
       54.35913041950905, -20.81422344913986}, {-7.105427357601002*^-15, 
       12.700025153137155`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.60612638434527, -16.23509328594077}, {0., 
       5.351614089262775}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.398523985331096`, -11.963807750722092`}, {
       7.105427357601002*^-15, 2.3601206515248663`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.60257086616028, -7.8835309549144466`}, {0., 
       0.987319309702869}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.1479982892435, -3.915615003639165}, {0., 
       0.3450507346058145}}]}, 
     {Arrowheads[Small], ArrowBox[{{50., 0.}, {0., 0.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.1479982892435, 3.915615003639165}, {
       0., -0.3450507346058145}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.60257086616028, 7.8835309549144466`}, {
       0., -0.987319309702869}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.398523985331096`, 11.963807750722092`}, {
       7.105427357601002*^-15, -2.3601206515248663`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.60612638434527, 16.23509328594077}, {
       0., -5.351614089262775}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.35913041950905, 
       20.81422344913986}, {-7.105427357601002*^-15, \
-12.700025153137155`}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQzfv3yk/Fid4ODCDQYHbAiveh8aQ5XhA+g9GBU1Fr
V5594gnlax8ICw3bsDkFxlc60Ph5ogKHJIwvdIARTMP4DAxo8g5o+h3QzHdA
s98BzX1QcT+HEoe1lYo7TA/A+AHH33x6q24I53OarPC/Wq8J5/ttiVRkfqoA
56/ll7nSclUAzmdAAXB5BzT9cD7UfDgfaj+6+xyUU/3/fNf1dtDYuPZTwQWT
A7sYFvdM9fVy+DT/mpC+jcGBaVdrrzJt9nRQ/b7QtOKt+gGV6ye5FH09He4V
bgzb0yF/QEJ00eyPQp4OmbebvuoG80PdiwhfNHkHNP0OaOY7oNmP7j6YuXu/
GKdtykzThNujcVKijTdDFMa3feC3/H3bQya4fIOTzSq5Ge/tYfwZ71XX+ote
g/PRAVR+P5p+GB9m/gE0+2F8mPsOAACTz8kp
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367626201981*^9, 3.566087068626449*^9, 
  3.566101862128296*^9, 3.566139326504966*^9, 3.6147078905959263`*^9},
 CellTags->"RG20.",
 CellLabel->
  "During evaluation of \
In[98]:=",ExpressionUUID->"420bdebb-b64e-48c3-a46d-705a04a995a4"]
}, Open  ]],

Cell[TextData[{
 "Furthermore, by rotating the mirror slightly first, ",
 StyleBox["TransferTraits", "Input"],
 " will transfer not only the reflective characteristic of the mirror, but \
also the amount of rotation imposed on the mirror surface."
}], "Text",
 CellTags->"RG20.",ExpressionUUID->"88237dc9-3747-4b9e-a1f4-b3d3ba2baf0d"],

Cell[CellGroupData[{

Cell["\<\
AnalyzeSystem[{
\tLineOfRays[45,NumberOfRays->11],
\tTransferTraits[Move[mirror,0,4],lens,{2}],
\tBoundary[150]},PlotType->TopView];\
\>", "Input",
 CellTags->"RG20.",
 CellLabel->"In[99]:=",ExpressionUUID->"ef932c33-bb50-4eda-89fa-95ac4b400788"],

Cell[BoxData[
 GraphicsBox[{
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], 
    {GrayLevel[0.5], EdgeForm[None], 
     PolygonBox[{{56.42197458095559, -25.}, {
      61.74391184360313, -24.939101256495604`}, {
      61.16260789573542, -16.626067504330408`}, {
      52.75044883428479, -16.666666666666668`}, {56.42197458095559, -25.}}], 
     PolygonBox[{{52.75044883428479, -16.666666666666668`}, {
      61.16260789573542, -16.626067504330408`}, {
      60.58130394786771, -8.313033752165204}, {
      50.67375799589206, -8.333333333333336}, {
      52.75044883428479, -16.666666666666668`}}], 
     PolygonBox[{{50.67375799589206, -8.333333333333336}, {
      60.58130394786771, -8.313033752165204}, {
      60., -7.088118893675416*^-15}, {50., 0.}, {
      50.67375799589206, -8.333333333333336}}], 
     PolygonBox[{{50., 0.}, {60., 0.}, {59.41869605213229, 8.3130337521652}, {
      50.67375799589206, 8.333333333333329}, {50., 0.}}], 
     PolygonBox[{{50.67375799589206, 8.333333333333329}, {59.41869605213229, 
      8.3130337521652}, {58.83739210426458, 16.6260675043304}, {
      52.75044883428479, 16.666666666666664`}, {50.67375799589206, 
      8.333333333333329}}], 
     PolygonBox[{{52.75044883428479, 16.666666666666664`}, {58.83739210426458,
       16.6260675043304}, {58.25608815639687, 24.9391012564956}, {
      56.42197458095559, 24.999999999999993`}, {52.75044883428479, 
      16.666666666666664`}}], 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{56.42197458095559, -25.}, {
       52.75044883428479, -16.666666666666668`}, {
       50.67375799589206, -8.333333333333336}, {
       50., -3.552713678800501*^-15}, {50.67375799589206, 
       8.333333333333329}, {52.75044883428478, 16.666666666666657`}, {
       56.42197458095559, 24.999999999999993`}, {58.25608815639687, 
       24.939101256495604`}, {58.83739210426458, 16.626067504330404`}, {
       59.41869605213229, 8.313033752165204}, {60., 3.544059446837708*^-15}, {
       60.58130394786771, -8.313033752165197}, {
       61.16260789573542, -16.626067504330393`}, {
       61.74391184360313, -24.939101256495597`}, {56.42197458095559, -25.}}], 
      
      {GrayLevel[0.5], EdgeForm[None], 
       PolygonBox[{{56.42197458095559, 0.}, {60., 3.054159052737908*^-15}, {
        60., 2.5451325439482567`*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}, {56.42197458095559, 0.}}], 
       PolygonBox[{{52.75044883428479, 5.102694996447305*^-16}, {60., 
        2.5451325439482567`*^-15}, {60., 2.0361060351586054`*^-15}, {
        50.67375799589206, 1.020538999289461*^-15}, {52.75044883428479, 
        5.102694996447305*^-16}}], 
       PolygonBox[{{50.67375799589206, 1.020538999289461*^-15}, {60., 
        2.0361060351586054`*^-15}, {60., 1.5270795263689544`*^-15}, {50., 
        1.5308084989341915`*^-15}, {50.67375799589206, 
        1.020538999289461*^-15}}], 
       PolygonBox[{{50., 1.5308084989341915`*^-15}, {60., 
        1.527079526368954*^-15}, {60., 1.0180530175793027`*^-15}, {
        50.67375799589206, 2.041077998578922*^-15}, {50., 
        1.5308084989341915`*^-15}}], 
       PolygonBox[{{50.67375799589206, 2.041077998578922*^-15}, {60., 
        1.0180530175793027`*^-15}, {60., 5.0902650878965145`*^-16}, {
        52.75044883428479, 2.5513474982236525`*^-15}, {50.67375799589206, 
        2.041077998578922*^-15}}], 
       PolygonBox[{{52.75044883428479, 2.5513474982236525`*^-15}, {60., 
        5.090265087896515*^-16}, {60., 2.5430982759127372`*^-31}, {
        56.42197458095559, 3.0616169978683826`*^-15}, {52.75044883428479, 
        2.5513474982236525`*^-15}}], 
       {GrayLevel[0], AbsoluteThickness[0.5], 
        LineBox[{{56.42197458095559, 0.}, {52.75044883428479, 0.}, {
         50.67375799589206, 0.}, {50., 0.}, {50.67375799589206, 0.}, {
         52.75044883428478, 0.}, {56.42197458095559, 0.}, {60., 0.}, {60., 
         0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {60., 0.}, {
         56.42197458095559, 0.}}]}}}}, {{}, 
     {GrayLevel[0.5], EdgeForm[None], 
      PolygonBox[{{60., 0.}, {59.41869605213229, 8.3130337521652}, {
       59.43850350383078, 8.029773996029085}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.41869605213229, 8.3130337521652}, {58.83739210426458, 
       16.6260675043304}, {58.87700700766157, 16.05954799205817}, {
       59.43850350383078, 8.029773996029085}, {59.41869605213229, 
       8.3130337521652}}], 
      PolygonBox[{{58.83739210426458, 16.6260675043304}, {58.25608815639687, 
       24.939101256495604`}, {58.31551051149235, 24.089321988087256`}, {
       58.87700700766157, 16.05954799205817}, {58.83739210426458, 
       16.6260675043304}}], 
      PolygonBox[{{60., 0.}, {59.43850350383078, 8.029773996029085}, {
       59.49657601382638, 7.199298411892537}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.43850350383078, 8.029773996029085}, {58.87700700766157, 
       16.05954799205817}, {58.993152027652755`, 14.398596823785073`}, {
       59.49657601382638, 7.199298411892537}, {59.43850350383078, 
       8.029773996029085}}], 
      PolygonBox[{{58.87700700766157, 16.05954799205817}, {58.31551051149235, 
       24.089321988087256`}, {58.48972804147913, 21.597895235677612`}, {
       58.993152027652755`, 14.398596823785073`}, {58.87700700766157, 
       16.05954799205817}}], 
      PolygonBox[{{60., 0.}, {59.49657601382638, 7.199298411892537}, {
       59.58895603653223, 5.878202538388663}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.49657601382638, 7.199298411892537}, {
       58.993152027652755`, 14.398596823785073`}, {59.17791207306446, 
       11.756405076777327`}, {59.58895603653223, 5.878202538388663}, {
       59.49657601382638, 7.199298411892537}}], 
      PolygonBox[{{58.993152027652755`, 14.398596823785073`}, {
       58.48972804147913, 21.597895235677612`}, {58.76686810959669, 
       17.63460761516599}, {59.17791207306446, 11.756405076777327`}, {
       58.993152027652755`, 14.398596823785073`}}], 
      PolygonBox[{{60., 0.}, {59.58895603653223, 5.878202538388663}, {
       59.709348026066145`, 4.156516876082602}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.58895603653223, 5.878202538388663}, {59.17791207306446, 
       11.756405076777327`}, {59.41869605213229, 8.313033752165204}, {
       59.709348026066145`, 4.156516876082602}, {59.58895603653223, 
       5.878202538388663}}], 
      PolygonBox[{{59.17791207306446, 11.756405076777327`}, {
       58.76686810959669, 17.63460761516599}, {59.128044078198435`, 
       12.469550628247806`}, {59.41869605213229, 8.313033752165204}, {
       59.17791207306446, 11.756405076777327`}}], 
      PolygonBox[{{60., 0.}, {59.709348026066145`, 4.156516876082602}, {
       59.84954746729856, 2.151571457640424}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.709348026066145`, 4.156516876082602}, {
       59.41869605213229, 8.313033752165204}, {59.699094934597106`, 
       4.303142915280848}, {59.84954746729856, 2.151571457640424}, {
       59.709348026066145`, 4.156516876082602}}], 
      PolygonBox[{{59.41869605213229, 8.313033752165204}, {
       59.128044078198435`, 12.469550628247806`}, {59.54864240189566, 
       6.454714372921273}, {59.699094934597106`, 4.303142915280848}, {
       59.41869605213229, 8.313033752165204}}], 
      PolygonBox[{{60., 0.}, {59.84954746729856, 2.151571457640424}, {60., 
       2.3548908040176238`*^-15}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.84954746729856, 2.151571457640424}, {
       59.699094934597106`, 4.303142915280848}, {60., 
       4.7097816080352475`*^-15}, {60., 2.3548908040176238`*^-15}, {
       59.84954746729856, 2.151571457640424}}], 
      PolygonBox[{{59.699094934597106`, 4.303142915280848}, {
       59.54864240189566, 6.454714372921273}, {60., 
       7.0646724120528725`*^-15}, {60., 4.7097816080352475`*^-15}, {
       59.699094934597106`, 4.303142915280848}}], 
      PolygonBox[{{60., 0.}, {60., 5.090265087896513*^-16}, {
       60.15045253270144, -2.1515714576404212`}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., 5.090265087896513*^-16}, {60., 
       1.0180530175793025`*^-15}, {
       60.300905065402894`, -4.3031429152808425`}, {
       60.15045253270144, -2.1515714576404212`}, {60., 
       5.090265087896513*^-16}}], 
      PolygonBox[{{60., 1.0180530175793025`*^-15}, {60., 
       1.527079526368954*^-15}, {60.45135759810434, -6.454714372921265}, {
       60.300905065402894`, -4.3031429152808425`}, {60., 
       1.0180530175793025`*^-15}}], 
      PolygonBox[{{60., 0.}, {60.15045253270144, -2.1515714576404212`}, {
       60.290651973933855`, -4.156516876082598}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.15045253270144, -2.1515714576404212`}, {
       60.300905065402894`, -4.3031429152808425`}, {
       60.58130394786771, -8.313033752165197}, {
       60.290651973933855`, -4.156516876082598}, {
       60.15045253270144, -2.1515714576404212`}}], 
      PolygonBox[{{60.300905065402894`, -4.3031429152808425`}, {
       60.45135759810434, -6.454714372921265}, {
       60.871955921801565`, -12.469550628247797`}, {
       60.58130394786771, -8.313033752165197}, {
       60.300905065402894`, -4.3031429152808425`}}], 
      PolygonBox[{{60., 0.}, {60.290651973933855`, -4.156516876082598}, {
       60.41104396346777, -5.878202538388662}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.290651973933855`, -4.156516876082598}, {
       60.58130394786771, -8.313033752165197}, {
       60.82208792693554, -11.756405076777323`}, {
       60.41104396346777, -5.878202538388662}, {
       60.290651973933855`, -4.156516876082598}}], 
      PolygonBox[{{60.58130394786771, -8.313033752165197}, {
       60.871955921801565`, -12.469550628247797`}, {
       61.23313189040331, -17.634607615165987`}, {
       60.82208792693554, -11.756405076777323`}, {
       60.58130394786771, -8.313033752165197}}], 
      PolygonBox[{{60., 0.}, {60.41104396346777, -5.878202538388662}, {
       60.50342398617362, -7.199298411892537}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.41104396346777, -5.878202538388662}, {
       60.82208792693554, -11.756405076777323`}, {
       61.006847972347245`, -14.398596823785073`}, {
       60.50342398617362, -7.199298411892537}, {
       60.41104396346777, -5.878202538388662}}], 
      PolygonBox[{{60.82208792693554, -11.756405076777323`}, {
       61.23313189040331, -17.634607615165987`}, {
       61.51027195852087, -21.597895235677612`}, {
       61.006847972347245`, -14.398596823785073`}, {
       60.82208792693554, -11.756405076777323`}}], 
      PolygonBox[{{60., 0.}, {60.50342398617362, -7.199298411892534}, {
       60.56149649616922, -8.029773996029085}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.50342398617362, -7.199298411892534}, {
       61.006847972347245`, -14.398596823785068`}, {
       61.12299299233843, -16.05954799205817}, {
       60.56149649616922, -8.029773996029085}, {
       60.50342398617362, -7.199298411892534}}], 
      PolygonBox[{{61.006847972347245`, -14.398596823785068`}, {
       61.51027195852087, -21.597895235677605`}, {
       61.68448948850765, -24.089321988087256`}, {
       61.12299299233843, -16.05954799205817}, {
       61.006847972347245`, -14.398596823785068`}}], 
      PolygonBox[{{60., 0.}, {60.56149649616922, -8.029773996029085}, {
       60.58130394786771, -8.3130337521652}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.56149649616922, -8.029773996029085}, {
       61.12299299233843, -16.05954799205817}, {
       61.16260789573542, -16.6260675043304}, {
       60.58130394786771, -8.3130337521652}, {
       60.56149649616922, -8.029773996029085}}], 
      PolygonBox[{{61.12299299233843, -16.05954799205817}, {
       61.68448948850765, -24.089321988087256`}, {
       61.74391184360313, -24.939101256495604`}, {
       61.16260789573542, -16.6260675043304}, {
       61.12299299233843, -16.05954799205817}}], 
      PolygonBox[{{60., 0.}, {60.58130394786771, -8.3130337521652}, {
       60.56149649616922, -8.029773996029085}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.58130394786771, -8.3130337521652}, {
       61.16260789573542, -16.6260675043304}, {
       61.12299299233843, -16.05954799205817}, {
       60.56149649616922, -8.029773996029085}, {
       60.58130394786771, -8.3130337521652}}], 
      PolygonBox[{{61.16260789573542, -16.6260675043304}, {
       61.74391184360313, -24.939101256495604`}, {
       61.68448948850765, -24.089321988087256`}, {
       61.12299299233843, -16.05954799205817}, {
       61.16260789573542, -16.6260675043304}}], 
      PolygonBox[{{60., 0.}, {60.56149649616922, -8.029773996029085}, {
       60.50342398617362, -7.199298411892537}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.56149649616922, -8.029773996029085}, {
       61.12299299233843, -16.05954799205817}, {
       61.006847972347245`, -14.398596823785073`}, {
       60.50342398617362, -7.199298411892537}, {
       60.56149649616922, -8.029773996029085}}], 
      PolygonBox[{{61.12299299233843, -16.05954799205817}, {
       61.68448948850765, -24.08932198808726}, {
       61.51027195852087, -21.597895235677612`}, {
       61.006847972347245`, -14.398596823785073`}, {
       61.12299299233843, -16.05954799205817}}], 
      PolygonBox[{{60., 0.}, {60.50342398617362, -7.199298411892537}, {
       60.41104396346777, -5.878202538388664}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.50342398617362, -7.199298411892537}, {
       61.006847972347245`, -14.398596823785073`}, {
       60.82208792693554, -11.756405076777328`}, {
       60.41104396346777, -5.878202538388664}, {
       60.50342398617362, -7.199298411892537}}], 
      PolygonBox[{{61.006847972347245`, -14.398596823785073`}, {
       61.51027195852087, -21.597895235677612`}, {
       61.23313189040331, -17.634607615165994`}, {
       60.82208792693554, -11.756405076777328`}, {
       61.006847972347245`, -14.398596823785073`}}], 
      PolygonBox[{{60., 0.}, {60.41104396346777, -5.878202538388665}, {
       60.290651973933855`, -4.156516876082604}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.41104396346777, -5.878202538388665}, {
       60.82208792693554, -11.75640507677733}, {
       60.58130394786771, -8.313033752165207}, {
       60.290651973933855`, -4.156516876082604}, {
       60.41104396346777, -5.878202538388665}}], 
      PolygonBox[{{60.82208792693554, -11.75640507677733}, {
       61.23313189040331, -17.634607615165997`}, {
       60.871955921801565`, -12.469550628247813`}, {
       60.58130394786771, -8.313033752165207}, {
       60.82208792693554, -11.75640507677733}}], 
      PolygonBox[{{60., 0.}, {60.290651973933855`, -4.156516876082604}, {
       60.15045253270144, -2.151571457640429}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.290651973933855`, -4.156516876082604}, {
       60.58130394786771, -8.313033752165207}, {
       60.300905065402894`, -4.303142915280858}, {
       60.15045253270144, -2.151571457640429}, {
       60.290651973933855`, -4.156516876082604}}], 
      PolygonBox[{{60.58130394786771, -8.313033752165207}, {
       60.871955921801565`, -12.469550628247813`}, {
       60.45135759810434, -6.454714372921287}, {
       60.300905065402894`, -4.303142915280858}, {
       60.58130394786771, -8.313033752165207}}], 
      PolygonBox[{{60., 0.}, {60.15045253270144, -2.151571457640429}, {
       60., -8.910536707280845*^-15}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60.15045253270144, -2.151571457640429}, {
       60.300905065402894`, -4.303142915280858}, {
       60., -1.782107341456169*^-14}, {60., -8.910536707280845*^-15}, {
       60.15045253270144, -2.151571457640429}}], 
      PolygonBox[{{60.300905065402894`, -4.303142915280858}, {
       60.45135759810434, -6.454714372921287}, {
       60., -2.6731610121842537`*^-14}, {60., -1.782107341456169*^-14}, {
       60.300905065402894`, -4.303142915280858}}], 
      PolygonBox[{{60., 0.}, {60., -1.5270795263689538`*^-15}, {
       59.84954746729856, 2.1515714576404186`}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{60., -1.5270795263689538`*^-15}, {
       60., -3.0541590527379075`*^-15}, {59.699094934597106`, 
       4.303142915280837}, {59.84954746729856, 2.1515714576404186`}, {
       60., -1.5270795263689538`*^-15}}], 
      PolygonBox[{{60., -3.0541590527379075`*^-15}, {
       60., -4.581238579106862*^-15}, {59.54864240189566, 
       6.454714372921256}, {59.699094934597106`, 4.303142915280837}, {
       60., -3.0541590527379075`*^-15}}], 
      PolygonBox[{{60., 0.}, {59.84954746729856, 2.1515714576404186`}, {
       59.709348026066145`, 4.156516876082595}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.84954746729856, 2.1515714576404186`}, {
       59.699094934597106`, 4.303142915280837}, {59.41869605213229, 
       8.31303375216519}, {59.709348026066145`, 4.156516876082595}, {
       59.84954746729856, 2.1515714576404186`}}], 
      PolygonBox[{{59.699094934597106`, 4.303142915280837}, {
       59.54864240189566, 6.454714372921256}, {59.128044078198435`, 
       12.469550628247786`}, {59.41869605213229, 8.31303375216519}, {
       59.699094934597106`, 4.303142915280837}}], 
      PolygonBox[{{60., 0.}, {59.709348026066145`, 4.156516876082595}, {
       59.58895603653223, 5.878202538388657}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.709348026066145`, 4.156516876082595}, {
       59.41869605213229, 8.31303375216519}, {59.17791207306446, 
       11.756405076777314`}, {59.58895603653223, 5.878202538388657}, {
       59.709348026066145`, 4.156516876082595}}], 
      PolygonBox[{{59.41869605213229, 8.31303375216519}, {59.128044078198435`,
        12.469550628247786`}, {58.76686810959669, 17.634607615165972`}, {
       59.17791207306446, 11.756405076777314`}, {59.41869605213229, 
       8.31303375216519}}], 
      PolygonBox[{{60., 0.}, {59.58895603653223, 5.878202538388662}, {
       59.49657601382638, 7.199298411892533}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.58895603653223, 5.878202538388662}, {59.17791207306446, 
       11.756405076777323`}, {58.993152027652755`, 14.398596823785066`}, {
       59.49657601382638, 7.199298411892533}, {59.58895603653223, 
       5.878202538388662}}], 
      PolygonBox[{{59.17791207306446, 11.756405076777323`}, {
       58.76686810959669, 17.634607615165987`}, {58.48972804147913, 
       21.5978952356776}, {58.993152027652755`, 14.398596823785066`}, {
       59.17791207306446, 11.756405076777323`}}], 
      PolygonBox[{{60., 0.}, {59.49657601382638, 7.199298411892533}, {
       59.43850350383079, 8.029773996029084}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.49657601382638, 7.199298411892533}, {
       58.993152027652755`, 14.398596823785066`}, {58.87700700766157, 
       16.059547992058167`}, {59.43850350383079, 8.029773996029084}, {
       59.49657601382638, 7.199298411892533}}], 
      PolygonBox[{{58.993152027652755`, 14.398596823785066`}, {
       58.48972804147913, 21.5978952356776}, {58.31551051149235, 
       24.089321988087253`}, {58.87700700766157, 16.059547992058167`}, {
       58.993152027652755`, 14.398596823785066`}}], 
      PolygonBox[{{60., 0.}, {59.43850350383079, 8.029773996029084}, {
       59.41869605213229, 8.3130337521652}, {60., 0.}, {60., 0.}}], 
      PolygonBox[{{59.43850350383079, 8.029773996029084}, {58.87700700766157, 
       16.059547992058167`}, {58.83739210426458, 16.6260675043304}, {
       59.41869605213229, 8.3130337521652}, {59.43850350383079, 
       8.029773996029084}}], 
      PolygonBox[{{58.87700700766157, 16.059547992058167`}, {
       58.31551051149235, 24.089321988087253`}, {58.25608815639687, 
       24.939101256495604`}, {58.83739210426458, 16.6260675043304}, {
       58.87700700766157, 16.059547992058167`}}], 
      {GrayLevel[0], AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQzeWvUX9cwdfhh/uCDxkfLBw2GTMsS9LwdWBa5nnu
rpiFgzL3xIz1dr4OGaubV/LPNHUQ7fi6WyPJ18HkHcfS0kWGDq3qU/YnT/B1
+AXWr+EwbzXXK8tjvg7295mWLrgo6cAABn4OwYJM3plNt22SQr6KHrP0czCD
yB+ovpHtMCffz+ErRP+B1+VcLtfn+jkYQ8w/cPdL3vSAg34OaRD7D/id+R85
97ofzH0Hvm243mBx3w/mfrg8M1Qeph/qfrj5ZlDzYfb/g9oPc58/1H0w9//r
cfxxbuGXPTD/6UD9B/P/e6j/YeEDdT88/FKh4QcLX0Zo+KKHPwCWNLcS
        "]]}, 
      {GrayLevel[0], AbsoluteThickness[0.5], 
       LineBox[{{56.42197458095559, 25.}, {58.25608815639687, 
        24.939101256495604`}, {58.31551051149235, 24.089321988087256`}, {
        56.42197458095559, 24.148145657226706`}, {56.42197458095559, 25.}}], 
       LineBox[{{56.42197458095559, 24.148145657226706`}, {58.31551051149235, 
        24.089321988087256`}, {58.48972804147913, 21.597895235677612`}, {
        56.42197458095559, 21.65063509461097}, {56.42197458095559, 
        24.148145657226706`}}], 
       LineBox[{{56.42197458095559, 21.65063509461097}, {58.48972804147913, 
        21.597895235677612`}, {58.76686810959669, 17.63460761516599}, {
        56.42197458095559, 17.67766952966369}, {56.42197458095559, 
        21.65063509461097}}], 
       LineBox[{{56.42197458095559, 17.67766952966369}, {58.76686810959669, 
        17.63460761516599}, {59.128044078198435`, 12.469550628247806`}, {
        56.42197458095559, 12.500000000000004`}, {56.42197458095559, 
        17.67766952966369}}], 
       LineBox[{{56.42197458095559, 12.500000000000004`}, {
        59.128044078198435`, 12.469550628247806`}, {59.54864240189566, 
        6.454714372921273}, {56.42197458095559, 6.470476127563024}, {
        56.42197458095559, 12.500000000000004`}}], 
       LineBox[{{56.42197458095559, 6.470476127563024}, {59.54864240189566, 
        6.454714372921273}, {60., 7.0646724120528725`*^-15}, {
        56.42197458095559, 7.0819236220599744`*^-15}, {56.42197458095559, 
        6.470476127563024}}], 
       LineBox[{{56.42197458095559, 1.5308084989341915`*^-15}, {60., 
        1.527079526368954*^-15}, {60.45135759810434, -6.454714372921265}, {
        56.42197458095559, -6.470476127563016}, {56.42197458095559, 
        1.5308084989341915`*^-15}}], 
       LineBox[{{56.42197458095559, -6.470476127563016}, {
        60.45135759810434, -6.454714372921265}, {
        60.871955921801565`, -12.469550628247797`}, {
        56.42197458095559, -12.499999999999995`}, {
        56.42197458095559, -6.470476127563016}}], 
       LineBox[{{56.42197458095559, -12.499999999999995`}, {
        60.871955921801565`, -12.469550628247797`}, {
        61.23313189040331, -17.634607615165987`}, {
        56.42197458095559, -17.677669529663685`}, {
        56.42197458095559, -12.499999999999995`}}], 
       LineBox[{{56.42197458095559, -17.677669529663685`}, {
        61.23313189040331, -17.634607615165987`}, {
        61.51027195852087, -21.597895235677612`}, {
        56.42197458095559, -21.65063509461097}, {
        56.42197458095559, -17.677669529663685`}}], 
       LineBox[{{56.4219745809556, -21.650635094610962`}, {
        61.51027195852087, -21.597895235677605`}, {
        61.68448948850765, -24.089321988087256`}, {
        56.42197458095559, -24.148145657226706`}, {
        56.4219745809556, -21.650635094610962`}}], 
       LineBox[{{56.42197458095559, -24.148145657226706`}, {
        61.68448948850765, -24.089321988087256`}, {
        61.74391184360313, -24.939101256495604`}, {56.42197458095559, -25.}, {
        56.42197458095559, -24.148145657226706`}}], 
       LineBox[{{56.42197458095559, -25.}, {
        61.74391184360313, -24.939101256495604`}, {
        61.68448948850765, -24.089321988087256`}, {
        56.42197458095559, -24.148145657226706`}, {56.42197458095559, -25.}}],
        LineBox[{{56.42197458095559, -24.14814565722671}, {
        61.68448948850765, -24.08932198808726}, {
        61.51027195852087, -21.597895235677612`}, {
        56.42197458095559, -21.65063509461097}, {
        56.42197458095559, -24.14814565722671}}], 
       LineBox[{{56.42197458095559, -21.65063509461097}, {
        61.51027195852087, -21.597895235677612`}, {
        61.23313189040331, -17.634607615165994`}, {
        56.42197458095559, -17.677669529663692`}, {
        56.42197458095559, -21.65063509461097}}], 
       LineBox[{{56.42197458095559, -17.677669529663696`}, {
        61.23313189040331, -17.634607615165997`}, {
        60.871955921801565`, -12.469550628247813`}, {
        56.42197458095559, -12.50000000000001}, {
        56.42197458095559, -17.677669529663696`}}], 
       LineBox[{{56.42197458095559, -12.50000000000001}, {
        60.871955921801565`, -12.469550628247813`}, {
        60.45135759810434, -6.454714372921287}, {
        56.42197458095559, -6.470476127563038}, {
        56.42197458095559, -12.50000000000001}}], 
       LineBox[{{56.42197458095559, -6.470476127563038}, {
        60.45135759810434, -6.454714372921287}, {
        60., -2.6731610121842537`*^-14}, {
        56.42197458095559, -2.6796885989305705`*^-14}, {
        56.42197458095559, -6.470476127563038}}], 
       LineBox[{{56.42197458095559, -4.592425496802574*^-15}, {
        60., -4.581238579106862*^-15}, {59.54864240189566, 
        6.454714372921256}, {56.42197458095559, 6.470476127563007}, {
        56.42197458095559, -4.592425496802574*^-15}}], 
       LineBox[{{56.42197458095559, 6.470476127563007}, {59.54864240189566, 
        6.454714372921256}, {59.128044078198435`, 12.469550628247786`}, {
        56.42197458095559, 12.499999999999984`}, {56.42197458095559, 
        6.470476127563007}}], 
       LineBox[{{56.42197458095559, 12.499999999999984`}, {
        59.128044078198435`, 12.469550628247786`}, {58.76686810959669, 
        17.634607615165972`}, {56.4219745809556, 17.67766952966367}, {
        56.42197458095559, 12.499999999999984`}}], 
       LineBox[{{56.42197458095559, 17.677669529663685`}, {58.76686810959669, 
        17.634607615165987`}, {58.48972804147913, 21.5978952356776}, {
        56.42197458095559, 21.65063509461096}, {56.42197458095559, 
        17.677669529663685`}}], 
       LineBox[{{56.42197458095559, 21.65063509461096}, {58.48972804147913, 
        21.5978952356776}, {58.31551051149235, 24.089321988087253`}, {
        56.42197458095559, 24.148145657226703`}, {56.42197458095559, 
        21.65063509461096}}], 
       LineBox[{{56.42197458095559, 24.148145657226703`}, {58.31551051149235, 
        24.089321988087253`}, {58.25608815639687, 24.939101256495604`}, {
        56.42197458095559, 25.}, {56.42197458095559, 
        24.148145657226703`}}]}}}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None], {}, {
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {150., -75.}, {150., 75.}, {150., 
       75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {0., -75.}, {0., -75.}, {150., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0, -75}, {0, 75}, {0, 75}, {0, -75}, {0, -75}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{0., 75.}, {150., 75.}, {150., 75.}, {0., 75.}, {0., 75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., -75.}, {150., 75.}, {0., 75.}, {0., -75.}, {
       150., -75.}}]}, 
     {GrayLevel[0], AbsoluteThickness[0.5], 
      LineBox[{{150., 75.}, {150., -75.}, {0., -75.}, {0., 75.}, {150., 
       75.}}]}}, 
    {RGBColor[
     0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
     AbsoluteThickness[0.5], Arrowheads[Small], 
     ArrowBox[{{0., -22.5}, {55.13384936237171, -22.5}}], 
     {Arrowheads[Small], ArrowBox[{{0., -18.}, {53.223211750877866`, -18.}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{0., -13.5}, {51.787526330610106`, -13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -9.}, {50.78673366752143, -9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., -4.5}, {50.19556052328608, -4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 0.}, {50.00000000000001, 0.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 4.5}, {50.19556052328608, 4.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 9.}, {50.78673366752143, 9.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 13.5}, {51.787526330610106`, 13.5}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 18.}, {53.223211750877866`, 18.}}]}, 
     {Arrowheads[Small], ArrowBox[{{0., 22.5}, {55.13384936237171, 22.5}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, -22.5}, {
       61.501908366222096`, -21.478290293505655`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, -18.}, {
       61.18930478324572, -17.007850782708104`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, -13.5}, {
       60.885884336553765`, -12.668736239104033`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, -9.}, {
       60.58822444683637, -8.412001498245917}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, -4.5}, {
       60.293677470795, -4.199783496954531}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.00000000000001, 0.}, {60., 1.3160531514142608`*^-17}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.19556052328608, 4.5}, {59.70509892115632, 
       4.217281907287726}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.78673366752143, 9.}, {59.406819607250874`, 
       8.482874826730532}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.787526330610106`, 13.5}, {59.102723397971445`, 
       12.83165322556691}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{53.223211750877866`, 18.}, {58.78979756879808, 
       17.306701071680042`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{55.13384936237171, 22.5}, {58.46400865042464, 
       21.965699663473792`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.501908366222096`, -21.478290293505655`}, {
       54.59468414989931, -21.343853804324674`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{61.18930478324572, -17.007850782708104`}, {
       52.91288160454506, -17.137949219013493`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.885884336553765`, -12.668736239104033`}, {
       51.685452543872245`, -13.115447014616135`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.58822444683637, -8.412001498245917}, {
       50.82096369288934, -9.192177680187244}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60.293677470795, -4.199783496954531}, {
       50.27205530075018, -5.305667640000377}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{60., 1.3160531514142608`*^-17}, {
       50.018970200245256`, -1.4027422592469745`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.70509892115632, 4.217281907287726}, {50.063641727539434`, 
       2.568735358087422}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.406819607250874`, 8.482874826730532}, {50.4302955854847, 
       6.667492745615344}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{59.102723397971445`, 12.83165322556691}, {51.17298455841387, 
       10.968787315447594`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{58.78979756879808, 17.306701071680042`}, {52.39551383476961, 
       15.581458849167275`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{58.46400865042464, 21.965699663473792`}, {
       54.302393284066305`, 20.684225551999532`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.59468414989931, -21.343853804324674`}, {
       0., -5.290489970111288}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.91288160454506, -17.137949219013493`}, {
       0., -8.429194611537804}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.685452543872245`, -13.115447014616135`}, {
       0., -9.903941385036243}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.82096369288934, -9.192177680187244}, {
       0., -10.630330753320383`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.27205530075018, -5.305667640000377}, {
       0., -11.04983491641444}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.018970200245256`, -1.4027422592469745`}, {
       0., -11.466145409758393`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.063641727539434`, 2.568735358087422}, {
       0., -12.186289802722595`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{50.4302955854847, 6.667492745615344}, {
       0., -13.662002241314948`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{51.17298455841387, 10.968787315447594`}, {
       0., -16.82033477054474}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{52.39551383476961, 15.581458849167275`}, {
       7.105427357601002*^-15, -24.481639978610808`}}]}, 
     {Arrowheads[Small], 
      ArrowBox[{{54.302393284066305`, 20.684225551999532`}, {
       0., -66.0352749194548}}]}}, 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQAWIQzfv3yk/Fid4ODCDQYHbAiveh8aQ5XhA+g9GBU1Fr
V5594gnlax8ICw3bsDkFxlc60Ph5ogKHJIwvdIARTMP4DAxo8g5o+h3QzHdA
s98BzX0OCxw7O+wO+DncnTnBurDK9IBK0zxl6xl+Dlt+uTUxMRke2H8kb0VK
oZ+DusnKGSlhmgci3/t88PL2c+Da63jn4yWFA5WBepbTVf0cOM62cU85I3AA
Yo+fwwUhWe/ZEXk2N9KL1znc8nU45/Bdtf6egMNZR7NVQlt8HUT3dsZZf1dw
UMoM5FLr9XWouDGr+NxKTYcoSxMxiVRfh4nNCt+a/QwdXAPXLkqxBupPuCFu
8d3UwWCR+Rw5H2+Hf7o9Z9kiTA/wBb3zvVni5fBF+8biAGXDA2JFG1/sue7p
8D6F4b60tdaBhyKzwkQzPR1O3nwmk5qkdKBsm+vWS0qewHAQ+cBgKXqg+PKk
ublMng5Gb5nuLSz8tn+dRWOmKoenw77mGfJHe1gc+hb9fSNs7ulw+sMj8+bV
Ug4PepZFq0wD6neUfMLyQdVh984WowVGXg7hnlk/t2jqOyif2XFpi5q3w4c3
D9I115vA423FsafGZZqiB2B828iM1P23FeD8qWV70i+eU4bzlSLTtu1yUoXz
b6QGfGuWVIPz2/RL5qx6h+DrdbckJMZrwPlyyw2+fgzShvOfOS0uZbxkAOPb
xk35ctCn2gIuHx2956NjU8ABAMZ/8ac=
      "]]}}, 
   {AbsolutePointSize[1], AbsoluteThickness[1], EdgeForm[None]}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  FormatType:>TraditionalForm,
  GridLines:>None,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367626905622*^9, 3.5660870693368797`*^9, 
  3.566101862937282*^9, 3.566139327681723*^9, 3.614707891233761*^9},
 CellTags->"RG20.",
 CellLabel->
  "During evaluation of \
In[99]:=",ExpressionUUID->"94792538-1c94-42d8-a7b3-a5f9c4b05b93"]
}, Open  ]],

Cell[TextData[{
 "If the donor component contains more than one surface, then only the traits \
from a single surface (specified by the ",
 StyleBox["DonorSurfaceNumber", "Input"],
 " option) will be used. In general, the ",
 StyleBox["surfacenumbers",
  FontSlant->"Italic"],
 " parameter of ",
 StyleBox["TransferTraits", "Input"],
 " can pass either: a list of integers, ",
 StyleBox["First", "Input"],
 ", ",
 StyleBox["Last", "Input"],
 ", or ",
 StyleBox["All", "Input"],
 " as a setting. ",
 StyleBox["TransferTraits", "Input"],
 " uses the options: ",
 StyleBox["TransferSurfaceFunction", "Input"],
 ", ",
 StyleBox["TransferDeflectionFunction", "Input"],
 ", ",
 StyleBox["TransferRendering", "Input"],
 ", and ",
 StyleBox["DonorSurfaceNumber", "Input"],
 "."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"RG20.",ExpressionUUID->"976e2ebe-a4ee-4641-912f-e4b68c00761e"],

Cell[TextData[{
 StyleBox["TransferTraits", "Input"],
 " works equally well with both ",
 StyleBox["AnalyzeSystem", "Input"],
 " and ",
 StyleBox["TurboPlot", "Input"],
 " ray-trace functions. Here is an example using ",
 StyleBox["TurboPlot", "Input"],
 ". This time, however, we will make the lens a donor and transfer its shape \
characteristics to the mirror by using the ",
 StyleBox["TransferSurfaceFunction->True", "Input"],
 " option setting. This time, however, we will use ",
 StyleBox["TransferDeflectionFunction->False", "Input"],
 " in order to not transfer the optical properties of the lens (keeping the \
mirror reflective)."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True,
 CellTags->"RG20.",ExpressionUUID->"d01968e4-b06c-4ae4-92c2-862d9e2ad656"],

Cell[CellGroupData[{

Cell[TextData[{
 "TurboPlot[{\n\tLineOfRays[45,NumberOfRays->11],\n\t\
TransferTraits[lens,mirror,{1},",
 StyleBox["TransferSurfaceFunction", "Input"],
 "->True,",
 StyleBox["TransferDeflectionFunction", "Input"],
 "->False],\n\tBoundary[150]},PlotType->TopView];"
}], "Input",
 CellTags->"RG20.",
 CellLabel->
  "In[100]:=",ExpressionUUID->"9a1deb8c-0770-4dfd-9eb9-1caf516d6659"],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.4, 0.6, 0.8], AbsolutePointSize[1.], AbsoluteThickness[1.], 
   EdgeForm[None], PolygonBox[CompressedData["
1:eJxTTMoPSmVmYGDgAWJWIGYCYs/KCGdmMx8HBjCwPIDO7/CU2MqX4OWwZhUI
GMD5q6F8XOpXo6mH6dd/vG2zbZgnlK+AwUfXT0j9fzDwgNrPsBeNz0BAPQMu
9asg6h1g/BVQPi71K9DUw/TD/APhG2Dw0fUTUu8BDW+IOyzg/H9QPrp61PhB
xPfp8+fXz5782gamXktXdy/j72dwfntX16n0pEM26PrR5dH1w/zTAZZ/BOdD
1F/CMB9dHl0/LLzPgt17G84/DeWj60eXx6W+A82+djT7sJv/CEM/zD+daOGh
iRYeMP3o8jB+F1Q/LD5v3L59eMu6KZYw/im0+ILpBwDcCryu
    "]], 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgAmJ+KO1ZGeHMbObjwAAGlgc6PCW28iV4OaxeBQIGB/Qf
b9tsG+bpsAbMVzjwHww8oOo/7IHJr4DIO7RD9UP4Bg4eUPP/gfVZOKDZ54Bm
nwOafQ5o9tmg2XcAzb4DaPYdQPcfKp+BAWY/jA8zH8ZHtR9Tvh1Nvwea+QNt
HwDlo5o/
      "]],
     FontColor->GrayLevel[0.]]}, 
   {GrayLevel[0.], AbsoluteThickness[0.5], 
    StyleBox[LineBox[CompressedData["
1:eJxTTMoPSmVmYGBgA2JWIGZigIIDSQ4QOsgBjX+AAB9dPXb9cHtw8AnZh1u/
AwE+cfoJ+YeQfYTCh5D7iA9fdPej8zHcDwAEwkb2
      "]],
     FontColor->GrayLevel[0.]]}, 
   {RGBColor[
    0.038747429704798886`, 0.9161617552424038, 0.039847212269181365`], 
    AbsoluteThickness[0.5], LineBox[CompressedData["
1:eJxTTMoPSmVmYGAQA2ImKEYBDWYHeP9e+ak40dsBxkdVYHTAiveh8aQ5Xg4w
Pqq89oFTUWtXnn3i6QDjo8orHQgLDduwOQUmr4QmL3Sg8fNEBQ5JmLwQmjwD
AyOYhMmjAyEHNP1o6pQc0OxHk9d2QHM/mryRA5r/UeUbzBzQwg+df8DgpZFU
eI0WhH8gCGd4Rp2b8+DpBX/c4dklmltz1hVneEoYLys4X26NMzyXpdutVJ2n
dQB/eDIw4ApPqH6c4Qm1H3d4QtyPMzyh/scIT7TwcwAAZh+H4w==
     "]], 
    {RGBColor[0., 0., 0.], AbsolutePointSize[2.5], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQA2IQzfv3yk/Fid4ODCDQYHbAiveh8aQ5XhA+g9GBU1Fr
V5594gnlax8ICw3bsDkFxlc60Ph5ogKHJIwvdIARTMP4DAxo8g5o+h3QzHdA
s98BzX0OBi+NpMJrtCD8A0EHYPZEnZvz4OkFfzifoUs0t+asK5wvYbys4Hy5
NZy/LN1upeo8LYR6NACVh/sDqh/Oh5oP50PtR3efAwA4cFRE
      "]]}}},
  AspectRatio:>Automatic,
  DisplayFunction->Identity,
  PlotRange:>All]], "Print",
 CellChangeTimes->{3.563367627749758*^9, 3.5660870699687567`*^9, 
  3.566101864143839*^9, 3.566139329639606*^9, 3.614707892315011*^9},
 CellTags->"RG20.",
 CellLabel->
  "During evaluation of \
In[100]:=",ExpressionUUID->"5f9bef18-f3bc-4ad0-8ebc-a85d59dcee79"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"6436c37b-2f71-4f5a-\
97f5-1d8c56ab8aed"]
}, Open  ]],

Cell[CellGroupData[{

Cell["21. What's Missing?", "Section",
 CellTags->{
  "What's Missing", "RG21.", 
   "21."},ExpressionUUID->"d39bd8e9-1177-4306-8ca7-77cd6f4afc93"],

Cell[TextData[{
 "This section provides a road map of the features missing from either the \
User Guide discussion or the basic ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package as a whole. The User Guide discussion has been designed to help \
the novice user become familiar with the basic features in ",
 StyleBox["Optica.",
  FontSlant->"Italic"],
 " In some instances, in order to avoid overwhelming the user with the more \
specialized capabilities of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", some topics have been omitted from this discussion. In other instances, \
certain aspects of optical modelling have not been included in the basic ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package, but have instead been incorporated into extensions of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". Finally, there can be occasions when a feature is not yet built into the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " system. This section will help you to determine the status of any \
particular feature not discussed previously in the User Guide discussion. If \
you should discover that a desired feature is missing from ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", then please contact optica support and let us know about it. We will try \
our best to help you to find an appropriate solution to your modelling \
problem. In addition, Optica Software offers a consulting service for custom \
solutions in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"9a73353d-4300-4462-8499-aefb7bebd549"],

Cell[CellGroupData[{

Cell["Features not discussed here", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Features not discussed here", "What's Missing", 
   "RG21."},ExpressionUUID->"e52217ef-ac6b-4840-95cb-6737e8877556"],

Cell[TextData[{
 "The User Guide discussion does not discuss every feature present in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". In particular, there has been no mention about the modelling of: optical \
coatings, polarized elements/polarization ray-tracing, bi-refringence, \
diffraction gratings, customized optical elements, or user-defined surface \
shapes. Nevertheless, all of these capabilities are a part of the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package and is documented further in the companion ",
 ButtonBox["Principles Of Optica",
  BaseStyle->"AddOnsLinkText",
  ButtonData:>"Principles of Rayica"],
 " guide as well as through our website: www.opticasoftware.com."
}], "Text",
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"fd8eec84-ca17-40d5-b500-a4576be18653"],

Cell[TextData[{
 "In addition, the following topics are left for advanced documentation: \
wave-front propagation, coherent point spread functions, analytical solutions \
to optical systems, and Gaussian optics/paraxial analysis. Although ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " can model diffraction gratings, its does not model diffractive behavior in \
general. These items were originally a part of the ",
 StyleBox["Wavica",
  FontSlant->"Italic"],
 " but are now combined within the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " package",
 ". The basic ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " guide is therefore limited to three-dimensional, geometric ray-trace \
calculations, intensity measurements, publication illustrations, and \
optimizations. Most of the topics and examples given in this User's Guide \
will concentrate on the use of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " for endeavors that involve geometric ray-trace calculations."
}], "Text",
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"ceb071e0-1de7-468c-8c8b-c20fe4c299d0"],

Cell[TextData[{
 "The basic package also includes special functions for importing data from \
other ray-trace packages such as Zemax and Code V. Using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Import", "Input"],
 " function, you can also import and export some data formats between \
mechanical CAD packages and ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". You can also build new refractive material models and create your own new \
deflection models with the same mechanisms that enable ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " to model refraction, reflection, and diffraction on optical surfaces. You \
can model new optical components from scratch with the generic building block \
language used by ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " to model its built-in component functions. There is also a built-in \
facility to model bulk material effects such as gain and absorption, as well \
as user-created bulk material behaviors such as photon diffusion and \
graded-index refraction. The ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " database is also fully extensible and ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " provides special functions to help you add your own database items. \
Unfortunately, the complete coverage of the every aspect of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s capabilities is simply too vast to mention within a single introductory \
discussion or even within the scope of a basic user manual. It is the \
expectation of the author that ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s documentation will, by necessity, be an on-going endeavor that is \
continually updated as a result of feedback from the ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "-user community. For this purpose, a new Optica Software web-site \
(www.opticasoftware.com) has been erected to provide on-line documentation, \
additional examples, up-to-date software, and advanced technical support."
}], "Text",
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"b9524a5d-6928-420f-b34f-2b1a1b0c1429"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Features left to the future", "Subsection",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 AspectRatioFixed->True,
 CellTags->{
  "Features left to the future", "What's Missing", 
   "RG21."},ExpressionUUID->"3cdc573b-b05b-4668-b37f-e2d853505dcc"],

Cell[TextData[{
 "Until now, all parts of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " and its extensions have utilized ray-trace calculations for some aspect of \
its package function. Unfortunately, this has left out some important optical \
design tools, which, for example, depend heavily on coupled-wave theory or \
finite element analysis. Such applications include thin film design and \
integrated optics/ optical waveguides. Until now, we simply haven't had the \
time and resources to development these important tools. In general, we \
always welcome possible collaborations with scientists and engineers that \
could lead to such applications in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"d0f11d3d-3d17-45eb-bf31-29c5ff3d53d7"],

Cell[TextData[{
 "Finally, some of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s present limitations are due to the current state of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". In particular, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " does not yet have a simple, built-in facility to generate stand-alone Java \
or C-code. Once available, this will enable high-speed ray-trace capabilities \
that are on par with every other optical design package on the market. In the \
near future, it is likely that ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will be packaged together with the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " engine to permit a single integrated optical design product that has wider \
appeal to non-",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " users."
}], "Text",
 CellTags->{
  "What's Missing", 
   "RG21."},ExpressionUUID->"0315375b-e20d-4040-84d6-b496835f53fd"],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"5d418490-2bed-445c-\
b91b-c390932fd2ef"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["22. Backward Compatibility Issues", "Section",
 CellTags->{
  "Backward Compatibility", "RG22.", 
   "22."},ExpressionUUID->"44e4ee72-4c79-4f62-a2c3-21d1a43cf67f"],

Cell[TextData[{
 "The new ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " system has been rebuilt from the ground up. As a consequence, users of the \
original ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will notice some important changes in the basic functional behavior of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", such as the use of ",
 StyleBox["Source", "Input"],
 " objects to model light sources. Such changes have resulted in many \
important new capabilities for ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". While many of the changes in functional behavior have already been \
discussed in the User Guide presentation, there have also been some important \
changes made to the input formats of certain functions in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " that have not been covered. In this section, we will examine some of these \
input format changes that may affect legacy code from ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " version 1. In general, such format changes have been made to simplify the \
usability of the affected functions. Perhaps the most important format \
changes have been with the ",
 StyleBox["Move", "Input"],
 " functions. These changes to ",
 StyleBox["Move", "Input"],
 " are discussed next."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"1fff4d7f-9ccf-4d2d-85f7-6e2690c95ca1"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Move3D",
  FontFamily->"Courier"],
 " is now obsolete"
}], "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"9ebbfb22-8058-4a5a-9efb-d34b4ab7b580"],

Cell[TextData[{
 "It is no longer necessary to use separate functions for three-dimensional \
positioning. In particular, ",
 StyleBox["Move3D", "Input"],
 ", ",
 StyleBox["MoveLinear3D", "Input"],
 StyleBox[", ", "MathCaption"],
 StyleBox["MoveDirect3D", "Input"],
 ", and ",
 StyleBox["MoveReflected3D", "Input"],
 " functionalities have now been absorbed by the ",
 StyleBox["Move", "Input"],
 ", ",
 StyleBox["MoveLinear", "Input"],
 StyleBox[", ", "MathCaption"],
 StyleBox["MoveDirect", "Input"],
 ", and ",
 StyleBox["MoveReflected", "Input"],
 " functions. However, the original ",
 StyleBox["3D", "Input"],
 " functions will continue to be supported in the new ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " edition."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"b21ddcf9-bf95-4b6a-9be3-5cd62d7c00e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Move[",
  FontFamily->"Courier"],
 StyleBox["object", "Input"],
 ", {x,y,z}",
 StyleBox["]",
  FontFamily->"Courier"],
 " now works"
}], "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"25945faa-a20f-4b29-8cad-53bf25b6ada2"],

Cell[TextData[{
 "There is a new pattern of ",
 StyleBox["Move", "Input"],
 " called ",
 StyleBox["Move[", "Input"],
 StyleBox["object",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 " ",
 StyleBox["{", "Input"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["y",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["z",
  FontSlant->"Italic"],
 StyleBox["}]", "Input"],
 " that gives a simple three-dimensional translation. Unfortunately, this new \
pattern conflicts with an older pattern of ",
 StyleBox["Move", "Input"],
 " and can create a legacy problem for some pre-existing system designs made \
in original ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " edition. This is explained further next."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"dd3bfab9-da54-48f2-bff3-1c9bf08b2cff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Move[",
  FontFamily->"Courier"],
 StyleBox["object", "Input"],
 ", {x,y,angle}",
 StyleBox["]",
  FontFamily->"Courier"],
 " has become ",
 StyleBox["Move[",
  FontFamily->"Courier"],
 StyleBox["object", "Input"],
 ", {x,y}, angle",
 StyleBox["]",
  FontFamily->"Courier"]
}], "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"ddbbf9b1-3e8a-47e2-aa9d-7ca7c0c1cb19"],

Cell[TextData[{
 StyleBox["Move[", "Input"],
 StyleBox["object",
  FontSlant->"Italic"],
 StyleBox[",{", "Input"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["y",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 StyleBox["}]", "Input"],
 " has now been superseded by ",
 StyleBox["Move[", "Input"],
 StyleBox["object",
  FontSlant->"Italic"],
 StyleBox[",{", "Input"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["y",
  FontSlant->"Italic"],
 StyleBox["},", "Input"],
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 StyleBox["]", "Input"],
 ". This change has been made in order to support the ",
 StyleBox["Move[", "Input"],
 StyleBox["object",
  FontSlant->"Italic"],
 StyleBox[",{", "Input"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["y",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["z",
  FontSlant->"Italic"],
 StyleBox["}]", "Input"],
 " format shown previously. Unfortunately, this has adverse implications for \
any legacy code that used ",
 StyleBox["Move[", "Input"],
 StyleBox["object",
  FontSlant->"Italic"],
 StyleBox[",{", "Input"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["y",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["rotationangle",
  FontSlant->"Italic"],
 StyleBox["}]", "Input"],
 "."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"0dde57cf-1cf9-4dfb-85d3-396d9aeb9640"]
}, Open  ]],

Cell[CellGroupData[{

Cell["How to recover version 1 behaviors", "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"889794e7-a81e-4555-9199-a60440190b8f"],

Cell[TextData[{
 "Some of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 "'s new behaviors are irreversible. However, if you are interested to \
recover the original ",
 StyleBox["Move", "Input"],
 " behaviors of Version 1, you can call ",
 StyleBox["SetOptions", "Input"],
 " with ",
 StyleBox["Move", "Input"],
 " as shown."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"887cd1d7-580b-4b04-89b2-dca8ba6d1489"],

Cell[CellGroupData[{

Cell["SetOptions[Move, OpticaVersion->1]", "Input",
 CellTags->{"Backward Compatibility", "RG22."},
 CellLabel->
  "In[101]:=",ExpressionUUID->"56f8e24b-c46a-4879-be75-1e2ebbb6c6e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"MoveGraphicalOutput", "\[Rule]", "True"}], ",", 
   RowBox[{"PositionRelative", "\[Rule]", "True"}], ",", 
   RowBox[{"TiltRelative", "\[Rule]", "True"}], ",", 
   RowBox[{"TwistRelative", "\[Rule]", "True"}], ",", 
   RowBox[{"PositionGroup", "\[Rule]", "True"}], ",", 
   RowBox[{"TiltGroup", "\[Rule]", "True"}], ",", 
   RowBox[{"TwistGroup", "\[Rule]", "True"}], ",", 
   RowBox[{"Group", "\[Rule]", "1"}], ",", 
   RowBox[{"TwistAngle", "\[Rule]", "0"}], ",", 
   RowBox[{"MoveRelative", "\[Rule]", "False"}], ",", 
   RowBox[{"OpticaVersion", "\[Rule]", "1"}], ",", 
   RowBox[{"SymbolicValues", "\[Rule]", 
    RowBox[{"{", "}"}]}], ",", 
   RowBox[{"SymbolicNormalize", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Simplify", "\[Rule]", "False"}], ",", 
   RowBox[{"OutputType", "\[Rule]", "Move"}], ",", 
   RowBox[{"Resonate", "\[Rule]", "False"}], ",", 
   RowBox[{"Alignment", "\[Rule]", "Bottom"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "0.5`"}], ",", 
   RowBox[{"Boundary", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ArrangeSymbols", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\<\"xx\"\>", ",", "\<\"yy\"\>", ",", "\<\"\[Theta]\"\>"}], 
     "}"}]}], ",", 
   RowBox[{"StartIndex", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Print", "\[Rule]", "False"}]}], "}"}]], "Output",
 CellChangeTimes->{3.563367627984067*^9, 3.566087070130972*^9, 
  3.566101864229315*^9, 3.5661393302473097`*^9, 3.614707892394505*^9},
 CellTags->{"Backward Compatibility", "RG22."},
 CellLabel->
  "Out[101]=",ExpressionUUID->"9b05f338-6bae-46d3-b82a-0545bc42aa70"]
}, Open  ]],

Cell[TextData[{
 "Here, the default setting is ",
 StyleBox["OpticaVersion", "Input",
  FontWeight->"Bold"],
 StyleBox["->2", "Input"],
 ". In order to recover many of the default option behaviors from the \
original ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " edition, including the original ",
 StyleBox["Move", "Input"],
 " behaviors, you can call ",
 StyleBox["SetOptions", "Input"],
 " with ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " as shown."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"551560ab-dcf3-4fcf-90f7-f9b2cc52d543"],

Cell[CellGroupData[{

Cell["SetOptions[Optica,OpticaVersion->1]", "Input",
 CellTags->{"Backward Compatibility", "RG22."},
 CellLabel->
  "In[102]:=",ExpressionUUID->"2a32a075-5288-426d-ad6d-9c0059c0028b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"OpticaVersion", "\[Rule]", "1"}], ",", 
   RowBox[{"1", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PropagateSystem", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ModularSystem", "\[Rule]", "True"}], "}"}]}], ",", 
      RowBox[{"Move", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"OpticaVersion", "\[Rule]", "1"}], "}"}]}], ",", 
      RowBox[{"DrawSystem", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ShowArrows", "\[Rule]", "False"}], ",", 
         RowBox[{"ShowLabels", "\[Rule]", "False"}]}], "}"}]}], ",", 
      RowBox[{"ShowSystem", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ShowArrows", "\[Rule]", "False"}], ",", 
         RowBox[{"ShowLabels", "\[Rule]", "False"}]}], "}"}]}], ",", 
      RowBox[{"Boundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"GraphicDesign", "\[Rule]", "Off"}], "}"}]}], ",", 
      RowBox[{"Screen", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"GraphicDesign", "\[Rule]", "Off"}], "}"}]}]}], "}"}]}], ",", 
   
   RowBox[{"2", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PropagateSystem", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ModularSystem", "\[Rule]", "False"}], "}"}]}], ",", 
      RowBox[{"Move", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"OpticaVersion", "\[Rule]", "2"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"3", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PropagateSystem", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"ModularSystem", "\[Rule]", "False"}], "}"}]}], ",", 
      RowBox[{"Move", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"OpticaVersion", "\[Rule]", "3"}], "}"}]}]}], "}"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.563367628064618*^9, 3.566087070162435*^9, 
  3.56610186427028*^9, 3.566139330304995*^9, 3.6147078924527407`*^9},
 CellTags->{"Backward Compatibility", "RG22."},
 CellLabel->
  "Out[102]=",ExpressionUUID->"4eae78a1-49f4-413c-938e-f8b9aab0c576"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "New Function Name Alias: ",
 StyleBox["AnalyzeSystem",
  FontFamily->"Courier"],
 " for ",
 StyleBox["DrawSystem",
  FontFamily->"Courier"]
}], "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"5eb1be0a-f892-4962-8d2e-780097fe1de0"],

Cell[TextData[{
 "Previous users of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " will notice that the new version has adopted a new naming alias for ",
 StyleBox["DrawSystem", "Input"],
 ".that is called ",
 StyleBox["AnalyzeSystem", "Input"],
 ".  Nevertheless, the original ",
 StyleBox["DrawSystem", "Input"],
 " still exists and works the same as before. The only change in ",
 StyleBox["AnalyzeSystem", "Input"],
 " is that the ",
 StyleBox["Options[AnalyzeSystem]", "Input"],
 " contains a reduced subset of the ",
 StyleBox["Options[DrawSystem]", "Input"],
 " in order to reduce option clutter."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"186fd96c-5dd9-49ef-bb4d-be189043c513"]
}, Open  ]],

Cell[CellGroupData[{

Cell["New Parametric Surface Function Format", "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"e1f6db08-382c-49f4-88d1-f6d5f29c9027"],

Cell[TextData[{
 "A new format can now be used to specify parametric surfaces in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". While the original parametric format for ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 " required a distinct ",
 StyleBox["Function", "Input"],
 " to specify each spatial coordinate direction, the new format embeds all \
three coordinates within a single ",
 StyleBox["Function", "Input"],
 " head. In particular, "
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"c468bd9b-f498-4bdb-b335-33f1631ffe9c"],

Cell[TextData[{
 StyleBox["Function[{", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["},{", "Input"],
 StyleBox["xcoordinate",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["],", "Input"],
 " ",
 StyleBox["ycoordinate",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["],", "Input"],
 " ",
 StyleBox["zcoordinate",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["]}]", "Input"]
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"da00a46c-c883-40b8-ae15-e1abff07de6b"],

Cell["can now be used instead of", "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"883028bd-5da7-4eeb-a206-5dd71bc5c1b9"],

Cell[TextData[{
 StyleBox["{Function[{", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["},", "Input"],
 StyleBox["xcoordinate",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["]], Function[{", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["}, ", "Input"],
 StyleBox["ycoordinate",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["]], Function[{", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["},", "Input"],
 StyleBox["zcoordinate",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["]]}", "Input"],
 " "
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"83320e74-4ea2-4842-86f6-e556d83abd72"]
}, Open  ]],

Cell[CellGroupData[{

Cell["New Grating Vector Format", "Subsection",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"5f1d0e95-b0c4-4de5-8869-00cb0ed2b831"],

Cell[TextData[{
 "There is a new coordinate order used to specify grating vectors in ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ". The grating vector now has a different coordinate order that is more \
intuitive. In particular, ",
 StyleBox["Function[{", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["},{", "Input"],
 StyleBox["Gx",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["],", "Input"],
 " ",
 StyleBox["Gy",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["],", "Input"],
 " ",
 StyleBox["Gz",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["]}]", "Input"],
 " for grating functions and ",
 StyleBox["{", "Input"],
 StyleBox["Gx",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox[" Gy",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox[" Gy",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 " for constant grating vectors are now used instead of ",
 StyleBox["Function[{", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["},{", "Input"],
 StyleBox["Gy",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["],", "Input"],
 " ",
 StyleBox["Gz",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["],", "Input"],
 " ",
 StyleBox["Gx",
  FontSlant->"Italic"],
 StyleBox["[", "Input"],
 StyleBox["s",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox["t",
  FontSlant->"Italic"],
 StyleBox["]}]", "Input"],
 " and ",
 StyleBox["{", "Input"],
 StyleBox["Gy",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox[" Gz",
  FontSlant->"Italic"],
 StyleBox[",", "Input"],
 StyleBox[" Gx",
  FontSlant->"Italic"],
 StyleBox["}", "Input"],
 "."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"634a8f1c-56db-4d25-9b47-47ae6bad8c77"],

Cell[TextData[{
 "If you are interested to recover the original ",
 StyleBox["Grating", "Input"],
 " behaviors of ",
 StyleBox["Optica",
  FontSlant->"Italic"],
 ", you can call ",
 StyleBox["SetOptions", "Input"],
 " with ",
 StyleBox["Grating", "Input"],
 " as shown."
}], "Text",
 CellTags->{
  "Backward Compatibility", 
   "RG22."},ExpressionUUID->"bfad9ebf-115f-49c1-9b02-f312fee0821f"],

Cell[CellGroupData[{

Cell["SetOptions[Grating, OpticaVersion->1]", "Input",
 CellTags->{"Backward Compatibility", "RG22."},
 CellLabel->
  "In[103]:=",ExpressionUUID->"ad1429ae-c6a4-4a74-991b-dc7afa9f7a35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Labels", "\[Rule]", "\<\"G\"\>"}], ",", 
   RowBox[{"LabelPositions", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ComponentDescription", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"OffAxis", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}]}], ",", 
   RowBox[{"SurfaceNormalCalculations", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"SurfaceRayIntersections", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"ExtrapolateSurfaceFunction", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"SwitchDirectionOnReflection", "\[Rule]", "False"}], ",", 
   RowBox[{"DoubleSubstrate", "\[Rule]", "False"}], ",", 
   RowBox[{"OpticaVersion", "\[Rule]", "1"}], ",", 
   RowBox[{"SimpleDiffraction", "\[Rule]", "False"}], ",", 
   RowBox[{"ComponentMedium", "\[Rule]", "BK7"}], ",", 
   RowBox[{"Transmittance", "\[Rule]", "100"}], ",", 
   RowBox[{"Reflectance", "\[Rule]", "Reflectance"}], ",", 
   RowBox[{"DiffractedOrders", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.2`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0.8`"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"MismatchCutOff", "\[Rule]", "1.`*^10"}], ",", 
   RowBox[{"EfficiencyFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"1", "&"}], ")"}]}], ",", 
   RowBox[{"VacuumFrequency", "\[Rule]", "False"}], ",", 
   RowBox[{"FollowContour", "\[Rule]", "False"}], ",", 
   RowBox[{"SurfaceGrating", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"GratingMedium", "\[Rule]", "BK7"}], ",", 
   RowBox[{"CoupledWaveTheory", "\[Rule]", "False"}], ",", 
   RowBox[{"GratingThickness", "\[Rule]", "7.5`"}], ",", 
   RowBox[{"GratingModulation", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"BK7", ",", 
       RowBox[{
        RowBox[{"0.028`", " ", "#1"}], "&"}]}], "}"}], "}"}]}], ",", 
   RowBox[{"GratingRotationMatrix", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.`", ",", "0.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "1.`", ",", "0.`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.`", ",", "0.`", ",", "1.`"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Temperature", "\[Rule]", "Temperature"}], ",", 
   RowBox[{"Tension", "\[Rule]", "Tension"}], ",", 
   RowBox[{"GraphicDesign", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"Automatic", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Sketch", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Trace"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Wire", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Mesh"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}]}], "}"}]}], ",", 
   RowBox[{"Solid", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SurfaceRendering", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"Fill", ",", "Trace"}], "}"}], "}"}]}], ",", 
      RowBox[{"EdgeRendering", "\[Rule]", "Fill"}], ",", 
      RowBox[{"CrossRendering", "\[Rule]", "Empty"}]}], "}"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5633676281476927`*^9, 3.566087070197905*^9, 
  3.566101864322369*^9, 3.56613933035417*^9, 3.614707892485654*^9},
 CellTags->{"Backward Compatibility", "RG22."},
 CellLabel->
  "Out[103]=",ExpressionUUID->"1634a1bc-1220-4446-bc19-63db0d4fb6ad"]
}, Open  ]],

Cell[TextData[ButtonBox["Go to list of topics",
 BaseStyle->"Hyperlink",
 ButtonData:>"list of topics"]], "Text",ExpressionUUID->"238c9db7-0b9f-41f7-\
84da-bc2e91f5c039"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"Brackets",
PrintingStyleEnvironment->"Printout",
WindowToolbars->{},
WindowSize->{1144, 752},
WindowMargins->{{218, Automatic}, {Automatic, 70}},
ShowSelection->True,
ShowCellLabel->True,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"HelpBrowser.nb",
PrivateNotebookOptions -> {"ColorPalette" -> {RGBColor, 128}},
RenderingOptions -> {"ObjectDithering" -> True},
RenderingOptions -> {"RasterDithering" -> False},
CharacterEncoding -> Automatic
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "list of topics"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}]},
 "Components and Sources"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[2724, 82, 290, 6, 20, "Outline2",ExpressionUUID->"4a364c6c-e761-4046-a86f-d89ea8625e78",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[3017, 90, 688, 20, 55, "Outline3",ExpressionUUID->"6b27a151-f4f4-4956-b667-3be01c6cdcfb",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[94095, 2370, 1653, 36, 95, "Text",ExpressionUUID->"3a3fa262-4e29-486e-8f42-6aba6019448f",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[95773, 2410, 276, 7, 31, "Subsubsection",ExpressionUUID->"b23d5c84-e672-4ff2-9bd7-b56a49123486",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[96052, 2419, 1149, 20, 72, "Text",ExpressionUUID->"0a9fdeff-c71d-4bda-8c34-871b949d40e1",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[97204, 2441, 222, 5, 20, "Text",ExpressionUUID->"7d0d805f-4722-4877-902c-6e903b587b3f",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[97463, 2451, 300, 7, 35, "Subsection",ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "Modeling a light source", "RG2.", "RG2.1", "2.1"}],
  Cell[97766, 2460, 470, 12, 20, "Text",ExpressionUUID->"5e956b8d-0a1d-4670-9ef7-316f471bb0aa",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[98239, 2474, 4259, 148, 252, "FramedBox",ExpressionUUID->"163be0ce-c836-4a05-b602-043cfeb767c5",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[102501, 2624, 181, 3, 26, "Commentary",ExpressionUUID->"27a68c2a-97e8-4545-9c15-783313072250",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[102685, 2629, 426, 13, 21, "Text",ExpressionUUID->"0d4877d2-630c-4e99-8871-bfb21f4e30b2",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[103136, 2646, 196, 2, 24, "Input",ExpressionUUID->"8f30dbd1-2c32-4f9c-9b9c-6b2fa197b05a",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[103335, 2650, 4626, 131, 120, "Output",ExpressionUUID->"98f38436-b1e7-4aef-a162-3c76193a021f",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[107976, 2784, 414, 12, 27, "Commentary",ExpressionUUID->"634fbaf7-e6e1-48c2-8a43-5d6fe3abb5e0",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[108393, 2798, 810, 20, 39, "Text",ExpressionUUID->"bb566f6b-daf3-4983-869d-a2f2b0573f0b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[109206, 2820, 803, 21, 38, "Text",ExpressionUUID->"f6d83e78-531c-4ffa-ac13-f9f2557d1e00",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110034, 2845, 295, 5, 35, "Input",ExpressionUUID->"3c66cd45-fbcd-4b97-a7ff-ed3bf9d5a639",
   PageBreakWithin->Automatic,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110332, 2852, 444, 11, 24, "Output",ExpressionUUID->"cbee1408-a603-4db7-a141-fc74ed03cd9f",
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110791, 2866, 1300, 35, 66, "Text",ExpressionUUID->"83e9195b-377a-46f7-940b-d5f912ae28cd",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[112116, 2905, 174, 2, 24, "Input",ExpressionUUID->"44acd788-f49f-4b3c-ada7-aaa673fd1ee2",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[112293, 2909, 1020, 19, 116, "Output",ExpressionUUID->"efe3dfab-e4d5-413f-be0c-367f2a295ab4",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[113328, 2931, 1529, 41, 83, "Text",ExpressionUUID->"194aaa1b-e39b-483d-98c9-86fbf1a155d7",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[114860, 2974, 2226, 61, 119, "Text",ExpressionUUID->"2db9e75b-e121-4086-8722-eee8505e9120",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[117089, 3037, 222, 5, 20, "Text",ExpressionUUID->"e89a6918-b041-49fc-8ab5-cdb7ffb5adfd",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[117348, 3047, 294, 7, 35, "Subsection",ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", "2.2"}],
  Cell[117645, 3056, 1206, 37, 51, "Text",ExpressionUUID->"3dae03d0-b7a4-4671-b970-ff4fb797fb9f",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[118854, 3095, 583, 19, 34, "Text",ExpressionUUID->"07b827ce-dce5-4812-850d-a7d45348011b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[120852, 3168, 807, 24, 38, "Text",ExpressionUUID->"ec17fe0d-d65b-4b4b-aec1-5b1491287176",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[121684, 3196, 181, 2, 24, "Input",ExpressionUUID->"ccde2674-390a-4365-96e1-7846afb2c154",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[121868, 3200, 444, 11, 24, "Output",ExpressionUUID->"de932cca-b2d3-496e-be44-bc5e187564af",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122327, 3214, 465, 15, 21, "Text",ExpressionUUID->"e2f135df-65eb-45c1-8caf-4fc68baa3243",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122817, 3233, 174, 2, 24, "Input",ExpressionUUID->"26ac156b-7290-47db-8499-89f9e7408435",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122994, 3237, 1006, 19, 116, "Output",ExpressionUUID->"b59b4740-4088-412d-9344-67d755cedbec",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124015, 3259, 520, 17, 34, "Text",ExpressionUUID->"ae70480d-bef9-4f92-901c-c4f9883b9009",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124560, 3280, 186, 2, 24, "Input",ExpressionUUID->"26204c28-0611-4bdb-8ee8-f41e1974186f",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124749, 3284, 2229, 38, 278, "Output",ExpressionUUID->"1e7fbbbe-ac15-463a-b599-8d861ee982fb",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[126993, 3325, 1202, 41, 54, "Text",ExpressionUUID->"06637bc5-a376-4811-8505-c4e6bcc7afba",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[128220, 3370, 211, 2, 24, "Input",ExpressionUUID->"c14e6e5e-b415-4b18-87dd-2a3d5e9dfadf",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[128434, 3374, 1082, 18, 116, "Output",ExpressionUUID->"35245519-99f9-4861-a0fc-d218481c739f",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[129531, 3395, 1511, 39, 86, "Text",ExpressionUUID->"78c6969c-cf10-4e6b-b4db-fe4cd0465117",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[131045, 3436, 222, 5, 20, "Text",ExpressionUUID->"e4f9b90a-8b43-46b2-a164-64cf7a7d1efd",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[131304, 3446, 412, 13, 35, "Subsection",ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"How Rayica manages default light source settings", "Components and Sources", "RG2.", "RG2.3", "2.3"}],
  Cell[131719, 3461, 1314, 39, 66, "Text",ExpressionUUID->"f7db2f37-f6c0-4557-a85c-9e4ca13ee1d9",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133036, 3502, 725, 17, 51, "Text",ExpressionUUID->"7fd2b89a-85a7-4bac-9b28-1d4e4e9630e0",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133786, 3523, 164, 2, 24, "Input",ExpressionUUID->"dc651577-4f0a-49cd-a800-e175d4bf5069",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133953, 3527, 4775, 103, 200, "Output",ExpressionUUID->"623a4163-fa46-4247-ad2b-263ba7b59c86",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[138743, 3633, 1018, 26, 54, "Text",ExpressionUUID->"c380cecc-f3c6-42a5-a0c4-0d6ef93e9822",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[139764, 3661, 332, 7, 20, "Text",ExpressionUUID->"ff5b866d-87d0-457e-81c5-34d395797f94",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140121, 3672, 181, 2, 24, "Input",ExpressionUUID->"d0320a23-7f02-4e4a-88e6-aacdfcd7a573",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140305, 3676, 488, 12, 24, "Output",ExpressionUUID->"bae2cc55-2bed-4232-892f-843be9ddaa2e",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140808, 3691, 518, 14, 38, "Text",ExpressionUUID->"2dd4bb18-47b5-4437-9dce-4eb4c658c3c4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[141351, 3709, 170, 2, 24, "Input",ExpressionUUID->"b70d0283-7f35-4b33-9bcb-39989eb809fe",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[141524, 3713, 1289, 27, 56, "Output",ExpressionUUID->"df31c411-7635-43b3-af9e-e120b2b1bff3",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[142828, 3743, 1177, 36, 47, "Text",ExpressionUUID->"13fe18f5-4bd8-4d78-a9c2-bc1b9650fca4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[144008, 3781, 222, 5, 20, "Text",ExpressionUUID->"e9fedc5c-f759-4cd7-a3b7-2ab02f59cb2a",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[144267, 3791, 312, 7, 35, "Subsection",ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Modeling an optical component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[144582, 3800, 634, 16, 37, "Text",ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145241, 3820, 190, 2, 24, "Input",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145434, 3824, 51836, 1500, 686, "Output",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[197285, 5327, 465, 14, 27, "Commentary",ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb",
   CellTags->{"Components and Sources", "2.4", "Component", "RG2.", "RG2.4"}],
  Cell[197753, 5343, 532, 14, 37, "Text",ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199103, 5390, 366, 11, 22, "Text",ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199494, 5405, 288, 5, 24, "Input",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199785, 5412, 510, 12, 23, "Output",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[200310, 5427, 1518, 39, 69, "Text",ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[201831, 5468, 844, 22, 51, "Text",ExpressionUUID->"eef9b50e-e13a-421f-9021-c75994b22de3",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[202678, 5492, 1355, 43, 56, "Text",ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204058, 5539, 284, 5, 24, "Input",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204345, 5546, 2602, 59, 120, "Output",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[206962, 5608, 832, 20, 52, "Text",ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[207819, 5632, 280, 7, 24, "Input",ExpressionUUID->"86d06f27-cac4-455d-963a-9c1e384be627",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[208102, 5641, 583, 14, 24, "Output",ExpressionUUID->"b7c3aa15-7beb-46bd-ad1e-9086c3bfae34",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[208700, 5658, 222, 5, 20, "Text",ExpressionUUID->"ee8c6ee2-63b1-40ce-a0a3-a0d34bd8fb34",
   CellTags->{"Components and Sources", "RG2."}]},
 "TurboPlot"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[6724, 200, 293, 7, 20, "Outline2",ExpressionUUID->"c87a726b-0d67-4996-9dac-7542c014ef85",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[7020, 209, 386, 12, 29, "Outline3",ExpressionUUID->"864d8473-2564-4695-84d1-669e9e4ec4c7",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[876156, 18157, 273, 8, 60, "Section",ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4",
   CellTags->{"TurboPlot", "14.", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[877579, 18202, 924, 31, 84, "FramedBox",ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"TurboPlot", "TurboTrace", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[878506, 18235, 1937, 50, 116, "Text",ExpressionUUID->"29a70b22-afb3-4a67-9ca0-396573e8c165",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[880446, 18287, 306, 6, 57, "Input",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc",
   CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"}],
  Cell[880755, 18295, 1503, 38, 85, "Text",ExpressionUUID->"0aa5efea-2314-4787-add1-c1cbe3b2041d",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[882261, 18335, 210, 5, 20, "Text",ExpressionUUID->"0b78c116-1673-43d7-b13b-269d0483e4c4",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[882496, 18344, 264, 7, 35, "Subsection",ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee",
   CellTags->{"AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[882763, 18353, 524, 14, 34, "Text",ExpressionUUID->"5d45d815-e34a-4638-b9aa-6a2cae8bcc92",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883312, 18371, 207, 2, 24, "Input",ExpressionUUID->"735af2c0-1890-47d1-927f-6c25ec9a3696",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883522, 18375, 22837, 385, 250, "Print",ExpressionUUID->"30129e9c-da09-4b82-99d7-c51a0ba85383",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[906362, 18762, 1112, 30, 36, "Print",ExpressionUUID->"8af346c3-607a-4d3c-b60b-37087ac743cf",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907477, 18794, 440, 8, 24, "Output",ExpressionUUID->"1be6b05a-38ba-4dd0-9c1b-bf8a553810e2",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907932, 18805, 601, 14, 38, "Text",ExpressionUUID->"858724e0-3458-4097-a3ad-5905352e1e8a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908558, 18823, 203, 2, 24, "Input",ExpressionUUID->"4316b42e-16b4-4337-b1d0-5fcbb5018272",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908764, 18827, 19666, 328, 250, "Print",ExpressionUUID->"a775210d-8ac8-4f96-881b-f0406171236d",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928433, 19157, 424, 8, 24, "Output",ExpressionUUID->"2701a2cb-a51f-48fb-8a91-292322a5ed60",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928872, 19168, 2384, 53, 150, "Text",ExpressionUUID->"7563334e-5902-41f8-a1df-a57b98fd95db",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931259, 19223, 288, 6, 57, "Input",ExpressionUUID->"82dd5976-98c4-4850-8129-65296a055626",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931550, 19231, 247, 7, 21, "Text",ExpressionUUID->"8a0d808b-3acd-42e1-8a4e-3cbf9708bab9",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931822, 19242, 294, 8, 24, "Input",ExpressionUUID->"4ba6f6b3-7128-4561-bf3a-51d141ee8235",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[932119, 19252, 13905, 237, 135, "Print",ExpressionUUID->"d17e9029-8a30-4cfd-a2de-1ef7fd95dc7b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946027, 19491, 426, 8, 24, "Output",ExpressionUUID->"0654bc51-0d0e-44fc-9ad4-a4a620076efc",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946468, 19502, 342, 10, 21, "Text",ExpressionUUID->"b6867a6d-2e38-4d9a-8d99-c590923b8370",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946835, 19516, 202, 2, 24, "Input",ExpressionUUID->"dcf9a401-6d74-4dca-b0a9-dbfb831b5a69",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[947040, 19520, 19508, 327, 250, "Print",ExpressionUUID->"17aad0ef-4d85-49dc-8687-7a9910b92579",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966551, 19849, 425, 8, 24, "Output",ExpressionUUID->"19a4ddc9-b309-4657-a005-e419ddaea093",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966991, 19860, 658, 16, 38, "Text",ExpressionUUID->"ba8154d8-97ee-46e3-af97-1bfcda3007ef",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[967652, 19878, 567, 17, 51, "FramedBox",ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968222, 19897, 250, 7, 21, "Text",ExpressionUUID->"584eb23d-c0e4-4cf3-a9f3-f1123ef41b41",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968497, 19908, 280, 6, 24, "Input",ExpressionUUID->"0c4146da-356c-4135-94fc-acd9c4891d21",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968780, 19916, 14063, 238, 135, "Print",ExpressionUUID->"c2262dfd-d7a6-4354-93bc-b64c5143062b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[982846, 20156, 424, 8, 24, "Output",ExpressionUUID->"cd0d7832-4882-42ac-aeec-555723c25398",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[983285, 20167, 899, 20, 54, "Text",ExpressionUUID->"8df57715-fe35-4019-a07d-935cd5a2b382",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984209, 20191, 314, 6, 24, "Input",ExpressionUUID->"c7a7c134-59da-4d2c-9066-7712b50842ab",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984526, 20199, 15065, 256, 136, "Print",ExpressionUUID->"79dbe714-1168-4ff2-a903-f39e4fe98437",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[999594, 20457, 427, 8, 24, "Output",ExpressionUUID->"5c23b081-6025-46f9-8058-23f0ddb28122",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000036, 20468, 462, 12, 38, "Text",ExpressionUUID->"55aa0c10-0f2e-40e5-b147-d90827498dd5",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000501, 20482, 623, 15, 38, "Text",ExpressionUUID->"d1849c45-2f29-4caa-9f87-63d7f316366a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1001127, 20499, 210, 5, 20, "Text",ExpressionUUID->"43b79d3c-25d1-403a-95e3-08fa65c30a51",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[1001374, 20509, 194, 3, 35, "Subsection",ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d",
   CellTags->{"CreateClones", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1001571, 20514, 619, 19, 38, "Text",ExpressionUUID->"a90ae5b6-7add-4130-878d-cf27bd3d377f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1002193, 20535, 1009, 31, 64, "FramedBox",ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1003205, 20568, 1956, 47, 116, "Text",ExpressionUUID->"f2eb698c-dfad-4527-9f7b-106a2af4bfa3",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005164, 20617, 286, 9, 106, "Input",ExpressionUUID->"3d9f37b8-a9c7-4b91-a648-ad87a2a1e908",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005453, 20628, 325, 10, 21, "Text",ExpressionUUID->"d9110934-fde3-43cf-9643-be18578b550b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005781, 20640, 184, 2, 24, "Input",ExpressionUUID->"1ecb9700-e924-4fa3-bdaf-531de38950d0",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005968, 20644, 489, 15, 34, "Text",ExpressionUUID->"42dc2622-9471-42c3-a3f3-61f3f7d82508",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1006460, 20661, 556, 19, 51, "FramedBox",ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"BallLens", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007019, 20682, 431, 11, 21, "Text",ExpressionUUID->"9242d2d5-8928-426b-b5ac-4a96ee390dbe",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007475, 20697, 347, 6, 57, "Input",ExpressionUUID->"eecc06bf-c7ed-45b9-a4f4-24ee8c6632e7",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007825, 20705, 287, 5, 20, "Print",ExpressionUUID->"61a0f1ab-c69a-45ca-b951-868a02bace37",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008115, 20712, 273, 5, 19, "Print",ExpressionUUID->"b5d7340c-5ec3-4fe7-9d03-09cc88fbe637",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008391, 20719, 403, 9, 20, "Print",ExpressionUUID->"2d34b417-9b1a-4ec2-9bbc-51a827395fef",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008797, 20730, 396, 9, 19, "Print",ExpressionUUID->"194685f5-51ca-400c-ac76-52d433b092e4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1009196, 20741, 155603, 3614, 2712, "Print",ExpressionUUID->"9e5f9dee-8ead-479a-b7ab-b29ca9c88f05",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1164802, 24357, 402, 9, 20, "Print",ExpressionUUID->"5a157a4a-5cd0-4ff8-9446-a9a4d1cf4f63",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165207, 24368, 285, 5, 20, "Print",ExpressionUUID->"a7ac1691-3058-41ef-b826-3e248fce341f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165495, 24375, 592, 13, 20, "Print",ExpressionUUID->"68ed0864-f5f9-4899-9e1d-f86d4eb9da48",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166090, 24390, 294, 5, 20, "Print",ExpressionUUID->"a3c73fa8-cd00-4292-8000-e81065aa2e52",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166387, 24397, 434, 10, 20, "Print",ExpressionUUID->"5e96a7e3-3195-49c5-a721-3e13d8eba6dd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166824, 24409, 299, 5, 20, "Print",ExpressionUUID->"73b92b16-de30-4bf4-8330-439f37608ec1",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167126, 24416, 294, 5, 20, "Print",ExpressionUUID->"116e553e-8c5d-4dc1-a5f3-801621bf9f27",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167423, 24423, 295, 5, 20, "Print",ExpressionUUID->"6276257f-c7ec-4594-ad4f-72208f6b4d0f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167721, 24430, 564, 13, 20, "Print",ExpressionUUID->"5a6866f8-45c9-4989-b288-05184518c8f4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168288, 24445, 280, 5, 20, "Print",ExpressionUUID->"b9cffd6e-5cfc-4fb1-a8d3-92d7bd52cace",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168571, 24452, 291, 5, 20, "Print",ExpressionUUID->"b0d73961-ee2c-4ee2-b8a0-2f0c81abd029",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168865, 24459, 284, 5, 20, "Print",ExpressionUUID->"1ca37af5-a564-4e12-963d-e72507044653",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169152, 24466, 408, 10, 20, "Print",ExpressionUUID->"6b21dd82-13da-49a4-bfcc-1692d2a751f9",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169563, 24478, 470, 12, 20, "Print",ExpressionUUID->"6d322694-d70a-45fe-91ab-4a334dca967d",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170036, 24492, 293, 5, 20, "Print",ExpressionUUID->"2602bd1b-8e54-4f2d-985e-854ee2ebdd2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170332, 24499, 3005, 67, 36, "Print",ExpressionUUID->"24daf8aa-d778-478d-b1bb-3cb981a0470c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173340, 24568, 298, 5, 20, "Print",ExpressionUUID->"dec65d5e-7134-4048-bd69-fcddd67bff86",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173641, 24575, 380, 9, 20, "Print",ExpressionUUID->"5def9516-870b-45c4-bb4d-185c5bf57e2b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174024, 24586, 410, 10, 20, "Print",ExpressionUUID->"569cd10d-ec2f-4e84-b8fa-4bbe68d67c43",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174437, 24598, 285, 5, 20, "Print",ExpressionUUID->"dbc020dc-58c1-450b-987e-0de518fcb018",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174725, 24605, 420, 9, 20, "Print",ExpressionUUID->"06ebf166-0ece-4a92-84a9-2078defc9ffd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175148, 24616, 402, 9, 20, "Print",ExpressionUUID->"4a173113-385f-46f7-9c3d-0b055bbb25e5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175553, 24627, 406, 9, 20, "Print",ExpressionUUID->"931ebe39-1913-4ea1-a5d6-0c9aefc4d074",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175962, 24638, 271, 5, 20, "Print",ExpressionUUID->"fc7c54b5-8308-460e-a42b-d07ec905a15a",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176236, 24645, 434, 10, 20, "Print",ExpressionUUID->"4060f68c-4778-4814-9ce7-8d1f7fd45431",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176673, 24657, 608, 14, 20, "Print",ExpressionUUID->"c2df0822-6d87-4e5a-bdfe-fdb1e7570704",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1177284, 24673, 775, 15, 22, "Message",ExpressionUUID->"d47b94fb-92d1-4460-93e6-ffdef0044a62",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178062, 24690, 442, 10, 20, "Print",ExpressionUUID->"372e005e-ae85-45d5-b357-dccdbfec3b2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178507, 24702, 730, 15, 20, "Print",ExpressionUUID->"2444f75e-2c81-4fc8-bcee-98bc3bccbf99",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179240, 24719, 306, 6, 20, "Print",ExpressionUUID->"cde16d7f-25f9-49c2-8d01-9591f38344b8",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179549, 24727, 282, 5, 20, "Print",ExpressionUUID->"1939d258-9116-4640-8d0a-a8e388c1c894",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179834, 24734, 286, 5, 20, "Print",ExpressionUUID->"30244d4b-b1f1-4417-a269-c577adbf4778",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180123, 24741, 279, 5, 20, "Print",ExpressionUUID->"3b6f39ab-476c-4aeb-8ace-ef042b612aa2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180405, 24748, 304, 6, 20, "Print",ExpressionUUID->"372b9b9a-5013-4ebb-9371-b8c7809d5a85",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180712, 24756, 304, 6, 20, "Print",ExpressionUUID->"ccdfd2bb-c013-42e4-99bb-9aab14e88f10",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181019, 24764, 304, 6, 20, "Print",ExpressionUUID->"07c418d1-350c-47f1-b1a3-2dbcf1f4738c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181326, 24772, 304, 6, 20, "Print",ExpressionUUID->"c9a2bb0f-da80-40ea-8eaa-0a1efb0c580f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181633, 24780, 281, 5, 20, "Print",ExpressionUUID->"63686a72-2217-4f16-b1dc-3b9f396962c5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181917, 24787, 293, 5, 20, "Print",ExpressionUUID->"830aa83c-4800-4bb1-8ca2-22aff9582db6",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182213, 24794, 279, 5, 20, "Print",ExpressionUUID->"1ed4033f-5589-4337-a159-deb93b7ea346",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182495, 24801, 1129508, 18866, 341, "Print",ExpressionUUID->"fdb36d72-ab79-4189-a843-7506cad40be2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2312018, 43670, 1213, 33, 70, "Text",ExpressionUUID->"9c4ed069-1dcb-4b31-b3b4-de62ad8e215e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313234, 43705, 288, 8, 21, "Text",ExpressionUUID->"0d7d4221-ebf2-4a36-a888-5a1eb445b649",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2314769, 43760, 490, 15, 34, "Text",ExpressionUUID->"e2766717-50f1-411a-8db8-c3dba15ad878",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2315262, 43777, 210, 5, 20, "Text",ExpressionUUID->"bfafdff3-9501-4a72-ad94-f41a96b5bd5d",
   CellTags->{"TurboPlot", "RG14."}]},
 "Getting Started Introduction"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}]},
 "Introduction to AnalyzeSystem and TurboPlot"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[208971, 5669, 448, 16, 60, "Section",ExpressionUUID->"f36ffa46-c6d2-439a-9436-fd7c63745e3d",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"3.", "Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[209422, 5687, 1126, 28, 68, "Text",ExpressionUUID->"8c47ee91-acd1-4aff-8716-af3ea27f1b84",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[210551, 5717, 1041, 36, 81, "FramedBox",ExpressionUUID->"261340f7-80cc-4036-9f76-943150729697",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[211595, 5755, 1805, 45, 103, "Text",ExpressionUUID->"6225c1c0-5cd6-48f5-850b-53c0f81f7cc6",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[213403, 5802, 523, 14, 34, "Text",ExpressionUUID->"ec9c95de-5825-40d9-a289-df1341e2c666",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[213951, 5820, 352, 9, 24, "Input",ExpressionUUID->"1726bb25-462a-4549-bd93-8573fad0fabc",
   PageBreakWithin->Automatic,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[214306, 5831, 12705, 212, 438, "Print",ExpressionUUID->"666eb69d-8757-4ccf-9432-9f88066ccff9",
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[227014, 6045, 689, 18, 20, "Print",ExpressionUUID->"f2f0a085-d829-463d-9de9-2ce44ffc6b56",
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[227706, 6065, 339, 4, 23, "Output",ExpressionUUID->"29727901-5758-4d7f-9da3-179fef404a45",
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[228060, 6072, 1358, 36, 65, "Text",ExpressionUUID->"52d1cb2a-fcf5-454d-aae0-8a2cdb930012",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}]},
 "Move"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[229628, 6118, 299, 12, 60, "Section",ExpressionUUID->"e79ee304-6444-418c-a347-afc29e47298d",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Move", "4.", "RG4."}],
  Cell[229930, 6132, 840, 30, 38, "Text",ExpressionUUID->"9e0ee182-ff3f-43f3-a9dc-be44675bfa86",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}],
  Cell[230773, 6164, 862, 33, 51, "FramedBox",ExpressionUUID->"5f9681df-c37c-4521-9524-cfd663be2990",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Move", "RG4."}],
  Cell[231638, 6199, 1087, 38, 38, "Text",ExpressionUUID->"7e8db4f2-fbe3-4f2b-9a30-04dacb450d99",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}],
  Cell[232750, 6241, 375, 10, 57, "Input",ExpressionUUID->"6b5272ea-3406-4e38-bc14-4af8d413c5fe",
   PageBreakWithin->Automatic,
   CellTags->{"Move", "RG4."}],
  Cell[233128, 6253, 26290, 425, 266, "Print",ExpressionUUID->"f2905d4c-0a2b-409a-a72a-a56e8893f778",
   CellTags->{"Move", "RG4."}],
  Cell[259421, 6680, 927, 26, 20, "Print",ExpressionUUID->"9a43684d-2201-4b5a-9a78-d826030078b5",
   CellTags->{"Move", "RG4."}],
  Cell[260351, 6708, 308, 4, 24, "Output",ExpressionUUID->"b55e7357-d863-4697-8813-7f7cc22a5135",
   CellTags->{"Move", "RG4."}],
  Cell[260674, 6715, 588, 13, 37, "Text",ExpressionUUID->"3015ad87-e28b-447b-9c45-8090fc0f0d9a",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}],
  Cell[261265, 6730, 2635, 116, 165, "FramedBox",ExpressionUUID->"2eda5272-ff28-49d0-af7c-f78001c32ec2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Move", "RG4."}],
  Cell[263903, 6848, 259, 7, 27, "Commentary",ExpressionUUID->"7709d5f4-20e7-46c4-a5c1-f6761964cc32",
   CellTags->{"Move", "RG4."}],
  Cell[264165, 6857, 520, 18, 34, "Text",ExpressionUUID->"ba405f05-8953-47a7-97ad-0df30ed40a7b",
   CellTags->{"Move", "RG4."}],
  Cell[264710, 6879, 167, 2, 24, "Input",ExpressionUUID->"90ddc9bd-c7cd-4c1e-af5a-3b8f958d6218",
   CellTags->{"Move", "RG4."}],
  Cell[264880, 6883, 3782, 106, 56, "Output",ExpressionUUID->"83fbebe7-5ac1-4249-96b0-6497e0927650",
   CellTags->{"Move", "RG4."}],
  Cell[268677, 6992, 380, 11, 27, "Commentary",ExpressionUUID->"f7bcd3be-e8bb-4554-9d2c-ae586a1da6eb",
   CellTags->{"Move", "RG4."}],
  Cell[269060, 7005, 474, 15, 21, "Text",ExpressionUUID->"c4e24659-88c0-410a-a21f-b62e1ff992ad",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}]},
 "AnalyzeSystem"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[4202, 127, 271, 6, 20, "Outline2",ExpressionUUID->"64fd74ad-0072-470b-b3f7-9f300bdb4b0d",
   CellTags->{"AnalyzeSystem", "RG5."}],
  Cell[4476, 135, 407, 12, 29, "Outline3",ExpressionUUID->"d60aceae-7f54-4a23-b259-fa147cdc1f4a",
   CellTags->{"AnalyzeSystem", "RG5."}],
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292639, 7528, 858, 21, 53, "Text",ExpressionUUID->"7369556e-547f-4c48-9122-ce4aa18cf0e1",
   CellTags->{"AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[295305, 7601, 2694, 99, 146, "FramedBox",ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298002, 7702, 231, 7, 26, "Commentary",ExpressionUUID->"26b43ee4-7126-4285-afb4-1c0266581bb3",
   CellTags->{"AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}]},
 "ShowSystem"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[299518, 7748, 338, 12, 63, "Section",ExpressionUUID->"64a2e08a-22da-4300-95b9-1ad25b5ce535",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowSystem", "component rendering", "6.", "RG6."}],
  Cell[299859, 7762, 856, 26, 39, "Text",ExpressionUUID->"a762463d-3045-4825-87b2-14bb8f507bfc",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[300740, 7792, 388, 11, 24, "Input",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[301131, 7805, 12794, 217, 138, "Print",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[313940, 8025, 705, 18, 34, "Text",ExpressionUUID->"30f2a5f0-70af-48be-a362-2f0d0ed3bc92",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[314648, 8045, 1216, 35, 164, "FramedBox",ExpressionUUID->"4d2d16ec-590d-4087-a948-7eca66168471",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[315867, 8082, 147, 3, 26, "Commentary",ExpressionUUID->"accb7d7d-bdeb-4ef8-ab85-02949feef222",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[316017, 8087, 840, 24, 38, "Text",ExpressionUUID->"1164e3f4-4cce-443b-a3eb-b8e6ed0b0d18",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[316860, 8113, 692, 23, 51, "FramedBox",ExpressionUUID->"81b20859-5e84-4947-9587-7215471a8f59",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[317555, 8138, 306, 9, 21, "Text",ExpressionUUID->"666c3868-dbeb-4e1e-8f1f-c61134156135",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[317864, 8149, 1396, 33, 165, "FramedBox",ExpressionUUID->"0936f727-cc05-485f-a077-877a4972781b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "ShowSystem", "RG6."}],
  Cell[319263, 8184, 184, 7, 27, "Commentary",ExpressionUUID->"c0abbaea-40b0-43c3-92b0-8d371ecf8e2c",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[319450, 8193, 461, 12, 34, "Text",ExpressionUUID->"61d6452e-a86b-42c5-97dc-5a2e42ff0159",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[319936, 8209, 387, 13, 24, "Input",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[320326, 8224, 15785, 256, 256, "Print",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[336126, 8483, 228, 6, 26, "Commentary",ExpressionUUID->"ba2e33a9-701f-45ed-9ae6-785a655b2088",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[336357, 8491, 1151, 34, 67, "Text",ExpressionUUID->"b9ee1085-a4db-4909-8120-573cd6b1d0cb",
   CellTags->{"ShowSystem", "RG6."}]},
 "Tracing a Cone of Rays"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[337718, 8535, 276, 7, 60, "Section",ExpressionUUID->"ef5cb7f7-4a2e-41b7-a582-7cd49609ad04",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ConeOfRays", "7.", "Tracing a Cone of Rays", "RG7."}],
  Cell[337997, 8544, 534, 16, 21, "Text",ExpressionUUID->"9c94a08d-a3e8-4d8e-acb6-662ceb40fb6c",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338556, 8564, 437, 10, 57, "Input",ExpressionUUID->"fed97f40-88bc-4f03-9201-d0237877757f",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338996, 8576, 15095, 255, 223, "Print",ExpressionUUID->"37191ea6-48c5-4143-badd-2a16889b8e71",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354106, 8834, 511, 13, 34, "Text",ExpressionUUID->"8d708064-4943-4d97-9338-80fdec46d92e",
   CellTags->{"Tracing a Cone of Rays", "RG7."}],
  Cell[354620, 8849, 355, 10, 21, "Text",ExpressionUUID->"24b310c7-f413-4438-a984-916a3d387316",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354978, 8861, 635, 20, 51, "FramedBox",ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", "RG7."}],
  Cell[355616, 8883, 1266, 45, 55, "Text",ExpressionUUID->"e506ddcd-0879-41ab-9c62-f1893312d38a",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[356907, 8932, 486, 11, 57, "Input",ExpressionUUID->"78ae942a-cb18-4547-b900-445b13070a83",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[357396, 8945, 56644, 921, 223, "Print",ExpressionUUID->"b1b87736-fe15-4098-9aab-1bb1ba1e1fba",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414055, 9869, 416, 13, 21, "Text",ExpressionUUID->"072f6e22-85e4-42b4-8783-7cc94a7c1fd3",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414496, 9886, 262, 4, 24, "Input",ExpressionUUID->"21c87232-2508-40e4-a406-184ea43091fe",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414761, 9892, 40317, 694, 107, "Print",ExpressionUUID->"af61dccd-7843-4695-8d08-5324bb57a8b7",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455093, 10589, 727, 22, 39, "Text",ExpressionUUID->"566e4a0b-26a1-49bf-a5d6-8f6376ae9285",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455845, 10615, 263, 4, 24, "Input",ExpressionUUID->"43392047-6d38-472c-b510-86ef1a1bb072",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[456111, 10621, 44399, 773, 365, "Print",ExpressionUUID->"0a748db5-bcea-4a91-831b-278c5989b2ec",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}]},
 "Adding a Cylindrical Lens"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[500732, 11405, 302, 7, 60, "Section",ExpressionUUID->"811accef-54a1-49dd-aafb-3af96471eef6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"cylindrical lens", "8.", "Adding a Cylindrical Lens", "RG8."}],
  Cell[501037, 11414, 441, 11, 21, "Text",ExpressionUUID->"de0b999c-b77b-4599-9529-4cf305828fbf",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[501481, 11427, 752, 26, 51, "FramedBox",ExpressionUUID->"cefabc0f-b2ba-4081-a914-a90102a52410",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"PlanoConvexCylindricalLens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[502236, 11455, 472, 16, 21, "Text",ExpressionUUID->"2a020f65-57b9-4d9c-a7ad-1909426b6614",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[502733, 11475, 584, 14, 89, "Input",ExpressionUUID->"8bec4a81-f674-4133-b165-e68c0b8dc5f6",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[503320, 11491, 89102, 1445, 220, "Print",ExpressionUUID->"0eb413d0-0c48-47c6-8df0-2f898569bd3d",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[592437, 12939, 243, 5, 20, "Text",ExpressionUUID->"09cb721d-419f-47bb-9788-3802a696cbee",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[592705, 12948, 268, 4, 24, "Input",ExpressionUUID->"5e6666c8-aa0e-4d60-801e-bbc7eef0bf62",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[592976, 12954, 64048, 1102, 104, "Print",ExpressionUUID->"3dab169f-74d4-49da-ad43-db9c6f5ac4cf",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[657061, 14061, 267, 4, 24, "Input",ExpressionUUID->"861c617d-2d33-4fa6-a2ed-2b5e8e334a04",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[657331, 14067, 65471, 1127, 104, "Print",ExpressionUUID->"d723f22c-56c9-45ab-9326-3be74b4f57f2",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[722817, 15197, 1246, 32, 60, "Text",ExpressionUUID->"f46b8f25-0f6f-43f7-9dcf-10d7b52d732b",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}]},
 "RayChoice"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[502733, 11475, 584, 14, 89, "Input",ExpressionUUID->"8bec4a81-f674-4133-b165-e68c0b8dc5f6",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[503320, 11491, 89102, 1445, 220, "Print",ExpressionUUID->"0eb413d0-0c48-47c6-8df0-2f898569bd3d",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[724273, 15239, 254, 10, 63, "Section",ExpressionUUID->"23359498-8046-434a-af0c-e565df2d8892",
   Evaluatable->False,
   CellTags->{"RayChoice", "9.", "RG9."}],
  Cell[724530, 15251, 382, 12, 21, "Text",ExpressionUUID->"0d1a8e3f-4e1d-4dc4-a61a-e7f9b3ef5afb",
   Evaluatable->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[724915, 15265, 719, 26, 51, "FramedBox",ExpressionUUID->"34779028-9be1-4672-b9ce-24514fb1786e",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[725637, 15293, 708, 19, 38, "Text",ExpressionUUID->"f42d6be7-cbe5-44e4-b7ee-1e7ef7b86e0a",
   Evaluatable->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[726370, 15316, 243, 4, 24, "Input",ExpressionUUID->"01fb40b3-1e7d-4bf2-967e-eea9be9f6230",
   PageBreakWithin->Automatic,
   CellTags->{"RayChoice", "RG9."}],
  Cell[726616, 15322, 88175, 1429, 220, "Print",ExpressionUUID->"d7fc8bc8-e503-4e02-a570-e01b7182818a",
   CellTags->{"RayChoice", "RG9."}],
  Cell[814806, 16754, 486, 16, 21, "Text",ExpressionUUID->"921d688e-0d66-4016-be31-dc9862d3972f",
   Evaluatable->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[815295, 16772, 579, 18, 51, "FramedBox",ExpressionUUID->"ab90f6a7-a383-4ac1-80ec-3fa98fb9b1f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RayChoice", "Surface", "RG9."}],
  Cell[815877, 16792, 453, 14, 21, "Text",ExpressionUUID->"41a7f206-e13a-4409-be36-f56525db8c24",
   Evaluatable->False,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816355, 16810, 300, 6, 24, "Input",ExpressionUUID->"47b9e46a-25c0-4cb3-b662-0d37b89eb12d",
   PageBreakWithin->Automatic,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816658, 16818, 3305, 74, 365, "Print",ExpressionUUID->"15442f90-5536-464e-8ab9-90af301ef1ce",
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}]},
 "Using Screen"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[820185, 16903, 371, 12, 63, "Section",ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Screen", "focal plane of system", "10.", "Using Screen", "RG10."}],
  Cell[820559, 16917, 735, 20, 38, "Text",ExpressionUUID->"4574287a-8995-4e63-99d6-4237667227af",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821297, 16939, 635, 21, 51, "FramedBox",ExpressionUUID->"cb264467-9607-4491-9e2a-150017352ac3",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821935, 16962, 612, 20, 21, "Text",ExpressionUUID->"4f17e7e8-b7ef-46c4-bbe9-62737fdd5493",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[848676, 17432, 451, 13, 21, "Text",ExpressionUUID->"045101ea-2a75-4098-a7f0-05d2a696de23",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849152, 17449, 310, 7, 24, "Input",ExpressionUUID->"da50deaa-c72e-495c-92e8-001633150ed5",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849465, 17458, 2021, 46, 365, "Print",ExpressionUUID->"a8b69489-f5d3-4bd3-9d7e-48f0bdb29221",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}]},
 "ShowRange"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[851708, 17515, 323, 12, 63, "Section",ExpressionUUID->"c348ff48-a54b-4c54-9da9-e9c1ed3d78d5",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowRange", "11.", "RG10.", "RG11."}],
  Cell[852034, 17529, 398, 13, 21, "Text",ExpressionUUID->"52816333-8b27-4409-b845-2b916f72b70f",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[852435, 17544, 570, 19, 51, "FramedBox",ExpressionUUID->"83ed5ffd-df16-4b3f-8c0a-adc45f84e000",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853008, 17565, 492, 16, 21, "Text",ExpressionUUID->"5b155320-e592-41f5-b201-2e505ba64340",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853525, 17585, 237, 4, 24, "Input",ExpressionUUID->"2a1441a5-322d-4c6b-ae11-20370f92fa09",
   PageBreakWithin->Automatic,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853765, 17591, 11298, 191, 438, "Print",ExpressionUUID->"877e34fe-4ce3-4102-a844-c6adfe1e2227",
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[865078, 17785, 1021, 35, 38, "Text",ExpressionUUID->"0a819798-1313-47bc-b289-5b2becae311b",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}]},
 "ReadRays"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[866309, 17830, 314, 12, 63, "Section",ExpressionUUID->"bd0bb247-7bc3-4815-8b2b-9ad91600848b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ReadRays", "12.", "RG12."}],
  Cell[866626, 17844, 370, 10, 21, "Text",ExpressionUUID->"13dfbd3e-a75a-4c9a-bca5-1ac9141cc3d0",
   Evaluatable->False,
   CellTags->{"ReadRays", "RG12."}],
  Cell[866999, 17856, 915, 36, 51, "FramedBox",ExpressionUUID->"ea5251f0-0c41-4a77-8e3b-bde02cad7014",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReadRays", "RG12."}],
  Cell[867917, 17894, 637, 17, 34, "Text",ExpressionUUID->"1050e920-03fb-4f3e-ae26-7e4e6e181dc9",
   Evaluatable->False,
   CellTags->{"ReadRays", "RG12."}],
  Cell[868579, 17915, 253, 6, 24, "Input",ExpressionUUID->"fe649223-7d68-4e85-b6f0-1d4135c645e1",
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "RG12."}],
  Cell[868835, 17923, 502, 9, 23, "Output",ExpressionUUID->"2d332d18-8f36-4def-bdfb-fe46a3ca4054",
   CellTags->{"ReadRays", "RG12."}],
  Cell[869352, 17935, 290, 10, 21, "Text",ExpressionUUID->"47dff9d5-d9f6-4181-abad-0242b6d5c9ef",
   Evaluatable->False,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[869667, 17949, 209, 4, 24, "Input",ExpressionUUID->"a4c1ace1-3fbb-4027-9df6-3ef68a956e73",
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[869879, 17955, 564, 14, 47, "Output",ExpressionUUID->"79a1d2f7-7f12-4630-9a60-449f5dd8dd21",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[870458, 17972, 748, 26, 38, "Text",ExpressionUUID->"d3a991ea-bb9d-471a-8006-f40e33774c4f",
   Evaluatable->False,
   CellTags->{"ReadRays", "RG12."}]},
 "PropagateSystem"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[871416, 18008, 225, 8, 63, "Section",ExpressionUUID->"f16b8b76-3abc-432f-8b79-58f74680382d",
   CellTags->{"PropagateSystem", "13.", "RG13."}],
  Cell[871644, 18018, 533, 16, 22, "Text",ExpressionUUID->"689a409b-f5af-413a-907b-9b9cec7d70ae",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[872180, 18036, 1063, 37, 68, "FramedBox",ExpressionUUID->"437f1c99-1fe9-4e37-aac6-8df84c32b157",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[873246, 18075, 569, 16, 38, "Text",ExpressionUUID->"e7af37bd-e79a-4c38-9b7d-354f4c5af775",
   CellTags->{"PropagateSystem", "RG13."}],
  Cell[873840, 18095, 625, 13, 122, "Input",ExpressionUUID->"7e6e0e5e-ff02-4193-8367-bfdbf2f121c1",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
  Cell[874468, 18110, 547, 9, 23, "Output",ExpressionUUID->"5ef2f2a4-82c6-4e09-ba33-6b110c9e82af",
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
  Cell[875030, 18122, 916, 25, 51, "Text",ExpressionUUID->"7deed9e8-abe9-4501-81eb-e91376c45f45",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}]},
 "OptimizeSystem"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[2315521, 43788, 219, 7, 60, "Section",ExpressionUUID->"5c62ed6d-b544-44e0-affc-dcff777c52d7",
   CellTags->{"OptimizeSystem", "15.", "RG15."}],
  Cell[2315743, 43797, 532, 11, 37, "Text",ExpressionUUID->"419b7f51-9a7b-481a-b9c5-ae3663216c45",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2316278, 43810, 584, 20, 51, "FramedBox",ExpressionUUID->"188eecd5-87fc-44a1-97a8-d53de79f8064",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2316865, 43832, 675, 16, 38, "Text",ExpressionUUID->"9de3c256-3fe2-4d8a-a0f5-0251a566a82a",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2317543, 43850, 825, 34, 51, "FramedBox",ExpressionUUID->"464f8f91-b6db-4961-a243-0eaa5ee35b2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SphericalLens", "OptimizeSystem", "RG15."}],
  Cell[2318371, 43886, 311, 9, 21, "Text",ExpressionUUID->"2e5b0ef5-c7c3-44c6-ba4b-0e7f59661041",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2318685, 43897, 300, 7, 73, "Input",ExpressionUUID->"cc023c24-24c2-4956-bf37-e220676eb9b5",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2318988, 43906, 673, 16, 38, "Text",ExpressionUUID->"f106fd40-d378-4d6e-8a02-ef34ac16d402",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2319686, 43926, 289, 8, 24, "Input",ExpressionUUID->"edc39bfb-d98f-454b-ba00-fa5626702911",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2319978, 43936, 10054, 177, 135, "Print",ExpressionUUID->"326b1886-ce69-4775-b57f-27ed8186400d",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2330035, 44115, 413, 8, 24, "Output",ExpressionUUID->"f0700e2c-2c78-41a6-853d-7af972f922f5",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2330463, 44126, 268, 9, 21, "Text",ExpressionUUID->"07b449bf-c5a9-46e5-b911-cfe47228b2b3",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2330756, 44139, 199, 2, 24, "Input",ExpressionUUID->"6ece41d5-f3e3-45cf-aa92-7a37515cbd52",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2330958, 44143, 810, 18, 24, "Output",ExpressionUUID->"7ab3a572-6034-4db6-82c5-7498be5e4b4a",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2331783, 44164, 983, 24, 67, "Text",ExpressionUUID->"f12843e5-55ae-47eb-ae22-ba9bb72ec067",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2332791, 44192, 265, 6, 24, "Input",ExpressionUUID->"1a01a7b8-d66d-4978-801d-81d2ebe5808e",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2333059, 44200, 10128, 177, 135, "Print",ExpressionUUID->"1213985f-5e0e-420a-8dab-9c423b2d855e",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2343202, 44380, 682, 18, 38, "Text",ExpressionUUID->"26adf7e2-d329-4e5f-9eb1-652c33ff4999",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2343909, 44402, 213, 4, 24, "Input",ExpressionUUID->"e7a71eb1-906b-4f00-b5c4-af9e47b73be8",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2344125, 44408, 787, 17, 24, "Output",ExpressionUUID->"db4e6ada-8a4c-406b-a33e-82257316feac",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2344927, 44428, 843, 15, 60, "Text",ExpressionUUID->"2002864d-91c5-4d29-bf56-0440598d610f",
   CellTags->{"OptimizeSystem", "RG15."}]},
 "ReadTurboRays"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[2318685, 43897, 300, 7, 73, "Input",ExpressionUUID->"cc023c24-24c2-4956-bf37-e220676eb9b5",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2330756, 44139, 199, 2, 24, "Input",ExpressionUUID->"6ece41d5-f3e3-45cf-aa92-7a37515cbd52",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2330958, 44143, 810, 18, 24, "Output",ExpressionUUID->"7ab3a572-6034-4db6-82c5-7498be5e4b4a",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2332791, 44192, 265, 6, 24, "Input",ExpressionUUID->"1a01a7b8-d66d-4978-801d-81d2ebe5808e",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2333059, 44200, 10128, 177, 135, "Print",ExpressionUUID->"1213985f-5e0e-420a-8dab-9c423b2d855e",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2345980, 44453, 369, 14, 60, "Section",ExpressionUUID->"e91ead7e-40a8-487a-bf8c-0484bf29162e",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ReadTurboRays", "16.", "RG16."}],
  Cell[2346352, 44469, 729, 24, 38, "Text",ExpressionUUID->"e6500628-5d71-46fb-a65d-25f64f40cdac",
   Evaluatable->False,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2347084, 44495, 988, 38, 64, "FramedBox",ExpressionUUID->"fa23eb4b-123d-4b73-8c2a-049c29b39f31",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2348075, 44535, 851, 28, 38, "Text",ExpressionUUID->"27dc19c8-3f1e-4113-8d48-6d8c91574faf",
   Evaluatable->False,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2348951, 44567, 331, 10, 24, "Input",ExpressionUUID->"ac39550a-adc9-476a-badc-8f596522a545",
   PageBreakWithin->Automatic,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2349285, 44579, 631, 12, 23, "Output",ExpressionUUID->"c13cb3ca-df62-45ca-b807-f754b94cce80",
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2349953, 44596, 336, 10, 24, "Input",ExpressionUUID->"946ef065-9abd-4fb3-be82-da7b516f91d6",
   PageBreakWithin->Automatic,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2350292, 44608, 635, 12, 23, "Output",ExpressionUUID->"3f20e29b-88cd-423d-8ef8-208f94dec97c",
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2350942, 44623, 797, 31, 38, "Text",ExpressionUUID->"a97f46df-9b47-4469-9823-01f3549ca975",
   CellTags->{"ReadTurboRays", "RG16."}]},
 "FindIntensity"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7913, 238, 277, 6, 20, "Outline2",ExpressionUUID->"0225a6ed-e4de-45a0-bf44-173443ff56f9",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[8193, 246, 789, 24, 68, "Outline3",ExpressionUUID->"69e7edd6-dba9-4da0-af18-6eb332da20ac",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
   CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352216, 44673, 489, 12, 37, "Text",ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352708, 44687, 756, 26, 51, "FramedBox",ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2353467, 44715, 1670, 50, 70, "Text",ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2355140, 44767, 224, 5, 20, "Text",ExpressionUUID->"20a964d3-7fe5-429c-a9f8-92f8d718eb4d",
   CellTags->{"FindIntensity", "RG17.", "RG17.1"}],
  Cell[2355389, 44776, 318, 7, 35, "Subsection",ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", "17.1"}],
  Cell[2355710, 44785, 860, 19, 51, "Text",ExpressionUUID->"3309fe78-8bea-41d2-9e89-be26e8481dcc",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356595, 44808, 330, 8, 73, "Input",ExpressionUUID->"047766fb-8eda-427a-9c3e-35823ea5836e",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356928, 44818, 964, 22, 20, "Print",ExpressionUUID->"0de2e702-472d-4a7d-a33a-128938072ae6",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2357895, 44842, 323025, 5562, 296, "Print",ExpressionUUID->"eeabf9da-4b78-4217-9378-83252c32fedd",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2680923, 50406, 333374, 5584, 131, "Output",ExpressionUUID->"1c035b97-c43f-4851-8b25-054d8a319820",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3014312, 55993, 1281, 31, 72, "Text",ExpressionUUID->"61fe767f-feb3-477a-a22f-08ad310cb74c",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015596, 56026, 284, 7, 21, "Text",ExpressionUUID->"9f08fe51-ea3c-4aaa-9cef-8c9e59b7d550",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015905, 56037, 253, 7, 24, "Input",ExpressionUUID->"6c99f091-180f-479e-a164-578479e304a5",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3016161, 56046, 2360, 47, 104, "Output",ExpressionUUID->"af9e7bec-c4e9-4c06-977f-2f278dbbb732",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018536, 56096, 356, 8, 21, "Text",ExpressionUUID->"cc3b45c7-e4f3-4e3c-b46f-6d6e177fe337",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018895, 56106, 904, 25, 114, "FramedBox",ExpressionUUID->"46cb697f-b80f-4d01-bd6c-4876a42ca360",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3019802, 56133, 283, 8, 27, "Commentary",ExpressionUUID->"c67f89f6-560d-495a-8599-39f4b27400df",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020088, 56143, 292, 6, 20, "Text",ExpressionUUID->"e5a6054d-dd48-4061-bcbb-f0b7a1201f9a",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020383, 56151, 396, 9, 21, "Text",ExpressionUUID->"acbccdd9-b6e4-4445-8c63-5d21e8a43520",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020782, 56162, 911, 25, 100, "FramedBox",ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021696, 56189, 257, 8, 27, "Commentary",ExpressionUUID->"7831497e-8aba-4284-b96e-49915e0b2651",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021956, 56199, 756, 18, 51, "Text",ExpressionUUID->"b637b49d-dc30-4a08-809d-bb46795dbf59",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022737, 56221, 234, 3, 24, "Input",ExpressionUUID->"1b065470-deed-4044-8680-13146f928883",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022974, 56226, 731153, 12157, 371, "Print",ExpressionUUID->"2c1a3fe1-f530-44e5-ad59-dc837b0018fa",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3754142, 68386, 214, 5, 20, "Text",ExpressionUUID->"7db99dae-8ac2-4250-90f0-8207449940a8",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[3754393, 68396, 266, 7, 35, "Subsection",ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2", "17.2"}],
  Cell[3754662, 68405, 967, 20, 67, "Text",ExpressionUUID->"1e979e95-2969-4469-bdb2-4b4c0c51ff29",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3755654, 68429, 353, 7, 73, "Input",ExpressionUUID->"bf84e43a-fae7-473b-aa4b-b5e31a85f037",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3756010, 68438, 23625, 395, 213, "Print",ExpressionUUID->"b3b339b6-d05a-4a26-9fcc-fc53d96f9d15",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3779650, 68836, 420, 10, 21, "Text",ExpressionUUID->"f5f2213a-8c67-4cc7-a6e0-6cc3d95ece0b",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780073, 68848, 796, 28, 51, "FramedBox",ExpressionUUID->"a33391f6-588e-4017-94b4-c9b65311d253",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780872, 68878, 471, 12, 34, "Text",ExpressionUUID->"72ac0498-3b0e-4219-8bae-6f4e17c2f6fa",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781368, 68894, 182, 2, 24, "Input",ExpressionUUID->"9f4a8b78-0096-4924-824c-df2fc5d1f38e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781553, 68898, 21105, 421, 354, "Print",ExpressionUUID->"16d21f8f-ecc7-4ca0-8326-e017183ba907",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3802661, 69321, 1326, 31, 56, "Output",ExpressionUUID->"8a13b68c-4edf-455a-bfd8-08aa9b5a8063",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3804002, 69355, 1004, 26, 54, "Text",ExpressionUUID->"ef728d99-f6af-4701-821f-7667055c288e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805031, 69385, 188, 2, 24, "Input",ExpressionUUID->"d1fc3e93-d0bb-4abd-abbd-f079d7dd2d57",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805222, 69389, 378, 6, 23, "Output",ExpressionUUID->"591b7135-4c02-4d42-8df1-963cbf3dd8a1",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805615, 69398, 214, 5, 20, "Text",ExpressionUUID->"0767282a-0043-4f56-9f76-2b558adf3ab0",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[3805866, 69408, 312, 8, 35, "Subsection",ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "17.3", "Point Spread Function (PSF)"}],
  Cell[3806181, 69418, 458, 13, 21, "Text",ExpressionUUID->"7ee32d46-f354-4350-98ce-745d5fe62fb5",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3806664, 69435, 397, 8, 89, "Input",ExpressionUUID->"03f38441-916b-4472-a72f-cebe22f1de4b",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3807064, 69445, 963, 21, 20, "Print",ExpressionUUID->"a389c04a-1214-4a12-9503-59d753754c5f",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3808030, 69468, 1039597, 17914, 280, "Print",ExpressionUUID->"9e219fa5-0d2f-4a98-8336-e967b4266678",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[4847630, 87384, 1068108, 17936, 114, "Output",ExpressionUUID->"faea0d3b-afe1-4883-b972-798f0b1cc126",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5915753, 105323, 522, 14, 34, "Text",ExpressionUUID->"41ceb80e-2181-4cd7-b774-e47b379c16d3",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916300, 105341, 222, 2, 24, "Input",ExpressionUUID->"4bb39fd2-06ac-4850-8973-a84b4945ffe4",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916525, 105345, 956, 21, 20, "Print",ExpressionUUID->"e31d0700-a56e-4a47-9922-4c9df4642880",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5917484, 105368, 66039, 1197, 249, "Print",ExpressionUUID->"e24be2f9-c5d4-481a-b7cb-42d643c4e308",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5983538, 106568, 1774, 36, 119, "Text",ExpressionUUID->"6a8298d3-cd1c-4426-ba27-6e0e9d9c4ef0",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5985315, 106606, 1303, 53, 64, "FramedBox",ExpressionUUID->"383b92d9-bb1f-4fa8-9b79-4d97513a96de",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5986621, 106661, 468, 15, 21, "Text",ExpressionUUID->"8f2a8809-ca0e-424e-b3dd-02b65ee36fc7",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5987092, 106678, 919, 35, 51, "FramedBox",ExpressionUUID->"de33a8b9-bafc-4dc0-a878-7ae11c86ac7a",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5988014, 106715, 992, 30, 38, "Text",ExpressionUUID->"b6b2e779-1a5b-4ed1-b908-aea9d02a4f32",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5989009, 106747, 214, 5, 20, "Text",ExpressionUUID->"c35f1e2e-2fa0-4f19-b803-21670f38c3eb",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[5989260, 106757, 316, 7, 35, "Subsection",ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", "17.4"}],
  Cell[5989579, 106766, 469, 12, 38, "Text",ExpressionUUID->"30c801a3-37d5-4911-b3a1-d9d387a5f414",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5990051, 106780, 730, 23, 51, "FramedBox",ExpressionUUID->"9c0d1061-6d13-4c39-8a38-fc416aeca7f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4"}],
  Cell[5990784, 106805, 551, 13, 34, "Text",ExpressionUUID->"86795780-c101-4bd7-81de-63e3b9e5d003",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991360, 106822, 212, 3, 24, "Input",ExpressionUUID->"69d700c4-c02f-46db-91df-f1f4ad496ccd",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991575, 106827, 1277, 28, 56, "Output",ExpressionUUID->"b3e7fbc4-8c5c-4773-8b21-2c1f50002099",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5992889, 106860, 219, 3, 24, "Input",ExpressionUUID->"05011727-66ba-42d7-9311-76ce95abffd2",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5993111, 106865, 34653, 618, 242, "Print",ExpressionUUID->"532b389b-e46b-494e-850f-5801f1dd3eb4",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[6027767, 107485, 1134284, 18596, 192, "Output",ExpressionUUID->"8b30f9f8-5631-422e-a696-d65c329e250a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162066, 126084, 766, 18, 51, "Text",ExpressionUUID->"97450984-6a0c-4acf-9174-51e10e28d20a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162835, 126104, 244, 5, 20, "Text",ExpressionUUID->"8381b864-31bc-46c1-8f73-17774d620556",
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17."}],
  Cell[7163116, 126114, 318, 7, 35, "Subsection",ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", "17.5"}],
  Cell[7163437, 126123, 529, 12, 38, "Text",ExpressionUUID->"34623c4b-fe27-43e8-bd53-4b5427b399dd",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7163991, 126139, 403, 9, 73, "Input",ExpressionUUID->"fb3f9c9b-3e34-4d0e-ab34-9367873467c2",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7164397, 126150, 15205, 257, 216, "Print",ExpressionUUID->"73e948d6-1694-44b4-ae7d-aa818ce26431",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7179617, 126410, 1060, 22, 67, "Text",ExpressionUUID->"f8f0bdcf-fab1-40be-95b1-7e144ffe3c6c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7180702, 126436, 585, 13, 89, "Input",ExpressionUUID->"5edc0363-6e09-425e-a719-e41a4ce3275a",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7181290, 126451, 1017, 23, 20, "Print",ExpressionUUID->"2838a744-8620-4e26-a900-a8328ac1c274",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7182310, 126476, 40684, 723, 249, "Print",ExpressionUUID->"2f268b14-14d8-48a5-a7eb-687acda3458f",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7222997, 127201, 1020, 23, 20, "Print",ExpressionUUID->"3e3c72dd-d769-434f-b710-2079c05b91f7",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7224020, 127226, 53528, 952, 249, "Print",ExpressionUUID->"a296cdfd-0141-441f-98aa-ef27a78ddd7c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7277551, 128180, 101438, 1706, 301, "Output",ExpressionUUID->"a1a52898-e5e7-40a2-bad0-b10bb386556d",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379004, 129889, 958, 24, 54, "Text",ExpressionUUID->"3dd53550-bd89-4434-8178-b4bdb23c4c00",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379965, 129915, 534, 14, 38, "Text",ExpressionUUID->"d70a31c8-3057-42e4-ad73-12b52a878b1c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380524, 129933, 245, 6, 24, "Input",ExpressionUUID->"9588485b-e6e9-491f-baef-c7d69029eba3",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380772, 129941, 422, 8, 20, "Print",ExpressionUUID->"409ae0e2-9603-42ba-980c-4a24dcf7d5df",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381197, 129951, 338, 5, 23, "Output",ExpressionUUID->"de6bc496-b575-462e-bc44-25ac8b5a9211",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381550, 129959, 1382, 20, 85, "Text",ExpressionUUID->"f22e5175-9749-47ac-b69b-4446723b94d5",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7382935, 129981, 253, 5, 20, "Text",ExpressionUUID->"c605f174-ab57-4738-8b7a-88a1e288edac",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17."}]},
 "Resonate"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7383237, 129992, 211, 8, 63, "Section",ExpressionUUID->"6ac6bfd3-1a3d-49c7-95bf-3feeaabfa8cd",
   CellTags->{"Resonate", "18.", "RG18."}],
  Cell[7383451, 130002, 818, 23, 54, "Text",ExpressionUUID->"8d722c0e-fc4f-44f3-9c41-5eab67bf2242",
   Evaluatable->False,
   CellTags->{"ray tracing", "Resonate", "RG18."}],
  Cell[7384272, 130027, 622, 22, 51, "FramedBox",ExpressionUUID->"2a3a4728-f479-438e-ac36-9372ed3ae683",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Resonate", "RG18."}],
  Cell[7384897, 130051, 1152, 25, 66, "Text",ExpressionUUID->"f385f2b0-9078-4098-94f4-63d776aa23db",
   Evaluatable->False,
   CellTags->{"ray tracing", "Resonate", "RG18."}],
  Cell[7386074, 130080, 272, 8, 89, "Input",ExpressionUUID->"0c140923-69b9-470b-a77f-5008c14dc1d6",
   CellTags->{"Resonate", "RG18."}],
  Cell[7386349, 130090, 30541, 527, 365, "Print",ExpressionUUID->"6917394b-82e0-453f-9725-1fbfafe6fde5",
   CellTags->{"Resonate", "RG18."}],
  Cell[7416905, 130620, 287, 7, 21, "Text",ExpressionUUID->"b9ce648b-21ea-45df-ab34-f82451a785f1",
   CellTags->{"Resonate", "RG18."}],
  Cell[7417217, 130631, 236, 8, 89, "Input",ExpressionUUID->"5a9a8588-177e-4de2-83fb-261ce5be10d2",
   CellTags->{"Resonate", "RG18."}],
  Cell[7417456, 130641, 785, 23, 23, "Output",ExpressionUUID->"510cfad9-5bec-4894-a87f-08e0b2a1190d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7418256, 130667, 491, 13, 38, "Text",ExpressionUUID->"e6647d4c-317d-40ec-9b89-be6bce0d6eb8",
   CellTags->{"Resonate", "RG18."}],
  Cell[7418772, 130684, 146, 2, 24, "Input",ExpressionUUID->"33cb3d49-cf10-4fa5-baa7-e84bbc9e5d2d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7418921, 130688, 284, 4, 24, "Output",ExpressionUUID->"17d11535-b739-4885-9703-239044fb0481",
   CellTags->{"Resonate", "RG18."}],
  Cell[7419220, 130695, 318, 7, 21, "Text",ExpressionUUID->"71d16563-1462-43f1-98d8-24d033a3d5be",
   CellTags->{"Resonate", "RG18."}],
  Cell[7419563, 130706, 222, 7, 73, "Input",ExpressionUUID->"b4f7d976-188c-4529-9899-687a2e0498f3",
   CellTags->{"Resonate", "RG18."}],
  Cell[7419788, 130715, 32007, 545, 365, "Print",ExpressionUUID->"e96c081c-a9aa-41f5-99a6-34254acef2b3",
   CellTags->{"Resonate", "RG18."}],
  Cell[7451810, 131263, 371, 11, 21, "Text",ExpressionUUID->"286d46df-c400-4cf9-8232-126cf5763f8b",
   CellTags->{"Resonate", "RG18."}],
  Cell[7452206, 131278, 218, 7, 73, "Input",ExpressionUUID->"08e221a1-ddb4-4fe2-96bc-4448f258c60d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7452427, 131287, 14091, 233, 365, "Print",ExpressionUUID->"89ed0fca-2e01-49aa-b26c-a77ffe90711d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7466533, 131523, 378, 13, 21, "Text",ExpressionUUID->"8f92118e-8f6c-40ba-8b88-df844e2ec576",
   CellTags->{"Resonate", "RG18."}]},
 "Database"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7467121, 131546, 201, 8, 60, "Section",ExpressionUUID->"2ad8be42-a103-45bc-b5e7-11647de00c94",
   CellTags->{"Database", "19.", "RG19."}],
  Cell[7467325, 131556, 1344, 35, 63, "Text",ExpressionUUID->"320ecd25-a05c-4d82-a030-825895be5acc",
   CellTags->{"Database", "RG19."}],
  Cell[7468672, 131593, 1409, 47, 126, "FramedBox",ExpressionUUID->"f62bd2bd-7199-4214-9b20-7dd6e400011e",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Database", "RG19."}],
  Cell[7470084, 131642, 810, 20, 54, "Text",ExpressionUUID->"5f9a3aef-feca-426c-93d6-6be218e4b1f3",
   CellTags->{"Database", "RG19."}],
  Cell[7470897, 131664, 478, 12, 33, "Text",ExpressionUUID->"63bb1f15-1c8d-4b3b-97b4-013c42c4f946",
   CellTags->{"Database", "RG19."}],
  Cell[7471400, 131680, 191, 2, 24, "Input",ExpressionUUID->"c6e33c49-eca9-475d-8690-8d1296cfea33",
   CellTags->{"Database", "RG19."}],
  Cell[7471594, 131684, 7200, 164, 278, "Output",ExpressionUUID->"071c5fc1-692c-44bc-b0de-d41e4f3dded6",
   CellTags->{"Database", "RG19."}],
  Cell[7478809, 131851, 1255, 29, 79, "Text",ExpressionUUID->"cae6081d-4799-4ecd-8bff-afa8022ea3e3",
   CellTags->{"Database", "RG19."}],
  Cell[7480089, 131884, 142, 2, 24, "Input",ExpressionUUID->"eb683a7c-4ae2-4920-870b-9af074c17cfb",
   CellTags->{"Database", "RG19."}],
  Cell[7480234, 131888, 2893, 43, 216, "Output",ExpressionUUID->"ee141b33-8d36-4733-b715-5e5c09ae6fe6",
   CellTags->{"Database", "RG19."}],
  Cell[7483142, 131934, 625, 22, 38, "Text",ExpressionUUID->"80f30a0e-4f8b-4c98-ab07-102c54d63d5f",
   CellTags->{"Database", "RG19."}],
  Cell[7483770, 131958, 1382, 42, 133, "FramedBox",ExpressionUUID->"3c2399ec-fba3-40b1-99e9-e62ae314b455",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "Database", "RG19."}],
  Cell[7485155, 132002, 149, 2, 26, "Commentary",ExpressionUUID->"fff5d2ab-950e-4d33-b925-b247ae539596",
   CellTags->{"Database", "RG19."}],
  Cell[7485307, 132006, 729, 22, 38, "Text",ExpressionUUID->"a9b043b8-f5ec-4fde-aaa6-6f19e94a2bd2",
   CellTags->{"Database", "RG19."}],
  Cell[7486061, 132032, 236, 6, 24, "Input",ExpressionUUID->"f6a296c6-c0a2-4830-810f-ef9a52a1baf7",
   CellTags->{"Database", "RG19."}],
  Cell[7486300, 132040, 1410, 23, 104, "Output",ExpressionUUID->"45a7ee28-fa3e-4b6a-a4ef-38c7acfefa88",
   CellTags->{"Database", "RG19."}],
  Cell[7487725, 132066, 1551, 38, 103, "Text",ExpressionUUID->"fe197e53-825d-43bd-a771-59588321771f",
   CellTags->{"Database", "RG19."}],
  Cell[7489279, 132106, 467, 14, 51, "FramedBox",ExpressionUUID->"8267d24e-83d6-4a31-a9ba-c281cfb392d2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReportedInterval", "Database", "RG19."}],
  Cell[7489749, 132122, 958, 24, 54, "Text",ExpressionUUID->"4a8f756b-f7ad-431a-8619-9ad2af5c1d54",
   CellTags->{"Database", "RG19."}],
  Cell[7490732, 132150, 209, 3, 24, "Input",ExpressionUUID->"a58dda43-82da-49df-9870-1d174d20e15e",
   CellTags->{"Database", "RG19."}],
  Cell[7490944, 132155, 4131, 84, 200, "Output",ExpressionUUID->"d8592e33-4ed9-48fa-8902-17393762762e",
   CellTags->{"Database", "RG19."}],
  Cell[7495090, 132242, 1187, 31, 69, "Text",ExpressionUUID->"68ffe976-6bf7-4c62-894d-ffb512688a4b",
   CellTags->{"Database", "RG19."}],
  Cell[7496302, 132277, 205, 4, 24, "Input",ExpressionUUID->"3ac515bc-d8ce-4f77-83a8-d8ca5a9f623f",
   CellTags->{"Database", "RG19."}],
  Cell[7496510, 132283, 1772, 35, 72, "Output",ExpressionUUID->"0e8c1c8d-9eb9-41e0-82c9-cc8ebd31f04b",
   CellTags->{"Database", "RG19."}],
  Cell[7498297, 132321, 437, 13, 21, "Text",ExpressionUUID->"28e8b3b1-19f9-4ac0-bfd5-de2db6cf2ecc",
   CellTags->{"Database", "RG19."}],
  Cell[7498759, 132338, 233, 5, 41, "Input",ExpressionUUID->"8a9c311d-9b1b-4b3e-bbe8-f14f92da05ec",
   CellTags->{"Database", "RG19."}],
  Cell[7498995, 132345, 662, 16, 24, "Output",ExpressionUUID->"61b98bbe-fb27-457b-910b-4bd19dcbdfa8",
   CellTags->{"Database", "RG19."}],
  Cell[7499660, 132363, 13895, 227, 438, "Print",ExpressionUUID->"1c5e58ca-393f-4ec5-beab-2f1a1949f8ab",
   CellTags->{"Database", "RG19."}],
  Cell[7513570, 132593, 393, 11, 20, "Text",ExpressionUUID->"105f563c-551c-40db-8444-64442de81d48",
   CellTags->{"Database", "RG19."}],
  Cell[7513988, 132608, 205, 4, 24, "Input",ExpressionUUID->"c89563a2-51fd-4b4c-9315-c4a0710dcb74",
   CellTags->{"Database", "RG19."}],
  Cell[7514196, 132614, 8726, 175, 360, "Output",ExpressionUUID->"7b2d3ae9-a8b2-4e33-b74b-d7478c7126a5",
   CellTags->{"Database", "RG19."}],
  Cell[7522937, 132792, 544, 14, 38, "Text",ExpressionUUID->"06ec706d-fdd8-44c8-b609-6bd53f59f9a3",
   CellTags->{"Database", "RG19."}],
  Cell[7523506, 132810, 254, 5, 24, "Input",ExpressionUUID->"86e32bc2-274e-45c2-8206-2161f148fa42",
   CellTags->{"Database", "RG19."}],
  Cell[7523763, 132817, 954, 25, 131, "Output",ExpressionUUID->"8d38c99c-2568-4708-b441-e9f560629304",
   CellTags->{"Database", "RG19."}],
  Cell[7524732, 132845, 443, 12, 34, "Text",ExpressionUUID->"a0f07990-74b7-4276-b78d-161863b82f07",
   CellTags->{"Database", "RG19."}],
  Cell[7525200, 132861, 167, 2, 24, "Input",ExpressionUUID->"993138d5-d0c0-4851-bdd3-336bef7e015c",
   CellTags->{"Database", "RG19."}],
  Cell[7525370, 132865, 651, 16, 24, "Output",ExpressionUUID->"4fa51032-9c32-4056-aeb8-d8f07e45872a",
   CellTags->{"Database", "RG19."}],
  Cell[7526036, 132884, 237, 5, 20, "Text",ExpressionUUID->"80e078d0-8e72-4024-814d-fdde7d9e7cf6",
   CellTags->{"Database", "RG19."}],
  Cell[7526298, 132893, 153, 2, 24, "Input",ExpressionUUID->"f1dd3ebf-70de-4799-9372-7f56ef9939da",
   CellTags->{"Database", "RG19."}],
  Cell[7526454, 132897, 295, 5, 23, "Output",ExpressionUUID->"b71c509f-7fac-4f76-a1bc-eaa33bc4fce5",
   CellTags->{"Database", "RG19."}],
  Cell[7526786, 132907, 155, 2, 24, "Input",ExpressionUUID->"696fbf67-6d6e-4a36-ab5f-875ee48f709c",
   CellTags->{"Database", "RG19."}],
  Cell[7526944, 132911, 293, 5, 23, "Output",ExpressionUUID->"f0508462-a5a9-4d2c-b14c-0c1ef10d3b94",
   CellTags->{"Database", "RG19."}],
  Cell[7527252, 132919, 229, 7, 20, "Text",ExpressionUUID->"d1a9bf02-f552-4374-b7d1-5e1ecf461f62",
   CellTags->{"Database", "RG19."}]},
 "What's Missing"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[9684, 293, 255, 6, 20, "Outline2",ExpressionUUID->"fdeeb244-3332-43ca-95c2-6c4de1b3d371",
   CellTags->{"What's Missing", "RG21."}],
  Cell[9942, 301, 564, 16, 42, "Outline3",ExpressionUUID->"3eb4baaf-4492-4fa0-a5de-09e6ad2f6df5",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7638808, 135017, 147, 3, 60, "Section",ExpressionUUID->"d39bd8e9-1177-4306-8ca7-77cd6f4afc93",
   CellTags->{"What's Missing", "RG21.", "21."}],
  Cell[7638958, 135022, 1612, 38, 85, "Text",ExpressionUUID->"9a73353d-4300-4462-8499-aefb7bebd549",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7640595, 135064, 285, 7, 35, "Subsection",ExpressionUUID->"e52217ef-ac6b-4840-95cb-6737e8877556",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Features not discussed here", "What's Missing", "RG21."}],
  Cell[7640883, 135073, 816, 18, 46, "Text",ExpressionUUID->"fd8eec84-ca17-40d5-b500-a4576be18653",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7641702, 135093, 1097, 27, 59, "Text",ExpressionUUID->"ceb071e0-1de7-468c-8c8b-c20fe4c299d0",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7642802, 135122, 2098, 48, 112, "Text",ExpressionUUID->"b9524a5d-6928-420f-b34f-2b1a1b0c1429",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7644937, 135175, 285, 7, 35, "Subsection",ExpressionUUID->"3cdc573b-b05b-4668-b37f-e2d853505dcc",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Features left to the future", "What's Missing", "RG21."}],
  Cell[7645225, 135184, 833, 18, 46, "Text",ExpressionUUID->"d0f11d3d-3d17-45eb-bf31-29c5ff3d53d7",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7646061, 135204, 940, 27, 46, "Text",ExpressionUUID->"0315375b-e20d-4040-84d6-b496835f53fd",
   CellTags->{"What's Missing", "RG21."}]},
 "Backward Compatibility"->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7647223, 135242, 169, 3, 60, "Section",ExpressionUUID->"44e4ee72-4c79-4f62-a2c3-21d1a43cf67f",
   CellTags->{"Backward Compatibility", "RG22.", "22."}],
  Cell[7647395, 135247, 1392, 36, 80, "Text",ExpressionUUID->"1fff4d7f-9ccf-4d2d-85f7-6e2690c95ca1",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7648812, 135287, 209, 7, 35, "Subsection",ExpressionUUID->"9ebbfb22-8058-4a5a-9efb-d34b4ab7b580",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7649024, 135296, 851, 27, 38, "Text",ExpressionUUID->"b21ddcf9-bf95-4b6a-9be3-5cd62d7c00e0",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7649912, 135328, 287, 11, 35, "Subsection",ExpressionUUID->"25945faa-a20f-4b29-8cad-53bf25b6ada2",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7650202, 135341, 868, 30, 34, "Text",ExpressionUUID->"dd3bfab9-da54-48f2-bff3-1c9bf08b2cff",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7651107, 135376, 428, 17, 35, "Subsection",ExpressionUUID->"ddbbf9b1-3e8a-47e2-aa9d-7ca7c0c1cb19",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7651538, 135395, 1544, 61, 38, "Text",ExpressionUUID->"0dde57cf-1cf9-4dfb-85d3-396d9aeb9640",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653119, 135461, 166, 3, 35, "Subsection",ExpressionUUID->"889794e7-a81e-4555-9199-a60440190b8f",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653288, 135466, 449, 15, 21, "Text",ExpressionUUID->"887cd1d7-580b-4b04-89b2-dca8ba6d1489",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653762, 135485, 182, 3, 24, "Input",ExpressionUUID->"56f8e24b-c46a-4879-be75-1e2ebbb6c6e0",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653947, 135490, 1615, 33, 72, "Output",ExpressionUUID->"9b05f338-6bae-46d3-b82a-0545bc42aa70",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7655577, 135526, 584, 20, 34, "Text",ExpressionUUID->"551560ab-dcf3-4fcf-90f7-f9b2cc52d543",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7656186, 135550, 183, 3, 24, "Input",ExpressionUUID->"2a32a075-5288-426d-ad6d-9c0059c0028b",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7656372, 135555, 2026, 53, 88, "Output",ExpressionUUID->"4eae78a1-49f4-413c-938e-f8b9aab0c576",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7658447, 135614, 285, 10, 35, "Subsection",ExpressionUUID->"5eb1be0a-f892-4962-8d2e-780097fe1de0",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7658735, 135626, 729, 20, 38, "Text",ExpressionUUID->"186fd96c-5dd9-49ef-bb4d-be189043c513",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7659501, 135651, 170, 3, 35, "Subsection",ExpressionUUID->"e1f6db08-382c-49f4-88d1-f6d5f29c9027",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7659674, 135656, 571, 16, 38, "Text",ExpressionUUID->"c468bd9b-f498-4bdb-b335-33f1631ffe9c",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7660248, 135674, 922, 40, 21, "Text",ExpressionUUID->"da00a46c-c883-40b8-ae15-e1abff07de6b",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7661173, 135716, 152, 3, 20, "Text",ExpressionUUID->"883028bd-5da7-4eeb-a206-5dd71bc5c1b9",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7661328, 135721, 1199, 51, 21, "Text",ExpressionUUID->"83320e74-4ea2-4842-86f6-e556d83abd72",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7662564, 135777, 157, 3, 35, "Subsection",ExpressionUUID->"5f1d0e95-b0c4-4de5-8869-00cb0ed2b831",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7662724, 135782, 2425, 105, 38, "Text",ExpressionUUID->"634a8f1c-56db-4d25-9b47-47ae6bad8c77",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7665152, 135889, 392, 14, 21, "Text",ExpressionUUID->"bfad9ebf-115f-49c1-9b02-f312fee0821f",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7665569, 135907, 185, 3, 24, "Input",ExpressionUUID->"ad1429ae-c6a4-4a74-991b-dc7afa9f7a35",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7665757, 135912, 4128, 98, 177, "Output",ExpressionUUID->"1634a1bc-1220-4446-bc19-63db0d4fb6ad",
   CellTags->{"Backward Compatibility", "RG22."}]},
 "RG1."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[1482, 40, 273, 6, 24, "Outline2",ExpressionUUID->"dc0a96d6-42ba-4e7e-a04b-d1cd188e123c",
   CellTags->{"Optica User Guide Introduction", "RG1."}],
  Cell[1758, 48, 929, 29, 107, "Outline3",ExpressionUUID->"e0c4d643-70f6-4836-9c40-03b74debd9f2",
   CellTags->{"Optica User Guide Introduction", "RG1."}],
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11143, 338, 673, 12, 46, "Text",ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1",
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11819, 352, 1112, 29, 46, "Text",ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9",
   Evaluatable->False,
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[13343, 399, 1312, 46, 46, "Text",ExpressionUUID->"53444f15-79b2-4da2-b4fc-a3aabc38a11b",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[14680, 449, 331, 12, 24, "Input",ExpressionUUID->"d0f1842b-9e8e-4fc2-bb3d-62a54619b000",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15014, 463, 491, 11, 20, "Print",ExpressionUUID->"30459a7a-ca46-4d83-af0d-fdb4a9801d45",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15508, 476, 376, 9, 19, "Print",ExpressionUUID->"2b7b290f-ec8f-499f-8ccd-8f8a5c6dde38",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15899, 488, 904, 27, 33, "Text",ExpressionUUID->"b86d0f77-e2c9-4cc9-b06f-923277e3bc7c",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[16806, 517, 230, 5, 20, "Text",ExpressionUUID->"41f630dd-c76a-4762-9b3a-8b0549a3ab54",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
   CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[17359, 538, 817, 18, 46, "Text",ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e",
   CellTags->{"Loading Rayica", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18201, 560, 321, 9, 89, "Input",ExpressionUUID->"528d9f96-c640-4726-aec0-55305c4ecf62",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18525, 571, 11143, 190, 223, "Print",ExpressionUUID->"2cd65a8a-29ca-47a4-b77a-241da870ded0",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[29671, 763, 356, 5, 24, "Output",ExpressionUUID->"decbdd55-e771-48ea-ad88-55eaabd4f074",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[30042, 771, 230, 5, 20, "Text",ExpressionUUID->"033ae809-63ce-4eb9-9982-e5b4caef8625",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
   CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[30507, 786, 633, 12, 33, "Text",ExpressionUUID->"6fc8cab9-7ee2-44e2-b98b-cdd60e0e3655",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[31143, 800, 1410, 31, 83, "Text",ExpressionUUID->"dda7200a-0a2d-46e4-a177-efe1267d01ee",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[32556, 833, 230, 5, 20, "Text",ExpressionUUID->"054d5311-4067-40d5-bc3e-4b005d80ec26",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
   CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[33061, 849, 1018, 21, 66, "Text",ExpressionUUID->"87327b10-7eee-41c6-ac55-2a9376422dad",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34082, 872, 711, 18, 38, "Text",ExpressionUUID->"fa99db1d-7880-4526-9fdb-e0675a094fe9",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34796, 892, 522, 12, 37, "Text",ExpressionUUID->"aebb1dd9-09f9-4ca0-b88c-b3e5ed789c74",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35321, 906, 227, 3, 20, "Text",ExpressionUUID->"e0a3b9c6-0ae8-4dbb-8793-b4c9f770f285",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35551, 911, 707, 17, 130, "Text",ExpressionUUID->"4dafee9d-c203-44b3-bd11-6d428cd52708",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[36261, 930, 261, 5, 20, "Text",ExpressionUUID->"aa596a2d-47a7-483c-93b4-520dd475278c",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1."}],
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[36799, 946, 247, 5, 20, "Text",ExpressionUUID->"104e8fd2-1286-4ad8-bd49-62165d86e223",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37071, 955, 307, 9, 89, "Input",ExpressionUUID->"f920023b-619f-404b-8aca-2883db8d47c3",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37381, 966, 1126, 35, 24, "Output",ExpressionUUID->"369f0439-ef91-407d-b2b8-1a6d1ee2c936",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[38522, 1004, 562, 10, 33, "Text",ExpressionUUID->"dee619ee-4b4d-47a4-a93c-18511ca4be05",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39109, 1018, 224, 3, 24, "Input",ExpressionUUID->"5727830a-6763-4831-be3d-b5c19b2eeef4",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39336, 1023, 11138, 190, 223, "Print",ExpressionUUID->"acdffe68-5863-48c5-a77f-a7c3baf51997",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[50477, 1215, 353, 5, 24, "Output",ExpressionUUID->"c9ab9764-21af-4c4b-9970-43a26f36b411",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[50845, 1223, 230, 5, 20, "Text",ExpressionUUID->"ddcfaf90-344d-4cea-ab86-cbf260c01c93",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
   CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51314, 1238, 418, 9, 21, "Text",ExpressionUUID->"b961e791-5ad4-44d6-be6c-25237633de9a",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51757, 1251, 196, 3, 24, "Input",ExpressionUUID->"60b3ccf1-9b6a-42b4-beda-efdf85878f43",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51956, 1256, 1410, 21, 163, "Print",ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30",
   CellTags->{"Basic Commands", "Info3614689788-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[53369, 1279, 1353, 19, 196, "Print",ExpressionUUID->"3598c355-5d0a-4d3d-9b3d-f7fd245ab10e",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[54737, 1301, 510, 16, 21, "Text",ExpressionUUID->"32f40f05-473f-4afc-9899-3d622bcdf716",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55250, 1319, 686, 18, 38, "Text",ExpressionUUID->"65aef86b-430e-45bc-abf8-ddddcf93ef68",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55939, 1339, 523, 12, 34, "Text",ExpressionUUID->"81c3bf14-369a-4990-9b18-332f42382a7d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56487, 1355, 195, 3, 24, "Input",ExpressionUUID->"345e0557-ca6e-4cb5-b0f5-2b96d006835d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56685, 1360, 1498, 35, 56, "Output",ExpressionUUID->"b4961016-071a-4a8e-bb6c-c90ac5d3702f",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[58198, 1398, 230, 5, 20, "Text",ExpressionUUID->"49dddedf-8a52-4696-a0f4-ea824834129b",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
   CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[58664, 1413, 927, 24, 51, "Text",ExpressionUUID->"d698385b-2681-4ae0-b85a-a3df7977a811",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59616, 1441, 221, 3, 24, "Input",ExpressionUUID->"3714197e-e855-42e0-9712-befe94db8040",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59840, 1446, 9008, 156, 107, "Print",ExpressionUUID->"2ff772c7-f46b-4d90-ac24-db9ca5717551",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[68851, 1604, 349, 5, 24, "Output",ExpressionUUID->"7c91bc79-09f1-4b33-b1bc-0df23b38a0d8",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69215, 1612, 395, 9, 21, "Text",ExpressionUUID->"b92c4fea-2385-4575-a331-9f47851bad97",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69635, 1625, 188, 3, 24, "Input",ExpressionUUID->"f10454f4-a19f-41ea-8804-aceb1d31c86d",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69826, 1630, 873, 13, 127, "Print",ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2",
   CellTags->{"Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7", "Using Options"}],
  Cell[70714, 1646, 230, 5, 20, "Text",ExpressionUUID->"6bb1aa19-e7dd-4535-b457-9728b6bd06b2",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71408, 1671, 373, 8, 20, "Text",ExpressionUUID->"96d3fc89-4f11-4a94-b332-e31880fe2590",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71784, 1681, 5409, 196, 274, "FramedBox",ExpressionUUID->"d0491aa2-cbdf-42fd-85b3-1a702665c886",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77196, 1879, 279, 7, 26, "Commentary",ExpressionUUID->"223397e7-31c7-4429-a46a-a3d5f8837777",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77478, 1888, 2094, 61, 102, "Text",ExpressionUUID->"2801ba38-1670-4ec0-be89-130ee69482c6",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[79575, 1951, 1004, 29, 51, "Text",ExpressionUUID->"2aac3485-7adc-42ac-8fe9-0f6b80a73898",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80604, 1984, 243, 4, 24, "Input",ExpressionUUID->"03e61a5c-2d76-42f7-8f63-a22c86e3aa11",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80850, 1990, 11382, 328, 204, "Output",ExpressionUUID->"e70dce45-423a-49c4-993e-46f4773bad3d",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92247, 2321, 453, 12, 27, "Commentary",ExpressionUUID->"2d4d4264-4d40-40c7-96cc-f946b789a556",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92703, 2335, 719, 11, 46, "Text",ExpressionUUID->"04677792-97c0-428e-a416-043a30fdab99",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[93425, 2348, 230, 5, 20, "Text",ExpressionUUID->"65448239-c679-424f-b8b0-8efa2aa4a94c",
   CellTags->{"Rayica User Guide Introduction", "RG1."}]},
 "RG2."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[2724, 82, 290, 6, 20, "Outline2",ExpressionUUID->"4a364c6c-e761-4046-a86f-d89ea8625e78",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[3017, 90, 688, 20, 55, "Outline3",ExpressionUUID->"6b27a151-f4f4-4956-b667-3be01c6cdcfb",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[94095, 2370, 1653, 36, 95, "Text",ExpressionUUID->"3a3fa262-4e29-486e-8f42-6aba6019448f",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[95773, 2410, 276, 7, 31, "Subsubsection",ExpressionUUID->"b23d5c84-e672-4ff2-9bd7-b56a49123486",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[96052, 2419, 1149, 20, 72, "Text",ExpressionUUID->"0a9fdeff-c71d-4bda-8c34-871b949d40e1",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[97204, 2441, 222, 5, 20, "Text",ExpressionUUID->"7d0d805f-4722-4877-902c-6e903b587b3f",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[97463, 2451, 300, 7, 35, "Subsection",ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "Modeling a light source", "RG2.", "RG2.1", "2.1"}],
  Cell[97766, 2460, 470, 12, 20, "Text",ExpressionUUID->"5e956b8d-0a1d-4670-9ef7-316f471bb0aa",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[98239, 2474, 4259, 148, 252, "FramedBox",ExpressionUUID->"163be0ce-c836-4a05-b602-043cfeb767c5",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[102501, 2624, 181, 3, 26, "Commentary",ExpressionUUID->"27a68c2a-97e8-4545-9c15-783313072250",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[102685, 2629, 426, 13, 21, "Text",ExpressionUUID->"0d4877d2-630c-4e99-8871-bfb21f4e30b2",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[103136, 2646, 196, 2, 24, "Input",ExpressionUUID->"8f30dbd1-2c32-4f9c-9b9c-6b2fa197b05a",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[103335, 2650, 4626, 131, 120, "Output",ExpressionUUID->"98f38436-b1e7-4aef-a162-3c76193a021f",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[107976, 2784, 414, 12, 27, "Commentary",ExpressionUUID->"634fbaf7-e6e1-48c2-8a43-5d6fe3abb5e0",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[108393, 2798, 810, 20, 39, "Text",ExpressionUUID->"bb566f6b-daf3-4983-869d-a2f2b0573f0b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[109206, 2820, 803, 21, 38, "Text",ExpressionUUID->"f6d83e78-531c-4ffa-ac13-f9f2557d1e00",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110034, 2845, 295, 5, 35, "Input",ExpressionUUID->"3c66cd45-fbcd-4b97-a7ff-ed3bf9d5a639",
   PageBreakWithin->Automatic,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110332, 2852, 444, 11, 24, "Output",ExpressionUUID->"cbee1408-a603-4db7-a141-fc74ed03cd9f",
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110791, 2866, 1300, 35, 66, "Text",ExpressionUUID->"83e9195b-377a-46f7-940b-d5f912ae28cd",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[112116, 2905, 174, 2, 24, "Input",ExpressionUUID->"44acd788-f49f-4b3c-ada7-aaa673fd1ee2",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[112293, 2909, 1020, 19, 116, "Output",ExpressionUUID->"efe3dfab-e4d5-413f-be0c-367f2a295ab4",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[113328, 2931, 1529, 41, 83, "Text",ExpressionUUID->"194aaa1b-e39b-483d-98c9-86fbf1a155d7",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[114860, 2974, 2226, 61, 119, "Text",ExpressionUUID->"2db9e75b-e121-4086-8722-eee8505e9120",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[117089, 3037, 222, 5, 20, "Text",ExpressionUUID->"e89a6918-b041-49fc-8ab5-cdb7ffb5adfd",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[117348, 3047, 294, 7, 35, "Subsection",ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", "2.2"}],
  Cell[117645, 3056, 1206, 37, 51, "Text",ExpressionUUID->"3dae03d0-b7a4-4671-b970-ff4fb797fb9f",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[118854, 3095, 583, 19, 34, "Text",ExpressionUUID->"07b827ce-dce5-4812-850d-a7d45348011b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[120852, 3168, 807, 24, 38, "Text",ExpressionUUID->"ec17fe0d-d65b-4b4b-aec1-5b1491287176",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[121684, 3196, 181, 2, 24, "Input",ExpressionUUID->"ccde2674-390a-4365-96e1-7846afb2c154",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[121868, 3200, 444, 11, 24, "Output",ExpressionUUID->"de932cca-b2d3-496e-be44-bc5e187564af",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122327, 3214, 465, 15, 21, "Text",ExpressionUUID->"e2f135df-65eb-45c1-8caf-4fc68baa3243",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122817, 3233, 174, 2, 24, "Input",ExpressionUUID->"26ac156b-7290-47db-8499-89f9e7408435",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122994, 3237, 1006, 19, 116, "Output",ExpressionUUID->"b59b4740-4088-412d-9344-67d755cedbec",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124015, 3259, 520, 17, 34, "Text",ExpressionUUID->"ae70480d-bef9-4f92-901c-c4f9883b9009",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124560, 3280, 186, 2, 24, "Input",ExpressionUUID->"26204c28-0611-4bdb-8ee8-f41e1974186f",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124749, 3284, 2229, 38, 278, "Output",ExpressionUUID->"1e7fbbbe-ac15-463a-b599-8d861ee982fb",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[126993, 3325, 1202, 41, 54, "Text",ExpressionUUID->"06637bc5-a376-4811-8505-c4e6bcc7afba",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[128220, 3370, 211, 2, 24, "Input",ExpressionUUID->"c14e6e5e-b415-4b18-87dd-2a3d5e9dfadf",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[128434, 3374, 1082, 18, 116, "Output",ExpressionUUID->"35245519-99f9-4861-a0fc-d218481c739f",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[129531, 3395, 1511, 39, 86, "Text",ExpressionUUID->"78c6969c-cf10-4e6b-b4db-fe4cd0465117",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[131045, 3436, 222, 5, 20, "Text",ExpressionUUID->"e4f9b90a-8b43-46b2-a164-64cf7a7d1efd",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[131304, 3446, 412, 13, 35, "Subsection",ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"How Rayica manages default light source settings", "Components and Sources", "RG2.", "RG2.3", "2.3"}],
  Cell[131719, 3461, 1314, 39, 66, "Text",ExpressionUUID->"f7db2f37-f6c0-4557-a85c-9e4ca13ee1d9",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133036, 3502, 725, 17, 51, "Text",ExpressionUUID->"7fd2b89a-85a7-4bac-9b28-1d4e4e9630e0",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133786, 3523, 164, 2, 24, "Input",ExpressionUUID->"dc651577-4f0a-49cd-a800-e175d4bf5069",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133953, 3527, 4775, 103, 200, "Output",ExpressionUUID->"623a4163-fa46-4247-ad2b-263ba7b59c86",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[138743, 3633, 1018, 26, 54, "Text",ExpressionUUID->"c380cecc-f3c6-42a5-a0c4-0d6ef93e9822",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[139764, 3661, 332, 7, 20, "Text",ExpressionUUID->"ff5b866d-87d0-457e-81c5-34d395797f94",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140121, 3672, 181, 2, 24, "Input",ExpressionUUID->"d0320a23-7f02-4e4a-88e6-aacdfcd7a573",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140305, 3676, 488, 12, 24, "Output",ExpressionUUID->"bae2cc55-2bed-4232-892f-843be9ddaa2e",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140808, 3691, 518, 14, 38, "Text",ExpressionUUID->"2dd4bb18-47b5-4437-9dce-4eb4c658c3c4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[141351, 3709, 170, 2, 24, "Input",ExpressionUUID->"b70d0283-7f35-4b33-9bcb-39989eb809fe",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[141524, 3713, 1289, 27, 56, "Output",ExpressionUUID->"df31c411-7635-43b3-af9e-e120b2b1bff3",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[142828, 3743, 1177, 36, 47, "Text",ExpressionUUID->"13fe18f5-4bd8-4d78-a9c2-bc1b9650fca4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[144008, 3781, 222, 5, 20, "Text",ExpressionUUID->"e9fedc5c-f759-4cd7-a3b7-2ab02f59cb2a",
   CellTags->{"Components and Sources", "RG2."}],
  Cell[144267, 3791, 312, 7, 35, "Subsection",ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Modeling an optical component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[144582, 3800, 634, 16, 37, "Text",ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145241, 3820, 190, 2, 24, "Input",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145434, 3824, 51836, 1500, 686, "Output",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[197285, 5327, 465, 14, 27, "Commentary",ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb",
   CellTags->{"Components and Sources", "2.4", "Component", "RG2.", "RG2.4"}],
  Cell[197753, 5343, 532, 14, 37, "Text",ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199103, 5390, 366, 11, 22, "Text",ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199494, 5405, 288, 5, 24, "Input",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199785, 5412, 510, 12, 23, "Output",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[200310, 5427, 1518, 39, 69, "Text",ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[201831, 5468, 844, 22, 51, "Text",ExpressionUUID->"eef9b50e-e13a-421f-9021-c75994b22de3",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[202678, 5492, 1355, 43, 56, "Text",ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204058, 5539, 284, 5, 24, "Input",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204345, 5546, 2602, 59, 120, "Output",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[206962, 5608, 832, 20, 52, "Text",ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[207819, 5632, 280, 7, 24, "Input",ExpressionUUID->"86d06f27-cac4-455d-963a-9c1e384be627",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[208102, 5641, 583, 14, 24, "Output",ExpressionUUID->"b7c3aa15-7beb-46bd-ad1e-9086c3bfae34",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[208700, 5658, 222, 5, 20, "Text",ExpressionUUID->"ee8c6ee2-63b1-40ce-a0a3-a0d34bd8fb34",
   CellTags->{"Components and Sources", "RG2."}]},
 "RG5."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[4202, 127, 271, 6, 20, "Outline2",ExpressionUUID->"64fd74ad-0072-470b-b3f7-9f300bdb4b0d",
   CellTags->{"AnalyzeSystem", "RG5."}],
  Cell[4476, 135, 407, 12, 29, "Outline3",ExpressionUUID->"d60aceae-7f54-4a23-b259-fa147cdc1f4a",
   CellTags->{"AnalyzeSystem", "RG5."}],
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292639, 7528, 858, 21, 53, "Text",ExpressionUUID->"7369556e-547f-4c48-9122-ce4aa18cf0e1",
   CellTags->{"AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[293500, 7551, 187, 3, 20, "Text",ExpressionUUID->"b0feb3b6-78fc-4c46-97e7-8d25b7f404cf",
   CellTags->"RG5."],
  Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[295305, 7601, 2694, 99, 146, "FramedBox",ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298002, 7702, 231, 7, 26, "Commentary",ExpressionUUID->"26b43ee4-7126-4285-afb4-1c0266581bb3",
   CellTags->{"AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[299282, 7739, 187, 3, 20, "Text",ExpressionUUID->"a371b2c7-e818-4fbb-8cf6-e8cc10f8b2bb",
   CellTags->"RG5."]},
 "RG3."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[208971, 5669, 448, 16, 60, "Section",ExpressionUUID->"f36ffa46-c6d2-439a-9436-fd7c63745e3d",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"3.", "Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[209422, 5687, 1126, 28, 68, "Text",ExpressionUUID->"8c47ee91-acd1-4aff-8716-af3ea27f1b84",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[210551, 5717, 1041, 36, 81, "FramedBox",ExpressionUUID->"261340f7-80cc-4036-9f76-943150729697",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[211595, 5755, 1805, 45, 103, "Text",ExpressionUUID->"6225c1c0-5cd6-48f5-850b-53c0f81f7cc6",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[213403, 5802, 523, 14, 34, "Text",ExpressionUUID->"ec9c95de-5825-40d9-a289-df1341e2c666",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[213951, 5820, 352, 9, 24, "Input",ExpressionUUID->"1726bb25-462a-4549-bd93-8573fad0fabc",
   PageBreakWithin->Automatic,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[214306, 5831, 12705, 212, 438, "Print",ExpressionUUID->"666eb69d-8757-4ccf-9432-9f88066ccff9",
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[227014, 6045, 689, 18, 20, "Print",ExpressionUUID->"f2f0a085-d829-463d-9de9-2ce44ffc6b56",
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[227706, 6065, 339, 4, 23, "Output",ExpressionUUID->"29727901-5758-4d7f-9da3-179fef404a45",
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
  Cell[228060, 6072, 1358, 36, 65, "Text",ExpressionUUID->"52d1cb2a-fcf5-454d-aae0-8a2cdb930012",
   Evaluatable->False,
   CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}]},
 "RG4."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[229628, 6118, 299, 12, 60, "Section",ExpressionUUID->"e79ee304-6444-418c-a347-afc29e47298d",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Move", "4.", "RG4."}],
  Cell[229930, 6132, 840, 30, 38, "Text",ExpressionUUID->"9e0ee182-ff3f-43f3-a9dc-be44675bfa86",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}],
  Cell[230773, 6164, 862, 33, 51, "FramedBox",ExpressionUUID->"5f9681df-c37c-4521-9524-cfd663be2990",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Move", "RG4."}],
  Cell[231638, 6199, 1087, 38, 38, "Text",ExpressionUUID->"7e8db4f2-fbe3-4f2b-9a30-04dacb450d99",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}],
  Cell[232750, 6241, 375, 10, 57, "Input",ExpressionUUID->"6b5272ea-3406-4e38-bc14-4af8d413c5fe",
   PageBreakWithin->Automatic,
   CellTags->{"Move", "RG4."}],
  Cell[233128, 6253, 26290, 425, 266, "Print",ExpressionUUID->"f2905d4c-0a2b-409a-a72a-a56e8893f778",
   CellTags->{"Move", "RG4."}],
  Cell[259421, 6680, 927, 26, 20, "Print",ExpressionUUID->"9a43684d-2201-4b5a-9a78-d826030078b5",
   CellTags->{"Move", "RG4."}],
  Cell[260351, 6708, 308, 4, 24, "Output",ExpressionUUID->"b55e7357-d863-4697-8813-7f7cc22a5135",
   CellTags->{"Move", "RG4."}],
  Cell[260674, 6715, 588, 13, 37, "Text",ExpressionUUID->"3015ad87-e28b-447b-9c45-8090fc0f0d9a",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}],
  Cell[261265, 6730, 2635, 116, 165, "FramedBox",ExpressionUUID->"2eda5272-ff28-49d0-af7c-f78001c32ec2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Move", "RG4."}],
  Cell[263903, 6848, 259, 7, 27, "Commentary",ExpressionUUID->"7709d5f4-20e7-46c4-a5c1-f6761964cc32",
   CellTags->{"Move", "RG4."}],
  Cell[264165, 6857, 520, 18, 34, "Text",ExpressionUUID->"ba405f05-8953-47a7-97ad-0df30ed40a7b",
   CellTags->{"Move", "RG4."}],
  Cell[264710, 6879, 167, 2, 24, "Input",ExpressionUUID->"90ddc9bd-c7cd-4c1e-af5a-3b8f958d6218",
   CellTags->{"Move", "RG4."}],
  Cell[264880, 6883, 3782, 106, 56, "Output",ExpressionUUID->"83fbebe7-5ac1-4249-96b0-6497e0927650",
   CellTags->{"Move", "RG4."}],
  Cell[268677, 6992, 380, 11, 27, "Commentary",ExpressionUUID->"f7bcd3be-e8bb-4554-9d2c-ae586a1da6eb",
   CellTags->{"Move", "RG4."}],
  Cell[269060, 7005, 474, 15, 21, "Text",ExpressionUUID->"c4e24659-88c0-410a-a21f-b62e1ff992ad",
   Evaluatable->False,
   CellTags->{"Move", "RG4."}]},
 "RG6."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[299518, 7748, 338, 12, 63, "Section",ExpressionUUID->"64a2e08a-22da-4300-95b9-1ad25b5ce535",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowSystem", "component rendering", "6.", "RG6."}],
  Cell[299859, 7762, 856, 26, 39, "Text",ExpressionUUID->"a762463d-3045-4825-87b2-14bb8f507bfc",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[300740, 7792, 388, 11, 24, "Input",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[301131, 7805, 12794, 217, 138, "Print",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[313940, 8025, 705, 18, 34, "Text",ExpressionUUID->"30f2a5f0-70af-48be-a362-2f0d0ed3bc92",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[314648, 8045, 1216, 35, 164, "FramedBox",ExpressionUUID->"4d2d16ec-590d-4087-a948-7eca66168471",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[315867, 8082, 147, 3, 26, "Commentary",ExpressionUUID->"accb7d7d-bdeb-4ef8-ab85-02949feef222",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[316017, 8087, 840, 24, 38, "Text",ExpressionUUID->"1164e3f4-4cce-443b-a3eb-b8e6ed0b0d18",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[316860, 8113, 692, 23, 51, "FramedBox",ExpressionUUID->"81b20859-5e84-4947-9587-7215471a8f59",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[317555, 8138, 306, 9, 21, "Text",ExpressionUUID->"666c3868-dbeb-4e1e-8f1f-c61134156135",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[317864, 8149, 1396, 33, 165, "FramedBox",ExpressionUUID->"0936f727-cc05-485f-a077-877a4972781b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "ShowSystem", "RG6."}],
  Cell[319263, 8184, 184, 7, 27, "Commentary",ExpressionUUID->"c0abbaea-40b0-43c3-92b0-8d371ecf8e2c",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[319450, 8193, 461, 12, 34, "Text",ExpressionUUID->"61d6452e-a86b-42c5-97dc-5a2e42ff0159",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[319936, 8209, 387, 13, 24, "Input",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[320326, 8224, 15785, 256, 256, "Print",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[336126, 8483, 228, 6, 26, "Commentary",ExpressionUUID->"ba2e33a9-701f-45ed-9ae6-785a655b2088",
   CellTags->{"ShowSystem", "RG6."}],
  Cell[336357, 8491, 1151, 34, 67, "Text",ExpressionUUID->"b9ee1085-a4db-4909-8120-573cd6b1d0cb",
   CellTags->{"ShowSystem", "RG6."}]},
 "RG7."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[337718, 8535, 276, 7, 60, "Section",ExpressionUUID->"ef5cb7f7-4a2e-41b7-a582-7cd49609ad04",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ConeOfRays", "7.", "Tracing a Cone of Rays", "RG7."}],
  Cell[337997, 8544, 534, 16, 21, "Text",ExpressionUUID->"9c94a08d-a3e8-4d8e-acb6-662ceb40fb6c",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338556, 8564, 437, 10, 57, "Input",ExpressionUUID->"fed97f40-88bc-4f03-9201-d0237877757f",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338996, 8576, 15095, 255, 223, "Print",ExpressionUUID->"37191ea6-48c5-4143-badd-2a16889b8e71",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354106, 8834, 511, 13, 34, "Text",ExpressionUUID->"8d708064-4943-4d97-9338-80fdec46d92e",
   CellTags->{"Tracing a Cone of Rays", "RG7."}],
  Cell[354620, 8849, 355, 10, 21, "Text",ExpressionUUID->"24b310c7-f413-4438-a984-916a3d387316",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354978, 8861, 635, 20, 51, "FramedBox",ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", "RG7."}],
  Cell[355616, 8883, 1266, 45, 55, "Text",ExpressionUUID->"e506ddcd-0879-41ab-9c62-f1893312d38a",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[356907, 8932, 486, 11, 57, "Input",ExpressionUUID->"78ae942a-cb18-4547-b900-445b13070a83",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[357396, 8945, 56644, 921, 223, "Print",ExpressionUUID->"b1b87736-fe15-4098-9aab-1bb1ba1e1fba",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414055, 9869, 416, 13, 21, "Text",ExpressionUUID->"072f6e22-85e4-42b4-8783-7cc94a7c1fd3",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414496, 9886, 262, 4, 24, "Input",ExpressionUUID->"21c87232-2508-40e4-a406-184ea43091fe",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414761, 9892, 40317, 694, 107, "Print",ExpressionUUID->"af61dccd-7843-4695-8d08-5324bb57a8b7",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455093, 10589, 727, 22, 39, "Text",ExpressionUUID->"566e4a0b-26a1-49bf-a5d6-8f6376ae9285",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455845, 10615, 263, 4, 24, "Input",ExpressionUUID->"43392047-6d38-472c-b510-86ef1a1bb072",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[456111, 10621, 44399, 773, 365, "Print",ExpressionUUID->"0a748db5-bcea-4a91-831b-278c5989b2ec",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}]},
 "RG8."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[500732, 11405, 302, 7, 60, "Section",ExpressionUUID->"811accef-54a1-49dd-aafb-3af96471eef6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"cylindrical lens", "8.", "Adding a Cylindrical Lens", "RG8."}],
  Cell[501037, 11414, 441, 11, 21, "Text",ExpressionUUID->"de0b999c-b77b-4599-9529-4cf305828fbf",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[501481, 11427, 752, 26, 51, "FramedBox",ExpressionUUID->"cefabc0f-b2ba-4081-a914-a90102a52410",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"PlanoConvexCylindricalLens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[502236, 11455, 472, 16, 21, "Text",ExpressionUUID->"2a020f65-57b9-4d9c-a7ad-1909426b6614",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[502733, 11475, 584, 14, 89, "Input",ExpressionUUID->"8bec4a81-f674-4133-b165-e68c0b8dc5f6",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[503320, 11491, 89102, 1445, 220, "Print",ExpressionUUID->"0eb413d0-0c48-47c6-8df0-2f898569bd3d",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[592437, 12939, 243, 5, 20, "Text",ExpressionUUID->"09cb721d-419f-47bb-9788-3802a696cbee",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[592705, 12948, 268, 4, 24, "Input",ExpressionUUID->"5e6666c8-aa0e-4d60-801e-bbc7eef0bf62",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[592976, 12954, 64048, 1102, 104, "Print",ExpressionUUID->"3dab169f-74d4-49da-ad43-db9c6f5ac4cf",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[657061, 14061, 267, 4, 24, "Input",ExpressionUUID->"861c617d-2d33-4fa6-a2ed-2b5e8e334a04",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[657331, 14067, 65471, 1127, 104, "Print",ExpressionUUID->"d723f22c-56c9-45ab-9326-3be74b4f57f2",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[722817, 15197, 1246, 32, 60, "Text",ExpressionUUID->"f46b8f25-0f6f-43f7-9dcf-10d7b52d732b",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}]},
 "RG9."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[724273, 15239, 254, 10, 63, "Section",ExpressionUUID->"23359498-8046-434a-af0c-e565df2d8892",
   Evaluatable->False,
   CellTags->{"RayChoice", "9.", "RG9."}],
  Cell[724530, 15251, 382, 12, 21, "Text",ExpressionUUID->"0d1a8e3f-4e1d-4dc4-a61a-e7f9b3ef5afb",
   Evaluatable->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[724915, 15265, 719, 26, 51, "FramedBox",ExpressionUUID->"34779028-9be1-4672-b9ce-24514fb1786e",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[725637, 15293, 708, 19, 38, "Text",ExpressionUUID->"f42d6be7-cbe5-44e4-b7ee-1e7ef7b86e0a",
   Evaluatable->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[726370, 15316, 243, 4, 24, "Input",ExpressionUUID->"01fb40b3-1e7d-4bf2-967e-eea9be9f6230",
   PageBreakWithin->Automatic,
   CellTags->{"RayChoice", "RG9."}],
  Cell[726616, 15322, 88175, 1429, 220, "Print",ExpressionUUID->"d7fc8bc8-e503-4e02-a570-e01b7182818a",
   CellTags->{"RayChoice", "RG9."}],
  Cell[814806, 16754, 486, 16, 21, "Text",ExpressionUUID->"921d688e-0d66-4016-be31-dc9862d3972f",
   Evaluatable->False,
   CellTags->{"RayChoice", "RG9."}],
  Cell[815295, 16772, 579, 18, 51, "FramedBox",ExpressionUUID->"ab90f6a7-a383-4ac1-80ec-3fa98fb9b1f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RayChoice", "Surface", "RG9."}],
  Cell[815877, 16792, 453, 14, 21, "Text",ExpressionUUID->"41a7f206-e13a-4409-be36-f56525db8c24",
   Evaluatable->False,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816355, 16810, 300, 6, 24, "Input",ExpressionUUID->"47b9e46a-25c0-4cb3-b662-0d37b89eb12d",
   PageBreakWithin->Automatic,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816658, 16818, 3305, 74, 365, "Print",ExpressionUUID->"15442f90-5536-464e-8ab9-90af301ef1ce",
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}]},
 "RG10."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[820185, 16903, 371, 12, 63, "Section",ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Screen", "focal plane of system", "10.", "Using Screen", "RG10."}],
  Cell[820559, 16917, 735, 20, 38, "Text",ExpressionUUID->"4574287a-8995-4e63-99d6-4237667227af",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821297, 16939, 635, 21, 51, "FramedBox",ExpressionUUID->"cb264467-9607-4491-9e2a-150017352ac3",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821935, 16962, 612, 20, 21, "Text",ExpressionUUID->"4f17e7e8-b7ef-46c4-bbe9-62737fdd5493",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[848676, 17432, 451, 13, 21, "Text",ExpressionUUID->"045101ea-2a75-4098-a7f0-05d2a696de23",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849152, 17449, 310, 7, 24, "Input",ExpressionUUID->"da50deaa-c72e-495c-92e8-001633150ed5",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849465, 17458, 2021, 46, 365, "Print",ExpressionUUID->"a8b69489-f5d3-4bd3-9d7e-48f0bdb29221",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[851708, 17515, 323, 12, 63, "Section",ExpressionUUID->"c348ff48-a54b-4c54-9da9-e9c1ed3d78d5",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowRange", "11.", "RG10.", "RG11."}],
  Cell[852034, 17529, 398, 13, 21, "Text",ExpressionUUID->"52816333-8b27-4409-b845-2b916f72b70f",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[852435, 17544, 570, 19, 51, "FramedBox",ExpressionUUID->"83ed5ffd-df16-4b3f-8c0a-adc45f84e000",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853008, 17565, 492, 16, 21, "Text",ExpressionUUID->"5b155320-e592-41f5-b201-2e505ba64340",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853525, 17585, 237, 4, 24, "Input",ExpressionUUID->"2a1441a5-322d-4c6b-ae11-20370f92fa09",
   PageBreakWithin->Automatic,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853765, 17591, 11298, 191, 438, "Print",ExpressionUUID->"877e34fe-4ce3-4102-a844-c6adfe1e2227",
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[865078, 17785, 1021, 35, 38, "Text",ExpressionUUID->"0a819798-1313-47bc-b289-5b2becae311b",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}]},
 "RG11."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[851708, 17515, 323, 12, 63, "Section",ExpressionUUID->"c348ff48-a54b-4c54-9da9-e9c1ed3d78d5",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowRange", "11.", "RG10.", "RG11."}],
  Cell[852034, 17529, 398, 13, 21, "Text",ExpressionUUID->"52816333-8b27-4409-b845-2b916f72b70f",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[852435, 17544, 570, 19, 51, "FramedBox",ExpressionUUID->"83ed5ffd-df16-4b3f-8c0a-adc45f84e000",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853008, 17565, 492, 16, 21, "Text",ExpressionUUID->"5b155320-e592-41f5-b201-2e505ba64340",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853525, 17585, 237, 4, 24, "Input",ExpressionUUID->"2a1441a5-322d-4c6b-ae11-20370f92fa09",
   PageBreakWithin->Automatic,
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[853765, 17591, 11298, 191, 438, "Print",ExpressionUUID->"877e34fe-4ce3-4102-a844-c6adfe1e2227",
   CellTags->{"ShowRange", "RG10.", "RG11."}],
  Cell[865078, 17785, 1021, 35, 38, "Text",ExpressionUUID->"0a819798-1313-47bc-b289-5b2becae311b",
   Evaluatable->False,
   CellTags->{"ShowRange", "RG10.", "RG11."}]},
 "RG12."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[866309, 17830, 314, 12, 63, "Section",ExpressionUUID->"bd0bb247-7bc3-4815-8b2b-9ad91600848b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ReadRays", "12.", "RG12."}],
  Cell[866626, 17844, 370, 10, 21, "Text",ExpressionUUID->"13dfbd3e-a75a-4c9a-bca5-1ac9141cc3d0",
   Evaluatable->False,
   CellTags->{"ReadRays", "RG12."}],
  Cell[866999, 17856, 915, 36, 51, "FramedBox",ExpressionUUID->"ea5251f0-0c41-4a77-8e3b-bde02cad7014",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReadRays", "RG12."}],
  Cell[867917, 17894, 637, 17, 34, "Text",ExpressionUUID->"1050e920-03fb-4f3e-ae26-7e4e6e181dc9",
   Evaluatable->False,
   CellTags->{"ReadRays", "RG12."}],
  Cell[868579, 17915, 253, 6, 24, "Input",ExpressionUUID->"fe649223-7d68-4e85-b6f0-1d4135c645e1",
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "RG12."}],
  Cell[868835, 17923, 502, 9, 23, "Output",ExpressionUUID->"2d332d18-8f36-4def-bdfb-fe46a3ca4054",
   CellTags->{"ReadRays", "RG12."}],
  Cell[869352, 17935, 290, 10, 21, "Text",ExpressionUUID->"47dff9d5-d9f6-4181-abad-0242b6d5c9ef",
   Evaluatable->False,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[869667, 17949, 209, 4, 24, "Input",ExpressionUUID->"a4c1ace1-3fbb-4027-9df6-3ef68a956e73",
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[869879, 17955, 564, 14, 47, "Output",ExpressionUUID->"79a1d2f7-7f12-4630-9a60-449f5dd8dd21",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[870458, 17972, 748, 26, 38, "Text",ExpressionUUID->"d3a991ea-bb9d-471a-8006-f40e33774c4f",
   Evaluatable->False,
   CellTags->{"ReadRays", "RG12."}]},
 "RG13."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[871416, 18008, 225, 8, 63, "Section",ExpressionUUID->"f16b8b76-3abc-432f-8b79-58f74680382d",
   CellTags->{"PropagateSystem", "13.", "RG13."}],
  Cell[871644, 18018, 533, 16, 22, "Text",ExpressionUUID->"689a409b-f5af-413a-907b-9b9cec7d70ae",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[872180, 18036, 1063, 37, 68, "FramedBox",ExpressionUUID->"437f1c99-1fe9-4e37-aac6-8df84c32b157",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[873246, 18075, 569, 16, 38, "Text",ExpressionUUID->"e7af37bd-e79a-4c38-9b7d-354f4c5af775",
   CellTags->{"PropagateSystem", "RG13."}],
  Cell[873840, 18095, 625, 13, 122, "Input",ExpressionUUID->"7e6e0e5e-ff02-4193-8367-bfdbf2f121c1",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
  Cell[874468, 18110, 547, 9, 23, "Output",ExpressionUUID->"5ef2f2a4-82c6-4e09-ba33-6b110c9e82af",
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
  Cell[875030, 18122, 916, 25, 51, "Text",ExpressionUUID->"7deed9e8-abe9-4501-81eb-e91376c45f45",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}]},
 "RG14."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[6724, 200, 293, 7, 20, "Outline2",ExpressionUUID->"c87a726b-0d67-4996-9dac-7542c014ef85",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[7020, 209, 386, 12, 29, "Outline3",ExpressionUUID->"864d8473-2564-4695-84d1-669e9e4ec4c7",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[876156, 18157, 273, 8, 60, "Section",ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4",
   CellTags->{"TurboPlot", "14.", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[877579, 18202, 924, 31, 84, "FramedBox",ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"TurboPlot", "TurboTrace", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[878506, 18235, 1937, 50, 116, "Text",ExpressionUUID->"29a70b22-afb3-4a67-9ca0-396573e8c165",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[880446, 18287, 306, 6, 57, "Input",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc",
   CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"}],
  Cell[880755, 18295, 1503, 38, 85, "Text",ExpressionUUID->"0aa5efea-2314-4787-add1-c1cbe3b2041d",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[882261, 18335, 210, 5, 20, "Text",ExpressionUUID->"0b78c116-1673-43d7-b13b-269d0483e4c4",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[882496, 18344, 264, 7, 35, "Subsection",ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee",
   CellTags->{"AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[882763, 18353, 524, 14, 34, "Text",ExpressionUUID->"5d45d815-e34a-4638-b9aa-6a2cae8bcc92",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883312, 18371, 207, 2, 24, "Input",ExpressionUUID->"735af2c0-1890-47d1-927f-6c25ec9a3696",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883522, 18375, 22837, 385, 250, "Print",ExpressionUUID->"30129e9c-da09-4b82-99d7-c51a0ba85383",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[906362, 18762, 1112, 30, 36, "Print",ExpressionUUID->"8af346c3-607a-4d3c-b60b-37087ac743cf",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907477, 18794, 440, 8, 24, "Output",ExpressionUUID->"1be6b05a-38ba-4dd0-9c1b-bf8a553810e2",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907932, 18805, 601, 14, 38, "Text",ExpressionUUID->"858724e0-3458-4097-a3ad-5905352e1e8a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908558, 18823, 203, 2, 24, "Input",ExpressionUUID->"4316b42e-16b4-4337-b1d0-5fcbb5018272",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908764, 18827, 19666, 328, 250, "Print",ExpressionUUID->"a775210d-8ac8-4f96-881b-f0406171236d",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928433, 19157, 424, 8, 24, "Output",ExpressionUUID->"2701a2cb-a51f-48fb-8a91-292322a5ed60",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928872, 19168, 2384, 53, 150, "Text",ExpressionUUID->"7563334e-5902-41f8-a1df-a57b98fd95db",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931259, 19223, 288, 6, 57, "Input",ExpressionUUID->"82dd5976-98c4-4850-8129-65296a055626",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931550, 19231, 247, 7, 21, "Text",ExpressionUUID->"8a0d808b-3acd-42e1-8a4e-3cbf9708bab9",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931822, 19242, 294, 8, 24, "Input",ExpressionUUID->"4ba6f6b3-7128-4561-bf3a-51d141ee8235",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[932119, 19252, 13905, 237, 135, "Print",ExpressionUUID->"d17e9029-8a30-4cfd-a2de-1ef7fd95dc7b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946027, 19491, 426, 8, 24, "Output",ExpressionUUID->"0654bc51-0d0e-44fc-9ad4-a4a620076efc",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946468, 19502, 342, 10, 21, "Text",ExpressionUUID->"b6867a6d-2e38-4d9a-8d99-c590923b8370",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946835, 19516, 202, 2, 24, "Input",ExpressionUUID->"dcf9a401-6d74-4dca-b0a9-dbfb831b5a69",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[947040, 19520, 19508, 327, 250, "Print",ExpressionUUID->"17aad0ef-4d85-49dc-8687-7a9910b92579",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966551, 19849, 425, 8, 24, "Output",ExpressionUUID->"19a4ddc9-b309-4657-a005-e419ddaea093",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966991, 19860, 658, 16, 38, "Text",ExpressionUUID->"ba8154d8-97ee-46e3-af97-1bfcda3007ef",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[967652, 19878, 567, 17, 51, "FramedBox",ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968222, 19897, 250, 7, 21, "Text",ExpressionUUID->"584eb23d-c0e4-4cf3-a9f3-f1123ef41b41",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968497, 19908, 280, 6, 24, "Input",ExpressionUUID->"0c4146da-356c-4135-94fc-acd9c4891d21",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968780, 19916, 14063, 238, 135, "Print",ExpressionUUID->"c2262dfd-d7a6-4354-93bc-b64c5143062b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[982846, 20156, 424, 8, 24, "Output",ExpressionUUID->"cd0d7832-4882-42ac-aeec-555723c25398",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[983285, 20167, 899, 20, 54, "Text",ExpressionUUID->"8df57715-fe35-4019-a07d-935cd5a2b382",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984209, 20191, 314, 6, 24, "Input",ExpressionUUID->"c7a7c134-59da-4d2c-9066-7712b50842ab",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984526, 20199, 15065, 256, 136, "Print",ExpressionUUID->"79dbe714-1168-4ff2-a903-f39e4fe98437",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[999594, 20457, 427, 8, 24, "Output",ExpressionUUID->"5c23b081-6025-46f9-8058-23f0ddb28122",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000036, 20468, 462, 12, 38, "Text",ExpressionUUID->"55aa0c10-0f2e-40e5-b147-d90827498dd5",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000501, 20482, 623, 15, 38, "Text",ExpressionUUID->"d1849c45-2f29-4caa-9f87-63d7f316366a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1001127, 20499, 210, 5, 20, "Text",ExpressionUUID->"43b79d3c-25d1-403a-95e3-08fa65c30a51",
   CellTags->{"TurboPlot", "RG14."}],
  Cell[1001374, 20509, 194, 3, 35, "Subsection",ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d",
   CellTags->{"CreateClones", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1001571, 20514, 619, 19, 38, "Text",ExpressionUUID->"a90ae5b6-7add-4130-878d-cf27bd3d377f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1002193, 20535, 1009, 31, 64, "FramedBox",ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1003205, 20568, 1956, 47, 116, "Text",ExpressionUUID->"f2eb698c-dfad-4527-9f7b-106a2af4bfa3",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005164, 20617, 286, 9, 106, "Input",ExpressionUUID->"3d9f37b8-a9c7-4b91-a648-ad87a2a1e908",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005453, 20628, 325, 10, 21, "Text",ExpressionUUID->"d9110934-fde3-43cf-9643-be18578b550b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005781, 20640, 184, 2, 24, "Input",ExpressionUUID->"1ecb9700-e924-4fa3-bdaf-531de38950d0",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005968, 20644, 489, 15, 34, "Text",ExpressionUUID->"42dc2622-9471-42c3-a3f3-61f3f7d82508",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1006460, 20661, 556, 19, 51, "FramedBox",ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"BallLens", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007019, 20682, 431, 11, 21, "Text",ExpressionUUID->"9242d2d5-8928-426b-b5ac-4a96ee390dbe",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007475, 20697, 347, 6, 57, "Input",ExpressionUUID->"eecc06bf-c7ed-45b9-a4f4-24ee8c6632e7",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007825, 20705, 287, 5, 20, "Print",ExpressionUUID->"61a0f1ab-c69a-45ca-b951-868a02bace37",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008115, 20712, 273, 5, 19, "Print",ExpressionUUID->"b5d7340c-5ec3-4fe7-9d03-09cc88fbe637",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008391, 20719, 403, 9, 20, "Print",ExpressionUUID->"2d34b417-9b1a-4ec2-9bbc-51a827395fef",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008797, 20730, 396, 9, 19, "Print",ExpressionUUID->"194685f5-51ca-400c-ac76-52d433b092e4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1009196, 20741, 155603, 3614, 2712, "Print",ExpressionUUID->"9e5f9dee-8ead-479a-b7ab-b29ca9c88f05",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1164802, 24357, 402, 9, 20, "Print",ExpressionUUID->"5a157a4a-5cd0-4ff8-9446-a9a4d1cf4f63",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165207, 24368, 285, 5, 20, "Print",ExpressionUUID->"a7ac1691-3058-41ef-b826-3e248fce341f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165495, 24375, 592, 13, 20, "Print",ExpressionUUID->"68ed0864-f5f9-4899-9e1d-f86d4eb9da48",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166090, 24390, 294, 5, 20, "Print",ExpressionUUID->"a3c73fa8-cd00-4292-8000-e81065aa2e52",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166387, 24397, 434, 10, 20, "Print",ExpressionUUID->"5e96a7e3-3195-49c5-a721-3e13d8eba6dd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166824, 24409, 299, 5, 20, "Print",ExpressionUUID->"73b92b16-de30-4bf4-8330-439f37608ec1",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167126, 24416, 294, 5, 20, "Print",ExpressionUUID->"116e553e-8c5d-4dc1-a5f3-801621bf9f27",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167423, 24423, 295, 5, 20, "Print",ExpressionUUID->"6276257f-c7ec-4594-ad4f-72208f6b4d0f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167721, 24430, 564, 13, 20, "Print",ExpressionUUID->"5a6866f8-45c9-4989-b288-05184518c8f4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168288, 24445, 280, 5, 20, "Print",ExpressionUUID->"b9cffd6e-5cfc-4fb1-a8d3-92d7bd52cace",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168571, 24452, 291, 5, 20, "Print",ExpressionUUID->"b0d73961-ee2c-4ee2-b8a0-2f0c81abd029",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168865, 24459, 284, 5, 20, "Print",ExpressionUUID->"1ca37af5-a564-4e12-963d-e72507044653",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169152, 24466, 408, 10, 20, "Print",ExpressionUUID->"6b21dd82-13da-49a4-bfcc-1692d2a751f9",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169563, 24478, 470, 12, 20, "Print",ExpressionUUID->"6d322694-d70a-45fe-91ab-4a334dca967d",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170036, 24492, 293, 5, 20, "Print",ExpressionUUID->"2602bd1b-8e54-4f2d-985e-854ee2ebdd2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170332, 24499, 3005, 67, 36, "Print",ExpressionUUID->"24daf8aa-d778-478d-b1bb-3cb981a0470c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173340, 24568, 298, 5, 20, "Print",ExpressionUUID->"dec65d5e-7134-4048-bd69-fcddd67bff86",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173641, 24575, 380, 9, 20, "Print",ExpressionUUID->"5def9516-870b-45c4-bb4d-185c5bf57e2b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174024, 24586, 410, 10, 20, "Print",ExpressionUUID->"569cd10d-ec2f-4e84-b8fa-4bbe68d67c43",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174437, 24598, 285, 5, 20, "Print",ExpressionUUID->"dbc020dc-58c1-450b-987e-0de518fcb018",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174725, 24605, 420, 9, 20, "Print",ExpressionUUID->"06ebf166-0ece-4a92-84a9-2078defc9ffd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175148, 24616, 402, 9, 20, "Print",ExpressionUUID->"4a173113-385f-46f7-9c3d-0b055bbb25e5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175553, 24627, 406, 9, 20, "Print",ExpressionUUID->"931ebe39-1913-4ea1-a5d6-0c9aefc4d074",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175962, 24638, 271, 5, 20, "Print",ExpressionUUID->"fc7c54b5-8308-460e-a42b-d07ec905a15a",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176236, 24645, 434, 10, 20, "Print",ExpressionUUID->"4060f68c-4778-4814-9ce7-8d1f7fd45431",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176673, 24657, 608, 14, 20, "Print",ExpressionUUID->"c2df0822-6d87-4e5a-bdfe-fdb1e7570704",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1177284, 24673, 775, 15, 22, "Message",ExpressionUUID->"d47b94fb-92d1-4460-93e6-ffdef0044a62",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178062, 24690, 442, 10, 20, "Print",ExpressionUUID->"372e005e-ae85-45d5-b357-dccdbfec3b2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178507, 24702, 730, 15, 20, "Print",ExpressionUUID->"2444f75e-2c81-4fc8-bcee-98bc3bccbf99",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179240, 24719, 306, 6, 20, "Print",ExpressionUUID->"cde16d7f-25f9-49c2-8d01-9591f38344b8",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179549, 24727, 282, 5, 20, "Print",ExpressionUUID->"1939d258-9116-4640-8d0a-a8e388c1c894",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179834, 24734, 286, 5, 20, "Print",ExpressionUUID->"30244d4b-b1f1-4417-a269-c577adbf4778",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180123, 24741, 279, 5, 20, "Print",ExpressionUUID->"3b6f39ab-476c-4aeb-8ace-ef042b612aa2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180405, 24748, 304, 6, 20, "Print",ExpressionUUID->"372b9b9a-5013-4ebb-9371-b8c7809d5a85",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180712, 24756, 304, 6, 20, "Print",ExpressionUUID->"ccdfd2bb-c013-42e4-99bb-9aab14e88f10",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181019, 24764, 304, 6, 20, "Print",ExpressionUUID->"07c418d1-350c-47f1-b1a3-2dbcf1f4738c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181326, 24772, 304, 6, 20, "Print",ExpressionUUID->"c9a2bb0f-da80-40ea-8eaa-0a1efb0c580f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181633, 24780, 281, 5, 20, "Print",ExpressionUUID->"63686a72-2217-4f16-b1dc-3b9f396962c5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181917, 24787, 293, 5, 20, "Print",ExpressionUUID->"830aa83c-4800-4bb1-8ca2-22aff9582db6",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182213, 24794, 279, 5, 20, "Print",ExpressionUUID->"1ed4033f-5589-4337-a159-deb93b7ea346",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182495, 24801, 1129508, 18866, 341, "Print",ExpressionUUID->"fdb36d72-ab79-4189-a843-7506cad40be2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2312018, 43670, 1213, 33, 70, "Text",ExpressionUUID->"9c4ed069-1dcb-4b31-b3b4-de62ad8e215e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313234, 43705, 288, 8, 21, "Text",ExpressionUUID->"0d7d4221-ebf2-4a36-a888-5a1eb445b649",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2314769, 43760, 490, 15, 34, "Text",ExpressionUUID->"e2766717-50f1-411a-8db8-c3dba15ad878",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2315262, 43777, 210, 5, 20, "Text",ExpressionUUID->"bfafdff3-9501-4a72-ad94-f41a96b5bd5d",
   CellTags->{"TurboPlot", "RG14."}]},
 "RG15."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[2315521, 43788, 219, 7, 60, "Section",ExpressionUUID->"5c62ed6d-b544-44e0-affc-dcff777c52d7",
   CellTags->{"OptimizeSystem", "15.", "RG15."}],
  Cell[2315743, 43797, 532, 11, 37, "Text",ExpressionUUID->"419b7f51-9a7b-481a-b9c5-ae3663216c45",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2316278, 43810, 584, 20, 51, "FramedBox",ExpressionUUID->"188eecd5-87fc-44a1-97a8-d53de79f8064",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2316865, 43832, 675, 16, 38, "Text",ExpressionUUID->"9de3c256-3fe2-4d8a-a0f5-0251a566a82a",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2317543, 43850, 825, 34, 51, "FramedBox",ExpressionUUID->"464f8f91-b6db-4961-a243-0eaa5ee35b2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SphericalLens", "OptimizeSystem", "RG15."}],
  Cell[2318371, 43886, 311, 9, 21, "Text",ExpressionUUID->"2e5b0ef5-c7c3-44c6-ba4b-0e7f59661041",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2318685, 43897, 300, 7, 73, "Input",ExpressionUUID->"cc023c24-24c2-4956-bf37-e220676eb9b5",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2318988, 43906, 673, 16, 38, "Text",ExpressionUUID->"f106fd40-d378-4d6e-8a02-ef34ac16d402",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2319686, 43926, 289, 8, 24, "Input",ExpressionUUID->"edc39bfb-d98f-454b-ba00-fa5626702911",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2319978, 43936, 10054, 177, 135, "Print",ExpressionUUID->"326b1886-ce69-4775-b57f-27ed8186400d",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2330035, 44115, 413, 8, 24, "Output",ExpressionUUID->"f0700e2c-2c78-41a6-853d-7af972f922f5",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2330463, 44126, 268, 9, 21, "Text",ExpressionUUID->"07b449bf-c5a9-46e5-b911-cfe47228b2b3",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2330756, 44139, 199, 2, 24, "Input",ExpressionUUID->"6ece41d5-f3e3-45cf-aa92-7a37515cbd52",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2330958, 44143, 810, 18, 24, "Output",ExpressionUUID->"7ab3a572-6034-4db6-82c5-7498be5e4b4a",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2331783, 44164, 983, 24, 67, "Text",ExpressionUUID->"f12843e5-55ae-47eb-ae22-ba9bb72ec067",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2332791, 44192, 265, 6, 24, "Input",ExpressionUUID->"1a01a7b8-d66d-4978-801d-81d2ebe5808e",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2333059, 44200, 10128, 177, 135, "Print",ExpressionUUID->"1213985f-5e0e-420a-8dab-9c423b2d855e",
   CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
  Cell[2343202, 44380, 682, 18, 38, "Text",ExpressionUUID->"26adf7e2-d329-4e5f-9eb1-652c33ff4999",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2343909, 44402, 213, 4, 24, "Input",ExpressionUUID->"e7a71eb1-906b-4f00-b5c4-af9e47b73be8",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2344125, 44408, 787, 17, 24, "Output",ExpressionUUID->"db4e6ada-8a4c-406b-a33e-82257316feac",
   CellTags->{"OptimizeSystem", "RG15."}],
  Cell[2344927, 44428, 843, 15, 60, "Text",ExpressionUUID->"2002864d-91c5-4d29-bf56-0440598d610f",
   CellTags->{"OptimizeSystem", "RG15."}]},
 "RG16."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[2345980, 44453, 369, 14, 60, "Section",ExpressionUUID->"e91ead7e-40a8-487a-bf8c-0484bf29162e",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ReadTurboRays", "16.", "RG16."}],
  Cell[2346352, 44469, 729, 24, 38, "Text",ExpressionUUID->"e6500628-5d71-46fb-a65d-25f64f40cdac",
   Evaluatable->False,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2347084, 44495, 988, 38, 64, "FramedBox",ExpressionUUID->"fa23eb4b-123d-4b73-8c2a-049c29b39f31",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2348075, 44535, 851, 28, 38, "Text",ExpressionUUID->"27dc19c8-3f1e-4113-8d48-6d8c91574faf",
   Evaluatable->False,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2348951, 44567, 331, 10, 24, "Input",ExpressionUUID->"ac39550a-adc9-476a-badc-8f596522a545",
   PageBreakWithin->Automatic,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2349285, 44579, 631, 12, 23, "Output",ExpressionUUID->"c13cb3ca-df62-45ca-b807-f754b94cce80",
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2349953, 44596, 336, 10, 24, "Input",ExpressionUUID->"946ef065-9abd-4fb3-be82-da7b516f91d6",
   PageBreakWithin->Automatic,
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2350292, 44608, 635, 12, 23, "Output",ExpressionUUID->"3f20e29b-88cd-423d-8ef8-208f94dec97c",
   CellTags->{"ReadTurboRays", "RG16."}],
  Cell[2350942, 44623, 797, 31, 38, "Text",ExpressionUUID->"a97f46df-9b47-4469-9823-01f3549ca975",
   CellTags->{"ReadTurboRays", "RG16."}]},
 "RG17."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7913, 238, 277, 6, 20, "Outline2",ExpressionUUID->"0225a6ed-e4de-45a0-bf44-173443ff56f9",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[8193, 246, 789, 24, 68, "Outline3",ExpressionUUID->"69e7edd6-dba9-4da0-af18-6eb332da20ac",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
   CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352216, 44673, 489, 12, 37, "Text",ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352708, 44687, 756, 26, 51, "FramedBox",ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2353467, 44715, 1670, 50, 70, "Text",ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2355140, 44767, 224, 5, 20, "Text",ExpressionUUID->"20a964d3-7fe5-429c-a9f8-92f8d718eb4d",
   CellTags->{"FindIntensity", "RG17.", "RG17.1"}],
  Cell[2355389, 44776, 318, 7, 35, "Subsection",ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", "17.1"}],
  Cell[2355710, 44785, 860, 19, 51, "Text",ExpressionUUID->"3309fe78-8bea-41d2-9e89-be26e8481dcc",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356595, 44808, 330, 8, 73, "Input",ExpressionUUID->"047766fb-8eda-427a-9c3e-35823ea5836e",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356928, 44818, 964, 22, 20, "Print",ExpressionUUID->"0de2e702-472d-4a7d-a33a-128938072ae6",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2357895, 44842, 323025, 5562, 296, "Print",ExpressionUUID->"eeabf9da-4b78-4217-9378-83252c32fedd",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2680923, 50406, 333374, 5584, 131, "Output",ExpressionUUID->"1c035b97-c43f-4851-8b25-054d8a319820",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3014312, 55993, 1281, 31, 72, "Text",ExpressionUUID->"61fe767f-feb3-477a-a22f-08ad310cb74c",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015596, 56026, 284, 7, 21, "Text",ExpressionUUID->"9f08fe51-ea3c-4aaa-9cef-8c9e59b7d550",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015905, 56037, 253, 7, 24, "Input",ExpressionUUID->"6c99f091-180f-479e-a164-578479e304a5",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3016161, 56046, 2360, 47, 104, "Output",ExpressionUUID->"af9e7bec-c4e9-4c06-977f-2f278dbbb732",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018536, 56096, 356, 8, 21, "Text",ExpressionUUID->"cc3b45c7-e4f3-4e3c-b46f-6d6e177fe337",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018895, 56106, 904, 25, 114, "FramedBox",ExpressionUUID->"46cb697f-b80f-4d01-bd6c-4876a42ca360",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3019802, 56133, 283, 8, 27, "Commentary",ExpressionUUID->"c67f89f6-560d-495a-8599-39f4b27400df",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020088, 56143, 292, 6, 20, "Text",ExpressionUUID->"e5a6054d-dd48-4061-bcbb-f0b7a1201f9a",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020383, 56151, 396, 9, 21, "Text",ExpressionUUID->"acbccdd9-b6e4-4445-8c63-5d21e8a43520",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020782, 56162, 911, 25, 100, "FramedBox",ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021696, 56189, 257, 8, 27, "Commentary",ExpressionUUID->"7831497e-8aba-4284-b96e-49915e0b2651",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021956, 56199, 756, 18, 51, "Text",ExpressionUUID->"b637b49d-dc30-4a08-809d-bb46795dbf59",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022737, 56221, 234, 3, 24, "Input",ExpressionUUID->"1b065470-deed-4044-8680-13146f928883",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022974, 56226, 731153, 12157, 371, "Print",ExpressionUUID->"2c1a3fe1-f530-44e5-ad59-dc837b0018fa",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3754142, 68386, 214, 5, 20, "Text",ExpressionUUID->"7db99dae-8ac2-4250-90f0-8207449940a8",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[3754393, 68396, 266, 7, 35, "Subsection",ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2", "17.2"}],
  Cell[3754662, 68405, 967, 20, 67, "Text",ExpressionUUID->"1e979e95-2969-4469-bdb2-4b4c0c51ff29",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3755654, 68429, 353, 7, 73, "Input",ExpressionUUID->"bf84e43a-fae7-473b-aa4b-b5e31a85f037",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3756010, 68438, 23625, 395, 213, "Print",ExpressionUUID->"b3b339b6-d05a-4a26-9fcc-fc53d96f9d15",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3779650, 68836, 420, 10, 21, "Text",ExpressionUUID->"f5f2213a-8c67-4cc7-a6e0-6cc3d95ece0b",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780073, 68848, 796, 28, 51, "FramedBox",ExpressionUUID->"a33391f6-588e-4017-94b4-c9b65311d253",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780872, 68878, 471, 12, 34, "Text",ExpressionUUID->"72ac0498-3b0e-4219-8bae-6f4e17c2f6fa",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781368, 68894, 182, 2, 24, "Input",ExpressionUUID->"9f4a8b78-0096-4924-824c-df2fc5d1f38e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781553, 68898, 21105, 421, 354, "Print",ExpressionUUID->"16d21f8f-ecc7-4ca0-8326-e017183ba907",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3802661, 69321, 1326, 31, 56, "Output",ExpressionUUID->"8a13b68c-4edf-455a-bfd8-08aa9b5a8063",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3804002, 69355, 1004, 26, 54, "Text",ExpressionUUID->"ef728d99-f6af-4701-821f-7667055c288e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805031, 69385, 188, 2, 24, "Input",ExpressionUUID->"d1fc3e93-d0bb-4abd-abbd-f079d7dd2d57",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805222, 69389, 378, 6, 23, "Output",ExpressionUUID->"591b7135-4c02-4d42-8df1-963cbf3dd8a1",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805615, 69398, 214, 5, 20, "Text",ExpressionUUID->"0767282a-0043-4f56-9f76-2b558adf3ab0",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[3805866, 69408, 312, 8, 35, "Subsection",ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "17.3", "Point Spread Function (PSF)"}],
  Cell[3806181, 69418, 458, 13, 21, "Text",ExpressionUUID->"7ee32d46-f354-4350-98ce-745d5fe62fb5",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3806664, 69435, 397, 8, 89, "Input",ExpressionUUID->"03f38441-916b-4472-a72f-cebe22f1de4b",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3807064, 69445, 963, 21, 20, "Print",ExpressionUUID->"a389c04a-1214-4a12-9503-59d753754c5f",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3808030, 69468, 1039597, 17914, 280, "Print",ExpressionUUID->"9e219fa5-0d2f-4a98-8336-e967b4266678",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[4847630, 87384, 1068108, 17936, 114, "Output",ExpressionUUID->"faea0d3b-afe1-4883-b972-798f0b1cc126",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5915753, 105323, 522, 14, 34, "Text",ExpressionUUID->"41ceb80e-2181-4cd7-b774-e47b379c16d3",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916300, 105341, 222, 2, 24, "Input",ExpressionUUID->"4bb39fd2-06ac-4850-8973-a84b4945ffe4",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916525, 105345, 956, 21, 20, "Print",ExpressionUUID->"e31d0700-a56e-4a47-9922-4c9df4642880",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5917484, 105368, 66039, 1197, 249, "Print",ExpressionUUID->"e24be2f9-c5d4-481a-b7cb-42d643c4e308",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5983538, 106568, 1774, 36, 119, "Text",ExpressionUUID->"6a8298d3-cd1c-4426-ba27-6e0e9d9c4ef0",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5985315, 106606, 1303, 53, 64, "FramedBox",ExpressionUUID->"383b92d9-bb1f-4fa8-9b79-4d97513a96de",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5986621, 106661, 468, 15, 21, "Text",ExpressionUUID->"8f2a8809-ca0e-424e-b3dd-02b65ee36fc7",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5987092, 106678, 919, 35, 51, "FramedBox",ExpressionUUID->"de33a8b9-bafc-4dc0-a878-7ae11c86ac7a",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5988014, 106715, 992, 30, 38, "Text",ExpressionUUID->"b6b2e779-1a5b-4ed1-b908-aea9d02a4f32",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5989009, 106747, 214, 5, 20, "Text",ExpressionUUID->"c35f1e2e-2fa0-4f19-b803-21670f38c3eb",
   CellTags->{"FindIntensity", "RG17."}],
  Cell[5989260, 106757, 316, 7, 35, "Subsection",ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", "17.4"}],
  Cell[5989579, 106766, 469, 12, 38, "Text",ExpressionUUID->"30c801a3-37d5-4911-b3a1-d9d387a5f414",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5990051, 106780, 730, 23, 51, "FramedBox",ExpressionUUID->"9c0d1061-6d13-4c39-8a38-fc416aeca7f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4"}],
  Cell[5990784, 106805, 551, 13, 34, "Text",ExpressionUUID->"86795780-c101-4bd7-81de-63e3b9e5d003",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991360, 106822, 212, 3, 24, "Input",ExpressionUUID->"69d700c4-c02f-46db-91df-f1f4ad496ccd",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991575, 106827, 1277, 28, 56, "Output",ExpressionUUID->"b3e7fbc4-8c5c-4773-8b21-2c1f50002099",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5992889, 106860, 219, 3, 24, "Input",ExpressionUUID->"05011727-66ba-42d7-9311-76ce95abffd2",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5993111, 106865, 34653, 618, 242, "Print",ExpressionUUID->"532b389b-e46b-494e-850f-5801f1dd3eb4",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[6027767, 107485, 1134284, 18596, 192, "Output",ExpressionUUID->"8b30f9f8-5631-422e-a696-d65c329e250a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162066, 126084, 766, 18, 51, "Text",ExpressionUUID->"97450984-6a0c-4acf-9174-51e10e28d20a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162835, 126104, 244, 5, 20, "Text",ExpressionUUID->"8381b864-31bc-46c1-8f73-17774d620556",
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17."}],
  Cell[7163116, 126114, 318, 7, 35, "Subsection",ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", "17.5"}],
  Cell[7163437, 126123, 529, 12, 38, "Text",ExpressionUUID->"34623c4b-fe27-43e8-bd53-4b5427b399dd",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7163991, 126139, 403, 9, 73, "Input",ExpressionUUID->"fb3f9c9b-3e34-4d0e-ab34-9367873467c2",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7164397, 126150, 15205, 257, 216, "Print",ExpressionUUID->"73e948d6-1694-44b4-ae7d-aa818ce26431",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7179617, 126410, 1060, 22, 67, "Text",ExpressionUUID->"f8f0bdcf-fab1-40be-95b1-7e144ffe3c6c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7180702, 126436, 585, 13, 89, "Input",ExpressionUUID->"5edc0363-6e09-425e-a719-e41a4ce3275a",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7181290, 126451, 1017, 23, 20, "Print",ExpressionUUID->"2838a744-8620-4e26-a900-a8328ac1c274",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7182310, 126476, 40684, 723, 249, "Print",ExpressionUUID->"2f268b14-14d8-48a5-a7eb-687acda3458f",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7222997, 127201, 1020, 23, 20, "Print",ExpressionUUID->"3e3c72dd-d769-434f-b710-2079c05b91f7",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7224020, 127226, 53528, 952, 249, "Print",ExpressionUUID->"a296cdfd-0141-441f-98aa-ef27a78ddd7c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7277551, 128180, 101438, 1706, 301, "Output",ExpressionUUID->"a1a52898-e5e7-40a2-bad0-b10bb386556d",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379004, 129889, 958, 24, 54, "Text",ExpressionUUID->"3dd53550-bd89-4434-8178-b4bdb23c4c00",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379965, 129915, 534, 14, 38, "Text",ExpressionUUID->"d70a31c8-3057-42e4-ad73-12b52a878b1c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380524, 129933, 245, 6, 24, "Input",ExpressionUUID->"9588485b-e6e9-491f-baef-c7d69029eba3",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380772, 129941, 422, 8, 20, "Print",ExpressionUUID->"409ae0e2-9603-42ba-980c-4a24dcf7d5df",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381197, 129951, 338, 5, 23, "Output",ExpressionUUID->"de6bc496-b575-462e-bc44-25ac8b5a9211",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381550, 129959, 1382, 20, 85, "Text",ExpressionUUID->"f22e5175-9749-47ac-b69b-4446723b94d5",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7382935, 129981, 253, 5, 20, "Text",ExpressionUUID->"c605f174-ab57-4738-8b7a-88a1e288edac",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17."}]},
 "RG18."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7383237, 129992, 211, 8, 63, "Section",ExpressionUUID->"6ac6bfd3-1a3d-49c7-95bf-3feeaabfa8cd",
   CellTags->{"Resonate", "18.", "RG18."}],
  Cell[7383451, 130002, 818, 23, 54, "Text",ExpressionUUID->"8d722c0e-fc4f-44f3-9c41-5eab67bf2242",
   Evaluatable->False,
   CellTags->{"ray tracing", "Resonate", "RG18."}],
  Cell[7384272, 130027, 622, 22, 51, "FramedBox",ExpressionUUID->"2a3a4728-f479-438e-ac36-9372ed3ae683",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Resonate", "RG18."}],
  Cell[7384897, 130051, 1152, 25, 66, "Text",ExpressionUUID->"f385f2b0-9078-4098-94f4-63d776aa23db",
   Evaluatable->False,
   CellTags->{"ray tracing", "Resonate", "RG18."}],
  Cell[7386074, 130080, 272, 8, 89, "Input",ExpressionUUID->"0c140923-69b9-470b-a77f-5008c14dc1d6",
   CellTags->{"Resonate", "RG18."}],
  Cell[7386349, 130090, 30541, 527, 365, "Print",ExpressionUUID->"6917394b-82e0-453f-9725-1fbfafe6fde5",
   CellTags->{"Resonate", "RG18."}],
  Cell[7416905, 130620, 287, 7, 21, "Text",ExpressionUUID->"b9ce648b-21ea-45df-ab34-f82451a785f1",
   CellTags->{"Resonate", "RG18."}],
  Cell[7417217, 130631, 236, 8, 89, "Input",ExpressionUUID->"5a9a8588-177e-4de2-83fb-261ce5be10d2",
   CellTags->{"Resonate", "RG18."}],
  Cell[7417456, 130641, 785, 23, 23, "Output",ExpressionUUID->"510cfad9-5bec-4894-a87f-08e0b2a1190d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7418256, 130667, 491, 13, 38, "Text",ExpressionUUID->"e6647d4c-317d-40ec-9b89-be6bce0d6eb8",
   CellTags->{"Resonate", "RG18."}],
  Cell[7418772, 130684, 146, 2, 24, "Input",ExpressionUUID->"33cb3d49-cf10-4fa5-baa7-e84bbc9e5d2d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7418921, 130688, 284, 4, 24, "Output",ExpressionUUID->"17d11535-b739-4885-9703-239044fb0481",
   CellTags->{"Resonate", "RG18."}],
  Cell[7419220, 130695, 318, 7, 21, "Text",ExpressionUUID->"71d16563-1462-43f1-98d8-24d033a3d5be",
   CellTags->{"Resonate", "RG18."}],
  Cell[7419563, 130706, 222, 7, 73, "Input",ExpressionUUID->"b4f7d976-188c-4529-9899-687a2e0498f3",
   CellTags->{"Resonate", "RG18."}],
  Cell[7419788, 130715, 32007, 545, 365, "Print",ExpressionUUID->"e96c081c-a9aa-41f5-99a6-34254acef2b3",
   CellTags->{"Resonate", "RG18."}],
  Cell[7451810, 131263, 371, 11, 21, "Text",ExpressionUUID->"286d46df-c400-4cf9-8232-126cf5763f8b",
   CellTags->{"Resonate", "RG18."}],
  Cell[7452206, 131278, 218, 7, 73, "Input",ExpressionUUID->"08e221a1-ddb4-4fe2-96bc-4448f258c60d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7452427, 131287, 14091, 233, 365, "Print",ExpressionUUID->"89ed0fca-2e01-49aa-b26c-a77ffe90711d",
   CellTags->{"Resonate", "RG18."}],
  Cell[7466533, 131523, 378, 13, 21, "Text",ExpressionUUID->"8f92118e-8f6c-40ba-8b88-df844e2ec576",
   CellTags->{"Resonate", "RG18."}]},
 "RG19."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7467121, 131546, 201, 8, 60, "Section",ExpressionUUID->"2ad8be42-a103-45bc-b5e7-11647de00c94",
   CellTags->{"Database", "19.", "RG19."}],
  Cell[7467325, 131556, 1344, 35, 63, "Text",ExpressionUUID->"320ecd25-a05c-4d82-a030-825895be5acc",
   CellTags->{"Database", "RG19."}],
  Cell[7468672, 131593, 1409, 47, 126, "FramedBox",ExpressionUUID->"f62bd2bd-7199-4214-9b20-7dd6e400011e",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Database", "RG19."}],
  Cell[7470084, 131642, 810, 20, 54, "Text",ExpressionUUID->"5f9a3aef-feca-426c-93d6-6be218e4b1f3",
   CellTags->{"Database", "RG19."}],
  Cell[7470897, 131664, 478, 12, 33, "Text",ExpressionUUID->"63bb1f15-1c8d-4b3b-97b4-013c42c4f946",
   CellTags->{"Database", "RG19."}],
  Cell[7471400, 131680, 191, 2, 24, "Input",ExpressionUUID->"c6e33c49-eca9-475d-8690-8d1296cfea33",
   CellTags->{"Database", "RG19."}],
  Cell[7471594, 131684, 7200, 164, 278, "Output",ExpressionUUID->"071c5fc1-692c-44bc-b0de-d41e4f3dded6",
   CellTags->{"Database", "RG19."}],
  Cell[7478809, 131851, 1255, 29, 79, "Text",ExpressionUUID->"cae6081d-4799-4ecd-8bff-afa8022ea3e3",
   CellTags->{"Database", "RG19."}],
  Cell[7480089, 131884, 142, 2, 24, "Input",ExpressionUUID->"eb683a7c-4ae2-4920-870b-9af074c17cfb",
   CellTags->{"Database", "RG19."}],
  Cell[7480234, 131888, 2893, 43, 216, "Output",ExpressionUUID->"ee141b33-8d36-4733-b715-5e5c09ae6fe6",
   CellTags->{"Database", "RG19."}],
  Cell[7483142, 131934, 625, 22, 38, "Text",ExpressionUUID->"80f30a0e-4f8b-4c98-ab07-102c54d63d5f",
   CellTags->{"Database", "RG19."}],
  Cell[7483770, 131958, 1382, 42, 133, "FramedBox",ExpressionUUID->"3c2399ec-fba3-40b1-99e9-e62ae314b455",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "Database", "RG19."}],
  Cell[7485155, 132002, 149, 2, 26, "Commentary",ExpressionUUID->"fff5d2ab-950e-4d33-b925-b247ae539596",
   CellTags->{"Database", "RG19."}],
  Cell[7485307, 132006, 729, 22, 38, "Text",ExpressionUUID->"a9b043b8-f5ec-4fde-aaa6-6f19e94a2bd2",
   CellTags->{"Database", "RG19."}],
  Cell[7486061, 132032, 236, 6, 24, "Input",ExpressionUUID->"f6a296c6-c0a2-4830-810f-ef9a52a1baf7",
   CellTags->{"Database", "RG19."}],
  Cell[7486300, 132040, 1410, 23, 104, "Output",ExpressionUUID->"45a7ee28-fa3e-4b6a-a4ef-38c7acfefa88",
   CellTags->{"Database", "RG19."}],
  Cell[7487725, 132066, 1551, 38, 103, "Text",ExpressionUUID->"fe197e53-825d-43bd-a771-59588321771f",
   CellTags->{"Database", "RG19."}],
  Cell[7489279, 132106, 467, 14, 51, "FramedBox",ExpressionUUID->"8267d24e-83d6-4a31-a9ba-c281cfb392d2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReportedInterval", "Database", "RG19."}],
  Cell[7489749, 132122, 958, 24, 54, "Text",ExpressionUUID->"4a8f756b-f7ad-431a-8619-9ad2af5c1d54",
   CellTags->{"Database", "RG19."}],
  Cell[7490732, 132150, 209, 3, 24, "Input",ExpressionUUID->"a58dda43-82da-49df-9870-1d174d20e15e",
   CellTags->{"Database", "RG19."}],
  Cell[7490944, 132155, 4131, 84, 200, "Output",ExpressionUUID->"d8592e33-4ed9-48fa-8902-17393762762e",
   CellTags->{"Database", "RG19."}],
  Cell[7495090, 132242, 1187, 31, 69, "Text",ExpressionUUID->"68ffe976-6bf7-4c62-894d-ffb512688a4b",
   CellTags->{"Database", "RG19."}],
  Cell[7496302, 132277, 205, 4, 24, "Input",ExpressionUUID->"3ac515bc-d8ce-4f77-83a8-d8ca5a9f623f",
   CellTags->{"Database", "RG19."}],
  Cell[7496510, 132283, 1772, 35, 72, "Output",ExpressionUUID->"0e8c1c8d-9eb9-41e0-82c9-cc8ebd31f04b",
   CellTags->{"Database", "RG19."}],
  Cell[7498297, 132321, 437, 13, 21, "Text",ExpressionUUID->"28e8b3b1-19f9-4ac0-bfd5-de2db6cf2ecc",
   CellTags->{"Database", "RG19."}],
  Cell[7498759, 132338, 233, 5, 41, "Input",ExpressionUUID->"8a9c311d-9b1b-4b3e-bbe8-f14f92da05ec",
   CellTags->{"Database", "RG19."}],
  Cell[7498995, 132345, 662, 16, 24, "Output",ExpressionUUID->"61b98bbe-fb27-457b-910b-4bd19dcbdfa8",
   CellTags->{"Database", "RG19."}],
  Cell[7499660, 132363, 13895, 227, 438, "Print",ExpressionUUID->"1c5e58ca-393f-4ec5-beab-2f1a1949f8ab",
   CellTags->{"Database", "RG19."}],
  Cell[7513570, 132593, 393, 11, 20, "Text",ExpressionUUID->"105f563c-551c-40db-8444-64442de81d48",
   CellTags->{"Database", "RG19."}],
  Cell[7513988, 132608, 205, 4, 24, "Input",ExpressionUUID->"c89563a2-51fd-4b4c-9315-c4a0710dcb74",
   CellTags->{"Database", "RG19."}],
  Cell[7514196, 132614, 8726, 175, 360, "Output",ExpressionUUID->"7b2d3ae9-a8b2-4e33-b74b-d7478c7126a5",
   CellTags->{"Database", "RG19."}],
  Cell[7522937, 132792, 544, 14, 38, "Text",ExpressionUUID->"06ec706d-fdd8-44c8-b609-6bd53f59f9a3",
   CellTags->{"Database", "RG19."}],
  Cell[7523506, 132810, 254, 5, 24, "Input",ExpressionUUID->"86e32bc2-274e-45c2-8206-2161f148fa42",
   CellTags->{"Database", "RG19."}],
  Cell[7523763, 132817, 954, 25, 131, "Output",ExpressionUUID->"8d38c99c-2568-4708-b441-e9f560629304",
   CellTags->{"Database", "RG19."}],
  Cell[7524732, 132845, 443, 12, 34, "Text",ExpressionUUID->"a0f07990-74b7-4276-b78d-161863b82f07",
   CellTags->{"Database", "RG19."}],
  Cell[7525200, 132861, 167, 2, 24, "Input",ExpressionUUID->"993138d5-d0c0-4851-bdd3-336bef7e015c",
   CellTags->{"Database", "RG19."}],
  Cell[7525370, 132865, 651, 16, 24, "Output",ExpressionUUID->"4fa51032-9c32-4056-aeb8-d8f07e45872a",
   CellTags->{"Database", "RG19."}],
  Cell[7526036, 132884, 237, 5, 20, "Text",ExpressionUUID->"80e078d0-8e72-4024-814d-fdde7d9e7cf6",
   CellTags->{"Database", "RG19."}],
  Cell[7526298, 132893, 153, 2, 24, "Input",ExpressionUUID->"f1dd3ebf-70de-4799-9372-7f56ef9939da",
   CellTags->{"Database", "RG19."}],
  Cell[7526454, 132897, 295, 5, 23, "Output",ExpressionUUID->"b71c509f-7fac-4f76-a1bc-eaa33bc4fce5",
   CellTags->{"Database", "RG19."}],
  Cell[7526786, 132907, 155, 2, 24, "Input",ExpressionUUID->"696fbf67-6d6e-4a36-ab5f-875ee48f709c",
   CellTags->{"Database", "RG19."}],
  Cell[7526944, 132911, 293, 5, 23, "Output",ExpressionUUID->"f0508462-a5a9-4d2c-b14c-0c1ef10d3b94",
   CellTags->{"Database", "RG19."}],
  Cell[7527252, 132919, 229, 7, 20, "Text",ExpressionUUID->"d1a9bf02-f552-4374-b7d1-5e1ecf461f62",
   CellTags->{"Database", "RG19."}]},
 "RG20."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7527691, 132936, 201, 7, 63, "Section",ExpressionUUID->"362a1439-c548-49a1-877f-7518d0f44c3a",
   CellTags->{"20.", "RG20."}],
  Cell[7527895, 132945, 522, 13, 34, "Text",ExpressionUUID->"af54b50b-178f-46d4-bc93-5db03cb0f378",
   Evaluatable->False,
   CellTags->"RG20."],
  Cell[7528420, 132960, 783, 27, 64, "FramedBox",ExpressionUUID->"8edeb40e-fa64-4139-91ba-af1d10908acf",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->"RG20."],
  Cell[7529206, 132989, 162, 3, 20, "Text",ExpressionUUID->"c2d38fbb-66f4-4c9e-a3f7-d552593812ff",
   CellTags->"RG20."],
  Cell[7529393, 132996, 263, 8, 89, "Input",ExpressionUUID->"e22c50c9-d05f-40fd-94b8-485e8ad37cd1",
   CellTags->"RG20."],
  Cell[7529659, 133006, 13760, 242, 365, "Print",ExpressionUUID->"45130692-f163-4cee-8376-a5ce459d6f14",
   CellTags->"RG20."],
  Cell[7543434, 133251, 277, 6, 21, "Text",ExpressionUUID->"2f734fe7-0a8c-49f2-855c-ea313f7db36a",
   CellTags->"RG20."],
  Cell[7543736, 133261, 267, 8, 89, "Input",ExpressionUUID->"9048fd1a-1edd-4643-bb43-4e8ad7584667",
   CellTags->"RG20."],
  Cell[7544006, 133271, 28437, 488, 365, "Print",ExpressionUUID->"1f94aaa2-ade9-4bec-bfc7-f25f81cef97f",
   CellTags->"RG20."],
  Cell[7572458, 133762, 322, 8, 21, "Text",ExpressionUUID->"903c2994-bd9a-4764-aaef-410e2d6aafb0",
   CellTags->"RG20."],
  Cell[7572805, 133774, 246, 7, 73, "Input",ExpressionUUID->"abbf1530-e66c-40fe-b97e-867ec8f43908",
   CellTags->"RG20."],
  Cell[7573054, 133783, 27027, 484, 365, "Print",ExpressionUUID->"420bdebb-b64e-48c3-a46d-705a04a995a4",
   CellTags->"RG20."],
  Cell[7600096, 134270, 334, 6, 21, "Text",ExpressionUUID->"88237dc9-3747-4b9e-a1f4-b3d3ba2baf0d",
   CellTags->"RG20."],
  Cell[7600455, 134280, 256, 7, 73, "Input",ExpressionUUID->"ef932c33-bb50-4eda-89fa-95ac4b400788",
   CellTags->"RG20."],
  Cell[7600714, 134289, 33584, 601, 365, "Print",ExpressionUUID->"94792538-1c94-42d8-a7b3-a5f9c4b05b93",
   CellTags->"RG20."],
  Cell[7634313, 134893, 902, 29, 54, "Text",ExpressionUUID->"976e2ebe-a4ee-4641-912f-e4b68c00761e",
   Evaluatable->False,
   CellTags->"RG20."],
  Cell[7635218, 134924, 774, 18, 51, "Text",ExpressionUUID->"d01968e4-b06c-4ae4-92c2-862d9e2ad656",
   Evaluatable->False,
   CellTags->"RG20."],
  Cell[7636017, 134946, 380, 10, 73, "Input",ExpressionUUID->"9a1deb8c-0770-4dfd-9eb9-1caf516d6659",
   CellTags->"RG20."],
  Cell[7636400, 134958, 2186, 48, 365, "Print",ExpressionUUID->"5f9bef18-f3bc-4ad0-8ebc-a85d59dcee79",
   CellTags->"RG20."]},
 "RG21."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[9684, 293, 255, 6, 20, "Outline2",ExpressionUUID->"fdeeb244-3332-43ca-95c2-6c4de1b3d371",
   CellTags->{"What's Missing", "RG21."}],
  Cell[9942, 301, 564, 16, 42, "Outline3",ExpressionUUID->"3eb4baaf-4492-4fa0-a5de-09e6ad2f6df5",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7638808, 135017, 147, 3, 60, "Section",ExpressionUUID->"d39bd8e9-1177-4306-8ca7-77cd6f4afc93",
   CellTags->{"What's Missing", "RG21.", "21."}],
  Cell[7638958, 135022, 1612, 38, 85, "Text",ExpressionUUID->"9a73353d-4300-4462-8499-aefb7bebd549",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7640595, 135064, 285, 7, 35, "Subsection",ExpressionUUID->"e52217ef-ac6b-4840-95cb-6737e8877556",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Features not discussed here", "What's Missing", "RG21."}],
  Cell[7640883, 135073, 816, 18, 46, "Text",ExpressionUUID->"fd8eec84-ca17-40d5-b500-a4576be18653",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7641702, 135093, 1097, 27, 59, "Text",ExpressionUUID->"ceb071e0-1de7-468c-8c8b-c20fe4c299d0",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7642802, 135122, 2098, 48, 112, "Text",ExpressionUUID->"b9524a5d-6928-420f-b34f-2b1a1b0c1429",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7644937, 135175, 285, 7, 35, "Subsection",ExpressionUUID->"3cdc573b-b05b-4668-b37f-e2d853505dcc",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Features left to the future", "What's Missing", "RG21."}],
  Cell[7645225, 135184, 833, 18, 46, "Text",ExpressionUUID->"d0f11d3d-3d17-45eb-bf31-29c5ff3d53d7",
   CellTags->{"What's Missing", "RG21."}],
  Cell[7646061, 135204, 940, 27, 46, "Text",ExpressionUUID->"0315375b-e20d-4040-84d6-b496835f53fd",
   CellTags->{"What's Missing", "RG21."}]},
 "RG22."->{
  Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
   CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
  Cell[7647223, 135242, 169, 3, 60, "Section",ExpressionUUID->"44e4ee72-4c79-4f62-a2c3-21d1a43cf67f",
   CellTags->{"Backward Compatibility", "RG22.", "22."}],
  Cell[7647395, 135247, 1392, 36, 80, "Text",ExpressionUUID->"1fff4d7f-9ccf-4d2d-85f7-6e2690c95ca1",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7648812, 135287, 209, 7, 35, "Subsection",ExpressionUUID->"9ebbfb22-8058-4a5a-9efb-d34b4ab7b580",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7649024, 135296, 851, 27, 38, "Text",ExpressionUUID->"b21ddcf9-bf95-4b6a-9be3-5cd62d7c00e0",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7649912, 135328, 287, 11, 35, "Subsection",ExpressionUUID->"25945faa-a20f-4b29-8cad-53bf25b6ada2",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7650202, 135341, 868, 30, 34, "Text",ExpressionUUID->"dd3bfab9-da54-48f2-bff3-1c9bf08b2cff",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7651107, 135376, 428, 17, 35, "Subsection",ExpressionUUID->"ddbbf9b1-3e8a-47e2-aa9d-7ca7c0c1cb19",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7651538, 135395, 1544, 61, 38, "Text",ExpressionUUID->"0dde57cf-1cf9-4dfb-85d3-396d9aeb9640",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653119, 135461, 166, 3, 35, "Subsection",ExpressionUUID->"889794e7-a81e-4555-9199-a60440190b8f",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653288, 135466, 449, 15, 21, "Text",ExpressionUUID->"887cd1d7-580b-4b04-89b2-dca8ba6d1489",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653762, 135485, 182, 3, 24, "Input",ExpressionUUID->"56f8e24b-c46a-4879-be75-1e2ebbb6c6e0",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7653947, 135490, 1615, 33, 72, "Output",ExpressionUUID->"9b05f338-6bae-46d3-b82a-0545bc42aa70",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7655577, 135526, 584, 20, 34, "Text",ExpressionUUID->"551560ab-dcf3-4fcf-90f7-f9b2cc52d543",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7656186, 135550, 183, 3, 24, "Input",ExpressionUUID->"2a32a075-5288-426d-ad6d-9c0059c0028b",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7656372, 135555, 2026, 53, 88, "Output",ExpressionUUID->"4eae78a1-49f4-413c-938e-f8b9aab0c576",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7658447, 135614, 285, 10, 35, "Subsection",ExpressionUUID->"5eb1be0a-f892-4962-8d2e-780097fe1de0",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7658735, 135626, 729, 20, 38, "Text",ExpressionUUID->"186fd96c-5dd9-49ef-bb4d-be189043c513",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7659501, 135651, 170, 3, 35, "Subsection",ExpressionUUID->"e1f6db08-382c-49f4-88d1-f6d5f29c9027",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7659674, 135656, 571, 16, 38, "Text",ExpressionUUID->"c468bd9b-f498-4bdb-b335-33f1631ffe9c",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7660248, 135674, 922, 40, 21, "Text",ExpressionUUID->"da00a46c-c883-40b8-ae15-e1abff07de6b",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7661173, 135716, 152, 3, 20, "Text",ExpressionUUID->"883028bd-5da7-4eeb-a206-5dd71bc5c1b9",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7661328, 135721, 1199, 51, 21, "Text",ExpressionUUID->"83320e74-4ea2-4842-86f6-e556d83abd72",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7662564, 135777, 157, 3, 35, "Subsection",ExpressionUUID->"5f1d0e95-b0c4-4de5-8869-00cb0ed2b831",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7662724, 135782, 2425, 105, 38, "Text",ExpressionUUID->"634a8f1c-56db-4d25-9b47-47ae6bad8c77",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7665152, 135889, 392, 14, 21, "Text",ExpressionUUID->"bfad9ebf-115f-49c1-9b02-f312fee0821f",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7665569, 135907, 185, 3, 24, "Input",ExpressionUUID->"ad1429ae-c6a4-4a74-991b-dc7afa9f7a35",
   CellTags->{"Backward Compatibility", "RG22."}],
  Cell[7665757, 135912, 4128, 98, 177, "Output",ExpressionUUID->"1634a1bc-1220-4446-bc19-63db0d4fb6ad",
   CellTags->{"Backward Compatibility", "RG22."}]},
 "Optica User Guide Introduction"->{
  Cell[1482, 40, 273, 6, 24, "Outline2",ExpressionUUID->"dc0a96d6-42ba-4e7e-a04b-d1cd188e123c",
   CellTags->{"Optica User Guide Introduction", "RG1."}],
  Cell[1758, 48, 929, 29, 107, "Outline3",ExpressionUUID->"e0c4d643-70f6-4836-9c40-03b74debd9f2",
   CellTags->{"Optica User Guide Introduction", "RG1."}]},
 "1."->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}]},
 "Introduction"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}]},
 "Loading Rayica"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[13343, 399, 1312, 46, 46, "Text",ExpressionUUID->"53444f15-79b2-4da2-b4fc-a3aabc38a11b",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[14680, 449, 331, 12, 24, "Input",ExpressionUUID->"d0f1842b-9e8e-4fc2-bb3d-62a54619b000",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15014, 463, 491, 11, 20, "Print",ExpressionUUID->"30459a7a-ca46-4d83-af0d-fdb4a9801d45",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15508, 476, 376, 9, 19, "Print",ExpressionUUID->"2b7b290f-ec8f-499f-8ccd-8f8a5c6dde38",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15899, 488, 904, 27, 33, "Text",ExpressionUUID->"b86d0f77-e2c9-4cc9-b06f-923277e3bc7c",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[17359, 538, 817, 18, 46, "Text",ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e",
   CellTags->{"Loading Rayica", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}]},
 "Rayica's High Level Functions"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}]},
 "1. Introduction"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11143, 338, 673, 12, 46, "Text",ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1",
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11819, 352, 1112, 29, 46, "Text",ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9",
   Evaluatable->False,
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}]},
 "Rayica User Guide Introduction"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11143, 338, 673, 12, 46, "Text",ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1",
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11819, 352, 1112, 29, 46, "Text",ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9",
   Evaluatable->False,
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[13343, 399, 1312, 46, 46, "Text",ExpressionUUID->"53444f15-79b2-4da2-b4fc-a3aabc38a11b",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[14680, 449, 331, 12, 24, "Input",ExpressionUUID->"d0f1842b-9e8e-4fc2-bb3d-62a54619b000",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15014, 463, 491, 11, 20, "Print",ExpressionUUID->"30459a7a-ca46-4d83-af0d-fdb4a9801d45",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15508, 476, 376, 9, 19, "Print",ExpressionUUID->"2b7b290f-ec8f-499f-8ccd-8f8a5c6dde38",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15899, 488, 904, 27, 33, "Text",ExpressionUUID->"b86d0f77-e2c9-4cc9-b06f-923277e3bc7c",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[16806, 517, 230, 5, 20, "Text",ExpressionUUID->"41f630dd-c76a-4762-9b3a-8b0549a3ab54",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
   CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[17359, 538, 817, 18, 46, "Text",ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e",
   CellTags->{"Loading Rayica", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18201, 560, 321, 9, 89, "Input",ExpressionUUID->"528d9f96-c640-4726-aec0-55305c4ecf62",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18525, 571, 11143, 190, 223, "Print",ExpressionUUID->"2cd65a8a-29ca-47a4-b77a-241da870ded0",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[29671, 763, 356, 5, 24, "Output",ExpressionUUID->"decbdd55-e771-48ea-ad88-55eaabd4f074",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[30042, 771, 230, 5, 20, "Text",ExpressionUUID->"033ae809-63ce-4eb9-9982-e5b4caef8625",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
   CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[30507, 786, 633, 12, 33, "Text",ExpressionUUID->"6fc8cab9-7ee2-44e2-b98b-cdd60e0e3655",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[31143, 800, 1410, 31, 83, "Text",ExpressionUUID->"dda7200a-0a2d-46e4-a177-efe1267d01ee",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[32556, 833, 230, 5, 20, "Text",ExpressionUUID->"054d5311-4067-40d5-bc3e-4b005d80ec26",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
   CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[33061, 849, 1018, 21, 66, "Text",ExpressionUUID->"87327b10-7eee-41c6-ac55-2a9376422dad",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34082, 872, 711, 18, 38, "Text",ExpressionUUID->"fa99db1d-7880-4526-9fdb-e0675a094fe9",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34796, 892, 522, 12, 37, "Text",ExpressionUUID->"aebb1dd9-09f9-4ca0-b88c-b3e5ed789c74",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35321, 906, 227, 3, 20, "Text",ExpressionUUID->"e0a3b9c6-0ae8-4dbb-8793-b4c9f770f285",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35551, 911, 707, 17, 130, "Text",ExpressionUUID->"4dafee9d-c203-44b3-bd11-6d428cd52708",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[36261, 930, 261, 5, 20, "Text",ExpressionUUID->"aa596a2d-47a7-483c-93b4-520dd475278c",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1."}],
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[36799, 946, 247, 5, 20, "Text",ExpressionUUID->"104e8fd2-1286-4ad8-bd49-62165d86e223",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37071, 955, 307, 9, 89, "Input",ExpressionUUID->"f920023b-619f-404b-8aca-2883db8d47c3",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37381, 966, 1126, 35, 24, "Output",ExpressionUUID->"369f0439-ef91-407d-b2b8-1a6d1ee2c936",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[38522, 1004, 562, 10, 33, "Text",ExpressionUUID->"dee619ee-4b4d-47a4-a93c-18511ca4be05",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39109, 1018, 224, 3, 24, "Input",ExpressionUUID->"5727830a-6763-4831-be3d-b5c19b2eeef4",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39336, 1023, 11138, 190, 223, "Print",ExpressionUUID->"acdffe68-5863-48c5-a77f-a7c3baf51997",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[50477, 1215, 353, 5, 24, "Output",ExpressionUUID->"c9ab9764-21af-4c4b-9970-43a26f36b411",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[50845, 1223, 230, 5, 20, "Text",ExpressionUUID->"ddcfaf90-344d-4cea-ab86-cbf260c01c93",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
   CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51314, 1238, 418, 9, 21, "Text",ExpressionUUID->"b961e791-5ad4-44d6-be6c-25237633de9a",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51757, 1251, 196, 3, 24, "Input",ExpressionUUID->"60b3ccf1-9b6a-42b4-beda-efdf85878f43",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51956, 1256, 1410, 21, 163, "Print",ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30",
   CellTags->{"Basic Commands", "Info3614689788-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[53369, 1279, 1353, 19, 196, "Print",ExpressionUUID->"3598c355-5d0a-4d3d-9b3d-f7fd245ab10e",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[54737, 1301, 510, 16, 21, "Text",ExpressionUUID->"32f40f05-473f-4afc-9899-3d622bcdf716",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55250, 1319, 686, 18, 38, "Text",ExpressionUUID->"65aef86b-430e-45bc-abf8-ddddcf93ef68",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55939, 1339, 523, 12, 34, "Text",ExpressionUUID->"81c3bf14-369a-4990-9b18-332f42382a7d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56487, 1355, 195, 3, 24, "Input",ExpressionUUID->"345e0557-ca6e-4cb5-b0f5-2b96d006835d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56685, 1360, 1498, 35, 56, "Output",ExpressionUUID->"b4961016-071a-4a8e-bb6c-c90ac5d3702f",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[58198, 1398, 230, 5, 20, "Text",ExpressionUUID->"49dddedf-8a52-4696-a0f4-ea824834129b",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
   CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[58664, 1413, 927, 24, 51, "Text",ExpressionUUID->"d698385b-2681-4ae0-b85a-a3df7977a811",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59616, 1441, 221, 3, 24, "Input",ExpressionUUID->"3714197e-e855-42e0-9712-befe94db8040",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59840, 1446, 9008, 156, 107, "Print",ExpressionUUID->"2ff772c7-f46b-4d90-ac24-db9ca5717551",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[68851, 1604, 349, 5, 24, "Output",ExpressionUUID->"7c91bc79-09f1-4b33-b1bc-0df23b38a0d8",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69215, 1612, 395, 9, 21, "Text",ExpressionUUID->"b92c4fea-2385-4575-a331-9f47851bad97",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69635, 1625, 188, 3, 24, "Input",ExpressionUUID->"f10454f4-a19f-41ea-8804-aceb1d31c86d",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69826, 1630, 873, 13, 127, "Print",ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2",
   CellTags->{"Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7", "Using Options"}],
  Cell[70714, 1646, 230, 5, 20, "Text",ExpressionUUID->"6bb1aa19-e7dd-4535-b457-9728b6bd06b2",
   CellTags->{"Rayica User Guide Introduction", "RG1."}],
  Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71408, 1671, 373, 8, 20, "Text",ExpressionUUID->"96d3fc89-4f11-4a94-b332-e31880fe2590",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71784, 1681, 5409, 196, 274, "FramedBox",ExpressionUUID->"d0491aa2-cbdf-42fd-85b3-1a702665c886",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77196, 1879, 279, 7, 26, "Commentary",ExpressionUUID->"223397e7-31c7-4429-a46a-a3d5f8837777",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77478, 1888, 2094, 61, 102, "Text",ExpressionUUID->"2801ba38-1670-4ec0-be89-130ee69482c6",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[79575, 1951, 1004, 29, 51, "Text",ExpressionUUID->"2aac3485-7adc-42ac-8fe9-0f6b80a73898",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80604, 1984, 243, 4, 24, "Input",ExpressionUUID->"03e61a5c-2d76-42f7-8f63-a22c86e3aa11",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80850, 1990, 11382, 328, 204, "Output",ExpressionUUID->"e70dce45-423a-49c4-993e-46f4773bad3d",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92247, 2321, 453, 12, 27, "Commentary",ExpressionUUID->"2d4d4264-4d40-40c7-96cc-f946b789a556",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92703, 2335, 719, 11, 46, "Text",ExpressionUUID->"04677792-97c0-428e-a416-043a30fdab99",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[93425, 2348, 230, 5, 20, "Text",ExpressionUUID->"65448239-c679-424f-b8b0-8efa2aa4a94c",
   CellTags->{"Rayica User Guide Introduction", "RG1."}]},
 "RG1.1"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11143, 338, 673, 12, 46, "Text",ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1",
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11819, 352, 1112, 29, 46, "Text",ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9",
   Evaluatable->False,
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[13343, 399, 1312, 46, 46, "Text",ExpressionUUID->"53444f15-79b2-4da2-b4fc-a3aabc38a11b",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[14680, 449, 331, 12, 24, "Input",ExpressionUUID->"d0f1842b-9e8e-4fc2-bb3d-62a54619b000",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15014, 463, 491, 11, 20, "Print",ExpressionUUID->"30459a7a-ca46-4d83-af0d-fdb4a9801d45",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15508, 476, 376, 9, 19, "Print",ExpressionUUID->"2b7b290f-ec8f-499f-8ccd-8f8a5c6dde38",
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
  Cell[15899, 488, 904, 27, 33, "Text",ExpressionUUID->"b86d0f77-e2c9-4cc9-b06f-923277e3bc7c",
   Evaluatable->False,
   CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}]},
 "RG1.0"->{
  Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11143, 338, 673, 12, 46, "Text",ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1",
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
  Cell[11819, 352, 1112, 29, 46, "Text",ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9",
   Evaluatable->False,
   CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}]},
 "Loading"->{
  Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}]},
 "1.1"->{
  Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}]},
 "1.3"->{
  Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
   CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}]},
 "Rayica Example"->{
  Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
   CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}]},
 "A Basic Rayica Example"->{
  Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
   CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[17359, 538, 817, 18, 46, "Text",ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e",
   CellTags->{"Loading Rayica", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18201, 560, 321, 9, 89, "Input",ExpressionUUID->"528d9f96-c640-4726-aec0-55305c4ecf62",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18525, 571, 11143, 190, 223, "Print",ExpressionUUID->"2cd65a8a-29ca-47a4-b77a-241da870ded0",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[29671, 763, 356, 5, 24, "Output",ExpressionUUID->"decbdd55-e771-48ea-ad88-55eaabd4f074",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}]},
 "RG1.3"->{
  Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
   CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[17359, 538, 817, 18, 46, "Text",ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e",
   CellTags->{"Loading Rayica", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18201, 560, 321, 9, 89, "Input",ExpressionUUID->"528d9f96-c640-4726-aec0-55305c4ecf62",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[18525, 571, 11143, 190, 223, "Print",ExpressionUUID->"2cd65a8a-29ca-47a4-b77a-241da870ded0",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
  Cell[29671, 763, 356, 5, 24, "Output",ExpressionUUID->"decbdd55-e771-48ea-ad88-55eaabd4f074",
   CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}]},
 "1.4"->{
  Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
   CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}]},
 "Data"->{
  Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
   CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}]},
 "Inputting Data"->{
  Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
   CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[30507, 786, 633, 12, 33, "Text",ExpressionUUID->"6fc8cab9-7ee2-44e2-b98b-cdd60e0e3655",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[31143, 800, 1410, 31, 83, "Text",ExpressionUUID->"dda7200a-0a2d-46e4-a177-efe1267d01ee",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}]},
 "RG1.4"->{
  Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
   CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[30507, 786, 633, 12, 33, "Text",ExpressionUUID->"6fc8cab9-7ee2-44e2-b98b-cdd60e0e3655",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
  Cell[31143, 800, 1410, 31, 83, "Text",ExpressionUUID->"dda7200a-0a2d-46e4-a177-efe1267d01ee",
   CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}]},
 "1.5"->{
  Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
   CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}]},
 "Optical System"->{
  Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
   CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}]},
 "Modelling an Optical System"->{
  Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
   CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[33061, 849, 1018, 21, 66, "Text",ExpressionUUID->"87327b10-7eee-41c6-ac55-2a9376422dad",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34082, 872, 711, 18, 38, "Text",ExpressionUUID->"fa99db1d-7880-4526-9fdb-e0675a094fe9",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34796, 892, 522, 12, 37, "Text",ExpressionUUID->"aebb1dd9-09f9-4ca0-b88c-b3e5ed789c74",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35321, 906, 227, 3, 20, "Text",ExpressionUUID->"e0a3b9c6-0ae8-4dbb-8793-b4c9f770f285",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35551, 911, 707, 17, 130, "Text",ExpressionUUID->"4dafee9d-c203-44b3-bd11-6d428cd52708",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[36261, 930, 261, 5, 20, "Text",ExpressionUUID->"aa596a2d-47a7-483c-93b4-520dd475278c",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1."}]},
 "RG1.5"->{
  Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
   CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[33061, 849, 1018, 21, 66, "Text",ExpressionUUID->"87327b10-7eee-41c6-ac55-2a9376422dad",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34082, 872, 711, 18, 38, "Text",ExpressionUUID->"fa99db1d-7880-4526-9fdb-e0675a094fe9",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[34796, 892, 522, 12, 37, "Text",ExpressionUUID->"aebb1dd9-09f9-4ca0-b88c-b3e5ed789c74",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35321, 906, 227, 3, 20, "Text",ExpressionUUID->"e0a3b9c6-0ae8-4dbb-8793-b4c9f770f285",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
  Cell[35551, 911, 707, 17, 130, "Text",ExpressionUUID->"4dafee9d-c203-44b3-bd11-6d428cd52708",
   CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}]},
 "1.6"->{
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]},
 "Basic Rayica Example"->{
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]},
 "Variable"->{
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]},
 "Variable Definition"->{
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[36799, 946, 247, 5, 20, "Text",ExpressionUUID->"104e8fd2-1286-4ad8-bd49-62165d86e223",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37071, 955, 307, 9, 89, "Input",ExpressionUUID->"f920023b-619f-404b-8aca-2883db8d47c3",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37381, 966, 1126, 35, 24, "Output",ExpressionUUID->"369f0439-ef91-407d-b2b8-1a6d1ee2c936",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[38522, 1004, 562, 10, 33, "Text",ExpressionUUID->"dee619ee-4b4d-47a4-a93c-18511ca4be05",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39109, 1018, 224, 3, 24, "Input",ExpressionUUID->"5727830a-6763-4831-be3d-b5c19b2eeef4",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39336, 1023, 11138, 190, 223, "Print",ExpressionUUID->"acdffe68-5863-48c5-a77f-a7c3baf51997",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[50477, 1215, 353, 5, 24, "Output",ExpressionUUID->"c9ab9764-21af-4c4b-9970-43a26f36b411",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]},
 "RG1.6"->{
  Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
   CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[36799, 946, 247, 5, 20, "Text",ExpressionUUID->"104e8fd2-1286-4ad8-bd49-62165d86e223",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37071, 955, 307, 9, 89, "Input",ExpressionUUID->"f920023b-619f-404b-8aca-2883db8d47c3",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[37381, 966, 1126, 35, 24, "Output",ExpressionUUID->"369f0439-ef91-407d-b2b8-1a6d1ee2c936",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[38522, 1004, 562, 10, 33, "Text",ExpressionUUID->"dee619ee-4b4d-47a4-a93c-18511ca4be05",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39109, 1018, 224, 3, 24, "Input",ExpressionUUID->"5727830a-6763-4831-be3d-b5c19b2eeef4",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[39336, 1023, 11138, 190, 223, "Print",ExpressionUUID->"acdffe68-5863-48c5-a77f-a7c3baf51997",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
  Cell[50477, 1215, 353, 5, 24, "Output",ExpressionUUID->"c9ab9764-21af-4c4b-9970-43a26f36b411",
   CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]},
 "1.2"->{
  Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
   CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]},
 "Commands"->{
  Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
   CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]},
 "Basic Commands"->{
  Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
   CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51314, 1238, 418, 9, 21, "Text",ExpressionUUID->"b961e791-5ad4-44d6-be6c-25237633de9a",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51757, 1251, 196, 3, 24, "Input",ExpressionUUID->"60b3ccf1-9b6a-42b4-beda-efdf85878f43",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51956, 1256, 1410, 21, 163, "Print",ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30",
   CellTags->{"Basic Commands", "Info3614689788-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[53369, 1279, 1353, 19, 196, "Print",ExpressionUUID->"3598c355-5d0a-4d3d-9b3d-f7fd245ab10e",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[54737, 1301, 510, 16, 21, "Text",ExpressionUUID->"32f40f05-473f-4afc-9899-3d622bcdf716",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55250, 1319, 686, 18, 38, "Text",ExpressionUUID->"65aef86b-430e-45bc-abf8-ddddcf93ef68",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55939, 1339, 523, 12, 34, "Text",ExpressionUUID->"81c3bf14-369a-4990-9b18-332f42382a7d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56487, 1355, 195, 3, 24, "Input",ExpressionUUID->"345e0557-ca6e-4cb5-b0f5-2b96d006835d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56685, 1360, 1498, 35, 56, "Output",ExpressionUUID->"b4961016-071a-4a8e-bb6c-c90ac5d3702f",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]},
 "RG1.2"->{
  Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
   CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51314, 1238, 418, 9, 21, "Text",ExpressionUUID->"b961e791-5ad4-44d6-be6c-25237633de9a",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51757, 1251, 196, 3, 24, "Input",ExpressionUUID->"60b3ccf1-9b6a-42b4-beda-efdf85878f43",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[51956, 1256, 1410, 21, 163, "Print",ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30",
   CellTags->{"Basic Commands", "Info3614689788-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[53369, 1279, 1353, 19, 196, "Print",ExpressionUUID->"3598c355-5d0a-4d3d-9b3d-f7fd245ab10e",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[54737, 1301, 510, 16, 21, "Text",ExpressionUUID->"32f40f05-473f-4afc-9899-3d622bcdf716",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55250, 1319, 686, 18, 38, "Text",ExpressionUUID->"65aef86b-430e-45bc-abf8-ddddcf93ef68",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[55939, 1339, 523, 12, 34, "Text",ExpressionUUID->"81c3bf14-369a-4990-9b18-332f42382a7d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56487, 1355, 195, 3, 24, "Input",ExpressionUUID->"345e0557-ca6e-4cb5-b0f5-2b96d006835d",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
  Cell[56685, 1360, 1498, 35, 56, "Output",ExpressionUUID->"b4961016-071a-4a8e-bb6c-c90ac5d3702f",
   CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]},
 "Info3614689788-8836408"->{
  Cell[51956, 1256, 1410, 21, 163, "Print",ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30",
   CellTags->{"Basic Commands", "Info3614689788-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]},
 "1.7"->{
  Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
   CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}]},
 "Options"->{
  Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
   CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}]},
 "Using Options"->{
  Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
   CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[58664, 1413, 927, 24, 51, "Text",ExpressionUUID->"d698385b-2681-4ae0-b85a-a3df7977a811",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59616, 1441, 221, 3, 24, "Input",ExpressionUUID->"3714197e-e855-42e0-9712-befe94db8040",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59840, 1446, 9008, 156, 107, "Print",ExpressionUUID->"2ff772c7-f46b-4d90-ac24-db9ca5717551",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[68851, 1604, 349, 5, 24, "Output",ExpressionUUID->"7c91bc79-09f1-4b33-b1bc-0df23b38a0d8",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69215, 1612, 395, 9, 21, "Text",ExpressionUUID->"b92c4fea-2385-4575-a331-9f47851bad97",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69635, 1625, 188, 3, 24, "Input",ExpressionUUID->"f10454f4-a19f-41ea-8804-aceb1d31c86d",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69826, 1630, 873, 13, 127, "Print",ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2",
   CellTags->{"Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7", "Using Options"}]},
 "RG1.7"->{
  Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
   CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[58664, 1413, 927, 24, 51, "Text",ExpressionUUID->"d698385b-2681-4ae0-b85a-a3df7977a811",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59616, 1441, 221, 3, 24, "Input",ExpressionUUID->"3714197e-e855-42e0-9712-befe94db8040",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[59840, 1446, 9008, 156, 107, "Print",ExpressionUUID->"2ff772c7-f46b-4d90-ac24-db9ca5717551",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[68851, 1604, 349, 5, 24, "Output",ExpressionUUID->"7c91bc79-09f1-4b33-b1bc-0df23b38a0d8",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69215, 1612, 395, 9, 21, "Text",ExpressionUUID->"b92c4fea-2385-4575-a331-9f47851bad97",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69635, 1625, 188, 3, 24, "Input",ExpressionUUID->"f10454f4-a19f-41ea-8804-aceb1d31c86d",
   CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
  Cell[69826, 1630, 873, 13, 127, "Print",ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2",
   CellTags->{"Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7", "Using Options"}]},
 "Info3614689789-8836408"->{
  Cell[69826, 1630, 873, 13, 127, "Print",ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2",
   CellTags->{"Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7", "Using Options"}]},
 "1.8"->{
  Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}]},
 "High-Level Functions"->{
  Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}]},
 "Rayica's High-Level Functions"->{
  Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71408, 1671, 373, 8, 20, "Text",ExpressionUUID->"96d3fc89-4f11-4a94-b332-e31880fe2590",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71784, 1681, 5409, 196, 274, "FramedBox",ExpressionUUID->"d0491aa2-cbdf-42fd-85b3-1a702665c886",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77196, 1879, 279, 7, 26, "Commentary",ExpressionUUID->"223397e7-31c7-4429-a46a-a3d5f8837777",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77478, 1888, 2094, 61, 102, "Text",ExpressionUUID->"2801ba38-1670-4ec0-be89-130ee69482c6",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[79575, 1951, 1004, 29, 51, "Text",ExpressionUUID->"2aac3485-7adc-42ac-8fe9-0f6b80a73898",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80604, 1984, 243, 4, 24, "Input",ExpressionUUID->"03e61a5c-2d76-42f7-8f63-a22c86e3aa11",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80850, 1990, 11382, 328, 204, "Output",ExpressionUUID->"e70dce45-423a-49c4-993e-46f4773bad3d",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92247, 2321, 453, 12, 27, "Commentary",ExpressionUUID->"2d4d4264-4d40-40c7-96cc-f946b789a556",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92703, 2335, 719, 11, 46, "Text",ExpressionUUID->"04677792-97c0-428e-a416-043a30fdab99",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}]},
 "RG1.8"->{
  Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71408, 1671, 373, 8, 20, "Text",ExpressionUUID->"96d3fc89-4f11-4a94-b332-e31880fe2590",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[71784, 1681, 5409, 196, 274, "FramedBox",ExpressionUUID->"d0491aa2-cbdf-42fd-85b3-1a702665c886",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77196, 1879, 279, 7, 26, "Commentary",ExpressionUUID->"223397e7-31c7-4429-a46a-a3d5f8837777",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[77478, 1888, 2094, 61, 102, "Text",ExpressionUUID->"2801ba38-1670-4ec0-be89-130ee69482c6",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[79575, 1951, 1004, 29, 51, "Text",ExpressionUUID->"2aac3485-7adc-42ac-8fe9-0f6b80a73898",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80604, 1984, 243, 4, 24, "Input",ExpressionUUID->"03e61a5c-2d76-42f7-8f63-a22c86e3aa11",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[80850, 1990, 11382, 328, 204, "Output",ExpressionUUID->"e70dce45-423a-49c4-993e-46f4773bad3d",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92247, 2321, 453, 12, 27, "Commentary",ExpressionUUID->"2d4d4264-4d40-40c7-96cc-f946b789a556",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
  Cell[92703, 2335, 719, 11, 46, "Text",ExpressionUUID->"04677792-97c0-428e-a416-043a30fdab99",
   CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}]},
 "2."->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}]},
 "Ray"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[97766, 2460, 470, 12, 20, "Text",ExpressionUUID->"5e956b8d-0a1d-4670-9ef7-316f471bb0aa",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[98239, 2474, 4259, 148, 252, "FramedBox",ExpressionUUID->"163be0ce-c836-4a05-b602-043cfeb767c5",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[108393, 2798, 810, 20, 39, "Text",ExpressionUUID->"bb566f6b-daf3-4983-869d-a2f2b0573f0b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[109206, 2820, 803, 21, 38, "Text",ExpressionUUID->"f6d83e78-531c-4ffa-ac13-f9f2557d1e00",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110034, 2845, 295, 5, 35, "Input",ExpressionUUID->"3c66cd45-fbcd-4b97-a7ff-ed3bf9d5a639",
   PageBreakWithin->Automatic,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110332, 2852, 444, 11, 24, "Output",ExpressionUUID->"cbee1408-a603-4db7-a141-fc74ed03cd9f",
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[113328, 2931, 1529, 41, 83, "Text",ExpressionUUID->"194aaa1b-e39b-483d-98c9-86fbf1a155d7",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[117645, 3056, 1206, 37, 51, "Text",ExpressionUUID->"3dae03d0-b7a4-4671-b970-ff4fb797fb9f",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[118854, 3095, 583, 19, 34, "Text",ExpressionUUID->"07b827ce-dce5-4812-850d-a7d45348011b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[140808, 3691, 518, 14, 38, "Text",ExpressionUUID->"2dd4bb18-47b5-4437-9dce-4eb4c658c3c4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[142828, 3743, 1177, 36, 47, "Text",ExpressionUUID->"13fe18f5-4bd8-4d78-a9c2-bc1b9650fca4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[295305, 7601, 2694, 99, 146, "FramedBox",ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[317864, 8149, 1396, 33, 165, "FramedBox",ExpressionUUID->"0936f727-cc05-485f-a077-877a4972781b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "ShowSystem", "RG6."}]},
 "Component"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[144582, 3800, 634, 16, 37, "Text",ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145241, 3820, 190, 2, 24, "Input",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145434, 3824, 51836, 1500, 686, "Output",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[197285, 5327, 465, 14, 27, "Commentary",ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb",
   CellTags->{"Components and Sources", "2.4", "Component", "RG2.", "RG2.4"}],
  Cell[197753, 5343, 532, 14, 37, "Text",ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199103, 5390, 366, 11, 22, "Text",ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199494, 5405, 288, 5, 24, "Input",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199785, 5412, 510, 12, 23, "Output",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[200310, 5427, 1518, 39, 69, "Text",ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[202678, 5492, 1355, 43, 56, "Text",ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204058, 5539, 284, 5, 24, "Input",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204345, 5546, 2602, 59, 120, "Output",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[206962, 5608, 832, 20, 52, "Text",ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}]},
 "2. Introduction"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[94095, 2370, 1653, 36, 95, "Text",ExpressionUUID->"3a3fa262-4e29-486e-8f42-6aba6019448f",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[95773, 2410, 276, 7, 31, "Subsubsection",ExpressionUUID->"b23d5c84-e672-4ff2-9bd7-b56a49123486",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[96052, 2419, 1149, 20, 72, "Text",ExpressionUUID->"0a9fdeff-c71d-4bda-8c34-871b949d40e1",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}]},
 "2.1"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[97463, 2451, 300, 7, 35, "Subsection",ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "Modeling a light source", "RG2.", "RG2.1", "2.1"}]},
 "2.2"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[117348, 3047, 294, 7, 35, "Subsection",ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", "2.2"}]},
 "2.3"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[131304, 3446, 412, 13, 35, "Subsection",ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"How Rayica manages default light source settings", "Components and Sources", "RG2.", "RG2.3", "2.3"}]},
 "2.4"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[144267, 3791, 312, 7, 35, "Subsection",ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Modeling an optical component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[144582, 3800, 634, 16, 37, "Text",ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145241, 3820, 190, 2, 24, "Input",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145434, 3824, 51836, 1500, 686, "Output",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[197285, 5327, 465, 14, 27, "Commentary",ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb",
   CellTags->{"Components and Sources", "2.4", "Component", "RG2.", "RG2.4"}],
  Cell[197753, 5343, 532, 14, 37, "Text",ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199103, 5390, 366, 11, 22, "Text",ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199494, 5405, 288, 5, 24, "Input",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199785, 5412, 510, 12, 23, "Output",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[200310, 5427, 1518, 39, 69, "Text",ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[201831, 5468, 844, 22, 51, "Text",ExpressionUUID->"eef9b50e-e13a-421f-9021-c75994b22de3",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[202678, 5492, 1355, 43, 56, "Text",ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204058, 5539, 284, 5, 24, "Input",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204345, 5546, 2602, 59, 120, "Output",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[206962, 5608, 832, 20, 52, "Text",ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[207819, 5632, 280, 7, 24, "Input",ExpressionUUID->"86d06f27-cac4-455d-963a-9c1e384be627",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[208102, 5641, 583, 14, 24, "Output",ExpressionUUID->"b7c3aa15-7beb-46bd-ad1e-9086c3bfae34",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}]},
 "RG2.0"->{
  Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
   Evaluatable->False,
   PageBreakAbove->True,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
  Cell[94095, 2370, 1653, 36, 95, "Text",ExpressionUUID->"3a3fa262-4e29-486e-8f42-6aba6019448f",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[95773, 2410, 276, 7, 31, "Subsubsection",ExpressionUUID->"b23d5c84-e672-4ff2-9bd7-b56a49123486",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
  Cell[96052, 2419, 1149, 20, 72, "Text",ExpressionUUID->"0a9fdeff-c71d-4bda-8c34-871b949d40e1",
   CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}]},
 "Modeling a light source"->{
  Cell[97463, 2451, 300, 7, 35, "Subsection",ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "Modeling a light source", "RG2.", "RG2.1", "2.1"}]},
 "RG2.1"->{
  Cell[97463, 2451, 300, 7, 35, "Subsection",ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Components and Sources", "Modeling a light source", "RG2.", "RG2.1", "2.1"}],
  Cell[97766, 2460, 470, 12, 20, "Text",ExpressionUUID->"5e956b8d-0a1d-4670-9ef7-316f471bb0aa",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[98239, 2474, 4259, 148, 252, "FramedBox",ExpressionUUID->"163be0ce-c836-4a05-b602-043cfeb767c5",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[102501, 2624, 181, 3, 26, "Commentary",ExpressionUUID->"27a68c2a-97e8-4545-9c15-783313072250",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[102685, 2629, 426, 13, 21, "Text",ExpressionUUID->"0d4877d2-630c-4e99-8871-bfb21f4e30b2",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[103136, 2646, 196, 2, 24, "Input",ExpressionUUID->"8f30dbd1-2c32-4f9c-9b9c-6b2fa197b05a",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[103335, 2650, 4626, 131, 120, "Output",ExpressionUUID->"98f38436-b1e7-4aef-a162-3c76193a021f",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[107976, 2784, 414, 12, 27, "Commentary",ExpressionUUID->"634fbaf7-e6e1-48c2-8a43-5d6fe3abb5e0",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[108393, 2798, 810, 20, 39, "Text",ExpressionUUID->"bb566f6b-daf3-4983-869d-a2f2b0573f0b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[109206, 2820, 803, 21, 38, "Text",ExpressionUUID->"f6d83e78-531c-4ffa-ac13-f9f2557d1e00",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110034, 2845, 295, 5, 35, "Input",ExpressionUUID->"3c66cd45-fbcd-4b97-a7ff-ed3bf9d5a639",
   PageBreakWithin->Automatic,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110332, 2852, 444, 11, 24, "Output",ExpressionUUID->"cbee1408-a603-4db7-a141-fc74ed03cd9f",
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[110791, 2866, 1300, 35, 66, "Text",ExpressionUUID->"83e9195b-377a-46f7-940b-d5f912ae28cd",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[112116, 2905, 174, 2, 24, "Input",ExpressionUUID->"44acd788-f49f-4b3c-ada7-aaa673fd1ee2",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[112293, 2909, 1020, 19, 116, "Output",ExpressionUUID->"efe3dfab-e4d5-413f-be0c-367f2a295ab4",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
  Cell[113328, 2931, 1529, 41, 83, "Text",ExpressionUUID->"194aaa1b-e39b-483d-98c9-86fbf1a155d7",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
  Cell[114860, 2974, 2226, 61, 119, "Text",ExpressionUUID->"2db9e75b-e121-4086-8722-eee8505e9120",
   CellTags->{"Components and Sources", "RG2.", "RG2.1"}]},
 "Ray versus TurboRays"->{
  Cell[117348, 3047, 294, 7, 35, "Subsection",ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", "2.2"}]},
 "RG2.2"->{
  Cell[117348, 3047, 294, 7, 35, "Subsection",ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", "2.2"}],
  Cell[117645, 3056, 1206, 37, 51, "Text",ExpressionUUID->"3dae03d0-b7a4-4671-b970-ff4fb797fb9f",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[118854, 3095, 583, 19, 34, "Text",ExpressionUUID->"07b827ce-dce5-4812-850d-a7d45348011b",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}],
  Cell[120852, 3168, 807, 24, 38, "Text",ExpressionUUID->"ec17fe0d-d65b-4b4b-aec1-5b1491287176",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[121684, 3196, 181, 2, 24, "Input",ExpressionUUID->"ccde2674-390a-4365-96e1-7846afb2c154",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[121868, 3200, 444, 11, 24, "Output",ExpressionUUID->"de932cca-b2d3-496e-be44-bc5e187564af",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122327, 3214, 465, 15, 21, "Text",ExpressionUUID->"e2f135df-65eb-45c1-8caf-4fc68baa3243",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122817, 3233, 174, 2, 24, "Input",ExpressionUUID->"26ac156b-7290-47db-8499-89f9e7408435",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[122994, 3237, 1006, 19, 116, "Output",ExpressionUUID->"b59b4740-4088-412d-9344-67d755cedbec",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124015, 3259, 520, 17, 34, "Text",ExpressionUUID->"ae70480d-bef9-4f92-901c-c4f9883b9009",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124560, 3280, 186, 2, 24, "Input",ExpressionUUID->"26204c28-0611-4bdb-8ee8-f41e1974186f",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[124749, 3284, 2229, 38, 278, "Output",ExpressionUUID->"1e7fbbbe-ac15-463a-b599-8d861ee982fb",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[126993, 3325, 1202, 41, 54, "Text",ExpressionUUID->"06637bc5-a376-4811-8505-c4e6bcc7afba",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[128220, 3370, 211, 2, 24, "Input",ExpressionUUID->"c14e6e5e-b415-4b18-87dd-2a3d5e9dfadf",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[128434, 3374, 1082, 18, 116, "Output",ExpressionUUID->"35245519-99f9-4861-a0fc-d218481c739f",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
  Cell[129531, 3395, 1511, 39, 86, "Text",ExpressionUUID->"78c6969c-cf10-4e6b-b4db-fe4cd0465117",
   CellTags->{"Components and Sources", "RG2.", "RG2.2"}]},
 "CreateRays"->{
  Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}]},
 "TurboRays"->{
  Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}]},
 "How Rayica manages default light source settings"->{
  Cell[131304, 3446, 412, 13, 35, "Subsection",ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"How Rayica manages default light source settings", "Components and Sources", "RG2.", "RG2.3", "2.3"}]},
 "RG2.3"->{
  Cell[131304, 3446, 412, 13, 35, "Subsection",ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"How Rayica manages default light source settings", "Components and Sources", "RG2.", "RG2.3", "2.3"}],
  Cell[131719, 3461, 1314, 39, 66, "Text",ExpressionUUID->"f7db2f37-f6c0-4557-a85c-9e4ca13ee1d9",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133036, 3502, 725, 17, 51, "Text",ExpressionUUID->"7fd2b89a-85a7-4bac-9b28-1d4e4e9630e0",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133786, 3523, 164, 2, 24, "Input",ExpressionUUID->"dc651577-4f0a-49cd-a800-e175d4bf5069",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[133953, 3527, 4775, 103, 200, "Output",ExpressionUUID->"623a4163-fa46-4247-ad2b-263ba7b59c86",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[138743, 3633, 1018, 26, 54, "Text",ExpressionUUID->"c380cecc-f3c6-42a5-a0c4-0d6ef93e9822",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[139764, 3661, 332, 7, 20, "Text",ExpressionUUID->"ff5b866d-87d0-457e-81c5-34d395797f94",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140121, 3672, 181, 2, 24, "Input",ExpressionUUID->"d0320a23-7f02-4e4a-88e6-aacdfcd7a573",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140305, 3676, 488, 12, 24, "Output",ExpressionUUID->"bae2cc55-2bed-4232-892f-843be9ddaa2e",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[140808, 3691, 518, 14, 38, "Text",ExpressionUUID->"2dd4bb18-47b5-4437-9dce-4eb4c658c3c4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
  Cell[141351, 3709, 170, 2, 24, "Input",ExpressionUUID->"b70d0283-7f35-4b33-9bcb-39989eb809fe",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[141524, 3713, 1289, 27, 56, "Output",ExpressionUUID->"df31c411-7635-43b3-af9e-e120b2b1bff3",
   CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
  Cell[142828, 3743, 1177, 36, 47, "Text",ExpressionUUID->"13fe18f5-4bd8-4d78-a9c2-bc1b9650fca4",
   Evaluatable->False,
   CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}]},
 "Modeling an optical component"->{
  Cell[144267, 3791, 312, 7, 35, "Subsection",ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Modeling an optical component", "Components and Sources", "2.4", "RG2.", "RG2.4"}]},
 "RG2.4"->{
  Cell[144267, 3791, 312, 7, 35, "Subsection",ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Modeling an optical component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[144582, 3800, 634, 16, 37, "Text",ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145241, 3820, 190, 2, 24, "Input",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[145434, 3824, 51836, 1500, 686, "Output",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[197285, 5327, 465, 14, 27, "Commentary",ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb",
   CellTags->{"Components and Sources", "2.4", "Component", "RG2.", "RG2.4"}],
  Cell[197753, 5343, 532, 14, 37, "Text",ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199103, 5390, 366, 11, 22, "Text",ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199494, 5405, 288, 5, 24, "Input",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[199785, 5412, 510, 12, 23, "Output",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[200310, 5427, 1518, 39, 69, "Text",ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[201831, 5468, 844, 22, 51, "Text",ExpressionUUID->"eef9b50e-e13a-421f-9021-c75994b22de3",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[202678, 5492, 1355, 43, 56, "Text",ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204058, 5539, 284, 5, 24, "Input",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff",
   PageBreakWithin->Automatic,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[204345, 5546, 2602, 59, 120, "Output",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e",
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[206962, 5608, 832, 20, 52, "Text",ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2",
   Evaluatable->False,
   CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[207819, 5632, 280, 7, 24, "Input",ExpressionUUID->"86d06f27-cac4-455d-963a-9c1e384be627",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
  Cell[208102, 5641, 583, 14, 24, "Output",ExpressionUUID->"b7c3aa15-7beb-46bd-ad1e-9086c3bfae34",
   CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}]},
 "PlanoConvexLens"->{
  Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}]},
 "3."->{
  Cell[208971, 5669, 448, 16, 60, "Section",ExpressionUUID->"f36ffa46-c6d2-439a-9436-fd7c63745e3d",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"3.", "Introduction to AnalyzeSystem and TurboPlot", "RG3."}]},
 "4."->{
  Cell[229628, 6118, 299, 12, 60, "Section",ExpressionUUID->"e79ee304-6444-418c-a347-afc29e47298d",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Move", "4.", "RG4."}]},
 "ray tracing"->{
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[337997, 8544, 534, 16, 21, "Text",ExpressionUUID->"9c94a08d-a3e8-4d8e-acb6-662ceb40fb6c",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338556, 8564, 437, 10, 57, "Input",ExpressionUUID->"fed97f40-88bc-4f03-9201-d0237877757f",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338996, 8576, 15095, 255, 223, "Print",ExpressionUUID->"37191ea6-48c5-4143-badd-2a16889b8e71",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354620, 8849, 355, 10, 21, "Text",ExpressionUUID->"24b310c7-f413-4438-a984-916a3d387316",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354978, 8861, 635, 20, 51, "FramedBox",ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", "RG7."}],
  Cell[355616, 8883, 1266, 45, 55, "Text",ExpressionUUID->"e506ddcd-0879-41ab-9c62-f1893312d38a",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[356907, 8932, 486, 11, 57, "Input",ExpressionUUID->"78ae942a-cb18-4547-b900-445b13070a83",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[357396, 8945, 56644, 921, 223, "Print",ExpressionUUID->"b1b87736-fe15-4098-9aab-1bb1ba1e1fba",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414055, 9869, 416, 13, 21, "Text",ExpressionUUID->"072f6e22-85e4-42b4-8783-7cc94a7c1fd3",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414496, 9886, 262, 4, 24, "Input",ExpressionUUID->"21c87232-2508-40e4-a406-184ea43091fe",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414761, 9892, 40317, 694, 107, "Print",ExpressionUUID->"af61dccd-7843-4695-8d08-5324bb57a8b7",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455093, 10589, 727, 22, 39, "Text",ExpressionUUID->"566e4a0b-26a1-49bf-a5d6-8f6376ae9285",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455845, 10615, 263, 4, 24, "Input",ExpressionUUID->"43392047-6d38-472c-b510-86ef1a1bb072",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[456111, 10621, 44399, 773, 365, "Print",ExpressionUUID->"0a748db5-bcea-4a91-831b-278c5989b2ec",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[871644, 18018, 533, 16, 22, "Text",ExpressionUUID->"689a409b-f5af-413a-907b-9b9cec7d70ae",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[872180, 18036, 1063, 37, 68, "FramedBox",ExpressionUUID->"437f1c99-1fe9-4e37-aac6-8df84c32b157",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[875030, 18122, 916, 25, 51, "Text",ExpressionUUID->"7deed9e8-abe9-4501-81eb-e91376c45f45",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[7383451, 130002, 818, 23, 54, "Text",ExpressionUUID->"8d722c0e-fc4f-44f3-9c41-5eab67bf2242",
   Evaluatable->False,
   CellTags->{"ray tracing", "Resonate", "RG18."}],
  Cell[7384897, 130051, 1152, 25, 66, "Text",ExpressionUUID->"f385f2b0-9078-4098-94f4-63d776aa23db",
   Evaluatable->False,
   CellTags->{"ray tracing", "Resonate", "RG18."}]},
 "DrawSystem"->{
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[337997, 8544, 534, 16, 21, "Text",ExpressionUUID->"9c94a08d-a3e8-4d8e-acb6-662ceb40fb6c",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338556, 8564, 437, 10, 57, "Input",ExpressionUUID->"fed97f40-88bc-4f03-9201-d0237877757f",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[338996, 8576, 15095, 255, 223, "Print",ExpressionUUID->"37191ea6-48c5-4143-badd-2a16889b8e71",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354620, 8849, 355, 10, 21, "Text",ExpressionUUID->"24b310c7-f413-4438-a984-916a3d387316",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[354978, 8861, 635, 20, 51, "FramedBox",ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", "RG7."}],
  Cell[355616, 8883, 1266, 45, 55, "Text",ExpressionUUID->"e506ddcd-0879-41ab-9c62-f1893312d38a",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[356907, 8932, 486, 11, 57, "Input",ExpressionUUID->"78ae942a-cb18-4547-b900-445b13070a83",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[357396, 8945, 56644, 921, 223, "Print",ExpressionUUID->"b1b87736-fe15-4098-9aab-1bb1ba1e1fba",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414055, 9869, 416, 13, 21, "Text",ExpressionUUID->"072f6e22-85e4-42b4-8783-7cc94a7c1fd3",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414496, 9886, 262, 4, 24, "Input",ExpressionUUID->"21c87232-2508-40e4-a406-184ea43091fe",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[414761, 9892, 40317, 694, 107, "Print",ExpressionUUID->"af61dccd-7843-4695-8d08-5324bb57a8b7",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455093, 10589, 727, 22, 39, "Text",ExpressionUUID->"566e4a0b-26a1-49bf-a5d6-8f6376ae9285",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[455845, 10615, 263, 4, 24, "Input",ExpressionUUID->"43392047-6d38-472c-b510-86ef1a1bb072",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[456111, 10621, 44399, 773, 365, "Print",ExpressionUUID->"0a748db5-bcea-4a91-831b-278c5989b2ec",
   CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
  Cell[871644, 18018, 533, 16, 22, "Text",ExpressionUUID->"689a409b-f5af-413a-907b-9b9cec7d70ae",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[872180, 18036, 1063, 37, 68, "FramedBox",ExpressionUUID->"437f1c99-1fe9-4e37-aac6-8df84c32b157",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[875030, 18122, 916, 25, 51, "Text",ExpressionUUID->"7deed9e8-abe9-4501-81eb-e91376c45f45",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
  Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}]},
 "5."->{
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}]},
 "5.1"->{
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292639, 7528, 858, 21, 53, "Text",ExpressionUUID->"7369556e-547f-4c48-9122-ce4aa18cf0e1",
   CellTags->{"AnalyzeSystem", "5.1", "RG5.", "RG5.1"}]},
 "5.2"->{
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[295305, 7601, 2694, 99, 146, "FramedBox",ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298002, 7702, 231, 7, 26, "Commentary",ExpressionUUID->"26b43ee4-7126-4285-afb4-1c0266581bb3",
   CellTags->{"AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}]},
 "RG5.1"->{
  Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
  Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
   PageBreakWithin->Automatic,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
  Cell[292639, 7528, 858, 21, 53, "Text",ExpressionUUID->"7369556e-547f-4c48-9122-ce4aa18cf0e1",
   CellTags->{"AnalyzeSystem", "5.1", "RG5.", "RG5.1"}]},
 "Tracing a single ray"->{
  Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}]},
 "Boundary"->{
  Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}]},
 "Working with the ray-trace data"->{
  Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}]},
 "RG5.2"->{
  Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[295305, 7601, 2694, 99, 146, "FramedBox",ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Ray", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298002, 7702, 231, 7, 26, "Commentary",ExpressionUUID->"26b43ee4-7126-4285-afb4-1c0266581bb3",
   CellTags->{"AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
  Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}]},
 "component rendering"->{
  Cell[299518, 7748, 338, 12, 63, "Section",ExpressionUUID->"64a2e08a-22da-4300-95b9-1ad25b5ce535",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowSystem", "component rendering", "6.", "RG6."}],
  Cell[299859, 7762, 856, 26, 39, "Text",ExpressionUUID->"a762463d-3045-4825-87b2-14bb8f507bfc",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[300740, 7792, 388, 11, 24, "Input",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[301131, 7805, 12794, 217, 138, "Print",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[313940, 8025, 705, 18, 34, "Text",ExpressionUUID->"30f2a5f0-70af-48be-a362-2f0d0ed3bc92",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[314648, 8045, 1216, 35, 164, "FramedBox",ExpressionUUID->"4d2d16ec-590d-4087-a948-7eca66168471",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[316017, 8087, 840, 24, 38, "Text",ExpressionUUID->"1164e3f4-4cce-443b-a3eb-b8e6ed0b0d18",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[316860, 8113, 692, 23, 51, "FramedBox",ExpressionUUID->"81b20859-5e84-4947-9587-7215471a8f59",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[317555, 8138, 306, 9, 21, "Text",ExpressionUUID->"666c3868-dbeb-4e1e-8f1f-c61134156135",
   Evaluatable->False,
   CellTags->{"ShowSystem", "component rendering", "RG6."}],
  Cell[319936, 8209, 387, 13, 24, "Input",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[320326, 8224, 15785, 256, 256, "Print",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}]},
 "6."->{
  Cell[299518, 7748, 338, 12, 63, "Section",ExpressionUUID->"64a2e08a-22da-4300-95b9-1ad25b5ce535",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowSystem", "component rendering", "6.", "RG6."}]},
 "PlotType"->{
  Cell[300740, 7792, 388, 11, 24, "Input",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[301131, 7805, 12794, 217, 138, "Print",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[314648, 8045, 1216, 35, 164, "FramedBox",ExpressionUUID->"4d2d16ec-590d-4087-a948-7eca66168471",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[316860, 8113, 692, 23, 51, "FramedBox",ExpressionUUID->"81b20859-5e84-4947-9587-7215471a8f59",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
  Cell[319936, 8209, 387, 13, 24, "Input",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[320326, 8224, 15785, 256, 256, "Print",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}]},
 "TopView"->{
  Cell[300740, 7792, 388, 11, 24, "Input",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[301131, 7805, 12794, 217, 138, "Print",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[319936, 8209, 387, 13, 24, "Input",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144",
   PageBreakWithin->Automatic,
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
  Cell[320326, 8224, 15785, 256, 256, "Print",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb",
   CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}]},
 "ConeOfRays"->{
  Cell[337718, 8535, 276, 7, 60, "Section",ExpressionUUID->"ef5cb7f7-4a2e-41b7-a582-7cd49609ad04",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ConeOfRays", "7.", "Tracing a Cone of Rays", "RG7."}]},
 "7."->{
  Cell[337718, 8535, 276, 7, 60, "Section",ExpressionUUID->"ef5cb7f7-4a2e-41b7-a582-7cd49609ad04",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ConeOfRays", "7.", "Tracing a Cone of Rays", "RG7."}]},
 "GraphicDesign"->{
  Cell[354978, 8861, 635, 20, 51, "FramedBox",ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", "RG7."}]},
 "cylindrical lens"->{
  Cell[500732, 11405, 302, 7, 60, "Section",ExpressionUUID->"811accef-54a1-49dd-aafb-3af96471eef6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"cylindrical lens", "8.", "Adding a Cylindrical Lens", "RG8."}],
  Cell[501037, 11414, 441, 11, 21, "Text",ExpressionUUID->"de0b999c-b77b-4599-9529-4cf305828fbf",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[502236, 11455, 472, 16, 21, "Text",ExpressionUUID->"2a020f65-57b9-4d9c-a7ad-1909426b6614",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[502733, 11475, 584, 14, 89, "Input",ExpressionUUID->"8bec4a81-f674-4133-b165-e68c0b8dc5f6",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[503320, 11491, 89102, 1445, 220, "Print",ExpressionUUID->"0eb413d0-0c48-47c6-8df0-2f898569bd3d",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
  Cell[592437, 12939, 243, 5, 20, "Text",ExpressionUUID->"09cb721d-419f-47bb-9788-3802a696cbee",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[592705, 12948, 268, 4, 24, "Input",ExpressionUUID->"5e6666c8-aa0e-4d60-801e-bbc7eef0bf62",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[592976, 12954, 64048, 1102, 104, "Print",ExpressionUUID->"3dab169f-74d4-49da-ad43-db9c6f5ac4cf",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[657061, 14061, 267, 4, 24, "Input",ExpressionUUID->"861c617d-2d33-4fa6-a2ed-2b5e8e334a04",
   PageBreakWithin->Automatic,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[657331, 14067, 65471, 1127, 104, "Print",ExpressionUUID->"d723f22c-56c9-45ab-9326-3be74b4f57f2",
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
  Cell[722817, 15197, 1246, 32, 60, "Text",ExpressionUUID->"f46b8f25-0f6f-43f7-9dcf-10d7b52d732b",
   Evaluatable->False,
   CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}]},
 "8."->{
  Cell[500732, 11405, 302, 7, 60, "Section",ExpressionUUID->"811accef-54a1-49dd-aafb-3af96471eef6",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"cylindrical lens", "8.", "Adding a Cylindrical Lens", "RG8."}]},
 "PlanoConvexCylindricalLens"->{
  Cell[501481, 11427, 752, 26, 51, "FramedBox",ExpressionUUID->"cefabc0f-b2ba-4081-a914-a90102a52410",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"PlanoConvexCylindricalLens", "Adding a Cylindrical Lens", "RG8."}]},
 "9."->{
  Cell[724273, 15239, 254, 10, 63, "Section",ExpressionUUID->"23359498-8046-434a-af0c-e565df2d8892",
   Evaluatable->False,
   CellTags->{"RayChoice", "9.", "RG9."}]},
 "Surface"->{
  Cell[815295, 16772, 579, 18, 51, "FramedBox",ExpressionUUID->"ab90f6a7-a383-4ac1-80ec-3fa98fb9b1f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"RayChoice", "Surface", "RG9."}],
  Cell[815877, 16792, 453, 14, 21, "Text",ExpressionUUID->"41a7f206-e13a-4409-be36-f56525db8c24",
   Evaluatable->False,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816355, 16810, 300, 6, 24, "Input",ExpressionUUID->"47b9e46a-25c0-4cb3-b662-0d37b89eb12d",
   PageBreakWithin->Automatic,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816658, 16818, 3305, 74, 365, "Print",ExpressionUUID->"15442f90-5536-464e-8ab9-90af301ef1ce",
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}]},
 "ComponentNumber"->{
  Cell[815877, 16792, 453, 14, 21, "Text",ExpressionUUID->"41a7f206-e13a-4409-be36-f56525db8c24",
   Evaluatable->False,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816355, 16810, 300, 6, 24, "Input",ExpressionUUID->"47b9e46a-25c0-4cb3-b662-0d37b89eb12d",
   PageBreakWithin->Automatic,
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
  Cell[816658, 16818, 3305, 74, 365, "Print",ExpressionUUID->"15442f90-5536-464e-8ab9-90af301ef1ce",
   CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}]},
 "Screen"->{
  Cell[820185, 16903, 371, 12, 63, "Section",ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Screen", "focal plane of system", "10.", "Using Screen", "RG10."}],
  Cell[820559, 16917, 735, 20, 38, "Text",ExpressionUUID->"4574287a-8995-4e63-99d6-4237667227af",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821297, 16939, 635, 21, 51, "FramedBox",ExpressionUUID->"cb264467-9607-4491-9e2a-150017352ac3",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821935, 16962, 612, 20, 21, "Text",ExpressionUUID->"4f17e7e8-b7ef-46c4-bbe9-62737fdd5493",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[848676, 17432, 451, 13, 21, "Text",ExpressionUUID->"045101ea-2a75-4098-a7f0-05d2a696de23",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849152, 17449, 310, 7, 24, "Input",ExpressionUUID->"da50deaa-c72e-495c-92e8-001633150ed5",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849465, 17458, 2021, 46, 365, "Print",ExpressionUUID->"a8b69489-f5d3-4bd3-9d7e-48f0bdb29221",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[873840, 18095, 625, 13, 122, "Input",ExpressionUUID->"7e6e0e5e-ff02-4193-8367-bfdbf2f121c1",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
  Cell[874468, 18110, 547, 9, 23, "Output",ExpressionUUID->"5ef2f2a4-82c6-4e09-ba33-6b110c9e82af",
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}]},
 "focal plane of system"->{
  Cell[820185, 16903, 371, 12, 63, "Section",ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Screen", "focal plane of system", "10.", "Using Screen", "RG10."}],
  Cell[820559, 16917, 735, 20, 38, "Text",ExpressionUUID->"4574287a-8995-4e63-99d6-4237667227af",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821297, 16939, 635, 21, 51, "FramedBox",ExpressionUUID->"cb264467-9607-4491-9e2a-150017352ac3",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[821935, 16962, 612, 20, 21, "Text",ExpressionUUID->"4f17e7e8-b7ef-46c4-bbe9-62737fdd5493",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
  Cell[848676, 17432, 451, 13, 21, "Text",ExpressionUUID->"045101ea-2a75-4098-a7f0-05d2a696de23",
   Evaluatable->False,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849152, 17449, 310, 7, 24, "Input",ExpressionUUID->"da50deaa-c72e-495c-92e8-001633150ed5",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[849465, 17458, 2021, 46, 365, "Print",ExpressionUUID->"a8b69489-f5d3-4bd3-9d7e-48f0bdb29221",
   CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
  Cell[873840, 18095, 625, 13, 122, "Input",ExpressionUUID->"7e6e0e5e-ff02-4193-8367-bfdbf2f121c1",
   PageBreakWithin->Automatic,
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
  Cell[874468, 18110, 547, 9, 23, "Output",ExpressionUUID->"5ef2f2a4-82c6-4e09-ba33-6b110c9e82af",
   CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}]},
 "10."->{
  Cell[820185, 16903, 371, 12, 63, "Section",ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Screen", "focal plane of system", "10.", "Using Screen", "RG10."}]},
 "11."->{
  Cell[851708, 17515, 323, 12, 63, "Section",ExpressionUUID->"c348ff48-a54b-4c54-9da9-e9c1ed3d78d5",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ShowRange", "11.", "RG10.", "RG11."}]},
 "12."->{
  Cell[866309, 17830, 314, 12, 63, "Section",ExpressionUUID->"bd0bb247-7bc3-4815-8b2b-9ad91600848b",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ReadRays", "12.", "RG12."}]},
 "InputForm"->{
  Cell[869352, 17935, 290, 10, 21, "Text",ExpressionUUID->"47dff9d5-d9f6-4181-abad-0242b6d5c9ef",
   Evaluatable->False,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[869667, 17949, 209, 4, 24, "Input",ExpressionUUID->"a4c1ace1-3fbb-4027-9df6-3ef68a956e73",
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "InputForm", "RG12."}],
  Cell[869879, 17955, 564, 14, 47, "Output",ExpressionUUID->"79a1d2f7-7f12-4630-9a60-449f5dd8dd21",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   CellTags->{"ReadRays", "InputForm", "RG12."}]},
 "13."->{
  Cell[871416, 18008, 225, 8, 63, "Section",ExpressionUUID->"f16b8b76-3abc-432f-8b79-58f74680382d",
   CellTags->{"PropagateSystem", "13.", "RG13."}]},
 "14."->{
  Cell[876156, 18157, 273, 8, 60, "Section",ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4",
   CellTags->{"TurboPlot", "14.", "14. Introduction", "RG14.", "RG14.0"}]},
 "14. Introduction"->{
  Cell[876156, 18157, 273, 8, 60, "Section",ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4",
   CellTags->{"TurboPlot", "14.", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[877579, 18202, 924, 31, 84, "FramedBox",ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"TurboPlot", "TurboTrace", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[878506, 18235, 1937, 50, 116, "Text",ExpressionUUID->"29a70b22-afb3-4a67-9ca0-396573e8c165",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[880446, 18287, 306, 6, 57, "Input",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc",
   CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"}],
  Cell[880755, 18295, 1503, 38, 85, "Text",ExpressionUUID->"0aa5efea-2314-4787-add1-c1cbe3b2041d",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}]},
 "RG14.0"->{
  Cell[876156, 18157, 273, 8, 60, "Section",ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4",
   CellTags->{"TurboPlot", "14.", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
   Evaluatable->False,
   CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[877579, 18202, 924, 31, 84, "FramedBox",ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"TurboPlot", "TurboTrace", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[878506, 18235, 1937, 50, 116, "Text",ExpressionUUID->"29a70b22-afb3-4a67-9ca0-396573e8c165",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
  Cell[880446, 18287, 306, 6, 57, "Input",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc",
   CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"}],
  Cell[880755, 18295, 1503, 38, 85, "Text",ExpressionUUID->"0aa5efea-2314-4787-add1-c1cbe3b2041d",
   CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}]},
 "TurboTrace"->{
  Cell[877579, 18202, 924, 31, 84, "FramedBox",ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"TurboPlot", "TurboTrace", "14. Introduction", "RG14.", "RG14.0"}]},
 "14.1"->{
  Cell[880446, 18287, 306, 6, 57, "Input",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc",
   CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"}],
  Cell[882496, 18344, 264, 7, 35, "Subsection",ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee",
   CellTags->{"AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[882763, 18353, 524, 14, 34, "Text",ExpressionUUID->"5d45d815-e34a-4638-b9aa-6a2cae8bcc92",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883312, 18371, 207, 2, 24, "Input",ExpressionUUID->"735af2c0-1890-47d1-927f-6c25ec9a3696",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883522, 18375, 22837, 385, 250, "Print",ExpressionUUID->"30129e9c-da09-4b82-99d7-c51a0ba85383",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[906362, 18762, 1112, 30, 36, "Print",ExpressionUUID->"8af346c3-607a-4d3c-b60b-37087ac743cf",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907477, 18794, 440, 8, 24, "Output",ExpressionUUID->"1be6b05a-38ba-4dd0-9c1b-bf8a553810e2",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907932, 18805, 601, 14, 38, "Text",ExpressionUUID->"858724e0-3458-4097-a3ad-5905352e1e8a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908558, 18823, 203, 2, 24, "Input",ExpressionUUID->"4316b42e-16b4-4337-b1d0-5fcbb5018272",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908764, 18827, 19666, 328, 250, "Print",ExpressionUUID->"a775210d-8ac8-4f96-881b-f0406171236d",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928433, 19157, 424, 8, 24, "Output",ExpressionUUID->"2701a2cb-a51f-48fb-8a91-292322a5ed60",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928872, 19168, 2384, 53, 150, "Text",ExpressionUUID->"7563334e-5902-41f8-a1df-a57b98fd95db",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931259, 19223, 288, 6, 57, "Input",ExpressionUUID->"82dd5976-98c4-4850-8129-65296a055626",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931550, 19231, 247, 7, 21, "Text",ExpressionUUID->"8a0d808b-3acd-42e1-8a4e-3cbf9708bab9",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931822, 19242, 294, 8, 24, "Input",ExpressionUUID->"4ba6f6b3-7128-4561-bf3a-51d141ee8235",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[932119, 19252, 13905, 237, 135, "Print",ExpressionUUID->"d17e9029-8a30-4cfd-a2de-1ef7fd95dc7b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946027, 19491, 426, 8, 24, "Output",ExpressionUUID->"0654bc51-0d0e-44fc-9ad4-a4a620076efc",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946468, 19502, 342, 10, 21, "Text",ExpressionUUID->"b6867a6d-2e38-4d9a-8d99-c590923b8370",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946835, 19516, 202, 2, 24, "Input",ExpressionUUID->"dcf9a401-6d74-4dca-b0a9-dbfb831b5a69",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[947040, 19520, 19508, 327, 250, "Print",ExpressionUUID->"17aad0ef-4d85-49dc-8687-7a9910b92579",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966551, 19849, 425, 8, 24, "Output",ExpressionUUID->"19a4ddc9-b309-4657-a005-e419ddaea093",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966991, 19860, 658, 16, 38, "Text",ExpressionUUID->"ba8154d8-97ee-46e3-af97-1bfcda3007ef",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[967652, 19878, 567, 17, 51, "FramedBox",ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968222, 19897, 250, 7, 21, "Text",ExpressionUUID->"584eb23d-c0e4-4cf3-a9f3-f1123ef41b41",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968497, 19908, 280, 6, 24, "Input",ExpressionUUID->"0c4146da-356c-4135-94fc-acd9c4891d21",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968780, 19916, 14063, 238, 135, "Print",ExpressionUUID->"c2262dfd-d7a6-4354-93bc-b64c5143062b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[982846, 20156, 424, 8, 24, "Output",ExpressionUUID->"cd0d7832-4882-42ac-aeec-555723c25398",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[983285, 20167, 899, 20, 54, "Text",ExpressionUUID->"8df57715-fe35-4019-a07d-935cd5a2b382",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984209, 20191, 314, 6, 24, "Input",ExpressionUUID->"c7a7c134-59da-4d2c-9066-7712b50842ab",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984526, 20199, 15065, 256, 136, "Print",ExpressionUUID->"79dbe714-1168-4ff2-a903-f39e4fe98437",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[999594, 20457, 427, 8, 24, "Output",ExpressionUUID->"5c23b081-6025-46f9-8058-23f0ddb28122",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000036, 20468, 462, 12, 38, "Text",ExpressionUUID->"55aa0c10-0f2e-40e5-b147-d90827498dd5",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000501, 20482, 623, 15, 38, "Text",ExpressionUUID->"d1849c45-2f29-4caa-9f87-63d7f316366a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]},
 "AnalyzeSystem versus TurboPlot"->{
  Cell[882496, 18344, 264, 7, 35, "Subsection",ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee",
   CellTags->{"AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", "RG14.1"}]},
 "RG14.1"->{
  Cell[882496, 18344, 264, 7, 35, "Subsection",ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee",
   CellTags->{"AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[882763, 18353, 524, 14, 34, "Text",ExpressionUUID->"5d45d815-e34a-4638-b9aa-6a2cae8bcc92",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883312, 18371, 207, 2, 24, "Input",ExpressionUUID->"735af2c0-1890-47d1-927f-6c25ec9a3696",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[883522, 18375, 22837, 385, 250, "Print",ExpressionUUID->"30129e9c-da09-4b82-99d7-c51a0ba85383",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[906362, 18762, 1112, 30, 36, "Print",ExpressionUUID->"8af346c3-607a-4d3c-b60b-37087ac743cf",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907477, 18794, 440, 8, 24, "Output",ExpressionUUID->"1be6b05a-38ba-4dd0-9c1b-bf8a553810e2",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[907932, 18805, 601, 14, 38, "Text",ExpressionUUID->"858724e0-3458-4097-a3ad-5905352e1e8a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908558, 18823, 203, 2, 24, "Input",ExpressionUUID->"4316b42e-16b4-4337-b1d0-5fcbb5018272",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[908764, 18827, 19666, 328, 250, "Print",ExpressionUUID->"a775210d-8ac8-4f96-881b-f0406171236d",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928433, 19157, 424, 8, 24, "Output",ExpressionUUID->"2701a2cb-a51f-48fb-8a91-292322a5ed60",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[928872, 19168, 2384, 53, 150, "Text",ExpressionUUID->"7563334e-5902-41f8-a1df-a57b98fd95db",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931259, 19223, 288, 6, 57, "Input",ExpressionUUID->"82dd5976-98c4-4850-8129-65296a055626",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931550, 19231, 247, 7, 21, "Text",ExpressionUUID->"8a0d808b-3acd-42e1-8a4e-3cbf9708bab9",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[931822, 19242, 294, 8, 24, "Input",ExpressionUUID->"4ba6f6b3-7128-4561-bf3a-51d141ee8235",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[932119, 19252, 13905, 237, 135, "Print",ExpressionUUID->"d17e9029-8a30-4cfd-a2de-1ef7fd95dc7b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946027, 19491, 426, 8, 24, "Output",ExpressionUUID->"0654bc51-0d0e-44fc-9ad4-a4a620076efc",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946468, 19502, 342, 10, 21, "Text",ExpressionUUID->"b6867a6d-2e38-4d9a-8d99-c590923b8370",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[946835, 19516, 202, 2, 24, "Input",ExpressionUUID->"dcf9a401-6d74-4dca-b0a9-dbfb831b5a69",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[947040, 19520, 19508, 327, 250, "Print",ExpressionUUID->"17aad0ef-4d85-49dc-8687-7a9910b92579",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966551, 19849, 425, 8, 24, "Output",ExpressionUUID->"19a4ddc9-b309-4657-a005-e419ddaea093",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[966991, 19860, 658, 16, 38, "Text",ExpressionUUID->"ba8154d8-97ee-46e3-af97-1bfcda3007ef",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[967652, 19878, 567, 17, 51, "FramedBox",ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968222, 19897, 250, 7, 21, "Text",ExpressionUUID->"584eb23d-c0e4-4cf3-a9f3-f1123ef41b41",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968497, 19908, 280, 6, 24, "Input",ExpressionUUID->"0c4146da-356c-4135-94fc-acd9c4891d21",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[968780, 19916, 14063, 238, 135, "Print",ExpressionUUID->"c2262dfd-d7a6-4354-93bc-b64c5143062b",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[982846, 20156, 424, 8, 24, "Output",ExpressionUUID->"cd0d7832-4882-42ac-aeec-555723c25398",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[983285, 20167, 899, 20, 54, "Text",ExpressionUUID->"8df57715-fe35-4019-a07d-935cd5a2b382",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984209, 20191, 314, 6, 24, "Input",ExpressionUUID->"c7a7c134-59da-4d2c-9066-7712b50842ab",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[984526, 20199, 15065, 256, 136, "Print",ExpressionUUID->"79dbe714-1168-4ff2-a903-f39e4fe98437",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[999594, 20457, 427, 8, 24, "Output",ExpressionUUID->"5c23b081-6025-46f9-8058-23f0ddb28122",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000036, 20468, 462, 12, 38, "Text",ExpressionUUID->"55aa0c10-0f2e-40e5-b147-d90827498dd5",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1000501, 20482, 623, 15, 38, "Text",ExpressionUUID->"d1849c45-2f29-4caa-9f87-63d7f316366a",
   CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]},
 "SymbolicValues"->{
  Cell[967652, 19878, 567, 17, 51, "FramedBox",ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
  Cell[1002193, 20535, 1009, 31, 64, "FramedBox",ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "CreateClones"->{
  Cell[1001374, 20509, 194, 3, 35, "Subsection",ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d",
   CellTags->{"CreateClones", "TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "14.2"->{
  Cell[1001374, 20509, 194, 3, 35, "Subsection",ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d",
   CellTags->{"CreateClones", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1001571, 20514, 619, 19, 38, "Text",ExpressionUUID->"a90ae5b6-7add-4130-878d-cf27bd3d377f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1002193, 20535, 1009, 31, 64, "FramedBox",ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1003205, 20568, 1956, 47, 116, "Text",ExpressionUUID->"f2eb698c-dfad-4527-9f7b-106a2af4bfa3",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005164, 20617, 286, 9, 106, "Input",ExpressionUUID->"3d9f37b8-a9c7-4b91-a648-ad87a2a1e908",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005453, 20628, 325, 10, 21, "Text",ExpressionUUID->"d9110934-fde3-43cf-9643-be18578b550b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005781, 20640, 184, 2, 24, "Input",ExpressionUUID->"1ecb9700-e924-4fa3-bdaf-531de38950d0",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005968, 20644, 489, 15, 34, "Text",ExpressionUUID->"42dc2622-9471-42c3-a3f3-61f3f7d82508",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1006460, 20661, 556, 19, 51, "FramedBox",ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"BallLens", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007019, 20682, 431, 11, 21, "Text",ExpressionUUID->"9242d2d5-8928-426b-b5ac-4a96ee390dbe",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007475, 20697, 347, 6, 57, "Input",ExpressionUUID->"eecc06bf-c7ed-45b9-a4f4-24ee8c6632e7",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007825, 20705, 287, 5, 20, "Print",ExpressionUUID->"61a0f1ab-c69a-45ca-b951-868a02bace37",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008115, 20712, 273, 5, 19, "Print",ExpressionUUID->"b5d7340c-5ec3-4fe7-9d03-09cc88fbe637",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008391, 20719, 403, 9, 20, "Print",ExpressionUUID->"2d34b417-9b1a-4ec2-9bbc-51a827395fef",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008797, 20730, 396, 9, 19, "Print",ExpressionUUID->"194685f5-51ca-400c-ac76-52d433b092e4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1009196, 20741, 155603, 3614, 2712, "Print",ExpressionUUID->"9e5f9dee-8ead-479a-b7ab-b29ca9c88f05",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1164802, 24357, 402, 9, 20, "Print",ExpressionUUID->"5a157a4a-5cd0-4ff8-9446-a9a4d1cf4f63",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165207, 24368, 285, 5, 20, "Print",ExpressionUUID->"a7ac1691-3058-41ef-b826-3e248fce341f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165495, 24375, 592, 13, 20, "Print",ExpressionUUID->"68ed0864-f5f9-4899-9e1d-f86d4eb9da48",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166090, 24390, 294, 5, 20, "Print",ExpressionUUID->"a3c73fa8-cd00-4292-8000-e81065aa2e52",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166387, 24397, 434, 10, 20, "Print",ExpressionUUID->"5e96a7e3-3195-49c5-a721-3e13d8eba6dd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166824, 24409, 299, 5, 20, "Print",ExpressionUUID->"73b92b16-de30-4bf4-8330-439f37608ec1",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167126, 24416, 294, 5, 20, "Print",ExpressionUUID->"116e553e-8c5d-4dc1-a5f3-801621bf9f27",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167423, 24423, 295, 5, 20, "Print",ExpressionUUID->"6276257f-c7ec-4594-ad4f-72208f6b4d0f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167721, 24430, 564, 13, 20, "Print",ExpressionUUID->"5a6866f8-45c9-4989-b288-05184518c8f4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168288, 24445, 280, 5, 20, "Print",ExpressionUUID->"b9cffd6e-5cfc-4fb1-a8d3-92d7bd52cace",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168571, 24452, 291, 5, 20, "Print",ExpressionUUID->"b0d73961-ee2c-4ee2-b8a0-2f0c81abd029",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168865, 24459, 284, 5, 20, "Print",ExpressionUUID->"1ca37af5-a564-4e12-963d-e72507044653",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169152, 24466, 408, 10, 20, "Print",ExpressionUUID->"6b21dd82-13da-49a4-bfcc-1692d2a751f9",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169563, 24478, 470, 12, 20, "Print",ExpressionUUID->"6d322694-d70a-45fe-91ab-4a334dca967d",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170036, 24492, 293, 5, 20, "Print",ExpressionUUID->"2602bd1b-8e54-4f2d-985e-854ee2ebdd2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170332, 24499, 3005, 67, 36, "Print",ExpressionUUID->"24daf8aa-d778-478d-b1bb-3cb981a0470c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173340, 24568, 298, 5, 20, "Print",ExpressionUUID->"dec65d5e-7134-4048-bd69-fcddd67bff86",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173641, 24575, 380, 9, 20, "Print",ExpressionUUID->"5def9516-870b-45c4-bb4d-185c5bf57e2b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174024, 24586, 410, 10, 20, "Print",ExpressionUUID->"569cd10d-ec2f-4e84-b8fa-4bbe68d67c43",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174437, 24598, 285, 5, 20, "Print",ExpressionUUID->"dbc020dc-58c1-450b-987e-0de518fcb018",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174725, 24605, 420, 9, 20, "Print",ExpressionUUID->"06ebf166-0ece-4a92-84a9-2078defc9ffd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175148, 24616, 402, 9, 20, "Print",ExpressionUUID->"4a173113-385f-46f7-9c3d-0b055bbb25e5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175553, 24627, 406, 9, 20, "Print",ExpressionUUID->"931ebe39-1913-4ea1-a5d6-0c9aefc4d074",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175962, 24638, 271, 5, 20, "Print",ExpressionUUID->"fc7c54b5-8308-460e-a42b-d07ec905a15a",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176236, 24645, 434, 10, 20, "Print",ExpressionUUID->"4060f68c-4778-4814-9ce7-8d1f7fd45431",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176673, 24657, 608, 14, 20, "Print",ExpressionUUID->"c2df0822-6d87-4e5a-bdfe-fdb1e7570704",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1177284, 24673, 775, 15, 22, "Message",ExpressionUUID->"d47b94fb-92d1-4460-93e6-ffdef0044a62",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178062, 24690, 442, 10, 20, "Print",ExpressionUUID->"372e005e-ae85-45d5-b357-dccdbfec3b2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178507, 24702, 730, 15, 20, "Print",ExpressionUUID->"2444f75e-2c81-4fc8-bcee-98bc3bccbf99",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179240, 24719, 306, 6, 20, "Print",ExpressionUUID->"cde16d7f-25f9-49c2-8d01-9591f38344b8",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179549, 24727, 282, 5, 20, "Print",ExpressionUUID->"1939d258-9116-4640-8d0a-a8e388c1c894",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179834, 24734, 286, 5, 20, "Print",ExpressionUUID->"30244d4b-b1f1-4417-a269-c577adbf4778",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180123, 24741, 279, 5, 20, "Print",ExpressionUUID->"3b6f39ab-476c-4aeb-8ace-ef042b612aa2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180405, 24748, 304, 6, 20, "Print",ExpressionUUID->"372b9b9a-5013-4ebb-9371-b8c7809d5a85",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180712, 24756, 304, 6, 20, "Print",ExpressionUUID->"ccdfd2bb-c013-42e4-99bb-9aab14e88f10",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181019, 24764, 304, 6, 20, "Print",ExpressionUUID->"07c418d1-350c-47f1-b1a3-2dbcf1f4738c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181326, 24772, 304, 6, 20, "Print",ExpressionUUID->"c9a2bb0f-da80-40ea-8eaa-0a1efb0c580f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181633, 24780, 281, 5, 20, "Print",ExpressionUUID->"63686a72-2217-4f16-b1dc-3b9f396962c5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181917, 24787, 293, 5, 20, "Print",ExpressionUUID->"830aa83c-4800-4bb1-8ca2-22aff9582db6",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182213, 24794, 279, 5, 20, "Print",ExpressionUUID->"1ed4033f-5589-4337-a159-deb93b7ea346",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182495, 24801, 1129508, 18866, 341, "Print",ExpressionUUID->"fdb36d72-ab79-4189-a843-7506cad40be2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2312018, 43670, 1213, 33, 70, "Text",ExpressionUUID->"9c4ed069-1dcb-4b31-b3b4-de62ad8e215e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313234, 43705, 288, 8, 21, "Text",ExpressionUUID->"0d7d4221-ebf2-4a36-a888-5a1eb445b649",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2314769, 43760, 490, 15, 34, "Text",ExpressionUUID->"e2766717-50f1-411a-8db8-c3dba15ad878",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "RG14.2"->{
  Cell[1001374, 20509, 194, 3, 35, "Subsection",ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d",
   CellTags->{"CreateClones", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1001571, 20514, 619, 19, 38, "Text",ExpressionUUID->"a90ae5b6-7add-4130-878d-cf27bd3d377f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1002193, 20535, 1009, 31, 64, "FramedBox",ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SymbolicValues", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1003205, 20568, 1956, 47, 116, "Text",ExpressionUUID->"f2eb698c-dfad-4527-9f7b-106a2af4bfa3",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005164, 20617, 286, 9, 106, "Input",ExpressionUUID->"3d9f37b8-a9c7-4b91-a648-ad87a2a1e908",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005453, 20628, 325, 10, 21, "Text",ExpressionUUID->"d9110934-fde3-43cf-9643-be18578b550b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005781, 20640, 184, 2, 24, "Input",ExpressionUUID->"1ecb9700-e924-4fa3-bdaf-531de38950d0",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1005968, 20644, 489, 15, 34, "Text",ExpressionUUID->"42dc2622-9471-42c3-a3f3-61f3f7d82508",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1006460, 20661, 556, 19, 51, "FramedBox",ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"BallLens", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007019, 20682, 431, 11, 21, "Text",ExpressionUUID->"9242d2d5-8928-426b-b5ac-4a96ee390dbe",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007475, 20697, 347, 6, 57, "Input",ExpressionUUID->"eecc06bf-c7ed-45b9-a4f4-24ee8c6632e7",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1007825, 20705, 287, 5, 20, "Print",ExpressionUUID->"61a0f1ab-c69a-45ca-b951-868a02bace37",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008115, 20712, 273, 5, 19, "Print",ExpressionUUID->"b5d7340c-5ec3-4fe7-9d03-09cc88fbe637",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008391, 20719, 403, 9, 20, "Print",ExpressionUUID->"2d34b417-9b1a-4ec2-9bbc-51a827395fef",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1008797, 20730, 396, 9, 19, "Print",ExpressionUUID->"194685f5-51ca-400c-ac76-52d433b092e4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1009196, 20741, 155603, 3614, 2712, "Print",ExpressionUUID->"9e5f9dee-8ead-479a-b7ab-b29ca9c88f05",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1164802, 24357, 402, 9, 20, "Print",ExpressionUUID->"5a157a4a-5cd0-4ff8-9446-a9a4d1cf4f63",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165207, 24368, 285, 5, 20, "Print",ExpressionUUID->"a7ac1691-3058-41ef-b826-3e248fce341f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1165495, 24375, 592, 13, 20, "Print",ExpressionUUID->"68ed0864-f5f9-4899-9e1d-f86d4eb9da48",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166090, 24390, 294, 5, 20, "Print",ExpressionUUID->"a3c73fa8-cd00-4292-8000-e81065aa2e52",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166387, 24397, 434, 10, 20, "Print",ExpressionUUID->"5e96a7e3-3195-49c5-a721-3e13d8eba6dd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1166824, 24409, 299, 5, 20, "Print",ExpressionUUID->"73b92b16-de30-4bf4-8330-439f37608ec1",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167126, 24416, 294, 5, 20, "Print",ExpressionUUID->"116e553e-8c5d-4dc1-a5f3-801621bf9f27",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167423, 24423, 295, 5, 20, "Print",ExpressionUUID->"6276257f-c7ec-4594-ad4f-72208f6b4d0f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1167721, 24430, 564, 13, 20, "Print",ExpressionUUID->"5a6866f8-45c9-4989-b288-05184518c8f4",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168288, 24445, 280, 5, 20, "Print",ExpressionUUID->"b9cffd6e-5cfc-4fb1-a8d3-92d7bd52cace",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168571, 24452, 291, 5, 20, "Print",ExpressionUUID->"b0d73961-ee2c-4ee2-b8a0-2f0c81abd029",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1168865, 24459, 284, 5, 20, "Print",ExpressionUUID->"1ca37af5-a564-4e12-963d-e72507044653",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169152, 24466, 408, 10, 20, "Print",ExpressionUUID->"6b21dd82-13da-49a4-bfcc-1692d2a751f9",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1169563, 24478, 470, 12, 20, "Print",ExpressionUUID->"6d322694-d70a-45fe-91ab-4a334dca967d",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170036, 24492, 293, 5, 20, "Print",ExpressionUUID->"2602bd1b-8e54-4f2d-985e-854ee2ebdd2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1170332, 24499, 3005, 67, 36, "Print",ExpressionUUID->"24daf8aa-d778-478d-b1bb-3cb981a0470c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173340, 24568, 298, 5, 20, "Print",ExpressionUUID->"dec65d5e-7134-4048-bd69-fcddd67bff86",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1173641, 24575, 380, 9, 20, "Print",ExpressionUUID->"5def9516-870b-45c4-bb4d-185c5bf57e2b",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174024, 24586, 410, 10, 20, "Print",ExpressionUUID->"569cd10d-ec2f-4e84-b8fa-4bbe68d67c43",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174437, 24598, 285, 5, 20, "Print",ExpressionUUID->"dbc020dc-58c1-450b-987e-0de518fcb018",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1174725, 24605, 420, 9, 20, "Print",ExpressionUUID->"06ebf166-0ece-4a92-84a9-2078defc9ffd",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175148, 24616, 402, 9, 20, "Print",ExpressionUUID->"4a173113-385f-46f7-9c3d-0b055bbb25e5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175553, 24627, 406, 9, 20, "Print",ExpressionUUID->"931ebe39-1913-4ea1-a5d6-0c9aefc4d074",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1175962, 24638, 271, 5, 20, "Print",ExpressionUUID->"fc7c54b5-8308-460e-a42b-d07ec905a15a",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176236, 24645, 434, 10, 20, "Print",ExpressionUUID->"4060f68c-4778-4814-9ce7-8d1f7fd45431",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1176673, 24657, 608, 14, 20, "Print",ExpressionUUID->"c2df0822-6d87-4e5a-bdfe-fdb1e7570704",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1177284, 24673, 775, 15, 22, "Message",ExpressionUUID->"d47b94fb-92d1-4460-93e6-ffdef0044a62",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178062, 24690, 442, 10, 20, "Print",ExpressionUUID->"372e005e-ae85-45d5-b357-dccdbfec3b2e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1178507, 24702, 730, 15, 20, "Print",ExpressionUUID->"2444f75e-2c81-4fc8-bcee-98bc3bccbf99",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179240, 24719, 306, 6, 20, "Print",ExpressionUUID->"cde16d7f-25f9-49c2-8d01-9591f38344b8",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179549, 24727, 282, 5, 20, "Print",ExpressionUUID->"1939d258-9116-4640-8d0a-a8e388c1c894",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1179834, 24734, 286, 5, 20, "Print",ExpressionUUID->"30244d4b-b1f1-4417-a269-c577adbf4778",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180123, 24741, 279, 5, 20, "Print",ExpressionUUID->"3b6f39ab-476c-4aeb-8ace-ef042b612aa2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180405, 24748, 304, 6, 20, "Print",ExpressionUUID->"372b9b9a-5013-4ebb-9371-b8c7809d5a85",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1180712, 24756, 304, 6, 20, "Print",ExpressionUUID->"ccdfd2bb-c013-42e4-99bb-9aab14e88f10",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181019, 24764, 304, 6, 20, "Print",ExpressionUUID->"07c418d1-350c-47f1-b1a3-2dbcf1f4738c",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181326, 24772, 304, 6, 20, "Print",ExpressionUUID->"c9a2bb0f-da80-40ea-8eaa-0a1efb0c580f",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181633, 24780, 281, 5, 20, "Print",ExpressionUUID->"63686a72-2217-4f16-b1dc-3b9f396962c5",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1181917, 24787, 293, 5, 20, "Print",ExpressionUUID->"830aa83c-4800-4bb1-8ca2-22aff9582db6",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182213, 24794, 279, 5, 20, "Print",ExpressionUUID->"1ed4033f-5589-4337-a159-deb93b7ea346",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[1182495, 24801, 1129508, 18866, 341, "Print",ExpressionUUID->"fdb36d72-ab79-4189-a843-7506cad40be2",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2312018, 43670, 1213, 33, 70, "Text",ExpressionUUID->"9c4ed069-1dcb-4b31-b3b4-de62ad8e215e",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313234, 43705, 288, 8, 21, "Text",ExpressionUUID->"0d7d4221-ebf2-4a36-a888-5a1eb445b649",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
  Cell[2314769, 43760, 490, 15, 34, "Text",ExpressionUUID->"e2766717-50f1-411a-8db8-c3dba15ad878",
   CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "BallLens"->{
  Cell[1006460, 20661, 556, 19, 51, "FramedBox",ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"BallLens", "TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "ShowClones"->{
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "ShowArrows"->{
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "RunningCommentary"->{
  Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}]},
 "15."->{
  Cell[2315521, 43788, 219, 7, 60, "Section",ExpressionUUID->"5c62ed6d-b544-44e0-affc-dcff777c52d7",
   CellTags->{"OptimizeSystem", "15.", "RG15."}]},
 "SphericalLens"->{
  Cell[2317543, 43850, 825, 34, 51, "FramedBox",ExpressionUUID->"464f8f91-b6db-4961-a243-0eaa5ee35b2f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"SphericalLens", "OptimizeSystem", "RG15."}]},
 "16."->{
  Cell[2345980, 44453, 369, 14, 60, "Section",ExpressionUUID->"e91ead7e-40a8-487a-bf8c-0484bf29162e",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"ReadTurboRays", "16.", "RG16."}]},
 "17."->{
  Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
   CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}]},
 "17. Introduction"->{
  Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
   CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352216, 44673, 489, 12, 37, "Text",ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352708, 44687, 756, 26, 51, "FramedBox",ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2353467, 44715, 1670, 50, 70, "Text",ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}]},
 "RG17.1"->{
  Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
   CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352216, 44673, 489, 12, 37, "Text",ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352708, 44687, 756, 26, 51, "FramedBox",ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2353467, 44715, 1670, 50, 70, "Text",ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2355140, 44767, 224, 5, 20, "Text",ExpressionUUID->"20a964d3-7fe5-429c-a9f8-92f8d718eb4d",
   CellTags->{"FindIntensity", "RG17.", "RG17.1"}],
  Cell[2355389, 44776, 318, 7, 35, "Subsection",ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", "17.1"}],
  Cell[2355710, 44785, 860, 19, 51, "Text",ExpressionUUID->"3309fe78-8bea-41d2-9e89-be26e8481dcc",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356595, 44808, 330, 8, 73, "Input",ExpressionUUID->"047766fb-8eda-427a-9c3e-35823ea5836e",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356928, 44818, 964, 22, 20, "Print",ExpressionUUID->"0de2e702-472d-4a7d-a33a-128938072ae6",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2357895, 44842, 323025, 5562, 296, "Print",ExpressionUUID->"eeabf9da-4b78-4217-9378-83252c32fedd",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2680923, 50406, 333374, 5584, 131, "Output",ExpressionUUID->"1c035b97-c43f-4851-8b25-054d8a319820",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3014312, 55993, 1281, 31, 72, "Text",ExpressionUUID->"61fe767f-feb3-477a-a22f-08ad310cb74c",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015596, 56026, 284, 7, 21, "Text",ExpressionUUID->"9f08fe51-ea3c-4aaa-9cef-8c9e59b7d550",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015905, 56037, 253, 7, 24, "Input",ExpressionUUID->"6c99f091-180f-479e-a164-578479e304a5",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3016161, 56046, 2360, 47, 104, "Output",ExpressionUUID->"af9e7bec-c4e9-4c06-977f-2f278dbbb732",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018536, 56096, 356, 8, 21, "Text",ExpressionUUID->"cc3b45c7-e4f3-4e3c-b46f-6d6e177fe337",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018895, 56106, 904, 25, 114, "FramedBox",ExpressionUUID->"46cb697f-b80f-4d01-bd6c-4876a42ca360",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3019802, 56133, 283, 8, 27, "Commentary",ExpressionUUID->"c67f89f6-560d-495a-8599-39f4b27400df",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020088, 56143, 292, 6, 20, "Text",ExpressionUUID->"e5a6054d-dd48-4061-bcbb-f0b7a1201f9a",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020383, 56151, 396, 9, 21, "Text",ExpressionUUID->"acbccdd9-b6e4-4445-8c63-5d21e8a43520",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020782, 56162, 911, 25, 100, "FramedBox",ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021696, 56189, 257, 8, 27, "Commentary",ExpressionUUID->"7831497e-8aba-4284-b96e-49915e0b2651",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021956, 56199, 756, 18, 51, "Text",ExpressionUUID->"b637b49d-dc30-4a08-809d-bb46795dbf59",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022737, 56221, 234, 3, 24, "Input",ExpressionUUID->"1b065470-deed-4044-8680-13146f928883",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022974, 56226, 731153, 12157, 371, "Print",ExpressionUUID->"2c1a3fe1-f530-44e5-ad59-dc837b0018fa",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}]},
 "RG17.0"->{
  Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
   CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352216, 44673, 489, 12, 37, "Text",ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2352708, 44687, 756, 26, 51, "FramedBox",ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
  Cell[2353467, 44715, 1670, 50, 70, "Text",ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0",
   CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}]},
 "2-D Calculations with FindIntensity"->{
  Cell[2355389, 44776, 318, 7, 35, "Subsection",ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", "17.1"}],
  Cell[2355710, 44785, 860, 19, 51, "Text",ExpressionUUID->"3309fe78-8bea-41d2-9e89-be26e8481dcc",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356595, 44808, 330, 8, 73, "Input",ExpressionUUID->"047766fb-8eda-427a-9c3e-35823ea5836e",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2356928, 44818, 964, 22, 20, "Print",ExpressionUUID->"0de2e702-472d-4a7d-a33a-128938072ae6",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2357895, 44842, 323025, 5562, 296, "Print",ExpressionUUID->"eeabf9da-4b78-4217-9378-83252c32fedd",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[2680923, 50406, 333374, 5584, 131, "Output",ExpressionUUID->"1c035b97-c43f-4851-8b25-054d8a319820",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3014312, 55993, 1281, 31, 72, "Text",ExpressionUUID->"61fe767f-feb3-477a-a22f-08ad310cb74c",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015596, 56026, 284, 7, 21, "Text",ExpressionUUID->"9f08fe51-ea3c-4aaa-9cef-8c9e59b7d550",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3015905, 56037, 253, 7, 24, "Input",ExpressionUUID->"6c99f091-180f-479e-a164-578479e304a5",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3016161, 56046, 2360, 47, 104, "Output",ExpressionUUID->"af9e7bec-c4e9-4c06-977f-2f278dbbb732",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018536, 56096, 356, 8, 21, "Text",ExpressionUUID->"cc3b45c7-e4f3-4e3c-b46f-6d6e177fe337",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3018895, 56106, 904, 25, 114, "FramedBox",ExpressionUUID->"46cb697f-b80f-4d01-bd6c-4876a42ca360",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3019802, 56133, 283, 8, 27, "Commentary",ExpressionUUID->"c67f89f6-560d-495a-8599-39f4b27400df",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020088, 56143, 292, 6, 20, "Text",ExpressionUUID->"e5a6054d-dd48-4061-bcbb-f0b7a1201f9a",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020383, 56151, 396, 9, 21, "Text",ExpressionUUID->"acbccdd9-b6e4-4445-8c63-5d21e8a43520",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3020782, 56162, 911, 25, 100, "FramedBox",ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021696, 56189, 257, 8, 27, "Commentary",ExpressionUUID->"7831497e-8aba-4284-b96e-49915e0b2651",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3021956, 56199, 756, 18, 51, "Text",ExpressionUUID->"b637b49d-dc30-4a08-809d-bb46795dbf59",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022737, 56221, 234, 3, 24, "Input",ExpressionUUID->"1b065470-deed-4044-8680-13146f928883",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[3022974, 56226, 731153, 12157, 371, "Print",ExpressionUUID->"2c1a3fe1-f530-44e5-ad59-dc837b0018fa",
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}]},
 "17.1"->{
  Cell[2355389, 44776, 318, 7, 35, "Subsection",ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", "17.1"}]},
 "Plot2D"->{
  Cell[3020782, 56162, 911, 25, 100, "FramedBox",ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
  Cell[7483770, 131958, 1382, 42, 133, "FramedBox",ExpressionUUID->"3c2399ec-fba3-40b1-99e9-e62ae314b455",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"Plot2D", "Database", "RG19."}]},
 "FindFocus"->{
  Cell[3754393, 68396, 266, 7, 35, "Subsection",ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2", "17.2"}],
  Cell[3754662, 68405, 967, 20, 67, "Text",ExpressionUUID->"1e979e95-2969-4469-bdb2-4b4c0c51ff29",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3755654, 68429, 353, 7, 73, "Input",ExpressionUUID->"bf84e43a-fae7-473b-aa4b-b5e31a85f037",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3756010, 68438, 23625, 395, 213, "Print",ExpressionUUID->"b3b339b6-d05a-4a26-9fcc-fc53d96f9d15",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3779650, 68836, 420, 10, 21, "Text",ExpressionUUID->"f5f2213a-8c67-4cc7-a6e0-6cc3d95ece0b",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780073, 68848, 796, 28, 51, "FramedBox",ExpressionUUID->"a33391f6-588e-4017-94b4-c9b65311d253",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780872, 68878, 471, 12, 34, "Text",ExpressionUUID->"72ac0498-3b0e-4219-8bae-6f4e17c2f6fa",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781368, 68894, 182, 2, 24, "Input",ExpressionUUID->"9f4a8b78-0096-4924-824c-df2fc5d1f38e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781553, 68898, 21105, 421, 354, "Print",ExpressionUUID->"16d21f8f-ecc7-4ca0-8326-e017183ba907",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3802661, 69321, 1326, 31, 56, "Output",ExpressionUUID->"8a13b68c-4edf-455a-bfd8-08aa9b5a8063",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3804002, 69355, 1004, 26, 54, "Text",ExpressionUUID->"ef728d99-f6af-4701-821f-7667055c288e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805031, 69385, 188, 2, 24, "Input",ExpressionUUID->"d1fc3e93-d0bb-4abd-abbd-f079d7dd2d57",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805222, 69389, 378, 6, 23, "Output",ExpressionUUID->"591b7135-4c02-4d42-8df1-963cbf3dd8a1",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}]},
 "RG17.2"->{
  Cell[3754393, 68396, 266, 7, 35, "Subsection",ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2", "17.2"}],
  Cell[3754662, 68405, 967, 20, 67, "Text",ExpressionUUID->"1e979e95-2969-4469-bdb2-4b4c0c51ff29",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3755654, 68429, 353, 7, 73, "Input",ExpressionUUID->"bf84e43a-fae7-473b-aa4b-b5e31a85f037",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3756010, 68438, 23625, 395, 213, "Print",ExpressionUUID->"b3b339b6-d05a-4a26-9fcc-fc53d96f9d15",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3779650, 68836, 420, 10, 21, "Text",ExpressionUUID->"f5f2213a-8c67-4cc7-a6e0-6cc3d95ece0b",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780073, 68848, 796, 28, 51, "FramedBox",ExpressionUUID->"a33391f6-588e-4017-94b4-c9b65311d253",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3780872, 68878, 471, 12, 34, "Text",ExpressionUUID->"72ac0498-3b0e-4219-8bae-6f4e17c2f6fa",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781368, 68894, 182, 2, 24, "Input",ExpressionUUID->"9f4a8b78-0096-4924-824c-df2fc5d1f38e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3781553, 68898, 21105, 421, 354, "Print",ExpressionUUID->"16d21f8f-ecc7-4ca0-8326-e017183ba907",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3802661, 69321, 1326, 31, 56, "Output",ExpressionUUID->"8a13b68c-4edf-455a-bfd8-08aa9b5a8063",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3804002, 69355, 1004, 26, 54, "Text",ExpressionUUID->"ef728d99-f6af-4701-821f-7667055c288e",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805031, 69385, 188, 2, 24, "Input",ExpressionUUID->"d1fc3e93-d0bb-4abd-abbd-f079d7dd2d57",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
  Cell[3805222, 69389, 378, 6, 23, "Output",ExpressionUUID->"591b7135-4c02-4d42-8df1-963cbf3dd8a1",
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}]},
 "17.2"->{
  Cell[3754393, 68396, 266, 7, 35, "Subsection",ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2", "17.2"}]},
 "RG17.3"->{
  Cell[3805866, 69408, 312, 8, 35, "Subsection",ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "17.3", "Point Spread Function (PSF)"}],
  Cell[3806181, 69418, 458, 13, 21, "Text",ExpressionUUID->"7ee32d46-f354-4350-98ce-745d5fe62fb5",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3806664, 69435, 397, 8, 89, "Input",ExpressionUUID->"03f38441-916b-4472-a72f-cebe22f1de4b",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3807064, 69445, 963, 21, 20, "Print",ExpressionUUID->"a389c04a-1214-4a12-9503-59d753754c5f",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3808030, 69468, 1039597, 17914, 280, "Print",ExpressionUUID->"9e219fa5-0d2f-4a98-8336-e967b4266678",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[4847630, 87384, 1068108, 17936, 114, "Output",ExpressionUUID->"faea0d3b-afe1-4883-b972-798f0b1cc126",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5915753, 105323, 522, 14, 34, "Text",ExpressionUUID->"41ceb80e-2181-4cd7-b774-e47b379c16d3",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916300, 105341, 222, 2, 24, "Input",ExpressionUUID->"4bb39fd2-06ac-4850-8973-a84b4945ffe4",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916525, 105345, 956, 21, 20, "Print",ExpressionUUID->"e31d0700-a56e-4a47-9922-4c9df4642880",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5917484, 105368, 66039, 1197, 249, "Print",ExpressionUUID->"e24be2f9-c5d4-481a-b7cb-42d643c4e308",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5983538, 106568, 1774, 36, 119, "Text",ExpressionUUID->"6a8298d3-cd1c-4426-ba27-6e0e9d9c4ef0",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5985315, 106606, 1303, 53, 64, "FramedBox",ExpressionUUID->"383b92d9-bb1f-4fa8-9b79-4d97513a96de",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5986621, 106661, 468, 15, 21, "Text",ExpressionUUID->"8f2a8809-ca0e-424e-b3dd-02b65ee36fc7",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5987092, 106678, 919, 35, 51, "FramedBox",ExpressionUUID->"de33a8b9-bafc-4dc0-a878-7ae11c86ac7a",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5988014, 106715, 992, 30, 38, "Text",ExpressionUUID->"b6b2e779-1a5b-4ed1-b908-aea9d02a4f32",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}]},
 "17.3"->{
  Cell[3805866, 69408, 312, 8, 35, "Subsection",ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "17.3", "Point Spread Function (PSF)"}]},
 "Point Spread Function (PSF)"->{
  Cell[3805866, 69408, 312, 8, 35, "Subsection",ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "17.3", "Point Spread Function (PSF)"}],
  Cell[3806181, 69418, 458, 13, 21, "Text",ExpressionUUID->"7ee32d46-f354-4350-98ce-745d5fe62fb5",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3806664, 69435, 397, 8, 89, "Input",ExpressionUUID->"03f38441-916b-4472-a72f-cebe22f1de4b",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3807064, 69445, 963, 21, 20, "Print",ExpressionUUID->"a389c04a-1214-4a12-9503-59d753754c5f",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[3808030, 69468, 1039597, 17914, 280, "Print",ExpressionUUID->"9e219fa5-0d2f-4a98-8336-e967b4266678",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[4847630, 87384, 1068108, 17936, 114, "Output",ExpressionUUID->"faea0d3b-afe1-4883-b972-798f0b1cc126",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5915753, 105323, 522, 14, 34, "Text",ExpressionUUID->"41ceb80e-2181-4cd7-b774-e47b379c16d3",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916300, 105341, 222, 2, 24, "Input",ExpressionUUID->"4bb39fd2-06ac-4850-8973-a84b4945ffe4",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5916525, 105345, 956, 21, 20, "Print",ExpressionUUID->"e31d0700-a56e-4a47-9922-4c9df4642880",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5917484, 105368, 66039, 1197, 249, "Print",ExpressionUUID->"e24be2f9-c5d4-481a-b7cb-42d643c4e308",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5983538, 106568, 1774, 36, 119, "Text",ExpressionUUID->"6a8298d3-cd1c-4426-ba27-6e0e9d9c4ef0",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5985315, 106606, 1303, 53, 64, "FramedBox",ExpressionUUID->"383b92d9-bb1f-4fa8-9b79-4d97513a96de",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5986621, 106661, 468, 15, 21, "Text",ExpressionUUID->"8f2a8809-ca0e-424e-b3dd-02b65ee36fc7",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5987092, 106678, 919, 35, 51, "FramedBox",ExpressionUUID->"de33a8b9-bafc-4dc0-a878-7ae11c86ac7a",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
  Cell[5988014, 106715, 992, 30, 38, "Text",ExpressionUUID->"b6b2e779-1a5b-4ed1-b908-aea9d02a4f32",
   CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}]},
 "ModulationTransferFunction"->{
  Cell[5989260, 106757, 316, 7, 35, "Subsection",ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", "17.4"}],
  Cell[5989579, 106766, 469, 12, 38, "Text",ExpressionUUID->"30c801a3-37d5-4911-b3a1-d9d387a5f414",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5990051, 106780, 730, 23, 51, "FramedBox",ExpressionUUID->"9c0d1061-6d13-4c39-8a38-fc416aeca7f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4"}],
  Cell[5990784, 106805, 551, 13, 34, "Text",ExpressionUUID->"86795780-c101-4bd7-81de-63e3b9e5d003",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991360, 106822, 212, 3, 24, "Input",ExpressionUUID->"69d700c4-c02f-46db-91df-f1f4ad496ccd",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991575, 106827, 1277, 28, 56, "Output",ExpressionUUID->"b3e7fbc4-8c5c-4773-8b21-2c1f50002099",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5992889, 106860, 219, 3, 24, "Input",ExpressionUUID->"05011727-66ba-42d7-9311-76ce95abffd2",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5993111, 106865, 34653, 618, 242, "Print",ExpressionUUID->"532b389b-e46b-494e-850f-5801f1dd3eb4",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[6027767, 107485, 1134284, 18596, 192, "Output",ExpressionUUID->"8b30f9f8-5631-422e-a696-d65c329e250a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162066, 126084, 766, 18, 51, "Text",ExpressionUUID->"97450984-6a0c-4acf-9174-51e10e28d20a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162835, 126104, 244, 5, 20, "Text",ExpressionUUID->"8381b864-31bc-46c1-8f73-17774d620556",
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17."}]},
 "RG17.4"->{
  Cell[5989260, 106757, 316, 7, 35, "Subsection",ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", "17.4"}],
  Cell[5989579, 106766, 469, 12, 38, "Text",ExpressionUUID->"30c801a3-37d5-4911-b3a1-d9d387a5f414",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5990051, 106780, 730, 23, 51, "FramedBox",ExpressionUUID->"9c0d1061-6d13-4c39-8a38-fc416aeca7f4",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4"}],
  Cell[5990784, 106805, 551, 13, 34, "Text",ExpressionUUID->"86795780-c101-4bd7-81de-63e3b9e5d003",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991360, 106822, 212, 3, 24, "Input",ExpressionUUID->"69d700c4-c02f-46db-91df-f1f4ad496ccd",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5991575, 106827, 1277, 28, 56, "Output",ExpressionUUID->"b3e7fbc4-8c5c-4773-8b21-2c1f50002099",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5992889, 106860, 219, 3, 24, "Input",ExpressionUUID->"05011727-66ba-42d7-9311-76ce95abffd2",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[5993111, 106865, 34653, 618, 242, "Print",ExpressionUUID->"532b389b-e46b-494e-850f-5801f1dd3eb4",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[6027767, 107485, 1134284, 18596, 192, "Output",ExpressionUUID->"8b30f9f8-5631-422e-a696-d65c329e250a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
  Cell[7162066, 126084, 766, 18, 51, "Text",ExpressionUUID->"97450984-6a0c-4acf-9174-51e10e28d20a",
   CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}]},
 "17.4"->{
  Cell[5989260, 106757, 316, 7, 35, "Subsection",ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", "17.4"}]},
 "1-D Calculations with FindIntensity"->{
  Cell[7163116, 126114, 318, 7, 35, "Subsection",ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", "17.5"}],
  Cell[7163437, 126123, 529, 12, 38, "Text",ExpressionUUID->"34623c4b-fe27-43e8-bd53-4b5427b399dd",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7163991, 126139, 403, 9, 73, "Input",ExpressionUUID->"fb3f9c9b-3e34-4d0e-ab34-9367873467c2",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7164397, 126150, 15205, 257, 216, "Print",ExpressionUUID->"73e948d6-1694-44b4-ae7d-aa818ce26431",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7179617, 126410, 1060, 22, 67, "Text",ExpressionUUID->"f8f0bdcf-fab1-40be-95b1-7e144ffe3c6c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7180702, 126436, 585, 13, 89, "Input",ExpressionUUID->"5edc0363-6e09-425e-a719-e41a4ce3275a",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7181290, 126451, 1017, 23, 20, "Print",ExpressionUUID->"2838a744-8620-4e26-a900-a8328ac1c274",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7182310, 126476, 40684, 723, 249, "Print",ExpressionUUID->"2f268b14-14d8-48a5-a7eb-687acda3458f",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7222997, 127201, 1020, 23, 20, "Print",ExpressionUUID->"3e3c72dd-d769-434f-b710-2079c05b91f7",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7224020, 127226, 53528, 952, 249, "Print",ExpressionUUID->"a296cdfd-0141-441f-98aa-ef27a78ddd7c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7277551, 128180, 101438, 1706, 301, "Output",ExpressionUUID->"a1a52898-e5e7-40a2-bad0-b10bb386556d",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379004, 129889, 958, 24, 54, "Text",ExpressionUUID->"3dd53550-bd89-4434-8178-b4bdb23c4c00",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379965, 129915, 534, 14, 38, "Text",ExpressionUUID->"d70a31c8-3057-42e4-ad73-12b52a878b1c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380524, 129933, 245, 6, 24, "Input",ExpressionUUID->"9588485b-e6e9-491f-baef-c7d69029eba3",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380772, 129941, 422, 8, 20, "Print",ExpressionUUID->"409ae0e2-9603-42ba-980c-4a24dcf7d5df",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381197, 129951, 338, 5, 23, "Output",ExpressionUUID->"de6bc496-b575-462e-bc44-25ac8b5a9211",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381550, 129959, 1382, 20, 85, "Text",ExpressionUUID->"f22e5175-9749-47ac-b69b-4446723b94d5",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7382935, 129981, 253, 5, 20, "Text",ExpressionUUID->"c605f174-ab57-4738-8b7a-88a1e288edac",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17."}]},
 "RG17.5"->{
  Cell[7163116, 126114, 318, 7, 35, "Subsection",ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", "17.5"}],
  Cell[7163437, 126123, 529, 12, 38, "Text",ExpressionUUID->"34623c4b-fe27-43e8-bd53-4b5427b399dd",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7163991, 126139, 403, 9, 73, "Input",ExpressionUUID->"fb3f9c9b-3e34-4d0e-ab34-9367873467c2",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7164397, 126150, 15205, 257, 216, "Print",ExpressionUUID->"73e948d6-1694-44b4-ae7d-aa818ce26431",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7179617, 126410, 1060, 22, 67, "Text",ExpressionUUID->"f8f0bdcf-fab1-40be-95b1-7e144ffe3c6c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7180702, 126436, 585, 13, 89, "Input",ExpressionUUID->"5edc0363-6e09-425e-a719-e41a4ce3275a",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7181290, 126451, 1017, 23, 20, "Print",ExpressionUUID->"2838a744-8620-4e26-a900-a8328ac1c274",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7182310, 126476, 40684, 723, 249, "Print",ExpressionUUID->"2f268b14-14d8-48a5-a7eb-687acda3458f",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7222997, 127201, 1020, 23, 20, "Print",ExpressionUUID->"3e3c72dd-d769-434f-b710-2079c05b91f7",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7224020, 127226, 53528, 952, 249, "Print",ExpressionUUID->"a296cdfd-0141-441f-98aa-ef27a78ddd7c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7277551, 128180, 101438, 1706, 301, "Output",ExpressionUUID->"a1a52898-e5e7-40a2-bad0-b10bb386556d",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379004, 129889, 958, 24, 54, "Text",ExpressionUUID->"3dd53550-bd89-4434-8178-b4bdb23c4c00",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7379965, 129915, 534, 14, 38, "Text",ExpressionUUID->"d70a31c8-3057-42e4-ad73-12b52a878b1c",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380524, 129933, 245, 6, 24, "Input",ExpressionUUID->"9588485b-e6e9-491f-baef-c7d69029eba3",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7380772, 129941, 422, 8, 20, "Print",ExpressionUUID->"409ae0e2-9603-42ba-980c-4a24dcf7d5df",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381197, 129951, 338, 5, 23, "Output",ExpressionUUID->"de6bc496-b575-462e-bc44-25ac8b5a9211",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
  Cell[7381550, 129959, 1382, 20, 85, "Text",ExpressionUUID->"f22e5175-9749-47ac-b69b-4446723b94d5",
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}]},
 "17.5"->{
  Cell[7163116, 126114, 318, 7, 35, "Subsection",ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", "17.5"}]},
 "18."->{
  Cell[7383237, 129992, 211, 8, 63, "Section",ExpressionUUID->"6ac6bfd3-1a3d-49c7-95bf-3feeaabfa8cd",
   CellTags->{"Resonate", "18.", "RG18."}]},
 "19."->{
  Cell[7467121, 131546, 201, 8, 60, "Section",ExpressionUUID->"2ad8be42-a103-45bc-b5e7-11647de00c94",
   CellTags->{"Database", "19.", "RG19."}]},
 "ReportedInterval"->{
  Cell[7489279, 132106, 467, 14, 51, "FramedBox",ExpressionUUID->"8267d24e-83d6-4a31-a9ba-c281cfb392d2",
   Evaluatable->False,
   PageBreakWithin->False,
   CellTags->{"ReportedInterval", "Database", "RG19."}]},
 "20."->{
  Cell[7527691, 132936, 201, 7, 63, "Section",ExpressionUUID->"362a1439-c548-49a1-877f-7518d0f44c3a",
   CellTags->{"20.", "RG20."}]},
 "21."->{
  Cell[7638808, 135017, 147, 3, 60, "Section",ExpressionUUID->"d39bd8e9-1177-4306-8ca7-77cd6f4afc93",
   CellTags->{"What's Missing", "RG21.", "21."}]},
 "Features not discussed here"->{
  Cell[7640595, 135064, 285, 7, 35, "Subsection",ExpressionUUID->"e52217ef-ac6b-4840-95cb-6737e8877556",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Features not discussed here", "What's Missing", "RG21."}]},
 "Features left to the future"->{
  Cell[7644937, 135175, 285, 7, 35, "Subsection",ExpressionUUID->"3cdc573b-b05b-4668-b37f-e2d853505dcc",
   Evaluatable->False,
   PageBreakWithin->Automatic,
   PageBreakBelow->Automatic,
   CellTags->{"Features left to the future", "What's Missing", "RG21."}]},
 "22."->{
  Cell[7647223, 135242, 169, 3, 60, "Section",ExpressionUUID->"44e4ee72-4c79-4f62-a2c3-21d1a43cf67f",
   CellTags->{"Backward Compatibility", "RG22.", "22."}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"list of topics", 7670756, 136041},
 {"Components and Sources", 7671510, 136044},
 {"TurboPlot", 7685980, 136241},
 {"Getting Started Introduction", 7703393, 136463},
 {"Introduction to AnalyzeSystem and TurboPlot", 7704168, 136466},
 {"Move", 7706867, 136499},
 {"AnalyzeSystem", 7710029, 136546},
 {"ShowSystem", 7714492, 136604},
 {"Tracing a Cone of Rays", 7718360, 136656},
 {"Adding a Cylindrical Lens", 7722318, 136705},
 {"RayChoice", 7725498, 136744},
 {"Using Screen", 7728539, 136785},
 {"ShowRange", 7731186, 136816},
 {"ReadRays", 7733632, 136847},
 {"PropagateSystem", 7736564, 136888},
 {"OptimizeSystem", 7738606, 136910},
 {"ReadTurboRays", 7742567, 136959},
 {"FindIntensity", 7745646, 136999},
 {"Resonate", 7763020, 137203},
 {"Database", 7766520, 137248},
 {"What's Missing", 7773412, 137343},
 {"Backward Compatibility", 7775987, 137374},
 {"RG1.", 7780861, 137431},
 {"RG2.", 7794978, 137587},
 {"RG5.", 7809443, 137784},
 {"RG3.", 7814136, 137846},
 {"RG4.", 7816835, 137879},
 {"RG6.", 7819988, 137926},
 {"RG7.", 7823838, 137978},
 {"RG8.", 7827775, 138027},
 {"RG9.", 7830950, 138066},
 {"RG10.", 7833578, 138102},
 {"RG11.", 7837491, 138156},
 {"RG12.", 7839498, 138182},
 {"RG13.", 7841984, 138218},
 {"RG14.", 7844017, 138240},
 {"RG15.", 7861407, 138462},
 {"RG16.", 7865360, 138511},
 {"RG17.", 7867629, 138541},
 {"RG18.", 7885000, 138745},
 {"RG19.", 7888497, 138790},
 {"RG20.", 7895380, 138885},
 {"RG21.", 7898609, 138931},
 {"RG22.", 7901167, 138962},
 {"Optica User Guide Introduction", 7906067, 139019},
 {"1.", 7906387, 139024},
 {"Introduction", 7906756, 139030},
 {"Loading Rayica", 7907127, 139036},
 {"Rayica's High Level Functions", 7908956, 139061},
 {"1. Introduction", 7909328, 139067},
 {"Rayica User Guide Introduction", 7910119, 139078},
 {"RG1.1", 7923203, 139228},
 {"RG1.0", 7925206, 139256},
 {"Loading", 7925974, 139267},
 {"1.1", 7926273, 139273},
 {"1.3", 7926572, 139279},
 {"Rayica Example", 7926812, 139282},
 {"A Basic Rayica Example", 7927060, 139285},
 {"RG1.3", 7928067, 139296},
 {"1.4", 7929072, 139307},
 {"Data", 7929284, 139310},
 {"Inputting Data", 7929506, 139313},
 {"RG1.4", 7930080, 139320},
 {"1.5", 7930652, 139327},
 {"Optical System", 7930897, 139330},
 {"Modelling an Optical System", 7931155, 139333},
 {"RG1.5", 7932540, 139348},
 {"1.6", 7933740, 139361},
 {"Basic Rayica Example", 7934001, 139364},
 {"Variable", 7934250, 139367},
 {"Variable Definition", 7934510, 139370},
 {"RG1.6", 7936063, 139387},
 {"1.2", 7937614, 139404},
 {"Commands", 7937835, 139407},
 {"Basic Commands", 7938062, 139410},
 {"RG1.2", 7939943, 139431},
 {"Info3614689788-8836408", 7941841, 139452},
 {"1.7", 7942062, 139455},
 {"Options", 7942280, 139458},
 {"Using Options", 7942504, 139461},
 {"RG1.7", 7944012, 139478},
 {"Info3614689789-8836408", 7945537, 139495},
 {"1.8", 7945756, 139498},
 {"High-Level Functions", 7946126, 139505},
 {"Rayica's High-Level Functions", 7946505, 139512},
 {"RG1.8", 7948701, 139539},
 {"2.", 7950894, 139566},
 {"Ray", 7951244, 139573},
 {"Component", 7954333, 139625},
 {"2. Introduction", 7957454, 139670},
 {"2.1", 7958420, 139686},
 {"2.2", 7959048, 139698},
 {"2.3", 7959674, 139710},
 {"2.4", 7960329, 139722},
 {"RG2.0", 7964216, 139778},
 {"Modeling a light source", 7965202, 139794},
 {"RG2.1", 7965493, 139800},
 {"Ray versus TurboRays", 7968549, 139845},
 {"RG2.2", 7968838, 139851},
 {"CreateRays", 7971796, 139893},
 {"TurboRays", 7972060, 139898},
 {"How Rayica manages default light source settings", 7972363, 139903},
 {"RG2.3", 7972681, 139909},
 {"Modeling an optical component", 7974967, 139941},
 {"RG2.4", 7975265, 139947},
 {"PlanoConvexLens", 7978823, 139997},
 {"3.", 7979083, 140002},
 {"4.", 7979354, 140008},
 {"ray tracing", 7979595, 140014},
 {"DrawSystem", 7986512, 140116},
 {"5.", 7992495, 140202},
 {"5.1", 7992789, 140208},
 {"5.2", 7995160, 140243},
 {"RG5.1", 7996540, 140266},
 {"Tracing a single ray", 7998928, 140301},
 {"Boundary", 7999226, 140307},
 {"Working with the ray-trace data", 7999515, 140312},
 {"RG5.2", 7999821, 140318},
 {"component rendering", 8000932, 140336},
 {"6.", 8003166, 140372},
 {"PlotType", 8003433, 140378},
 {"TopView", 8004698, 140397},
 {"ConeOfRays", 8005514, 140408},
 {"7.", 8005777, 140414},
 {"GraphicDesign", 8006051, 140420},
 {"cylindrical lens", 8006323, 140425},
 {"8.", 8008536, 140458},
 {"PlanoConvexCylindricalLens", 8008833, 140464},
 {"9.", 8009079, 140469},
 {"Surface", 8009261, 140473},
 {"ComponentNumber", 8010037, 140486},
 {"Screen", 8010603, 140495},
 {"focal plane of system", 8012926, 140529},
 {"10.", 8015231, 140563},
 {"11.", 8015510, 140569},
 {"12.", 8015760, 140575},
 {"InputForm", 8016006, 140581},
 {"13.", 8016571, 140592},
 {"14.", 8016733, 140595},
 {"14. Introduction", 8016932, 140598},
 {"RG14.0", 8018084, 140614},
 {"TurboTrace", 8019240, 140630},
 {"14.1", 8019487, 140635},
 {"AnalyzeSystem versus TurboPlot", 8024779, 140704},
 {"RG14.1", 8024986, 140707},
 {"SymbolicValues", 8030088, 140774},
 {"CreateClones", 8030564, 140783},
 {"14.2", 8030752, 140786},
 {"RG14.2", 8040523, 140915},
 {"BallLens", 8050296, 141044},
 {"ShowClones", 8050536, 141049},
 {"ShowArrows", 8050814, 141054},
 {"RunningCommentary", 8051099, 141059},
 {"15.", 8051370, 141064},
 {"SphericalLens", 8051542, 141067},
 {"16.", 8051767, 141072},
 {"17.", 8052013, 141078},
 {"17. Introduction", 8052227, 141081},
 {"RG17.1", 8053030, 141092},
 {"RG17.0", 8057987, 141150},
 {"2-D Calculations with FindIntensity", 8058819, 141161},
 {"17.1", 8062835, 141207},
 {"Plot2D", 8063136, 141213},
 {"FindFocus", 8063613, 141222},
 {"RG17.2", 8065926, 141254},
 {"17.2", 8068237, 141286},
 {"RG17.3", 8068512, 141292},
 {"17.3", 8071500, 141330},
 {"Point Spread Function (PSF)", 8071814, 141336},
 {"ModulationTransferFunction", 8074824, 141374},
 {"RG17.4", 8076999, 141402},
 {"17.4", 8079001, 141428},
 {"1-D Calculations with FindIntensity", 8079323, 141434},
 {"RG17.5", 8082892, 141474},
 {"17.5", 8086279, 141512},
 {"18.", 8086578, 141518},
 {"19.", 8086735, 141521},
 {"ReportedInterval", 8086905, 141524},
 {"20.", 8087128, 141529},
 {"21.", 8087273, 141532},
 {"Features not discussed here", 8087460, 141535},
 {"Features left to the future", 8087758, 141541},
 {"22.", 8088032, 141547}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 878, 14, 132, "Chapter",ExpressionUUID->"29810d0e-0f9e-4495-8b40-95da28df57a3",
 CellTags->{"list of topics", "Components and Sources", "TurboPlot", "Getting Started Introduction", "Introduction to AnalyzeSystem and TurboPlot", "Move", "AnalyzeSystem", "ShowSystem", "Tracing a Cone of Rays", "Adding a Cylindrical Lens", "RayChoice", "Using Screen", "ShowRange", "ReadRays", "PropagateSystem", "OptimizeSystem", "ReadTurboRays", "FindIntensity", "Resonate", "Database", "What's Missing", "Backward Compatibility", "RG1.", "RG2.", "RG5.", "RG3.", "RG4.", "RG6.", "RG7.", "RG8.", "RG9.", "RG10.", "RG11.", "RG12.", "RG13.", "RG14.", "RG15.", "RG16.", "RG17.", "RG18.", "RG19.", "RG20.", "RG21.", "RG22."}],
Cell[CellGroupData[{
Cell[1482, 40, 273, 6, 24, "Outline2",ExpressionUUID->"dc0a96d6-42ba-4e7e-a04b-d1cd188e123c",
 CellTags->{"Optica User Guide Introduction", "RG1."}],
Cell[1758, 48, 929, 29, 107, "Outline3",ExpressionUUID->"e0c4d643-70f6-4836-9c40-03b74debd9f2",
 CellTags->{"Optica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2724, 82, 290, 6, 20, "Outline2",ExpressionUUID->"4a364c6c-e761-4046-a86f-d89ea8625e78",
 CellTags->{"Components and Sources", "RG2."}],
Cell[3017, 90, 688, 20, 55, "Outline3",ExpressionUUID->"6b27a151-f4f4-4956-b667-3be01c6cdcfb",
 CellTags->{"Components and Sources", "RG2."}]
}, Open  ]],
Cell[3720, 113, 242, 4, 20, "Outline2",ExpressionUUID->"8e43a153-945d-443c-a0cc-85ec2123aaf5"],
Cell[3965, 119, 212, 4, 20, "Outline2",ExpressionUUID->"b74d67e9-0c5c-4ce5-8590-e9aa832807f4"],
Cell[CellGroupData[{
Cell[4202, 127, 271, 6, 20, "Outline2",ExpressionUUID->"64fd74ad-0072-470b-b3f7-9f300bdb4b0d",
 CellTags->{"AnalyzeSystem", "RG5."}],
Cell[4476, 135, 407, 12, 29, "Outline3",ExpressionUUID->"d60aceae-7f54-4a23-b259-fa147cdc1f4a",
 CellTags->{"AnalyzeSystem", "RG5."}]
}, Open  ]],
Cell[4898, 150, 218, 4, 20, "Outline2",ExpressionUUID->"d874da31-c29b-488e-bdbc-ce9772b4d92a"],
Cell[5119, 156, 217, 4, 20, "Outline2",ExpressionUUID->"6173a065-e587-4289-b359-1a97c194207a"],
Cell[5339, 162, 234, 4, 20, "Outline2",ExpressionUUID->"366e34ac-5a23-4e5e-9912-7d62cad0673b"],
Cell[5576, 168, 215, 4, 20, "Outline2",ExpressionUUID->"27036f11-17b1-419a-9225-d2efc422b35e"],
Cell[5794, 174, 236, 4, 20, "Outline2",ExpressionUUID->"b0f5a7c1-8385-4a35-8868-0d36a17dc819"],
Cell[6033, 180, 217, 4, 20, "Outline2",ExpressionUUID->"5d01d7a9-8738-4410-9bb4-b920f68abd19"],
Cell[6253, 186, 218, 4, 20, "Outline2",ExpressionUUID->"4fdc0240-d792-44aa-9a7d-d69a91f27981"],
Cell[6474, 192, 225, 4, 20, "Outline2",ExpressionUUID->"a77b774e-25e0-4f93-8238-7d0210d8bc9d"],
Cell[CellGroupData[{
Cell[6724, 200, 293, 7, 20, "Outline2",ExpressionUUID->"c87a726b-0d67-4996-9dac-7542c014ef85",
 CellTags->{"TurboPlot", "RG14."}],
Cell[7020, 209, 386, 12, 29, "Outline3",ExpressionUUID->"864d8473-2564-4695-84d1-669e9e4ec4c7",
 CellTags->{"TurboPlot", "RG14."}]
}, Open  ]],
Cell[7421, 224, 229, 4, 20, "Outline2",ExpressionUUID->"17e5c49d-2fae-46d7-9e75-4d321d6f1a9c"],
Cell[7653, 230, 235, 4, 20, "Outline2",ExpressionUUID->"bc59ff48-ba49-4640-979c-25cf3357c9ad"],
Cell[CellGroupData[{
Cell[7913, 238, 277, 6, 20, "Outline2",ExpressionUUID->"0225a6ed-e4de-45a0-bf44-173443ff56f9",
 CellTags->{"FindIntensity", "RG17."}],
Cell[8193, 246, 789, 24, 68, "Outline3",ExpressionUUID->"69e7edd6-dba9-4da0-af18-6eb332da20ac",
 CellTags->{"FindIntensity", "RG17."}]
}, Open  ]],
Cell[8997, 273, 218, 4, 20, "Outline2",ExpressionUUID->"7ae9b663-367a-4311-8677-e276b0672d16"],
Cell[9218, 279, 214, 4, 20, "Outline2",ExpressionUUID->"ef984e6b-ab68-43bb-afb9-ca465f2a990c"],
Cell[9435, 285, 224, 4, 20, "Outline2",ExpressionUUID->"080fecd6-06a0-444a-b8dd-234d550a7beb"],
Cell[CellGroupData[{
Cell[9684, 293, 255, 6, 20, "Outline2",ExpressionUUID->"fdeeb244-3332-43ca-95c2-6c4de1b3d371",
 CellTags->{"What's Missing", "RG21."}],
Cell[9942, 301, 564, 16, 42, "Outline3",ExpressionUUID->"3eb4baaf-4492-4fa0-a5de-09e6ad2f6df5",
 CellTags->{"What's Missing", "RG21."}]
}, Open  ]],
Cell[10521, 320, 226, 4, 20, "Outline2",ExpressionUUID->"1aa6e449-50c0-46db-a167-7167ccfb2930"],
Cell[CellGroupData[{
Cell[10772, 328, 368, 8, 34, "Section",ExpressionUUID->"4985c2a5-af4c-4195-ba16-c88e0e161cf3",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"1.", "Introduction", "Loading Rayica", "Rayica's High Level Functions", "1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
Cell[11143, 338, 673, 12, 46, "Text",ExpressionUUID->"a1c1d49a-5b8e-4797-92df-e4c8a93775f1",
 CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
Cell[11819, 352, 1112, 29, 46, "Text",ExpressionUUID->"e163ce8f-1da4-46f1-bce6-23c8aa83d3f9",
 Evaluatable->False,
 CellTags->{"1. Introduction", "Rayica User Guide Introduction", "RG1.", "RG1.1", "RG1.0"}],
Cell[CellGroupData[{
Cell[12956, 385, 384, 12, 35, "Subsection",ExpressionUUID->"f6e66eed-bbc2-420e-a6a8-f5316830796f",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Loading", "Loading Rayica", "1.1", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
Cell[13343, 399, 1312, 46, 46, "Text",ExpressionUUID->"53444f15-79b2-4da2-b4fc-a3aabc38a11b",
 Evaluatable->False,
 CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
Cell[CellGroupData[{
Cell[14680, 449, 331, 12, 24, "Input",ExpressionUUID->"d0f1842b-9e8e-4fc2-bb3d-62a54619b000",
 CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
Cell[15014, 463, 491, 11, 20, "Print",ExpressionUUID->"30459a7a-ca46-4d83-af0d-fdb4a9801d45",
 CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
Cell[15508, 476, 376, 9, 19, "Print",ExpressionUUID->"2b7b290f-ec8f-499f-8ccd-8f8a5c6dde38",
 CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}]
}, Open  ]],
Cell[15899, 488, 904, 27, 33, "Text",ExpressionUUID->"b86d0f77-e2c9-4cc9-b06f-923277e3bc7c",
 Evaluatable->False,
 CellTags->{"Loading Rayica", "Rayica User Guide Introduction", "RG1.", "RG1.1"}],
Cell[16806, 517, 230, 5, 20, "Text",ExpressionUUID->"41f630dd-c76a-4762-9b3a-8b0549a3ab54",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[17073, 527, 283, 9, 35, "Subsection",ExpressionUUID->"bc604f2d-4f32-4d87-9768-d4a08a193793",
 CellTags->{"1.3", "Rayica Example", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
Cell[17359, 538, 817, 18, 46, "Text",ExpressionUUID->"2844b907-0f49-4a9d-a47c-dd4d9de13f0e",
 CellTags->{"Loading Rayica", "A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
Cell[CellGroupData[{
Cell[18201, 560, 321, 9, 89, "Input",ExpressionUUID->"528d9f96-c640-4726-aec0-55305c4ecf62",
 CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
Cell[18525, 571, 11143, 190, 223, "Print",ExpressionUUID->"2cd65a8a-29ca-47a4-b77a-241da870ded0",
 CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}],
Cell[29671, 763, 356, 5, 24, "Output",ExpressionUUID->"decbdd55-e771-48ea-ad88-55eaabd4f074",
 CellTags->{"A Basic Rayica Example", "Rayica User Guide Introduction", "RG1.", "RG1.3"}]
}, Open  ]],
Cell[30042, 771, 230, 5, 20, "Text",ExpressionUUID->"033ae809-63ce-4eb9-9982-e5b4caef8625",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[30309, 781, 195, 3, 35, "Subsection",ExpressionUUID->"426b8b19-afd3-4ff1-8b0e-bf2f9764ef7a",
 CellTags->{"1.4", "Data", "Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
Cell[30507, 786, 633, 12, 33, "Text",ExpressionUUID->"6fc8cab9-7ee2-44e2-b98b-cdd60e0e3655",
 CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
Cell[31143, 800, 1410, 31, 83, "Text",ExpressionUUID->"dda7200a-0a2d-46e4-a177-efe1267d01ee",
 CellTags->{"Inputting Data", "Rayica User Guide Introduction", "RG1.", "RG1.4"}],
Cell[32556, 833, 230, 5, 20, "Text",ExpressionUUID->"054d5311-4067-40d5-bc3e-4b005d80ec26",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[32823, 843, 235, 4, 35, "Subsection",ExpressionUUID->"a22d248b-8602-423d-82cb-ee0cf38a3784",
 CellTags->{"1.5", "Optical System", "Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
Cell[33061, 849, 1018, 21, 66, "Text",ExpressionUUID->"87327b10-7eee-41c6-ac55-2a9376422dad",
 CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
Cell[34082, 872, 711, 18, 38, "Text",ExpressionUUID->"fa99db1d-7880-4526-9fdb-e0675a094fe9",
 CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
Cell[34796, 892, 522, 12, 37, "Text",ExpressionUUID->"aebb1dd9-09f9-4ca0-b88c-b3e5ed789c74",
 CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
Cell[35321, 906, 227, 3, 20, "Text",ExpressionUUID->"e0a3b9c6-0ae8-4dbb-8793-b4c9f770f285",
 CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
Cell[35551, 911, 707, 17, 130, "Text",ExpressionUUID->"4dafee9d-c203-44b3-bd11-6d428cd52708",
 CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1.", "RG1.5"}],
Cell[36261, 930, 261, 5, 20, "Text",ExpressionUUID->"aa596a2d-47a7-483c-93b4-520dd475278c",
 CellTags->{"Modelling an Optical System", "Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[36559, 940, 237, 4, 35, "Subsection",ExpressionUUID->"cebbc5ac-d38f-4d36-9440-a9a5f16e1093",
 CellTags->{"1.6", "Basic Rayica Example", "Variable", "Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
Cell[36799, 946, 247, 5, 20, "Text",ExpressionUUID->"104e8fd2-1286-4ad8-bd49-62165d86e223",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
Cell[CellGroupData[{
Cell[37071, 955, 307, 9, 89, "Input",ExpressionUUID->"f920023b-619f-404b-8aca-2883db8d47c3",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
Cell[37381, 966, 1126, 35, 24, "Output",ExpressionUUID->"369f0439-ef91-407d-b2b8-1a6d1ee2c936",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]
}, Open  ]],
Cell[38522, 1004, 562, 10, 33, "Text",ExpressionUUID->"dee619ee-4b4d-47a4-a93c-18511ca4be05",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
Cell[CellGroupData[{
Cell[39109, 1018, 224, 3, 24, "Input",ExpressionUUID->"5727830a-6763-4831-be3d-b5c19b2eeef4",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
Cell[39336, 1023, 11138, 190, 223, "Print",ExpressionUUID->"acdffe68-5863-48c5-a77f-a7c3baf51997",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}],
Cell[50477, 1215, 353, 5, 24, "Output",ExpressionUUID->"c9ab9764-21af-4c4b-9970-43a26f36b411",
 CellTags->{"Variable Definition", "Rayica User Guide Introduction", "RG1.", "RG1.6"}]
}, Open  ]],
Cell[50845, 1223, 230, 5, 20, "Text",ExpressionUUID->"ddcfaf90-344d-4cea-ab86-cbf260c01c93",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[51112, 1233, 199, 3, 35, "Subsection",ExpressionUUID->"f0266965-d834-4247-80bb-0e0d47ead451",
 CellTags->{"1.2", "Commands", "Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[51314, 1238, 418, 9, 21, "Text",ExpressionUUID->"b961e791-5ad4-44d6-be6c-25237633de9a",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[CellGroupData[{
Cell[51757, 1251, 196, 3, 24, "Input",ExpressionUUID->"60b3ccf1-9b6a-42b4-beda-efdf85878f43",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[51956, 1256, 1410, 21, 163, "Print",ExpressionUUID->"483d8202-4615-41ba-a4e6-d78b48226d30",
 CellTags->{"Basic Commands", "Info3614689788-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[53369, 1279, 1353, 19, 196, "Print",ExpressionUUID->"3598c355-5d0a-4d3d-9b3d-f7fd245ab10e",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]
}, Open  ]],
Cell[54737, 1301, 510, 16, 21, "Text",ExpressionUUID->"32f40f05-473f-4afc-9899-3d622bcdf716",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[55250, 1319, 686, 18, 38, "Text",ExpressionUUID->"65aef86b-430e-45bc-abf8-ddddcf93ef68",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[55939, 1339, 523, 12, 34, "Text",ExpressionUUID->"81c3bf14-369a-4990-9b18-332f42382a7d",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[CellGroupData[{
Cell[56487, 1355, 195, 3, 24, "Input",ExpressionUUID->"345e0557-ca6e-4cb5-b0f5-2b96d006835d",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}],
Cell[56685, 1360, 1498, 35, 56, "Output",ExpressionUUID->"b4961016-071a-4a8e-bb6c-c90ac5d3702f",
 CellTags->{"Basic Commands", "Rayica User Guide Introduction", "RG1.", "RG1.2"}]
}, Open  ]],
Cell[58198, 1398, 230, 5, 20, "Text",ExpressionUUID->"49dddedf-8a52-4696-a0f4-ea824834129b",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[58465, 1408, 196, 3, 35, "Subsection",ExpressionUUID->"ef4c9df2-0f9a-4a7f-adbb-9107e9721366",
 CellTags->{"1.7", "Options", "Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
Cell[58664, 1413, 927, 24, 51, "Text",ExpressionUUID->"d698385b-2681-4ae0-b85a-a3df7977a811",
 CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
Cell[CellGroupData[{
Cell[59616, 1441, 221, 3, 24, "Input",ExpressionUUID->"3714197e-e855-42e0-9712-befe94db8040",
 CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
Cell[59840, 1446, 9008, 156, 107, "Print",ExpressionUUID->"2ff772c7-f46b-4d90-ac24-db9ca5717551",
 CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
Cell[68851, 1604, 349, 5, 24, "Output",ExpressionUUID->"7c91bc79-09f1-4b33-b1bc-0df23b38a0d8",
 CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}]
}, Open  ]],
Cell[69215, 1612, 395, 9, 21, "Text",ExpressionUUID->"b92c4fea-2385-4575-a331-9f47851bad97",
 CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
Cell[CellGroupData[{
Cell[69635, 1625, 188, 3, 24, "Input",ExpressionUUID->"f10454f4-a19f-41ea-8804-aceb1d31c86d",
 CellTags->{"Using Options", "Rayica User Guide Introduction", "RG1.", "RG1.7"}],
Cell[69826, 1630, 873, 13, 127, "Print",ExpressionUUID->"b7e20753-0ee7-4824-ab84-5d04bdee76c2",
 CellTags->{"Info3614689789-8836408", "Rayica User Guide Introduction", "RG1.", "RG1.7", "Using Options"}]
}, Open  ]],
Cell[70714, 1646, 230, 5, 20, "Text",ExpressionUUID->"6bb1aa19-e7dd-4535-b457-9728b6bd06b2",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[70981, 1656, 424, 13, 35, "Subsection",ExpressionUUID->"6951d732-d2cd-4fbe-9086-0ab07531e204",
 Evaluatable->False,
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"1.8", "High-Level Functions", "Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[71408, 1671, 373, 8, 20, "Text",ExpressionUUID->"96d3fc89-4f11-4a94-b332-e31880fe2590",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[71784, 1681, 5409, 196, 274, "FramedBox",ExpressionUUID->"d0491aa2-cbdf-42fd-85b3-1a702665c886",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[77196, 1879, 279, 7, 26, "Commentary",ExpressionUUID->"223397e7-31c7-4429-a46a-a3d5f8837777",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[77478, 1888, 2094, 61, 102, "Text",ExpressionUUID->"2801ba38-1670-4ec0-be89-130ee69482c6",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[79575, 1951, 1004, 29, 51, "Text",ExpressionUUID->"2aac3485-7adc-42ac-8fe9-0f6b80a73898",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[CellGroupData[{
Cell[80604, 1984, 243, 4, 24, "Input",ExpressionUUID->"03e61a5c-2d76-42f7-8f63-a22c86e3aa11",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[80850, 1990, 11382, 328, 204, "Output",ExpressionUUID->"e70dce45-423a-49c4-993e-46f4773bad3d",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}]
}, Open  ]],
Cell[92247, 2321, 453, 12, 27, "Commentary",ExpressionUUID->"2d4d4264-4d40-40c7-96cc-f946b789a556",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[92703, 2335, 719, 11, 46, "Text",ExpressionUUID->"04677792-97c0-428e-a416-043a30fdab99",
 CellTags->{"Rayica's High-Level Functions", "Rayica User Guide Introduction", "RG1.", "RG1.8"}],
Cell[93425, 2348, 230, 5, 20, "Text",ExpressionUUID->"65448239-c679-424f-b8b0-8efa2aa4a94c",
 CellTags->{"Rayica User Guide Introduction", "RG1."}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93704, 2359, 388, 9, 60, "Section",ExpressionUUID->"08711c91-2858-401f-ae70-9371c779aa70",
 Evaluatable->False,
 PageBreakAbove->True,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"2.", "Ray", "Component", "Components and Sources", "2. Introduction", "2.1", "2.2", "2.3", "2.4", "RG2.", "RG2.0"}],
Cell[94095, 2370, 1653, 36, 95, "Text",ExpressionUUID->"3a3fa262-4e29-486e-8f42-6aba6019448f",
 CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
Cell[CellGroupData[{
Cell[95773, 2410, 276, 7, 31, "Subsubsection",ExpressionUUID->"b23d5c84-e672-4ff2-9bd7-b56a49123486",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
Cell[96052, 2419, 1149, 20, 72, "Text",ExpressionUUID->"0a9fdeff-c71d-4bda-8c34-871b949d40e1",
 CellTags->{"Components and Sources", "2. Introduction", "RG2.", "RG2.0"}],
Cell[97204, 2441, 222, 5, 20, "Text",ExpressionUUID->"7d0d805f-4722-4877-902c-6e903b587b3f",
 CellTags->{"Components and Sources", "RG2."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[97463, 2451, 300, 7, 35, "Subsection",ExpressionUUID->"2154c1e8-d748-4e0f-a4b6-67e437ae3541",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Components and Sources", "Modeling a light source", "RG2.", "RG2.1", "2.1"}],
Cell[97766, 2460, 470, 12, 20, "Text",ExpressionUUID->"5e956b8d-0a1d-4670-9ef7-316f471bb0aa",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
Cell[98239, 2474, 4259, 148, 252, "FramedBox",ExpressionUUID->"163be0ce-c836-4a05-b602-043cfeb767c5",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
Cell[102501, 2624, 181, 3, 26, "Commentary",ExpressionUUID->"27a68c2a-97e8-4545-9c15-783313072250",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[102685, 2629, 426, 13, 21, "Text",ExpressionUUID->"0d4877d2-630c-4e99-8871-bfb21f4e30b2",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[CellGroupData[{
Cell[103136, 2646, 196, 2, 24, "Input",ExpressionUUID->"8f30dbd1-2c32-4f9c-9b9c-6b2fa197b05a",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[103335, 2650, 4626, 131, 120, "Output",ExpressionUUID->"98f38436-b1e7-4aef-a162-3c76193a021f",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}]
}, Open  ]],
Cell[107976, 2784, 414, 12, 27, "Commentary",ExpressionUUID->"634fbaf7-e6e1-48c2-8a43-5d6fe3abb5e0",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[108393, 2798, 810, 20, 39, "Text",ExpressionUUID->"bb566f6b-daf3-4983-869d-a2f2b0573f0b",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
Cell[109206, 2820, 803, 21, 38, "Text",ExpressionUUID->"f6d83e78-531c-4ffa-ac13-f9f2557d1e00",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
Cell[CellGroupData[{
Cell[110034, 2845, 295, 5, 35, "Input",ExpressionUUID->"3c66cd45-fbcd-4b97-a7ff-ed3bf9d5a639",
 PageBreakWithin->Automatic,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
Cell[110332, 2852, 444, 11, 24, "Output",ExpressionUUID->"cbee1408-a603-4db7-a141-fc74ed03cd9f",
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}]
}, Open  ]],
Cell[110791, 2866, 1300, 35, 66, "Text",ExpressionUUID->"83e9195b-377a-46f7-940b-d5f912ae28cd",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[CellGroupData[{
Cell[112116, 2905, 174, 2, 24, "Input",ExpressionUUID->"44acd788-f49f-4b3c-ada7-aaa673fd1ee2",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[112293, 2909, 1020, 19, 116, "Output",ExpressionUUID->"efe3dfab-e4d5-413f-be0c-367f2a295ab4",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}]
}, Open  ]],
Cell[113328, 2931, 1529, 41, 83, "Text",ExpressionUUID->"194aaa1b-e39b-483d-98c9-86fbf1a155d7",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.1"}],
Cell[114860, 2974, 2226, 61, 119, "Text",ExpressionUUID->"2db9e75b-e121-4086-8722-eee8505e9120",
 CellTags->{"Components and Sources", "RG2.", "RG2.1"}],
Cell[117089, 3037, 222, 5, 20, "Text",ExpressionUUID->"e89a6918-b041-49fc-8ab5-cdb7ffb5adfd",
 CellTags->{"Components and Sources", "RG2."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[117348, 3047, 294, 7, 35, "Subsection",ExpressionUUID->"04e59e43-108b-4175-b18e-c661ed145fbd",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Ray versus TurboRays", "Components and Sources", "RG2.", "RG2.2", "2.2"}],
Cell[117645, 3056, 1206, 37, 51, "Text",ExpressionUUID->"3dae03d0-b7a4-4671-b970-ff4fb797fb9f",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
Cell[118854, 3095, 583, 19, 34, "Text",ExpressionUUID->"07b827ce-dce5-4812-850d-a7d45348011b",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.2"}],
Cell[119440, 3116, 1409, 50, 110, "FramedBox",ExpressionUUID->"f262f2d8-c5b5-4f21-9069-500b8272bbab",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"CreateRays", "Ray", "TurboRays", "Components and Sources", "RG2.", "RG2.2"}],
Cell[120852, 3168, 807, 24, 38, "Text",ExpressionUUID->"ec17fe0d-d65b-4b4b-aec1-5b1491287176",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[CellGroupData[{
Cell[121684, 3196, 181, 2, 24, "Input",ExpressionUUID->"ccde2674-390a-4365-96e1-7846afb2c154",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[121868, 3200, 444, 11, 24, "Output",ExpressionUUID->"de932cca-b2d3-496e-be44-bc5e187564af",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}]
}, Open  ]],
Cell[122327, 3214, 465, 15, 21, "Text",ExpressionUUID->"e2f135df-65eb-45c1-8caf-4fc68baa3243",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[CellGroupData[{
Cell[122817, 3233, 174, 2, 24, "Input",ExpressionUUID->"26ac156b-7290-47db-8499-89f9e7408435",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[122994, 3237, 1006, 19, 116, "Output",ExpressionUUID->"b59b4740-4088-412d-9344-67d755cedbec",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}]
}, Open  ]],
Cell[124015, 3259, 520, 17, 34, "Text",ExpressionUUID->"ae70480d-bef9-4f92-901c-c4f9883b9009",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[CellGroupData[{
Cell[124560, 3280, 186, 2, 24, "Input",ExpressionUUID->"26204c28-0611-4bdb-8ee8-f41e1974186f",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[124749, 3284, 2229, 38, 278, "Output",ExpressionUUID->"1e7fbbbe-ac15-463a-b599-8d861ee982fb",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}]
}, Open  ]],
Cell[126993, 3325, 1202, 41, 54, "Text",ExpressionUUID->"06637bc5-a376-4811-8505-c4e6bcc7afba",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[CellGroupData[{
Cell[128220, 3370, 211, 2, 24, "Input",ExpressionUUID->"c14e6e5e-b415-4b18-87dd-2a3d5e9dfadf",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[128434, 3374, 1082, 18, 116, "Output",ExpressionUUID->"35245519-99f9-4861-a0fc-d218481c739f",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}]
}, Open  ]],
Cell[129531, 3395, 1511, 39, 86, "Text",ExpressionUUID->"78c6969c-cf10-4e6b-b4db-fe4cd0465117",
 CellTags->{"Components and Sources", "RG2.", "RG2.2"}],
Cell[131045, 3436, 222, 5, 20, "Text",ExpressionUUID->"e4f9b90a-8b43-46b2-a164-64cf7a7d1efd",
 CellTags->{"Components and Sources", "RG2."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[131304, 3446, 412, 13, 35, "Subsection",ExpressionUUID->"b6623f8f-dc12-4d18-869a-8e6f94edcffa",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"How Rayica manages default light source settings", "Components and Sources", "RG2.", "RG2.3", "2.3"}],
Cell[131719, 3461, 1314, 39, 66, "Text",ExpressionUUID->"f7db2f37-f6c0-4557-a85c-9e4ca13ee1d9",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[133036, 3502, 725, 17, 51, "Text",ExpressionUUID->"7fd2b89a-85a7-4bac-9b28-1d4e4e9630e0",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[CellGroupData[{
Cell[133786, 3523, 164, 2, 24, "Input",ExpressionUUID->"dc651577-4f0a-49cd-a800-e175d4bf5069",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[133953, 3527, 4775, 103, 200, "Output",ExpressionUUID->"623a4163-fa46-4247-ad2b-263ba7b59c86",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}]
}, Open  ]],
Cell[138743, 3633, 1018, 26, 54, "Text",ExpressionUUID->"c380cecc-f3c6-42a5-a0c4-0d6ef93e9822",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[139764, 3661, 332, 7, 20, "Text",ExpressionUUID->"ff5b866d-87d0-457e-81c5-34d395797f94",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[CellGroupData[{
Cell[140121, 3672, 181, 2, 24, "Input",ExpressionUUID->"d0320a23-7f02-4e4a-88e6-aacdfcd7a573",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[140305, 3676, 488, 12, 24, "Output",ExpressionUUID->"bae2cc55-2bed-4232-892f-843be9ddaa2e",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}]
}, Open  ]],
Cell[140808, 3691, 518, 14, 38, "Text",ExpressionUUID->"2dd4bb18-47b5-4437-9dce-4eb4c658c3c4",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
Cell[CellGroupData[{
Cell[141351, 3709, 170, 2, 24, "Input",ExpressionUUID->"b70d0283-7f35-4b33-9bcb-39989eb809fe",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}],
Cell[141524, 3713, 1289, 27, 56, "Output",ExpressionUUID->"df31c411-7635-43b3-af9e-e120b2b1bff3",
 CellTags->{"Components and Sources", "RG2.", "RG2.3"}]
}, Open  ]],
Cell[142828, 3743, 1177, 36, 47, "Text",ExpressionUUID->"13fe18f5-4bd8-4d78-a9c2-bc1b9650fca4",
 Evaluatable->False,
 CellTags->{"Ray", "Components and Sources", "RG2.", "RG2.3"}],
Cell[144008, 3781, 222, 5, 20, "Text",ExpressionUUID->"e9fedc5c-f759-4cd7-a3b7-2ab02f59cb2a",
 CellTags->{"Components and Sources", "RG2."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[144267, 3791, 312, 7, 35, "Subsection",ExpressionUUID->"249cd70a-e2a0-468b-8640-8bed88c95740",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Modeling an optical component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[144582, 3800, 634, 16, 37, "Text",ExpressionUUID->"86de7ae5-0eca-49c7-95a8-0991f250a0e8",
 Evaluatable->False,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[CellGroupData[{
Cell[145241, 3820, 190, 2, 24, "Input",ExpressionUUID->"d22fa188-d1ca-421f-9bc7-c2251836fcc7",
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[145434, 3824, 51836, 1500, 686, "Output",ExpressionUUID->"c13f1112-acac-468a-be18-168132b78ffc",
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}]
}, Open  ]],
Cell[197285, 5327, 465, 14, 27, "Commentary",ExpressionUUID->"9c9f6ad5-006b-4b0b-915b-a777db6172cb",
 CellTags->{"Components and Sources", "2.4", "Component", "RG2.", "RG2.4"}],
Cell[197753, 5343, 532, 14, 37, "Text",ExpressionUUID->"f171c788-d55d-4504-a18e-b1bda124cad0",
 Evaluatable->False,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[198288, 5359, 812, 29, 51, "FramedBox",ExpressionUUID->"cc948faa-c4ed-4869-b138-e9828e0c49d8",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Component", "PlanoConvexLens", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[199103, 5390, 366, 11, 22, "Text",ExpressionUUID->"1618b427-0d03-4508-8b04-0a1afadd3238",
 Evaluatable->False,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[CellGroupData[{
Cell[199494, 5405, 288, 5, 24, "Input",ExpressionUUID->"3e9be787-61f3-458a-9b23-3af67b3d7d8e",
 PageBreakWithin->Automatic,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[199785, 5412, 510, 12, 23, "Output",ExpressionUUID->"2825a7df-ebe0-467f-949b-750106cd5cca",
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}]
}, Open  ]],
Cell[200310, 5427, 1518, 39, 69, "Text",ExpressionUUID->"0d67ff6c-7cd7-496e-a6de-5768f86ca930",
 Evaluatable->False,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[201831, 5468, 844, 22, 51, "Text",ExpressionUUID->"eef9b50e-e13a-421f-9021-c75994b22de3",
 CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[202678, 5492, 1355, 43, 56, "Text",ExpressionUUID->"5c808751-7867-47b2-aab5-3bc3d8c199f6",
 Evaluatable->False,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[CellGroupData[{
Cell[204058, 5539, 284, 5, 24, "Input",ExpressionUUID->"0d7fe5c5-b1fa-4a05-a112-a8f4a2ba80ff",
 PageBreakWithin->Automatic,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[204345, 5546, 2602, 59, 120, "Output",ExpressionUUID->"d2afd54c-a23f-45a4-bf1c-2ad6e42f007e",
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}]
}, Open  ]],
Cell[206962, 5608, 832, 20, 52, "Text",ExpressionUUID->"d4bae18c-4795-49e1-872f-a3d98e623fc2",
 Evaluatable->False,
 CellTags->{"Component", "Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[CellGroupData[{
Cell[207819, 5632, 280, 7, 24, "Input",ExpressionUUID->"86d06f27-cac4-455d-963a-9c1e384be627",
 CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}],
Cell[208102, 5641, 583, 14, 24, "Output",ExpressionUUID->"b7c3aa15-7beb-46bd-ad1e-9086c3bfae34",
 CellTags->{"Components and Sources", "2.4", "RG2.", "RG2.4"}]
}, Open  ]],
Cell[208700, 5658, 222, 5, 20, "Text",ExpressionUUID->"ee8c6ee2-63b1-40ce-a0a3-a0d34bd8fb34",
 CellTags->{"Components and Sources", "RG2."}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[208971, 5669, 448, 16, 60, "Section",ExpressionUUID->"f36ffa46-c6d2-439a-9436-fd7c63745e3d",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"3.", "Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[209422, 5687, 1126, 28, 68, "Text",ExpressionUUID->"8c47ee91-acd1-4aff-8716-af3ea27f1b84",
 Evaluatable->False,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[210551, 5717, 1041, 36, 81, "FramedBox",ExpressionUUID->"261340f7-80cc-4036-9f76-943150729697",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[211595, 5755, 1805, 45, 103, "Text",ExpressionUUID->"6225c1c0-5cd6-48f5-850b-53c0f81f7cc6",
 Evaluatable->False,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[213403, 5802, 523, 14, 34, "Text",ExpressionUUID->"ec9c95de-5825-40d9-a289-df1341e2c666",
 Evaluatable->False,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[CellGroupData[{
Cell[213951, 5820, 352, 9, 24, "Input",ExpressionUUID->"1726bb25-462a-4549-bd93-8573fad0fabc",
 PageBreakWithin->Automatic,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[214306, 5831, 12705, 212, 438, "Print",ExpressionUUID->"666eb69d-8757-4ccf-9432-9f88066ccff9",
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[227014, 6045, 689, 18, 20, "Print",ExpressionUUID->"f2f0a085-d829-463d-9de9-2ce44ffc6b56",
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[227706, 6065, 339, 4, 23, "Output",ExpressionUUID->"29727901-5758-4d7f-9da3-179fef404a45",
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}]
}, Open  ]],
Cell[228060, 6072, 1358, 36, 65, "Text",ExpressionUUID->"52d1cb2a-fcf5-454d-aae0-8a2cdb930012",
 Evaluatable->False,
 CellTags->{"Introduction to AnalyzeSystem and TurboPlot", "RG3."}],
Cell[229421, 6110, 170, 3, 20, "Text",ExpressionUUID->"6f19e759-f76b-41fc-aa73-ce032764c1fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[229628, 6118, 299, 12, 60, "Section",ExpressionUUID->"e79ee304-6444-418c-a347-afc29e47298d",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Move", "4.", "RG4."}],
Cell[229930, 6132, 840, 30, 38, "Text",ExpressionUUID->"9e0ee182-ff3f-43f3-a9dc-be44675bfa86",
 Evaluatable->False,
 CellTags->{"Move", "RG4."}],
Cell[230773, 6164, 862, 33, 51, "FramedBox",ExpressionUUID->"5f9681df-c37c-4521-9524-cfd663be2990",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Move", "RG4."}],
Cell[231638, 6199, 1087, 38, 38, "Text",ExpressionUUID->"7e8db4f2-fbe3-4f2b-9a30-04dacb450d99",
 Evaluatable->False,
 CellTags->{"Move", "RG4."}],
Cell[CellGroupData[{
Cell[232750, 6241, 375, 10, 57, "Input",ExpressionUUID->"6b5272ea-3406-4e38-bc14-4af8d413c5fe",
 PageBreakWithin->Automatic,
 CellTags->{"Move", "RG4."}],
Cell[233128, 6253, 26290, 425, 266, "Print",ExpressionUUID->"f2905d4c-0a2b-409a-a72a-a56e8893f778",
 CellTags->{"Move", "RG4."}],
Cell[259421, 6680, 927, 26, 20, "Print",ExpressionUUID->"9a43684d-2201-4b5a-9a78-d826030078b5",
 CellTags->{"Move", "RG4."}],
Cell[260351, 6708, 308, 4, 24, "Output",ExpressionUUID->"b55e7357-d863-4697-8813-7f7cc22a5135",
 CellTags->{"Move", "RG4."}]
}, Open  ]],
Cell[260674, 6715, 588, 13, 37, "Text",ExpressionUUID->"3015ad87-e28b-447b-9c45-8090fc0f0d9a",
 Evaluatable->False,
 CellTags->{"Move", "RG4."}],
Cell[261265, 6730, 2635, 116, 165, "FramedBox",ExpressionUUID->"2eda5272-ff28-49d0-af7c-f78001c32ec2",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Move", "RG4."}],
Cell[263903, 6848, 259, 7, 27, "Commentary",ExpressionUUID->"7709d5f4-20e7-46c4-a5c1-f6761964cc32",
 CellTags->{"Move", "RG4."}],
Cell[264165, 6857, 520, 18, 34, "Text",ExpressionUUID->"ba405f05-8953-47a7-97ad-0df30ed40a7b",
 CellTags->{"Move", "RG4."}],
Cell[CellGroupData[{
Cell[264710, 6879, 167, 2, 24, "Input",ExpressionUUID->"90ddc9bd-c7cd-4c1e-af5a-3b8f958d6218",
 CellTags->{"Move", "RG4."}],
Cell[264880, 6883, 3782, 106, 56, "Output",ExpressionUUID->"83fbebe7-5ac1-4249-96b0-6497e0927650",
 CellTags->{"Move", "RG4."}]
}, Open  ]],
Cell[268677, 6992, 380, 11, 27, "Commentary",ExpressionUUID->"f7bcd3be-e8bb-4554-9d2c-ae586a1da6eb",
 CellTags->{"Move", "RG4."}],
Cell[269060, 7005, 474, 15, 21, "Text",ExpressionUUID->"c4e24659-88c0-410a-a21f-b62e1ff992ad",
 Evaluatable->False,
 CellTags->{"Move", "RG4."}],
Cell[269537, 7022, 170, 3, 20, "Text",ExpressionUUID->"57d0a25f-679e-425d-8d87-f73ab60c1c03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[269744, 7030, 400, 13, 60, "Section",ExpressionUUID->"0319581f-f767-4b74-b441-96504d2b4da6",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ray tracing", "DrawSystem", "5.", "AnalyzeSystem", "5.1", "5.2", "RG5.", "RG5.1"}],
Cell[CellGroupData[{
Cell[270169, 7047, 300, 7, 35, "Subsection",ExpressionUUID->"366753db-b85c-4434-8b71-dd02f345134a",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ray tracing", "Tracing a single ray", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[270472, 7056, 873, 22, 39, "Text",ExpressionUUID->"55286c60-27d2-4630-81e6-97a7b1a1ab24",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[271348, 7080, 614, 18, 51, "FramedBox",ExpressionUUID->"6cfb2490-cb14-4e77-80bf-8238a226b4a2",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ray tracing", "DrawSystem", "Boundary", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[271965, 7100, 1992, 81, 55, "Text",ExpressionUUID->"3a76cb8d-0c5d-491e-8195-ca6835e3fb96",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[273960, 7183, 764, 23, 38, "Text",ExpressionUUID->"4a839b86-246e-4641-b570-db7a0d293935",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[CellGroupData[{
Cell[274749, 7210, 493, 14, 73, "Input",ExpressionUUID->"da36b75b-dc18-4f2c-a702-881827e858db",
 PageBreakWithin->Automatic,
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[275245, 7226, 15788, 256, 256, "Print",ExpressionUUID->"88350966-dd78-4726-8f28-f9a3042ec591",
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[291036, 7484, 1220, 34, 36, "Print",ExpressionUUID->"0ff95cdb-893c-4782-af50-1cfb298d33d6",
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[292259, 7520, 365, 5, 24, "Output",ExpressionUUID->"03201069-e344-4e9f-9349-939a9f87a7b6",
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.1", "RG5.", "RG5.1"}]
}, Open  ]],
Cell[292639, 7528, 858, 21, 53, "Text",ExpressionUUID->"7369556e-547f-4c48-9122-ce4aa18cf0e1",
 CellTags->{"AnalyzeSystem", "5.1", "RG5.", "RG5.1"}],
Cell[293500, 7551, 187, 3, 20, "Text",ExpressionUUID->"b0feb3b6-78fc-4c46-97e7-8d25b7f404cf",
 CellTags->"RG5."]
}, Open  ]],
Cell[CellGroupData[{
Cell[293724, 7559, 322, 7, 35, "Subsection",ExpressionUUID->"a2b13210-c967-46e5-a09b-967dcc61a330",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ray tracing", "Working with the ray-trace data", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
Cell[294049, 7568, 1253, 31, 67, "Text",ExpressionUUID->"e27d58c1-d2f1-4afc-aae8-3180a299d281",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
Cell[295305, 7601, 2694, 99, 146, "FramedBox",ExpressionUUID->"698d2ab3-3957-4c61-8c0b-5ff8e0224da2",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Ray", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
Cell[298002, 7702, 231, 7, 26, "Commentary",ExpressionUUID->"26b43ee4-7126-4285-afb4-1c0266581bb3",
 CellTags->{"AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
Cell[298236, 7711, 1043, 26, 54, "Text",ExpressionUUID->"2f6e58a5-a5a0-4d2d-b7d9-25d6b6df71f0",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "AnalyzeSystem", "5.2", "RG5.", "RG5.2"}],
Cell[299282, 7739, 187, 3, 20, "Text",ExpressionUUID->"a371b2c7-e818-4fbb-8cf6-e8cc10f8b2bb",
 CellTags->"RG5."]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[299518, 7748, 338, 12, 63, "Section",ExpressionUUID->"64a2e08a-22da-4300-95b9-1ad25b5ce535",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ShowSystem", "component rendering", "6.", "RG6."}],
Cell[299859, 7762, 856, 26, 39, "Text",ExpressionUUID->"a762463d-3045-4825-87b2-14bb8f507bfc",
 Evaluatable->False,
 CellTags->{"ShowSystem", "component rendering", "RG6."}],
Cell[CellGroupData[{
Cell[300740, 7792, 388, 11, 24, "Input",ExpressionUUID->"3d5e01d2-1811-45c3-b981-230c6f396ce4",
 PageBreakWithin->Automatic,
 CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
Cell[301131, 7805, 12794, 217, 138, "Print",ExpressionUUID->"51f5d35a-07a1-4da7-b1be-84fe8e7b52fb",
 CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}]
}, Open  ]],
Cell[313940, 8025, 705, 18, 34, "Text",ExpressionUUID->"30f2a5f0-70af-48be-a362-2f0d0ed3bc92",
 Evaluatable->False,
 CellTags->{"ShowSystem", "component rendering", "RG6."}],
Cell[314648, 8045, 1216, 35, 164, "FramedBox",ExpressionUUID->"4d2d16ec-590d-4087-a948-7eca66168471",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
Cell[315867, 8082, 147, 3, 26, "Commentary",ExpressionUUID->"accb7d7d-bdeb-4ef8-ab85-02949feef222",
 CellTags->{"ShowSystem", "RG6."}],
Cell[316017, 8087, 840, 24, 38, "Text",ExpressionUUID->"1164e3f4-4cce-443b-a3eb-b8e6ed0b0d18",
 Evaluatable->False,
 CellTags->{"ShowSystem", "component rendering", "RG6."}],
Cell[316860, 8113, 692, 23, 51, "FramedBox",ExpressionUUID->"81b20859-5e84-4947-9587-7215471a8f59",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ShowSystem", "component rendering", "PlotType", "RG6."}],
Cell[317555, 8138, 306, 9, 21, "Text",ExpressionUUID->"666c3868-dbeb-4e1e-8f1f-c61134156135",
 Evaluatable->False,
 CellTags->{"ShowSystem", "component rendering", "RG6."}],
Cell[317864, 8149, 1396, 33, 165, "FramedBox",ExpressionUUID->"0936f727-cc05-485f-a077-877a4972781b",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Ray", "ShowSystem", "RG6."}],
Cell[319263, 8184, 184, 7, 27, "Commentary",ExpressionUUID->"c0abbaea-40b0-43c3-92b0-8d371ecf8e2c",
 CellTags->{"ShowSystem", "RG6."}],
Cell[319450, 8193, 461, 12, 34, "Text",ExpressionUUID->"61d6452e-a86b-42c5-97dc-5a2e42ff0159",
 CellTags->{"ShowSystem", "RG6."}],
Cell[CellGroupData[{
Cell[319936, 8209, 387, 13, 24, "Input",ExpressionUUID->"4e26961f-7390-4396-b473-ee2037840144",
 PageBreakWithin->Automatic,
 CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}],
Cell[320326, 8224, 15785, 256, 256, "Print",ExpressionUUID->"f630a1b3-8630-45da-8669-da640cb610fb",
 CellTags->{"ShowSystem", "component rendering", "PlotType", "TopView", "RG6."}]
}, Open  ]],
Cell[336126, 8483, 228, 6, 26, "Commentary",ExpressionUUID->"ba2e33a9-701f-45ed-9ae6-785a655b2088",
 CellTags->{"ShowSystem", "RG6."}],
Cell[336357, 8491, 1151, 34, 67, "Text",ExpressionUUID->"b9ee1085-a4db-4909-8120-573cd6b1d0cb",
 CellTags->{"ShowSystem", "RG6."}],
Cell[337511, 8527, 170, 3, 20, "Text",ExpressionUUID->"cf788e64-fa61-4fd6-bfab-7cc276a4538f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337718, 8535, 276, 7, 60, "Section",ExpressionUUID->"ef5cb7f7-4a2e-41b7-a582-7cd49609ad04",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ConeOfRays", "7.", "Tracing a Cone of Rays", "RG7."}],
Cell[337997, 8544, 534, 16, 21, "Text",ExpressionUUID->"9c94a08d-a3e8-4d8e-acb6-662ceb40fb6c",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[CellGroupData[{
Cell[338556, 8564, 437, 10, 57, "Input",ExpressionUUID->"fed97f40-88bc-4f03-9201-d0237877757f",
 PageBreakWithin->Automatic,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[338996, 8576, 15095, 255, 223, "Print",ExpressionUUID->"37191ea6-48c5-4143-badd-2a16889b8e71",
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}]
}, Open  ]],
Cell[354106, 8834, 511, 13, 34, "Text",ExpressionUUID->"8d708064-4943-4d97-9338-80fdec46d92e",
 CellTags->{"Tracing a Cone of Rays", "RG7."}],
Cell[354620, 8849, 355, 10, 21, "Text",ExpressionUUID->"24b310c7-f413-4438-a984-916a3d387316",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[354978, 8861, 635, 20, 51, "FramedBox",ExpressionUUID->"5dd6b5e6-6bda-4e87-bcfc-89f6c17b0459",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ray tracing", "DrawSystem", "GraphicDesign", "Tracing a Cone of Rays", "RG7."}],
Cell[355616, 8883, 1266, 45, 55, "Text",ExpressionUUID->"e506ddcd-0879-41ab-9c62-f1893312d38a",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[CellGroupData[{
Cell[356907, 8932, 486, 11, 57, "Input",ExpressionUUID->"78ae942a-cb18-4547-b900-445b13070a83",
 PageBreakWithin->Automatic,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[357396, 8945, 56644, 921, 223, "Print",ExpressionUUID->"b1b87736-fe15-4098-9aab-1bb1ba1e1fba",
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}]
}, Open  ]],
Cell[414055, 9869, 416, 13, 21, "Text",ExpressionUUID->"072f6e22-85e4-42b4-8783-7cc94a7c1fd3",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[CellGroupData[{
Cell[414496, 9886, 262, 4, 24, "Input",ExpressionUUID->"21c87232-2508-40e4-a406-184ea43091fe",
 PageBreakWithin->Automatic,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[414761, 9892, 40317, 694, 107, "Print",ExpressionUUID->"af61dccd-7843-4695-8d08-5324bb57a8b7",
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}]
}, Open  ]],
Cell[455093, 10589, 727, 22, 39, "Text",ExpressionUUID->"566e4a0b-26a1-49bf-a5d6-8f6376ae9285",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[CellGroupData[{
Cell[455845, 10615, 263, 4, 24, "Input",ExpressionUUID->"43392047-6d38-472c-b510-86ef1a1bb072",
 PageBreakWithin->Automatic,
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}],
Cell[456111, 10621, 44399, 773, 365, "Print",ExpressionUUID->"0a748db5-bcea-4a91-831b-278c5989b2ec",
 CellTags->{"ray tracing", "DrawSystem", "Tracing a Cone of Rays", "RG7."}]
}, Open  ]],
Cell[500525, 11397, 170, 3, 20, "Text",ExpressionUUID->"49c80eb8-69b3-49c3-afc0-0193bec43fa0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[500732, 11405, 302, 7, 60, "Section",ExpressionUUID->"811accef-54a1-49dd-aafb-3af96471eef6",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"cylindrical lens", "8.", "Adding a Cylindrical Lens", "RG8."}],
Cell[501037, 11414, 441, 11, 21, "Text",ExpressionUUID->"de0b999c-b77b-4599-9529-4cf305828fbf",
 Evaluatable->False,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
Cell[501481, 11427, 752, 26, 51, "FramedBox",ExpressionUUID->"cefabc0f-b2ba-4081-a914-a90102a52410",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"PlanoConvexCylindricalLens", "Adding a Cylindrical Lens", "RG8."}],
Cell[502236, 11455, 472, 16, 21, "Text",ExpressionUUID->"2a020f65-57b9-4d9c-a7ad-1909426b6614",
 Evaluatable->False,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
Cell[CellGroupData[{
Cell[502733, 11475, 584, 14, 89, "Input",ExpressionUUID->"8bec4a81-f674-4133-b165-e68c0b8dc5f6",
 PageBreakWithin->Automatic,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}],
Cell[503320, 11491, 89102, 1445, 220, "Print",ExpressionUUID->"0eb413d0-0c48-47c6-8df0-2f898569bd3d",
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RayChoice", "RG8."}]
}, Open  ]],
Cell[592437, 12939, 243, 5, 20, "Text",ExpressionUUID->"09cb721d-419f-47bb-9788-3802a696cbee",
 Evaluatable->False,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
Cell[CellGroupData[{
Cell[592705, 12948, 268, 4, 24, "Input",ExpressionUUID->"5e6666c8-aa0e-4d60-801e-bbc7eef0bf62",
 PageBreakWithin->Automatic,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
Cell[592976, 12954, 64048, 1102, 104, "Print",ExpressionUUID->"3dab169f-74d4-49da-ad43-db9c6f5ac4cf",
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[657061, 14061, 267, 4, 24, "Input",ExpressionUUID->"861c617d-2d33-4fa6-a2ed-2b5e8e334a04",
 PageBreakWithin->Automatic,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
Cell[657331, 14067, 65471, 1127, 104, "Print",ExpressionUUID->"d723f22c-56c9-45ab-9326-3be74b4f57f2",
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}]
}, Open  ]],
Cell[722817, 15197, 1246, 32, 60, "Text",ExpressionUUID->"f46b8f25-0f6f-43f7-9dcf-10d7b52d732b",
 Evaluatable->False,
 CellTags->{"cylindrical lens", "Adding a Cylindrical Lens", "RG8."}],
Cell[724066, 15231, 170, 3, 20, "Text",ExpressionUUID->"b259f704-e50e-4139-a571-9e943a1cff62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[724273, 15239, 254, 10, 63, "Section",ExpressionUUID->"23359498-8046-434a-af0c-e565df2d8892",
 Evaluatable->False,
 CellTags->{"RayChoice", "9.", "RG9."}],
Cell[724530, 15251, 382, 12, 21, "Text",ExpressionUUID->"0d1a8e3f-4e1d-4dc4-a61a-e7f9b3ef5afb",
 Evaluatable->False,
 CellTags->{"RayChoice", "RG9."}],
Cell[724915, 15265, 719, 26, 51, "FramedBox",ExpressionUUID->"34779028-9be1-4672-b9ce-24514fb1786e",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"RayChoice", "RG9."}],
Cell[725637, 15293, 708, 19, 38, "Text",ExpressionUUID->"f42d6be7-cbe5-44e4-b7ee-1e7ef7b86e0a",
 Evaluatable->False,
 CellTags->{"RayChoice", "RG9."}],
Cell[CellGroupData[{
Cell[726370, 15316, 243, 4, 24, "Input",ExpressionUUID->"01fb40b3-1e7d-4bf2-967e-eea9be9f6230",
 PageBreakWithin->Automatic,
 CellTags->{"RayChoice", "RG9."}],
Cell[726616, 15322, 88175, 1429, 220, "Print",ExpressionUUID->"d7fc8bc8-e503-4e02-a570-e01b7182818a",
 CellTags->{"RayChoice", "RG9."}]
}, Open  ]],
Cell[814806, 16754, 486, 16, 21, "Text",ExpressionUUID->"921d688e-0d66-4016-be31-dc9862d3972f",
 Evaluatable->False,
 CellTags->{"RayChoice", "RG9."}],
Cell[815295, 16772, 579, 18, 51, "FramedBox",ExpressionUUID->"ab90f6a7-a383-4ac1-80ec-3fa98fb9b1f4",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"RayChoice", "Surface", "RG9."}],
Cell[815877, 16792, 453, 14, 21, "Text",ExpressionUUID->"41a7f206-e13a-4409-be36-f56525db8c24",
 Evaluatable->False,
 CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
Cell[CellGroupData[{
Cell[816355, 16810, 300, 6, 24, "Input",ExpressionUUID->"47b9e46a-25c0-4cb3-b662-0d37b89eb12d",
 PageBreakWithin->Automatic,
 CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}],
Cell[816658, 16818, 3305, 74, 365, "Print",ExpressionUUID->"15442f90-5536-464e-8ab9-90af301ef1ce",
 CellTags->{"RayChoice", "Surface", "ComponentNumber", "RG9."}]
}, Open  ]],
Cell[819978, 16895, 170, 3, 20, "Text",ExpressionUUID->"3f256fca-30a0-473e-a808-d951fc8ebfa3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[820185, 16903, 371, 12, 63, "Section",ExpressionUUID->"55270133-e4f3-4291-afdd-5549525a965b",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Screen", "focal plane of system", "10.", "Using Screen", "RG10."}],
Cell[820559, 16917, 735, 20, 38, "Text",ExpressionUUID->"4574287a-8995-4e63-99d6-4237667227af",
 Evaluatable->False,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
Cell[821297, 16939, 635, 21, 51, "FramedBox",ExpressionUUID->"cb264467-9607-4491-9e2a-150017352ac3",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
Cell[821935, 16962, 612, 20, 21, "Text",ExpressionUUID->"4f17e7e8-b7ef-46c4-bbe9-62737fdd5493",
 Evaluatable->False,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
Cell[CellGroupData[{
Cell[822572, 16986, 618, 15, 106, "Input",ExpressionUUID->"d2c4a75f-aa0e-4e56-b483-35087b7e3359",
 PageBreakWithin->Automatic,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}],
Cell[823193, 17003, 25468, 426, 205, "Print",ExpressionUUID->"21e9e5eb-41f4-4500-9dc0-ea6cd876d642",
 CellTags->{"Screen", "focal plane of system", "Using Screen", "ShowRange", "ReadRays", "RG10."}]
}, Open  ]],
Cell[848676, 17432, 451, 13, 21, "Text",ExpressionUUID->"045101ea-2a75-4098-a7f0-05d2a696de23",
 Evaluatable->False,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
Cell[CellGroupData[{
Cell[849152, 17449, 310, 7, 24, "Input",ExpressionUUID->"da50deaa-c72e-495c-92e8-001633150ed5",
 PageBreakWithin->Automatic,
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}],
Cell[849465, 17458, 2021, 46, 365, "Print",ExpressionUUID->"a8b69489-f5d3-4bd3-9d7e-48f0bdb29221",
 CellTags->{"Screen", "focal plane of system", "Using Screen", "RG10."}]
}, Open  ]],
Cell[851501, 17507, 170, 3, 20, "Text",ExpressionUUID->"ac6416fe-20af-42a9-a43d-d1e28b756094"]
}, Open  ]],
Cell[CellGroupData[{
Cell[851708, 17515, 323, 12, 63, "Section",ExpressionUUID->"c348ff48-a54b-4c54-9da9-e9c1ed3d78d5",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ShowRange", "11.", "RG10.", "RG11."}],
Cell[852034, 17529, 398, 13, 21, "Text",ExpressionUUID->"52816333-8b27-4409-b845-2b916f72b70f",
 Evaluatable->False,
 CellTags->{"ShowRange", "RG10.", "RG11."}],
Cell[852435, 17544, 570, 19, 51, "FramedBox",ExpressionUUID->"83ed5ffd-df16-4b3f-8c0a-adc45f84e000",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ShowRange", "RG10.", "RG11."}],
Cell[853008, 17565, 492, 16, 21, "Text",ExpressionUUID->"5b155320-e592-41f5-b201-2e505ba64340",
 Evaluatable->False,
 CellTags->{"ShowRange", "RG10.", "RG11."}],
Cell[CellGroupData[{
Cell[853525, 17585, 237, 4, 24, "Input",ExpressionUUID->"2a1441a5-322d-4c6b-ae11-20370f92fa09",
 PageBreakWithin->Automatic,
 CellTags->{"ShowRange", "RG10.", "RG11."}],
Cell[853765, 17591, 11298, 191, 438, "Print",ExpressionUUID->"877e34fe-4ce3-4102-a844-c6adfe1e2227",
 CellTags->{"ShowRange", "RG10.", "RG11."}]
}, Open  ]],
Cell[865078, 17785, 1021, 35, 38, "Text",ExpressionUUID->"0a819798-1313-47bc-b289-5b2becae311b",
 Evaluatable->False,
 CellTags->{"ShowRange", "RG10.", "RG11."}],
Cell[866102, 17822, 170, 3, 20, "Text",ExpressionUUID->"d4d6509b-1bb1-476c-99c4-a60ac1b3776c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[866309, 17830, 314, 12, 63, "Section",ExpressionUUID->"bd0bb247-7bc3-4815-8b2b-9ad91600848b",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ReadRays", "12.", "RG12."}],
Cell[866626, 17844, 370, 10, 21, "Text",ExpressionUUID->"13dfbd3e-a75a-4c9a-bca5-1ac9141cc3d0",
 Evaluatable->False,
 CellTags->{"ReadRays", "RG12."}],
Cell[866999, 17856, 915, 36, 51, "FramedBox",ExpressionUUID->"ea5251f0-0c41-4a77-8e3b-bde02cad7014",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ReadRays", "RG12."}],
Cell[867917, 17894, 637, 17, 34, "Text",ExpressionUUID->"1050e920-03fb-4f3e-ae26-7e4e6e181dc9",
 Evaluatable->False,
 CellTags->{"ReadRays", "RG12."}],
Cell[CellGroupData[{
Cell[868579, 17915, 253, 6, 24, "Input",ExpressionUUID->"fe649223-7d68-4e85-b6f0-1d4135c645e1",
 PageBreakWithin->Automatic,
 CellTags->{"ReadRays", "RG12."}],
Cell[868835, 17923, 502, 9, 23, "Output",ExpressionUUID->"2d332d18-8f36-4def-bdfb-fe46a3ca4054",
 CellTags->{"ReadRays", "RG12."}]
}, Open  ]],
Cell[869352, 17935, 290, 10, 21, "Text",ExpressionUUID->"47dff9d5-d9f6-4181-abad-0242b6d5c9ef",
 Evaluatable->False,
 CellTags->{"ReadRays", "InputForm", "RG12."}],
Cell[CellGroupData[{
Cell[869667, 17949, 209, 4, 24, "Input",ExpressionUUID->"a4c1ace1-3fbb-4027-9df6-3ef68a956e73",
 PageBreakWithin->Automatic,
 CellTags->{"ReadRays", "InputForm", "RG12."}],
Cell[869879, 17955, 564, 14, 47, "Output",ExpressionUUID->"79a1d2f7-7f12-4630-9a60-449f5dd8dd21",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 CellTags->{"ReadRays", "InputForm", "RG12."}]
}, Open  ]],
Cell[870458, 17972, 748, 26, 38, "Text",ExpressionUUID->"d3a991ea-bb9d-471a-8006-f40e33774c4f",
 Evaluatable->False,
 CellTags->{"ReadRays", "RG12."}],
Cell[871209, 18000, 170, 3, 20, "Text",ExpressionUUID->"3b5c3ef3-45c4-4b44-8a67-3d791441bfcb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[871416, 18008, 225, 8, 63, "Section",ExpressionUUID->"f16b8b76-3abc-432f-8b79-58f74680382d",
 CellTags->{"PropagateSystem", "13.", "RG13."}],
Cell[871644, 18018, 533, 16, 22, "Text",ExpressionUUID->"689a409b-f5af-413a-907b-9b9cec7d70ae",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
Cell[872180, 18036, 1063, 37, 68, "FramedBox",ExpressionUUID->"437f1c99-1fe9-4e37-aac6-8df84c32b157",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
Cell[873246, 18075, 569, 16, 38, "Text",ExpressionUUID->"e7af37bd-e79a-4c38-9b7d-354f4c5af775",
 CellTags->{"PropagateSystem", "RG13."}],
Cell[CellGroupData[{
Cell[873840, 18095, 625, 13, 122, "Input",ExpressionUUID->"7e6e0e5e-ff02-4193-8367-bfdbf2f121c1",
 PageBreakWithin->Automatic,
 CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}],
Cell[874468, 18110, 547, 9, 23, "Output",ExpressionUUID->"5ef2f2a4-82c6-4e09-ba33-6b110c9e82af",
 CellTags->{"Screen", "focal plane of system", "PropagateSystem", "RG13."}]
}, Open  ]],
Cell[875030, 18122, 916, 25, 51, "Text",ExpressionUUID->"7deed9e8-abe9-4501-81eb-e91376c45f45",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "PropagateSystem", "RG13."}],
Cell[875949, 18149, 170, 3, 20, "Text",ExpressionUUID->"04de5925-9e8f-4b1c-95d9-ed36b11f1035"]
}, Open  ]],
Cell[CellGroupData[{
Cell[876156, 18157, 273, 8, 60, "Section",ExpressionUUID->"de61901f-8900-49ff-b492-3f3ed363f3d4",
 CellTags->{"TurboPlot", "14.", "14. Introduction", "RG14.", "RG14.0"}],
Cell[876432, 18167, 1144, 33, 54, "Text",ExpressionUUID->"d3877f7e-b5e8-410a-b8aa-a53668772f90",
 Evaluatable->False,
 CellTags->{"ray tracing", "DrawSystem", "TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
Cell[877579, 18202, 924, 31, 84, "FramedBox",ExpressionUUID->"3153d43a-d797-444b-88a0-92f1b0376a86",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"TurboPlot", "TurboTrace", "14. Introduction", "RG14.", "RG14.0"}],
Cell[878506, 18235, 1937, 50, 116, "Text",ExpressionUUID->"29a70b22-afb3-4a67-9ca0-396573e8c165",
 CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
Cell[880446, 18287, 306, 6, 57, "Input",ExpressionUUID->"02ae3c14-bbdf-4017-8ab7-57b0db814fcc",
 CellTags->{"TurboPlot", "14. Introduction", "14.1", "RG14.", "RG14.0"}],
Cell[880755, 18295, 1503, 38, 85, "Text",ExpressionUUID->"0aa5efea-2314-4787-add1-c1cbe3b2041d",
 CellTags->{"TurboPlot", "14. Introduction", "RG14.", "RG14.0"}],
Cell[882261, 18335, 210, 5, 20, "Text",ExpressionUUID->"0b78c116-1673-43d7-b13b-269d0483e4c4",
 CellTags->{"TurboPlot", "RG14."}],
Cell[CellGroupData[{
Cell[882496, 18344, 264, 7, 35, "Subsection",ExpressionUUID->"9c1f755a-9067-4879-8ddd-7bed3f4c37ee",
 CellTags->{"AnalyzeSystem versus TurboPlot", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[882763, 18353, 524, 14, 34, "Text",ExpressionUUID->"5d45d815-e34a-4638-b9aa-6a2cae8bcc92",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[CellGroupData[{
Cell[883312, 18371, 207, 2, 24, "Input",ExpressionUUID->"735af2c0-1890-47d1-927f-6c25ec9a3696",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[883522, 18375, 22837, 385, 250, "Print",ExpressionUUID->"30129e9c-da09-4b82-99d7-c51a0ba85383",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[906362, 18762, 1112, 30, 36, "Print",ExpressionUUID->"8af346c3-607a-4d3c-b60b-37087ac743cf",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[907477, 18794, 440, 8, 24, "Output",ExpressionUUID->"1be6b05a-38ba-4dd0-9c1b-bf8a553810e2",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]
}, Open  ]],
Cell[907932, 18805, 601, 14, 38, "Text",ExpressionUUID->"858724e0-3458-4097-a3ad-5905352e1e8a",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[CellGroupData[{
Cell[908558, 18823, 203, 2, 24, "Input",ExpressionUUID->"4316b42e-16b4-4337-b1d0-5fcbb5018272",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[908764, 18827, 19666, 328, 250, "Print",ExpressionUUID->"a775210d-8ac8-4f96-881b-f0406171236d",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[928433, 19157, 424, 8, 24, "Output",ExpressionUUID->"2701a2cb-a51f-48fb-8a91-292322a5ed60",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]
}, Open  ]],
Cell[928872, 19168, 2384, 53, 150, "Text",ExpressionUUID->"7563334e-5902-41f8-a1df-a57b98fd95db",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[931259, 19223, 288, 6, 57, "Input",ExpressionUUID->"82dd5976-98c4-4850-8129-65296a055626",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[931550, 19231, 247, 7, 21, "Text",ExpressionUUID->"8a0d808b-3acd-42e1-8a4e-3cbf9708bab9",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[CellGroupData[{
Cell[931822, 19242, 294, 8, 24, "Input",ExpressionUUID->"4ba6f6b3-7128-4561-bf3a-51d141ee8235",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[932119, 19252, 13905, 237, 135, "Print",ExpressionUUID->"d17e9029-8a30-4cfd-a2de-1ef7fd95dc7b",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[946027, 19491, 426, 8, 24, "Output",ExpressionUUID->"0654bc51-0d0e-44fc-9ad4-a4a620076efc",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]
}, Open  ]],
Cell[946468, 19502, 342, 10, 21, "Text",ExpressionUUID->"b6867a6d-2e38-4d9a-8d99-c590923b8370",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[CellGroupData[{
Cell[946835, 19516, 202, 2, 24, "Input",ExpressionUUID->"dcf9a401-6d74-4dca-b0a9-dbfb831b5a69",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[947040, 19520, 19508, 327, 250, "Print",ExpressionUUID->"17aad0ef-4d85-49dc-8687-7a9910b92579",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[966551, 19849, 425, 8, 24, "Output",ExpressionUUID->"19a4ddc9-b309-4657-a005-e419ddaea093",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]
}, Open  ]],
Cell[966991, 19860, 658, 16, 38, "Text",ExpressionUUID->"ba8154d8-97ee-46e3-af97-1bfcda3007ef",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[967652, 19878, 567, 17, 51, "FramedBox",ExpressionUUID->"90282067-0c13-4cd5-86e4-6ad2c7f8fe2f",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"SymbolicValues", "TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[968222, 19897, 250, 7, 21, "Text",ExpressionUUID->"584eb23d-c0e4-4cf3-a9f3-f1123ef41b41",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[CellGroupData[{
Cell[968497, 19908, 280, 6, 24, "Input",ExpressionUUID->"0c4146da-356c-4135-94fc-acd9c4891d21",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[968780, 19916, 14063, 238, 135, "Print",ExpressionUUID->"c2262dfd-d7a6-4354-93bc-b64c5143062b",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[982846, 20156, 424, 8, 24, "Output",ExpressionUUID->"cd0d7832-4882-42ac-aeec-555723c25398",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]
}, Open  ]],
Cell[983285, 20167, 899, 20, 54, "Text",ExpressionUUID->"8df57715-fe35-4019-a07d-935cd5a2b382",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[CellGroupData[{
Cell[984209, 20191, 314, 6, 24, "Input",ExpressionUUID->"c7a7c134-59da-4d2c-9066-7712b50842ab",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[984526, 20199, 15065, 256, 136, "Print",ExpressionUUID->"79dbe714-1168-4ff2-a903-f39e4fe98437",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[999594, 20457, 427, 8, 24, "Output",ExpressionUUID->"5c23b081-6025-46f9-8058-23f0ddb28122",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}]
}, Open  ]],
Cell[1000036, 20468, 462, 12, 38, "Text",ExpressionUUID->"55aa0c10-0f2e-40e5-b147-d90827498dd5",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[1000501, 20482, 623, 15, 38, "Text",ExpressionUUID->"d1849c45-2f29-4caa-9f87-63d7f316366a",
 CellTags->{"TurboPlot", "14.1", "RG14.", "RG14.1"}],
Cell[1001127, 20499, 210, 5, 20, "Text",ExpressionUUID->"43b79d3c-25d1-403a-95e3-08fa65c30a51",
 CellTags->{"TurboPlot", "RG14."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[1001374, 20509, 194, 3, 35, "Subsection",ExpressionUUID->"a0ca6d8b-5959-4689-bcf2-a00628a3a37d",
 CellTags->{"CreateClones", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1001571, 20514, 619, 19, 38, "Text",ExpressionUUID->"a90ae5b6-7add-4130-878d-cf27bd3d377f",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1002193, 20535, 1009, 31, 64, "FramedBox",ExpressionUUID->"bcac5337-6dc7-4955-b6fd-2bf3f27f6752",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"SymbolicValues", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1003205, 20568, 1956, 47, 116, "Text",ExpressionUUID->"f2eb698c-dfad-4527-9f7b-106a2af4bfa3",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1005164, 20617, 286, 9, 106, "Input",ExpressionUUID->"3d9f37b8-a9c7-4b91-a648-ad87a2a1e908",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1005453, 20628, 325, 10, 21, "Text",ExpressionUUID->"d9110934-fde3-43cf-9643-be18578b550b",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1005781, 20640, 184, 2, 24, "Input",ExpressionUUID->"1ecb9700-e924-4fa3-bdaf-531de38950d0",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1005968, 20644, 489, 15, 34, "Text",ExpressionUUID->"42dc2622-9471-42c3-a3f3-61f3f7d82508",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1006460, 20661, 556, 19, 51, "FramedBox",ExpressionUUID->"d60aedc0-f21a-41a4-b8bf-21faa0ccee4b",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"BallLens", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1007019, 20682, 431, 11, 21, "Text",ExpressionUUID->"9242d2d5-8928-426b-b5ac-4a96ee390dbe",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[CellGroupData[{
Cell[1007475, 20697, 347, 6, 57, "Input",ExpressionUUID->"eecc06bf-c7ed-45b9-a4f4-24ee8c6632e7",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1007825, 20705, 287, 5, 20, "Print",ExpressionUUID->"61a0f1ab-c69a-45ca-b951-868a02bace37",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1008115, 20712, 273, 5, 19, "Print",ExpressionUUID->"b5d7340c-5ec3-4fe7-9d03-09cc88fbe637",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1008391, 20719, 403, 9, 20, "Print",ExpressionUUID->"2d34b417-9b1a-4ec2-9bbc-51a827395fef",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1008797, 20730, 396, 9, 19, "Print",ExpressionUUID->"194685f5-51ca-400c-ac76-52d433b092e4",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1009196, 20741, 155603, 3614, 2712, "Print",ExpressionUUID->"9e5f9dee-8ead-479a-b7ab-b29ca9c88f05",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1164802, 24357, 402, 9, 20, "Print",ExpressionUUID->"5a157a4a-5cd0-4ff8-9446-a9a4d1cf4f63",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1165207, 24368, 285, 5, 20, "Print",ExpressionUUID->"a7ac1691-3058-41ef-b826-3e248fce341f",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1165495, 24375, 592, 13, 20, "Print",ExpressionUUID->"68ed0864-f5f9-4899-9e1d-f86d4eb9da48",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1166090, 24390, 294, 5, 20, "Print",ExpressionUUID->"a3c73fa8-cd00-4292-8000-e81065aa2e52",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1166387, 24397, 434, 10, 20, "Print",ExpressionUUID->"5e96a7e3-3195-49c5-a721-3e13d8eba6dd",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1166824, 24409, 299, 5, 20, "Print",ExpressionUUID->"73b92b16-de30-4bf4-8330-439f37608ec1",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1167126, 24416, 294, 5, 20, "Print",ExpressionUUID->"116e553e-8c5d-4dc1-a5f3-801621bf9f27",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1167423, 24423, 295, 5, 20, "Print",ExpressionUUID->"6276257f-c7ec-4594-ad4f-72208f6b4d0f",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1167721, 24430, 564, 13, 20, "Print",ExpressionUUID->"5a6866f8-45c9-4989-b288-05184518c8f4",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1168288, 24445, 280, 5, 20, "Print",ExpressionUUID->"b9cffd6e-5cfc-4fb1-a8d3-92d7bd52cace",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1168571, 24452, 291, 5, 20, "Print",ExpressionUUID->"b0d73961-ee2c-4ee2-b8a0-2f0c81abd029",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1168865, 24459, 284, 5, 20, "Print",ExpressionUUID->"1ca37af5-a564-4e12-963d-e72507044653",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1169152, 24466, 408, 10, 20, "Print",ExpressionUUID->"6b21dd82-13da-49a4-bfcc-1692d2a751f9",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1169563, 24478, 470, 12, 20, "Print",ExpressionUUID->"6d322694-d70a-45fe-91ab-4a334dca967d",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1170036, 24492, 293, 5, 20, "Print",ExpressionUUID->"2602bd1b-8e54-4f2d-985e-854ee2ebdd2e",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1170332, 24499, 3005, 67, 36, "Print",ExpressionUUID->"24daf8aa-d778-478d-b1bb-3cb981a0470c",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1173340, 24568, 298, 5, 20, "Print",ExpressionUUID->"dec65d5e-7134-4048-bd69-fcddd67bff86",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1173641, 24575, 380, 9, 20, "Print",ExpressionUUID->"5def9516-870b-45c4-bb4d-185c5bf57e2b",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1174024, 24586, 410, 10, 20, "Print",ExpressionUUID->"569cd10d-ec2f-4e84-b8fa-4bbe68d67c43",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1174437, 24598, 285, 5, 20, "Print",ExpressionUUID->"dbc020dc-58c1-450b-987e-0de518fcb018",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1174725, 24605, 420, 9, 20, "Print",ExpressionUUID->"06ebf166-0ece-4a92-84a9-2078defc9ffd",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1175148, 24616, 402, 9, 20, "Print",ExpressionUUID->"4a173113-385f-46f7-9c3d-0b055bbb25e5",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1175553, 24627, 406, 9, 20, "Print",ExpressionUUID->"931ebe39-1913-4ea1-a5d6-0c9aefc4d074",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1175962, 24638, 271, 5, 20, "Print",ExpressionUUID->"fc7c54b5-8308-460e-a42b-d07ec905a15a",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1176236, 24645, 434, 10, 20, "Print",ExpressionUUID->"4060f68c-4778-4814-9ce7-8d1f7fd45431",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1176673, 24657, 608, 14, 20, "Print",ExpressionUUID->"c2df0822-6d87-4e5a-bdfe-fdb1e7570704",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1177284, 24673, 775, 15, 22, "Message",ExpressionUUID->"d47b94fb-92d1-4460-93e6-ffdef0044a62",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1178062, 24690, 442, 10, 20, "Print",ExpressionUUID->"372e005e-ae85-45d5-b357-dccdbfec3b2e",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1178507, 24702, 730, 15, 20, "Print",ExpressionUUID->"2444f75e-2c81-4fc8-bcee-98bc3bccbf99",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1179240, 24719, 306, 6, 20, "Print",ExpressionUUID->"cde16d7f-25f9-49c2-8d01-9591f38344b8",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1179549, 24727, 282, 5, 20, "Print",ExpressionUUID->"1939d258-9116-4640-8d0a-a8e388c1c894",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1179834, 24734, 286, 5, 20, "Print",ExpressionUUID->"30244d4b-b1f1-4417-a269-c577adbf4778",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1180123, 24741, 279, 5, 20, "Print",ExpressionUUID->"3b6f39ab-476c-4aeb-8ace-ef042b612aa2",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1180405, 24748, 304, 6, 20, "Print",ExpressionUUID->"372b9b9a-5013-4ebb-9371-b8c7809d5a85",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1180712, 24756, 304, 6, 20, "Print",ExpressionUUID->"ccdfd2bb-c013-42e4-99bb-9aab14e88f10",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1181019, 24764, 304, 6, 20, "Print",ExpressionUUID->"07c418d1-350c-47f1-b1a3-2dbcf1f4738c",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1181326, 24772, 304, 6, 20, "Print",ExpressionUUID->"c9a2bb0f-da80-40ea-8eaa-0a1efb0c580f",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1181633, 24780, 281, 5, 20, "Print",ExpressionUUID->"63686a72-2217-4f16-b1dc-3b9f396962c5",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1181917, 24787, 293, 5, 20, "Print",ExpressionUUID->"830aa83c-4800-4bb1-8ca2-22aff9582db6",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1182213, 24794, 279, 5, 20, "Print",ExpressionUUID->"1ed4033f-5589-4337-a159-deb93b7ea346",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[1182495, 24801, 1129508, 18866, 341, "Print",ExpressionUUID->"fdb36d72-ab79-4189-a843-7506cad40be2",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}]
}, Open  ]],
Cell[2312018, 43670, 1213, 33, 70, "Text",ExpressionUUID->"9c4ed069-1dcb-4b31-b3b4-de62ad8e215e",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[2313234, 43705, 288, 8, 21, "Text",ExpressionUUID->"0d7d4221-ebf2-4a36-a888-5a1eb445b649",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[2313525, 43715, 1241, 43, 97, "FramedBox",ExpressionUUID->"d618b69a-b231-4e2f-81e3-32bc4a9dd673",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ShowClones", "ShowArrows", "RunningCommentary", "TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[2314769, 43760, 490, 15, 34, "Text",ExpressionUUID->"e2766717-50f1-411a-8db8-c3dba15ad878",
 CellTags->{"TurboPlot", "14.2", "RG14.", "RG14.2"}],
Cell[2315262, 43777, 210, 5, 20, "Text",ExpressionUUID->"bfafdff3-9501-4a72-ad94-f41a96b5bd5d",
 CellTags->{"TurboPlot", "RG14."}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2315521, 43788, 219, 7, 60, "Section",ExpressionUUID->"5c62ed6d-b544-44e0-affc-dcff777c52d7",
 CellTags->{"OptimizeSystem", "15.", "RG15."}],
Cell[2315743, 43797, 532, 11, 37, "Text",ExpressionUUID->"419b7f51-9a7b-481a-b9c5-ae3663216c45",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2316278, 43810, 584, 20, 51, "FramedBox",ExpressionUUID->"188eecd5-87fc-44a1-97a8-d53de79f8064",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2316865, 43832, 675, 16, 38, "Text",ExpressionUUID->"9de3c256-3fe2-4d8a-a0f5-0251a566a82a",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2317543, 43850, 825, 34, 51, "FramedBox",ExpressionUUID->"464f8f91-b6db-4961-a243-0eaa5ee35b2f",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"SphericalLens", "OptimizeSystem", "RG15."}],
Cell[2318371, 43886, 311, 9, 21, "Text",ExpressionUUID->"2e5b0ef5-c7c3-44c6-ba4b-0e7f59661041",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2318685, 43897, 300, 7, 73, "Input",ExpressionUUID->"cc023c24-24c2-4956-bf37-e220676eb9b5",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
Cell[2318988, 43906, 673, 16, 38, "Text",ExpressionUUID->"f106fd40-d378-4d6e-8a02-ef34ac16d402",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[CellGroupData[{
Cell[2319686, 43926, 289, 8, 24, "Input",ExpressionUUID->"edc39bfb-d98f-454b-ba00-fa5626702911",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2319978, 43936, 10054, 177, 135, "Print",ExpressionUUID->"326b1886-ce69-4775-b57f-27ed8186400d",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2330035, 44115, 413, 8, 24, "Output",ExpressionUUID->"f0700e2c-2c78-41a6-853d-7af972f922f5",
 CellTags->{"OptimizeSystem", "RG15."}]
}, Open  ]],
Cell[2330463, 44126, 268, 9, 21, "Text",ExpressionUUID->"07b449bf-c5a9-46e5-b911-cfe47228b2b3",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[CellGroupData[{
Cell[2330756, 44139, 199, 2, 24, "Input",ExpressionUUID->"6ece41d5-f3e3-45cf-aa92-7a37515cbd52",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
Cell[2330958, 44143, 810, 18, 24, "Output",ExpressionUUID->"7ab3a572-6034-4db6-82c5-7498be5e4b4a",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}]
}, Open  ]],
Cell[2331783, 44164, 983, 24, 67, "Text",ExpressionUUID->"f12843e5-55ae-47eb-ae22-ba9bb72ec067",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[CellGroupData[{
Cell[2332791, 44192, 265, 6, 24, "Input",ExpressionUUID->"1a01a7b8-d66d-4978-801d-81d2ebe5808e",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}],
Cell[2333059, 44200, 10128, 177, 135, "Print",ExpressionUUID->"1213985f-5e0e-420a-8dab-9c423b2d855e",
 CellTags->{"OptimizeSystem", "ReadTurboRays", "RG15."}]
}, Open  ]],
Cell[2343202, 44380, 682, 18, 38, "Text",ExpressionUUID->"26adf7e2-d329-4e5f-9eb1-652c33ff4999",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[CellGroupData[{
Cell[2343909, 44402, 213, 4, 24, "Input",ExpressionUUID->"e7a71eb1-906b-4f00-b5c4-af9e47b73be8",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2344125, 44408, 787, 17, 24, "Output",ExpressionUUID->"db4e6ada-8a4c-406b-a33e-82257316feac",
 CellTags->{"OptimizeSystem", "RG15."}]
}, Open  ]],
Cell[2344927, 44428, 843, 15, 60, "Text",ExpressionUUID->"2002864d-91c5-4d29-bf56-0440598d610f",
 CellTags->{"OptimizeSystem", "RG15."}],
Cell[2345773, 44445, 170, 3, 20, "Text",ExpressionUUID->"d6bcaf1c-8738-4475-9022-fe1fc2493382"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2345980, 44453, 369, 14, 60, "Section",ExpressionUUID->"e91ead7e-40a8-487a-bf8c-0484bf29162e",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"ReadTurboRays", "16.", "RG16."}],
Cell[2346352, 44469, 729, 24, 38, "Text",ExpressionUUID->"e6500628-5d71-46fb-a65d-25f64f40cdac",
 Evaluatable->False,
 CellTags->{"ReadTurboRays", "RG16."}],
Cell[2347084, 44495, 988, 38, 64, "FramedBox",ExpressionUUID->"fa23eb4b-123d-4b73-8c2a-049c29b39f31",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ReadTurboRays", "RG16."}],
Cell[2348075, 44535, 851, 28, 38, "Text",ExpressionUUID->"27dc19c8-3f1e-4113-8d48-6d8c91574faf",
 Evaluatable->False,
 CellTags->{"ReadTurboRays", "RG16."}],
Cell[CellGroupData[{
Cell[2348951, 44567, 331, 10, 24, "Input",ExpressionUUID->"ac39550a-adc9-476a-badc-8f596522a545",
 PageBreakWithin->Automatic,
 CellTags->{"ReadTurboRays", "RG16."}],
Cell[2349285, 44579, 631, 12, 23, "Output",ExpressionUUID->"c13cb3ca-df62-45ca-b807-f754b94cce80",
 CellTags->{"ReadTurboRays", "RG16."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[2349953, 44596, 336, 10, 24, "Input",ExpressionUUID->"946ef065-9abd-4fb3-be82-da7b516f91d6",
 PageBreakWithin->Automatic,
 CellTags->{"ReadTurboRays", "RG16."}],
Cell[2350292, 44608, 635, 12, 23, "Output",ExpressionUUID->"3f20e29b-88cd-423d-8ef8-208f94dec97c",
 CellTags->{"ReadTurboRays", "RG16."}]
}, Open  ]],
Cell[2350942, 44623, 797, 31, 38, "Text",ExpressionUUID->"a97f46df-9b47-4469-9823-01f3549ca975",
 CellTags->{"ReadTurboRays", "RG16."}],
Cell[2351742, 44656, 170, 3, 20, "Text",ExpressionUUID->"5b1727ec-11f1-466b-8ffa-b4a074884a97"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2351949, 44664, 264, 7, 60, "Section",ExpressionUUID->"95b870e4-08e2-4824-a2f5-318143f92fb1",
 CellTags->{"FindIntensity", "17.", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
Cell[2352216, 44673, 489, 12, 37, "Text",ExpressionUUID->"b39192dd-6785-4636-95f1-d7902bf6e6c8",
 CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
Cell[2352708, 44687, 756, 26, 51, "FramedBox",ExpressionUUID->"e37a6300-f17f-4524-895d-80b21d5e303b",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
Cell[2353467, 44715, 1670, 50, 70, "Text",ExpressionUUID->"b3e52c49-643d-4f39-b19a-d11af54bc6f0",
 CellTags->{"FindIntensity", "17. Introduction", "RG17.", "RG17.1", "RG17.0"}],
Cell[2355140, 44767, 224, 5, 20, "Text",ExpressionUUID->"20a964d3-7fe5-429c-a9f8-92f8d718eb4d",
 CellTags->{"FindIntensity", "RG17.", "RG17.1"}],
Cell[CellGroupData[{
Cell[2355389, 44776, 318, 7, 35, "Subsection",ExpressionUUID->"d3079b71-3c8d-403b-95ed-e0c12c644377",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1", "17.1"}],
Cell[2355710, 44785, 860, 19, 51, "Text",ExpressionUUID->"3309fe78-8bea-41d2-9e89-be26e8481dcc",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[CellGroupData[{
Cell[2356595, 44808, 330, 8, 73, "Input",ExpressionUUID->"047766fb-8eda-427a-9c3e-35823ea5836e",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[2356928, 44818, 964, 22, 20, "Print",ExpressionUUID->"0de2e702-472d-4a7d-a33a-128938072ae6",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[2357895, 44842, 323025, 5562, 296, "Print",ExpressionUUID->"eeabf9da-4b78-4217-9378-83252c32fedd",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[2680923, 50406, 333374, 5584, 131, "Output",ExpressionUUID->"1c035b97-c43f-4851-8b25-054d8a319820",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}]
}, Open  ]],
Cell[3014312, 55993, 1281, 31, 72, "Text",ExpressionUUID->"61fe767f-feb3-477a-a22f-08ad310cb74c",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3015596, 56026, 284, 7, 21, "Text",ExpressionUUID->"9f08fe51-ea3c-4aaa-9cef-8c9e59b7d550",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[CellGroupData[{
Cell[3015905, 56037, 253, 7, 24, "Input",ExpressionUUID->"6c99f091-180f-479e-a164-578479e304a5",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3016161, 56046, 2360, 47, 104, "Output",ExpressionUUID->"af9e7bec-c4e9-4c06-977f-2f278dbbb732",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}]
}, Open  ]],
Cell[3018536, 56096, 356, 8, 21, "Text",ExpressionUUID->"cc3b45c7-e4f3-4e3c-b46f-6d6e177fe337",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3018895, 56106, 904, 25, 114, "FramedBox",ExpressionUUID->"46cb697f-b80f-4d01-bd6c-4876a42ca360",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3019802, 56133, 283, 8, 27, "Commentary",ExpressionUUID->"c67f89f6-560d-495a-8599-39f4b27400df",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3020088, 56143, 292, 6, 20, "Text",ExpressionUUID->"e5a6054d-dd48-4061-bcbb-f0b7a1201f9a",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3020383, 56151, 396, 9, 21, "Text",ExpressionUUID->"acbccdd9-b6e4-4445-8c63-5d21e8a43520",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3020782, 56162, 911, 25, 100, "FramedBox",ExpressionUUID->"b12cff0f-1804-413d-bff6-f56faf7def3f",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Plot2D", "FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3021696, 56189, 257, 8, 27, "Commentary",ExpressionUUID->"7831497e-8aba-4284-b96e-49915e0b2651",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3021956, 56199, 756, 18, 51, "Text",ExpressionUUID->"b637b49d-dc30-4a08-809d-bb46795dbf59",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[CellGroupData[{
Cell[3022737, 56221, 234, 3, 24, "Input",ExpressionUUID->"1b065470-deed-4044-8680-13146f928883",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}],
Cell[3022974, 56226, 731153, 12157, 371, "Print",ExpressionUUID->"2c1a3fe1-f530-44e5-ad59-dc837b0018fa",
 CellTags->{"FindIntensity", "2-D Calculations with FindIntensity", "RG17.", "RG17.1"}]
}, Open  ]],
Cell[3754142, 68386, 214, 5, 20, "Text",ExpressionUUID->"7db99dae-8ac2-4250-90f0-8207449940a8",
 CellTags->{"FindIntensity", "RG17."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[3754393, 68396, 266, 7, 35, "Subsection",ExpressionUUID->"48957a1c-fa8a-4f5a-aa3a-051bf28c5250",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2", "17.2"}],
Cell[3754662, 68405, 967, 20, 67, "Text",ExpressionUUID->"1e979e95-2969-4469-bdb2-4b4c0c51ff29",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[CellGroupData[{
Cell[3755654, 68429, 353, 7, 73, "Input",ExpressionUUID->"bf84e43a-fae7-473b-aa4b-b5e31a85f037",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[3756010, 68438, 23625, 395, 213, "Print",ExpressionUUID->"b3b339b6-d05a-4a26-9fcc-fc53d96f9d15",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}]
}, Open  ]],
Cell[3779650, 68836, 420, 10, 21, "Text",ExpressionUUID->"f5f2213a-8c67-4cc7-a6e0-6cc3d95ece0b",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[3780073, 68848, 796, 28, 51, "FramedBox",ExpressionUUID->"a33391f6-588e-4017-94b4-c9b65311d253",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[3780872, 68878, 471, 12, 34, "Text",ExpressionUUID->"72ac0498-3b0e-4219-8bae-6f4e17c2f6fa",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[CellGroupData[{
Cell[3781368, 68894, 182, 2, 24, "Input",ExpressionUUID->"9f4a8b78-0096-4924-824c-df2fc5d1f38e",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[3781553, 68898, 21105, 421, 354, "Print",ExpressionUUID->"16d21f8f-ecc7-4ca0-8326-e017183ba907",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[3802661, 69321, 1326, 31, 56, "Output",ExpressionUUID->"8a13b68c-4edf-455a-bfd8-08aa9b5a8063",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}]
}, Open  ]],
Cell[3804002, 69355, 1004, 26, 54, "Text",ExpressionUUID->"ef728d99-f6af-4701-821f-7667055c288e",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[CellGroupData[{
Cell[3805031, 69385, 188, 2, 24, "Input",ExpressionUUID->"d1fc3e93-d0bb-4abd-abbd-f079d7dd2d57",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}],
Cell[3805222, 69389, 378, 6, 23, "Output",ExpressionUUID->"591b7135-4c02-4d42-8df1-963cbf3dd8a1",
 CellTags->{"FindIntensity", "FindFocus", "RG17.", "RG17.2"}]
}, Open  ]],
Cell[3805615, 69398, 214, 5, 20, "Text",ExpressionUUID->"0767282a-0043-4f56-9f76-2b558adf3ab0",
 CellTags->{"FindIntensity", "RG17."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[3805866, 69408, 312, 8, 35, "Subsection",ExpressionUUID->"1e5db568-2377-4b14-a68a-6c85dceeb176",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "17.3", "Point Spread Function (PSF)"}],
Cell[3806181, 69418, 458, 13, 21, "Text",ExpressionUUID->"7ee32d46-f354-4350-98ce-745d5fe62fb5",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[CellGroupData[{
Cell[3806664, 69435, 397, 8, 89, "Input",ExpressionUUID->"03f38441-916b-4472-a72f-cebe22f1de4b",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[3807064, 69445, 963, 21, 20, "Print",ExpressionUUID->"a389c04a-1214-4a12-9503-59d753754c5f",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[3808030, 69468, 1039597, 17914, 280, "Print",ExpressionUUID->"9e219fa5-0d2f-4a98-8336-e967b4266678",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[4847630, 87384, 1068108, 17936, 114, "Output",ExpressionUUID->"faea0d3b-afe1-4883-b972-798f0b1cc126",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}]
}, Open  ]],
Cell[5915753, 105323, 522, 14, 34, "Text",ExpressionUUID->"41ceb80e-2181-4cd7-b774-e47b379c16d3",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[CellGroupData[{
Cell[5916300, 105341, 222, 2, 24, "Input",ExpressionUUID->"4bb39fd2-06ac-4850-8973-a84b4945ffe4",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5916525, 105345, 956, 21, 20, "Print",ExpressionUUID->"e31d0700-a56e-4a47-9922-4c9df4642880",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5917484, 105368, 66039, 1197, 249, "Print",ExpressionUUID->"e24be2f9-c5d4-481a-b7cb-42d643c4e308",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}]
}, Open  ]],
Cell[5983538, 106568, 1774, 36, 119, "Text",ExpressionUUID->"6a8298d3-cd1c-4426-ba27-6e0e9d9c4ef0",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5985315, 106606, 1303, 53, 64, "FramedBox",ExpressionUUID->"383b92d9-bb1f-4fa8-9b79-4d97513a96de",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5986621, 106661, 468, 15, 21, "Text",ExpressionUUID->"8f2a8809-ca0e-424e-b3dd-02b65ee36fc7",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5987092, 106678, 919, 35, 51, "FramedBox",ExpressionUUID->"de33a8b9-bafc-4dc0-a878-7ae11c86ac7a",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5988014, 106715, 992, 30, 38, "Text",ExpressionUUID->"b6b2e779-1a5b-4ed1-b908-aea9d02a4f32",
 CellTags->{"FindIntensity", "RG17.", "RG17.3", "Point Spread Function (PSF)"}],
Cell[5989009, 106747, 214, 5, 20, "Text",ExpressionUUID->"c35f1e2e-2fa0-4f19-b803-21670f38c3eb",
 CellTags->{"FindIntensity", "RG17."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[5989260, 106757, 316, 7, 35, "Subsection",ExpressionUUID->"a68fa382-f002-468f-95d1-aaee94a5e786",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4", "17.4"}],
Cell[5989579, 106766, 469, 12, 38, "Text",ExpressionUUID->"30c801a3-37d5-4911-b3a1-d9d387a5f414",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
Cell[5990051, 106780, 730, 23, 51, "FramedBox",ExpressionUUID->"9c0d1061-6d13-4c39-8a38-fc416aeca7f4",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17.", "RG17.4"}],
Cell[5990784, 106805, 551, 13, 34, "Text",ExpressionUUID->"86795780-c101-4bd7-81de-63e3b9e5d003",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
Cell[CellGroupData[{
Cell[5991360, 106822, 212, 3, 24, "Input",ExpressionUUID->"69d700c4-c02f-46db-91df-f1f4ad496ccd",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
Cell[5991575, 106827, 1277, 28, 56, "Output",ExpressionUUID->"b3e7fbc4-8c5c-4773-8b21-2c1f50002099",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[5992889, 106860, 219, 3, 24, "Input",ExpressionUUID->"05011727-66ba-42d7-9311-76ce95abffd2",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
Cell[5993111, 106865, 34653, 618, 242, "Print",ExpressionUUID->"532b389b-e46b-494e-850f-5801f1dd3eb4",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
Cell[6027767, 107485, 1134284, 18596, 192, "Output",ExpressionUUID->"8b30f9f8-5631-422e-a696-d65c329e250a",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}]
}, Open  ]],
Cell[7162066, 126084, 766, 18, 51, "Text",ExpressionUUID->"97450984-6a0c-4acf-9174-51e10e28d20a",
 CellTags->{"ModulationTransferFunction", "FindIntensity", "RG17.", "RG17.4"}],
Cell[7162835, 126104, 244, 5, 20, "Text",ExpressionUUID->"8381b864-31bc-46c1-8f73-17774d620556",
 CellTags->{"FindIntensity", "ModulationTransferFunction", "RG17."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7163116, 126114, 318, 7, 35, "Subsection",ExpressionUUID->"948bf3aa-ffa4-4b5b-ad11-b7370dfacdc0",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5", "17.5"}],
Cell[7163437, 126123, 529, 12, 38, "Text",ExpressionUUID->"34623c4b-fe27-43e8-bd53-4b5427b399dd",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[CellGroupData[{
Cell[7163991, 126139, 403, 9, 73, "Input",ExpressionUUID->"fb3f9c9b-3e34-4d0e-ab34-9367873467c2",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7164397, 126150, 15205, 257, 216, "Print",ExpressionUUID->"73e948d6-1694-44b4-ae7d-aa818ce26431",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}]
}, Open  ]],
Cell[7179617, 126410, 1060, 22, 67, "Text",ExpressionUUID->"f8f0bdcf-fab1-40be-95b1-7e144ffe3c6c",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[CellGroupData[{
Cell[7180702, 126436, 585, 13, 89, "Input",ExpressionUUID->"5edc0363-6e09-425e-a719-e41a4ce3275a",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7181290, 126451, 1017, 23, 20, "Print",ExpressionUUID->"2838a744-8620-4e26-a900-a8328ac1c274",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7182310, 126476, 40684, 723, 249, "Print",ExpressionUUID->"2f268b14-14d8-48a5-a7eb-687acda3458f",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7222997, 127201, 1020, 23, 20, "Print",ExpressionUUID->"3e3c72dd-d769-434f-b710-2079c05b91f7",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7224020, 127226, 53528, 952, 249, "Print",ExpressionUUID->"a296cdfd-0141-441f-98aa-ef27a78ddd7c",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7277551, 128180, 101438, 1706, 301, "Output",ExpressionUUID->"a1a52898-e5e7-40a2-bad0-b10bb386556d",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}]
}, Open  ]],
Cell[7379004, 129889, 958, 24, 54, "Text",ExpressionUUID->"3dd53550-bd89-4434-8178-b4bdb23c4c00",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7379965, 129915, 534, 14, 38, "Text",ExpressionUUID->"d70a31c8-3057-42e4-ad73-12b52a878b1c",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[CellGroupData[{
Cell[7380524, 129933, 245, 6, 24, "Input",ExpressionUUID->"9588485b-e6e9-491f-baef-c7d69029eba3",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7380772, 129941, 422, 8, 20, "Print",ExpressionUUID->"409ae0e2-9603-42ba-980c-4a24dcf7d5df",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7381197, 129951, 338, 5, 23, "Output",ExpressionUUID->"de6bc496-b575-462e-bc44-25ac8b5a9211",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}]
}, Open  ]],
Cell[7381550, 129959, 1382, 20, 85, "Text",ExpressionUUID->"f22e5175-9749-47ac-b69b-4446723b94d5",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17.", "RG17.5"}],
Cell[7382935, 129981, 253, 5, 20, "Text",ExpressionUUID->"c605f174-ab57-4738-8b7a-88a1e288edac",
 CellTags->{"FindIntensity", "1-D Calculations with FindIntensity", "RG17."}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7383237, 129992, 211, 8, 63, "Section",ExpressionUUID->"6ac6bfd3-1a3d-49c7-95bf-3feeaabfa8cd",
 CellTags->{"Resonate", "18.", "RG18."}],
Cell[7383451, 130002, 818, 23, 54, "Text",ExpressionUUID->"8d722c0e-fc4f-44f3-9c41-5eab67bf2242",
 Evaluatable->False,
 CellTags->{"ray tracing", "Resonate", "RG18."}],
Cell[7384272, 130027, 622, 22, 51, "FramedBox",ExpressionUUID->"2a3a4728-f479-438e-ac36-9372ed3ae683",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Resonate", "RG18."}],
Cell[7384897, 130051, 1152, 25, 66, "Text",ExpressionUUID->"f385f2b0-9078-4098-94f4-63d776aa23db",
 Evaluatable->False,
 CellTags->{"ray tracing", "Resonate", "RG18."}],
Cell[CellGroupData[{
Cell[7386074, 130080, 272, 8, 89, "Input",ExpressionUUID->"0c140923-69b9-470b-a77f-5008c14dc1d6",
 CellTags->{"Resonate", "RG18."}],
Cell[7386349, 130090, 30541, 527, 365, "Print",ExpressionUUID->"6917394b-82e0-453f-9725-1fbfafe6fde5",
 CellTags->{"Resonate", "RG18."}]
}, Open  ]],
Cell[7416905, 130620, 287, 7, 21, "Text",ExpressionUUID->"b9ce648b-21ea-45df-ab34-f82451a785f1",
 CellTags->{"Resonate", "RG18."}],
Cell[CellGroupData[{
Cell[7417217, 130631, 236, 8, 89, "Input",ExpressionUUID->"5a9a8588-177e-4de2-83fb-261ce5be10d2",
 CellTags->{"Resonate", "RG18."}],
Cell[7417456, 130641, 785, 23, 23, "Output",ExpressionUUID->"510cfad9-5bec-4894-a87f-08e0b2a1190d",
 CellTags->{"Resonate", "RG18."}]
}, Open  ]],
Cell[7418256, 130667, 491, 13, 38, "Text",ExpressionUUID->"e6647d4c-317d-40ec-9b89-be6bce0d6eb8",
 CellTags->{"Resonate", "RG18."}],
Cell[CellGroupData[{
Cell[7418772, 130684, 146, 2, 24, "Input",ExpressionUUID->"33cb3d49-cf10-4fa5-baa7-e84bbc9e5d2d",
 CellTags->{"Resonate", "RG18."}],
Cell[7418921, 130688, 284, 4, 24, "Output",ExpressionUUID->"17d11535-b739-4885-9703-239044fb0481",
 CellTags->{"Resonate", "RG18."}]
}, Open  ]],
Cell[7419220, 130695, 318, 7, 21, "Text",ExpressionUUID->"71d16563-1462-43f1-98d8-24d033a3d5be",
 CellTags->{"Resonate", "RG18."}],
Cell[CellGroupData[{
Cell[7419563, 130706, 222, 7, 73, "Input",ExpressionUUID->"b4f7d976-188c-4529-9899-687a2e0498f3",
 CellTags->{"Resonate", "RG18."}],
Cell[7419788, 130715, 32007, 545, 365, "Print",ExpressionUUID->"e96c081c-a9aa-41f5-99a6-34254acef2b3",
 CellTags->{"Resonate", "RG18."}]
}, Open  ]],
Cell[7451810, 131263, 371, 11, 21, "Text",ExpressionUUID->"286d46df-c400-4cf9-8232-126cf5763f8b",
 CellTags->{"Resonate", "RG18."}],
Cell[CellGroupData[{
Cell[7452206, 131278, 218, 7, 73, "Input",ExpressionUUID->"08e221a1-ddb4-4fe2-96bc-4448f258c60d",
 CellTags->{"Resonate", "RG18."}],
Cell[7452427, 131287, 14091, 233, 365, "Print",ExpressionUUID->"89ed0fca-2e01-49aa-b26c-a77ffe90711d",
 CellTags->{"Resonate", "RG18."}]
}, Open  ]],
Cell[7466533, 131523, 378, 13, 21, "Text",ExpressionUUID->"8f92118e-8f6c-40ba-8b88-df844e2ec576",
 CellTags->{"Resonate", "RG18."}],
Cell[7466914, 131538, 170, 3, 20, "Text",ExpressionUUID->"531e7d13-ed42-4ebb-9a61-a12438db75a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7467121, 131546, 201, 8, 60, "Section",ExpressionUUID->"2ad8be42-a103-45bc-b5e7-11647de00c94",
 CellTags->{"Database", "19.", "RG19."}],
Cell[7467325, 131556, 1344, 35, 63, "Text",ExpressionUUID->"320ecd25-a05c-4d82-a030-825895be5acc",
 CellTags->{"Database", "RG19."}],
Cell[7468672, 131593, 1409, 47, 126, "FramedBox",ExpressionUUID->"f62bd2bd-7199-4214-9b20-7dd6e400011e",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Database", "RG19."}],
Cell[7470084, 131642, 810, 20, 54, "Text",ExpressionUUID->"5f9a3aef-feca-426c-93d6-6be218e4b1f3",
 CellTags->{"Database", "RG19."}],
Cell[7470897, 131664, 478, 12, 33, "Text",ExpressionUUID->"63bb1f15-1c8d-4b3b-97b4-013c42c4f946",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7471400, 131680, 191, 2, 24, "Input",ExpressionUUID->"c6e33c49-eca9-475d-8690-8d1296cfea33",
 CellTags->{"Database", "RG19."}],
Cell[7471594, 131684, 7200, 164, 278, "Output",ExpressionUUID->"071c5fc1-692c-44bc-b0de-d41e4f3dded6",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7478809, 131851, 1255, 29, 79, "Text",ExpressionUUID->"cae6081d-4799-4ecd-8bff-afa8022ea3e3",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7480089, 131884, 142, 2, 24, "Input",ExpressionUUID->"eb683a7c-4ae2-4920-870b-9af074c17cfb",
 CellTags->{"Database", "RG19."}],
Cell[7480234, 131888, 2893, 43, 216, "Output",ExpressionUUID->"ee141b33-8d36-4733-b715-5e5c09ae6fe6",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7483142, 131934, 625, 22, 38, "Text",ExpressionUUID->"80f30a0e-4f8b-4c98-ab07-102c54d63d5f",
 CellTags->{"Database", "RG19."}],
Cell[7483770, 131958, 1382, 42, 133, "FramedBox",ExpressionUUID->"3c2399ec-fba3-40b1-99e9-e62ae314b455",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"Plot2D", "Database", "RG19."}],
Cell[7485155, 132002, 149, 2, 26, "Commentary",ExpressionUUID->"fff5d2ab-950e-4d33-b925-b247ae539596",
 CellTags->{"Database", "RG19."}],
Cell[7485307, 132006, 729, 22, 38, "Text",ExpressionUUID->"a9b043b8-f5ec-4fde-aaa6-6f19e94a2bd2",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7486061, 132032, 236, 6, 24, "Input",ExpressionUUID->"f6a296c6-c0a2-4830-810f-ef9a52a1baf7",
 CellTags->{"Database", "RG19."}],
Cell[7486300, 132040, 1410, 23, 104, "Output",ExpressionUUID->"45a7ee28-fa3e-4b6a-a4ef-38c7acfefa88",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7487725, 132066, 1551, 38, 103, "Text",ExpressionUUID->"fe197e53-825d-43bd-a771-59588321771f",
 CellTags->{"Database", "RG19."}],
Cell[7489279, 132106, 467, 14, 51, "FramedBox",ExpressionUUID->"8267d24e-83d6-4a31-a9ba-c281cfb392d2",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->{"ReportedInterval", "Database", "RG19."}],
Cell[7489749, 132122, 958, 24, 54, "Text",ExpressionUUID->"4a8f756b-f7ad-431a-8619-9ad2af5c1d54",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7490732, 132150, 209, 3, 24, "Input",ExpressionUUID->"a58dda43-82da-49df-9870-1d174d20e15e",
 CellTags->{"Database", "RG19."}],
Cell[7490944, 132155, 4131, 84, 200, "Output",ExpressionUUID->"d8592e33-4ed9-48fa-8902-17393762762e",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7495090, 132242, 1187, 31, 69, "Text",ExpressionUUID->"68ffe976-6bf7-4c62-894d-ffb512688a4b",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7496302, 132277, 205, 4, 24, "Input",ExpressionUUID->"3ac515bc-d8ce-4f77-83a8-d8ca5a9f623f",
 CellTags->{"Database", "RG19."}],
Cell[7496510, 132283, 1772, 35, 72, "Output",ExpressionUUID->"0e8c1c8d-9eb9-41e0-82c9-cc8ebd31f04b",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7498297, 132321, 437, 13, 21, "Text",ExpressionUUID->"28e8b3b1-19f9-4ac0-bfd5-de2db6cf2ecc",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7498759, 132338, 233, 5, 41, "Input",ExpressionUUID->"8a9c311d-9b1b-4b3e-bbe8-f14f92da05ec",
 CellTags->{"Database", "RG19."}],
Cell[7498995, 132345, 662, 16, 24, "Output",ExpressionUUID->"61b98bbe-fb27-457b-910b-4bd19dcbdfa8",
 CellTags->{"Database", "RG19."}],
Cell[7499660, 132363, 13895, 227, 438, "Print",ExpressionUUID->"1c5e58ca-393f-4ec5-beab-2f1a1949f8ab",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7513570, 132593, 393, 11, 20, "Text",ExpressionUUID->"105f563c-551c-40db-8444-64442de81d48",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7513988, 132608, 205, 4, 24, "Input",ExpressionUUID->"c89563a2-51fd-4b4c-9315-c4a0710dcb74",
 CellTags->{"Database", "RG19."}],
Cell[7514196, 132614, 8726, 175, 360, "Output",ExpressionUUID->"7b2d3ae9-a8b2-4e33-b74b-d7478c7126a5",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7522937, 132792, 544, 14, 38, "Text",ExpressionUUID->"06ec706d-fdd8-44c8-b609-6bd53f59f9a3",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7523506, 132810, 254, 5, 24, "Input",ExpressionUUID->"86e32bc2-274e-45c2-8206-2161f148fa42",
 CellTags->{"Database", "RG19."}],
Cell[7523763, 132817, 954, 25, 131, "Output",ExpressionUUID->"8d38c99c-2568-4708-b441-e9f560629304",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7524732, 132845, 443, 12, 34, "Text",ExpressionUUID->"a0f07990-74b7-4276-b78d-161863b82f07",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7525200, 132861, 167, 2, 24, "Input",ExpressionUUID->"993138d5-d0c0-4851-bdd3-336bef7e015c",
 CellTags->{"Database", "RG19."}],
Cell[7525370, 132865, 651, 16, 24, "Output",ExpressionUUID->"4fa51032-9c32-4056-aeb8-d8f07e45872a",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7526036, 132884, 237, 5, 20, "Text",ExpressionUUID->"80e078d0-8e72-4024-814d-fdde7d9e7cf6",
 CellTags->{"Database", "RG19."}],
Cell[CellGroupData[{
Cell[7526298, 132893, 153, 2, 24, "Input",ExpressionUUID->"f1dd3ebf-70de-4799-9372-7f56ef9939da",
 CellTags->{"Database", "RG19."}],
Cell[7526454, 132897, 295, 5, 23, "Output",ExpressionUUID->"b71c509f-7fac-4f76-a1bc-eaa33bc4fce5",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7526786, 132907, 155, 2, 24, "Input",ExpressionUUID->"696fbf67-6d6e-4a36-ab5f-875ee48f709c",
 CellTags->{"Database", "RG19."}],
Cell[7526944, 132911, 293, 5, 23, "Output",ExpressionUUID->"f0508462-a5a9-4d2c-b14c-0c1ef10d3b94",
 CellTags->{"Database", "RG19."}]
}, Open  ]],
Cell[7527252, 132919, 229, 7, 20, "Text",ExpressionUUID->"d1a9bf02-f552-4374-b7d1-5e1ecf461f62",
 CellTags->{"Database", "RG19."}],
Cell[7527484, 132928, 170, 3, 20, "Text",ExpressionUUID->"b2806b3a-4d9b-442f-b745-e4ce07d6e2ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7527691, 132936, 201, 7, 63, "Section",ExpressionUUID->"362a1439-c548-49a1-877f-7518d0f44c3a",
 CellTags->{"20.", "RG20."}],
Cell[7527895, 132945, 522, 13, 34, "Text",ExpressionUUID->"af54b50b-178f-46d4-bc93-5db03cb0f378",
 Evaluatable->False,
 CellTags->"RG20."],
Cell[7528420, 132960, 783, 27, 64, "FramedBox",ExpressionUUID->"8edeb40e-fa64-4139-91ba-af1d10908acf",
 Evaluatable->False,
 PageBreakWithin->False,
 CellTags->"RG20."],
Cell[7529206, 132989, 162, 3, 20, "Text",ExpressionUUID->"c2d38fbb-66f4-4c9e-a3f7-d552593812ff",
 CellTags->"RG20."],
Cell[CellGroupData[{
Cell[7529393, 132996, 263, 8, 89, "Input",ExpressionUUID->"e22c50c9-d05f-40fd-94b8-485e8ad37cd1",
 CellTags->"RG20."],
Cell[7529659, 133006, 13760, 242, 365, "Print",ExpressionUUID->"45130692-f163-4cee-8376-a5ce459d6f14",
 CellTags->"RG20."]
}, Open  ]],
Cell[7543434, 133251, 277, 6, 21, "Text",ExpressionUUID->"2f734fe7-0a8c-49f2-855c-ea313f7db36a",
 CellTags->"RG20."],
Cell[CellGroupData[{
Cell[7543736, 133261, 267, 8, 89, "Input",ExpressionUUID->"9048fd1a-1edd-4643-bb43-4e8ad7584667",
 CellTags->"RG20."],
Cell[7544006, 133271, 28437, 488, 365, "Print",ExpressionUUID->"1f94aaa2-ade9-4bec-bfc7-f25f81cef97f",
 CellTags->"RG20."]
}, Open  ]],
Cell[7572458, 133762, 322, 8, 21, "Text",ExpressionUUID->"903c2994-bd9a-4764-aaef-410e2d6aafb0",
 CellTags->"RG20."],
Cell[CellGroupData[{
Cell[7572805, 133774, 246, 7, 73, "Input",ExpressionUUID->"abbf1530-e66c-40fe-b97e-867ec8f43908",
 CellTags->"RG20."],
Cell[7573054, 133783, 27027, 484, 365, "Print",ExpressionUUID->"420bdebb-b64e-48c3-a46d-705a04a995a4",
 CellTags->"RG20."]
}, Open  ]],
Cell[7600096, 134270, 334, 6, 21, "Text",ExpressionUUID->"88237dc9-3747-4b9e-a1f4-b3d3ba2baf0d",
 CellTags->"RG20."],
Cell[CellGroupData[{
Cell[7600455, 134280, 256, 7, 73, "Input",ExpressionUUID->"ef932c33-bb50-4eda-89fa-95ac4b400788",
 CellTags->"RG20."],
Cell[7600714, 134289, 33584, 601, 365, "Print",ExpressionUUID->"94792538-1c94-42d8-a7b3-a5f9c4b05b93",
 CellTags->"RG20."]
}, Open  ]],
Cell[7634313, 134893, 902, 29, 54, "Text",ExpressionUUID->"976e2ebe-a4ee-4641-912f-e4b68c00761e",
 Evaluatable->False,
 CellTags->"RG20."],
Cell[7635218, 134924, 774, 18, 51, "Text",ExpressionUUID->"d01968e4-b06c-4ae4-92c2-862d9e2ad656",
 Evaluatable->False,
 CellTags->"RG20."],
Cell[CellGroupData[{
Cell[7636017, 134946, 380, 10, 73, "Input",ExpressionUUID->"9a1deb8c-0770-4dfd-9eb9-1caf516d6659",
 CellTags->"RG20."],
Cell[7636400, 134958, 2186, 48, 365, "Print",ExpressionUUID->"5f9bef18-f3bc-4ad0-8ebc-a85d59dcee79",
 CellTags->"RG20."]
}, Open  ]],
Cell[7638601, 135009, 170, 3, 20, "Text",ExpressionUUID->"6436c37b-2f71-4f5a-97f5-1d8c56ab8aed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7638808, 135017, 147, 3, 60, "Section",ExpressionUUID->"d39bd8e9-1177-4306-8ca7-77cd6f4afc93",
 CellTags->{"What's Missing", "RG21.", "21."}],
Cell[7638958, 135022, 1612, 38, 85, "Text",ExpressionUUID->"9a73353d-4300-4462-8499-aefb7bebd549",
 CellTags->{"What's Missing", "RG21."}],
Cell[CellGroupData[{
Cell[7640595, 135064, 285, 7, 35, "Subsection",ExpressionUUID->"e52217ef-ac6b-4840-95cb-6737e8877556",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Features not discussed here", "What's Missing", "RG21."}],
Cell[7640883, 135073, 816, 18, 46, "Text",ExpressionUUID->"fd8eec84-ca17-40d5-b500-a4576be18653",
 CellTags->{"What's Missing", "RG21."}],
Cell[7641702, 135093, 1097, 27, 59, "Text",ExpressionUUID->"ceb071e0-1de7-468c-8c8b-c20fe4c299d0",
 CellTags->{"What's Missing", "RG21."}],
Cell[7642802, 135122, 2098, 48, 112, "Text",ExpressionUUID->"b9524a5d-6928-420f-b34f-2b1a1b0c1429",
 CellTags->{"What's Missing", "RG21."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7644937, 135175, 285, 7, 35, "Subsection",ExpressionUUID->"3cdc573b-b05b-4668-b37f-e2d853505dcc",
 Evaluatable->False,
 PageBreakWithin->Automatic,
 PageBreakBelow->Automatic,
 CellTags->{"Features left to the future", "What's Missing", "RG21."}],
Cell[7645225, 135184, 833, 18, 46, "Text",ExpressionUUID->"d0f11d3d-3d17-45eb-bf31-29c5ff3d53d7",
 CellTags->{"What's Missing", "RG21."}],
Cell[7646061, 135204, 940, 27, 46, "Text",ExpressionUUID->"0315375b-e20d-4040-84d6-b496835f53fd",
 CellTags->{"What's Missing", "RG21."}],
Cell[7647004, 135233, 170, 3, 20, "Text",ExpressionUUID->"5d418490-2bed-445c-b91b-c390932fd2ef"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7647223, 135242, 169, 3, 60, "Section",ExpressionUUID->"44e4ee72-4c79-4f62-a2c3-21d1a43cf67f",
 CellTags->{"Backward Compatibility", "RG22.", "22."}],
Cell[7647395, 135247, 1392, 36, 80, "Text",ExpressionUUID->"1fff4d7f-9ccf-4d2d-85f7-6e2690c95ca1",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[CellGroupData[{
Cell[7648812, 135287, 209, 7, 35, "Subsection",ExpressionUUID->"9ebbfb22-8058-4a5a-9efb-d34b4ab7b580",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7649024, 135296, 851, 27, 38, "Text",ExpressionUUID->"b21ddcf9-bf95-4b6a-9be3-5cd62d7c00e0",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7649912, 135328, 287, 11, 35, "Subsection",ExpressionUUID->"25945faa-a20f-4b29-8cad-53bf25b6ada2",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7650202, 135341, 868, 30, 34, "Text",ExpressionUUID->"dd3bfab9-da54-48f2-bff3-1c9bf08b2cff",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7651107, 135376, 428, 17, 35, "Subsection",ExpressionUUID->"ddbbf9b1-3e8a-47e2-aa9d-7ca7c0c1cb19",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7651538, 135395, 1544, 61, 38, "Text",ExpressionUUID->"0dde57cf-1cf9-4dfb-85d3-396d9aeb9640",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7653119, 135461, 166, 3, 35, "Subsection",ExpressionUUID->"889794e7-a81e-4555-9199-a60440190b8f",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7653288, 135466, 449, 15, 21, "Text",ExpressionUUID->"887cd1d7-580b-4b04-89b2-dca8ba6d1489",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[CellGroupData[{
Cell[7653762, 135485, 182, 3, 24, "Input",ExpressionUUID->"56f8e24b-c46a-4879-be75-1e2ebbb6c6e0",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7653947, 135490, 1615, 33, 72, "Output",ExpressionUUID->"9b05f338-6bae-46d3-b82a-0545bc42aa70",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[7655577, 135526, 584, 20, 34, "Text",ExpressionUUID->"551560ab-dcf3-4fcf-90f7-f9b2cc52d543",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[CellGroupData[{
Cell[7656186, 135550, 183, 3, 24, "Input",ExpressionUUID->"2a32a075-5288-426d-ad6d-9c0059c0028b",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7656372, 135555, 2026, 53, 88, "Output",ExpressionUUID->"4eae78a1-49f4-413c-938e-f8b9aab0c576",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7658447, 135614, 285, 10, 35, "Subsection",ExpressionUUID->"5eb1be0a-f892-4962-8d2e-780097fe1de0",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7658735, 135626, 729, 20, 38, "Text",ExpressionUUID->"186fd96c-5dd9-49ef-bb4d-be189043c513",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7659501, 135651, 170, 3, 35, "Subsection",ExpressionUUID->"e1f6db08-382c-49f4-88d1-f6d5f29c9027",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7659674, 135656, 571, 16, 38, "Text",ExpressionUUID->"c468bd9b-f498-4bdb-b335-33f1631ffe9c",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7660248, 135674, 922, 40, 21, "Text",ExpressionUUID->"da00a46c-c883-40b8-ae15-e1abff07de6b",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7661173, 135716, 152, 3, 20, "Text",ExpressionUUID->"883028bd-5da7-4eeb-a206-5dd71bc5c1b9",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7661328, 135721, 1199, 51, 21, "Text",ExpressionUUID->"83320e74-4ea2-4842-86f6-e556d83abd72",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[CellGroupData[{
Cell[7662564, 135777, 157, 3, 35, "Subsection",ExpressionUUID->"5f1d0e95-b0c4-4de5-8869-00cb0ed2b831",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7662724, 135782, 2425, 105, 38, "Text",ExpressionUUID->"634a8f1c-56db-4d25-9b47-47ae6bad8c77",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7665152, 135889, 392, 14, 21, "Text",ExpressionUUID->"bfad9ebf-115f-49c1-9b02-f312fee0821f",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[CellGroupData[{
Cell[7665569, 135907, 185, 3, 24, "Input",ExpressionUUID->"ad1429ae-c6a4-4a74-991b-dc7afa9f7a35",
 CellTags->{"Backward Compatibility", "RG22."}],
Cell[7665757, 135912, 4128, 98, 177, "Output",ExpressionUUID->"1634a1bc-1220-4446-bc19-63db0d4fb6ad",
 CellTags->{"Backward Compatibility", "RG22."}]
}, Open  ]],
Cell[7669900, 136013, 170, 3, 20, "Text",ExpressionUUID->"238c9db7-0b9f-41f7-84da-bc2e91f5c039"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

